/* Copyright 2017-2021 PaGMO development team

This file is part of the PaGMO library.

The PaGMO library is free software; you can redistribute it and/or modify
it under the terms of either:

  * the GNU Lesser General Public License as published by the Free
    Software Foundation; either version 3 of the License, or (at your
    option) any later version.

or

  * the GNU General Public License as published by the Free Software
    Foundation; either version 3 of the License, or (at your option) any
    later version.

or both in parallel, as here.

The PaGMO library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received copies of the GNU General Public License and the
GNU Lesser General Public License along with the PaGMO library.  If not,
see https://www.gnu.org/licenses/. */

#include <initializer_list>
#include <iterator>
#include <unordered_map>
#include <vector>

#include "cec2014_data.hpp"

namespace pagmo
{

namespace detail
{

namespace cec2014_data
{

namespace
{

const double rot_30_50[25000] = {-0.3369211299249118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38640302133094528,
                                 0,
                                 0,
                                 0,
                                 0.42619757018861848,
                                 0,
                                 0,
                                 0.64401610465897741,
                                 0,
                                 -0.31604550056309721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20221519971420171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21952583399553538,
                                 0.11210003392173989,
                                 0,
                                 0.10856891866214073,
                                 0,
                                 0,
                                 -0.36919754120012971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0095535540057854404,
                                 0,
                                 0,
                                 0.34164552363623585,
                                 0,
                                 0,
                                 0,
                                 0.75372656901734369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32593140538792592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062465243140297416,
                                 0.11256101577680314,
                                 0,
                                 -0.13919923448558019,
                                 0,
                                 0,
                                 -0.43710023718178631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41492511818620698,
                                 0,
                                 0,
                                 -0.12408567456594574,
                                 0,
                                 0,
                                 0,
                                 0.17996725287915541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74367112789039924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28214288499156787,
                                 0,
                                 -0.16978211478987143,
                                 0,
                                 0,
                                 0.59514041007664309,
                                 0,
                                 0,
                                 0.31617163212274718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39962019518868125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59721144727984898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43511947484894031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41348076637704811,
                                 0,
                                 -0.63046125188759983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96667811258953129,
                                 0,
                                 0.089328399173700584,
                                 0.56284788547522369,
                                 0,
                                 0.19081572547919126,
                                 0,
                                 0,
                                 0.15305276176462843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64060634857468635,
                                 0,
                                 0,
                                 -0.25838762444623764,
                                 0,
                                 0,
                                 0,
                                 0.19885247915743715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31417183065160842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32688889431658674,
                                 0,
                                 -0.49266012327285635,
                                 0,
                                 0,
                                 -0.29505523309521914,
                                 0,
                                 0,
                                 -0.63293142442149242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19683291155905541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35608125961335868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61910299337557295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84797382223305262,
                                 0,
                                 0.42019197530466995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3349527731190084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3496704801013612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092374908779128906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6315493224463784,
                                 0.25142582109959943,
                                 0,
                                 -0.28105802215618858,
                                 0,
                                 0,
                                 -0.23180591883457013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10949289653848759,
                                 0,
                                 0,
                                 0.42494537759838213,
                                 0,
                                 0,
                                 0,
                                 -0.45601011774388661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068486627580951004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068031440634873278,
                                 0,
                                 -0.091930931217162754,
                                 0,
                                 0,
                                 0.09013816005463407,
                                 0,
                                 0,
                                 -0.025235656453740762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1636313632116706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069340909712921395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38334853919657952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19457498536201456,
                                 0,
                                 -0.99419509176716525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11612270439839681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28440557755855794,
                                 0,
                                 0,
                                 0,
                                 -0.14042591775794275,
                                 0,
                                 0,
                                 0.33708815640971446,
                                 0,
                                 0.19353028005852588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13185355145724878,
                                 0,
                                 0.42529087209308714,
                                 -0.36274451963501131,
                                 0,
                                 0.0033618767560260523,
                                 0,
                                 -0.64627238159426392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028125961575082112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47135436740106607,
                                 0,
                                 0,
                                 0,
                                 -0.73052029027211562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030611229976091198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5286425131678264,
                                 -0.1178874468692534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0134984950043107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23978314589646571,
                                 0,
                                 -0.25608128056937129,
                                 0,
                                 0,
                                 0.27683562671973605,
                                 0,
                                 0,
                                 0.79784120722451812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29456178746224804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59039837578589316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011732264957338437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56517469280987076,
                                 0,
                                 -0.33802414166705386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40737316588895234,
                                 0,
                                 -0.027071695556306508,
                                 0.080827680845112368,
                                 0,
                                 -0.23967139969310816,
                                 0,
                                 0,
                                 0.7074692442608832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1789388871071883,
                                 0,
                                 0,
                                 0.50579381228105924,
                                 0,
                                 0,
                                 0,
                                 0.26511257471789551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27685323687554964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14157245087395787,
                                 0,
                                 0,
                                 0,
                                 0.084616825592767425,
                                 0,
                                 0,
                                 0.17646559135992296,
                                 0,
                                 -0.43200379867500366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53791424261146459,
                                 0,
                                 -0.27180360685053262,
                                 -0.28890206867275886,
                                 0,
                                 0.1968246146793195,
                                 0,
                                 -0.14059107541185448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49983070050043477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86498733760685198,
                                 0,
                                 0,
                                 0,
                                 0.1382489534566099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.5679078758913176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43834409643716044,
                                 0.32348173926399826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50949727348377227,
                                 0,
                                 0,
                                 0,
                                 0.069120479436078908,
                                 -0.26191099065645407,
                                 0,
                                 -0.82332199383580884,
                                 0,
                                 0,
                                 -0.018166967592011168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30066403605472514,
                                 0,
                                 0,
                                 -0.30709928720625046,
                                 0,
                                 0,
                                 0,
                                 0.24469922789213988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062042736402485775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31851772084917979,
                                 0,
                                 0,
                                 0,
                                 0.13814768174565722,
                                 0,
                                 0,
                                 0.42213861961585253,
                                 0,
                                 -0.13008717852135532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080174184759595132,
                                 0,
                                 0.67014895445723754,
                                 0.062360936058091225,
                                 0,
                                 0.21788614401705561,
                                 0,
                                 0.39550633615193198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14498948323081243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18144829900088189,
                                 0,
                                 -0.54569743886559074,
                                 0,
                                 0,
                                 -0.40043748463766865,
                                 0,
                                 0,
                                 0.46781598374463862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31475820664200843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37795241497354198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54769616065289617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45693954510366702,
                                 0,
                                 0.51927920451890686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53964908395835698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77617205975464176,
                                 0,
                                 0,
                                 0,
                                 0.18889163005666826,
                                 0,
                                 0,
                                 0.138350932351956,
                                 0,
                                 0.22709243124335693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15781177402874658,
                                 0,
                                 -0.2997256311199738,
                                 -0.12026114878482748,
                                 0,
                                 0.18164766759793227,
                                 0,
                                 -0.34359048372582279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10445996079824234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094434566974142028,
                                 0.69424911108436549,
                                 0,
                                 -0.27178223846365901,
                                 0,
                                 0,
                                 0.083839401014578707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43962576328859715,
                                 0,
                                 0,
                                 -0.27715582505043679,
                                 0,
                                 0,
                                 0,
                                 -0.046262274155977931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39494213866795802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66313971107814418,
                                 0.33132787966263366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79046165215730158,
                                 0,
                                 0.71906190914252976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.089134800186236665,
                                 0,
                                 0.67886528870187446,
                                 0.49478499561545103,
                                 0,
                                 0,
                                 -0.14411600586782997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031606691546720696,
                                 -0.56029497686142093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1403863897008745,
                                 0,
                                 0.43813589641971179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84665916119487294,
                                 0,
                                 -0.71748012966064412,
                                 0.066626563310351647,
                                 0,
                                 0,
                                 0.34464628347887094,
                                 0,
                                 0.29418820035429288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11901769326816625,
                                 0,
                                 0,
                                 0,
                                 -0.20196845040494676,
                                 0,
                                 0,
                                 0.55308082830100891,
                                 0,
                                 -0.077501416228620945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73931858109402027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11227559444100987,
                                 0,
                                 0,
                                 0,
                                 0.78774691407574671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18255548768877658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072910589499228851,
                                 -0.74549570520493103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54763007035567401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56070397568189023,
                                 0,
                                 -0.76461819725579261,
                                 0,
                                 0,
                                 -0.14717587064276244,
                                 0,
                                 0,
                                 -0.26431686420326617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48068957135720808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57423105235228167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63740805523180177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21600344027274493,
                                 0,
                                 -0.73508713105946888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63985625253025302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045569084589000136,
                                 0,
                                 0,
                                 0,
                                 -0.15663936536528342,
                                 0,
                                 0,
                                 0.67006355645109228,
                                 0,
                                 -0.040485643210152217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15790247076886565,
                                 0,
                                 -0.27057976369155845,
                                 0.57827515663983731,
                                 0,
                                 -0.1594185955154096,
                                 0,
                                 -0.13482321240121062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21592352344811316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073126058773984953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16980957118155407,
                                 0,
                                 0,
                                 0,
                                 0.8323072479046052,
                                 0,
                                 0,
                                 -0.3222898003599074,
                                 0,
                                 -0.078299318168004645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40383218730950987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22858058808170406,
                                 0,
                                 0,
                                 0,
                                 -0.080279217894122512,
                                 0,
                                 0,
                                 -0.15380666564613671,
                                 0,
                                 0.17751287962337989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14541420546282957,
                                 0,
                                 0.01373401300273374,
                                 0.46670023643606001,
                                 0,
                                 0.74972647887433119,
                                 0,
                                 -0.13951184607091879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25581727038009733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12537599994171197,
                                 0,
                                 0,
                                 0,
                                 0.83062016201939959,
                                 0,
                                 0,
                                 -0.13626888833501349,
                                 0,
                                 0.11039411802275778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30370795512008175,
                                 0,
                                 0.14546901919178215,
                                 0.21811771281248438,
                                 0,
                                 -0.060332539313656362,
                                 0,
                                 -0.24363833758257517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19904819726130218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54123026250262984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7135547643450546,
                                 0,
                                 0,
                                 0,
                                 -0.05871402241813227,
                                 0,
                                 0,
                                 -0.26412571639700089,
                                 0,
                                 -0.35033467435820881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044331554037627618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22547076318066761,
                                 0,
                                 0,
                                 0,
                                 0.12526569312368563,
                                 0,
                                 0,
                                 0.25008904959371819,
                                 0,
                                 0.74263835601483708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086326285128570296,
                                 0,
                                 -0.17636153780162397,
                                 -0.14890481721191776,
                                 0,
                                 -0.1165410621184888,
                                 0,
                                 0.35931542192544563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3405840936155512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63485434110182104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46801454946146842,
                                 0,
                                 0,
                                 0,
                                 0.15572864903241798,
                                 0,
                                 0,
                                 0.23845415995638178,
                                 0,
                                 -0.24021184583962796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48898754346598944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18695332886441518,
                                 0,
                                 0,
                                 0,
                                 0.36675460712783131,
                                 0,
                                 0,
                                 0.17197829997705011,
                                 0,
                                 -0.31726417130645979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69307712553585632,
                                 0,
                                 -0.095859715674477861,
                                 0.091058370673793743,
                                 0,
                                 -0.22786237443548274,
                                 0,
                                 0.0064187255862145354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38795276168333115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33958695672418404,
                                 0.17702742852061337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3283422398703103,
                                 0,
                                 -0.17901784249818997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.4265515142555791,
                                 0,
                                 0.54751155843882915,
                                 0.2476257060299169,
                                 0,
                                 0,
                                 0.017476011768817135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34363879475194659,
                                 0,
                                 0.3102608137905904,
                                 0,
                                 0,
                                 -0.40731335702711013,
                                 0,
                                 0,
                                 -0.45452434396960989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42253693876436832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86063047183406405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14563193209459452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17124618803301594,
                                 0,
                                 -0.42687540170475369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15714376203922137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2176198725304617,
                                 -0.34461896178568041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73843149483091741,
                                 0,
                                 0.26296952581147282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23818601297258277,
                                 0,
                                 0.34828862105145147,
                                 -0.27238043736475842,
                                 0,
                                 0,
                                 0.22475879546122673,
                                 0,
                                 0,
                                 0.72570240953796639,
                                 -0.19400671422305243,
                                 0,
                                 0.2103925844741702,
                                 0,
                                 0,
                                 0.29598245030381071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2994860397989898,
                                 0,
                                 0,
                                 -0.43998368041763958,
                                 0,
                                 0,
                                 0,
                                 0.14042052443279079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02917715522939027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31403790065231429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2819471282056818,
                                 0,
                                 0,
                                 0,
                                 0.23901939823752361,
                                 0,
                                 0,
                                 0.2210234341127314,
                                 0,
                                 0.84115508313951948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091446753896415073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37373786519781932,
                                 0,
                                 0,
                                 0,
                                 -0.49468580498627995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73530978569270888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48542074657496964,
                                 -0.58058642330887866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46934826978037963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78890762800326342,
                                 0,
                                 0,
                                 0,
                                 -0.29896678755877221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21808089304425918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19955338014198803,
                                 -0.81403455714000128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15646838405373129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19834496077844907,
                                 0,
                                 0,
                                 0,
                                 0.21735867060498548,
                                 0,
                                 0,
                                 0.27305226023903439,
                                 0,
                                 -0.099599442948382508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18922293668108747,
                                 0,
                                 -0.26731938580066245,
                                 -0.36925533491169044,
                                 0,
                                 0.47342511982160429,
                                 0,
                                 0.24887187477060507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54704101190643539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1521656622229151,
                                 0,
                                 -0.83423559411700965,
                                 0,
                                 0,
                                 0.31431232402854159,
                                 0,
                                 0,
                                 0.45711256105733017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45476125243201476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10358904554278339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31866723977461603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13923381013561864,
                                 0,
                                 0.10582394779357035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31139342604797254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18400265871303673,
                                 1.0234692216878898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6305433730008938,
                                 0,
                                 -0.48305775820999247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61112551455583364,
                                 0,
                                 -0.50194688528528753,
                                 -0.34942559824761543,
                                 0,
                                 0,
                                 0.18974152464933675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21628862161492846,
                                 0,
                                 -0.30446641640416156,
                                 0,
                                 0,
                                 0.33617282318225239,
                                 0,
                                 0,
                                 -0.44866134906294219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22643206151014839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69508373115298561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9025296133029701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7948791375631894,
                                 0,
                                 0.28885938110366405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27464351600835024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31707257483151297,
                                 -0.32415347491748492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43884252431660864,
                                 0,
                                 -0.51654003004503157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24257073459447587,
                                 0,
                                 -0.8278477874975575,
                                 1.0686584051237669,
                                 0,
                                 0,
                                 -0.074279667302949937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19683463382144328,
                                 -0.46110444631025704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33420357631765846,
                                 0,
                                 -0.44399752567507506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1304914431594224,
                                 0,
                                 0.17819764312286263,
                                 0.39167192831054376,
                                 0,
                                 0,
                                 1.2981892430095283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09337860699886627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38799131656214503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42451186655264628,
                                 0,
                                 0,
                                 0,
                                 0.46491764319619877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30871660044930621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.99237347345634852,
                                 0.023375992377338558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29500824619586363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6568005004300641,
                                 0.74560750632111927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65124111224062287,
                                 0,
                                 0.88812424903919573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022205951327843615,
                                 0,
                                 -0.5110884571977069,
                                 0.46965363303915209,
                                 0,
                                 0,
                                 0.13446626894857572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047319524534852012,
                                 0,
                                 -0.082186591164110256,
                                 0,
                                 0,
                                 0.89760701469705828,
                                 0,
                                 0,
                                 -0.43764417170867354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28625543059392083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19442077416922296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67652838243071278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32656620579946888,
                                 0,
                                 0.14037286408595256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31551986106797936,
                                 -0.28754016733482257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056046177729267385,
                                 0.12059588507085497,
                                 0.25678923297216905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47754165632582002,
                                 0,
                                 0.057660104237653942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085138572734056409,
                                 0.24224610452378365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68773734387898244,
                                 0,
                                 0,
                                 0,
                                 0.25181396591051075,
                                 0,
                                 -0.13700064852664756,
                                 0,
                                 -0.92716453221267092,
                                 0,
                                 0.17823392451088785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40800434765351262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06113069746395583,
                                 0.49959404098066629,
                                 0.43816451496236186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75514291186465998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26428908292480641,
                                 0,
                                 0.48743641220099398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18668176216680013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13275191774380668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41016075351583126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68691486298693283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40463198100855191,
                                 0,
                                 -0.30174936553781795,
                                 0,
                                 -0.53605883166379831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34918203749397098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88299317581784464,
                                 -0.032844223490058722,
                                 -0.46410543249892905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48828482777757676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53186887065148525,
                                 0,
                                 0.22558612304046172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75676627754615489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27699207760534639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030755252418137313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12593931111846279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19648564585603684,
                                 0,
                                 0.23406143994246717,
                                 0,
                                 -0.76571247697947609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0045202691946566453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98730450399529834,
                                 0.46636614014409361,
                                 -0.6673525299871611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27212142381127635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57019165963734408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048872904388971919,
                                 0,
                                 0,
                                 0.56766009329985301,
                                 0,
                                 -0.067932655405017819,
                                 0,
                                 0,
                                 -0.015107030030684445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28966099998326317,
                                 0,
                                 0,
                                 0.35593646773135779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36717515843571891,
                                 0,
                                 0,
                                 0.23445401057691378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51932141970117396,
                                 0.51633613392291489,
                                 0.4415655748106736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22081408594296476,
                                 0,
                                 0.13620978982229154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057230417803406097,
                                 0.058859133396035497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050002395449499276,
                                 0,
                                 0,
                                 0,
                                 -0.37040720114568992,
                                 0.26701219895265044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59980552358563133,
                                 -0.41755872669863148,
                                 -0.33375273752294066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17429694017169797,
                                 0,
                                 0.14534016060718113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31691063544220521,
                                 0.14169950846994497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17677445683175055,
                                 0,
                                 0,
                                 0,
                                 0.28271565866908371,
                                 0.5771351991243272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021277986651789985,
                                 -0.10082168685411694,
                                 0.44182679034457578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31892597015325619,
                                 0,
                                 -0.29349181501110649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14059704321402233,
                                 0.03199176251916136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25660164579827283,
                                 0,
                                 0,
                                 0,
                                 0.43197182551269542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33882882143285475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21923465628185829,
                                 0,
                                 0,
                                 0.051870614931367992,
                                 0,
                                 0,
                                 0,
                                 0.50014152671663614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031434657579369155,
                                 -0.052979796408944319,
                                 0.968497083666916,
                                 -0.12055161114806613,
                                 0,
                                 0,
                                 0,
                                 -1.0485571778404292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060660254853881011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82606587036220369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51366939996363192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24224954626109635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94476739009139021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33381442391543475,
                                 0,
                                 0.27540676598930269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20485061991682685,
                                 0,
                                 0.50200117775174447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13931441960562976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25925193565083149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76860363843472812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1692909164476763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060498673827939421,
                                 0,
                                 -0.0014493326340153656,
                                 0,
                                 -0.079242354142951318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026971168121214639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5281735164798711,
                                 -1.0276627379929106,
                                 -0.054470570513668784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68469926274537829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1915672843996514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51414778139275197,
                                 0,
                                 0,
                                 0.31659392774034212,
                                 0,
                                 -0.13756370267365586,
                                 0,
                                 0,
                                 0.73634286794747772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18676996380394631,
                                 0,
                                 0,
                                 0.048688899959630383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018549919827019118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18488483704319972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28674258916527501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13506570434218781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3241692594476201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072114358339949725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29254201024517129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63690651107571994,
                                 0,
                                 0.73597457636932295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66092451618244819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082389239577209727,
                                 0,
                                 0,
                                 0.087417559923286065,
                                 0,
                                 0.17685792263826677,
                                 0,
                                 0,
                                 -0.057640003260775147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39568384889669167,
                                 0,
                                 0,
                                 0.59767796599358236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019058154165437755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46625126063564548,
                                 0,
                                 -0.15927700108877424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40739748982134155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57717881206611321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011275322698703183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50794229019357862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13531009982947026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12199643617038713,
                                 0,
                                 0,
                                 -0.60503366916184897,
                                 0,
                                 0.014989358020940924,
                                 0,
                                 0,
                                 0.30819968764981848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24718472901064248,
                                 0,
                                 0,
                                 0.39306774156716251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53844966114606596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.093408032305761779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45465145300974596,
                                 0,
                                 0,
                                 0.36886753273193151,
                                 0,
                                 0,
                                 0,
                                 0.10096965752939248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92133868703964028,
                                 0.14652622623159553,
                                 -0.37490493235017502,
                                 -0.25060451495775388,
                                 0,
                                 0,
                                 0,
                                 -0.70423443652039719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38206502034621415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27629083323874787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42078623382258096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91814592002457363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0529148008549383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59345831700138219,
                                 0,
                                 -0.42977887742445042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019624155267716787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59160291861315895,
                                 0,
                                 0,
                                 0.30501163772448275,
                                 0,
                                 0.1675649753473625,
                                 0,
                                 0,
                                 0.1471427760845358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5761107107864597,
                                 0,
                                 0,
                                 0.25219022579888645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33370091621488013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081445915692627727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14047718859389458,
                                 0,
                                 0,
                                 0.54691236492897866,
                                 0,
                                 0,
                                 0,
                                 0.29124448233974942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50391848209599788,
                                 -0.039451733825152449,
                                 -0.22871701336965328,
                                 -0.15316450695026013,
                                 0,
                                 0,
                                 0,
                                 -0.20246401487182622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0487545287719822,
                                 0,
                                 0,
                                 1.054730754106644,
                                 0,
                                 0.37227171646535473,
                                 0,
                                 0.68449941366326927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72107323537762014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21312690909781851,
                                 -0.032668958666834891,
                                 -0.37161146568991821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42802415043872943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11035525782922664,
                                 0,
                                 -0.64342320369781003,
                                 0,
                                 0.28339796923609356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73724460102021405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19527497201981614,
                                 -0.20393549909050154,
                                 -0.7735858123337388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69276352644446682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84762342633640519,
                                 0,
                                 -0.0031844041843240856,
                                 0,
                                 0.26286265369040296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0515009673913067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023328396570435617,
                                 -0.45672415516225656,
                                 -0.30036084956789788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05501730308399233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25884893558814126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76442472581919196,
                                 0,
                                 0,
                                 0.2935146168952083,
                                 0,
                                 0,
                                 0,
                                 1.049425298221049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.248413509912361,
                                 0.42296720565591034,
                                 0.25450555171214256,
                                 0.026143479703388983,
                                 0,
                                 0,
                                 0,
                                 0.26461690660610504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10860437900831726,
                                 0,
                                 0.45927534230044209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51292249196842743,
                                 0.30371697743728837,
                                 -0.10066706784802459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40929576311884242,
                                 0,
                                 0.21664052207543222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089315418954979825,
                                 0.059353799396733554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35352826224218864,
                                 0,
                                 0,
                                 0,
                                 0.26955579936793028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14795839765222774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48804984450411604,
                                 0,
                                 0,
                                 -0.10048980245258926,
                                 0,
                                 -0.26524453490799876,
                                 0,
                                 0,
                                 -0.43489261914585026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33329310031909903,
                                 0,
                                 0,
                                 0.51268943250916243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31047779797233527,
                                 0,
                                 0,
                                 0.29875414156397395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096875538780229808,
                                 0.21106171358148176,
                                 -0.53236646836907775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31969780896312311,
                                 0,
                                 -0.069731893084282431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50977223065649624,
                                 0.37757425445404463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080490247193836226,
                                 0,
                                 0,
                                 0,
                                 -0.23962896040212833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2906242306199186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0366123521941071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31437800941811822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024221133352679614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095182616031341261,
                                 0,
                                 -0.50905836558994422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22010254634589901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32592988637237574,
                                 0,
                                 0,
                                 0.041080198622296234,
                                 0,
                                 -0.91313566638666233,
                                 0,
                                 0,
                                 -0.010137947290939586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012301650874646764,
                                 0,
                                 0,
                                 -0.036146721688814054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090882100749908268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19461261063644222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41879045583280589,
                                 0,
                                 0,
                                 -0.1872572409253897,
                                 0,
                                 0,
                                 0,
                                 -0.27864192338129246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79667174180619615,
                                 -0.89469909600526687,
                                 0.62817999921574108,
                                 -0.46381822057945998,
                                 0,
                                 0,
                                 0,
                                 0.67544560534085196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25406669629161288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8440733963083944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45360460615500892,
                                 0,
                                 0,
                                 -0.41775633938475887,
                                 0,
                                 0,
                                 0,
                                 0.051313990065234655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71347553583349521,
                                 0.39689337496298366,
                                 0.45742625308048046,
                                 0.63690314164021711,
                                 0,
                                 0,
                                 0,
                                 -0.16589200542354363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22116787676726934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63432649102069949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11079602761245916,
                                 0,
                                 0,
                                 -0.42140329603740834,
                                 0,
                                 0,
                                 0,
                                 0.090544174447337422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33104616779780527,
                                 -0.77866293068728931,
                                 -0.45153600913791664,
                                 0.69469571892366644,
                                 0,
                                 0,
                                 0,
                                 0.022418396636767264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64206270587683378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89191560891113231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41697264417607582,
                                 0,
                                 0,
                                 0.34331460971750266,
                                 0,
                                 0,
                                 0,
                                 0.32213700491489738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30705318453925512,
                                 -0.24657455566165482,
                                 -0.10870714749169738,
                                 0.53538289059520794,
                                 0,
                                 0,
                                 0,
                                 0.07576543457713282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11493248830664742,
                                 0,
                                 0,
                                 0,
                                 0.1246680729385153,
                                 0,
                                 0.65115457158822077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34901200484520178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43178794938192777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20911375079061562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45659262144971169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26249496320225929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2548504938535644,
                                 -0.5749090034084241,
                                 0.28373024639944816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088176164238417731,
                                 0,
                                 0.28798718354539099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020152225847173605,
                                 0.20516535587710993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16411760186068217,
                                 0,
                                 0,
                                 0,
                                 -0.54311990262610832,
                                 -0.29434904309734355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039472948572021889,
                                 -0.14152921632235571,
                                 0.23129547212902829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44710752866997527,
                                 0,
                                 0.10056367670868044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47440676805578036,
                                 0.57025716348840483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12023562760956058,
                                 0,
                                 0,
                                 0,
                                 0.25207657003045875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1557241297006296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19044889519835229,
                                 0,
                                 0,
                                 0.075593316133521715,
                                 0,
                                 0,
                                 0,
                                 -0.28127134200169923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53717605029847371,
                                 -0.88218771348603187,
                                 -0.1643694123562299,
                                 -0.043814025165619552,
                                 0,
                                 0,
                                 0,
                                 -0.35037453511771011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74548446115735156,
                                 0,
                                 0,
                                 0.42013872823363246,
                                 0,
                                 -0.76311590612360658,
                                 0,
                                 -0.76931534531978563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58673259348741369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0016261177998237869,
                                 -0.035949277293439039,
                                 0.35794477506590255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49874362007985013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61022179749976035,
                                 0,
                                 -0.10069768374686465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29200020392866566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56468091592598668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44296165075234756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13094141591391029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29335878077723698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1904576344167016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43561163851600532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074811753377766466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74983115556509161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49870724001599487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52586780404595901,
                                 0,
                                 0.17791563692168999,
                                 0,
                                 0,
                                 0,
                                 -0.044862668332253532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11782024132142614,
                                 0.21576951915874215,
                                 -0.06765494640778992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29421936168328688,
                                 0,
                                 0.45230094567355417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43692362772522225,
                                 0.4361169192909703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50326535311275677,
                                 0,
                                 0,
                                 0,
                                 0.08634023921092665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77658859389777835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0077747415817756155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54333962812683845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45071594002373427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54947133679917681,
                                 0,
                                 -0.26969409733685096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33515889038955188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13105504952614733,
                                 0,
                                 0,
                                 0.31465036235030097,
                                 0,
                                 0.11273219102544571,
                                 0,
                                 0,
                                 -0.38519628283060109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46947663920387489,
                                 0,
                                 0,
                                 -0.17737100039409226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59877769824910132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48989703717049254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30398017330373295,
                                 0,
                                 0,
                                 -1.121638499263963,
                                 0,
                                 0,
                                 0,
                                 0.74746033640758491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14036434411774223,
                                 0.03317486541444703,
                                 -0.24653167509539764,
                                 -0.74910532267712193,
                                 0,
                                 0,
                                 0,
                                 0.13468481557706913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35590253095919022,
                                 0,
                                 -0.01503048901642812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11866684553502546,
                                 0.020854508691093961,
                                 -0.018755676096375937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16470272142864489,
                                 0,
                                 -0.72210769877978487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43018728692750635,
                                 0.46171526886815034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035991275899444709,
                                 0,
                                 0,
                                 0,
                                 -0.19183743088398986,
                                 0.1385654200203621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094463936831286094,
                                 0.15425101249626655,
                                 0,
                                 -0.4910662365396915,
                                 0,
                                 0,
                                 0,
                                 0.33112118418640135,
                                 0,
                                 0,
                                 0,
                                 0.29912088401288273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070953726381219745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15836518220992635,
                                 -0.11538421497376444,
                                 0,
                                 -0.68146514535153535,
                                 0,
                                 0,
                                 0,
                                 0.48522387420214996,
                                 -0.61652688518290821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60042703892239546,
                                 0,
                                 0,
                                 -0.065472444637543703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03534479032494544,
                                 0,
                                 -0.12363457235919868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33647915816439689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23498533391386453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65867702807619366,
                                 0.059375438762238844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039000714421010718,
                                 0,
                                 0,
                                 0.34318841093376717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052636130169773941,
                                 0,
                                 0.137777353110977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30866362685870741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3121712119246118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27713819857418509,
                                 0.43589578102846288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46109386016351694,
                                 0,
                                 -0.24303371597734863,
                                 0.3431069992530319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58633944013171224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11650275945623016,
                                 -0.66059835693507019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37220136657387037,
                                 0,
                                 -0.36148369345655074,
                                 -0.46018754336271445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2627927412869559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053065917200737535,
                                 0,
                                 0.33517487075175095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60892898380930349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21717653626028213,
                                 0,
                                 0,
                                 0.53876659757343937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1172029708421384,
                                 0,
                                 -0.82341074776164391,
                                 0,
                                 -0.30638842853794374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1359156076232749,
                                 0.25845482137762837,
                                 0,
                                 0.30119002993445426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83861310693607749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47315195817861161,
                                 0,
                                 -0.058798787148112111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061599062639322855,
                                 0.082036774598687412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1054835624516553,
                                 0,
                                 0,
                                 -0.041700439800605629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66180983377173874,
                                 0,
                                 -1.0566417990266705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24123819600117946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45491164498065056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36664158363914218,
                                 0.42232314279232164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37734448551510175,
                                 -0.25516765492133453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33553394769062928,
                                 0,
                                 0,
                                 -0.4616842523248102,
                                 0,
                                 -0.37975485175989832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098836192809760359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37841514432552853,
                                 0.052302434595916145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61223964403983699,
                                 -0.40223718813564463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10606846000446653,
                                 0,
                                 0,
                                 -0.35955145307085912,
                                 0,
                                 0.4188467330929036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038391993845721013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4954429005704285,
                                 -0.11617937601097406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66449917617227872,
                                 0,
                                 0,
                                 -0.061243572707226281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92125073712088446,
                                 0,
                                 -0.18462838983033397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73406978701435444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23828482541368032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6707159798248219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25049383810824277,
                                 -0.12967598116062606,
                                 0,
                                 0.13586662138786429,
                                 0,
                                 0,
                                 0,
                                 -0.36987277247490025,
                                 0,
                                 0,
                                 0,
                                 -0.24259316076996473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27106506015899479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21733477735799139,
                                 0.2455861212643895,
                                 0,
                                 -0.27465758293471887,
                                 0,
                                 0,
                                 0.16039460142740941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21468894575792777,
                                 0.63945536055312657,
                                 0,
                                 0.31948661760540842,
                                 0,
                                 0,
                                 0,
                                 -0.018109747958104216,
                                 0,
                                 0,
                                 0,
                                 0.012451876943018251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088690999653471742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59406521417333913,
                                 0.15222068385175017,
                                 0,
                                 -0.18103494281511207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33552862038285358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34843270838745322,
                                 0,
                                 0,
                                 0.62249018654491173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0461024595077975,
                                 0,
                                 -0.26117245696980063,
                                 0,
                                 0.018348329569852329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011418264273638096,
                                 0.37962529654770572,
                                 0,
                                 -0.41174727428213231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10615663354686011,
                                 0.26133340656363169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31300179277404561,
                                 0.11776747392048284,
                                 0,
                                 -0.25961036344507465,
                                 0,
                                 0,
                                 0,
                                 0.3354634277225898,
                                 0,
                                 0,
                                 0,
                                 -0.73216202521635987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28545316936592602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062518230121806864,
                                 0.0050074302404402027,
                                 0,
                                 0.13584532287808529,
                                 0,
                                 0,
                                 0,
                                 0.50067682411900405,
                                 0.1129926572962833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50888214664306342,
                                 0,
                                 0,
                                 -0.0041161879021810455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93458178726021679,
                                 0,
                                 -0.0024354528299578085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96309565351260906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094356772855774762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46904882406775805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66657940503804025,
                                 0,
                                 0,
                                 0.23347536594019497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68810060993022482,
                                 0,
                                 0.30183689912963596,
                                 0,
                                 0.23750679139679773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35883059466658718,
                                 -0.28099655803528678,
                                 0,
                                 0.49551262304696236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33072459191752546,
                                 0,
                                 -0.46582061030064059,
                                 -0.93906928520655808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27870755594549146,
                                 0,
                                 0,
                                 -0.13855442408566956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2398139098868485,
                                 0,
                                 -0.032397868827480789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55245060350651842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12697381614484882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42069385775616952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42739802484990752,
                                 -0.027533851372036622,
                                 0,
                                 -0.12627349185160222,
                                 0,
                                 0,
                                 0,
                                 -0.26222358281010949,
                                 0,
                                 0,
                                 0,
                                 -0.38633449585321655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34355494413111148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25553114617565881,
                                 0.076858272898073718,
                                 0,
                                 -0.46518339200928366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44905425853383335,
                                 -0.76171783990068664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10499310537215553,
                                 -0.20631330734590392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29112001014458033,
                                 0,
                                 0,
                                 0.16376592558866651,
                                 0,
                                 -0.15642155999983373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16884794693063815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017802007172426741,
                                 0.054658605833587004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41560517267790609,
                                 -0.17631945481706429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21935735647625865,
                                 0,
                                 0,
                                 0.37315711971217275,
                                 0,
                                 -0.32696667129894558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7061219623215893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69533635861284737,
                                 0.11194734453321681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45458369190396469,
                                 0,
                                 -0.49579468721415443,
                                 -0.083423150397124918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21108532304730313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40285867554884008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43175549440760896,
                                 -0.22365168866940516,
                                 0,
                                 0.22156472785489145,
                                 0,
                                 0,
                                 0,
                                 0.013859062620649343,
                                 0,
                                 0,
                                 0,
                                 -0.34261365975938363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58545342479551743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078945832580080227,
                                 -0.05506350091459674,
                                 0,
                                 -0.2873755981634738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34796785583622802,
                                 0.020798239841523319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30565223075676773,
                                 0,
                                 0.60993628804437328,
                                 -0.36667787232450805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52781396422590798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48872822388887144,
                                 -0.46429269986145461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22721817438687711,
                                 0,
                                 0.3773854186735458,
                                 0.5471853912055723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22829215203743647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19276983238091938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53547615725756015,
                                 0,
                                 0,
                                 0.07328224422167047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13808023743703146,
                                 0,
                                 0.76973916247887852,
                                 0,
                                 0.26325090983992072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68090173523611563,
                                 0.64894318130073536,
                                 0,
                                 0.23191774340241234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49251554018627847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.99031063526639451,
                                 0,
                                 -0.52493490551719924,
                                 0,
                                 0,
                                 0.1733232722154493,
                                 0,
                                 -0.2371552585958728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096155705111431455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1392097445264182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44646397785088898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59753914733218183,
                                 0,
                                 0,
                                 -1.0404860543616015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15024580802675988,
                                 0,
                                 0.12541967764529566,
                                 0,
                                 0.20441203969434663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33500973441470216,
                                 -0.061379151254078723,
                                 0,
                                 -0.86785524522263668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41063352675576148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38876052051545162,
                                 0,
                                 0.21523689944993576,
                                 0,
                                 0,
                                 0.47779355480448715,
                                 0,
                                 -1.1210992701119979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.94884493546547188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39856455582689904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070460552807020904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12878526223193226,
                                 0,
                                 0,
                                 0.34668398067961176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45429850589998555,
                                 0,
                                 -0.16107718700969773,
                                 0,
                                 0.72312431467494565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0475461191756539,
                                 0.66902541571483731,
                                 0,
                                 0.18341776225630751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13028834984862178,
                                 0,
                                 0,
                                 0,
                                 0.25727799906002824,
                                 -0.3808834375804348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54512464350524259,
                                 0,
                                 -0.22362859989883874,
                                 0.47925053528813633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46030873873214817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0757315890940302,
                                 0,
                                 0.93970414137468661,
                                 0,
                                 0,
                                 0.1116700980507295,
                                 0,
                                 -0.5465489020430554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65382641264715746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54324404193023457,
                                 0,
                                 0,
                                 -0.41633351551160197,
                                 -0.3253495664851983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.036818961511180248,
                                 0,
                                 0,
                                 -1.2580330511122924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15758675332486921,
                                 0,
                                 -0.33794971650644057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14551969761343464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052189575043677452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25772837365553725,
                                 0,
                                 -0.059521776669765505,
                                 0,
                                 0,
                                 -0.74920819302640496,
                                 0,
                                 -0.43546332432865337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1013598579576098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65914305848676791,
                                 0,
                                 0.12188448322095653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40164843985771914,
                                 -0.51551617001501449,
                                 0,
                                 0.29740184023895561,
                                 0,
                                 0,
                                 0,
                                 0.082744704337340991,
                                 0,
                                 0,
                                 0,
                                 0.19814851689848137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48710970333818115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12690806577282887,
                                 0.32177270624990678,
                                 0,
                                 -0.25804885546853351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24082744793609959,
                                 -0.13204184862856419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45449639170686668,
                                 0.094967920319844856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1402999686668209,
                                 0,
                                 0,
                                 -0.031134536060137191,
                                 0,
                                 0.54920344788061659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62185476347725477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26069758903058116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5407916367670158,
                                 0,
                                 0,
                                 -0.3926103264013564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37046191181876359,
                                 0,
                                 -0.8799708408721959,
                                 0,
                                 0.74657999603279535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52210844103200826,
                                 -0.10417417470129485,
                                 0,
                                 0.15370993389909551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076937702875543995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1404559496221367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0243306195333617,
                                 0,
                                 0,
                                 -0.40766781972399824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14333835658440999,
                                 0,
                                 0.62888171697648709,
                                 0,
                                 0.15353898872809699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077637254846938009,
                                 0.43634201759976166,
                                 0,
                                 0.33280453649977282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38038527840329983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062273348421075493,
                                 -0.0028284029237843067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19741448787997115,
                                 0.50049498727779418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76822293535267527,
                                 0,
                                 0,
                                 -0.17393130226276868,
                                 0,
                                 0.29362660075798475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0033407958371513558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45291178127790732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34511631182125213,
                                 0,
                                 0,
                                 0.22728185197657452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071935581805880749,
                                 0,
                                 0.47382015981901604,
                                 0,
                                 0.95928896200409264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19743943033664779,
                                 -0.19397151075066932,
                                 0,
                                 0.58921645565209935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0577268364881096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22524782206094507,
                                 0.43960200429168178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14421801164159487,
                                 -0.23409242182593831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23181163458747889,
                                 0,
                                 0,
                                 0.66517053504292389,
                                 0,
                                 0.33241871219809599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27152297288166916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1848583576743999,
                                 0,
                                 0.73275710305500219,
                                 0,
                                 0,
                                 -0.53636645122557347,
                                 0,
                                 0.88653809478700418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14378520828601327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49031406142512957,
                                 0,
                                 0,
                                 0.77065613327081017,
                                 0.31417735487994358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037140660257830693,
                                 0,
                                 0,
                                 -0.39970967250993633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42882851473635125,
                                 0,
                                 0.86208943328416265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92722638445890271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17138697076271844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12309254991160623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41986296193119138,
                                 -0.022481765387288161,
                                 0,
                                 -0.22824054729798543,
                                 0,
                                 0,
                                 0,
                                 -0.6681710529607845,
                                 0,
                                 0,
                                 0,
                                 0.039562241707750169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15146520701714913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093945230740895266,
                                 -0.52535816551753456,
                                 0,
                                 -0.013334008155441085,
                                 0,
                                 0,
                                 0.15706349166520053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2354984678045936,
                                 -0.045554786100838698,
                                 0,
                                 0.52715694038464267,
                                 0,
                                 0,
                                 0,
                                 0.28421344073645571,
                                 0,
                                 0,
                                 0,
                                 -0.085251022877028168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15029771992069502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032920516300493925,
                                 -0.70438779464314294,
                                 0,
                                 -0.17894553883604464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63858975733936307,
                                 -0.15815503707787804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18078788898504319,
                                 -0.62058648171812192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28233091940607358,
                                 0,
                                 0,
                                 -0.13353498209205428,
                                 0,
                                 0.22502344347431527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034646419225674019,
                                 0,
                                 0,
                                 0,
                                 0.20727552509261721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14872845397190887,
                                 -0.46637179194880429,
                                 0,
                                 -0.2957245470170754,
                                 0,
                                 0,
                                 0,
                                 0.19406034177514295,
                                 0,
                                 0,
                                 0,
                                 -0.026921543922984972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29756849240970562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68798279102585913,
                                 -0.13615250264272846,
                                 0,
                                 0.10569782148671544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62742285483843063,
                                 0,
                                 0.40865533068747262,
                                 0,
                                 0,
                                 -1.0218229378486767,
                                 0,
                                 -0.80491478243293668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41975552301617203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60832075571840938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75397061253274922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28019833498025631,
                                 0,
                                 0,
                                 -0.84382430164144073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12083047488626011,
                                 0,
                                 -0.3789710968875496,
                                 0,
                                 -0.63312711775392616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20106055146276053,
                                 0.71767127845862233,
                                 0,
                                 0.5788856134879814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10445957701994599,
                                 0.39874477206976428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63267631804689806,
                                 0,
                                 0,
                                 0,
                                 -0.50149614184052838,
                                 0,
                                 0,
                                 -0.59802736908336029,
                                 -0.68356583943540983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1594565527969945,
                                 0,
                                 0,
                                 0,
                                 -0.38961640100505129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062474367995855519,
                                 -0.16546334907158247,
                                 0,
                                 0.74711598314661221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040562463276037769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25993291579213762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11856296652050104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42610917387344005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36695078201443038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77492611541393275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0046291938280560857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30128281753516184,
                                 0,
                                 0.67043957350999195,
                                 0.19499712085984813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44451938954183828,
                                 -0.29753778400955466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18723077776175751,
                                 0,
                                 0,
                                 0.31703714422358931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0757455867768146,
                                 0,
                                 -0.0042667763344745313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36043303747127786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7470933592555159,
                                 0,
                                 0.9751229657500835,
                                 0,
                                 0,
                                 0,
                                 -0.63570205874221908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15743059976085505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95924730668200375,
                                 0,
                                 -0.52259213800459769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48541176617400639,
                                 0,
                                 0.13337912345477493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10076201975063609,
                                 0,
                                 0,
                                 0,
                                 -0.67046614785958725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38319222350683646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12534035599412954,
                                 0,
                                 -0.0097226815523990817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51114914113014376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91293832806383968,
                                 0,
                                 0.77286267851950807,
                                 0,
                                 0,
                                 0,
                                 0.78730492073024838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26982733495776101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2596946691490209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068419292365828541,
                                 0,
                                 -0.067430215584931022,
                                 0,
                                 0,
                                 0,
                                 -0.051077432945874662,
                                 0,
                                 0,
                                 0,
                                 -0.17383923759151682,
                                 -0.41999314992371295,
                                 0,
                                 0,
                                 -0.45805442346327596,
                                 0,
                                 0,
                                 -0.33052820681187089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56765999820788404,
                                 0,
                                 0.86861503887676705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18053348205894773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34221536563809374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16825405079949496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24767674262698186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078428471649137063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25922409754724535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51724332537767759,
                                 0,
                                 0.023146781842430516,
                                 0.42143611779481521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19038187508395518,
                                 -0.011629845755006755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61649956091169733,
                                 0,
                                 0,
                                 0.26583042420751657,
                                 0,
                                 0,
                                 0.81490362229751057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14849786106006763,
                                 0,
                                 0,
                                 0,
                                 0.2009830427209055,
                                 0,
                                 0,
                                 -0.034451819640915121,
                                 0.20591951557651081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7986771637605421,
                                 0,
                                 0,
                                 0,
                                 0.44603088534641688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90703977470784403,
                                 0.34905287458098927,
                                 0,
                                 0.43568742768715318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040164446064803211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23169970994399863,
                                 0,
                                 0.26972615387017057,
                                 -0.23025827724092918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66493546767140643,
                                 -0.074807718683633673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086358771730265765,
                                 0,
                                 0,
                                 0.60310677410207902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28456492294374308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063753557174018663,
                                 0,
                                 -0.32965564244529766,
                                 0.31610563225359195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1823713718501167,
                                 -0.75898778286962076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30212661495006427,
                                 0,
                                 0,
                                 -0.075897377834781038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43083915474513429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57831492517400707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20326331698459738,
                                 0,
                                 0.34295248211300855,
                                 0,
                                 0,
                                 0,
                                 -0.057752902544159719,
                                 0,
                                 0,
                                 0,
                                 0.18286307953006209,
                                 -0.11059610800101451,
                                 0,
                                 0,
                                 0.30661158136595568,
                                 0,
                                 0,
                                 0.42178456180091461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.008854825048232904,
                                 -0.64081202354397149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87868433816111879,
                                 0,
                                 0,
                                 0,
                                 -0.14168548814228474,
                                 0,
                                 0,
                                 -0.32938914059674751,
                                 -0.35990759916251042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40900844327538655,
                                 0,
                                 0,
                                 0,
                                 0.47616882147255074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072386598244725292,
                                 -0.2812029869356098,
                                 0,
                                 0.83960898810608664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24133868392789026,
                                 0,
                                 -1.16500144634479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32162613722436917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1318684029642696,
                                 0,
                                 0.064026456348328514,
                                 0,
                                 0,
                                 0,
                                 0.20921076097080582,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094733851923291451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3738325388798337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79298732130591532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10881813531294438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30981805439746218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33855165782918201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.551859089186994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5516522057523352,
                                 0,
                                 0,
                                 0,
                                 -0.17673750230193602,
                                 0,
                                 0,
                                 0.86994620291016278,
                                 -0.18918535155429353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6956409965428344,
                                 0,
                                 0,
                                 0,
                                 -0.17029139687357156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19615719999833334,
                                 0.076656366035560086,
                                 0,
                                 0.48932094550724775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48228893442916676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87692270714051523,
                                 0,
                                 0,
                                 0,
                                 -0.13957262407200124,
                                 0,
                                 0,
                                 -0.36852264616097929,
                                 -0.33515395968118722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14382438953669013,
                                 0,
                                 0,
                                 0,
                                 -0.15735346698120106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32959142836034494,
                                 0.49439997466471591,
                                 0,
                                 -0.35606006415966684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013034419101740632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80918474712782307,
                                 0,
                                 -0.23594916880897163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092621113176167447,
                                 0,
                                 0.26737157309470566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24145994906365312,
                                 0,
                                 0,
                                 0,
                                 -0.20022078928298781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7276339015679435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60617251880352141,
                                 0,
                                 0.67199689452911326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60718034349855909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77147471178570071,
                                 0,
                                 -0.45128575537868187,
                                 0,
                                 0,
                                 0,
                                 1.0938266640508729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31764714438496106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72755133247023929,
                                 0,
                                 0.67078566897382452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47421624186004685,
                                 0,
                                 -0.12807307477759491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80130745800238001,
                                 0,
                                 0,
                                 0,
                                 0.61169592744697754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7840261824208743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2643790626104308,
                                 0,
                                 -0.28649802492821819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55334799008244795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62120167201174137,
                                 0,
                                 0.2220713559439359,
                                 0,
                                 0,
                                 0,
                                 0.30221351336413366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017320362190231114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12447036724013742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37812502512059476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10901077345131233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2480687419655197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49843344401769196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73121419186432812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02213421355279372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19133502764999788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14670322281383885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13293749688717599,
                                 0,
                                 0.50479759103000887,
                                 0,
                                 0,
                                 0,
                                 0.11660847869362109,
                                 0,
                                 0,
                                 0,
                                 -0.69081917927041747,
                                 -0.014986152442275157,
                                 0,
                                 0,
                                 0.33804348124454253,
                                 0,
                                 0,
                                 -0.017423433723917858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25247941272725533,
                                 0,
                                 0,
                                 0,
                                 -0.0078301610261431592,
                                 0,
                                 -0.23653276487580355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8748779354209667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0061859228883059392,
                                 0,
                                 -0.97317982213477627,
                                 0,
                                 0,
                                 0,
                                 -0.044246198716943422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00023713928746227353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38650090716416496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46034104978460511,
                                 0,
                                 0.47042710046007152,
                                 0,
                                 0,
                                 0,
                                 -0.13917653596290258,
                                 0,
                                 0,
                                 0,
                                 0.40304331982959685,
                                 -0.4655656550114794,
                                 0,
                                 0,
                                 0.076876877464626306,
                                 0,
                                 0,
                                 -0.0051045327254297113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11357789428822308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57057625857079863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57370356143981904,
                                 0,
                                 0.1059324552984296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24029869119914671,
                                 0,
                                 0.081678260642504247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54328433360242701,
                                 0,
                                 0,
                                 0,
                                 -0.89276938471131739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2572330878925756,
                                 0,
                                 0,
                                 -0.27028654113197453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86110349650957385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3126875299816006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17638369932029155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23717754945170252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017551730002458885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15324597333349776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21977982014435771,
                                 0,
                                 -0.078246380403154958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0420391361269372,
                                 0,
                                 -1.1011255489399747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10069903492586629,
                                 0,
                                 0,
                                 0,
                                 -0.13283966984442352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013237612017935385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24308676812684729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11000273254748889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41309791300693766,
                                 0,
                                 0.075333922797742009,
                                 0,
                                 0,
                                 0,
                                 -0.16890986794286708,
                                 0,
                                 0,
                                 0,
                                 -0.039440412957256185,
                                 -0.5443411488271801,
                                 0,
                                 0,
                                 0.004909329751383161,
                                 0,
                                 0,
                                 -0.3030443691879729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57812608413268873,
                                 0,
                                 0,
                                 -0.86604324761009899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13184977053862881,
                                 0,
                                 -0.015925715659596856,
                                 0.46109640195861334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10269615544850352,
                                 -0.081266621662553509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0094139532888445621,
                                 0,
                                 0,
                                 -0.049817911463065773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21881200653396143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066709074236582538,
                                 0,
                                 -0.13216439947034156,
                                 0.49751173223814227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0020741174995171723,
                                 0.55662720206412553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5682869530777056,
                                 0,
                                 0,
                                 0.22337781431835491,
                                 0,
                                 0,
                                 0.10682446471631205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092754727664632136,
                                 0,
                                 0,
                                 0,
                                 -0.47559408129376923,
                                 0,
                                 0,
                                 0.41833772235027633,
                                 0.012289163010253165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78333460596748272,
                                 0,
                                 0,
                                 0,
                                 -0.17444970437359497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66518111870866714,
                                 0.22817200892569134,
                                 0,
                                 0.59931874439888577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048447519652108778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43197143308439545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66536961699121444,
                                 0,
                                 -0.083354306307447473,
                                 0,
                                 0,
                                 0,
                                 0.42017460135570034,
                                 0,
                                 0,
                                 0,
                                 -0.25531690040524213,
                                 -0.18545437719613087,
                                 0,
                                 0,
                                 0.070192288224041333,
                                 0,
                                 0,
                                 -0.080090935652353409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27188342109363917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46024465771480322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22453152885441091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21990046668383356,
                                 0,
                                 0.16387332817198019,
                                 0,
                                 0,
                                 0,
                                 0.64743621296977671,
                                 0,
                                 0,
                                 0,
                                 0.19022987272655653,
                                 0.092106721656322568,
                                 0,
                                 0,
                                 0.073005927218637467,
                                 0,
                                 0,
                                 -0.42160283835830897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12500497359719981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72308404592958575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22947408938045336,
                                 0,
                                 0.48783328715167418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53637932787360143,
                                 0,
                                 -0.34060061241403755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15803918486151303,
                                 0,
                                 0,
                                 0,
                                 -0.48008344344927156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15398997131565234,
                                 0,
                                 0.23293146762939371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033124482453154941,
                                 0,
                                 0,
                                 0,
                                 1.2303666643267954,
                                 0,
                                 0,
                                 -0.32973894474256649,
                                 -0.095153716089673837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12774142398854943,
                                 0,
                                 0,
                                 0,
                                 -0.1675005827113184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44551720165991726,
                                 -0.50353295993467229,
                                 0,
                                 -0.059901953798743891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60283824689596777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35915255830799975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10435836073822385,
                                 0,
                                 -0.35882590155322447,
                                 0,
                                 0,
                                 0,
                                 -0.26545810661374775,
                                 0,
                                 0,
                                 0,
                                 -0.37725169723865931,
                                 -0.22019838144614498,
                                 0,
                                 0,
                                 0.22701558813687706,
                                 0,
                                 0,
                                 0.12729807898164902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19731634007680401,
                                 0,
                                 -0.13731259654646402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081909667247884899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28406158239502177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70621034561681384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34218232502912815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52718429304151804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29554252826132893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056169225428132109,
                                 0,
                                 -0.61772333035614169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62245912873820575,
                                 0,
                                 -0.65708829859489626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26059301380139221,
                                 0,
                                 0,
                                 0,
                                 -0.26550710175762504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03924272259200718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2518955385602682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019705682459698434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15485979518365489,
                                 0,
                                 -0.48316935817461065,
                                 0,
                                 0,
                                 0,
                                 0.26549712774095385,
                                 0,
                                 0,
                                 0,
                                 0.20829548948261684,
                                 -0.34366650675438098,
                                 0,
                                 0,
                                 0.55934026896051869,
                                 0,
                                 0,
                                 0.044260693639354712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36321232050210311,
                                 0.16856813188864761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26423975164449254,
                                 0,
                                 0,
                                 0,
                                 -0.17541952942860381,
                                 0,
                                 0,
                                 0.21776747832198656,
                                 -0.70114945144277219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3486884121292006,
                                 0,
                                 0,
                                 0,
                                 -0.39849477358999108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59333385456275578,
                                 -1.269255994732629,
                                 0,
                                 -0.11214047432049143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46800832228700201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50942568323181803,
                                 0,
                                 0,
                                 0,
                                 -0.2109524048255027,
                                 0,
                                 0,
                                 -0.010548408021323341,
                                 0.31846295983231465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25290251284307563,
                                 0,
                                 0,
                                 0,
                                 0.85594278077268382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60599510775667964,
                                 -0.31079220341984115,
                                 0,
                                 -0.24560333693411202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15224749949369448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66448536485189758,
                                 0,
                                 0.067518576999032437,
                                 0.39525956557155378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46008509180391427,
                                 0.098113102670045735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38772562027446239,
                                 0,
                                 0,
                                 -0.053435822692226354,
                                 0,
                                 0,
                                 -0.14545972423404629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4418738802116321,
                                 0,
                                 0,
                                 0,
                                 0.015933679912314924,
                                 0,
                                 0,
                                 0.32951913819486889,
                                 -1.1607082305855845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076831283290051955,
                                 0,
                                 0,
                                 0,
                                 0.44991573925818285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17306684017311835,
                                 0.29077939033672173,
                                 0,
                                 -0.076079807770660174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69508373786110356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24576064112263102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17059354525039805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34722251063387627,
                                 0,
                                 0.58844723547473765,
                                 0.12275233889588912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26178171539559769,
                                 0.060108881745391828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.112981229265677,
                                 0,
                                 0,
                                 -0.63567962248227583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64234386015527312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44491401707554484,
                                 0,
                                 -0.86007545092586501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82665507453856935,
                                 0,
                                 0.026685025063437895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91418126593751226,
                                 0,
                                 0,
                                 0,
                                 0.04497688190750207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18278876245816811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069518952712470189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22070916980245731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16679781890472939,
                                 0,
                                 -0.0053133781272260011,
                                 0,
                                 0,
                                 0,
                                 0.44258381403109853,
                                 0,
                                 0,
                                 0,
                                 -0.089612684474198873,
                                 -0.29769117464691364,
                                 0,
                                 0,
                                 -0.44867972522235577,
                                 0,
                                 0,
                                 0.64680448725655859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08002744226764795,
                                 -0.051729488628883935,
                                 0,
                                 0,
                                 -0.25725925728320398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45558001770845791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56303493275523431,
                                 0,
                                 0,
                                 0,
                                 -0.19000147066615855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46931655781830267,
                                 0.21864740420949008,
                                 -0.32002338796575763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050236065368018279,
                                 0,
                                 0,
                                 0,
                                 0.15563482934697404,
                                 0,
                                 0,
                                 0,
                                 -0.20553257316936566,
                                 0,
                                 0,
                                 0.63127266722301256,
                                 -0.34878248844529952,
                                 0,
                                 0,
                                 0,
                                 -0.48202207350275367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60155519189885209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51929172452722527,
                                 -0.36081563556660162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89915355070658831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53614364359164524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.044428551241221,
                                 0,
                                 0,
                                 -0.55045121250080287,
                                 0,
                                 0.24984473667181001,
                                 0,
                                 0.62658047988565424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22591428851185302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1829251588611768,
                                 0,
                                 0,
                                 -0.16521103091039474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33703299333866987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70480379838895646,
                                 0,
                                 0,
                                 0,
                                 0.061856585469640755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55578791418440077,
                                 -0.12120280004876605,
                                 0.038568215407780188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59479794831406829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037412184467996892,
                                 0,
                                 0,
                                 0,
                                 -0.36201790047841675,
                                 0,
                                 0,
                                 0,
                                 -0.51705078065925369,
                                 0,
                                 -0.26501361088494413,
                                 0,
                                 0,
                                 0,
                                 -0.41974402334432936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56759012940400821,
                                 0,
                                 0,
                                 0,
                                 0.10122483411026309,
                                 0,
                                 0,
                                 0,
                                 -0.5337960325747132,
                                 0,
                                 0,
                                 -0.2771595579174797,
                                 0.046726871717134903,
                                 0,
                                 0,
                                 0,
                                 -0.060040990673058271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.9079177444642057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41838454974941008,
                                 0.12208788067730819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45520279061789726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19276085489910999,
                                 0,
                                 0,
                                 0,
                                 0.30388069683385255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34356116919040963,
                                 0,
                                 0.1121688898947958,
                                 0,
                                 0,
                                 0,
                                 -0.1889022209255464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25447650192703042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59654122162011858,
                                 0,
                                 0,
                                 0,
                                 0.44531814936963138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10729846593248329,
                                 -0.27158544682940222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27753637419062116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2645137695234925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064407598309070682,
                                 0,
                                 -0.23300650627499284,
                                 0,
                                 0,
                                 0,
                                 0.12234752057731152,
                                 0,
                                 0,
                                 -0.011058364140453858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52695816629297609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40002910939082925,
                                 -0.746759186955539,
                                 0,
                                 0,
                                 -0.27426660261446445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22577439596528312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24055013773839246,
                                 0,
                                 0,
                                 0,
                                 0.22789283802757157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021599637847942176,
                                 0.091753408649667814,
                                 -0.44437565501511905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62337198319143183,
                                 0,
                                 0,
                                 0,
                                 0.49763501407186583,
                                 0,
                                 0,
                                 0,
                                 0.18164380739537361,
                                 0,
                                 0,
                                 0.76249570180978088,
                                 0.37061959152653207,
                                 0,
                                 0,
                                 0,
                                 0.68183053694145213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061306618859314467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29507071712236893,
                                 0.20139150491408248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11019384678064068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0019144421750934282,
                                 0,
                                 0,
                                 0,
                                 0.58026006995223622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53351269309699723,
                                 0,
                                 -0.037149753470919644,
                                 0,
                                 0,
                                 0,
                                 -0.0034900713559304908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018721195867942159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13777794072052352,
                                 0,
                                 0,
                                 0,
                                 0.050078519125398735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33353825889854133,
                                 0.49414333477522654,
                                 0,
                                 0,
                                 0,
                                 -0.69210608497186599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49270262191306213,
                                 0,
                                 0,
                                 -0.34003310141600207,
                                 0,
                                 0.89587925295191906,
                                 0,
                                 -0.21154862300098456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44066451428587095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76453653057665494,
                                 0,
                                 0,
                                 0,
                                 -0.53835335101789372,
                                 0,
                                 0,
                                 0,
                                 -0.033060949371880255,
                                 0,
                                 0,
                                 -0.020631300779436229,
                                 -0.90839360038889916,
                                 0,
                                 0,
                                 0,
                                 0.40746829636724441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48409851217683098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53190671283716429,
                                 -0.0029811702847387239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37999160627058431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14887523886618581,
                                 0,
                                 0,
                                 0,
                                 0.3544850388055415,
                                 0,
                                 0,
                                 0,
                                 -0.25774512470070637,
                                 0,
                                 0,
                                 -0.45220154791142364,
                                 0.14975317161249213,
                                 0,
                                 0,
                                 0,
                                 0.81543543979701305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28097275574579367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22444884007614663,
                                 -0.18463043580083074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43708266482415342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15212225291851436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56605950953784601,
                                 0,
                                 0,
                                 -1.0802649520111891,
                                 0,
                                 -0.26110692180829675,
                                 0,
                                 -0.34589392563100085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36111179674656024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078000151672772744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32945001122209522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67176869305685072,
                                 0,
                                 -0.017151826536485615,
                                 0,
                                 0,
                                 0,
                                 -1.0122589925369039,
                                 0,
                                 0,
                                 0.10157816779594731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7789127360134247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11676738551713808,
                                 0,
                                 0,
                                 -0.63738703193994328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46482244297050868,
                                 0,
                                 0,
                                 0.32033493308994221,
                                 0,
                                 -0.32123569187117962,
                                 0,
                                 0.78659347535737723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77361134344471227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35308106293792357,
                                 0,
                                 0,
                                 0,
                                 -1.0238880315645345,
                                 0,
                                 0,
                                 0,
                                 -0.014974590068325529,
                                 0,
                                 0,
                                 0.23824414637014635,
                                 -0.44910347474157464,
                                 0,
                                 0,
                                 0,
                                 0.48992579522776214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37491613372609833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34954947887685195,
                                 0.20429646749551883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39299369521799826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80629530710740505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46146012434704436,
                                 0,
                                 0,
                                 0.49027941439279638,
                                 0,
                                 -0.50244631003499873,
                                 0,
                                 -1.4132143877231469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36180825592971055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35625770132487761,
                                 0,
                                 0,
                                 0,
                                 -0.22313634309148739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20006023908046122,
                                 0,
                                 0.34210730574022719,
                                 0,
                                 0,
                                 0,
                                 0.64270569380571729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4986703199390855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050855385111257118,
                                 0,
                                 0,
                                 0,
                                 0.010991646820153092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0019877792295024607,
                                 0.042135260024936394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84887638246725261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17319027529342476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17520586632425805,
                                 0,
                                 -0.55665968603955962,
                                 0,
                                 0,
                                 0,
                                 -0.57912045529436262,
                                 0,
                                 0,
                                 0.49201884152694331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21124063245798147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2619643565502322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43402823550487268,
                                 0,
                                 0,
                                 0,
                                 -0.4214463847337297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37551101720151275,
                                 0,
                                 0.019145945369357015,
                                 0,
                                 0,
                                 0,
                                 -0.54100915659386917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022412664303149837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088497276318384582,
                                 0,
                                 0,
                                 0,
                                 0.38796424458960921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12631020180801822,
                                 0.15853018387512113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10091158502328634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33072617760182915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38534794670832984,
                                 0,
                                 -0.033823961196185165,
                                 0,
                                 0,
                                 0,
                                 0.24803952860931869,
                                 0,
                                 0,
                                 -1.1469962631950339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0065143038678321941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60130499234801005,
                                 0,
                                 0,
                                 0.11667861242249067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30910398702334319,
                                 0,
                                 0,
                                 -0.33958810159712349,
                                 0,
                                 -0.32754347788444893,
                                 0,
                                 0.49026240873753824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95007345714283242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0031358882406077801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27459420795433498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096941159107059097,
                                 0,
                                 0,
                                 0,
                                 0.014952374025994225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1631912421751886,
                                 0,
                                 0.29945720145420729,
                                 0,
                                 0,
                                 0,
                                 -0.2362032195408913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17631239448984889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32548178472434125,
                                 0,
                                 0,
                                 0,
                                 -0.37590972689863206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5479303317779225,
                                 0.48961276161642514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53436856151818091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95166171276271339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019876223543213202,
                                 0,
                                 -1.1793965983457904,
                                 0,
                                 0,
                                 0,
                                 0.2546666448043125,
                                 0,
                                 0,
                                 0.21139782623602066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45286458028676529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032285977805831416,
                                 0,
                                 0.50767004086802991,
                                 0,
                                 0,
                                 0,
                                 -0.11893359031317559,
                                 0,
                                 0,
                                 0,
                                 -1.1999742937220337,
                                 0,
                                 0,
                                 -0.10708397890563852,
                                 0.40633910721876143,
                                 0,
                                 0,
                                 0,
                                 0.14784064177305878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02124926112083006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010502636148455834,
                                 0.48045881046860284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30498657039472432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30022847655985696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65685631046616422,
                                 0,
                                 0,
                                 0,
                                 -0.23671107927245014,
                                 0,
                                 0,
                                 0,
                                 0.63744032498075232,
                                 0,
                                 0.037736064614987769,
                                 0,
                                 0,
                                 0,
                                 -0.12089803856476565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39763273297819313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10117059944748986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67404567839861962,
                                 0,
                                 0.23983527367135915,
                                 0,
                                 0,
                                 0,
                                 -0.85807856106856684,
                                 0,
                                 0,
                                 0.36970567627791917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00904093164447866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40095400520631402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24123271090866166,
                                 0,
                                 0,
                                 0,
                                 -0.064466434918276277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4473170663427265,
                                 0,
                                 0.15561870973075548,
                                 0,
                                 0,
                                 0,
                                 0.24042224102369197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47667282396656985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42118527111462767,
                                 0,
                                 0,
                                 0,
                                 0.19927689088510986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38076537149495615,
                                 -0.25735326350234433,
                                 0,
                                 -0.4545895074904428,
                                 0,
                                 0,
                                 -0.10695786221752876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25874690797857258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092399654184888852,
                                 0,
                                 0,
                                 0,
                                 -0.33611785803738231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058658673345214518,
                                 -0.69360863996142585,
                                 0.3300177828967622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3260271990854387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70711946803812054,
                                 0,
                                 0,
                                 0,
                                 0.14878136352875887,
                                 0,
                                 0,
                                 0,
                                 -0.54249543226816854,
                                 0,
                                 0.27594436208510487,
                                 0,
                                 0,
                                 0,
                                 -0.033254236513990676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23291561281008419,
                                 0,
                                 0,
                                 0,
                                 -0.41094386210900957,
                                 0,
                                 0,
                                 0,
                                 -0.79855415000426999,
                                 0,
                                 0,
                                 0.22116817697713823,
                                 0.1104610322143946,
                                 0,
                                 0,
                                 0,
                                 0.072885437951901333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027170681266213428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52577195185266257,
                                 -0.76427389834951209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41093177698805011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035558949491449734,
                                 0,
                                 0,
                                 0,
                                 -0.53438136132607039,
                                 0,
                                 0,
                                 0,
                                 0.41236717425851482,
                                 0,
                                 0,
                                 -0.26246428371779629,
                                 0.78141617341955028,
                                 0,
                                 0,
                                 0,
                                 0.043274800555485431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48089981105208746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77742587597469937,
                                 -0.25108651443802144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3916891488204956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3322889112064249,
                                 0,
                                 0,
                                 0.031864464001207515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02069775886958377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12240576816569027,
                                 0,
                                 0,
                                 0,
                                 0.30051838545712173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28958167330458534,
                                 0.40051216860473354,
                                 0.73387895691905614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6089418457774628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10240545652589561,
                                 0,
                                 0,
                                 0,
                                 -0.35183077581854583,
                                 0,
                                 0,
                                 0,
                                 0.13653077091620675,
                                 0,
                                 -0.081518472261566097,
                                 0,
                                 0,
                                 0,
                                 -0.68529712052141789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45405250799945374,
                                 0,
                                 0,
                                 0,
                                 -0.053358073896728274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14328174836215832,
                                 0,
                                 0.07690371530380645,
                                 0,
                                 0,
                                 0,
                                 -0.17057908446725736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23161577459510965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29923895323160898,
                                 0,
                                 0,
                                 0,
                                 -0.65402444481797561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28628372595019186,
                                 -0.28731865009893709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26632790515802057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1241709875891209,
                                 0,
                                 0,
                                 0,
                                 -0.62861579297880665,
                                 0,
                                 0,
                                 0,
                                 -0.10238255836599724,
                                 0,
                                 -0.42637737273625542,
                                 0,
                                 0,
                                 0,
                                 0.57115089543295849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2277075856137476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7696546194510514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45254588652179262,
                                 0,
                                 -0.29050560134899017,
                                 0,
                                 0,
                                 0,
                                 -0.022168864197472049,
                                 0,
                                 0,
                                 -0.072786217733182057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64248851828867959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68131122544636713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57639508650818638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19476987572631621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19771808471473945,
                                 0,
                                 0,
                                 0,
                                 -0.46177798225448435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01233745838615523,
                                 0,
                                 -0.62639594929967335,
                                 0,
                                 0,
                                 0,
                                 0.10231198734702351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16023871489893957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48342158534823171,
                                 0,
                                 0,
                                 0,
                                 -0.042958776495024178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19274458935494507,
                                 0.21519294833177258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089687253250965257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20301936383128999,
                                 0,
                                 0,
                                 0,
                                 0.52137539312278713,
                                 0,
                                 0,
                                 0,
                                 0.053890524322200151,
                                 0,
                                 -0.81471194860834673,
                                 0,
                                 0,
                                 0,
                                 -0.11066745747039752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1891449979030442,
                                 0,
                                 0,
                                 0,
                                 -0.5979430602987571,
                                 0,
                                 0,
                                 0,
                                 -0.13384478000207967,
                                 0,
                                 0,
                                 -0.15084582238440716,
                                 0.0098026872080897443,
                                 0,
                                 0,
                                 0,
                                 -0.28272506556296939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40749768639551931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62476491726014927,
                                 0.39794087990124188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077938083677094261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070173936467748985,
                                 0,
                                 0,
                                 0.080820027592229421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72865945886901207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06248103217251956,
                                 0,
                                 0,
                                 0,
                                 0.44009952479448933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49708020311466322,
                                 0.1042524543076179,
                                 -0.045280913396030395,
                                 0,
                                 0,
                                 0,
                                 -0.14806129563240655,
                                 0,
                                 0,
                                 -0.030844630910974825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14382928358528943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31517254331342975,
                                 0,
                                 0,
                                 0,
                                 -0.70953869247917856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26048761306118584,
                                 0.52566506882812059,
                                 0.097381462994023754,
                                 0,
                                 0,
                                 0,
                                 0.24959786358144079,
                                 0,
                                 0,
                                 -0.90075647320775432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09418971050922556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040254464275695873,
                                 0,
                                 0,
                                 0,
                                 0.087856678833682644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26102549356267513,
                                 0.01972877211402857,
                                 0.19900811605442084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22433215358954506,
                                 0,
                                 0,
                                 0,
                                 -0.33925270730542112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21680183424797433,
                                 0,
                                 0.55298763322395927,
                                 0,
                                 0,
                                 0,
                                 -0.0088476079998149604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31125881716309073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084287272352156078,
                                 0,
                                 0,
                                 0,
                                 0.13837136539032888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52052739630805223,
                                 0.29601393015028443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53326136503746402,
                                 0,
                                 0,
                                 0,
                                 0.089386841415782889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34912527699621637,
                                 0,
                                 -0.22507970265139518,
                                 0,
                                 0,
                                 0,
                                 0.32450607403003712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50120794653358147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032521107986103213,
                                 0,
                                 0,
                                 0,
                                 0.13706694973323724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16128705876074126,
                                 0.36430878840409592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099543294020414758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11279487758527576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24988534611273694,
                                 0,
                                 -0.4527805036997431,
                                 0,
                                 0,
                                 0,
                                 -0.29275623226280567,
                                 0,
                                 0,
                                 -0.44939267485371404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68035277132975658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1655307497325995,
                                 -0.67431151259219779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090952602798271207,
                                 0,
                                 0,
                                 0,
                                 0.10417185789948571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43125849274932287,
                                 -0.36866287919730156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65734590549151972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76587364830039362,
                                 -0.084511281463539645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083163249660975658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015214175264501265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70989540471414725,
                                 0.19217768213024294,
                                 0,
                                 0,
                                 -0.58019233873973897,
                                 0,
                                 0,
                                 0,
                                 0.075077456783868901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30002976432835538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50199683382258664,
                                 0,
                                 0,
                                 0,
                                 -0.41852240512372102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32764285125808507,
                                 0,
                                 0,
                                 0,
                                 -0.11338380080194296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20182472501376536,
                                 0.24971711979557665,
                                 -0.35703792207999846,
                                 -0.25588404489521988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27319567720997723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3626828771729263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69636541017919196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29667976626840342,
                                 0,
                                 0,
                                 0,
                                 -0.076865786761825539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058605820954166152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65364743279621607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40321567153534704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55928550910059793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26026625163999512,
                                 0,
                                 0,
                                 0,
                                 0.60384508624020183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053118831842842523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010988265122022715,
                                 0.51653464404103588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.7866009949634507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40044877214644398,
                                 0,
                                 0,
                                 0,
                                 -0.10541362920390791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71364190913897718,
                                 0,
                                 -0.21499518836604928,
                                 0,
                                 0,
                                 -0.36583023133158526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039687232327100017,
                                 0.23027472589501663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14377640517409068,
                                 0,
                                 0.16352091255920453,
                                 0,
                                 0,
                                 0.19281341935530288,
                                 0,
                                 0.057194134680792728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37111413696934603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75780973444824551,
                                 -0.47869131674470594,
                                 0,
                                 0,
                                 0.28398364302517998,
                                 0,
                                 0,
                                 0,
                                 -0.31066898933366466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32472435636359642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24692566651045436,
                                 0,
                                 0,
                                 0,
                                 -0.4803384864327056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63194169453632609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52205260697463862,
                                 0,
                                 0,
                                 0,
                                 -0.37555445176994795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57158460767495201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28747315123316031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3644751831512783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21030452625359014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35309105735957047,
                                 0,
                                 0,
                                 0,
                                 0.2222966497664679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95084769970368399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50427504207525642,
                                 0.12612152843957958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077093936428277124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16953555071096654,
                                 0,
                                 0,
                                 0,
                                 0.56952319843146226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0013700389679595082,
                                 0,
                                 -0.076881431580656343,
                                 0,
                                 0,
                                 -0.19862192716135504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52523700836093268,
                                 0.20518398767809348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31722048312019602,
                                 0,
                                 -0.27795644800460895,
                                 0,
                                 0,
                                 0.32507647771841941,
                                 0,
                                 0,
                                 -0.27635146924689225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66657790161887465,
                                 0.076771168913600224,
                                 -0.05823191797534194,
                                 -0.18311599625370376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13128356451553436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64257304687505545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.079699654358284466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39456135189813452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03879703373580573,
                                 -0.60117596066672074,
                                 0.21363883658154875,
                                 -0.5822180087160006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029831076447550949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29152502635239796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10443896685208832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68896649691633827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0010587988744654997,
                                 -0.24888522698813617,
                                 -0.48559576459953491,
                                 -0.42902842887692566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046862622873075722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13213882574824182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15444991027695734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39030068406210983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019107892057033837,
                                 -0.1091552710537281,
                                 -0.71263943092518578,
                                 0.22189013305449379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.488772756487035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097564289680494271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17285139143746073,
                                 0,
                                 0,
                                 -0.49490366397663654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7087503007182776,
                                 0,
                                 0,
                                 0,
                                 -0.7149348830184592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80342938612816628,
                                 0.32672196302024309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95504394299649853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047266578320855762,
                                 -0.69209218947117357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035173896215208181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10337330883941227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74359447276862467,
                                 0.6242760777508003,
                                 0,
                                 0,
                                 0.26418815221140607,
                                 0,
                                 0,
                                 0,
                                 -0.075700417142891774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066305936502394178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44552518509655353,
                                 0,
                                 0,
                                 0,
                                 0.85339913672986412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05691279141065006,
                                 0,
                                 0,
                                 0.48750723801612705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43956602998643973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10096069654420756,
                                 -0.73007787865684193,
                                 0,
                                 0,
                                 0.37453211824705523,
                                 0,
                                 0,
                                 0,
                                 0.71256912901340419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28528703925651139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20308301653854083,
                                 0,
                                 0,
                                 0,
                                 0.089772443646108868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20197260301010178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82136449602096884,
                                 0,
                                 0,
                                 0,
                                 0.27202131021580556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52739071423408856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21402456566793754,
                                 0.68917546588834699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10913729701534479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40215201383226673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79156859715267447,
                                 0,
                                 0,
                                 0,
                                 0.30885502982784541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30451446933565174,
                                 -0.22682639431040386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84491782766240542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10716089344534355,
                                 -0.43252285744285285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39066846406697292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30356397346580799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3080424200953944,
                                 -0.41753483037733574,
                                 0,
                                 0,
                                 -0.44843378891280095,
                                 0,
                                 0,
                                 0,
                                 0.63165415464330388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81748468383028161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19809899350969712,
                                 0,
                                 0,
                                 0,
                                 0.13756493679981624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24190209514319114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31328506836667702,
                                 0,
                                 0,
                                 0,
                                 -0.55591516946448394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49679404143650097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35273331798447094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45805033761156105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10851527675193923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31334896665266321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45277245801078275,
                                 -0.39917293215912741,
                                 0.21143163099725315,
                                 0.27295706817234716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47466476522787704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039041963308421308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43752792676222779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63822225152343592,
                                 0,
                                 0,
                                 0,
                                 0.027431835853897746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090437407004166373,
                                 0,
                                 0.052980879439144216,
                                 0,
                                 0,
                                 -0.0030306548381526964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060244012524275803,
                                 0.30870088958108355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68186439743682392,
                                 0,
                                 0.097598571923694338,
                                 0,
                                 0,
                                 0.086802367449868328,
                                 0,
                                 -0.054813835339728473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34064297549443534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0031605457313472283,
                                 0.15752084109990866,
                                 0,
                                 0,
                                 -0.038463685169196224,
                                 0,
                                 0,
                                 0,
                                 0.52072697744280827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1839455938097252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1697785497912169,
                                 0,
                                 0,
                                 0,
                                 0.26835396270977691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39654536145999147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0040112699689342076,
                                 0,
                                 0,
                                 0,
                                 -0.1803235395246422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41488130148622859,
                                 0,
                                 -0.036872487079780851,
                                 0,
                                 0,
                                 -0.66476571544326535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18256864542789009,
                                 -0.40343099123364246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15540192122997545,
                                 0,
                                 0.27172126407231806,
                                 0,
                                 0,
                                 0.24082716271058136,
                                 0.16993341769487727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35586893348897525,
                                 0,
                                 0,
                                 0,
                                 -1.0943476552232969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80832929498444839,
                                 -0.3075487071087365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1502066063270984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041314774480318672,
                                 0.0024340686328666815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48055733989117616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8257280456440621,
                                 0,
                                 0,
                                 0,
                                 -0.68350977530212631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18111996345354175,
                                 -0.0037189841682915732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040367324057870468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16985099714891805,
                                 -0.57860636547528022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43384942574602953,
                                 0,
                                 0,
                                 0,
                                 0.11244133982117833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49500921505264489,
                                 0,
                                 0.032120283889993904,
                                 0,
                                 0,
                                 -0.18436609609722579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054656607771721578,
                                 -0.54092781878845442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18855070713271721,
                                 0,
                                 0.028697962617632064,
                                 0,
                                 0,
                                 -0.43256182879875182,
                                 0,
                                 0,
                                 0,
                                 -0.15213479432883056,
                                 0,
                                 0,
                                 0,
                                 -0.18344619197119633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55408033839776782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0026168256262978223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5904885767428224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53620319895230417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3807484813324517,
                                 -0.25829714189879716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6173118496408404,
                                 0.11790560657833569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088469524787398682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44444534448113915,
                                 -0.17859597152535109,
                                 -0.08138987851942453,
                                 0.39107520829624559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50701193799904343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44841682311509662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38084389782732408,
                                 0,
                                 0,
                                 0,
                                 -0.14271492502220556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85086171065751182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16422785921403008,
                                 -0.40976413094270753,
                                 0,
                                 0,
                                 0.1392469803258736,
                                 0,
                                 0,
                                 0,
                                 0.20721409361157067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52606497220894943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69152005068460409,
                                 0,
                                 0,
                                 0,
                                 -0.03496496479770779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74181880063315808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.055611798279913249,
                                 0,
                                 0,
                                 0,
                                 1.1160524798341362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78464286200868649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51327039953501674,
                                 -0.65456886988390384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15718098512216178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42714952244762372,
                                 0,
                                 0,
                                 0,
                                 0.6988479256083624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18326919541310013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26789814377744475,
                                 0.63814419019591928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47533532589632776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47369149800150057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11429690681099647,
                                 0,
                                 0,
                                 0,
                                 0.3544680221285037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018204840400882404,
                                 -0.52665891277774768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010592255824936392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85487029341601084,
                                 -0.41618346042655374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15920731440280858,
                                 0,
                                 0,
                                 0,
                                 0.18866607141560682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00059640424225110289,
                                 0,
                                 -0.071290611047550828,
                                 0,
                                 0,
                                 -0.20341803509184664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3201253690343121,
                                 -0.24281898026768575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39126745636966076,
                                 0,
                                 -0.76018302321252973,
                                 0,
                                 0,
                                 0.013666760511878429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41915885537534697,
                                 0,
                                 0,
                                 0,
                                 -0.52055663305358246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060384198738544566,
                                 0,
                                 -0.36459121133593092,
                                 0,
                                 0,
                                 -0.03063415808116917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25320198410519751,
                                 0.053406136817176958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36371033568662603,
                                 0,
                                 -0.26530377008224421,
                                 0,
                                 0,
                                 0.38233549711297371,
                                 0,
                                 0.72750148284382488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47703744101016632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16685239186143022,
                                 -0.042592993310415085,
                                 0,
                                 0,
                                 -0.25404119899735067,
                                 0,
                                 0,
                                 0,
                                 -0.31621124949728829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65238679456453785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56389937468834572,
                                 0,
                                 0,
                                 0,
                                 0.48104049866799159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058691690024755619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57333744169405287,
                                 0,
                                 0,
                                 0,
                                 -0.099825243973521105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28681350662521571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4354705040305592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36638604774497213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.505157218271583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47349676864561996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23801933399952374,
                                 0,
                                 0,
                                 0,
                                 -0.73811205284720027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64837504562719839,
                                 -0.19017163249862562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55639369599246824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26197987106126469,
                                 0.58113519375400868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012835924641065422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062032769755610173,
                                 0,
                                 0,
                                 0,
                                 -0.039645180000090929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63090182289894181,
                                 -1.2599960134861086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5730543706953356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28504202726574163,
                                 0.38267855785778737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56149782337372278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37435496888614478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095545207816988373,
                                 -0.78449154076216543,
                                 0,
                                 0,
                                 0.039378976620816977,
                                 0,
                                 0,
                                 0,
                                 -0.23979794764692886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013685352439988085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60083798052237936,
                                 0,
                                 0,
                                 0,
                                 0.37785944305888441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29299660691996066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47688708193250195,
                                 0,
                                 0,
                                 0,
                                 0.49031647816676494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0496121400813208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82689237205509003,
                                 -0.19783776235806655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21009106264630828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046997436831693391,
                                 0,
                                 0,
                                 0,
                                 0.52035543970713527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072969077599904592,
                                 0,
                                 -0.57161245408422867,
                                 0,
                                 0,
                                 0.11184921016154047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44143146391589716,
                                 -0.13771652156217956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017775096312181507,
                                 0,
                                 0.38452388059187292,
                                 0,
                                 0,
                                 0.14298175091341606,
                                 0,
                                 0,
                                 0,
                                 -0.43523997987620444,
                                 0,
                                 0,
                                 0,
                                 -0.70738337855608802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18380714194750536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41957361647948233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10885474754521093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29748693167973028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054843825478454289,
                                 0,
                                 0,
                                 0,
                                 -0.17484519615489902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16921465714511288,
                                 0,
                                 -0.68293892021093772,
                                 0,
                                 0,
                                 0.023086570384369107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40090097343028708,
                                 0.11687779019512688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12878425079245273,
                                 0,
                                 -0.12329479568130365,
                                 0,
                                 0,
                                 -0.51447075261107811,
                                 0,
                                 0,
                                 0.14856456232285997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33246755640482317,
                                 0.55248595619774643,
                                 0.16883590083820438,
                                 -0.31822645124205234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42869126068885249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37549006245560418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32804045983447694,
                                 0,
                                 0,
                                 0,
                                 -0.28563438329452034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88868189002169973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19344421024683001,
                                 0.38705296739528205,
                                 0,
                                 0,
                                 0.59911326945982513,
                                 0,
                                 0,
                                 0,
                                 0.24929370825934849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022883068572719108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41007321275300002,
                                 0,
                                 0,
                                 0,
                                 -0.84434860977956006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30001543080684201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095245481909537313,
                                 0,
                                 0,
                                 0,
                                 0.10346222900135559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16664067025876056,
                                 0,
                                 0.10729668643902776,
                                 0,
                                 0,
                                 -0.54354713596804904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40053487743309069,
                                 0.50968406094293872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22755781601545844,
                                 0,
                                 0.022250481601881977,
                                 0,
                                 0,
                                 -0.41595073126620075,
                                 -0.58118324306706448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73136985341445637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04710365280038338,
                                 0,
                                 -0.81991571486439729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4655869041490186,
                                 0,
                                 0,
                                 0.047104297730340187,
                                 -1.0439447617790441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60235562799597198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26282950348344453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47364098596426357,
                                 0.054638588404222907,
                                 0,
                                 -0.53088012072808732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050320107995004172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014838718796652618,
                                 0,
                                 0,
                                 -0.41603069891799516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2846522493159846,
                                 -0.10323204999820597,
                                 0,
                                 0.39274443103948087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088017119122802412,
                                 0,
                                 0,
                                 0.25157308364109499,
                                 0,
                                 0,
                                 0,
                                 0.17752292856755753,
                                 0,
                                 -0.42354903710833819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1604351928324996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17067914003752063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53923815885332693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6102517361051546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12587726186818729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5793798783341072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063372616671676901,
                                 0.67879052567610498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1035844638447508,
                                 0,
                                 0,
                                 -0.41589838192119027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64652038247310728,
                                 0,
                                 0,
                                 -0.20453281299688836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047553738421793335,
                                 0.52132997074305709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12059265825152718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17852297152489163,
                                 0,
                                 0,
                                 0,
                                 0.090442969925236982,
                                 0,
                                 0,
                                 0.45894852415624149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44339369294583447,
                                 0,
                                 0,
                                 -0.79521794710836158,
                                 0,
                                 0,
                                 -0.65533073209312853,
                                 0,
                                 0,
                                 -0.11148249020496198,
                                 0,
                                 0,
                                 0,
                                 0.51693200881250778,
                                 0,
                                 -0.060700292125703117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28311627206843526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44715436865340447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076790346840384174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034805868316787489,
                                 0,
                                 -0.11355619753885272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90676423794357741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090440115367106055,
                                 0,
                                 0.02753918587339993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082350678880543857,
                                 0,
                                 0,
                                 0.01106417635115553,
                                 -1.0979803741008676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16344133755681123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20035564812973325,
                                 0,
                                 0,
                                 0.41270399185384832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61859251621961375,
                                 0.34664899089401985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095169631081677336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68779982361752012,
                                 0,
                                 0,
                                 0,
                                 -0.089420880714402143,
                                 0,
                                 0,
                                 0.77229171194799495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44265130281924392,
                                 0,
                                 0,
                                 -0.1474652638794777,
                                 0,
                                 0,
                                 0,
                                 0.45831772350786348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31756934734581099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67312774620097415,
                                 0.41156545475928596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046885461491160685,
                                 0,
                                 0,
                                 0.25378975784862767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12331730147647919,
                                 0,
                                 0,
                                 -0.43764846514221839,
                                 0,
                                 0,
                                 0,
                                 -0.22182661568505857,
                                 0,
                                 0.46423512355021052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28043250110605855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30130922930012782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5915516337818455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095772605599129007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12024090253434504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3466458897839122,
                                 0,
                                 -0.010385661626806736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056425490113153703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.02302895924432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.319893578001055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14064495839120722,
                                 0,
                                 0,
                                 -0.23525888136678347,
                                 0,
                                 0,
                                 0,
                                 0.16421875627276233,
                                 0,
                                 -0.37938929446817865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81329613655241995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046222177370781256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23618045183848013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18601052794326556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59190357988750186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2216607432700147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23954189607266924,
                                 0,
                                 0,
                                 -0.37258498220653735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66819034101804775,
                                 0.64617552369154285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5992610140077177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0194688963199918,
                                 0,
                                 0,
                                 0,
                                 -0.40965465054163352,
                                 0,
                                 0,
                                 -0.064687305298927245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33290450488169121,
                                 0,
                                 0,
                                 -0.18393426746925085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98530776247988783,
                                 0,
                                 0,
                                 -0.098313759425458114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33155477518272219,
                                 0.69881861657049127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052203224089011444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52350075155556097,
                                 0,
                                 0,
                                 0,
                                 -0.37139667863012366,
                                 0,
                                 0,
                                 -0.19561887425482921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34347990634936348,
                                 0,
                                 0,
                                 -0.40398971536187894,
                                 0,
                                 0.44661075418817892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30292150976921617,
                                 -0.66770499885164358,
                                 0,
                                 0.29274294176984361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12867378467845378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099752793410102292,
                                 0,
                                 0,
                                 -0.19390977515083041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16391090752669846,
                                 -0.034925380325228322,
                                 0,
                                 -0.29163996016032179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12547695165454997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095445714979432175,
                                 0.15159592723777296,
                                 0,
                                 0.10773188173299336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045820324990959928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23235746175192099,
                                 0,
                                 0,
                                 0.1862782087128047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2099836521896353,
                                 -0.8959615304851487,
                                 0,
                                 0.054119359264744746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28173580182524494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41882587814785005,
                                 0,
                                 0.15192244357021939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88595296466035067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2339427927771866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6903325934850677,
                                 0,
                                 0,
                                 0,
                                 0.21019800934192759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63991287651909656,
                                 -0.12282771951034649,
                                 0,
                                 -0.41555234392432594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49006973776153856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23220655250124633,
                                 0,
                                 0,
                                 -0.066425710247835029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0036390081604191493,
                                 -0.21637349200863204,
                                 0,
                                 -0.11500683376271603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12709722361309017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81251611090651932,
                                 0,
                                 -0.35527199728727077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60518657842770351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2369712789025181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037794166163925058,
                                 0,
                                 0,
                                 0.68298166296603557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.397827607018297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8259950278771383,
                                 0,
                                 -0.66345341875612318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52922096073168767,
                                 0,
                                 0,
                                 0.12338103298031368,
                                 -0.069572927154636449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81608890129648137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3184575347881084,
                                 0,
                                 0,
                                 -0.037866146941984841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042321257499532666,
                                 0.28157628948848029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62518653773113708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70819291642929849,
                                 0,
                                 0,
                                 0,
                                 0.053041299354298271,
                                 0,
                                 0,
                                 0.22425795189662412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.122641267615448,
                                 0,
                                 0,
                                 0.59656352531665113,
                                 -0.010359205819075023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38925418416938434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85123220683037248,
                                 0,
                                 -0.54375856453446225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36561974027370919,
                                 0,
                                 0,
                                 -0.74507316202126983,
                                 0.27889742649119204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48411432498778717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11434156534500391,
                                 0,
                                 0,
                                 -0.45901354610617939,
                                 0,
                                 0,
                                 0,
                                 0.12853955912578119,
                                 0,
                                 0.28938207002230454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020045602113816133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36829011025238356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25252157386316487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69004463150921802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.5870196223527775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15141009792247589,
                                 0,
                                 -0.10597009489389714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24670032253242699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42591380132011963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034887265299449105,
                                 0,
                                 0,
                                 0,
                                 -0.10471525155640944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12540992463413314,
                                 -0.20348778850912747,
                                 0,
                                 -0.53741995766174744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32281252207673639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20693694579083496,
                                 0,
                                 0,
                                 0.25383364331776814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65315259276346938,
                                 0.069227040150063909,
                                 0,
                                 0.014715331627749698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067331841327369898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1619915734432408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018342056396958843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051270251196037238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13409787774907433,
                                 -0.13203258704005064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97890624986086017,
                                 0,
                                 0,
                                 -0.057988269809303605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6623160070495886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16648980180565537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082358029294029828,
                                 0.35679355079481967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094989623776426876,
                                 0,
                                 0,
                                 0.62490890631951013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35081461921448598,
                                 0,
                                 0,
                                 0.64754761434364161,
                                 0,
                                 0,
                                 0,
                                 -0.18053357205081072,
                                 0,
                                 0.44202937004786702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3608288178711011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12385075128151456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21049509482321066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19945983589943667,
                                 0,
                                 0,
                                 -0.56377837582538126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22750252666444254,
                                 -0.44127893714180411,
                                 0,
                                 0.036827958050281343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13859742589310903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20986482399058551,
                                 0,
                                 0,
                                 -0.52810405625093015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064719227695976531,
                                 -0.192934068457145,
                                 0,
                                 0.2252878740797217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1947386413631233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095837428797683366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70487729598713167,
                                 0,
                                 0.21278638254087134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03166459516222056,
                                 0,
                                 0,
                                 0.59976874637860411,
                                 -0.38289148167407661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75931717169764101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32118629280461153,
                                 0,
                                 0,
                                 -0.4381832965085502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55340012867375399,
                                 0.21381845633669144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029128623828010049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81650361252341919,
                                 0,
                                 0,
                                 0,
                                 0.70809998601446789,
                                 0,
                                 0,
                                 0.033042182587066676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69268536270451675,
                                 0,
                                 0,
                                 0.18775908086412396,
                                 0,
                                 0.10732833741398637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076250845219525382,
                                 -0.08123673772042489,
                                 0,
                                 0.33578518915185102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23156163437975999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28823424357812333,
                                 0,
                                 0,
                                 0.17321775129165412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21193828973844137,
                                 0.081145931199959442,
                                 0,
                                 0.80318657603591781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97777109142405905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39238061432148913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085834162871184908,
                                 0,
                                 0.060749564930404565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34733319473631735,
                                 0,
                                 0,
                                 0.28421822917502576,
                                 0.50630009253819153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10241676130928183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39605232960259179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03639297827903526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43533287175455276,
                                 0,
                                 -0.29923039675077817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1117930481496228,
                                 0,
                                 0,
                                 -0.016341481911991806,
                                 0.099384828745648454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034406854125544062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15482596796651371,
                                 0,
                                 0,
                                 -0.42214760062113549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11578509038653557,
                                 0.088750311648673946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09113278682190476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46819299139931309,
                                 0,
                                 0,
                                 0,
                                 0.98836236537351585,
                                 0,
                                 0,
                                 -0.41570688638683256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98457383080385719,
                                 0,
                                 0,
                                 -0.67817580519873488,
                                 0,
                                 0,
                                 0.464067161189396,
                                 0,
                                 0,
                                 -0.15480065247102062,
                                 0,
                                 0,
                                 0,
                                 -0.098531736264261066,
                                 0,
                                 0.027144687766395961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033371198423082671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72337911624265927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42631340961630948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20999758297678112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048454974075311553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68175338117807305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53990989474591411,
                                 -0.47398625128218819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09811006069183266,
                                 0,
                                 0,
                                 0.084102306041998448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51617495439900885,
                                 0,
                                 0,
                                 -0.47692308627097535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15394002765418718,
                                 0.27270832640416581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5452517963043545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32201718483885666,
                                 0,
                                 0,
                                 0,
                                 -0.72711199953965711,
                                 0,
                                 0,
                                 -0.064003054550551247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54797482128918762,
                                 0,
                                 0,
                                 0.47365404757399704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14539763218516663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37656066901788199,
                                 0,
                                 -1.0215383474569117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12012444591673981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33854269170320683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28307418421725916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57684744129060417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26140677247765953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47604114160441591,
                                 -0.021449717185393583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10082635419352914,
                                 0,
                                 0,
                                 0.60139198216468415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36340994762599882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29870768725756824,
                                 0.31008095370119271,
                                 0,
                                 0.17305512847236298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54951536968875669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32158346708368635,
                                 0,
                                 0,
                                 -0.46799854959432191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16572826777582322,
                                 -0.022340438742311189,
                                 0,
                                 -0.015426860003845196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44288200418681067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31414869535630935,
                                 -0.23125833567795881,
                                 0,
                                 -0.12047713176428676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28900924906793046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65304489284801592,
                                 0,
                                 0,
                                 0.19380265628945625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07654200928297937,
                                 0.19438895715318705,
                                 0,
                                 0.21441030040558215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25757094077477305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19072371176217109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28199359954491388,
                                 0,
                                 0.58936900122477698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59552606324997526,
                                 0,
                                 0,
                                 -0.85113651982733829,
                                 -0.1638852710559533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88398683392930488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054679476765482307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063949009672440216,
                                 -0.34749429012425065,
                                 0,
                                 -0.028052436028749815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41965657966319136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42672079647670347,
                                 0,
                                 0,
                                 0.34683367275561411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58220328952722566,
                                 -0.22731486452282892,
                                 0,
                                 0.047464308903037516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3515964906467931,
                                 0,
                                 0,
                                 -0.32903392011722432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1659559535286283,
                                 -0.51057890243843573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34986009676064755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36930895651035228,
                                 0,
                                 0,
                                 0,
                                 0.36175077659303773,
                                 0,
                                 0,
                                 1.2989303271061823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014028468669544157,
                                 0,
                                 0,
                                 -0.062984113477863243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30795179043848153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25103640225512402,
                                 0,
                                 -0.48277650336661859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14144702430093709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84031643140234369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0790404805652365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41988478948012126,
                                 0,
                                 0,
                                 0.15305269453739193,
                                 0,
                                 0,
                                 0,
                                 0.752508318100789,
                                 0,
                                 0.42142902189629694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14933128650294136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061187422638774115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088274888719062694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15021403780794748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058915193276802835,
                                 0,
                                 0,
                                 -0.77161081222772354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62816991164109037,
                                 -0.85936890207679817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76364939450211566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095382786660645799,
                                 0,
                                 0,
                                 0,
                                 0.049672345943825136,
                                 0,
                                 0,
                                 -0.018311101587331458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1743437661018104,
                                 0,
                                 0,
                                 -0.2648520670796074,
                                 -0.74334544270398817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37020372211330071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34119890423819416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10258873133165132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12372180875725557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41004698625025976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22467527110601512,
                                 0,
                                 0,
                                 0,
                                 -0.60323310908388383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017609398284961442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15697729523098819,
                                 -0.57039885927953315,
                                 -0.40325726128337464,
                                 0,
                                 -0.14151003242124816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018299037299388733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18969800568699158,
                                 0.12791529104723609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014557658364921748,
                                 0.28629281488193253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014638910876471102,
                                 0,
                                 0.3287374962309903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61933570277555483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058133533191893461,
                                 0,
                                 -0.59559146313400602,
                                 0,
                                 0,
                                 0.26049270281155412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21688707683119693,
                                 0.036204780221327337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055895775517344759,
                                 0,
                                 0.63010772776805346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22683319155871329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34149421612537206,
                                 0,
                                 0.61009609345448268,
                                 0,
                                 0,
                                 0.10583139321970605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.003629632290041086,
                                 0,
                                 0,
                                 -0.072864128859764871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88514507537604092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55953220322719111,
                                 -0.23312182444102794,
                                 0,
                                 0,
                                 0,
                                 -0.081766847379375604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35726423674288071,
                                 0,
                                 0,
                                 -0.41633149431327532,
                                 -0.82728194532725263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60566150636469007,
                                 0,
                                 0.059038871921328444,
                                 0,
                                 0,
                                 0,
                                 0.024160122461897346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0075849281209137802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59824496897089852,
                                 -0.14416085683285373,
                                 -0.15398843178367003,
                                 0,
                                 0.31241011464848184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67671227359019248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038384630886515031,
                                 -0.19096694854014976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14458586990036243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19101492774787171,
                                 0.44837204580808843,
                                 0,
                                 0,
                                 0,
                                 0.26607295633034989,
                                 1.2460880531398673,
                                 0,
                                 0.22669741573024527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36021748375402568,
                                 0,
                                 0,
                                 0.51234196447159031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16508533360176419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079087723083761718,
                                 0.35457640108298516,
                                 0,
                                 0,
                                 0,
                                 0.95144528611198043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5848487690825066,
                                 0,
                                 0,
                                 -0.15325305083711038,
                                 0.22615211984289391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3918784078930998,
                                 -0.045863834241280058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70226163262859898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37188793260573749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54647904466926867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054126377117004854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25466735689185754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11580352033053637,
                                 0.44589845463872491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48731881753493811,
                                 0,
                                 0.19077457505630391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41227285520423157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44265207578587312,
                                 0,
                                 0.11014402969764436,
                                 0,
                                 0,
                                 0.3685757314371923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0056201806643849384,
                                 0,
                                 0,
                                 -0.15572729736645091,
                                 0.38849735483050651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4653744717559124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51658990034384755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35950029272746559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79843612670503183,
                                 0.28966585678426526,
                                 0,
                                 0,
                                 0,
                                 -0.58392900673618087,
                                 -0.25297157303766515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28147604976223051,
                                 0,
                                 0.4322566790931453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40398001457084193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25880591959741522,
                                 0,
                                 -0.31272504421725578,
                                 0,
                                 0,
                                 -0.031311110560904576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1722293105336612,
                                 0,
                                 0,
                                 0,
                                 -0.13114157206904326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79144090379627607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15831440336736946,
                                 0.34252732429377514,
                                 -0.1255264406059802,
                                 0,
                                 -0.28165603963484309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1052682698835644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17024146058578146,
                                 0.22185863689391064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46708302705629307,
                                 0,
                                 0,
                                 0.79318998486120218,
                                 0.74891935424959477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28026395606620386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084533409639269835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069543060888317632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20841286780506588,
                                 0.60967481649449795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9502151115324794,
                                 0,
                                 0,
                                 0.098720718334731838,
                                 -0.5522729895735512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18015250044118181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0099722323420910475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38639734256294456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070733444592286088,
                                 -0.24468110444546159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63587449777491345,
                                 0,
                                 0,
                                 0.22294699438322574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14208515806641916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74332971415316362,
                                 -0.38494095841060744,
                                 0,
                                 0,
                                 0,
                                 -0.36228265234004131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42571625520529277,
                                 0,
                                 0,
                                 -0.22647531654303865,
                                 0.4617469114098619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44639673805938851,
                                 0.049173206308788145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42311743836457838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04005639859673911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75028067086130301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037384128444987869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50262357280264047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065667915434823448,
                                 0,
                                 0,
                                 0,
                                 0.1673088172300333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30790875905224024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04692653922243336,
                                 -0.3679849633016925,
                                 -0.062385963705104422,
                                 0,
                                 -0.17952095156049186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16332269274809455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30032115149965005,
                                 -0.76307651702678991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092525959243454151,
                                 0,
                                 0,
                                 0,
                                 0.45877635376099729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050186149009625036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29292856473287671,
                                 -0.40611246282903285,
                                 -0.060365315943136377,
                                 0,
                                 0.10176902293279844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24380588778930071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49975417135041211,
                                 0.45223183207446438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48629827326774894,
                                 0,
                                 0,
                                 0,
                                 0.46931397195337177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21649592987421074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038862028217928946,
                                 0.21070444580940961,
                                 -0.53559655752795454,
                                 0,
                                 -0.29775120104710368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011546128943284405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25127669234927208,
                                 -0.10811353939558721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44747240232337038,
                                 -0.25526902454916578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47732010537298297,
                                 0,
                                 0.17431327763458559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18584302015118154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59086345758003989,
                                 0,
                                 0.27799653889218567,
                                 0,
                                 0,
                                 0.12428693910984993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23466557899044099,
                                 0,
                                 0,
                                 0,
                                 0.31936234058745078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31271437765090593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30407283178890132,
                                 -0.38700124617638931,
                                 0.30673766357635956,
                                 0,
                                 0.14944162326057139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3574907720705997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4787290610811068,
                                 0.17180590452461786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15210584577367178,
                                 0,
                                 0,
                                 0.19981906052343887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36393928351886118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82511298185809223,
                                 0.50583033208965889,
                                 0,
                                 0,
                                 0,
                                 0.081626438969966963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21127976815496446,
                                 0,
                                 0,
                                 0.30005176692438951,
                                 -0.13723844696120491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22710917980741435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51360268264619446,
                                 0,
                                 0,
                                 -0.67255557513057784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19639440566168953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09038739377141454,
                                 0.65486033007895628,
                                 0,
                                 0,
                                 0,
                                 -0.39287660503808824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1988920414216955,
                                 0,
                                 0,
                                 0.80434156181967797,
                                 0.33869902518631612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82489448267505716,
                                 0.079171472429841683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076934698005083874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46690030039482039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13021271180692118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86744240549075791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020133616855381238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043257913724512653,
                                 0,
                                 0,
                                 0.34542357609946062,
                                 0.21352841228727468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43052839674094845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0028702715863227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21675153389121818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28489371794234797,
                                 0.072016358020063384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18407835220729987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34818072081261875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38047108840004851,
                                 0,
                                 0,
                                 -0.41339473918582176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36624308682273704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18875069309206322,
                                 -0.6878650298124438,
                                 0,
                                 0,
                                 0,
                                 0.19903192910578754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3469507213446249,
                                 0,
                                 0,
                                 0.65688171071833468,
                                 -0.10360702134577052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41790361997912578,
                                 0,
                                 -0.40064612806924271,
                                 0,
                                 0,
                                 0,
                                 0.13288459736874267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3364214367647097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36165445680070468,
                                 0.096162359172686729,
                                 -0.43732130699858329,
                                 0,
                                 0.51196840740597183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0069668133692630252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33661170684060293,
                                 -0.043431346715796619,
                                 0,
                                 0,
                                 0,
                                 0.016263366968643056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078531414001063823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65291330702105477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33183396853268654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40535304701502262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54115400583212125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0021627968628346872,
                                 0.73636135964720428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44517543581256369,
                                 0,
                                 0.056452996035615939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083595010798560937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037741224605866194,
                                 0,
                                 0.075602674572597839,
                                 0,
                                 0,
                                 -0.49221018950064044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50658244072175584,
                                 0,
                                 0,
                                 -0.16037306312394339,
                                 0.52462748661204628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53246650335259571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062455065837564772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45801686192179608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37613442065177544,
                                 -1.008493207538534,
                                 0,
                                 0,
                                 0,
                                 -0.10944537101161012,
                                 -0.15004382755952583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49522112093675646,
                                 0,
                                 0.10621606135866112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29640056013989402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41067550076472487,
                                 0,
                                 0.050944242492507674,
                                 0,
                                 0,
                                 -0.67073077716791663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12707460708716667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11232438223052077,
                                 -0.63318193236643916,
                                 0,
                                 0,
                                 0,
                                 -0.61170595972030772,
                                 1.0735111104648447,
                                 0,
                                 0.6441227744800575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57000600422460646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57809449712937511,
                                 0.62635390666362556,
                                 0,
                                 0,
                                 0,
                                 -0.45725813213674654,
                                 0.17652890178006875,
                                 0,
                                 0.31062822594678752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62140969777636546,
                                 0.15492615130208659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093238177739734085,
                                 0,
                                 -0.47623652071061884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32003466240912692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31286168827261518,
                                 0,
                                 0.27844523582394592,
                                 0,
                                 0,
                                 0.27661692504302643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61177797525694078,
                                 0,
                                 0,
                                 0.11976989045934607,
                                 -0.67662232706163383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0296132932703443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33839212756380443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3852475905318794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70498818552830644,
                                 0.77133986367106377,
                                 0,
                                 0.66059324712666267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4226858243198256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31525621527005848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029085870878737631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25218694793837726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47023667435459821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54726851065123716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21145985876393691,
                                 0.22821446896346392,
                                 0,
                                 0,
                                 0,
                                 -0.7204592199818648,
                                 0.63754438575441397,
                                 0,
                                 -0.73238548292933847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57716838371301971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27117258046466342,
                                 0.39301325373662871,
                                 0,
                                 0,
                                 0,
                                 -0.31199884396643912,
                                 -0.66766816632755854,
                                 0,
                                 0.68371815772328204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72546926378780252,
                                 0,
                                 0,
                                 -0.23204842425842995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33576236145801203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23642350413628094,
                                 -0.38885433079841902,
                                 0,
                                 0,
                                 0,
                                 0.3986883351411839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20495161537387091,
                                 0,
                                 0,
                                 0.21221801073250435,
                                 0.58694193562055874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23526816697617695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36506332150398246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.4642943083500408,
                                 0.11413253016119951,
                                 0,
                                 0,
                                 0,
                                 0.52219341045265488,
                                 0.12775447589113548,
                                 0,
                                 0.56751062244204997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018418898051289333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047848836927347344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41334396036941501,
                                 0,
                                 0,
                                 0.86050236950888936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29120567305041517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30139288116866753,
                                 -0.26908382804972009,
                                 0,
                                 0,
                                 0,
                                 -0.53075092566632753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78686489406885018,
                                 0,
                                 0,
                                 0.19785595372272666,
                                 -0.11810943832141074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37956252299068322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30259915286013239,
                                 0,
                                 0,
                                 -0.39699721056958176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34849702060118426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28718867391267877,
                                 -0.1276062333465352,
                                 0,
                                 0,
                                 0,
                                 0.11686131600219157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021180294534127501,
                                 0,
                                 0,
                                 -0.04622125634258463,
                                 -0.66273530800268865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74249923123101791,
                                 0,
                                 0.21851492174550968,
                                 0,
                                 0,
                                 0,
                                 -0.13053674573526453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091730425507226071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31554766176309695,
                                 0.098963851172459524,
                                 -0.33216040842170291,
                                 0,
                                 0.4819900798179701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53355929685433456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43346750053354322,
                                 0.04699121296930759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63535748597847153,
                                 0,
                                 0,
                                 0,
                                 -0.15137351983942615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098349359844425305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42432720182925404,
                                 0.15162514281704945,
                                 0.32839937241353184,
                                 0,
                                 0.3937579669496325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17849817230825923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0094393212128981163,
                                 -0.25660940188141901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30936717837481942,
                                 0,
                                 0,
                                 -1.3149261135083841,
                                 0.090091927128971613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54716925911194192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40454182115830978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081670078049601053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27910470230678031,
                                 0.32696468132787482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32888392780129722,
                                 0,
                                 0,
                                 0.33499186709941836,
                                 -0.0042177905821298902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81051394099084306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028227035185134319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81232286595592651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14950588075965443,
                                 0.79673388313595206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31089020455144539,
                                 0,
                                 0,
                                 0.24477580085198597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24786468457966493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24162180806690764,
                                 0.037153835859490295,
                                 0,
                                 0,
                                 0,
                                 0.27462739485050097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97375138064857814,
                                 0,
                                 0,
                                 0.78749431787396718,
                                 -0.4785432379696547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017528369509344277,
                                 0.23603925333632902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90877161824206409,
                                 -0.62618183489206414,
                                 0,
                                 -0.47795803331827091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61680822917506894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6150912355625674,
                                 0,
                                 0,
                                 0.095527082190623405,
                                 0,
                                 0,
                                 0,
                                 0.43558337359525334,
                                 0,
                                 0,
                                 0.2104756251495242,
                                 0,
                                 -0.1709094550501446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60660941870584351,
                                 0,
                                 0,
                                 -0.088838697817693685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29243949597635849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24499430880701881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26269672164480262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57971547381636612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29816063148582567,
                                 0,
                                 0,
                                 -0.23012900560333635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54855591424293848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015768933927408746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70067400207125397,
                                 0,
                                 0,
                                 0.25697192668720037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010371594263920196,
                                 0,
                                 -0.63738765351312865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29107413803137366,
                                 0,
                                 0,
                                 0.22791638194518649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20426227414651496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4434257154133136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43456557233859727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17251869406093509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37291598984323626,
                                 0,
                                 0,
                                 0,
                                 0.16750103503596583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13907216453179574,
                                 0.1134309130242234,
                                 0,
                                 0.14023062367479061,
                                 0.25022613446448383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16778180121681091,
                                 0.15143919403264591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38064369467593417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72278454466973219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59259261363163418,
                                 0,
                                 0,
                                 -0.40286925181042549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13382511142229783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026281356260144717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46448181501396268,
                                 0,
                                 0,
                                 0.50218237085963968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74064907803991287,
                                 0,
                                 0,
                                 0,
                                 -0.77613987559317277,
                                 0.36644161862437985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63119483928092279,
                                 0.58623635281277586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010695992792968506,
                                 0,
                                 0,
                                 -0.63109795488433862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38196617628119728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47796637003449299,
                                 0,
                                 0.16212595434557003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3684129277949399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31734653205937546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11153715192177452,
                                 0,
                                 0,
                                 0,
                                 -0.30401897290762947,
                                 0,
                                 0,
                                 0.40756477257520468,
                                 0,
                                 0,
                                 0,
                                 -0.17923864104232157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36472857975122841,
                                 0,
                                 0,
                                 0,
                                 -0.32781697390551673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21613877239595874,
                                 -0.17620413787104322,
                                 0,
                                 -0.033841753170495772,
                                 -0.75000170331129812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24187456819856676,
                                 -0.16361509938380719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11204838160364877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14237050628997031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47650928560279893,
                                 0,
                                 0.19143501343459268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40745504109661596,
                                 0,
                                 0,
                                 -0.41376848991732335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36710473162038504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49785483595901137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083221761060957355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097551931924279092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65766909823790742,
                                 0,
                                 0,
                                 0,
                                 0.28043998163328021,
                                 -0.35956221268960592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56106302084525483,
                                 0.36868603387208199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37102577705352446,
                                 0,
                                 0,
                                 -0.53451967781009357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51828064581647204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35543503361111034,
                                 0,
                                 0.41626806002169897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27329311596341099,
                                 0,
                                 0,
                                 0,
                                 0.013321588749977437,
                                 -0.70641357722883824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69898061157634317,
                                 -0.10090446669309502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78717546884585543,
                                 0,
                                 0,
                                 0.0017321856520352841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52118336686793754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68274538572018983,
                                 0,
                                 -0.15573458153023034,
                                 0,
                                 -0.21026667067446431,
                                 0,
                                 0.19209232689040806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14126914420939735,
                                 0,
                                 0,
                                 -0.52473326194850389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5792575815826474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10152134025671544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5174817398496464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09976581792479533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20126676451134481,
                                 0,
                                 0,
                                 0,
                                 -0.55197559806222718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1647585580287998,
                                 -0.23813490884944272,
                                 0,
                                 -0.22913346796967587,
                                 0.25393223524124559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42039346099532265,
                                 0.41350094263742948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30949662144804435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10234957183432913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29838799847676717,
                                 0,
                                 0,
                                 0,
                                 0.25989572872353717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41073429273597295,
                                 0.61645295249278886,
                                 0,
                                 -0.29681692615998112,
                                 -0.018369302445638239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27802233883420219,
                                 -0.24071628418377394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21028503632547593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16371818743804006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33182203096144147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80110449160266339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48998771104930472,
                                 0,
                                 0,
                                 0,
                                 0.36901653646533705,
                                 0,
                                 0,
                                 -0.78555259259139021,
                                 0,
                                 0,
                                 0,
                                 0.042325794008715611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23197047534867027,
                                 0,
                                 0,
                                 0,
                                 0.13832724965954446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034854702548948041,
                                 -0.55851179035329235,
                                 0,
                                 -0.20270092348741231,
                                 0.3695352396940344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088633983428950347,
                                 -0.63384559922710826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12807131497601876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10120550458648049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3237022927066231,
                                 0,
                                 0,
                                 0,
                                 0.13324812316145279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091867475523636138,
                                 -0.12098638236247053,
                                 0,
                                 0.55502588075713899,
                                 -0.16589976599844775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25244071031479198,
                                 -0.13537735789984037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64764655660026027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13156200588795389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11404064262857004,
                                 0,
                                 0,
                                 -0.16643746997006129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73574585163097928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35286379688822728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4878029806582278,
                                 0,
                                 0,
                                 -0.23559867387828115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60035020819822638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33429391750704701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48085611317274496,
                                 0,
                                 0,
                                 0,
                                 0.27465813113050952,
                                 -0.16399362451691885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3160837105022084,
                                 0.048127051127817844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71622739473722918,
                                 0,
                                 0,
                                 -0.3097110189314225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57806957632336309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026817828853887615,
                                 0,
                                 -0.24653283350966237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013035895098172823,
                                 0,
                                 0,
                                 0,
                                 0.93148066593334677,
                                 0.2555588859115604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27129956466213068,
                                 -0.14212697843240837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5781116886995854,
                                 0,
                                 0,
                                 0.15200382151252734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12502351230152087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51448836273964316,
                                 0,
                                 -0.96440219423905871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025040143848501697,
                                 0,
                                 0,
                                 0,
                                 0.33010238816042281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33208694556843282,
                                 -0.14207389323849973,
                                 0,
                                 -0.15001516932212144,
                                 0.043556000611816012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59222206142003231,
                                 0.46482008060535979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24695307693612262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32827808056446856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34563764959216714,
                                 0,
                                 0,
                                 0,
                                 0.041451125704587463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51958080621351987,
                                 -0.10181742223781873,
                                 0,
                                 0.60923434907032226,
                                 0.18530002671368762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080340891551284668,
                                 0.074442360104853639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42452144221506688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027713660616147849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06959681408566476,
                                 0,
                                 0,
                                 0.73724538819959018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24037845336071256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038887175906129806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13950850014467145,
                                 0,
                                 0,
                                 0.61062990931078909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52040141033804388,
                                 0,
                                 -0.13355240074273933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4096588819300529,
                                 0,
                                 0,
                                 -0.35279805285592575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062900703604306871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55255494475402256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21856547038189572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24902797513859337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70503794490627358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36703959864681018,
                                 -0.082306091501677503,
                                 0,
                                 0.31992584694639603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11085682497220749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63066398241438726,
                                 0,
                                 0,
                                 -1.0302959619817913,
                                 0,
                                 0,
                                 0,
                                 0.046450447178967187,
                                 0,
                                 -0.73334778423161839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35172158753250482,
                                 -0.47725553258686437,
                                 0,
                                 0.71933636277964996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.508161245742208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46946542694860549,
                                 0,
                                 0,
                                 -0.15433613248751613,
                                 0,
                                 0,
                                 0,
                                 -0.14505211800463569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21901234583529736,
                                 0,
                                 0,
                                 0,
                                 0.10058184118039742,
                                 1.2645121121843472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20311409806875555,
                                 0.015933170232618855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17234784339000642,
                                 0,
                                 0,
                                 -0.36613561893286795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014248126190443553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44942712499801751,
                                 0,
                                 0.34658833252452242,
                                 0.2901419258509188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45899899417951012,
                                 0.59323677283932308,
                                 0,
                                 0.16550238833917971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54905993554138277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68656778790775352,
                                 0,
                                 0,
                                 -0.20513195614720897,
                                 0,
                                 0,
                                 0,
                                 -0.64070456185893787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29832368884343408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14524448876827067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34250970978886058,
                                 0,
                                 0,
                                 0,
                                 0.61458322406811039,
                                 -0.28055113842862478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70519207943983409,
                                 0.36549799734166083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64270484608296652,
                                 0,
                                 0,
                                 0.10623557936674584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33779758866619042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017862487595817683,
                                 0,
                                 0.17007457983208113,
                                 0,
                                 0.51780324576627312,
                                 0,
                                 0.63197864451134778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37710544197198614,
                                 0,
                                 0,
                                 0.16937941455653482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08894120204479003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23109369814333108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2368093063637195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21021752731851026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24599378115185702,
                                 0,
                                 0,
                                 0,
                                 -0.43261842450688853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3030021633575421,
                                 0.36858653228539279,
                                 0,
                                 0.30277618787047633,
                                 0.2259298346634516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39389462589916474,
                                 -0.15679685911147534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15738131799403712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42123294612936885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.722168695145187,
                                 0,
                                 0,
                                 -0.44755025984699576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033799040820336995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26541297140952308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038223270954834909,
                                 0,
                                 0,
                                 0.45290584194497957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35206152544270125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77908696505900732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24917972591717069,
                                 0,
                                 0,
                                 0,
                                 -0.0645730599904073,
                                 0,
                                 0,
                                 -0.25289324183604633,
                                 0,
                                 0,
                                 0,
                                 -1.2501063872302589,
                                 0,
                                 0,
                                 0,
                                 -0.60249526113690988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89029014546667573,
                                 0.56808759610540394,
                                 0,
                                 -0.076544484849345978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35610179372438172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80890741670682398,
                                 0,
                                 0,
                                 0.2589123447768461,
                                 0,
                                 0,
                                 0,
                                 0.033134286465048679,
                                 0,
                                 0,
                                 0,
                                 0.143379298197085,
                                 0,
                                 0,
                                 0.11490682227358957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28448394385139703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89587472005808788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18557262284246931,
                                 0,
                                 0,
                                 -0.21972476498215063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29641362968304236,
                                 0,
                                 0,
                                 0,
                                 -0.53947531650910818,
                                 0.011781857188735811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58763626062232954,
                                 0.12989685988326091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01731797698456182,
                                 0,
                                 0,
                                 -0.30782890896852255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40390124037323488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17999812407892399,
                                 0,
                                 -0.50699490956343096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26757854636434508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79804045581575334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62138472633319253,
                                 0,
                                 0,
                                 0,
                                 -0.42336214981293346,
                                 0,
                                 0,
                                 0.97604528167879967,
                                 0,
                                 0,
                                 0,
                                 -0.021447684700874402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32271827139807863,
                                 0,
                                 -0.2662675717403451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21783916325226896,
                                 0,
                                 0,
                                 -0.58337875099136549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22639954068651544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.315139151938088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0073131251700557561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53530076637676993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69676934981476479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13611766255677984,
                                 -0.21600961661561596,
                                 0,
                                 0.46857579542139516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46922658472984408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45734342170159292,
                                 0,
                                 0,
                                 0.99658797637492902,
                                 0,
                                 0,
                                 0,
                                 -0.23612065229562204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45850324511803581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48455641921007958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61337980096487821,
                                 0,
                                 0,
                                 0,
                                 0.93074581863613548,
                                 0,
                                 0,
                                 0.30889413163238227,
                                 0,
                                 0,
                                 0,
                                 0.60738521533931045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50908173192337514,
                                 0,
                                 0,
                                 0,
                                 -0.39689118178384419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50634392905997716,
                                 0.16242572839214647,
                                 0,
                                 -0.064045439955597638,
                                 0.24229893577903516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27459420434146076,
                                 -0.23472752437751415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026946286113719353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3263605453361425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22551063500249821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051562670493816395,
                                 0.41354113394014252,
                                 0,
                                 0.91848381463616746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47846898572262264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59326788425955468,
                                 0,
                                 0,
                                 -0.068785506849776967,
                                 0,
                                 0,
                                 0,
                                 0.63326932611776143,
                                 0,
                                 0,
                                 0.20306244676466167,
                                 0,
                                 -0.053370781159417409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061979534771034905,
                                 0,
                                 0,
                                 -0.011217392067655093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5825178510538368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1647769825222197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6029319936441585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47110977499084172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5056653734505796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72111354602520383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2549633849965996,
                                 0,
                                 0,
                                 0,
                                 -0.90967940239050937,
                                 0,
                                 0,
                                 -0.48068637545120863,
                                 0,
                                 0,
                                 0,
                                 0.43095182164018653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34939518157715577,
                                 0,
                                 0,
                                 0,
                                 0.37337437721336386,
                                 -0.1682157364382062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25218014424685831,
                                 -1.0384969961069783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59344450928667203,
                                 0,
                                 0,
                                 -0.66796526400954015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10343896353995619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13702841451970721,
                                 0,
                                 0.053431533521023339,
                                 0.1614755590563467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48173329225746725,
                                 -0.9466409559178256,
                                 0,
                                 -0.28603934627887456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77067516609307818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51003924441629322,
                                 0,
                                 0,
                                 0.020565870669302773,
                                 0,
                                 0,
                                 0,
                                 -0.40559435786708842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35990770691129126,
                                 0,
                                 0,
                                 0,
                                 0.3183358063485775,
                                 -0.18542997905222028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045215056422119482,
                                 0.16468162229284045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59620058249982399,
                                 0,
                                 0,
                                 -0.63075316958604288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67639526511886872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69120726039621194,
                                 0,
                                 -0.19754574414047762,
                                 0.94400383727742876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54575177810675823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069790909160269823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53349561773806831,
                                 0,
                                 0,
                                 0.39100203928513733,
                                 0,
                                 -0.40023764761159603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038100836105851285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60550319274072939,
                                 0,
                                 0,
                                 0.32468932062458095,
                                 -0.29831753020581636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41445415697788357,
                                 0,
                                 0,
                                 0,
                                 0.13068813482009084,
                                 0.50225596875194689,
                                 0,
                                 0.049165741470093352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21183678669239067,
                                 0,
                                 0,
                                 -0.11450731474076135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41524694659923311,
                                 0,
                                 0,
                                 0,
                                 -0.42509811707891454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10672755440024151,
                                 0,
                                 0.36599737553998213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28931994525913302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24993718366023898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90675778011607333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081570530211286588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11566812570636098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10762358010602691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027846778376746793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74497300592345306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28638661372277291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44349651860963857,
                                 0,
                                 0,
                                 -0.2441538309418351,
                                 -0.24189135476171914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18573821844316063,
                                 0,
                                 0,
                                 0,
                                 0.11363149377910853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25838263201812528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037108542113298351,
                                 0,
                                 0,
                                 0,
                                 0.23598024428920811,
                                 0,
                                 0,
                                 0,
                                 -0.092244127045754798,
                                 -0.32389563035775265,
                                 0,
                                 0.091981540526049885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40675905305154164,
                                 0,
                                 0,
                                 -0.080065879967353745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61543077618528841,
                                 0,
                                 0,
                                 0,
                                 0.085486976723513575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51380383273707353,
                                 0,
                                 0.022681441607393486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17422337074580996,
                                 0,
                                 0,
                                 0,
                                 -0.30078522086869219,
                                 0.28513340465326148,
                                 0,
                                 -0.098485543784846891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61058464175293781,
                                 0,
                                 0,
                                 -0.083789311488715656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46475615226920286,
                                 0,
                                 0,
                                 0,
                                 0.3802278503026581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082698854477341849,
                                 0,
                                 -0.20230954993560585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21455415141048201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.4776328581932729,
                                 -0.68599949205192878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28372047670919281,
                                 0,
                                 0.05687086339998737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10516992587487335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2870667135651368,
                                 0,
                                 0,
                                 0,
                                 0.26381279758997489,
                                 -0.36548133754874373,
                                 0,
                                 -0.30946740589691341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11978821574367018,
                                 0,
                                 0,
                                 -0.5205203916116613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084413326873283068,
                                 0,
                                 0,
                                 0,
                                 0.41557995608050879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34978018021618845,
                                 0,
                                 0.17657759638557496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38035800213315285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022886816550261063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21103903216740488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1282716821034609,
                                 0,
                                 0,
                                 0.28332894244783519,
                                 0.18372775268396299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72368669042469969,
                                 0,
                                 0,
                                 0,
                                 -0.39504339468076893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31468462116719709,
                                 0,
                                 -0.074939347379643695,
                                 0,
                                 0,
                                 0.087352366589848018,
                                 0,
                                 0,
                                 0.6785918313462409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78114671697265736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38799781314700277,
                                 0,
                                 0.39803980109224574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1195745572064026,
                                 0.42471279621469055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064142732780946149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43610646831112204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53469252828962399,
                                 0,
                                 0,
                                 0.087611692918881295,
                                 0,
                                 0.52248238803445735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78331822630762871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23625914369065856,
                                 0,
                                 0,
                                 -0.22626210739248581,
                                 -0.16220819346734758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32084249402791726,
                                 0,
                                 0.14730776368692544,
                                 0,
                                 0,
                                 -0.78381705999688212,
                                 0,
                                 0,
                                 -0.19766024033934693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26510975131686704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17425652363585578,
                                 0,
                                 -0.055212410341072292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52220265377425401,
                                 0,
                                 0,
                                 -0.53777581965774091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45829757522819792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2538938230771115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58290102538425548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17369173788774261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2575965871866448,
                                 0,
                                 0,
                                 -0.3932155910866737,
                                 0,
                                 0,
                                 0,
                                 0.34172288006074847,
                                 0.1651057579746866,
                                 0,
                                 0.15239158915857931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28227245169792431,
                                 0,
                                 0,
                                 -0.058709051746957258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074015784332105664,
                                 0,
                                 0,
                                 0,
                                 0.10330490940509522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19012083551781508,
                                 0,
                                 -0.73668392267417071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42578365525970169,
                                 0,
                                 0.57264081788669108,
                                 0,
                                 0,
                                 0.26022216435456136,
                                 0,
                                 0,
                                 -0.20037494993799138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49678917281459278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65738303154111,
                                 0,
                                 0.11122780549935717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77313205327131962,
                                 0,
                                 0,
                                 0,
                                 0.21740421014070521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23150956197912159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33636108260918429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024057392430699695,
                                 0,
                                 0,
                                 0.74269056364324815,
                                 -0.206659715225609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0049165640563430535,
                                 0,
                                 0,
                                 0,
                                 0.43714930204309888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16818505573775014,
                                 0,
                                 0,
                                 0,
                                 -0.36357904024130755,
                                 0.46624139654802566,
                                 0,
                                 0.25803259295292613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33948483691792003,
                                 0,
                                 0,
                                 -0.38803171790956748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30207741024231277,
                                 0,
                                 0,
                                 0,
                                 0.40938112961107098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062436725355568885,
                                 0,
                                 0.16432171283227781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42564329868555006,
                                 0,
                                 -1.0892476283756736,
                                 0,
                                 0,
                                 0.6354487777502954,
                                 0,
                                 0,
                                 -0.23026298624027375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72868641146395263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071096288561230542,
                                 0,
                                 -0.15036953678306983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31886463964251177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87969002584202771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035181618935437586,
                                 -0.68196641413749493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95292314631988806,
                                 0,
                                 0.073957233636775532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34557158315342495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61081339005371749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40208249180401689,
                                 -0.80568708013268875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4743142730259865,
                                 0,
                                 0.26333038467581887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46320160630187257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071157093737199972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86844089112155864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2500595597941272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52407254693666916,
                                 0,
                                 0,
                                 0.068694107139351812,
                                 0,
                                 -0.15529129986171544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11885837505571285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20650637025593288,
                                 0,
                                 0,
                                 0.28940225062761965,
                                 0.59647972715183806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2948484617514634,
                                 0,
                                 0,
                                 0,
                                 0.3155802048859635,
                                 -0.090484089999682549,
                                 0,
                                 0.50738341046767488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15086398279322044,
                                 0,
                                 0,
                                 0.36555626674628883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064321554705486145,
                                 0,
                                 0,
                                 0,
                                 0.40810880763048835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21121541538682045,
                                 0,
                                 0.41970809463482261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12030206332274479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79978132892684717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18808127118990681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40856695804602416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09927788176283156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36567693101095222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50856478666494209,
                                 0,
                                 -0.29749355691768076,
                                 0,
                                 0,
                                 0.19621351027123612,
                                 0,
                                 0,
                                 -0.78427309874732931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22663789157159742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064245163905358602,
                                 0,
                                 -0.93660856664276404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.325132306783112,
                                 0,
                                 0,
                                 0,
                                 0.24670154125835936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.049493786105425763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21136512358694082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62404055994776197,
                                 0,
                                 0,
                                 0.14731661162471846,
                                 0.34250936201026039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42322423082602623,
                                 0,
                                 0,
                                 0,
                                 -0.42948024642038474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32324047869695577,
                                 0,
                                 0,
                                 0,
                                 -0.50329953751546497,
                                 -0.39004405774448109,
                                 0,
                                 0.55914295875634912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0048445780628399576,
                                 0,
                                 0,
                                 -0.12600500216672067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043083107834214505,
                                 0,
                                 0,
                                 0,
                                 -0.20227011775494091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31550918228611075,
                                 0,
                                 -0.1386139380731744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13630426576740662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65391354370462351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66002034638963458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16648937242071771,
                                 0,
                                 0,
                                 -0.58101163315940163,
                                 0,
                                 -0.20032151531987102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25684632031922516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1491540338528792,
                                 0,
                                 0,
                                 0.92568861653856782,
                                 -0.76192868638335554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60938829858045551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46653799590384781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14448645215989961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34293254450566418,
                                 0,
                                 0,
                                 -0.084108835137710447,
                                 -0.25710506239348241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44334742015346251,
                                 0,
                                 0,
                                 0,
                                 0.052677232074630292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26557502273826566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13304476079794847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41215274473464192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12391887535676416,
                                 0,
                                 0,
                                 0.12653367413081737,
                                 0.77749199166425564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17906964297427372,
                                 0,
                                 0,
                                 0,
                                 0.2719792665512808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.206489478167174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10269711400574411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43956527685666252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33880891402666063,
                                 0,
                                 0,
                                 -0.52956197121702397,
                                 0,
                                 0.49063653269994389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50285259404014548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73422048550679275,
                                 0,
                                 0,
                                 0.065485686559351441,
                                 0.28110965838794416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0619899530607084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19669773886370956,
                                 -0.102349940314171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13568221104745448,
                                 0,
                                 1.1841262883792609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1614870192994147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072617385275178359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12805449225428925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29394134523201576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68121206020678748,
                                 0,
                                 0,
                                 0.3755267062360868,
                                 0,
                                 -0.73539907641047586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21928000171639678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43064024754466135,
                                 0,
                                 0,
                                 -0.38989640844435391,
                                 -0.11583276589634994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42253128255816902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00130839894461365,
                                 0.14725257960282967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51893833193881733,
                                 0,
                                 -0.15975206619899449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86766581811312327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73494018791663662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2920704663809538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1081361593301068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2824126638473668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067575737164314864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52776978024867882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4801590527061797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33660008169467615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10507665568131754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49676930096369643,
                                 0,
                                 0,
                                 0.1181949901962652,
                                 -0.17621005694468747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034968703276170243,
                                 0,
                                 0,
                                 0,
                                 -0.59336664641143222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44170962135704245,
                                 0,
                                 0,
                                 0,
                                 -0.45348998479410974,
                                 -0.044157392644541826,
                                 0,
                                 -0.45553587984806032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3414649504003528,
                                 0,
                                 0,
                                 0.47333711294348818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11019016786309757,
                                 0,
                                 0,
                                 0,
                                 0.16034882818299487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080869998009241204,
                                 0,
                                 0.068823831083296705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0039988550716279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34687864450830108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42804847073846525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068346120571168109,
                                 0,
                                 0,
                                 0.42521345223830426,
                                 0,
                                 0.14341660290530722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61236742672703859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34995883536583244,
                                 0,
                                 0,
                                 0.67114251791345114,
                                 -0.0028008256206849278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30057922251190661,
                                 0,
                                 0,
                                 0,
                                 0.08260744173513182,
                                 0.14505285905887341,
                                 0,
                                 0.12750263360080161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26115132033237143,
                                 0,
                                 0,
                                 0.41826232062370733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33290637490894287,
                                 0,
                                 0,
                                 0,
                                 0.28854997822614586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63615041180486009,
                                 0,
                                 -0.15366332117371834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27200955692079964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19946648071325176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71682907139713514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13081849574973778,
                                 0,
                                 0,
                                 -0.49976698298081024,
                                 0.21462756124174268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18108087682254936,
                                 0,
                                 0,
                                 0,
                                 0.16323056182030679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20535700425741132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048878857819566801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21191499980218684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10707053292761926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89998136339822787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29849763388338174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39140890489188607,
                                 0,
                                 -0.98484032536044519,
                                 0,
                                 0,
                                 -0.14808915303589526,
                                 0,
                                 0,
                                 0.074324338409330115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.99478881502579808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50870040201017375,
                                 0,
                                 -0.043269928125895613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24111936032567061,
                                 0.0074609128531777438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44471242695418473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024063539167905976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026902779931900517,
                                 0,
                                 0,
                                 -0.91689151514381306,
                                 0,
                                 -0.9088463196654768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73006916285287526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11609280527564775,
                                 0,
                                 0,
                                 -0.56305020030128827,
                                 0.42426028556104056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4154612868880212,
                                 0,
                                 -0.063033958540542709,
                                 0,
                                 0,
                                 -0.18676125110541991,
                                 0,
                                 0,
                                 0.57887762881971971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25541826790612493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64365021384096521,
                                 0,
                                 -0.15826178211660313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41164080300378392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80262433753151396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043733254476396227,
                                 0.24698808307494952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13605505442976062,
                                 0,
                                 0.67642026718028125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55806637314759233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1646244012519944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42158987892092431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53047913869376151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69789134397537544,
                                 0,
                                 0,
                                 0.044370010002026408,
                                 0,
                                 0.2962264090950022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67906889992493058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73162243873298516,
                                 0,
                                 0,
                                 -0.49774058101386481,
                                 -0.53664201246691223,
                                 0,
                                 0,
                                 0,
                                 0.38685230960420675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029900178886995817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90542391334220607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12922889161900769,
                                 0,
                                 0,
                                 -0.11790601668546674,
                                 0,
                                 0.056371806836660585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67697565833004592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70567323116555736,
                                 0,
                                 0,
                                 -0.001699513132096769,
                                 0.65674854194316701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10469679557393322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15257973578052436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17409759221329971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012258164226985779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14612424211615549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62882801486358797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3634047775695371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64861372713168064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70200556841655359,
                                 0,
                                 -0.098244608825784979,
                                 0,
                                 0,
                                 0.23622084858590681,
                                 0,
                                 0,
                                 0.56765304747355905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02269448182911156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20433050328752098,
                                 0,
                                 -0.79205193744974633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0089553586122432804};

const double rot_30_20[4000] = {-0.2317690274719742,
                                0,
                                -0.31234248504873008,
                                -0.12074513432292905,
                                0.27850062060388903,
                                0.44613048510237113,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.079131203436895226,
                                0,
                                0,
                                0,
                                -0.29275660251833702,
                                0.68233622312298325,
                                0,
                                0,
                                0.62102514654240748,
                                0,
                                0,
                                0,
                                0,
                                0.01793548625825428,
                                0,
                                0,
                                0,
                                -0.26537453236342534,
                                0,
                                0.77693283649064848,
                                0,
                                0.30808960519733231,
                                0,
                                -0.76919625924389701,
                                0,
                                0,
                                0,
                                -0.032326076296853065,
                                0,
                                -0.10515237878979401,
                                -0.25879731036723891,
                                0.23697359104475774,
                                -0.49335629303536982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35654907158308269,
                                0,
                                0,
                                0,
                                0.61372135725789911,
                                0.34290508109576801,
                                0,
                                0.3866974159689418,
                                0,
                                0.43399408853094146,
                                0.27905734158243589,
                                0.095777938418120503,
                                -0.32286134662145161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40377631491502397,
                                0,
                                0,
                                0,
                                -0.14824975416997377,
                                0.53461675524101238,
                                0,
                                -0.21594295099181388,
                                0,
                                0.82271399329426842,
                                -0.36452236227362211,
                                0.076521512650862128,
                                0.30971859385580913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18903838904642845,
                                0,
                                0,
                                0,
                                0.076570315952089213,
                                0.015940497499629142,
                                0,
                                -0.022681504601924071,
                                0,
                                -0.090021949173577975,
                                -0.39803758603686784,
                                0.6429680392677426,
                                -0.040294024846051171,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58409467702190909,
                                0,
                                0,
                                0,
                                0.028199134719267931,
                                -0.27559823518226922,
                                0,
                                0,
                                0.21583381698019269,
                                0,
                                0,
                                0,
                                0,
                                0.80517457077288168,
                                0,
                                0,
                                0,
                                -0.17726383270213505,
                                0,
                                -0.58453265922424269,
                                0,
                                0.642882765963525,
                                0,
                                -0.98482540091057769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22395866306271944,
                                0.063373580114055944,
                                0.86830226689881085,
                                0,
                                0.17301764650120577,
                                0,
                                0,
                                0,
                                0.035214667276001144,
                                0,
                                0,
                                0,
                                -0.40087691513592649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34398976504384543,
                                0.38555288044868324,
                                -0.26782586285433896,
                                0,
                                -0.092563342234842527,
                                0,
                                0,
                                0,
                                -0.6857438348082705,
                                0,
                                0,
                                0,
                                -0.42717296942327188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.010630363025172436,
                                0.73038060878956901,
                                -0.18192926109284213,
                                0,
                                0.003176267836201993,
                                0,
                                0,
                                0,
                                0.62158751779123589,
                                0,
                                0,
                                0,
                                -0.21668358196482357,
                                0,
                                0.23188484113048516,
                                0,
                                0,
                                0,
                                0,
                                -0.4978073376033017,
                                0,
                                0,
                                0,
                                -0.73683198596945099,
                                0,
                                -0.65992442249595207,
                                0,
                                -0.14031483199614614,
                                0,
                                -0.035742455563093731,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.81683467731052128,
                                0.3720834695733734,
                                0.25574888276164681,
                                0,
                                -0.13907915849882707,
                                0,
                                0,
                                0,
                                -0.32398732422517795,
                                0,
                                0,
                                0,
                                0.067946390574437299,
                                0,
                                -0.51995390258606711,
                                0,
                                0,
                                0,
                                0,
                                -0.99704423670214015,
                                0,
                                0,
                                0,
                                -0.065399435693515834,
                                0,
                                -0.14732040458492124,
                                0,
                                1.0976236492783973,
                                0,
                                0.29949515428323248,
                                0,
                                0,
                                0,
                                -0.71627401317256678,
                                0,
                                0.12088624241931772,
                                0.5930873574552008,
                                0.28696863793275035,
                                -0.17773737820264177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.034612601840534385,
                                0,
                                0,
                                0,
                                0.035616316051374254,
                                -0.064632127704738807,
                                0,
                                0,
                                0.14283544512696056,
                                0,
                                0,
                                0,
                                0,
                                0.47276358373633581,
                                0,
                                0,
                                0,
                                -0.33106834742841001,
                                0,
                                0.52775344740921537,
                                0,
                                0.11196122037483597,
                                0,
                                1.3692401688036855,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31034332619107813,
                                -0.4102106593440108,
                                -0.16389673109360486,
                                0,
                                -0.36616829277823265,
                                0,
                                0,
                                0,
                                0.18499103244881732,
                                0,
                                0,
                                0,
                                -0.73501781996318716,
                                0,
                                -0.77228593126058376,
                                0,
                                0,
                                0,
                                0,
                                0.29593673139898796,
                                0,
                                0,
                                0,
                                -0.70469537417152062,
                                0,
                                0.58533041438736899,
                                0,
                                -0.37456177640556565,
                                0,
                                -0.34655419453417302,
                                0,
                                0,
                                0,
                                0.48394678186636547,
                                0,
                                0.034880128014134454,
                                0.41102081703440191,
                                0.54337025065815014,
                                0.34569878008814836,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35687919724962253,
                                0,
                                0,
                                0,
                                0.15928444916892021,
                                -0.16777247665801048,
                                0,
                                -0.036117763215380655,
                                0,
                                -0.047348784111869865,
                                0.16902770982458543,
                                -0.24544212781736463,
                                0.45241603780083683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4450986427919203,
                                0,
                                0,
                                0,
                                0.69452387685086026,
                                0.14994967968227957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26051618759276146,
                                -0.084605192844302415,
                                -0.22125233319883333,
                                0,
                                0.89892413585978692,
                                0,
                                0,
                                0,
                                -0.054358160492683293,
                                0,
                                0,
                                0,
                                -0.25495346782613226,
                                0.3909318768576967,
                                0,
                                0,
                                -0.63000846188952964,
                                0,
                                0,
                                0.15427347407234443,
                                0.034866083439096834,
                                0,
                                0,
                                -0.23424773144979294,
                                0,
                                0,
                                0,
                                0,
                                0.41202214630966422,
                                0.28044892320018355,
                                0,
                                0,
                                -0.34922744703736547,
                                0,
                                -0.15464400315686985,
                                -0.48199041438194384,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87922406039417988,
                                0,
                                1.3047905972060729,
                                0,
                                0,
                                -0.3632864393984736,
                                -0.087404482755416568,
                                0,
                                0,
                                0.50941478676527518,
                                1.0026742929930834,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15155826783609083,
                                0,
                                -0.061924484054836137,
                                0,
                                0,
                                -0.44065429265517869,
                                -0.58393771191968213,
                                0,
                                0.36250040576519854,
                                0,
                                0,
                                0.36669485415372111,
                                0,
                                0,
                                0.2878138383271478,
                                0.24513116824415196,
                                0,
                                0,
                                -0.333015693176132,
                                0,
                                0,
                                0,
                                0,
                                0.10048153410632173,
                                -0.63083958851859312,
                                0,
                                0,
                                -0.26878926232208744,
                                0,
                                0,
                                0,
                                0,
                                0.32988386134968783,
                                0.84166649627060819,
                                0,
                                0,
                                -0.10580988636779325,
                                0.17036145121536883,
                                0,
                                0.087731646654237716,
                                0,
                                -0.36723092072773822,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17196844565867075,
                                -0.38302750245653489,
                                0,
                                0,
                                -0.7424083615293271,
                                0.26453976582758898,
                                0,
                                -0.15292789023045356,
                                0,
                                -0.42329467688188205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.033892988915577349,
                                0,
                                0,
                                -0.070080912759206249,
                                0,
                                0,
                                -0.16013580990793203,
                                -0.11310556227071485,
                                0,
                                0,
                                -0.733327065272116,
                                0,
                                0,
                                0,
                                0,
                                0.067632765705039094,
                                -0.014188985666404419,
                                0,
                                0,
                                0.64261923575784197,
                                0.24918937051575921,
                                0,
                                0,
                                0.41823800001098765,
                                0,
                                0,
                                0.16849430316360728,
                                0.5712753121266847,
                                0,
                                0,
                                0.054795386848959682,
                                0,
                                0,
                                0,
                                0,
                                0.1309451968615126,
                                0.57633727131697077,
                                0,
                                0,
                                0.23647831024138169,
                                0,
                                0,
                                0,
                                0,
                                -0.4396112468392987,
                                0.049862571910811226,
                                0,
                                0,
                                -0.30699845367879908,
                                -0.0074274726190185041,
                                0,
                                0.84256763725891581,
                                0,
                                0.0056775265815902087,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23560348012597399,
                                0.32327283841819754,
                                0,
                                0,
                                -0.5440709935011464,
                                -0.54962655855829401,
                                0,
                                -0.34748603712650489,
                                0,
                                0.34804672998568831,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80592627405535344,
                                0,
                                0,
                                0.0336556598648559,
                                0,
                                0,
                                -0.21950604424885306,
                                -0.33194420642061084,
                                0,
                                0,
                                0.25378764244688318,
                                0,
                                0,
                                0,
                                0,
                                -0.31226557051680881,
                                -0.0027980636780404189,
                                0,
                                0,
                                0.17045379009880288,
                                0,
                                0,
                                0,
                                0,
                                0.65981339201764722,
                                -0.052659524556562254,
                                0,
                                0,
                                -0.20282943942237358,
                                0.13157771906355606,
                                0,
                                0.27021133953052168,
                                0,
                                0.65605382136407209,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35714340358124658,
                                -0.71534156496090806,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.89114476413664401,
                                0,
                                0.71677970523170598,
                                0,
                                0,
                                0.40070027580001061,
                                0.011858473183259055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42128699391015401,
                                -0.18741081013224797,
                                0,
                                0,
                                0.078949443641371991,
                                -0.76258669727419837,
                                0,
                                0.25541198327440529,
                                0,
                                -0.36658926647776202,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65116814248251509,
                                0.43594751576906254,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25646610179667673,
                                0,
                                -0.081060065241591039,
                                0,
                                0,
                                1.4586514596825946,
                                -0.091285044821797751,
                                0,
                                -0.0260647877935693,
                                0,
                                0,
                                0.49336703060168513,
                                0,
                                0,
                                0.09159386922504123,
                                -0.65446743904157167,
                                0,
                                0,
                                -0.052168422674446435,
                                0,
                                0,
                                0,
                                0,
                                0.49433710349219756,
                                0.22680617018637417,
                                0,
                                0,
                                -0.14373857957868935,
                                0.039127640728287616,
                                0,
                                0,
                                -0.16455577711742186,
                                0,
                                0,
                                0.074963626390826793,
                                0.071165633373435372,
                                0,
                                0,
                                0.47450113599730925,
                                0,
                                0,
                                0,
                                0,
                                0.60625535432039657,
                                -0.37005136101353586,
                                0,
                                0,
                                0.48069890659367742,
                                0,
                                -0.87653594491448272,
                                -0.31991276696682835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.03170557329764695,
                                0,
                                -0.036686694182167134,
                                0,
                                0,
                                -0.49664047005936712,
                                -0.9223294178185073,
                                0,
                                0,
                                -1.0012653628677854,
                                0.56478219821891373,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1537331826588075,
                                0,
                                0.51154570108905173,
                                0,
                                0,
                                -0.27058795066234231,
                                0.7961633185572381,
                                0,
                                0.028180520869620328,
                                0,
                                0,
                                0.13102491667631161,
                                0,
                                0,
                                -0.88155385327756808,
                                0.23657468969349818,
                                0,
                                0,
                                -0.034298534701659944,
                                0,
                                0,
                                0,
                                0,
                                0.29832174512531157,
                                -0.051351335204544421,
                                0,
                                0,
                                -0.23690575488323928,
                                -0.8175335079537418,
                                -0.11216812044928548,
                                0,
                                0,
                                0,
                                0,
                                0.11530029046231122,
                                -0.3081565040906139,
                                0,
                                0,
                                0.11702666182054001,
                                0,
                                1.2039831115928461,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26032909575627716,
                                -0.25544962308723723,
                                0,
                                0,
                                0,
                                0,
                                1.1784145489630142,
                                0.25266692005086905,
                                0,
                                0,
                                -0.020275180162573427,
                                0,
                                0.42668903960658366,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.094648046019843918,
                                0,
                                0,
                                0.36340503377949285,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58731534702415122,
                                0,
                                0.67677975311365957,
                                0.048106090824888925,
                                -0.030767557924690402,
                                -0.21984555865517469,
                                0,
                                0.066448999075663928,
                                0,
                                0,
                                0,
                                0,
                                0.63934934283263334,
                                0.39722927125747953,
                                0,
                                0,
                                0,
                                0.18777852860975125,
                                -0.40127208823039273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2018695646222427,
                                0,
                                0.44318160854816091,
                                0,
                                0,
                                0,
                                -0.5836743270425353,
                                -0.20780943371617369,
                                0,
                                0,
                                0,
                                -0.028430201789123775,
                                -0.59840125047583437,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.018311277221485359,
                                0,
                                0.50686475848268586,
                                0,
                                0,
                                -0.316002810170605,
                                0,
                                0,
                                -0.47799460498358337,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32768900074719498,
                                0,
                                -0.037584463590753299,
                                -0.25241027429498647,
                                -0.44278802278989116,
                                0.0066733923007935431,
                                0,
                                0.55050340107588602,
                                0,
                                0.3581261553886938,
                                -0.54501409359979291,
                                0,
                                0,
                                0,
                                0,
                                -1.0042456887788971,
                                -0.20886091822286929,
                                0,
                                0,
                                -1.0013405536120967,
                                0,
                                0.33415088515655228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56599652873613981,
                                -0.18554535228692398,
                                0,
                                0,
                                0,
                                0,
                                -0.42716042402380483,
                                0.40784099701893256,
                                0,
                                0,
                                0.54970337521070856,
                                0,
                                1.0714537486602316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41131832469049645,
                                -0.68604582699432237,
                                0,
                                0,
                                0,
                                0.26322001523236421,
                                -0.15921175957736558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51529106668975122,
                                0,
                                0.00056108873762139577,
                                0,
                                0,
                                0,
                                -0.25309507067968451,
                                0.074216715018419366,
                                0,
                                0,
                                0,
                                0.94315353034022409,
                                0.14734220173028395,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13538589174323101,
                                0,
                                -0.029276586591592629,
                                -0.39628042912063904,
                                -0.67663206322634406,
                                0,
                                0,
                                0,
                                0,
                                0.37800905200300516,
                                1.0623953542795312,
                                0,
                                0,
                                0.22761397532514266,
                                0,
                                -0.44370483740637046,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.089811991949361417,
                                0,
                                0,
                                0.47916985670850931,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24231827392060212,
                                0,
                                -0.39943716697853332,
                                0.13072488397172405,
                                -0.64218386188292642,
                                0.20915180829274396,
                                0,
                                -0.26613581423762311,
                                0,
                                0.4356198702467407,
                                -1.2763374875357061,
                                0,
                                0,
                                0,
                                0,
                                -0.19740778262374159,
                                -0.29469632264528078,
                                0,
                                0,
                                0.67075339599236949,
                                0,
                                0.18104790561727713,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18631659147021123,
                                0,
                                0,
                                -0.32888835200043331,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39603407034025268,
                                0,
                                0.43887818556706187,
                                0.07937075856564707,
                                -0.59031050045978328,
                                -0.17594755405018347,
                                0,
                                -0.34919591489570528,
                                0,
                                0,
                                0,
                                -0.69035557516962431,
                                0,
                                0,
                                0.27590713859680388,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32821686310399339,
                                0,
                                0.034821882536726217,
                                0.22921663421302779,
                                -0.020902014798811763,
                                -0.51670635270366261,
                                0,
                                0.13558371372474431,
                                0,
                                0,
                                0,
                                -0.1209384573011941,
                                0,
                                0,
                                0.16706692468036466,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.039657383737408153,
                                0,
                                -0.010783194802229876,
                                -0.9048475816558883,
                                0.008832378571979542,
                                -0.20699506467076992,
                                0,
                                -0.30675630899886919,
                                0,
                                0,
                                0,
                                0.19460885431228234,
                                0,
                                0,
                                0.43758363292737301,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47198597585296315,
                                0,
                                0.21380654926122705,
                                -0.19823403194608913,
                                -0.16801799262130157,
                                0.35285285669981525,
                                0,
                                0.55689499940398091,
                                0,
                                0,
                                0,
                                0,
                                0.11509165663469982,
                                -0.52487251470647822,
                                0,
                                0,
                                0,
                                -0.067294562301461497,
                                0.3840516395574286,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63805866782006293,
                                0,
                                0.39002521756467168,
                                0,
                                0,
                                0.56507908154080666,
                                0,
                                0,
                                0.078556330833040255,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0070492893600585735,
                                0,
                                -0.37596592989391742,
                                4.4733760414542023e-05,
                                -0.11567443044528321,
                                -0.66526973873972961,
                                0,
                                0.27775899702222134,
                                0,
                                0,
                                0,
                                0,
                                -0.063802267322196612,
                                0.21763729252144223,
                                0,
                                0,
                                0,
                                -0.024063073201225915,
                                0.53511016061272831,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51762949040028505,
                                0,
                                0.62745603413590434,
                                0.2776414798381267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57469654041422336,
                                -0.2778548944172532,
                                -0.61394755254519173,
                                -0.043485042358704123,
                                -0.35489990168586294,
                                0,
                                0,
                                0,
                                0.10084184281823287,
                                0,
                                0,
                                -0.022140214380511548,
                                0,
                                0,
                                0,
                                0.20162902435977181,
                                -0.73814124215708776,
                                0,
                                -0.55215457109575206,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.054512044979998328,
                                0,
                                0,
                                0,
                                0.061468547860050599,
                                0,
                                0,
                                0.49222330719701191,
                                0,
                                -0.063696776568885227,
                                -0.66423229884810475,
                                0,
                                0.45181915713410703,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3893581472615615,
                                0,
                                0,
                                0,
                                -0.32042429659992983,
                                0,
                                0,
                                -0.46214508404108645,
                                0,
                                0,
                                0,
                                0.62837902900934373,
                                0,
                                -0.15298987239572787,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.044896039723553605,
                                0,
                                0.2693266276523314,
                                0,
                                -0.71124725143134282,
                                0,
                                0,
                                -0.036176724997396957,
                                0,
                                0,
                                0.54885228637697292,
                                -0.060319964040607382,
                                0,
                                0.89708074867777188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66968110024333583,
                                0,
                                0,
                                0,
                                0.47311849790122595,
                                0,
                                0,
                                0.24625803669753452,
                                0,
                                0,
                                0,
                                -0.27354713423274984,
                                0,
                                0.6053478487380477,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44854881506712929,
                                0,
                                -0.17790847556205933,
                                0,
                                -0.44968191465989948,
                                0,
                                0,
                                -0.3516598609937342,
                                0,
                                -0.32619917353708022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36708451954275906,
                                -0.035559129223980523,
                                0.013433703544522585,
                                -0.41994519262725266,
                                -0.72987270530500359,
                                0,
                                0,
                                0,
                                0.21812784424523904,
                                0,
                                0,
                                -0.027390718110635898,
                                0,
                                0,
                                0.30177365559747954,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.085104775857946652,
                                0.47318435069925929,
                                -0.035237285419628672,
                                0.25035480912834568,
                                -0.29070894929120417,
                                0,
                                0,
                                0,
                                -0.012021717015280712,
                                0,
                                0,
                                0.72746889730860886,
                                0,
                                0,
                                0.2415738532714303,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25600848856397684,
                                0.41331973393032545,
                                -0.42443040449777492,
                                -0.41658085699734165,
                                0.37060312527976375,
                                0,
                                0,
                                0,
                                0.44684277546093604,
                                0,
                                0,
                                -0.12071703945596798,
                                0,
                                0,
                                -0.32013060602498916,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60134258103831173,
                                0.18733121092794916,
                                0.28512046318746298,
                                -0.52319656693902294,
                                0.15261460946207236,
                                0,
                                0,
                                0,
                                0.092022970981009783,
                                0,
                                0,
                                0.33767253417190068,
                                0,
                                0,
                                -0.089105848488269634,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0023285599932653667,
                                -0.36290845959474188,
                                0.16217130379500505,
                                0.32927473780292038,
                                0.10735641325846654,
                                0,
                                0,
                                0,
                                0.81491441688397404,
                                0,
                                0,
                                0.22365125639104433,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.076070328817212443,
                                0,
                                -0.1023205047058473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60132395205323919,
                                0,
                                -0.15320052133263687,
                                0,
                                -0.025919293691239298,
                                0,
                                0,
                                -0.77331178353585894,
                                0,
                                0,
                                -0.32068611563180172,
                                -0.14195132309408109,
                                0,
                                0.04512790876316361,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50434093126464263,
                                0,
                                0,
                                0,
                                1.2165058314645081,
                                0,
                                0,
                                -0.27525264006366434,
                                0,
                                0,
                                0,
                                -0.012953137320031989,
                                0,
                                0.094685416297138836,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38811235065436972,
                                0,
                                -0.73793638977493203,
                                0,
                                -0.30948650807796863,
                                0,
                                0,
                                0.44710589059795547,
                                0,
                                -0.62765768264911892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17085944249717297,
                                0.47429545631799114,
                                -0.31666961504411067,
                                0.44069443471568193,
                                -0.051871457085984896,
                                0,
                                0,
                                0,
                                0.093684848633785761,
                                0,
                                0,
                                -0.21433146206727396,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.158724516930253,
                                0,
                                0.58918540261035524,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53299411336968405,
                                0,
                                0.52871297401893591,
                                0,
                                -0.045774753191313161,
                                0,
                                0,
                                0.24890083821418124,
                                0,
                                0,
                                1.0724556210258833,
                                0.68966459050521767,
                                0,
                                -0.70936507906014723,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68285006266269621,
                                0,
                                0,
                                0,
                                -0.5995051199062118,
                                0,
                                0,
                                0.51500199879275699,
                                0.40336883657856426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26716736665512963,
                                0.36748314418112171,
                                0.48335519899134916,
                                0.095759386008142711,
                                -0.28629749845185265,
                                0,
                                0,
                                0,
                                0.24719950190739576,
                                0,
                                0,
                                -0.49497005853979753,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70651525835383888,
                                0,
                                -0.4935319934723672,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.021997481421587459,
                                0,
                                0.21966751688405456,
                                0,
                                -0.43973228953727578,
                                0,
                                0,
                                0.12312663200057924,
                                0,
                                0,
                                0.72664787117182339,
                                -0.096873191504203718,
                                0,
                                -0.27105484889746628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7251574550365627,
                                0,
                                0,
                                0,
                                -0.0080926424063191282,
                                0,
                                0,
                                -0.72245468007024294,
                                -0.38873003266899131,
                                0,
                                0,
                                0,
                                0.92144787015092999,
                                0,
                                0.71265646659624926,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.96969750526994003,
                                -0.85541559849065563,
                                0.4776302698446786,
                                0,
                                0,
                                0,
                                -0.51543377776015475,
                                0,
                                0,
                                0,
                                0.22589614145880177,
                                0,
                                0.079751236843963513,
                                0,
                                -0.087064200648580781,
                                0.49151359742986345,
                                -0.20317453540689143,
                                0.61415005760069452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.096502423068098503,
                                0,
                                0,
                                -0.15383121327598545,
                                0.017464157558547883,
                                0,
                                0,
                                0,
                                0,
                                -0.96247517477903721,
                                0,
                                0,
                                0,
                                0,
                                0.14595145570650322,
                                0.04477422552714292,
                                0,
                                0,
                                0,
                                0.16237592266856438,
                                0,
                                0,
                                0,
                                0.59013628866405132,
                                0.08387839833176336,
                                0,
                                0,
                                0,
                                0,
                                -0.24435605378291475,
                                0,
                                0,
                                0,
                                0,
                                -0.67870111453689252,
                                0.13537285820069436,
                                0,
                                0,
                                0,
                                -0.32562659667741101,
                                0,
                                -0.94337447934990626,
                                0,
                                0,
                                0,
                                -0.57568084030240385,
                                0,
                                -0.60535407353882864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31669232529894353,
                                -0.0072459975768485174,
                                -0.58775591210954337,
                                0,
                                0,
                                0,
                                0.0648089804822293,
                                0,
                                0,
                                0,
                                -0.21863857872110792,
                                0,
                                -0.089658768788900861,
                                0,
                                0.45816812698820669,
                                0.72440772669271003,
                                -0.091220051291342807,
                                -0.42071926740646409,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14123698636801482,
                                0.3341446463532553,
                                0,
                                0,
                                0,
                                -0.49590459610324167,
                                0,
                                -0.20650458681294814,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50227715702924014,
                                -1.1355454824932136,
                                -1.0296110920582371,
                                0,
                                0,
                                0,
                                -0.59590820474510309,
                                0,
                                0,
                                0,
                                -0.24509657421251185,
                                0,
                                -0.031972590403191108,
                                0,
                                -0.49874870781272135,
                                -0.060219354375841319,
                                -0.061514168149115561,
                                -0.49409017875641925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2889863188400778,
                                0,
                                0,
                                -0.22090405291806478,
                                0.35731937984923101,
                                0,
                                0,
                                0,
                                0,
                                0.016006903642849464,
                                0,
                                0,
                                0,
                                0,
                                0.24869964779867704,
                                0.66857887283125672,
                                0,
                                0,
                                0,
                                -0.56073060841441769,
                                0,
                                0,
                                0.1847353176905577,
                                0,
                                0,
                                0,
                                -0.53960207190773979,
                                0,
                                0.25601728118317896,
                                0,
                                -0.44959432502774543,
                                0.32727113098547056,
                                0.14796312443188708,
                                0.12409056025564222,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5124691351841083,
                                0,
                                0.22475087495595142,
                                0,
                                0,
                                0,
                                0.38776904029966125,
                                0,
                                0.76615995192696129,
                                0,
                                -0.16277269001236644,
                                0.083269979268417213,
                                -0.31654425184443985,
                                -0.26307259358365792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.096357940633232414,
                                0,
                                -0.099375839559765158,
                                0,
                                0,
                                0,
                                -0.020647499437303336,
                                0,
                                -0.23233935224151653,
                                0,
                                0.064246143342046827,
                                -0.12936022954460613,
                                -0.79163417502125299,
                                -0.11241023651401065,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52491350184758567,
                                0,
                                0.051037897512415997,
                                0,
                                0,
                                0,
                                -0.62966545627062542,
                                0,
                                0.29655196923035887,
                                0,
                                0.24664510011035073,
                                -0.26243673524715982,
                                -0.33682511583246488,
                                0.30322675666334253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42174519050589987,
                                0,
                                0,
                                0.65584417939973227,
                                -0.15839585563746866,
                                0,
                                0,
                                0,
                                0,
                                0.044208402625350508,
                                0,
                                0,
                                0,
                                0,
                                0.44393638559809978,
                                0.45129004271196949,
                                0,
                                0,
                                0,
                                0.37693841047683541,
                                0,
                                0,
                                0,
                                -0.33532386688935234,
                                0.11394688157101318,
                                0,
                                0,
                                0,
                                0,
                                0.10420177097178626,
                                0,
                                0,
                                0,
                                0,
                                -0.49874670285812511,
                                0.51055409089885928,
                                0,
                                0,
                                0,
                                0.5952329376433616,
                                0,
                                0.56216342193657332,
                                0,
                                0,
                                0,
                                -0.15612346183378401,
                                0,
                                1.1301404400528956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37300665675491995,
                                0.63708841877301237,
                                -0.70837036849783563,
                                0,
                                0,
                                0.36329333391008628,
                                0,
                                0,
                                0,
                                -0.00051595158999884205,
                                0,
                                -0.50129319466543776,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1924512006143999,
                                0.39338249333931496,
                                0.12023426565195154,
                                0,
                                0,
                                -0.0066433005908473411,
                                0,
                                0,
                                0,
                                -1.1066004030223946,
                                0,
                                0.6846256576511357,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.034293602123018199,
                                -0.084040347812165739,
                                1.0021039678437313,
                                0,
                                0,
                                0,
                                0,
                                -0.19157983889254682,
                                -0.90934544556804431,
                                0,
                                0,
                                0,
                                0,
                                -0.029377610745773334,
                                0,
                                0,
                                0,
                                0,
                                -0.10190027879545227,
                                0.26142602473773047,
                                0,
                                0,
                                0,
                                -0.23832278261355416,
                                0,
                                0,
                                -0.52716288796142008,
                                0,
                                0,
                                0,
                                -0.051532939005798348,
                                0,
                                0.43601402914179749,
                                0,
                                0.4900613642993038,
                                -0.17428157329195318,
                                0.2904924133897232,
                                -0.11181107355438594,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40238494774376055,
                                0.29157481582627931,
                                0,
                                0,
                                -0.41313989598796269,
                                0.077002835729675048,
                                0.060159841508044209,
                                0,
                                0.44188845658747233,
                                0.1573859266941405,
                                0,
                                0,
                                0,
                                -0.46078830341707699,
                                0,
                                0,
                                -0.54989936472560341,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2814841875917342,
                                -0.19976532093129595,
                                0,
                                0,
                                0,
                                0.13566357289730285,
                                0,
                                0,
                                0.1623015402374634,
                                0,
                                1.0982293721099818,
                                0,
                                0.3378269890770686,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.074522598915214511,
                                -0.20784818897734067,
                                0,
                                0,
                                0,
                                1.0151980630211506,
                                0,
                                0,
                                1.1134748503594016,
                                0,
                                -0.35792335039368511,
                                0,
                                0.89358798080455137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63351447315378562,
                                0,
                                0,
                                0.14874528598350611,
                                -0.11187150031171714,
                                -0.35878048398924622,
                                0,
                                0.32921780907129483,
                                0.089487530931854103,
                                0,
                                0,
                                0,
                                0.564549952305614,
                                0,
                                0,
                                -0.013658377596190166,
                                0,
                                0,
                                0,
                                0,
                                -0.12894994172509675,
                                0,
                                0,
                                -0.34142168587760763,
                                0.15473548299075429,
                                -0.15008631518548066,
                                0,
                                0.22725937147345784,
                                -0.85932525813354366,
                                0,
                                0,
                                0,
                                0.17325921618990203,
                                0,
                                0,
                                -0.015122700014104401,
                                0,
                                0,
                                0,
                                0,
                                -0.17902760048832603,
                                0,
                                0,
                                -0.57681568607436118,
                                0.36886651421924244,
                                0.035482625352127525,
                                0,
                                0.20851892585128551,
                                0.41818932794634628,
                                0,
                                0,
                                0,
                                0.27160795074270255,
                                0,
                                0,
                                0.4536275181189755,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.98207727325103156,
                                -0.45618913860958477,
                                0,
                                0,
                                0,
                                -0.30384033471568755,
                                0,
                                0,
                                -0.37661304804035833,
                                0,
                                -1.1516642264556569,
                                0,
                                0.00058211475479419406,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17152691425259106,
                                0,
                                0,
                                -0.44534880218756845,
                                -0.12520564023467029,
                                0.25698773701008409,
                                0,
                                -0.60926986931375038,
                                0.011663925632216465,
                                0,
                                0,
                                0,
                                0.40734368589987502,
                                0,
                                0,
                                -0.39147045035315298,
                                0,
                                0,
                                0,
                                0,
                                -0.44954094622061092,
                                0,
                                0,
                                0.33428169816885278,
                                0.35646513461471085,
                                0.16219427452687266,
                                0,
                                0.24604476578194684,
                                0.12830866858624795,
                                0,
                                0,
                                0,
                                0.41336170654226601,
                                0,
                                0,
                                -0.53378391453531093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41242133863920316,
                                -1.5231218710728482,
                                0,
                                0,
                                0,
                                -0.61944420203766237,
                                0,
                                0,
                                0.65774823132305582,
                                0,
                                0.042003732977675623,
                                0,
                                -0.16933735493590635,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41264976282430743,
                                0,
                                0,
                                0,
                                0.045195759135593497,
                                0,
                                -0.23747898883767599,
                                -0.42642467358543823,
                                -0.49440508568472169,
                                0.58737284195345019,
                                0,
                                0.070594813602888523,
                                -0.23561300948933983,
                                0,
                                0,
                                0,
                                1.1419412254220358,
                                0,
                                0,
                                -0.18803898912576422,
                                0,
                                0.18469417529433152,
                                0,
                                -0.78737381719544741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47206843500069828,
                                0,
                                0,
                                -0.21188563300401944,
                                -0.74597931619042857,
                                -0.30044829585856214,
                                0,
                                0.19679302040158367,
                                0.14857081223884849,
                                0,
                                0,
                                0,
                                0.10567430171461099,
                                0,
                                0,
                                -0.11633449773503737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32041584236723364,
                                -0.98722371054630831,
                                0,
                                0,
                                0,
                                0.22627202023965653,
                                0,
                                0,
                                -0.81084707041131376,
                                0,
                                -0.0075185039963495126,
                                0,
                                0.28434408545650686,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10345438062507341,
                                0,
                                0,
                                0,
                                -0.33201193528154183,
                                0,
                                0.31639576448485085,
                                0.67989482221446274,
                                -0.44346747761834393,
                                0.34646589038016717,
                                -0.10299231965099399,
                                0,
                                0,
                                -0.054127923826140983,
                                0.34974386481046388,
                                -0.813175000183329,
                                0,
                                -0.36159088548148971,
                                0.12339769352385747,
                                0,
                                0,
                                0,
                                -0.13116409174560764,
                                0,
                                0,
                                -0.19927222552507404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47472777199533439,
                                0,
                                0,
                                0,
                                -0.24050842142245255,
                                0,
                                0.50916739421604174,
                                -0.21938345574916765,
                                -0.33138517661243916,
                                -0.54735050055112533,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47964583407089095,
                                0,
                                0,
                                0,
                                -0.73057558396014766,
                                0,
                                0.037965181982353845,
                                -0.47145281778242265,
                                0.043553090050928542,
                                0.10292329128435784,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49922823051688192,
                                0,
                                0,
                                0,
                                0.54127343148870166,
                                0,
                                0.54675242695022619,
                                -0.28699462514161195,
                                -0.25495865218843394,
                                0.10717369386910391,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33817444400825758,
                                0,
                                0,
                                0,
                                0.056245052203527102,
                                0,
                                -0.53279118172602213,
                                0.056055807655494838,
                                -0.61820974295680797,
                                -0.46182524437137928,
                                -0.77137839802807751,
                                0,
                                0,
                                0,
                                0,
                                -0.79791800042464955,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3364918270701836,
                                -0.55793235752518888,
                                0,
                                0,
                                -0.1743440841319657,
                                -0.33823824772361161,
                                0,
                                0,
                                0,
                                0.19690832456900823,
                                0,
                                0,
                                0.053276403531155279,
                                0,
                                0,
                                0,
                                0,
                                0.378425905464505,
                                0,
                                0,
                                0,
                                0,
                                0.49511743574994077,
                                0,
                                0,
                                0,
                                0.74737147348068689,
                                -0.10713158292161397,
                                0,
                                0,
                                0.55779630134824643,
                                0.095011267146127718,
                                0,
                                0,
                                -0.73656814048476849,
                                0.1749578483630119,
                                0.042185815693716787,
                                0,
                                0.061100987334072425,
                                -0.30177176510161596,
                                0,
                                0,
                                0,
                                0.10056887751691296,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52209133941085417,
                                -0.52566770337683633,
                                0,
                                0,
                                -0.50647315336478493,
                                0.055750023694724385,
                                0.13006424490967061,
                                0,
                                -0.28510670838166308,
                                -0.0033280352293652143,
                                0,
                                0,
                                0,
                                -0.30538068034968124,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34618254069377474,
                                0,
                                0,
                                0.086863639751957988,
                                0,
                                0,
                                0,
                                0,
                                0.49684998705543049,
                                0,
                                0,
                                0,
                                0,
                                -0.45345154728514275,
                                0,
                                0,
                                0,
                                0.041115914772924547,
                                -0.64687218427442061,
                                -0.44768579819488857,
                                0,
                                0,
                                0,
                                0,
                                -0.3658324068799732,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.042287553276221468,
                                0.74240309217514322,
                                0,
                                0,
                                0.67555660450916954,
                                0.22704849535618388,
                                0,
                                0,
                                0,
                                0,
                                0.36124245263290433,
                                -0.44030070834467044,
                                0,
                                0,
                                0.16082800796462371,
                                0.50587253717734393,
                                0.31847841725555409,
                                0,
                                0.21867062997678166,
                                0.48269334968367894,
                                0,
                                0,
                                0,
                                -0.10783454052360075,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23963055935476302,
                                0.10682236776241379,
                                0,
                                0,
                                0.24092363837514308,
                                0.7298849765333717,
                                0.010909720530762371,
                                0,
                                0.00050097514955915745,
                                -0.58255559911662469,
                                0,
                                0,
                                0,
                                -0.029993319783396824,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26246909184932654,
                                -0.31294032909347613,
                                0,
                                0,
                                0.14936144125576023,
                                0.11297246453111945,
                                -0.38525639279461094,
                                0,
                                -0.71700293353573619,
                                0.011184295508102626,
                                0,
                                0,
                                0,
                                0.368056958934951,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66929196973282701,
                                0,
                                0,
                                0.48781425277655555,
                                0,
                                0,
                                0,
                                0,
                                0.23101547132383093,
                                0,
                                0,
                                0,
                                0,
                                0.33409867258264236,
                                0,
                                0,
                                0,
                                -0.14547192028867933,
                                0.35767773684459969,
                                0,
                                0,
                                -0.067643476694839555,
                                -0.20951792441880401,
                                0,
                                0,
                                -0.10907332187957974,
                                0.12186080172769775,
                                -0.83407818931565469,
                                0,
                                0.45876020342684276,
                                0.08715961584884932,
                                0,
                                0,
                                0,
                                -0.10504954111784007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27217137461817542,
                                0.28435305820349233,
                                0,
                                0,
                                0.075381844742192006,
                                0.042999966599324438,
                                -0.1705135594963306,
                                0,
                                -0.33616826112564147,
                                0.064559998009784875,
                                0,
                                0,
                                0,
                                -0.83143411908648901,
                                0,
                                0,
                                0,
                                0,
                                0.61100143479276536,
                                0,
                                0,
                                0,
                                0,
                                -1.1844286521417811,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41412468333118857,
                                -0.64950693776053614,
                                0,
                                0,
                                -0.5139056320236115,
                                0.52216589257468871,
                                0,
                                0,
                                -0.90342619818935865,
                                0,
                                0,
                                0,
                                0,
                                0.25724081133716109,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69413051372925461,
                                0.011384815128349671,
                                0,
                                0,
                                0.018418992204549692,
                                0.95430445429572663,
                                0,
                                0,
                                0,
                                -0.62273858852122455,
                                0,
                                0,
                                -0.51389790556988479,
                                0,
                                0,
                                0,
                                0,
                                -0.45117520547265422,
                                0,
                                0,
                                0,
                                0,
                                0.10820771183275471,
                                0,
                                0,
                                0,
                                0.33787981851862525,
                                -0.13665594140733364,
                                0,
                                0,
                                0.28429225046835443,
                                -0.53542928644504217,
                                0,
                                0,
                                0.27776648371100421,
                                -0.38494253265567302,
                                0.081069950273607985,
                                0,
                                0.17204798184432399,
                                -0.56979728819469844,
                                0,
                                0,
                                0,
                                -0.21521298309337669,
                                0,
                                0,
                                0,
                                0,
                                -0.54055111091564512,
                                0,
                                0,
                                0,
                                0,
                                0.15123781019148719,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55446395207497379,
                                -0.84212117546008725,
                                0,
                                0,
                                0.57970003476559784,
                                0.4440400944957611,
                                0,
                                0,
                                0.3158754197391419,
                                0,
                                0,
                                0,
                                0,
                                0.12899497481253602,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87235105007767699,
                                -0.051288884269291124,
                                0,
                                0,
                                0.87748734146814145,
                                0.20097485957093886,
                                0,
                                0,
                                0,
                                -0.019661803947070327,
                                0,
                                0,
                                -0.67564798198583298,
                                0,
                                0,
                                0,
                                0,
                                0.53779029514331744,
                                0,
                                0,
                                0,
                                0,
                                0.29191618488622889,
                                0,
                                0,
                                0,
                                -0.39759178346729779,
                                0.10295888050306289,
                                0,
                                -0.072409138356437933,
                                0,
                                0,
                                -0.17624509863606444,
                                0,
                                0,
                                0,
                                0,
                                0.25256347491628195,
                                0,
                                0,
                                0,
                                0,
                                -0.58369043864108128,
                                0,
                                0,
                                0,
                                0.38254579404867506,
                                0.64254996717928925,
                                -0.34608458732007857,
                                -0.37778334369970989,
                                0.67704245423860576,
                                -0.36038545110780756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.89642247114676255,
                                0,
                                0,
                                -0.080958793547005664,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0310877787510528,
                                0.19936437223965725,
                                0.44205443921368071,
                                0.43691980006909781,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66326545932101988,
                                0,
                                0,
                                0.81413357937629538,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11621569428595752,
                                -0.62309039546604372,
                                0.354361080706669,
                                -0.61941399804585506,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0960932622210211,
                                0,
                                0,
                                0.2063280003856848,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77138033994660815,
                                -0.49561675617952067,
                                -0.80386567154306232,
                                -0.59926428849973412,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49012353232223199,
                                0,
                                0,
                                0.47347652455709849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18837125572696473,
                                0,
                                -0.19817036397662635,
                                0.020780479958827716,
                                0,
                                0,
                                -0.23314526365937913,
                                0,
                                0,
                                0,
                                -0.909866995933306,
                                0,
                                0,
                                0,
                                -0.20639351795635155,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.012519904029378026,
                                0,
                                0,
                                0.57866082955306364,
                                0,
                                0,
                                0.44687838287323645,
                                0,
                                0.23551983253769632,
                                0,
                                0.0022872321383619783,
                                0.18574590446862602,
                                0.10550559031503963,
                                0,
                                0.60347892564746919,
                                0,
                                0,
                                0,
                                0,
                                -0.62910149817705618,
                                0,
                                0.092480802487039451,
                                0.64174754397317935,
                                0,
                                0,
                                0.41003111386231006,
                                0,
                                0,
                                0,
                                -0.0086750735752370856,
                                0,
                                0,
                                0,
                                0.12505168823501284,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11284459907022693,
                                0,
                                0.38977752764303836,
                                -0.31328507876224215,
                                0,
                                0,
                                0.45153167732045646,
                                0,
                                0,
                                0,
                                -0.018786106097513855,
                                0,
                                0,
                                0,
                                -0.73003990399427054,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18308320114186583,
                                0,
                                0,
                                -0.15199708390608974,
                                0,
                                0,
                                -0.36270583502080167,
                                0,
                                0.4306556407969887,
                                0,
                                -0.031405890538204966,
                                0.36630298649778609,
                                0.70081377473823614,
                                0,
                                0.0073122838251515887,
                                0.70036487791752844,
                                0.91707574097512445,
                                0.13864558308017827,
                                -0.17337903954189915,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.038509706079587785,
                                0,
                                0,
                                0.88668525869004466,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24411925755871391,
                                0,
                                -0.19770797726011224,
                                0.28460988969057377,
                                0,
                                0,
                                -0.59430957735057632,
                                0,
                                0,
                                0,
                                0.38108519157107512,
                                0,
                                0,
                                0,
                                -0.56734888520347959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.012778999399706024,
                                0,
                                0,
                                -0.14193867333266938,
                                0,
                                0,
                                -0.070192954420301101,
                                0,
                                0.087911609771789023,
                                0,
                                -0.5671617047712314,
                                -0.69925051853849851,
                                0.21211287167856357,
                                0,
                                0.33379492332402372,
                                0.55056554072130481,
                                -0.66673562751032434,
                                -0.064024633832598044,
                                0.56117608359207072,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.8506439160764373,
                                0,
                                0,
                                1.0891935684655913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0071379279472633672,
                                0,
                                0,
                                -0.22521366091783263,
                                0,
                                0,
                                0.45265547724467381,
                                0,
                                -0.49352695909602651,
                                0,
                                -0.51794484302518728,
                                0.39402943841880828,
                                0.26236013115257473,
                                0,
                                -0.091668529556267253,
                                0,
                                0,
                                0,
                                0,
                                -0.69573927792058066,
                                0,
                                -0.16087332836861568,
                                -0.6387585313894002,
                                0,
                                0,
                                -0.098983555434248929,
                                0,
                                0,
                                0,
                                0.13745256588670937,
                                0,
                                0,
                                0,
                                0.23100479614104175,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62028125491206343,
                                0,
                                0,
                                0.56941160607731922,
                                0,
                                0,
                                -0.13528903695934091,
                                0,
                                -0.32744039066682495,
                                0,
                                -0.050227276657243761,
                                -0.18098188996295445,
                                0.18820688595948565,
                                0,
                                -0.30789965730770347,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10763999032017876,
                                0,
                                0,
                                -0.17686123309661034,
                                0,
                                0,
                                0.65215090147501531,
                                0,
                                0.28753940578400844,
                                0,
                                0.32404166035984522,
                                -0.34415373989039805,
                                0.29265545797568204,
                                0,
                                -0.37424860337194799,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44112502619320015,
                                0,
                                0,
                                -0.41151245005176157,
                                0,
                                0,
                                0.0067218208014517833,
                                0,
                                -0.38177028244636535,
                                0,
                                0.44985465294915739,
                                -0.047093763664206513,
                                0.072836815887352926,
                                0,
                                0.52950944295612334,
                                0,
                                0,
                                0,
                                0,
                                -0.11120394199596317,
                                0,
                                0.85748505229218053,
                                0.023779616262351498,
                                0,
                                0,
                                -0.45895021309198819,
                                0,
                                0,
                                0,
                                -0.087147827992758609,
                                0,
                                0,
                                0,
                                0.18318721628272427,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61252187648796719,
                                0,
                                0,
                                0.2152412165872172,
                                0,
                                0,
                                -0.12357609615804767,
                                0,
                                -0.41487847517805859,
                                0,
                                0.31491934377563496,
                                -0.18356478771203183,
                                0.50747380626507654,
                                0,
                                0.026326419828341264,
                                0.55122914061467321,
                                0,
                                -0.012631978455854745,
                                0,
                                0,
                                0.42289068903245797,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4485090617864565,
                                -0.27471894073945874,
                                -0.49042783147123131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18532021334288992,
                                0,
                                0,
                                0.69251649155379591,
                                0,
                                -0.081875284254167638,
                                0.300279398672117,
                                0.10778529510803689,
                                0,
                                -0.54805759724240066,
                                0,
                                0.27434916128378162,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.044201651329207295,
                                0.41096546265497352,
                                0,
                                0.44535616029728198,
                                0,
                                0,
                                0.12285867047465344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11605025997840684,
                                0.77716205597056487,
                                0.014916500856251291,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.064352879739807356,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1132096227821129,
                                0,
                                0.072662568771013458,
                                0,
                                0,
                                0,
                                0,
                                0.054807511509331663,
                                -0.94462138014276897,
                                -0.098351087457167086,
                                0,
                                0,
                                -0.46416158087445003,
                                0,
                                0,
                                0.20214158165554569,
                                0,
                                -0.056092931883723191,
                                -0.52797546560431186,
                                0.55396773915187048,
                                0,
                                -0.08487441761373915,
                                0,
                                -0.083217589556337179,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.375205555023713,
                                0.60388984056795492,
                                0,
                                -0.59578844127073505,
                                0,
                                0,
                                -0.055263040604033059,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46298730281031425,
                                -0.043062852222111536,
                                0.24715893316876353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38671363655383095,
                                0,
                                0,
                                0.29512091318509542,
                                0,
                                0.49774994557196589,
                                0.055725169253587351,
                                0.358820610247015,
                                0,
                                0.59875531908166046,
                                0,
                                0.11969623814878601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10444402905517255,
                                0,
                                -0.053373271802429567,
                                0,
                                0,
                                0.23533148047838032,
                                0,
                                -0.4006447410412296,
                                0.32263007997240978,
                                -0.27412741505664351,
                                0,
                                0.3454745676193407,
                                0,
                                -0.33121719517778903,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61070505498735361,
                                0,
                                -0.73776491741995676,
                                0,
                                0,
                                0.25763032849859424,
                                0,
                                0.25805199249038929,
                                0.20716914826071164,
                                -0.27401537841403739,
                                0,
                                0.24685697863275119,
                                0,
                                0.3293683511134724,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18791845949884034,
                                0,
                                0,
                                0,
                                -0.32648709470090748,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33556372900294584,
                                0,
                                0.27934090171691495,
                                0,
                                0,
                                0,
                                0,
                                0.90113700685501941,
                                -0.37081129467469776,
                                0.31257139161657266,
                                0,
                                0,
                                0.029757584901735787,
                                0,
                                0,
                                -0.10216563247283034,
                                0,
                                0.65732966597632303,
                                -0.11116221770152884,
                                -0.39031841153026914,
                                0,
                                -0.3474500873571037,
                                0,
                                -0.06828983198546032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51624007450875253,
                                0,
                                0,
                                0,
                                -0.19008685964091737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0819292096751996,
                                0,
                                -0.3060739024453093,
                                0,
                                0,
                                0,
                                0,
                                -0.57797953030286064,
                                -0.68845053745100293,
                                0.39633857133371686,
                                0,
                                0,
                                0.14483173831691634,
                                0,
                                0,
                                0.50244228436447269,
                                0,
                                -0.018626483930580071,
                                -0.57854734212614178,
                                -0.43585446024727514,
                                0,
                                0.10486152686996159,
                                0,
                                -0.30786066478774315,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30946454759048003,
                                0.18009300382094195,
                                0,
                                0.62858260241759389,
                                0,
                                0,
                                -0.025544770931884925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53744972045211825,
                                -0.5310902927008635,
                                -0.029812507032509233,
                                0,
                                0,
                                0,
                                0,
                                -0.34686021445218329,
                                0,
                                -0.1564027799734872,
                                0,
                                0,
                                0.81460454291273499,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41514631629774168,
                                0.084396079499243354,
                                -0.11034690091822916,
                                0,
                                0,
                                0,
                                0,
                                -0.099123080590430276,
                                0,
                                -0.16418446701265782,
                                0,
                                0,
                                -0.37253471235043589,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3313850481557109,
                                0.17179824178715949,
                                -0.82771086603818922,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72758430395168849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30855196206274704,
                                0,
                                0.30331575811123235,
                                0,
                                0,
                                0,
                                0,
                                -0.030827947893993068,
                                0.055549200170754778,
                                0.74938428313763705,
                                0,
                                0,
                                0,
                                0,
                                0.76806878476723384,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1253762004420006,
                                0,
                                1.2735191787794529,
                                0,
                                0,
                                0,
                                0,
                                -0.057377724543951902,
                                -0.32764854187785042,
                                -0.63330820949642164,
                                0,
                                0,
                                0,
                                0,
                                0.95594494865352608,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.075824732419498719,
                                0,
                                -0.3993347500684587,
                                0,
                                0,
                                0,
                                0,
                                0.45292372588032487,
                                -0.085170939000918405,
                                -0.35312012575386487,
                                0,
                                0,
                                -0.17791987766501921,
                                0,
                                0,
                                0.088447606243518273,
                                0,
                                0.28785193672386133,
                                0.36590382034772906,
                                0.24536096594490159,
                                0,
                                -0.1480294680717831,
                                0,
                                -0.7654084856411919,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27534036744025547,
                                -0.686913283079436,
                                0,
                                -0.057020503908859002,
                                0,
                                -0.12807946984175872,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.029741121375795987,
                                0,
                                0,
                                -1.5198524083628453,
                                0,
                                -0.16273516865484541,
                                0,
                                0.41835307146282119,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24517762878529875,
                                0.41236104872114493,
                                0.068046443711811927,
                                -0.4629569496354059,
                                0,
                                -0.60225192542738482,
                                0,
                                0,
                                0.057602141555405717,
                                0,
                                0,
                                -0.099207657608319677,
                                0,
                                -0.27141577039279785,
                                0,
                                0.77944069051414222,
                                0,
                                0.28165658328643006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69310748480154438,
                                0,
                                0,
                                0.57936515516372356,
                                0,
                                -0.16103488452374459,
                                0,
                                0,
                                0,
                                -0.32920516373261316,
                                0,
                                -0.21277470026386544,
                                -0.35470635301364228,
                                0,
                                0,
                                0,
                                0,
                                -0.0051276011860426872,
                                0,
                                -0.83031743794495072,
                                0,
                                0,
                                -0.17629790180764104,
                                0,
                                0,
                                0,
                                0.18541814214056987,
                                0,
                                -0.29645387175996651,
                                0,
                                0.051324907230843486,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5670934150955218,
                                0,
                                0,
                                0.44112459340479765,
                                0,
                                1.1738512853195502,
                                0,
                                0,
                                0,
                                0.42072845628445921,
                                0,
                                0.59304085243712068,
                                -0.09799857447052468,
                                0,
                                0,
                                0,
                                0,
                                0.35836682137615655,
                                0,
                                -0.16144869221016517,
                                0,
                                0,
                                -0.55425078613861323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64775815195142761,
                                0,
                                0.59479787784175597,
                                0.1698254976773797,
                                0,
                                0,
                                0,
                                0,
                                0.30391153048544323,
                                0,
                                -0.038476260221908309,
                                0,
                                0,
                                0.3223996285223929,
                                0,
                                0,
                                0,
                                0,
                                0.28162684740205352,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37607719445962029,
                                -0.40225878220466355,
                                0.10735539084425116,
                                0.56158171716616057,
                                0,
                                -0.3932553898067967,
                                0,
                                0,
                                -0.36074519177854691,
                                0,
                                0,
                                0.075855354240362605,
                                0,
                                0,
                                0.55751311969920569,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62013631602405139,
                                -0.21397612446930747,
                                0.45081318594347985,
                                -0.050712042539450469,
                                0,
                                0.050138749054809209,
                                0,
                                0,
                                0.072624647764512607,
                                0,
                                0,
                                0.21267772701845528,
                                0,
                                0,
                                0.34449799112925195,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44058889695505271,
                                0.073432287849818589,
                                0.32213404638495929,
                                -0.1254057710577931,
                                0,
                                0.63595530274010958,
                                0,
                                0,
                                -0.21633032399142987,
                                0,
                                0,
                                -0.33327968685854997,
                                0,
                                0,
                                0.45975876705975721,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.074493108102982278,
                                0.27232723531510739,
                                -0.68037838721586552,
                                0.10717238019739025,
                                0,
                                0.23598637552911556,
                                0,
                                0,
                                -0.24243697406463804,
                                0,
                                0,
                                0.34647453754331881,
                                0,
                                0,
                                0,
                                0,
                                0.008190613379828654,
                                0,
                                0.44436323137764394,
                                0.11822829440009849,
                                0,
                                0,
                                0,
                                0,
                                -0.87322998700276944,
                                0,
                                -0.14942718749224601,
                                0,
                                0,
                                -0.060309272028637756,
                                0,
                                0,
                                0,
                                0,
                                0.12752498311308613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33319026790160167,
                                -0.63677674434612774,
                                -0.24558430487290081,
                                -0.42816129449346724,
                                0,
                                0.082620064029729337,
                                0,
                                0,
                                0.3829623510543908,
                                0,
                                0,
                                0.26479618522554749,
                                0,
                                0,
                                0,
                                0,
                                0.38797420560999091,
                                0,
                                -0.056016714253103152,
                                0.67693430608964233,
                                0,
                                0,
                                0,
                                0,
                                0.12898994840615713,
                                0,
                                -0.5026365373964693,
                                0,
                                0,
                                0.3446972486527598,
                                0,
                                0,
                                0,
                                -0.43664415620402386,
                                0,
                                0.6080295152770353,
                                0,
                                -0.53722472624163753,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60282692417473327,
                                0,
                                0,
                                -0.22828912980268143,
                                0,
                                0.4530686102569671,
                                0,
                                -0.13256232138146129,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31342212842849548,
                                0.34441168104290909,
                                0.37895622061406509,
                                0.13496082549659608,
                                0,
                                0.10729718739112656,
                                0,
                                0,
                                0.20130031849379487,
                                0,
                                0,
                                0.74277698410353221,
                                0,
                                0,
                                0,
                                0,
                                -0.38003925120770149,
                                0,
                                -0.22056383454030726,
                                0.6029270258616013,
                                0,
                                0,
                                0,
                                0,
                                -0.0039615262389142702,
                                0,
                                0.089748962889500655,
                                0,
                                0,
                                -0.65979556977155196,
                                0,
                                0,
                                0,
                                0.62286197341967853,
                                0,
                                0.045240805533884071,
                                0,
                                -1.0946496650964601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.75291974877029788,
                                0,
                                0,
                                -0.25079761149038443,
                                0,
                                -0.2271973991473282,
                                0,
                                -0.26637148427492596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.070482900130564324,
                                -0.13675526908251637,
                                0.10003704994416154,
                                -0.48885179907375287,
                                0,
                                -0.040760822233796234,
                                0,
                                0,
                                -0.75399872971465176,
                                0,
                                0,
                                0.29362794089267413,
                                0,
                                -1.0451389117081316,
                                0,
                                -0.60219990606399632,
                                0,
                                -0.28936321461581671,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19914925016973642,
                                0,
                                0,
                                0.37951922920448872,
                                0,
                                -0.13607501903742669};

const double rot_30_10[1000] = {-0.64593544560235117,
                                0.54457021864364874,
                                0,
                                0,
                                0,
                                0,
                                0.41918112502951088,
                                0,
                                0,
                                -0.94705167199130025,
                                -0.50111966523862683,
                                0.30629408751342901,
                                0,
                                0,
                                0,
                                0,
                                0.020064823744167504,
                                0,
                                0,
                                0.29252456898398704,
                                0,
                                0,
                                -0.58850824872966667,
                                -0.76236535719752174,
                                0.023901752864966357,
                                0.26260624703027269,
                                0,
                                -0.052327539252802757,
                                0.013623405911879681,
                                0,
                                0,
                                0,
                                -0.087488802117784079,
                                -0.090497438410835268,
                                0.1231692889782387,
                                -0.30227760286035721,
                                0,
                                0.90485561967808714,
                                0.24258979315636631,
                                0,
                                0,
                                0,
                                0.40312133060341998,
                                -0.2739916136496709,
                                0.86552296977963783,
                                0.0055012144101422022,
                                0,
                                -0.11180252718488105,
                                0.027599072468137448,
                                0,
                                0,
                                0,
                                0.4743615371999842,
                                -0.41344318929059654,
                                -0.39227045767021124,
                                -0.16722727884204633,
                                0,
                                -0.166349942868631,
                                0.6281182078338281,
                                0,
                                -0.072131278536568477,
                                1.0012491151216751,
                                0,
                                0,
                                0,
                                0,
                                0.27148631098002873,
                                0,
                                0,
                                -0.31052139119412631,
                                0,
                                0,
                                -0.46384640535344862,
                                0.1551714624650406,
                                0.21197254399873891,
                                -0.69801068021656498,
                                0,
                                -0.37192122937952743,
                                0.30048570599660401,
                                0,
                                0,
                                0,
                                -0.20814559269803556,
                                0.37486586654629139,
                                0.19057688704646,
                                0.56960694692426095,
                                0,
                                0.00079166421505502682,
                                0.67481756330578146,
                                0,
                                -0.90099400055189793,
                                0.096185282584594911,
                                0,
                                0,
                                0,
                                0,
                                0.1253619108439914,
                                0,
                                0,
                                0.80329845349756579,
                                0.90742215615294253,
                                0,
                                0,
                                0,
                                -0.20389974443447628,
                                -0.75022469165525041,
                                0,
                                0,
                                -0.45122678296749325,
                                0,
                                0,
                                0.013806762577716652,
                                0.46865140817316597,
                                0.17600080968649418,
                                0,
                                0,
                                -0.40453854558540553,
                                0.28995716682046846,
                                0,
                                -0.70814712628042131,
                                0,
                                0.41627881400433564,
                                0.17729528936460176,
                                0.35554076123697081,
                                0,
                                0,
                                0.62207497742666007,
                                -0.42651339402740573,
                                0,
                                -0.31619320621124075,
                                0,
                                0.68779883669575748,
                                0.3060378627154009,
                                -0.62563447227948066,
                                0,
                                0,
                                -0.15211768831118777,
                                -0.041518642520869897,
                                0,
                                0.13035146775626746,
                                0.8750768567337619,
                                0,
                                0,
                                0,
                                0.014670121903001564,
                                0.070623259294829127,
                                0,
                                0,
                                0.73717952937321829,
                                0,
                                0.21673833014106195,
                                0,
                                0,
                                0,
                                0.62845215570592594,
                                0.51711089728464199,
                                0,
                                0,
                                -0.097838346382817104,
                                0,
                                0,
                                -0.30495951631188889,
                                0.75994929279961676,
                                0.023828919199605107,
                                0,
                                0,
                                0.33621258823253042,
                                0.22864403784854545,
                                0,
                                0.40446501438846083,
                                0,
                                0.47694770241796053,
                                -0.19834771865906412,
                                0.39554321689512623,
                                0,
                                0,
                                0.11187585768473286,
                                0.72177452972646439,
                                0,
                                0.2079662374874236,
                                0.063840716745764164,
                                0,
                                0,
                                0,
                                -0.20762677806291568,
                                0.16711843597781442,
                                0,
                                0,
                                0.53480975528011365,
                                0,
                                0,
                                0.1815892759148407,
                                0.19598040577345266,
                                0.54237785294234098,
                                0,
                                0,
                                -0.54833966159618042,
                                -0.39881173583828761,
                                0,
                                0.41799054408143066,
                                -0.22697747129303825,
                                -0.83591727777331415,
                                0.037946859108849332,
                                0.35645876810331439,
                                0,
                                0,
                                -0.0052962562004084893,
                                0.3481273681309322,
                                0,
                                0,
                                -0.85118368944109413,
                                0.14134330538189649,
                                -0.12468776701207035,
                                -0.42703184204335609,
                                0,
                                0,
                                0.044038217398373318,
                                0.23593600594259018,
                                0,
                                0,
                                -0.2599682748710998,
                                0.41167379973642615,
                                0.16412540667624237,
                                0.62993294703973957,
                                0,
                                0,
                                -0.56340192606024764,
                                0.14753569568042643,
                                0,
                                0,
                                0.094657908500730498,
                                0.32849736335455876,
                                -0.22386405601768977,
                                0.34622541486544134,
                                0,
                                0,
                                0.65713951224686251,
                                0.53038652942536968,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.046625278010792415,
                                -0.66931871599616921,
                                0,
                                0,
                                -0.24250059040425842,
                                0.75293030875547751,
                                0,
                                0,
                                0,
                                0,
                                0.51391674668825627,
                                -0.0095700123261223905,
                                0,
                                0,
                                -0.95484924963021656,
                                -1.1891276866411011,
                                0.36096528427871322,
                                -0.0045079074137480621,
                                -0.40547205049510299,
                                -0.32538429956447135,
                                0,
                                0,
                                -0.49614111075705097,
                                0.59434435674727448,
                                0,
                                0,
                                -0.13087396348878594,
                                -0.062114558633195677,
                                -0.86113480258045549,
                                0.26080347861051567,
                                0,
                                0,
                                -0.051210491610134599,
                                -0.40843563772638736,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12558751049135355,
                                0.68780032017766846,
                                0,
                                0,
                                0.57978069292079837,
                                0.57384390151883924,
                                0,
                                0,
                                0,
                                0,
                                -0.02814952659634911,
                                0.46232012939291728,
                                0,
                                0,
                                0.44548571408840576,
                                -0.64221710254497488,
                                -0.84764585334438758,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.084165474588357866,
                                -0.47537792925247857,
                                0,
                                0.2677001288118408,
                                0,
                                -0.34122921899059017,
                                -0.56253606359958874,
                                0.094641891403350359,
                                0.084892050311378531,
                                0.4211380260714227,
                                0,
                                0,
                                -0.61122402802830311,
                                0,
                                0,
                                0.089934807138798978,
                                -0.76206689770468838,
                                -0.37701101841782941,
                                -0.10922064842570377,
                                -0.41453725039253941,
                                0,
                                0,
                                0.29199004070973422,
                                0,
                                0,
                                -0.20701980191663163,
                                0.17537311245279447,
                                -0.36481731372382592,
                                -0.87056546570711713,
                                0.071142762745858623,
                                0,
                                0,
                                -0.17421216340252282,
                                0,
                                0,
                                0.51494305364735682,
                                -0.24602471340041196,
                                0.67075138421084934,
                                -0.45550456591187882,
                                0.11574854581083364,
                                0,
                                0,
                                0.059295337522591855,
                                0,
                                0,
                                0.57330262790878983,
                                -0.020738392535009864,
                                -0.49470215202583001,
                                0.10354579574856113,
                                0.63985091866383159,
                                0,
                                0,
                                0.077671531186138815,
                                0,
                                -0.45034017643228919,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21360944597035061,
                                0.31228327601182232,
                                0,
                                -0.76402174500602682,
                                -0.39458823797872244,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61201790768311248,
                                0.1059084773901114,
                                0,
                                0.57252887472547354,
                                0,
                                -0.48864598690625566,
                                -0.10532450556522997,
                                0.14552076604636624,
                                -0.069092823692319061,
                                0.47215825140547196,
                                0,
                                0,
                                0.70798892788028778,
                                0,
                                -0.60339346004882299,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2334897626216568,
                                0.54409948486077564,
                                0,
                                -0.60376284446141959,
                                -0.1912187379953442,
                                0,
                                -0.34821676340238406,
                                -0.69374155752232625,
                                0,
                                0,
                                0,
                                -0.55649394558619303,
                                0.22268797419628947,
                                -0.040344590291594359,
                                0,
                                -0.91733853770457774,
                                0,
                                0,
                                -1.0156802995909546,
                                0.33988773916966236,
                                -0.74733261522432293,
                                0,
                                0,
                                0,
                                -0.79854186424296103,
                                0,
                                -0.27823134189553828,
                                0.47731274002244894,
                                0,
                                0,
                                0,
                                -0.085682126757851973,
                                0.17674190370817083,
                                0.13605745947395526,
                                0.54565141932820871,
                                0,
                                -0.684869535206442,
                                0.34776381821552715,
                                0,
                                0,
                                0,
                                -0.092957037878018789,
                                0.27808944719490014,
                                0.1621845354500922,
                                0,
                                0.59841607835883415,
                                0,
                                0,
                                -0.1668418471905464,
                                0.060379072562907005,
                                -0.41511402933810959,
                                0,
                                0,
                                0,
                                0,
                                -0.49614153677697209,
                                0,
                                0,
                                -0.54153786516462765,
                                0.089992616525751842,
                                0.6203167720555478,
                                0,
                                0,
                                0,
                                0,
                                0.48073697803668242,
                                0,
                                0,
                                -0.36102286250852345,
                                -0.0074170676585814943,
                                -0.059637311523972919,
                                0,
                                0,
                                0,
                                -0.032023619194809713,
                                0,
                                -0.10557609125075373,
                                0.060029052939041497,
                                0,
                                0,
                                0,
                                0.19980760605427314,
                                0.32801787991272108,
                                -0.91471628420704554,
                                -0.11326362541391728,
                                0,
                                -0.54027573427593523,
                                -0.12875289591004518,
                                0,
                                0,
                                0,
                                0.24133571838323253,
                                -0.77009190788787507,
                                -0.16556478594053092,
                                0.11906575010353354,
                                0,
                                0.17100276526272915,
                                0.3870074042146161,
                                0,
                                0,
                                0,
                                -0.75905602058373556,
                                -0.37576767934985544,
                                -0.29906400532236554,
                                -0.85833568933599058,
                                0,
                                0,
                                0,
                                -0.70024561220381054,
                                0,
                                -0.10216030823839767,
                                0,
                                0,
                                -0.5273749316776063,
                                0,
                                -0.42698068573841041,
                                0.27615802732382699,
                                -0.62241273148822684,
                                0,
                                -0.27742816882749299,
                                0,
                                -0.062235320890200591,
                                -0.52267294325137259,
                                0,
                                0,
                                0.14985329576522571,
                                -0.16253514611444944,
                                -0.41755128737282499,
                                0,
                                0.28914043153322722,
                                0,
                                -0.79996530683225342,
                                0.23071748342227671,
                                0,
                                0,
                                -0.021341090561897091,
                                -0.2239168756126676,
                                0.30329406190252872,
                                0,
                                -0.83028532800797117,
                                0,
                                -0.40901842329435673,
                                0.027362495950624482,
                                0,
                                0.47926718605851915,
                                0,
                                0,
                                0,
                                -0.13320178840143782,
                                0,
                                -0.32987298190822872,
                                0,
                                0,
                                -0.99700394498378142,
                                0,
                                -0.5890295159426816,
                                -0.78174731932722641,
                                -0.047144979406415932,
                                0,
                                0.14365750652219644,
                                0,
                                0.13426871754730618,
                                0.032049045193586118,
                                0,
                                0.63118770463941809,
                                0,
                                0,
                                0,
                                -0.64811359919328337,
                                0,
                                0.52401390305597351,
                                0,
                                0,
                                -0.33680506820077694,
                                0,
                                0.64802469576867661,
                                -0.45345936136453469,
                                -0.4449075962219266,
                                0,
                                -0.21980861589375716,
                                0,
                                0.31998427827305559,
                                -0.16059285826509456,
                                0,
                                0,
                                0.16698582164522252,
                                -0.17443061472572038,
                                0.38223109220747858,
                                0,
                                0.2847883236496786,
                                0,
                                -0.26166424144415362,
                                -0.80375153102685748,
                                0,
                                -0.18354918350327268,
                                0,
                                0,
                                0,
                                -0.10036747157007914,
                                0,
                                1.2954712911811879,
                                0,
                                0,
                                -0.52722452824735822,
                                0.39459159999116528,
                                0,
                                0,
                                0,
                                -0.12300427829742494,
                                -0.45880510910222883,
                                -0.71758803040018204,
                                -0.029837412146017039,
                                0,
                                -0.32069056122912676,
                                0,
                                0.96429010846988172,
                                -0.89380501526144551,
                                0.26711907814366043,
                                0,
                                0,
                                0,
                                0,
                                0.93880831577839308,
                                0,
                                0,
                                0.059810430175823596,
                                0.85937187679410054,
                                -1.1299524212868501,
                                0,
                                0,
                                0,
                                0,
                                0.40384298770758353,
                                0,
                                0,
                                0.46056425232457698,
                                -0.4925462161788291,
                                0.035579168432892827,
                                0,
                                0,
                                0,
                                0,
                                -0.60360087226063053,
                                0,
                                0.35027223670368091,
                                0,
                                0,
                                0,
                                -0.62707439934638276,
                                0.030057029326391094,
                                0.076911362226882773,
                                -0.47599462339714838,
                                0,
                                0.50069690804363798,
                                -0.43051935731368102,
                                0,
                                0,
                                0,
                                0.024518446466274012,
                                -0.51307158861288993,
                                -0.21706282738166582,
                                0.27266876428740167,
                                0,
                                0.65524418934500905,
                                -0.089224456631078586,
                                0,
                                0,
                                0,
                                -0.67558519690357499,
                                -0.21892966055232105,
                                0.32639736479780912,
                                0.529731717685332,
                                0,
                                -0.3170843883342167,
                                -0.61413674069477109,
                                0,
                                0,
                                0,
                                -0.36652392907571052,
                                0.44723683129520375,
                                -0.49358294019990179,
                                -0.16291666974903168,
                                0,
                                -0.13531271092635425,
                                0,
                                0.19678547780960678,
                                -0.77715979914679978,
                                -0.82043297180424957,
                                0,
                                0,
                                0,
                                0,
                                -0.061991347372458705,
                                0,
                                0.38876081651437078,
                                0,
                                0,
                                0,
                                -0.017068747096507922,
                                0.52668872426840596,
                                -0.28614057970259316,
                                0.62532636143972786,
                                0,
                                0.31346958940249259,
                                0.39486277343921805,
                                0,
                                0.38277980083328444,
                                0,
                                0,
                                -0.082560035009309002,
                                0.62246831822691084,
                                0,
                                0.49755571698495837,
                                -0.23604735996094212,
                                0,
                                -0.19973663624392574,
                                0,
                                -0.1340083026149429,
                                -0.35831952300706449,
                                0,
                                0,
                                -1.0938012390214107,
                                0,
                                0,
                                0.21966988881218616,
                                0,
                                0.027301747993950558,
                                0,
                                0,
                                -0.013279263906826324,
                                -0.50032757989099486,
                                0,
                                0.66776821767519345,
                                0.504560537417588,
                                0,
                                -0.18780948846486065,
                                0,
                                -0.62902162447301868,
                                -0.20112732552245607,
                                0,
                                0,
                                0.33239940239581928,
                                0,
                                0,
                                0,
                                -0.63670037281748637,
                                0,
                                0.18883627900535155,
                                0.29481588164175221,
                                0,
                                0,
                                -0.33734059607856154,
                                0,
                                0,
                                -0.052542594547569182,
                                0,
                                0.19316187781240768,
                                0,
                                0,
                                0.21915705103148947,
                                -0.51811579151177611,
                                0,
                                0.21042262225449607,
                                -0.77406478949183977,
                                -0.44645612306017307,
                                0,
                                -0.64627537095125942,
                                0,
                                0,
                                -0.28963340895646594,
                                0.1878695146071335,
                                0,
                                0.46808169765338453,
                                -0.21147608210706628,
                                0,
                                0.61525049006965404,
                                0,
                                0.42390022451554038,
                                0.2809651112726187,
                                0,
                                0,
                                -0.60270984008690243,
                                0,
                                0,
                                0.70993303367874039,
                                0,
                                -0.62952683951389199,
                                0,
                                0,
                                0.25998554226792819,
                                -0.0096535918388560571,
                                0,
                                -0.095615616386541924,
                                -0.15120524429604154,
                                -0.29956605904727257,
                                0,
                                -0.038037229446311861,
                                0,
                                0,
                                0.89078487581483234,
                                0.24160584810016733,
                                0,
                                0.18440014703618612,
                                0.15145577043915529,
                                -0.23273668527299418,
                                0.67913880739806876,
                                0.19030770849222645,
                                0,
                                -0.16491396794165017,
                                0,
                                -0.12607474427547075,
                                0,
                                0.63662833249559503,
                                0,
                                -0.3148722700149898,
                                0.28761644659314339,
                                -0.85663102085263165,
                                0,
                                -0.036307659252700589,
                                0,
                                -0.1933664429690001,
                                0,
                                -0.21355725216162794,
                                0,
                                -0.30216176604489453,
                                -0.48929003253974479,
                                -0.23661688560315389,
                                0,
                                0.48235193249622571,
                                0,
                                0.042124538958143776,
                                0,
                                0.61552263734169033,
                                0,
                                0,
                                0,
                                0,
                                0.30087757441539409,
                                0,
                                0.44731535397553013,
                                0,
                                -0.52299372781417786,
                                0,
                                -0.28548083457446455,
                                -0.77860142031401691,
                                -0.30316844939464804,
                                0.2559539115801891,
                                0,
                                -0.45457715537569632,
                                0,
                                -0.049150950311582009,
                                0,
                                -0.16522744510960719,
                                0,
                                0,
                                0,
                                0,
                                -0.16379018084006727,
                                0,
                                0.18572635365122597,
                                0,
                                -0.25110271508530391,
                                0,
                                -0.46645132188571736,
                                -0.18350351189185968,
                                0.20639548851194367,
                                -0.065584111437810261,
                                0,
                                0.059429246328020102,
                                0,
                                0.9549377951075948,
                                0,
                                -0.063151088099192842,
                                0,
                                0,
                                0,
                                0,
                                0.086927934627668041,
                                0,
                                -0.43566059061479823,
                                0,
                                -1.096328212289521,
                                0,
                                -0.64927269896022111,
                                0.33984356026372853,
                                -0.28658736470032842,
                                -0.32274609079366634,
                                0,
                                -0.72708288713592339,
                                0,
                                0.17498026278831694,
                                0,
                                0.37274841473495612,
                                0,
                                0,
                                0,
                                0,
                                0.77735657190776819,
                                0,
                                -0.074038712668497028,
                                0,
                                -0.16912236267298733,
                                0,
                                0.64934254281155834,
                                -0.64831935388152973,
                                0.31197044003750302,
                                -0.16176057712159875,
                                -0.25508613780718103,
                                0,
                                0,
                                0,
                                0,
                                -0.15970915388304102,
                                -0.6046602550848752,
                                -0.56148623688209853,
                                0.041381927513535297,
                                0.34128183904296089,
                                0.56450691657988739,
                                0,
                                0,
                                0,
                                0,
                                0.46781925459945656,
                                0.17036588380945339,
                                0.26254653418910867,
                                -0.062065846781191245,
                                -0.61650269888138765,
                                0.44756782180869203,
                                0,
                                0,
                                0,
                                0,
                                0.39074291579946502,
                                -0.44061841649497935,
                                -0.28790092189394156,
                                -0.92929476783648179,
                                -0.074777273089337043,
                                -0.19437513002942136,
                                0,
                                0,
                                0,
                                0,
                                0.056207914313261442,
                                -0.083615980938316167,
                                0,
                                0,
                                0,
                                0,
                                0.19558055755584874,
                                0.55517362461190811,
                                1.0218203381503872,
                                -0.17016618272626469,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27791014705304296,
                                -0.17992120121998292,
                                0.095272610313506853,
                                -1.4032393173646087,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.077675722154189747,
                                -1.1618298684152275,
                                0.85933962395727748,
                                -0.0596332576063714,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26197358197565146,
                                -0.61132792354697518,
                                -0.50187718655226854,
                                -0.39182401192152111,
                                0,
                                0,
                                0.25435437826753937,
                                0.050229129289572544,
                                0.43659863543138061,
                                -0.44826793968591255,
                                0,
                                0,
                                0,
                                0,
                                0.64924277037387923,
                                -0.34598005106277696,
                                -0.21886399427189876,
                                0.17606271701855286,
                                -0.53016472465591857,
                                -0.42097530971459585,
                                0,
                                0,
                                0,
                                0,
                                0.42223524299886572,
                                0.53340699714036166};

const double rot_30_100[100000] = {-1.0892954636690264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29731914492444872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39089364973824725,
                                   0,
                                   0.15242960745210238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31999704514840227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84358287194601878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15487228709615827,
                                   0,
                                   0.21415049504110312,
                                   0,
                                   0.2837075974915037,
                                   0,
                                   0,
                                   0.0058798827698504415,
                                   0.13637063528606039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31285060613162041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30174037635893347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024689430921171162,
                                   0,
                                   0,
                                   -0.15562170960790667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13970829355189762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25499869023097183,
                                   0,
                                   0,
                                   -0.18963388200168541,
                                   0,
                                   0,
                                   0,
                                   0.48795238442551053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50860681979327271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26323168368723976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33432716694948866,
                                   0,
                                   0,
                                   0,
                                   0.27511617254285164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18336975786107992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27753762374228647,
                                   -0.1410344903922032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025444097723998582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64305637061127985,
                                   0,
                                   0,
                                   0,
                                   -0.21755357884239071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14922809418471761,
                                   0,
                                   0.10570698635371074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34316430606851711,
                                   0,
                                   -0.17155668494969084,
                                   0,
                                   -0.20359088964156086,
                                   0,
                                   0.15797556478679378,
                                   0,
                                   0,
                                   -0.39041741434811766,
                                   0.45738966365835487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014534709925398688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059815539242436572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062553593465728308,
                                   0,
                                   0,
                                   0.27109327363725394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40922021537741343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22795874214770645,
                                   0,
                                   0,
                                   -0.29314082394560131,
                                   0,
                                   0,
                                   0,
                                   -0.39358232378705016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032757898833855832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46061803633816895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53344721566458908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23041841165749755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34946649408373032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13612975232303895,
                                   0,
                                   -0.5563401012997321,
                                   0,
                                   0,
                                   0,
                                   -0.52495027419365081,
                                   0,
                                   -0.25953844164130835,
                                   0,
                                   -0.11705651716854056,
                                   0,
                                   0,
                                   0.5646117111795399,
                                   -0.0098811938242647779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019771968161851186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28572157668638598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15472110845280684,
                                   0,
                                   0,
                                   -0.15634573254056777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084256368501751916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1935622990001909,
                                   0,
                                   0,
                                   -0.35134893710328186,
                                   0,
                                   0,
                                   0,
                                   0.091224707893930029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13317985799423185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50769123015793727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16127211904676825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54054238759354445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19578571490858745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13770427693817217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20350064626935804,
                                   0,
                                   -0.3045830800148579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41507227717736928,
                                   -0.28949059209374767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19368836826834904,
                                   0,
                                   0,
                                   0,
                                   0.023654354492870233,
                                   -0.24830391686863057,
                                   0,
                                   0,
                                   -0.60843322003928479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83778553654564081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2244040894708538,
                                   0,
                                   0,
                                   0,
                                   -0.15420539069038597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057051558157895546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36842830694795498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12875062505701457,
                                   0,
                                   0,
                                   0,
                                   -0.51107489968144637,
                                   0,
                                   0,
                                   0,
                                   -0.15769065468586252,
                                   0.6706791462500078,
                                   0,
                                   0,
                                   0,
                                   -0.20980137878441751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94934681460294179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13523533004514598,
                                   0,
                                   -0.097060047391649695,
                                   0,
                                   0.18387602871657274,
                                   0,
                                   0,
                                   -0.13038150437443932,
                                   0.10173075235857698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13428736435818078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19157045971805198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76045427000224397,
                                   0,
                                   0,
                                   -0.26346196477803246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019212746251638699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16422893184993795,
                                   0,
                                   0,
                                   0.11985550393631757,
                                   0,
                                   0,
                                   0,
                                   0.19999070282929679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35636321426834133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23381823394051496,
                                   0,
                                   0.26841653957082856,
                                   0,
                                   -0.080721243809849727,
                                   0,
                                   0,
                                   -0.56915119587939456,
                                   -0.32937565087052301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072374985739554615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22299072434975853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083106693001902002,
                                   0,
                                   0,
                                   -0.13084985143135835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25766215930606018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1098476374111938,
                                   0,
                                   0,
                                   -0.50967865778846067,
                                   0,
                                   0,
                                   0,
                                   0.062015669267121765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11523148628432367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14812333475861866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12584787419314042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32373954754543482,
                                   0,
                                   0.096001472394009316,
                                   0,
                                   0,
                                   0.63685617670020034,
                                   0,
                                   0,
                                   0,
                                   0.30507535669831065,
                                   0,
                                   0.072303910936533433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55532411797181336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47118164402824897,
                                   0,
                                   0,
                                   0,
                                   0.41958667382760695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10034913213229696,
                                   0,
                                   0,
                                   0.60090872015716079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.927008364173737,
                                   0,
                                   0,
                                   0,
                                   -0.034950503961995949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38917388936602665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73979406660899993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093688806754187892,
                                   0,
                                   0,
                                   0,
                                   0.14441052848725161,
                                   0,
                                   0,
                                   0,
                                   -0.37950204736983201,
                                   0.32778309470172906,
                                   0,
                                   0,
                                   0,
                                   -0.37843116437243179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39611104346681614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67251615062276837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.107294537196789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62683656599131099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15095032307288253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33394614397628924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061624579315846272,
                                   0,
                                   0.24779894116521917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30199743948283114,
                                   -0.85178724317945187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07467407366430584,
                                   0,
                                   0,
                                   0,
                                   0.4121759047580702,
                                   0.22496252727068863,
                                   0,
                                   0,
                                   -0.014523234672992966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13018068413007611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12602838151592405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10530180558005349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.277824630423329,
                                   0,
                                   0,
                                   0,
                                   0.26622585816040822,
                                   0,
                                   0,
                                   0,
                                   0.69607635860445383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22779933488488135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53656173481216263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025540452703191219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15733026593984384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14736923888717993,
                                   0,
                                   0,
                                   0,
                                   -0.12631453287799546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10182145841452381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46838070856894137,
                                   -0.072155550073007418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1832755190875294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045471048021220956,
                                   0,
                                   0,
                                   0,
                                   -0.48752460647024143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0043943597831271504,
                                   0,
                                   -0.20365025777753151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62272714792572526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41491414786746594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66595554994431438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17787826156692313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32278616218891965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49105956970208664,
                                   0,
                                   0,
                                   0,
                                   0.68057605288421852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68886196877196104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24672852051714461,
                                   0,
                                   0,
                                   -0.22364304362215021,
                                   0,
                                   0.39040840384151121,
                                   0,
                                   0.25322014130122827,
                                   0,
                                   0,
                                   0.24079627689419603,
                                   -0.43088231184833964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15232152255000081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29569664978186255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23839667388040237,
                                   0,
                                   0,
                                   0.4264027764910715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22401275020128864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13848535739928414,
                                   0,
                                   0,
                                   0.025619371046942979,
                                   0,
                                   0,
                                   0,
                                   -0.21351493072218464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15781847970773188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29553403379339754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6466963241115683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31240194035324875,
                                   0,
                                   0.082637823301954669,
                                   0,
                                   0,
                                   -0.13277084406341971,
                                   0,
                                   0,
                                   0,
                                   -1.2504476519754268,
                                   0,
                                   -0.25459962901538707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22086938704732745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021742772233188656,
                                   0,
                                   0,
                                   0,
                                   0.044774244171697009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17675474196716523,
                                   0,
                                   0,
                                   0.11645275600655682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39923616274713714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28961489974164512,
                                   0,
                                   0,
                                   0,
                                   0.023400489842790792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29171835274520658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3358745344686288,
                                   0.29616851227925806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4553486255257837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014637506929620854,
                                   0,
                                   0,
                                   0,
                                   -0.098256465739970184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11851617107955141,
                                   0,
                                   0.058276046358965855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48570143561189805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39844561363658476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015918955707074602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38141439551739381,
                                   0,
                                   0,
                                   0,
                                   -0.41521046273229134,
                                   0,
                                   0,
                                   0,
                                   0.033449700240247487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20093661811014277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56154292275127227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40778198748467681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44347196291941593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017434393852080843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83698805139007715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25468863266029962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074933802535112448,
                                   0,
                                   0.17888065148838048,
                                   0,
                                   0,
                                   -1.0796572719604312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42941588758459681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22315811168597288,
                                   0,
                                   -0.27159501153811949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029931099530788097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0636878660877458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38920459084262848,
                                   0,
                                   0.15956571323179741,
                                   0,
                                   0.045723982153672446,
                                   0,
                                   0,
                                   -0.10045316217628586,
                                   0.11729329391288271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21722640194483622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070860496093546194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05313356475819625,
                                   0,
                                   0,
                                   -0.41754422788292533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065035016509184446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074942095311680335,
                                   0,
                                   0,
                                   0.480192008567361,
                                   0,
                                   0,
                                   0,
                                   -0.40877603727793521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40027037134699806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15464369370013972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56740138593148703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66916647209338942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37230172637817094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2295507942214273,
                                   0,
                                   0,
                                   0,
                                   0.24428652034421983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3286707097838979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.050132859543697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04608940462891345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43787741433548488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85852352311771196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26945022002819269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031642695696951086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49809008784224557,
                                   0,
                                   -0.49481980045733687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14934365505997688,
                                   -0.13124980887848089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027956306266795284,
                                   0,
                                   0,
                                   0,
                                   -0.36405859420025677,
                                   -0.1294089797017656,
                                   0,
                                   0,
                                   -0.60084291813791402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30593797083184054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39771443949836438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52868566823738816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10141808351781972,
                                   0,
                                   0,
                                   0,
                                   0.14371510603470394,
                                   0,
                                   0,
                                   0,
                                   -0.014241574600093548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63075683595133436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017365764232762079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36471420473307725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76776105417456464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31184736668422536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30248494699853617,
                                   0,
                                   -0.47034218030811092,
                                   0,
                                   0,
                                   -0.037587869718168077,
                                   0,
                                   0,
                                   0,
                                   0.33101081268388305,
                                   0,
                                   0.27097778250675819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20231315791945376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57963530947474651,
                                   0,
                                   0,
                                   0,
                                   0.037710448761572084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3317172536160084,
                                   0,
                                   0,
                                   0.57422434318693993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5009142892369518,
                                   0,
                                   0,
                                   0,
                                   0.686954658043891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34269843187825066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24610012693453182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46086950339780497,
                                   0,
                                   0,
                                   0,
                                   -0.2186017817997043,
                                   0,
                                   0,
                                   0,
                                   0.46172628153734241,
                                   0.58485213155711668,
                                   0,
                                   0,
                                   0,
                                   0.14608910258259183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.419524215519822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05050103608717238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7495667672954327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18854489968311716,
                                   0,
                                   0.025274050987570847,
                                   0,
                                   0,
                                   -0.0046376605119447245,
                                   0,
                                   0,
                                   0,
                                   -0.39468092780943576,
                                   0,
                                   0.68473803112596288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19705805247665859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0036346565197118014,
                                   0,
                                   0,
                                   0,
                                   -0.6346476091043719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07912529794439413,
                                   0,
                                   0,
                                   -0.021539570041557907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42313265720270682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40271688755219015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62938592750548339,
                                   0,
                                   0,
                                   0,
                                   0.037516757184230171,
                                   0,
                                   0,
                                   0,
                                   0.38283915578613981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27064754279873188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10317898587931276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17544769968332954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74961739812218642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39202987853510368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031663664767964866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46444735171050755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71383068241482417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46912108475332542,
                                   0,
                                   -0.49037659679692952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35259502062165465,
                                   -0.43939150163290885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18102523462560394,
                                   0,
                                   0,
                                   0,
                                   0.54745741774185641,
                                   -0.12085584265685881,
                                   0,
                                   0,
                                   0.35078196665322348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098139353277765545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37711509633905671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17566967396913896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42431233319192785,
                                   0,
                                   -0.85717346812152106,
                                   0,
                                   0,
                                   0.55834723258580476,
                                   0,
                                   0,
                                   0,
                                   0.23459036063364808,
                                   0,
                                   0.17010315545369586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40102098473339937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42986219313775409,
                                   0,
                                   0,
                                   0,
                                   -0.22164198414459216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33844783408999102,
                                   0,
                                   0,
                                   0.27859672080183684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40983788393380438,
                                   0,
                                   0,
                                   0,
                                   -0.50837059117326511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75556366197767755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34819585500856409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37047028070404731,
                                   0,
                                   0,
                                   0,
                                   0.61630245156303531,
                                   0,
                                   0,
                                   0,
                                   0.44390120577420422,
                                   -0.02584473267176567,
                                   0,
                                   0,
                                   0,
                                   -0.60924992591675264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37008101680054245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20152678790442943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.506014778529155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28025741124730102,
                                   0,
                                   0,
                                   0,
                                   0.43378837051575247,
                                   0,
                                   0,
                                   0,
                                   -0.24212827219386587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50605401214183521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30737019471587618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16560866738534846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24206544833281529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21884327448656204,
                                   -0.094698394991588622,
                                   0,
                                   0,
                                   0,
                                   0.13168484931215374,
                                   -0.34205333344011613,
                                   0,
                                   0,
                                   0,
                                   0.057049038682495896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45253278974520272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24463968166317729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088976492310525623,
                                   0,
                                   0,
                                   0,
                                   0.68876473692275475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2496483375247312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39360030730315959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53107173372332916,
                                   0,
                                   -0.37878900788358083,
                                   0,
                                   0,
                                   -0.12809645688978433,
                                   0,
                                   0,
                                   0,
                                   -0.11508333436922037,
                                   0,
                                   -0.73893705889660133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35793328674744795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28356180458702374,
                                   0,
                                   0,
                                   0,
                                   -0.52255722061879417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3558950723568165,
                                   0,
                                   0,
                                   -0.13652178184178851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4466095054407952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19953386290024783,
                                   0,
                                   0,
                                   0,
                                   0.18088939235755441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49135232225712322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31789069049167118,
                                   0.012891279321194309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23172012794684513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39595417426548424,
                                   0,
                                   0,
                                   0,
                                   0.11110045563398727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049761344509823779,
                                   0,
                                   -0.36550303115436034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16270076803992023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88235173169763192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26294840224605565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52623587334475097,
                                   0,
                                   0.45465511656697105,
                                   0,
                                   0,
                                   0.55323725643570065,
                                   0,
                                   0,
                                   0,
                                   -0.033949598059662661,
                                   0,
                                   -0.83439413187130829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054172995855052725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18244833879650288,
                                   0,
                                   0,
                                   0,
                                   0.062768869233538832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31115688879772757,
                                   0,
                                   0,
                                   -0.29203731081833012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28588026578501963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70979239624030732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095697162954797466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57234022327498701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42574174202596243,
                                   0,
                                   0,
                                   0,
                                   0.047021150412450058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70021474274820017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073594559554619104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053819864506859751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30118500180224111,
                                   -0.27988222778005617,
                                   0,
                                   0,
                                   0,
                                   0.25155976156660498,
                                   0.0048734159488629525,
                                   0,
                                   0,
                                   0,
                                   -0.79503152228769247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062329254606767255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2972013523692113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20018262073340673,
                                   0,
                                   0,
                                   0,
                                   0.019725838880976329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014178860340141465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065286140765551795,
                                   -0.43964062199199755,
                                   0,
                                   0,
                                   0,
                                   0.34397649815626363,
                                   -0.048867559488132109,
                                   0,
                                   0,
                                   0,
                                   -0.047874699975617718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046970648745017184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81406987879713744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072367508407067543,
                                   0,
                                   0,
                                   0,
                                   0.095393296434264585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45895110881639395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49500870816528125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02479367023475873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46259035612132993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34463986085896087,
                                   0,
                                   -0.45929191284377041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65265502798652464,
                                   0,
                                   0,
                                   0,
                                   0.61232455048834133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42136561151274465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73015433267514518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37999857636028123,
                                   0,
                                   0,
                                   0,
                                   0.39892155178198835,
                                   0,
                                   0,
                                   0,
                                   -0.63129990120070567,
                                   -0.43129522670529558,
                                   0,
                                   0,
                                   0,
                                   0.22664760808294709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51002663924946834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050613082601948883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047546772913680396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42147915902208999,
                                   0,
                                   0,
                                   0,
                                   0.70033201711980264,
                                   0,
                                   0,
                                   0,
                                   -0.22233954082142227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33692760105827579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037903198533385279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40333146707805806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28387646127665889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28985510207183895,
                                   -0.11571496908970581,
                                   0,
                                   0,
                                   0,
                                   -0.40010067066891963,
                                   -0.053056043298125549,
                                   0,
                                   0,
                                   0,
                                   -0.004913693224178145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13990157621520419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0023769965746227931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76522769291799519,
                                   0,
                                   0,
                                   0,
                                   0.23224354142677611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46322107117345906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37643019227958407,
                                   -0.1388634857882507,
                                   0,
                                   0,
                                   0,
                                   -0.1645169600074248,
                                   0.63804352332777337,
                                   0,
                                   0,
                                   0,
                                   0.21773126139333013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23927661188820742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014172566081999838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25181132804459588,
                                   0,
                                   0,
                                   0,
                                   0.14835130043191186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38204436289629795,
                                   0,
                                   0,
                                   0,
                                   -1.261381472797082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24102672013483106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46820484450966016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36565239573867447,
                                   0,
                                   0,
                                   0,
                                   -0.51130124225273832,
                                   0,
                                   0,
                                   0,
                                   -0.41823384344580189,
                                   -0.26128634126459571,
                                   0,
                                   0,
                                   0,
                                   -0.13847178250310166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18380098672499248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37932107898945383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9002493585307032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23593695284952593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58118952219451947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13402166674703761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12623188445499645,
                                   0,
                                   0.68905183079526999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14833436518527221,
                                   -0.10841075161727755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39779820687375156,
                                   0,
                                   0,
                                   0,
                                   -0.31390464014385555,
                                   -0.36103645079100594,
                                   0,
                                   0,
                                   -0.15166616048937087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13606438713039232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37137282836345858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53269033509293329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32767560960025793,
                                   0,
                                   0,
                                   0,
                                   -0.18897374221609542,
                                   0,
                                   0,
                                   0,
                                   -0.023664298976692023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16646539646496797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068372351716255247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63426756430731968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29623213316214925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38725628467460937,
                                   0.28033236136479872,
                                   0,
                                   0,
                                   0,
                                   0.34709953904295376,
                                   0.64502422158595363,
                                   0,
                                   0,
                                   0,
                                   -0.15703711203318779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084579787945216645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015568932941738112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10264513445654017,
                                   0,
                                   0,
                                   0,
                                   0.32336622212644761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10392234041802208,
                                   0,
                                   0,
                                   0,
                                   -0.36600178704615444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59232167400889657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27948811953287495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29186276757905844,
                                   0,
                                   0,
                                   0,
                                   0.2016124992671425,
                                   0,
                                   0,
                                   0,
                                   0.27330968326410215,
                                   0.12319520030893454,
                                   0,
                                   0,
                                   0,
                                   1.161056199466854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077627403278721224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19028428608324471,
                                   0,
                                   0,
                                   0,
                                   -0.10574924353229681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37538939254515158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46855864813813042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65899850187476972,
                                   0,
                                   0,
                                   0,
                                   0.35452188195450096,
                                   0,
                                   0,
                                   0,
                                   0.93381670582868925,
                                   -0.22138737135500788,
                                   0,
                                   0,
                                   0,
                                   -0.16112652330224159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85626512777396901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36308545452884522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58039481210634813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31495145505410149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1123329305274854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41222552175254923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11402309551575407,
                                   0,
                                   -0.3988268432683118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56648479779333116,
                                   -0.3372814796986488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92747753919280074,
                                   0,
                                   0,
                                   0,
                                   -0.039279462976158891,
                                   -0.43094320131898567,
                                   0,
                                   0,
                                   0.25500726051510419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30592881482058165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096863464780493916,
                                   0,
                                   -0.16602537103642637,
                                   0,
                                   0.50249578237252401,
                                   0,
                                   0,
                                   0.1834044662849553,
                                   0.28244183867128303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052690632577815394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044718337951873403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043735661947182779,
                                   0,
                                   0,
                                   0.15146042910259366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60023954068481733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32946030137116655,
                                   0,
                                   0,
                                   -0.20511287326069086,
                                   0,
                                   0,
                                   0,
                                   -0.14859794056841322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1858147094699919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1350823634954284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32353492970352948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44264702234236275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051941303235724746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059335552102747033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38811977231031275,
                                   0,
                                   0.011795821509838003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67143392382032485,
                                   -0.17729810701705767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088714658899749291,
                                   0,
                                   0,
                                   0,
                                   -0.83459240363167986,
                                   0.62534287469942729,
                                   0,
                                   0,
                                   0.33946121374094529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38811753938990018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25579078038755731,
                                   0,
                                   0,
                                   0,
                                   0.61142570291826337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23418748093870817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22416196223986457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2116208795777284,
                                   0,
                                   0,
                                   0,
                                   -0.88489215285111478,
                                   0,
                                   0,
                                   0,
                                   -0.054052503605845112,
                                   -0.42489868408217807,
                                   0,
                                   0,
                                   0,
                                   0.057715217751387549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18037767755740025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094364548338258941,
                                   0,
                                   -0.41155184812645002,
                                   0,
                                   0.36289472473258394,
                                   0,
                                   0,
                                   -0.10910170346777517,
                                   -0.51981719776270963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35291134336659469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12472128415638181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1623672502690956,
                                   0,
                                   0,
                                   0.0039824701355633298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18506874374574633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40049840190322339,
                                   0,
                                   0,
                                   0.048256064587482175,
                                   0,
                                   0,
                                   0,
                                   -0.1239256808956636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17058222437313522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074680787245113719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37127489521182933,
                                   0,
                                   0,
                                   0,
                                   0.2877387975217009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09350377146880634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45652829465108768,
                                   0.11780772776765396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15453829868072264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075152992090223747,
                                   0,
                                   0,
                                   0,
                                   -0.38877638064854714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52031726849025883,
                                   0,
                                   0.29803125127870672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050145767793637552,
                                   0,
                                   0,
                                   0.25064975209992196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3758401898848876,
                                   0,
                                   0,
                                   0,
                                   0.48581156433397998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23341228523073848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058469933086249821,
                                   0.44557893250979552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12939911905740614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054785638380390952,
                                   0,
                                   0,
                                   0,
                                   0.29240079231928212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40918939199424698,
                                   0,
                                   -0.039512034188886928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17095140663272099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11669111381714567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36988866293347394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47252292998543521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73414091770689982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11746708469278452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27521674731320639,
                                   0,
                                   0.048243349081878467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032894317617057939,
                                   0.62272180193529314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53787830532569125,
                                   0,
                                   0,
                                   0,
                                   0.45326958020620489,
                                   0.33059749701291813,
                                   0,
                                   0,
                                   -0.2139077602363369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64980022566239315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084419716219820529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080128775871246699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23066822568509329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11863928626646306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22939021385921288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92938241692764945,
                                   0,
                                   0.055862918151836485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26543694692149933,
                                   0.11113166778534668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24363149625253938,
                                   0,
                                   0,
                                   0,
                                   0.20674382624998142,
                                   -0.40445282663955523,
                                   0,
                                   0,
                                   0.66741971219990126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37350268376240003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3726226297214863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70321819875059022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14220728544617126,
                                   0,
                                   -0.04756972785030697,
                                   0,
                                   0,
                                   -0.26693961222484697,
                                   0,
                                   0,
                                   0,
                                   -0.14689262315523538,
                                   0,
                                   -0.13153509092639817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44277918276527983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018431947491002819,
                                   0,
                                   0,
                                   0,
                                   0.74933052700066349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26003262327973281,
                                   0,
                                   0,
                                   0.66061439832768865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40509354960399407,
                                   0,
                                   -0.017393823987511037,
                                   0,
                                   0.3015741860685987,
                                   0,
                                   0,
                                   -0.076208893832204735,
                                   0.068183197422286124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14901048407820264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13720570673270754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44426769186466614,
                                   0,
                                   0,
                                   0.12174004719722235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25824592830822551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45818678663997542,
                                   0,
                                   0,
                                   0.067325876890087774,
                                   0,
                                   0,
                                   0,
                                   0.38200384183809577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23212752114866939,
                                   0,
                                   0,
                                   0,
                                   -0.55788180860303693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00011774450701275288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16054626556656582,
                                   0,
                                   1.0231559496186353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51785739772401373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.609585198512409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64902658946970926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13461438181328472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90364575059605134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56988626050724822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84719554756929361,
                                   0,
                                   0,
                                   0,
                                   -0.18807321336607213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28664585937242859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021878968861379799,
                                   0,
                                   -0.23821937908901419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57459780851141251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78743547419963567,
                                   0,
                                   -0.18075344202565247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29728511658003098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092935812170695825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36427586278577229,
                                   0,
                                   0,
                                   0,
                                   -0.08422528250560693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74710930803025577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68803320089129372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74711298658248226,
                                   0,
                                   0,
                                   0,
                                   0.54549373527780409,
                                   0,
                                   0,
                                   0,
                                   -0.47410381324658502,
                                   0.19301962085643545,
                                   0,
                                   0,
                                   0,
                                   -0.013550325122408663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62614452055028413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10065626975659928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12365376582345669,
                                   0,
                                   0,
                                   0,
                                   0.29803787573147572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65017812254222751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28809847136321975,
                                   0.26197166527782267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10670844163978335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48056998955554592,
                                   0,
                                   0,
                                   0,
                                   -0.24720195299684083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018342621164264616,
                                   0,
                                   0.026883877087393572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082992806920540091,
                                   0,
                                   0.10312926562801407,
                                   0,
                                   0.42558178274656278,
                                   0,
                                   -0.057543592523936787,
                                   0,
                                   0,
                                   0.2465163095427714,
                                   0.10369637876251482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58261703214130145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00053785642028817034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078111256130774021,
                                   0,
                                   0,
                                   -0.098641298288253423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00075819460679976735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054639401371620572,
                                   0,
                                   0,
                                   -0.34242187031898436,
                                   0,
                                   0,
                                   0,
                                   -0.32395867074513007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39108520775871525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18501633495434328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6395485376176212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79834631205110806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5763795681122863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42158825439023445,
                                   0,
                                   0,
                                   0,
                                   -0.71370153656010338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2320921718448527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27638276588919436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2349287535469905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63969546689127998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22147126963872163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45525781861977166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52136662570052228,
                                   0,
                                   0.086405019017621418,
                                   0,
                                   0,
                                   0,
                                   0.32758436426735599,
                                   0,
                                   -0.20840590013300955,
                                   0,
                                   -0.034193811506156455,
                                   0,
                                   0,
                                   -0.045550503004693724,
                                   -0.19996106328637145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42272369647105174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5282558690642194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27148678082969163,
                                   0,
                                   0,
                                   0.22806370325201403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26349562905232204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24564462641356297,
                                   0,
                                   0,
                                   0.066046371679715235,
                                   0,
                                   0,
                                   0,
                                   -0.024398440022778949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29636232116956779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25459971148540311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38143338570545504,
                                   0,
                                   0,
                                   0,
                                   -0.025332524028869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18101706240592533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35212438252183098,
                                   0.41770009482003306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13761155558889387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17834466180041961,
                                   0,
                                   0,
                                   0,
                                   -0.51259647580064804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35673407402152169,
                                   0,
                                   -0.12981119276266062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014305404014945972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43706481296935146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28180644828775914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30355418046116406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0111011983964899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83881238452457896,
                                   0,
                                   0,
                                   0,
                                   0.21300747216143831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57303051121720039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68493334620672242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42732266330372776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044383404531858371,
                                   0.077564176783705821,
                                   0,
                                   0,
                                   0,
                                   0.072737120175613179,
                                   0.043411776620844188,
                                   0,
                                   0,
                                   0,
                                   -0.047747113824543039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81608298307521077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0007628668280966009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15987243952114899,
                                   0,
                                   0,
                                   0,
                                   -0.32924608012923567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21683379557387983,
                                   0,
                                   0.31283106858337262,
                                   0,
                                   -0.03132948245264295,
                                   0,
                                   0,
                                   -0.051528179750053103,
                                   0.21653919552987691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1566251292061962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30804297559081961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14547103994931487,
                                   0,
                                   0,
                                   0.4932644834370985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3277343681604788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4221272674970728,
                                   0,
                                   0,
                                   0.27712669673264478,
                                   0,
                                   0,
                                   0,
                                   0.22272146881611257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093247144194477105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24492853544829268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20744574302882698,
                                   0,
                                   0,
                                   0,
                                   0.34306122135486139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24649812768377513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12091648920139035,
                                   -0.26307592119963707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64956458564319308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048483240547378764,
                                   0,
                                   0,
                                   0,
                                   -0.14877545170740369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3063389158166625,
                                   0,
                                   -0.28133617231359309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12361927938281025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012732632793348415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14183692431044642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038409734114276367,
                                   0,
                                   -0.24430171994885538,
                                   0,
                                   0,
                                   0.89037791301837532,
                                   0,
                                   0,
                                   0,
                                   -0.29945378359516495,
                                   0,
                                   0.21356967560222642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34318542649805528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39013708276399744,
                                   0,
                                   0,
                                   0,
                                   0.61623407655292484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064063275621206978,
                                   0,
                                   0,
                                   -0.61623490178319529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11202802720227191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49623575526967484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066480286697293695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25076980270711752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90581894742997271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34006613410827352,
                                   0,
                                   0.39319049444176779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18255765876073859,
                                   -0.5829121180895952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095266929694857158,
                                   0,
                                   0,
                                   0,
                                   -0.15517398401524468,
                                   0.46396580635173984,
                                   0,
                                   0,
                                   0.081381873032861554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11186671414598541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33562278938234025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39844986189638121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45682771615272089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6758316205853091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59959042839426413,
                                   0,
                                   0,
                                   0,
                                   -0.57097016164147263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27686706035918818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57125508372370737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27052174884829883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15500731708012777,
                                   -0.76522988046635865,
                                   0,
                                   0,
                                   0,
                                   0.028898944207755906,
                                   0.17739801368076077,
                                   0,
                                   0,
                                   0,
                                   0.28637191674279072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061074371752968218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3684455815580302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22146292060425093,
                                   0,
                                   0,
                                   0,
                                   -0.1198825070757143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11844946658385072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29021527393601032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55991496098880567,
                                   0,
                                   -0.87950339628956276,
                                   0,
                                   0,
                                   -0.3145386139509686,
                                   0,
                                   0,
                                   0,
                                   -0.27689773159515635,
                                   0,
                                   -0.18347242646756515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58848089842913009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10381225913489822,
                                   0,
                                   0,
                                   0,
                                   0.26156174303899937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59282474037216426,
                                   0,
                                   0,
                                   -0.098846144029801047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52861957304077634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57981685879287748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095514001434582302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37555022921416537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64810350624688695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30753066112662403,
                                   0,
                                   -0.062035761513980693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24867307712429926,
                                   0.3896151931788932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0044148501354679681,
                                   0,
                                   0,
                                   0,
                                   0.068290247058502659,
                                   0.18316908101803084,
                                   0,
                                   0,
                                   -0.38949658736162501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54511681251007216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17168313411946379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47053808146852538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34076851867322078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68740755342561832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31977648669197756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16635042221246843,
                                   0,
                                   0.16900918394112038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49516210291564633,
                                   0.5363247763055039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43709688838945338,
                                   0,
                                   0,
                                   0,
                                   -0.3301457086938055,
                                   0.33489818458817167,
                                   0,
                                   0,
                                   0.082070768502925051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52421330431486457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55411858931919666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069986030503264476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085814084158526927,
                                   0,
                                   0,
                                   0,
                                   0.14252777086324556,
                                   0,
                                   0,
                                   0,
                                   0.50889017306422935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19825756032536943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53407462981394305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27724599784249027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05702305178985255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24271982534733194,
                                   -0.12788637678383474,
                                   0,
                                   0,
                                   0,
                                   -0.67700314313725884,
                                   0.13997119313112694,
                                   0,
                                   0,
                                   0,
                                   -0.4489039802957801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17338007098219474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20219197133790454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41282502147962685,
                                   0,
                                   0,
                                   0,
                                   0.02595799846695436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63937064160251322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16436191131850628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017319077157521373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29674794528046489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27760169650133976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55749961825627603,
                                   0,
                                   -0.020138794144892724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055774458549277317,
                                   -0.43566805173067313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10091502813152954,
                                   0,
                                   0,
                                   0,
                                   0.63693906426264491,
                                   0.076406615857390447,
                                   0,
                                   0,
                                   -0.57363536851129515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26561380883519597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26752804447710454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26486262428794416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52735525356585233,
                                   0,
                                   0.3877681727198844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87024041912208872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31542681565176134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4699146423675587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54091100901883149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35636806452443809,
                                   0,
                                   0.054089247813612844,
                                   0,
                                   0,
                                   0.48763179672441698,
                                   0,
                                   0,
                                   0,
                                   -0.46589165506358543,
                                   0,
                                   0.11010136854316656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38704204739438641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0310152852531229,
                                   0,
                                   0,
                                   0,
                                   -0.34237454892708563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45569867065903658,
                                   0,
                                   0,
                                   0.16954332205853637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54438526289306099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62971403611938548,
                                   -0.014391824857600932,
                                   0,
                                   0,
                                   0,
                                   0.17021573161495657,
                                   0.040870872168603273,
                                   0,
                                   0,
                                   0,
                                   -0.066956348682535818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073220520793418647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10968039714057976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20548755400492863,
                                   0,
                                   0,
                                   0,
                                   -0.46060248424570743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035952122216847002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20804071166067092,
                                   0,
                                   0,
                                   0,
                                   0.46494616064060557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14097574485508604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14061071711246603,
                                   -0.57724927817130134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35526224539016166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27525438962821253,
                                   0,
                                   0,
                                   0,
                                   -0.11189588117136558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38511282017166115,
                                   0,
                                   0.058454906658085282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012787523076069583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46259598692159559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098511672294939318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63773986616191547,
                                   0,
                                   -0.48800539147489508,
                                   0,
                                   0,
                                   -0.17644201398713985,
                                   0,
                                   0,
                                   0,
                                   0.45133372039299741,
                                   0,
                                   0.24221234267679664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28875793880735651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16496832167682973,
                                   0,
                                   0,
                                   0,
                                   -0.58748508914908704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51603124532286171,
                                   0,
                                   0,
                                   0.099919034688097486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43252052072864466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19638578386706135,
                                   0,
                                   0,
                                   0,
                                   -0.11078242778145561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13349621936805539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01490998427286723,
                                   -0.079540045198454465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27156101460357518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15283757532535866,
                                   0,
                                   0,
                                   0,
                                   -0.093776077196617472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21681625043862757,
                                   0,
                                   0.74888518216223987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15485071997558372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22009337906351201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16579806006211009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00012191575740805316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038352795939065376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0031372764414416832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074299631381363473,
                                   0,
                                   -0.3468539766235692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64498799948952334,
                                   0.05993539171341742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74000756079616559,
                                   0,
                                   0,
                                   0,
                                   -0.21756440764670459,
                                   0.46884430088207585,
                                   0,
                                   0,
                                   0.41032928833241011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62259055921986872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15148144317184511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1257747716194062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4106288975034541,
                                   0,
                                   0.5750889629577568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80446323428536326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19499636951652749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56853879059439827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22610295011467046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33085423230850575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33889848322057387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072314699430009857,
                                   0,
                                   -0.6293607700036552,
                                   0,
                                   0,
                                   0,
                                   0.22181538243801999,
                                   0,
                                   0.25753453976295559,
                                   0,
                                   0.54195060263864758,
                                   0,
                                   0,
                                   0.053839687825583224,
                                   -0.039831016354553106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34009662568587895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48428363862751894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0082043557177219478,
                                   0,
                                   0,
                                   -0.30384233086975043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21605981986726291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24761985120107791,
                                   0,
                                   0,
                                   0.04400227793746031,
                                   0,
                                   0,
                                   0,
                                   -0.060245866704362293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17358337212611047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045821902698248908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098811206041812455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29534655068906635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52621779615132425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76159333500839654,
                                   0,
                                   -0.20970821842306872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86962898804866384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15970861408072032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25683628073764625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094427933620673879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12704343794700046,
                                   0,
                                   0,
                                   0,
                                   0.41046035807640235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098026043751601316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6272943710804002,
                                   0,
                                   0,
                                   0,
                                   -0.39420165495107423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42196264346341317,
                                   0,
                                   0,
                                   0,
                                   0.34738119007175994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11091201164758073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19047986671329564,
                                   0.1508204882344619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10902038999903138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23353420216067722,
                                   0,
                                   0,
                                   0,
                                   0.29838654148779148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32598009065860661,
                                   0,
                                   0.24292075241949321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3921942239505381,
                                   0.7265812199119025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0061097531160725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052341119794853633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0041961148188837671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.395570141879732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65554529305090892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11046603704803597,
                                   0,
                                   0,
                                   0,
                                   0.44384990952785147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10897152701208057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088960176246742628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1835523532387266,
                                   0,
                                   -0.95798772428664425,
                                   0,
                                   -0.36542190692674648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57693007554896314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9481586712356409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44235656619554964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17743080627158569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10943012661886678,
                                   0,
                                   -0.089827076136693884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66841681471243164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081049636197379676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41489069139871965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67002603401775407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15175097512640681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81098171382680839,
                                   0,
                                   0,
                                   -0.29864548961664761,
                                   0,
                                   0,
                                   -0.06084358210899983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14246033881969491,
                                   -0.25539072397102452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17829938532373987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12501150180408604,
                                   0,
                                   0,
                                   0,
                                   0.1697544330304975,
                                   0.16823097099631237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2026934844505528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082615262930247624,
                                   0,
                                   0,
                                   0,
                                   -0.10701175648264544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52908724663350126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11912496942317602,
                                   -0.24900930799526894,
                                   0,
                                   0,
                                   0,
                                   0.2581605727244744,
                                   -0.15081746353721973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097222341582256622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0014801095058873427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19108514716545733,
                                   0,
                                   0.37072580694394941,
                                   0,
                                   0,
                                   -0.326248839081905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49886682338974897,
                                   0,
                                   0,
                                   0,
                                   0.055054472149537237,
                                   0,
                                   0,
                                   0,
                                   0.091375372871947955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06622012566736904,
                                   0,
                                   0.27096208664334448,
                                   0,
                                   0,
                                   0,
                                   -0.035175205119325217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11527852623692147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0503529395225817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049498490595553869,
                                   0,
                                   0.53927397221300266,
                                   0,
                                   1.1383871108950403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057086228300378128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38322095373461429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15187285532086039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.121983783517731,
                                   0,
                                   0,
                                   0.22451207059401029,
                                   0,
                                   0,
                                   -0.30534948141195839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058863035750334664,
                                   0.12241390299714427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021644342767146385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46791866804769833,
                                   0,
                                   0,
                                   0,
                                   -0.27690695051769409,
                                   0.40853036965497824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4928558016356282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32067832560269149,
                                   0,
                                   0,
                                   0,
                                   -0.11955605764224173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10256492590861166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27144410018233495,
                                   0,
                                   0,
                                   -0.57072994344229455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17531112326522158,
                                   -0.19450432855464167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61326005860129384,
                                   0.2154262917825529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12136034276748325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099988514628438885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2725390280672168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38953971948650518,
                                   0,
                                   -0.52818628817166513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13605893090231919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39351759185725216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26985225963312953,
                                   0,
                                   0.5684097836255938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079922434664853825,
                                   0,
                                   0,
                                   -0.0029237299120905627,
                                   0,
                                   0,
                                   -0.35905979670130916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11932401674568863,
                                   0.23606015749527298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013456725276617877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27336786567512572,
                                   0,
                                   0,
                                   0,
                                   0.39008750849068635,
                                   -0.63547679771980747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2977873167534828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24051675676391307,
                                   0,
                                   0,
                                   0,
                                   -0.13145951940171749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19796188689779845,
                                   0,
                                   -0.2728939498502736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8164046913032792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13229268478695647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22237435696157523,
                                   0,
                                   -0.39098804893086192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15780424558849207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81399410941559658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30662308125172222,
                                   0,
                                   0,
                                   0,
                                   -0.02040708743965523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0620995841716026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29151250048295513,
                                   0,
                                   0,
                                   -0.26221162345249083,
                                   0,
                                   -0.7457703522918111,
                                   -0.35236850705308165,
                                   -0.21379530740737679,
                                   0,
                                   0.42275534902507583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093362124867716834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25856962422346202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48899256094437055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15589592645313985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41141360441941138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33221214821809752,
                                   0,
                                   0,
                                   -0.33273078005975737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25636075132302583,
                                   0,
                                   0,
                                   -0.69862536548312093,
                                   0,
                                   0,
                                   0,
                                   -0.17024158612928383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050795561104725842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72663725004483581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38597130194621176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27441420339372036,
                                   0.40226216226615485,
                                   -0.53629205315796369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53859072604724545,
                                   0.030811797007981097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046929283191336504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31990895845776846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31372788927008161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80790668203874882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073833727385957948,
                                   0,
                                   0,
                                   -0.542699687274806,
                                   0,
                                   0,
                                   0,
                                   -0.29481629629903744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50125152049811816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14016690911221386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22267238780151422,
                                   0,
                                   -0.08927759999564279,
                                   0,
                                   -0.53465144238658135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19534831530888389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65209430410061109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0476350917067871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16978010951058634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16676788695413189,
                                   0,
                                   0,
                                   -0.0018970945959246011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42553761003823393,
                                   0.52410479232855567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30703123947204847,
                                   -0.12463703442357167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058511222373187448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46005308046706528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40338136307497607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090908960380134227,
                                   0,
                                   0,
                                   0.17278516103510239,
                                   0,
                                   0,
                                   0.3640540057323543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15980168609131062,
                                   -0.32504799068709506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32209297046360458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18891202008647301,
                                   0,
                                   0,
                                   0,
                                   -0.0095494888358087782,
                                   0.099261446192521807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40294929468247959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58083544136711585,
                                   0,
                                   0,
                                   0,
                                   0.22144785030756922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21295461983352379,
                                   0,
                                   0,
                                   -0.095735124750342598,
                                   0,
                                   0,
                                   0.30669771532582668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51539974321133419,
                                   -0.13136934625140712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48044453793479669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35333461629904495,
                                   0,
                                   0,
                                   0,
                                   0.34560869516532938,
                                   0.045073804313096835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064910358050331407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1140634987027008,
                                   0,
                                   0,
                                   0,
                                   -0.27231170985370601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10097240398369098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17392013956514221,
                                   0,
                                   0,
                                   -0.059539328493142404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18982014326787167,
                                   -0.68337690492877567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10014358056697543,
                                   -0.52564841560319264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045549743634231893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18140834838568015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36284567588112021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35491349719669762,
                                   0,
                                   0.56829923052628861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36963041264920665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3316047466378938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15357209054006529,
                                   0,
                                   0.52999967655649249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053696342636780754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29877379502608747,
                                   0.062254048217177713,
                                   0,
                                   0,
                                   0,
                                   0.0035502788870863146,
                                   -0.38003577935157751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091217538047969463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28634782021748051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57823243964715387,
                                   0,
                                   -0.032773128354970482,
                                   0,
                                   0,
                                   0.09935404517078629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15381591930458055,
                                   0,
                                   0,
                                   0,
                                   0.45024927821523125,
                                   0,
                                   0,
                                   0,
                                   0.1685935687608896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26289588191657187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43790653261817719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053384290854798074,
                                   0.23326995956412297,
                                   0,
                                   0,
                                   0,
                                   -0.052249650681847309,
                                   -0.26577245143556971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24185202829271646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29643136002723713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066520616208978575,
                                   0,
                                   -0.1879247613072435,
                                   0,
                                   0,
                                   -0.11135613526895606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24423667467720264,
                                   0,
                                   0,
                                   0,
                                   -0.60112721465252905,
                                   0,
                                   0,
                                   0,
                                   -0.0093680429392607456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24085264493633118,
                                   0,
                                   0,
                                   0.2571585549963753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0646939970163605,
                                   0,
                                   -0.54243949601480546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37460314002979789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51611197988763202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90287298238971703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67065312842160418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39260083503059584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067066227879663098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36947209446405455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27102747851089837,
                                   0.40119916116030863,
                                   0.25863233980349937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30659853712317148,
                                   -0.71993114463571439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15861396536972328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62570673649931097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72723688026348554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10732943048427483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41912094820513229,
                                   0,
                                   0,
                                   0,
                                   0.40561886568604044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023751671548694661,
                                   0,
                                   -1.0525612080011695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26414919231337219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1274107446580286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16457480792576529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4873745327476891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43279455278974283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047890862496647306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0027399426588368418,
                                   -0.5686304890568562,
                                   0,
                                   0,
                                   0,
                                   -0.092903733225029539,
                                   -0.47959688622802077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0065223339780766942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052240933795386531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42759988420221839,
                                   0,
                                   0.12739154529576938,
                                   0,
                                   0,
                                   0.35524332658892788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035710381640875213,
                                   0,
                                   0,
                                   0,
                                   0.032141352870262221,
                                   0,
                                   0,
                                   0,
                                   -0.17705167649220227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2720637977550302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13624763586081473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012870428448634331,
                                   0.64961142849389997,
                                   0,
                                   0,
                                   0,
                                   0.21497876726920273,
                                   -0.21421394777820774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11472893742325954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056334595358166643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23540141096758349,
                                   0,
                                   0.49553860159870416,
                                   0,
                                   0,
                                   0.2454920528265479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20549601637741188,
                                   0,
                                   0,
                                   0,
                                   -0.032780223688037437,
                                   0,
                                   0,
                                   0,
                                   0.12238593402170689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17696319851580739,
                                   0.42290635793484677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84114049186656037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45742124974781645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0098659050426089193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04130149380502212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38713287171499222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42402398687152226,
                                   0,
                                   0,
                                   0.27340121253944949,
                                   0,
                                   0,
                                   0.038916020335016732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55544068184195339,
                                   0.48700135362522229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24983166128447237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026699013841653227,
                                   0,
                                   0,
                                   0,
                                   -0.16813221001966802,
                                   -0.038193502884965369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072159175441865439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11653543424071254,
                                   0,
                                   0,
                                   0,
                                   -0.29430082459933676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24291025194585239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13945843188803325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63450476115985077,
                                   -1.030125810482871,
                                   -0.47418140193769104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14564779993876942,
                                   0.26236984849130973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20086347403024579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51362533241230379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34046065317361329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51192279622031478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061203553615883477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49128777787851008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15733107302463148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43146069483794552,
                                   0.30752343421128853,
                                   -0.23342329137354517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60267860157519137,
                                   0.57566447390552933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16102999059755585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88759412413409056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34074156474233819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12601161567345209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79787355040856967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21293730957617996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81916920704283303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039504969394028852,
                                   0.37240560264710032,
                                   -1.0918953089744237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24584488331580451,
                                   0.22395944135135781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23326606795720267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47144309733737416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51619245698969241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17024924732386348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28662150316824397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058586184557623967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056074584111544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17427126478059818,
                                   0,
                                   0,
                                   0.46275701386758389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47076210467930846,
                                   0,
                                   0,
                                   0.035901056851483246,
                                   0,
                                   0,
                                   0,
                                   -0.61056854866731902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39141918026198447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45832739652247584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050089895744058602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30919249056914244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90020764481137261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35796621657274663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14585813390832858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9241960348862287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045935812375076934,
                                   0,
                                   0.30175778264284486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28828839325025746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90358436319744173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45179054798279933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14168958654615779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52717494894307981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78810213831113973,
                                   0,
                                   0,
                                   0,
                                   0.66589391825692279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10629502135067825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1815420857443214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040716220009304922,
                                   0,
                                   -0.23321128865446353,
                                   0,
                                   0.3232752839405445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66747715750389491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59951417277354846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.259305458909596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37010349904856488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40938434108635136,
                                   0,
                                   0,
                                   -0.14102147910401736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49435275362384656,
                                   0.079249937894699279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49903564165602898,
                                   -0.29150596323132821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11015504186860627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085582170868822083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26721689048909125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17471097824520723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61549493522638898,
                                   0,
                                   0,
                                   0.49303381242021349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27521220633699506,
                                   -0.25154231144386319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16240150067527537,
                                   0.073600964001095989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11306182172350768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38678827551152234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11985378888533074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1069477590175732,
                                   0,
                                   0,
                                   -0.093151696984499738,
                                   0,
                                   0,
                                   -0.35531652072406783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067090456213348998,
                                   -0.21739320382395949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067466414437350908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36411780323278975,
                                   0,
                                   0,
                                   0,
                                   -0.25600398873664643,
                                   0.12695716573975144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5385414994632115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44167890039001478,
                                   0,
                                   0,
                                   0,
                                   -0.31301329096884301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12991187326747636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098098426339097086,
                                   -0.030546838927808163,
                                   0,
                                   0,
                                   0,
                                   0.023750058390161519,
                                   0.38139520567586027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30799643461634241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21594998128378476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2786733889953692,
                                   0,
                                   0.37774041020100385,
                                   0,
                                   0,
                                   0.24668242494605983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16843101511633737,
                                   0,
                                   0,
                                   0,
                                   -0.062148937245747542,
                                   0,
                                   0,
                                   0,
                                   -0.53445479276917451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29320915989857993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55858513436834811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47395733384411592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10612835955145257,
                                   0,
                                   0,
                                   0,
                                   -0.16983592187982804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12096758860379368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30697286920618921,
                                   0,
                                   0,
                                   0.3665783542345657,
                                   0,
                                   -0.88367421601111795,
                                   0.17033505058098897,
                                   -0.51626346825172431,
                                   0,
                                   0.73144057920085093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0276777862980662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1532445249396899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27471104571405963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12238715092745443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31459435647715395,
                                   0,
                                   0.76616716288610642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11712746927201012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21100481711409172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049575629032612596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31997458647999488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70417280023384876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0067886938112155168,
                                   0,
                                   0,
                                   -0.39218439405985084,
                                   0,
                                   0,
                                   0.47587706947801472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2129349818550956,
                                   0.1999910298104578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12733847936761361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19770145720570323,
                                   0,
                                   0,
                                   0,
                                   -0.57588634972251451,
                                   -0.32633518146145951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12233173900118727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016663201929810453,
                                   0,
                                   0,
                                   0,
                                   -0.16020362450412082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10362378376096767,
                                   0,
                                   0,
                                   -0.57339693414501325,
                                   0,
                                   0,
                                   0.088266178454046412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0031858158373049557,
                                   0.33620052237215242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52971532885940864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20752888293908256,
                                   0,
                                   0,
                                   0,
                                   0.32327203430290485,
                                   0.29938799376422232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077317391223938575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097535876581707717,
                                   0,
                                   0,
                                   0,
                                   0.079689625209964796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0448780578787367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31905268595939568,
                                   -0.073463574192829881,
                                   0,
                                   0,
                                   0,
                                   0.45348302769446436,
                                   0.35007923417472625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44058744833696434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3374996959959346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36668206803540776,
                                   0,
                                   -0.07616356103299525,
                                   0,
                                   0,
                                   0.15710355708958376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0048016196962516328,
                                   0,
                                   0,
                                   0,
                                   0.18244953078030937,
                                   0,
                                   0,
                                   0,
                                   0.22570308016226234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073333851710317699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2607291876538903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19790884141264542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97793129457372474,
                                   0,
                                   0,
                                   0,
                                   -0.03796880982329158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36801010465612577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5554785923429183,
                                   0,
                                   0,
                                   -0.10710397392137655,
                                   0,
                                   -0.50729869230032543,
                                   0.72150318154708548,
                                   0.48680679943453548,
                                   0,
                                   -0.047229039133378684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085443544279086903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0021126386774209423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24185875677357008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32771999193975265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39732105045499089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31426011975253859,
                                   0.53682810095386146,
                                   0.13427369447077217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32363006150962792,
                                   0.69680345077715333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28726326305798167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26216889599845328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37288183653417561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1110351780436868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79984456941777871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4766649126177146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76152547320166564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042062969507431915,
                                   0.37487200116014596,
                                   -0.16342496325645661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36017851137930917,
                                   -0.35802483719599915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50166109290118854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14743030268943919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22922592176588449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41451193739633424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039855664246028717,
                                   0,
                                   0,
                                   -0.5443033972114375,
                                   0,
                                   0,
                                   0,
                                   -0.10915672622386981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39166415294392659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43018844198575007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15626630658012072,
                                   0,
                                   -0.17250226948007066,
                                   0,
                                   0.69846928452957757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61894229612408713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067203440399497605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65292927561813596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44913038113936476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020575721755901562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54374093751799879,
                                   0,
                                   0,
                                   0,
                                   0.13579617512271647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52122475646802757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55868554271922155,
                                   0,
                                   0,
                                   -0.20148807389989998,
                                   0,
                                   0.22378983120186663,
                                   -0.72741926906198129,
                                   0.18261811042250922,
                                   0,
                                   0.77216531472039041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54859538774150562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50157718693854636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2711714704959553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14659104424879499,
                                   0,
                                   0,
                                   0,
                                   0.16045175426767916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2483370272321637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2766653530352855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7816663232805009,
                                   0,
                                   0.24141932680479491,
                                   0,
                                   -0.12280202081026406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23025404547874384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0099131854905660788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22421010878545769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24186782138151508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66287151873254635,
                                   0,
                                   -0.0093781036371512055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082719759850688412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52212146917606861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75853808568028813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42690200902627362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23202181692291118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69181128659112001,
                                   0,
                                   0,
                                   0,
                                   -0.51849000261678801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54543054249074963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9358857640681042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44379958821247306,
                                   0,
                                   -0.14964053869832006,
                                   0,
                                   -0.43009439730804333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37606940728305954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51448955405163099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32274949100355271,
                                   0,
                                   0,
                                   0.25441229872951271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56111604011892813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71444240632003508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52747257632905176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62496002394439742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1895249393581013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14724247128234563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22390058158122883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27980701139882969,
                                   0,
                                   0,
                                   0,
                                   0.43089225951474902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85013620337594864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091824744246311513,
                                   0,
                                   0,
                                   0.3232453220360072,
                                   0,
                                   -0.098494407975050588,
                                   -0.11584434913462208,
                                   0.75118979883347814,
                                   0,
                                   -0.75793572890483518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35607206772477473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2853780497387014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46067846250595812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18184301070449804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074249675773108315,
                                   0,
                                   0,
                                   -0.43173837017108574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12684655676905535,
                                   -0.10064915202674711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40727083059051244,
                                   0.43478009832929732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11610141590419967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59873486775987894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14810651592736165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14798740873320501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31837067945020014,
                                   0,
                                   0,
                                   -0.11025221031557048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13094271679613345,
                                   0.098429500981925572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089254017116473627,
                                   -0.38311185248256308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2060620992062896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45629085007403125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65753024723068543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93411476484008438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32654044871481963,
                                   0,
                                   0.4305379517517548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32708530190117202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70848358590787164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33569775716442307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65762435559905641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16292557501930482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10176230482693552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4722694426595922,
                                   0.056006887729675742,
                                   0,
                                   0,
                                   0,
                                   -0.48855544152406671,
                                   0.064808753832478708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4403317604495316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015366230286487441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10824978789443326,
                                   0,
                                   0.24482368031084534,
                                   0,
                                   0,
                                   0.051574277997458409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.212631372028803,
                                   0,
                                   0,
                                   0,
                                   0.23567569625883678,
                                   0,
                                   0,
                                   0,
                                   0.38858381932595493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019631226967908231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21783962838251503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61663754645707558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74941496015940412,
                                   0.169858648288856,
                                   0.58477992244456489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27592756751039088,
                                   0.34886636808629251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29212599970113262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11796550170509182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50325660214782419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12050537208991496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35211706196570963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30752873886520399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29447932070110133,
                                   0.020793922462636269,
                                   0,
                                   0,
                                   0,
                                   -0.40068085961597533,
                                   0.34711459313616755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28508954870715647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062821140035964576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11676378156963085,
                                   0,
                                   -0.14976093239386151,
                                   0,
                                   0,
                                   0.064443997644203416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33189113297319428,
                                   0,
                                   0,
                                   0,
                                   0.09857275744302027,
                                   0,
                                   0,
                                   0,
                                   0.23300732041564839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48748693149472944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099521021383057101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29023723676294416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65982138252634459,
                                   0,
                                   0,
                                   0.25089294697069758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23812279898195191,
                                   0,
                                   0,
                                   0.17237387090065431,
                                   0,
                                   0,
                                   0,
                                   -0.1842037403675551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53591057863303404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29492520207057116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27602709583529095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68226420464108883,
                                   0,
                                   0,
                                   0,
                                   -0.3125717324690504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24624047205809038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077488734167852721,
                                   0,
                                   0,
                                   0.53767068404914153,
                                   0,
                                   -0.14302532518050204,
                                   0.23839064177098668,
                                   0.59406161818212533,
                                   0,
                                   0.31816112162045901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15056166077867489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29270156545214709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6778427624330523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31933836384483194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073922459201901755,
                                   -0.07995715450758592,
                                   0,
                                   0,
                                   0,
                                   0.082718456121189499,
                                   0.017450010125963335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19952184799247386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077191918623672362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25612265338089146,
                                   0,
                                   -0.070006237705786026,
                                   0,
                                   0,
                                   0.7277105489498954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0367600817657667,
                                   0,
                                   0,
                                   0,
                                   -0.20594762298638836,
                                   0,
                                   0,
                                   0,
                                   0.26854323838261374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34250167741218707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18792506520462704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05308122604650542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53015882701872952,
                                   0,
                                   0,
                                   -0.21346108075808734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54541011241406301,
                                   0,
                                   0,
                                   0.14285266503744004,
                                   0,
                                   0,
                                   0,
                                   0.084288085582423039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55699998423876207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51392831503974312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62375536879800564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091570402814135282,
                                   0,
                                   0,
                                   0,
                                   -0.2301031853169061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17176591459767288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0050302048019625969,
                                   0,
                                   0,
                                   0.70826276540073929,
                                   0,
                                   0.21203785074571765,
                                   -0.30647038597316589,
                                   -0.92414867213992169,
                                   0,
                                   -0.297235816142779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14037291254131451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59422026591428889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092252635004281436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39973093917729241,
                                   0,
                                   -0.017945774470474813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39433796202181232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39744658615634554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60671996908464587,
                                   0,
                                   -0.39789167799562125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5166475631163634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23133773193323029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24881038479652778,
                                   0,
                                   0,
                                   0,
                                   -0.33829932761126169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42904750715898093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48633711614156555,
                                   0,
                                   0,
                                   0.19528132231245207,
                                   0,
                                   -0.70380840549492107,
                                   0.023940539621293527,
                                   0.24812335464725754,
                                   0,
                                   -0.25582559534170768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49511747238949166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6738120407724818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47312042714633173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17167988909976184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55637611733410253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083544415180929532,
                                   0,
                                   0,
                                   0,
                                   0.56330347363132949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54484598828454744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38060571439013724,
                                   0,
                                   0,
                                   0.058517497378671568,
                                   0,
                                   -0.29491531336612675,
                                   0.13141290929764024,
                                   -0.19450952258353058,
                                   0,
                                   -0.17323172943881354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1737077874174509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073306784013540807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61851405745186505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31343971780262098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72153224740076549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0010907114500923291,
                                   0,
                                   0,
                                   0,
                                   0.2774111376060947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1806765715927024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98959653046365414,
                                   0,
                                   0,
                                   0.05229050940988756,
                                   0,
                                   -0.016931729940865545,
                                   0.28583076072963842,
                                   -0.067662749723339924,
                                   0,
                                   -0.29666970493125444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0057630243011984935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3737946269877449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55485562148008249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18985612358104353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30248467939925272,
                                   0,
                                   0,
                                   0.16563711015550525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35106191541922444,
                                   -0.15969702117442031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10260304464504121,
                                   0.39896860253895861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72553761139665318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0044455743730327235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012103409108892349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.644433136618484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13576335945539325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2127924001007237,
                                   0,
                                   0,
                                   0,
                                   0.80411622043739306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16350084250299854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32547329107167955,
                                   0,
                                   0,
                                   -0.10102164848340225,
                                   0,
                                   0.51558786961054492,
                                   0.72226138254387395,
                                   -0.63497151728752066,
                                   0,
                                   0.11040010511792271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51486878963251803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39466645520604576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37620680772528259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90080305782634995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094731119633018918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1131422404025581,
                                   0,
                                   0,
                                   -0.10823696869086744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25227743691846305,
                                   0,
                                   0,
                                   0.2106460878328795,
                                   0,
                                   0,
                                   0,
                                   -0.21688617113626879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0028578490994232778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051049157439489901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29122256612901098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39083403562477348,
                                   -0.36876009826758166,
                                   -0.21956496091941902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30614037501741331,
                                   0.42090647175940776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20247979285492362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32418178219387067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58897461641875304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55128943112982054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54614192559943397,
                                   0,
                                   0,
                                   -0.2093739590304339,
                                   0,
                                   0,
                                   0,
                                   -0.6479705263268124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20045780466182195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93302513011958976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64104572422241834,
                                   0,
                                   0.57849696521382588,
                                   0,
                                   0.21515763492693174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0136483499603728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13195904323014279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16883427119822081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18415062499850796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71875156279405972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14849413082852833,
                                   0,
                                   0,
                                   -0.19894159453164501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10682885681803085,
                                   0,
                                   0,
                                   0.56750990128517109,
                                   0,
                                   0,
                                   0,
                                   -0.22727437754104235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052181778199122238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019563798722979704,
                                   0,
                                   0,
                                   -0.35566135481066802,
                                   0,
                                   0,
                                   -0.31873926972176903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49196134160023663,
                                   -0.43570434557667753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25792206462089023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074511368995873128,
                                   0,
                                   0,
                                   0,
                                   -0.25945746619417343,
                                   -0.30582311169419868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15166579481484715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28021540542500162,
                                   0,
                                   0,
                                   0,
                                   0.072238655407012575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40731445786068077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11103505256986948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055703243218652165,
                                   0,
                                   0,
                                   0,
                                   -0.77293011801991596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2516529637327104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59289878269521545,
                                   0,
                                   0,
                                   -0.17781073696632249,
                                   0,
                                   0.44408257064800544,
                                   0.67865209945660632,
                                   -0.21586583120897057,
                                   0,
                                   -0.27897676266363119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23430875754494956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48189508739306824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30575264958732556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34492566579165457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32222441903389432,
                                   0,
                                   0,
                                   0.4125874739269591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36212846952655808,
                                   0.03168304770837424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11256019628307064,
                                   0.16960894878606475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59939979771858876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13103687586013929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23862243738889685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089646772507451178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36062216950460763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21196719417528379,
                                   0,
                                   0,
                                   0.62793373358471172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39556785010132506,
                                   0,
                                   0,
                                   -0.27552033166690898,
                                   0,
                                   0,
                                   0,
                                   -0.022341809853491667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4356600833189242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44135687700609372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097445208034404138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56433422732619698,
                                   -0.83470625002040622,
                                   -0.28344807472523903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76457597739497241,
                                   -0.13404230468240999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34904588153819532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13020013783581105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28661881490455199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59472986336467615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34598085107133081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40250593658755079,
                                   0,
                                   -0.51662814008725222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14604038696069782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6862288771465066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073093761212205177,
                                   0,
                                   0.27111578983938456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25026976094756725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010787369835174559,
                                   0,
                                   -0.64536410066900096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66504087565795333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1893113098808934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24609735031938024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53231991289261327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93731046682008379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60109105388623618,
                                   0,
                                   -0.23739721092385357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038916352210161709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29800500294602045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69332041476488637,
                                   0,
                                   -0.10638349215716184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27138480017745675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29139847935244551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25109801130806059,
                                   0,
                                   0,
                                   -0.34790731104607953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35631069868795778,
                                   0,
                                   0,
                                   -0.13477151778140611,
                                   0,
                                   0,
                                   0,
                                   -0.67675397302828999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23287527152398169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22873577161218658,
                                   0,
                                   0,
                                   0,
                                   -0.40194382981803906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51193368832946673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063327582290846021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97077592149959335,
                                   0,
                                   0.18461703159789797,
                                   0,
                                   -0.19541068766977737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63054491384169864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37873300942906352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24096590044725497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33030798105022213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50949015208949522,
                                   -0.099805992728611695,
                                   0,
                                   0,
                                   0,
                                   0.11439639614148622,
                                   0.23272287789992574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024723637675685181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47969817990830665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22541852203262464,
                                   0,
                                   -0.067086541444189712,
                                   0,
                                   0,
                                   0.1191499679738683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29737107011879282,
                                   0,
                                   0,
                                   0,
                                   -0.22277306749477954,
                                   0,
                                   0,
                                   0,
                                   0.037838135025447368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33821171562357127,
                                   0.69811247717041647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26516206242737306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70495673451142793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57600991292106274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23863465234464137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33010973351415912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2015575996928835,
                                   0,
                                   0,
                                   0.073734513971699042,
                                   0,
                                   0,
                                   -0.054561417317297925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12601495072410598,
                                   0.14383998592168895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17187987800503102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45573121404932948,
                                   0,
                                   0,
                                   0,
                                   -0.095095293773053993,
                                   -0.1312623345485236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26851644363987964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045653608536938659,
                                   0,
                                   0,
                                   0,
                                   0.75940714907848406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75694978817991554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14010832243539911,
                                   0,
                                   0,
                                   0.10738601973807893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3800106856843144,
                                   -0.32341703571016978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21718971232580314,
                                   0.21818907029316592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1150223698833775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068115970872724307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18496066096506081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41146736750055368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39110368202068385,
                                   0.20199911011281677,
                                   0,
                                   0,
                                   0,
                                   0.18983927486282204,
                                   0.032810197197095492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29932108999108503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20696431529870091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17770415570907333,
                                   0,
                                   -0.18324119522126778,
                                   0,
                                   0,
                                   0.051337939223279977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19896081058508874,
                                   0,
                                   0,
                                   0,
                                   0.47243539446859201,
                                   0,
                                   0,
                                   0,
                                   -0.36481544604298122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06102024673498832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085389770282394389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035373197728984743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1355790989784505,
                                   0,
                                   0,
                                   0,
                                   0.33825837638441258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42660865624274896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61884227266238068,
                                   0,
                                   0,
                                   0.55710557709669895,
                                   0,
                                   -0.026770959975438973,
                                   0.82766940503005759,
                                   0.032084998282276803,
                                   0,
                                   0.53860575347687645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10547422787141848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3712258090360358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78197382553079831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1562067985341988,
                                   0,
                                   0,
                                   -0.35132156915168511,
                                   0,
                                   0,
                                   -0.28451915060338917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23357190331484706,
                                   0.30523166622694375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41610269719857618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31854285919186365,
                                   0,
                                   0,
                                   0,
                                   -0.12838799053725755,
                                   0.25421205972397043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22241675982204204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42784919590726644,
                                   0,
                                   0,
                                   0,
                                   0.18776803595138158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0042195281693499995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31352162789529153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11129177068990295,
                                   -0.12378818655918841,
                                   0.1272102635455539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48512174519986906,
                                   0.27942322621875881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90462782359639715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16499350868981272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51869008977980091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32790265577378425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019638483451878429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0057020517984662233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12575153374876344,
                                   0.22182647383505749,
                                   0,
                                   0,
                                   0,
                                   -0.41971913371097708,
                                   -0.075472081679500286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23010054871116625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31980893830111068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0076364913602952889,
                                   0,
                                   -0.08867800803711777,
                                   0,
                                   0,
                                   0.1781619002436356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47762718618667949,
                                   0,
                                   0,
                                   0,
                                   0.068826071544444617,
                                   0,
                                   0,
                                   0,
                                   -0.40991467258359449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39661604141047752,
                                   0.30724514301177586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.229776558053813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55435640161374244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30197616929575943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64778252768290201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30975864884186455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4010596844983817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20632999306442462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29734154012883168,
                                   0,
                                   0,
                                   0,
                                   0.68884395229064965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23322742830343268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068219979950044696,
                                   0,
                                   0,
                                   -0.6706303079510938,
                                   0,
                                   -0.55332372586291578,
                                   -0.11450080975813026,
                                   -0.21269621953103141,
                                   0,
                                   -0.29317181786655455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18805881657010734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67839434377565999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33088263555898167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40486954026355598,
                                   0,
                                   0,
                                   0,
                                   -0.15707162838584121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62882129848962587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011451623388551159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39259774666367664,
                                   0,
                                   -0.99172703944607676,
                                   0,
                                   0.47073906506014401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14753052479721807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63343979630560265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15809860494526856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72551333600489465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043722100758134944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62313062838625188,
                                   0.14670031203064959,
                                   -0.013973332106271087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071957613662991693,
                                   0.64670427159067434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48468549386499959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025116864475493134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38461689192106852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34299794396767114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23389107560364356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018039297423798985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19627971240479528,
                                   -0.13455151561446405,
                                   0,
                                   0,
                                   0,
                                   -0.19542016755614181,
                                   0.17985449980904217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40425571932833687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52756469301122488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030617544170374062,
                                   0,
                                   0.53168335669575462,
                                   0,
                                   0,
                                   -0.11976153273432963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28821395024874624,
                                   0,
                                   0,
                                   0,
                                   -0.091643972263726392,
                                   0,
                                   0,
                                   0,
                                   0.016499419668996269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20262105724928314,
                                   -0.14770384357349153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083898806160555964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30115572837492904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62259011701914213,
                                   0.074176200278028737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32412377325809699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045496409332633547,
                                   0,
                                   0,
                                   0,
                                   0.16169613383008441,
                                   0,
                                   0,
                                   0.30320780905782124,
                                   0,
                                   0,
                                   0.23325800678803688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13798520847783263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43436534780752628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2059339088318406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27473745474927802,
                                   0,
                                   -0.40587951124611388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0163123267731669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3033262751690986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34581251791778356,
                                   -0.35362666214542954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6023012629158806,
                                   0,
                                   0,
                                   0.20160647412626273,
                                   0,
                                   -0.45393136612870505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073732087967298396,
                                   0,
                                   -0.59552773991524421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1249694150255366,
                                   0,
                                   0,
                                   0.4096832054000884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.154037096962853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18078563453317575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85760174361999675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18292472681546493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39427688057604532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46595172757889369,
                                   0,
                                   0,
                                   -0.62210611107775005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31639721400644438,
                                   0,
                                   0,
                                   0,
                                   0.18515137494536629,
                                   0,
                                   -0.27520221556357682,
                                   0,
                                   -0.66384690241265232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16602920714635597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5443932083910874,
                                   0,
                                   0,
                                   0,
                                   0.79733238496367276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066909456677318374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39528186213552835,
                                   0,
                                   0,
                                   0,
                                   0.024808965990711529,
                                   0,
                                   0,
                                   0.030253193606848867,
                                   0,
                                   -0.21924518429772877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14926959883045013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25669963804199136,
                                   0.28860994341315427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33009139498883583,
                                   0,
                                   0.44588333019481424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25383465017262424,
                                   0,
                                   0,
                                   0.20454625580099661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18311006959626458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32030817270527351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20812935481741091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44679190534664703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66624392703780511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32385355956205536,
                                   0,
                                   0,
                                   -0.67762615890366873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10467362677276401,
                                   0,
                                   0,
                                   0,
                                   -0.88559360509194607,
                                   0,
                                   -0.017992694204458221,
                                   0,
                                   0.32479281735654658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15102346871199984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16461303029919402,
                                   0,
                                   0,
                                   0,
                                   0.18456860541717798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23992942203037371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29956958205427575,
                                   0,
                                   0,
                                   0,
                                   -0.5818107605945213,
                                   0,
                                   0,
                                   0.19408834499467215,
                                   0,
                                   -0.11014089788248524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46566206158875945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52240039714541842,
                                   -0.27626833491648189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21727199746114173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13857304921270672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28840556701786674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094300555607579536,
                                   -0.75908681765551145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16460497612637232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30675383112358728,
                                   0,
                                   0,
                                   0,
                                   -0.022494233189984635,
                                   0,
                                   0,
                                   0.25406184895657818,
                                   0,
                                   0,
                                   -0.1177962999330353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25287483918529924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035205813020930246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20741148117344807,
                                   0,
                                   0.12331194347346694,
                                   0,
                                   0.26982076513537923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36178618472810486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17111776256244765,
                                   0,
                                   0,
                                   0,
                                   -0.041095984305340269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61586975210926931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11512393404725312,
                                   0,
                                   0,
                                   0,
                                   -0.18628076809430144,
                                   0,
                                   0,
                                   0.57761740276781981,
                                   0,
                                   0.0079184293654938741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86684660927473933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4486932587676199,
                                   -0.039932179237066212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23457226188466551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85900316652482367,
                                   0.60355068539082379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0046019874309380995,
                                   0,
                                   0,
                                   0,
                                   -1.2568116901906394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076262940893654652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11663965823306649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021742689367061682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10400542795886888,
                                   0,
                                   -0.17225448269677712,
                                   0,
                                   -0.43116565604662793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47226723838349483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76455547920817313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.473731119072208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46682811837139293,
                                   0,
                                   -0.68374060605329112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13609237537601707,
                                   0,
                                   0,
                                   0.045358548264911785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87324287818031021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59402484280982992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76052687441410771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17083285194354014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1444657608098012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37080948210920123,
                                   0,
                                   0,
                                   -0.070814338653032396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29545166454931598,
                                   0.40193524731426844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69314109973497962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092065405360122921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013936781173287963,
                                   -0.04972161149073541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20973351046588015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35639856408791937,
                                   0,
                                   0,
                                   0,
                                   0.30081731632154024,
                                   0,
                                   0,
                                   -0.08551991007153531,
                                   0,
                                   0,
                                   -0.18153228175953973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15788679375448886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14200689337163483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50745813083808367,
                                   0,
                                   -0.4228480826398136,
                                   0,
                                   -0.62076612561879119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0031876066774844808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3955698133892761,
                                   0,
                                   0,
                                   0,
                                   -0.31637614474464554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33718720040140926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83928518515432482,
                                   0,
                                   0,
                                   0,
                                   -0.34630249314895378,
                                   0,
                                   0,
                                   0.03808409520002444,
                                   0,
                                   -0.11901401595554253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35372244595383695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22807456371053442,
                                   -0.31802108900284093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11984354784860408,
                                   0,
                                   0.59581038898225724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91170548925814743,
                                   0,
                                   0,
                                   -0.085358687738098349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66113527490323165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093159927650892857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096949965795593798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048143616173343312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40451800687494538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27173703165029828,
                                   0,
                                   0,
                                   -0.19280020595518468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18245704731374299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25620659114892186,
                                   0,
                                   0,
                                   0,
                                   0.025120236708529836,
                                   0,
                                   0,
                                   -0.10009647745026914,
                                   0,
                                   0,
                                   -0.66046591788313747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052265681638661063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54761572183875618,
                                   0,
                                   0,
                                   -0.42761748931120108,
                                   0,
                                   0,
                                   0,
                                   0.044958040765121055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37784126343903651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43252961586736749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21482039994137919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34624943118658175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11698304741542344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069960237339260725,
                                   -0.16271624670887894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27114610514173154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032744814622371984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44966582688893625,
                                   0.29961812130546828,
                                   0.19200213099961652,
                                   0.23254798216747502,
                                   0.039438598544493358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39770106802830085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39308199404999483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48773259097390897,
                                   0,
                                   -0.16971622278068721,
                                   0,
                                   -0.53423600183261133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82155929234951797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2815108244585699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51604796714400902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25616570770659197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2074969698174331,
                                   0,
                                   -0.27523490075812135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5447477817377645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79128045474010744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22232646483569293,
                                   0.55318199677272584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34345343090950509,
                                   0,
                                   0,
                                   0.44752309301732618,
                                   0,
                                   -1.1176154555105471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2741548648531178,
                                   0,
                                   0,
                                   0,
                                   -0.5096367677637349,
                                   0,
                                   0,
                                   -0.47174197155605369,
                                   0,
                                   0,
                                   0.39326224123394732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31507452723741314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34501728364637824,
                                   0,
                                   0,
                                   0.012964762590970111,
                                   0,
                                   0,
                                   0,
                                   -0.26350868698226299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3699140773664451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52738647338677536,
                                   0,
                                   -0.34939696519846991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86674619702395472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2727567786372217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12975218054956755,
                                   0.30070319010269708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56299022308790481,
                                   0,
                                   0,
                                   -0.15635296500630538,
                                   0,
                                   -0.023705704470427025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053410294798256444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19983925144860018,
                                   0,
                                   -0.51956041061337888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066974730205249258,
                                   -0.23320530606125794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19330614376355462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44142282354581502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51285811339063681,
                                   0,
                                   -0.043854626786487466,
                                   0,
                                   0,
                                   -0.36225711494325558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010533643825653367,
                                   0,
                                   0,
                                   0,
                                   -0.29732331520526561,
                                   0,
                                   0,
                                   0.25652426586825139,
                                   0,
                                   0,
                                   0.04452614487582035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32896538735986736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47480789189846451,
                                   0,
                                   0,
                                   0.55547560658101625,
                                   0,
                                   0,
                                   0,
                                   0.44887270158689418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15807298516932849,
                                   0,
                                   0.55109527160190919,
                                   0,
                                   -0.23171189388638441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21743291011179355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45096721349676921,
                                   0,
                                   0,
                                   0,
                                   -0.14599900282844985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40890819201244161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23859479012645557,
                                   0,
                                   0,
                                   0,
                                   0.34729075598090314,
                                   0,
                                   0,
                                   -0.90272737186599328,
                                   0,
                                   -0.68446725244277651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2985097220108559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31646157646275547,
                                   0.52223281533839172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11590344671832969,
                                   0,
                                   -0.90089549097190125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66513288451622443,
                                   0,
                                   0,
                                   -0.19223337585387781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18294550914832336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18154835530344118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19167482820976953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46039264576268607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63368543442493586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029227264614703229,
                                   0,
                                   0,
                                   0.079595836892019101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10458593398767614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35796840379449441,
                                   0,
                                   0,
                                   0,
                                   0.21006147510717577,
                                   0,
                                   0,
                                   0.71669200557859214,
                                   0,
                                   0,
                                   0.34830373465584086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22056844215620977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26381340220775423,
                                   0,
                                   0,
                                   -0.188758516100625,
                                   0,
                                   0,
                                   0,
                                   -0.19721092734681497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23137445818441654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57237183717276952,
                                   0,
                                   -0.28872772335619484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61010368469406817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15778890089211256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2113895442471766,
                                   0.33658475380629027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49895737636090076,
                                   0,
                                   0,
                                   -0.89127316354022401,
                                   0,
                                   -0.19724070487843454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79713705386023825,
                                   0,
                                   -0.22242610324735046,
                                   0,
                                   0.028993757519327451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087288201420568604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44988442203227891,
                                   0,
                                   0,
                                   0,
                                   0.052115310923897019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20104005207034864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52654788377091344,
                                   0,
                                   0,
                                   0,
                                   0.63406386618283594,
                                   0,
                                   0,
                                   0.0069734601667065244,
                                   0,
                                   -0.58887675515693361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51239934828377853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1693597487235303,
                                   0.36863152468641219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74330600028189098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4223015779670326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77726150606349476,
                                   0,
                                   1.1118046971314184,
                                   0,
                                   0.48633889380278544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41397591368361619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12252372284874924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31781710553784304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16072964820604996,
                                   0,
                                   0.076023312906638746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19693433961271478,
                                   0,
                                   0,
                                   0.12977029586841543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33631396970923827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44522861008882109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30557175941757497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60582601520062773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10577524896030394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38070150852907519,
                                   0,
                                   0,
                                   0.90352893568856874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12523100675718185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10231594516843612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98686564207236238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70886124019478236,
                                   0,
                                   0.10621588162134965,
                                   0,
                                   -0.8542968953872232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27076982569141533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44314238918367843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071705804909589985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68178204838043754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0028185702230139409,
                                   0,
                                   -0.45579798886758044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12004177599614091,
                                   0.45874594712432176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10247441181511438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089735929261939643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25562771533416501,
                                   0,
                                   -0.11103622225992682,
                                   0,
                                   0,
                                   0.079545596653517389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23750749921342434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80188336629154233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4054719741387891,
                                   0,
                                   -0.64737483386780648,
                                   0,
                                   0.67688491801288453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27681099684431482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0943342564307148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16022465298636357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37871483080546625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44339328168485731,
                                   0,
                                   0.13543915134395232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27064660011282232,
                                   -0.52217140226561387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43762116569156922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062007752669667099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077494731373919976,
                                   0,
                                   -0.18284411750134477,
                                   0,
                                   0,
                                   0.24683294902287634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052587545163480007,
                                   0,
                                   -0.092203104132865477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087229077026917942,
                                   0,
                                   0,
                                   -0.99519800602554831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51083557399507695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56383208393046991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16747105205023544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40025297631682877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077856359636299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24654613989853719,
                                   0,
                                   0,
                                   0.13911576988314578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55672401644889935,
                                   0,
                                   0,
                                   0,
                                   0.27495874883122223,
                                   0,
                                   -0.56788259294518761,
                                   0,
                                   -0.031500325788989814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73960292265207617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17549048220658275,
                                   0,
                                   0,
                                   0,
                                   0.36535499372024544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15408035447678783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20476151764074654,
                                   0,
                                   0,
                                   0,
                                   -0.12337825512686765,
                                   0,
                                   0,
                                   -0.44485777570674695,
                                   0,
                                   -0.044124584002733988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19719919867640875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54705054889135263,
                                   0.14010542201659759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11806661712410177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010492022929679816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39993892871307962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1423502819412624,
                                   -0.030612227896514011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096505459805916766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24059580778197054,
                                   0,
                                   0,
                                   0,
                                   0.49102263418002567,
                                   0,
                                   0,
                                   0.060878021089982512,
                                   0,
                                   0,
                                   0.47554449477967747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14147982877621795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49661878510650681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14899033595882633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077112788927541892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40484763362981724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083588311566678217,
                                   -0.0081989850126286956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43051539558125312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0010759239862112857,
                                   0,
                                   0,
                                   0,
                                   0.14353302810039936,
                                   0,
                                   0,
                                   -0.041119766174763969,
                                   0,
                                   0,
                                   0.15175469623938681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67745092224823156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33360634477883044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26613010193713699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37755879134582032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12119358544396917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48067768960240403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18259951729383403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054165435705521486,
                                   0.18051639187918805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31074498337550904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044667913450128799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34471642639240635,
                                   0.12890633663652834,
                                   -0.14895930012405151,
                                   -0.22305197945061561,
                                   0.40752616056251983,
                                   0,
                                   0,
                                   0,
                                   -0.54223160921808045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55116354193626538,
                                   0,
                                   -0.056512157745787439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19218605378931769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23578180145049243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75540216652654513,
                                   -0.38453567473158906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57478216153011363,
                                   0,
                                   0,
                                   0.62609276750801313,
                                   0,
                                   0.25122237964320071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0069383693080981579,
                                   0,
                                   -0.76396929259119661,
                                   0,
                                   0.38599098655201253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28852546232476517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40457993109734613,
                                   0,
                                   0,
                                   0,
                                   0.056137924921785334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098011351473137609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077585781557987205,
                                   0,
                                   0,
                                   0,
                                   0.045096430446940394,
                                   0,
                                   0,
                                   -0.86732597300267844,
                                   0,
                                   0.026842156884859678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24209197994402229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26785008730950466,
                                   -0.72292643434620318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017242561873580184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48090197655427624,
                                   0,
                                   -0.19495661836732783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41912359174204722,
                                   -0.26546726862805059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0054177944538838091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1932378137883824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0060144467306804811,
                                   0,
                                   -0.52000230295154481,
                                   0,
                                   0,
                                   0.42009721526637811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25089704099396326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047878112827908589,
                                   0,
                                   0.25872503631748761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34875936459656776,
                                   0.35199890326895761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44574558304679696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55780623985425914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18621282098144593,
                                   0,
                                   0.27814009186359873,
                                   0,
                                   0,
                                   0.020232226591266216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28198393165105323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31855664451653748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034353684578336027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27265337859002137,
                                   -0.078645621440942309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44471821935987871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3773413682354409,
                                   0,
                                   0,
                                   0,
                                   -0.26304810404070716,
                                   0,
                                   0,
                                   -0.33257390795036068,
                                   0,
                                   0,
                                   0.14607403241851435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44260311609100877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010290715757802389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21147546050254951,
                                   0,
                                   -0.14977531486994206,
                                   0,
                                   -0.13067035309427913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029639733786509231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31234900437845842,
                                   0,
                                   0,
                                   0,
                                   -0.69064564682577279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54339976127195533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45685564502059528,
                                   0,
                                   0,
                                   0,
                                   -0.78257959291783852,
                                   0,
                                   0,
                                   0.16901079398809829,
                                   0,
                                   0.080638065113657051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27375161909817158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30359209256215708,
                                   0.30152178879665659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052145252693816736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13994846542951983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080889138134896788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056256112830954524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55321998885027024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46779214075133435,
                                   0.13137951697456426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50140846980327003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02272662912046701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12433013853986939,
                                   0.0033571894499973554,
                                   0.18444630209809493,
                                   0.33957606329354717,
                                   -0.095480510064083035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66046462927051997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87754321580075767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81747017893977691,
                                   0,
                                   0.71901201623831923,
                                   0,
                                   0.084116496762933313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27165421294347353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54689038170014903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20032241629167499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070765208756426112,
                                   0,
                                   -0.23340181099289709,
                                   0,
                                   0.53404724404253412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7297902792734956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36092455443321303,
                                   0,
                                   0,
                                   0,
                                   -0.36281311658106302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52779960680697924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63526809558939978,
                                   0,
                                   0,
                                   0,
                                   0.090937691166581056,
                                   0,
                                   0,
                                   -0.058226447151345111,
                                   0,
                                   -0.87947799422534523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23021236714980323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25969803621138299,
                                   -0.095599686435435233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096734095114384883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49080752745417988,
                                   0,
                                   0,
                                   0.56704125315136966,
                                   -0.43499546641994125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37361420107587262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31528729122781635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32814725573811121,
                                   0,
                                   0.10151046247022011,
                                   0,
                                   -0.081951057404136426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1167272370086269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39854520381595021,
                                   0,
                                   0,
                                   0,
                                   0.27663535634880898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82944911254640008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028587879760079957,
                                   0,
                                   0,
                                   0,
                                   0.80715166188648457,
                                   0,
                                   0,
                                   -0.085300781394556532,
                                   0,
                                   0.86571421917051605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29699388697093482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2621309330731576,
                                   -0.1393172617187603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28389029671005989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32460282111850569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26905748275440561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035740495350968071,
                                   0.33503033026973922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062722046042295504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51736641783794879,
                                   0,
                                   0,
                                   0,
                                   -0.16662707491045378,
                                   0,
                                   0,
                                   -0.13398146056661148,
                                   0,
                                   0,
                                   0.52645688095028675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090814485642127657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15938279764056393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10348045202887132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21414589857983629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0017966444933073117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32539802209919622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25767204430388285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33725655541098393,
                                   0.047194275396831298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0054038422754039139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1776665361080712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32470970452196735,
                                   0.0013368744791583814,
                                   0.0083322072221359844,
                                   -0.32865168636979186,
                                   -0.64036546408998307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44707387151961964,
                                   0,
                                   -0.031823174192318067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43024612552954367,
                                   0,
                                   0,
                                   0.40536730619084388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48578689712426881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18275058242641193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38512701519239895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12228644929793334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52627445438546916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45474755631953495,
                                   0,
                                   0,
                                   -0.25677832710672838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043358649536617985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27816444443075811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21024313701636443,
                                   0,
                                   0.062735902486934739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15302290425207493,
                                   0.47245817202871837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29276781653172412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056628747470505392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24074289830812159,
                                   0,
                                   -0.68738853597356264,
                                   0,
                                   0,
                                   -0.092053714092561356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49295597331439389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37048357578648017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011711742440352613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45266833484474095,
                                   0.11984224144222493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33674659077719193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13438925410240091,
                                   0,
                                   0,
                                   0,
                                   0.36581357899696626,
                                   0,
                                   0,
                                   0.15964339250622364,
                                   0,
                                   0,
                                   0.065407024046845647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17880124999564573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27076943728517233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22537491513246893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38935579677817078,
                                   1.0301223054695861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5081674719373096,
                                   0,
                                   0,
                                   0,
                                   0.85412035220483751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45094526897961995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0317895858585098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1024420307694961,
                                   -0.48420865272138658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44404232178200193,
                                   0,
                                   0,
                                   0,
                                   -0.10177946570058834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42799532529263346,
                                   0,
                                   -0.42563692698918215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29047087143600497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017657069013441083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46511789399437881,
                                   0.094657966818742972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20842544738791349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086169790860565823,
                                   0,
                                   0,
                                   0,
                                   0.10696798160983945,
                                   0,
                                   0,
                                   0.65970116097939502,
                                   0,
                                   0,
                                   0.027156142100312156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083219574116346035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060631647803070447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7085224214451904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23545845010458438,
                                   0,
                                   0.065124080136681251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063822787157316971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023816195721390335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56039833001639816,
                                   -0.5734966923011221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24522060429168446,
                                   0,
                                   0,
                                   -0.3214460612877541,
                                   0,
                                   -0.31738873537432677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10388437931537403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92604061671704185,
                                   0,
                                   -0.19010643493034957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4759501150477296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65046943814462432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52397023534252352,
                                   -0.096281715761824274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22315781054999095,
                                   0,
                                   0,
                                   -0.41502017119699952,
                                   0,
                                   -0.26738575977237966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12146286762753089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01501503809378101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5057376064336081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27917814237741989,
                                   -0.45873669471233208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0021957404530284774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20023571824563502,
                                   0,
                                   0,
                                   0,
                                   0.16706353971608662,
                                   0,
                                   0,
                                   -0.25451842740201441,
                                   0,
                                   0,
                                   0.42331550332352186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34209575980190848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10888736862007421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15754906614535752,
                                   0,
                                   0,
                                   0,
                                   0.59097091377659761,
                                   0,
                                   0,
                                   -0.28302039567646231,
                                   0,
                                   0,
                                   0.017008953090030005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52444513470048282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14085351686240249,
                                   0,
                                   0,
                                   0.32537535980848387,
                                   0,
                                   0,
                                   0,
                                   0.38051318594587946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28377683000925358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035691337306576032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26087365749025915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16975228375714521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32508815219973458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059037166927697872,
                                   0.35384482024522879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24221423524064775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53181240180678835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43524151591431531,
                                   0.17326684224080652,
                                   -0.062345886410800203,
                                   -0.019034274242506023,
                                   0.14749247496633427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18510000502426854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23029512783407835,
                                   0,
                                   -0.013775324872058112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6799354427064439,
                                   -0.14183601430763032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12974276599335094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3955920287466046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063969346606610619,
                                   0,
                                   -0.12389143298893218,
                                   0,
                                   0,
                                   -0.48715020111737534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40000995000688183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60749097368496141,
                                   -0.072596220951515522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37846749890259745,
                                   0,
                                   0,
                                   0,
                                   0.068659193833726345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93256078266434916,
                                   0,
                                   0.36594204940527991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062407106728332225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29803144228505113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01593328159179612,
                                   0.017152154640636824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18882107501161285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20903899692806965,
                                   0,
                                   0,
                                   0,
                                   -0.52426335364321663,
                                   0,
                                   0,
                                   0.41346423778951941,
                                   0,
                                   0,
                                   0.22613470663515817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23007159173621269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37894020592557304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13441006447657233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62054504591712489,
                                   0,
                                   0,
                                   -0.51379400851474766,
                                   0.34202308776124313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44389050269584496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13731324198401496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92228199656380694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20645932786988916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60864599738426439,
                                   0,
                                   0.40357336457643056,
                                   0,
                                   0.41999650700278029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39146017273202516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09042661717510514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80270530402899376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17747766634670079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1521917469167051,
                                   0.8311847077321024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57117016539336996,
                                   0,
                                   0,
                                   0,
                                   -1.0074225060886068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36567516237449083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30156039999978956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20146020354989283,
                                   0,
                                   0,
                                   0.040453494352944895,
                                   0.44417032482601548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45876612663905469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6775581081536779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55679092615698211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0084541840675662547,
                                   0,
                                   0,
                                   0.50752773756179315,
                                   0.36287227815935907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041685509757289158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54673029452017918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65887171699370706,
                                   0,
                                   0,
                                   0,
                                   -0.15473047834837686,
                                   0,
                                   0,
                                   -0.059853204525723722,
                                   0,
                                   0,
                                   0.12146733412789826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17207168498081188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41318334346543406,
                                   0,
                                   0,
                                   -0.24192903542588301,
                                   0,
                                   0,
                                   0,
                                   0.51453962140169673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42258117404608625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35466413042631173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24748277845680394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19831610442910791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097737470420029199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48617750010218563,
                                   0.39114533228484688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19835640423663975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062590902223639208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057854680404865855,
                                   -0.19031665662918709,
                                   0.029931762151835597,
                                   0.013656078697580641,
                                   -0.33501161244824762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41154155490474331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30234489026375649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.191385004772997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073053424420074328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10932758942395092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24668988440932171,
                                   0.10311059111529589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10871602006328623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40171636690365453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18279824383676493,
                                   -0.57891813683607918,
                                   0.056233025966974375,
                                   -0.22496392783433833,
                                   0.1352343764245931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44780078579666244,
                                   0,
                                   0,
                                   0,
                                   -0.3535267137915003,
                                   0,
                                   0,
                                   0.197707728193524,
                                   0,
                                   0,
                                   0.016525062846367539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51211985800922855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0037416964920731523,
                                   0,
                                   0,
                                   -0.36739509114569008,
                                   0,
                                   0,
                                   0,
                                   0.4877212248079551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10517246460942582,
                                   0,
                                   0.54412623458120324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21548999617282485,
                                   0,
                                   0,
                                   0.46616711460166532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1612491347923446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56909117424254474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67961178682860979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30506746441635674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55072321075335995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1766416183606849,
                                   0,
                                   0,
                                   0.16954051758690478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062533738397355793,
                                   0.018407312056402947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23379610516506213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27419765743170416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031452817686854519,
                                   -0.24964419300202473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48476594720777344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44675816606836338,
                                   0,
                                   0,
                                   0,
                                   -0.27598814008823747,
                                   0,
                                   0,
                                   0.07633217787355237,
                                   0,
                                   0,
                                   0.34021432087759612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011280266407842326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41718668241167517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39596881082575103,
                                   0,
                                   -0.28111958725295905,
                                   0,
                                   0.48778745243809007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55623940248724268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15752282957376371,
                                   0,
                                   0,
                                   0,
                                   0.21190864465710102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0051437230689282756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18740186194386546,
                                   0,
                                   0,
                                   0,
                                   -0.19365546206931622,
                                   0,
                                   0,
                                   0.36273839697643456,
                                   0,
                                   -0.67142112258250841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2786658922294829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64257736760495177,
                                   0.057079192155120341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26736822081948225,
                                   0,
                                   0,
                                   0,
                                   -0.33006526981508683,
                                   0,
                                   0,
                                   0.25537576507304177,
                                   0,
                                   0,
                                   -0.52011038860447156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41738419232451296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30897550220750192,
                                   0,
                                   0,
                                   0.41643046827596342,
                                   0,
                                   0,
                                   0,
                                   -0.20186578353321943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22953361287773827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38807290500837288,
                                   0,
                                   1.1521266599543949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4867317697620262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20619891897221784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25840177546838317,
                                   -0.21388986147551711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061451044346412534,
                                   0,
                                   0,
                                   -0.1568751732879915,
                                   0,
                                   -0.76497499280254666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11735926899111424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54974687681016987,
                                   0,
                                   0,
                                   0.073218255304835986,
                                   0.32874729474070891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6714642678664835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34598441249374812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29698285205083408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26713747706352503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28602460102408184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17706103818559854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45808934053079375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34719898907390095,
                                   -0.39955902881067973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31485750029059478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049010551852440139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11022356748363675,
                                   0.13965312302586635,
                                   0.10656530741907515,
                                   -0.19274054115782838,
                                   0.23567579562308449,
                                   0,
                                   0,
                                   0,
                                   0.18879614760075727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48040814144188687,
                                   0,
                                   0.14476609007121699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13700820030315464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9746872083972854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34986531980816399,
                                   -0.3735698360668091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086943392590540347,
                                   0,
                                   0,
                                   -0.58128733145903089,
                                   0,
                                   0.66084673814343653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37356304321806955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036375281251137731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51443357364065234,
                                   0,
                                   -0.67871564604603185,
                                   0,
                                   0.59513715653803256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90716312750218331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36232250983672154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25629783897170005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52404897575567244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20044622506814597,
                                   0,
                                   -0.5997022710787856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20210720280973143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088647527091587505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10629941404792929,
                                   -1.0298549695434576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34499589224023747,
                                   0,
                                   0,
                                   -0.043056856184933233,
                                   0,
                                   -0.16660062890279614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28865048796432469,
                                   0,
                                   0.45408064587557539,
                                   0,
                                   -0.11804928783164059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2111461406064567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32846747306303131,
                                   0,
                                   0,
                                   0,
                                   0.26063231328401337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40713154177974581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3720060958611891,
                                   0,
                                   0,
                                   0,
                                   -0.078273801555339612,
                                   0,
                                   0,
                                   -0.20137793514287905,
                                   0,
                                   -0.50566113363305865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024647165053032272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09224403796338386,
                                   -0.85909581264554602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5367721444443232,
                                   0,
                                   -0.20477799509761982,
                                   0,
                                   -0.5394689111430393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05427127687052747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4973820148509035,
                                   0,
                                   0,
                                   0,
                                   -0.79036703184427781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087824055840634338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26278742501114111,
                                   0,
                                   0,
                                   0,
                                   0.66828123732746947,
                                   0,
                                   0,
                                   0.41442807195702847,
                                   0,
                                   -0.085753791119414891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042811031926544417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25566533173453287,
                                   -0.0051964565823130367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24849926761907673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3288834527726997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10568871828256042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035389211109717073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10676335817159829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067538139416757431,
                                   -0.3854964867347202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26029421526150587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14066166239230632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3893470568932243,
                                   -0.55591252019228132,
                                   0.032373954983522371,
                                   0.30191609676016901,
                                   -0.11280020307364426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25004380208979704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6333430423360864,
                                   0,
                                   -0.054531509875716276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31485448190158499,
                                   0.13351269530364063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34413668986958701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29182077464693712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32683958532887547,
                                   0,
                                   -0.01702842172614346,
                                   0,
                                   0,
                                   0.32514382986071849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0244665584168644,
                                   0,
                                   -0.3198011541203325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36291588318205192,
                                   0,
                                   0,
                                   -0.16510556923796008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37273229690696907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2251280193019175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35278552887258507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46856983762380205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14910343554704286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31969264585466328,
                                   0,
                                   0,
                                   -0.088194294508418536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62101486164946229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20931996821577759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1272597584338496,
                                   0,
                                   0.48175475069336637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13010378381227686,
                                   -0.063031892689680846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36563347460774426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37869413704368921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32853005725244855,
                                   0,
                                   -0.33798125313083915,
                                   0,
                                   0,
                                   -0.4332920928708216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74689252312022303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17650071268093848,
                                   0,
                                   0,
                                   0.38716680065448728,
                                   0.50671569950063389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017474171633252017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063519910315656597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0056066141253737,
                                   0,
                                   0.12515204438103628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24590926740994534,
                                   0,
                                   0,
                                   0.27600152879199957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010487667647282539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072845562066192276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087359949571130358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73333546390724069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19844595911730536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31949940938572624,
                                   0,
                                   0,
                                   0.20614555152210495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74729743257931502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32813838949656954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12386776940977959,
                                   0,
                                   -0.3997846963890862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093640488136835134,
                                   -0.054731441491894489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45523278545179974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23767889340115123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5950704761429968,
                                   0,
                                   0.046669806124625485,
                                   0,
                                   0,
                                   -0.29219002407248973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33969920237390966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29273034979679247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74583566097318088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05596179974728549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10050911038524477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077921420787507883,
                                   0.34754606962553963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011559312703619042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05010512775827923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050215682880732401,
                                   -0.20278987838944476,
                                   0.11443199631083247,
                                   -0.057388004564685437,
                                   0.19967769638631858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12085597765317814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2662535107623179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11590137462724889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071053671098371268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026549971019134089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11030288635914762,
                                   -0.18991579143709936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36520679962919689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083472493291127464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16522795639265878,
                                   -0.16923969578357723,
                                   -0.79360704634373902,
                                   0.10157527043988782,
                                   0.10327544196041545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10790925804047512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14802672127288358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054429852714300328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32398731245287249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20809260336489735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45216893785838302,
                                   0.38528964781617897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35229142170514854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2536748131782724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14665912585712082,
                                   0.043279438830975223,
                                   -0.36744132232023574,
                                   0.33877246072779543,
                                   -0.026150152985629952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22667907149007296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16813509082364869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18229714707980132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48364315111312661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42140939700984192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10151120951920971,
                                   -0.091511589786862566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12207236485039415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14057491013111972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025612248507721494,
                                   0.10520181210011559,
                                   -0.2705545791920726,
                                   -0.540888434018165,
                                   -0.21164359470759658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0391484682145853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01266633964635917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26039973325004784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29473363941944541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019951203905630429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02796542556396317,
                                   -0.1033587708350116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17098731455198632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63320962649144052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34081104791599942,
                                   0.28453993895300045,
                                   -0.18811539610856903,
                                   0.2691609431281049,
                                   -0.31084821907596849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02895248473301866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41737161914884002,
                                   0.55391741052749954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2008954143113393,
                                   0,
                                   0,
                                   0,
                                   0.28724956761934417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29271087268877305,
                                   0,
                                   0,
                                   0,
                                   0.07744997731137454,
                                   0,
                                   0.036750051627736251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078134134656920387,
                                   0,
                                   0,
                                   0.29752187448633527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26740629302724844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42573847990283015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31668360163501619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33538823650222654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17279274291570507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80173135886961799,
                                   0,
                                   0,
                                   -0.022726305036744093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82814277274301951,
                                   -0.53142366881785408,
                                   0,
                                   0,
                                   -0.22430432246344087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3641812021010411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074097888709899584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89730225060899649,
                                   0,
                                   0,
                                   0,
                                   -0.95634450428692885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36621493812737438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14100131879731484,
                                   0,
                                   -0.018446533912740423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1735957462613566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50150428696599125,
                                   0.91675932518800951,
                                   0,
                                   0.44570585234479682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21997114798738804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063084153798620132,
                                   0,
                                   0.57053902637093012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077140750904531791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21138943394198317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42535725945329672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018054127150040289,
                                   0,
                                   0,
                                   -0.44885577200274984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039244906492979403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42296679845864144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015792386423512272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60862741836016077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078772701256632383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46396903527997102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1610536638677654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17531527773894207,
                                   0,
                                   0,
                                   -0.85301449556606257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12511072619524916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77999445844895532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26244746946752989,
                                   0,
                                   0,
                                   0,
                                   0.053552359897834342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73949290668231582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0060206268520501087,
                                   0,
                                   -0.029161572122075687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15244515598462799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44983390086506425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32850087901421254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14688022881772037,
                                   0,
                                   0,
                                   -0.14286853809809064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15470561835574362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22417655509376946,
                                   0,
                                   -0.014816370788063978,
                                   0,
                                   0,
                                   0.048651849119482837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14752451903565561,
                                   0.31147958141590165,
                                   0,
                                   0.10449714176168325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15066456047954435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066595412838079265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23968687887274356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11328540468989458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59549737458876362,
                                   0,
                                   -0.031920157310438457,
                                   0,
                                   0,
                                   -0.17030851630921695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20649146078686093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40080187144418405,
                                   0,
                                   0.42942231615314846,
                                   -0.023532805594833346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29481369883226644,
                                   0.39777336264375468,
                                   0,
                                   -0.24419925103955742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43897832145395888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46239892895028234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32999693746969716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17580354329903025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10653236621555248,
                                   0,
                                   0.066560150184357153,
                                   0,
                                   0,
                                   0.20934215867735487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072452244572873789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023391582014578815,
                                   0,
                                   0.16998773470252984,
                                   -0.23369317089086655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025430025305264715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29972952872488229,
                                   0,
                                   0,
                                   0,
                                   -0.36712641968549864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83996042408617744,
                                   0,
                                   0,
                                   -0.19372622201034925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17796165954161966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36277228971884456,
                                   0.43255844453983366,
                                   0,
                                   0.26240161528936007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29561256457186752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10604850750123299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094301917660171181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094006439464878161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31316134010234076,
                                   0,
                                   0.51923294155734756,
                                   0,
                                   0,
                                   0.16431634326760924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29397817562074668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082251876529203738,
                                   0,
                                   0.090607142307043878,
                                   0.00088723331327447003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54338103031050378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14692094488159135,
                                   0,
                                   -0.096134003814291671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094994402503697548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15263856016699962,
                                   0.25787737811896871,
                                   0,
                                   0.21760494074506487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2703900341596811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10920217686468384,
                                   0,
                                   0.3806821671070082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2587100972804805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66988143994022542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40769822664083361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84242678957306449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32550736280051223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33854721180639125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10467430223510335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26507073454421659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0088174293198131568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57404919896172379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.014850407050464,
                                   0,
                                   -0.051390913980136309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58956603874153257,
                                   0,
                                   0.477675144177512,
                                   0,
                                   0,
                                   0,
                                   -0.29154156925537711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46938870756935708,
                                   0,
                                   0.29152143959995264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062171220008906694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27351966826563839,
                                   0.48146709432609236,
                                   0,
                                   -0.25791283003217996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56361020879645962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48782558490255978,
                                   0,
                                   0.22092771833371616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39411743303551461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19130649690228976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10432682898329568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54069305082425412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14299665275111839,
                                   0.86428860944525088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22691100235882644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10490615928824734,
                                   0,
                                   0,
                                   -0.89417868320379146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34755376780176794,
                                   0,
                                   0,
                                   0.29330374288815975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1215061529438108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57216712084802579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15738900192205987,
                                   0,
                                   0,
                                   0,
                                   0.17486415130952854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22580912168668293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3750514973675911,
                                   0.25866805665040238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12529898387692243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097221088261527353,
                                   0,
                                   0,
                                   0.079746500316079591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1017810620508707,
                                   0,
                                   0,
                                   0.079031528748032404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48343933712514475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13119750128258026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36475819159241074,
                                   0,
                                   0,
                                   0,
                                   0.47473584103917876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25177290097773947,
                                   0,
                                   0,
                                   0,
                                   0.2014623772182787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19480466634911026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025175576297790558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63556961541232726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42180193752329398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41648195475302574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40651734573853504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015844915186376811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65981099912174923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098911041825591822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46898479413138283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51512678265308776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17287416184980353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43947998836512786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10380633914020439,
                                   0,
                                   0.14676009823197894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52200853884349674,
                                   0,
                                   -0.18515974885349482,
                                   0,
                                   0,
                                   0,
                                   0.33574994717174972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39617325433004358,
                                   0,
                                   -0.13771951681336869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13728623193600159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49802088956375828,
                                   -0.055937912053801511,
                                   0,
                                   -0.47915365851799091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89123194234251946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04013920797351786,
                                   0,
                                   -0.056294514757305902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97617269524104666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15418039563971297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1508249648155747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047247436683220616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51512284950687715,
                                   -0.32219938467064319,
                                   0,
                                   -0.083024506262605394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0084816180389047889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51101611670502578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19150419765614787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1384866860405824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015569361441268015,
                                   0,
                                   0.032452389410401281,
                                   0,
                                   0,
                                   -0.51919075551188265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -7.1161427903226881e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14366607816437166,
                                   0,
                                   0.034499868040746326,
                                   -0.11914829964927644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69432362826286287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098723688807040577,
                                   0,
                                   0,
                                   0,
                                   -0.10428503858333429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16700846007192749,
                                   0,
                                   0,
                                   0.05017385251785924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68328890084635208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0050901464207515762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4157830518041124,
                                   0,
                                   0.44812855595758977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34211882636405599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19595017101083773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082255830695014534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57308932975838101,
                                   0,
                                   0,
                                   -0.097335886745535505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05519649155783582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09566983340264959,
                                   0,
                                   0.33511987157796169,
                                   0,
                                   0,
                                   0.040757898137070044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39987465047817339,
                                   0.016030410171123752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12447369039385484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25985500935050665,
                                   0,
                                   0,
                                   0.052564766433371546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019632171779133289,
                                   0,
                                   0,
                                   -0.074637494174388197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94947153669456663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61292910560697089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30767289482593801,
                                   0,
                                   0,
                                   0,
                                   -0.28512935579398524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96058201032428503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054246390576570117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56878950657912852,
                                   0,
                                   -0.1227832437071557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33431518080202804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36355619518967935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023155699548166542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33001860270169286,
                                   0,
                                   0,
                                   -0.31885002739272594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36951458918114699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13715534780350616,
                                   0,
                                   -0.12520121722094174,
                                   0,
                                   0,
                                   0.17994050084025964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10258790698578446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47445982968984418,
                                   0,
                                   0,
                                   0,
                                   0.29978564018219633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097194843363057309,
                                   0,
                                   0,
                                   -0.81037708388062446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091292418284748891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.427961208807625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075461806755046712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52060917295927667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32145338196083129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27520281419694309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41085184527334373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41661067115217354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13670498421593069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017935039498680257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68407022237476944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34437277333483773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036316922262243839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22385600706499748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44377140743001986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60166877366541593,
                                   0,
                                   0.15386415253059677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53991683378144606,
                                   0,
                                   0.78543404018486196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23645947278845292,
                                   -0.29317574470767921,
                                   0,
                                   -0.39413201822073429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32721282881570601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41105505682854721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27463315464226856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093467247103876716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08142526537964305,
                                   0,
                                   0.1328303146556393,
                                   0,
                                   0,
                                   0.17509671820880193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070726316206644407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36184906930667327,
                                   0,
                                   0.19775616051108047,
                                   0.33559436052713282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0062674820292896137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33888184786572229,
                                   0,
                                   -0.28961181742050929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61096105142483315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1937983938714021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52619178394302535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19333803020031348,
                                   0,
                                   0,
                                   0.017230683861650442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0090100112307288163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12824190037537186,
                                   0,
                                   0.24331896460918104,
                                   0,
                                   0,
                                   -0.011314393986165114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31112451739043956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19329788192424419,
                                   0,
                                   0.35760162349213176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025621624933822244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87159749223246774,
                                   0.015710729764531826,
                                   0,
                                   0.19902088070678881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13726626409078158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045383093753153442,
                                   0,
                                   0.33701411566631428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46363046901055494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47534028127234351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20442036445822001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19019540382004599,
                                   0,
                                   -0.13190525314014714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43470853951638988,
                                   0,
                                   0.55686865736088154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24060078319948164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12552858594528377,
                                   0.55750534305400257,
                                   0,
                                   -0.2930654034771325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15206084120058103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52928325052179992,
                                   0,
                                   -0.52575160813459321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19940500857732762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065601656592241098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30528018864136131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51557992986257939,
                                   -1.0085220866077389,
                                   0,
                                   0,
                                   -0.51298582711911056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78098807787473723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12266843487557491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46231464815747786,
                                   0,
                                   0,
                                   0,
                                   0.20219347795493542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21889509542493379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36675833508627531,
                                   0,
                                   -0.058321211952985917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86411671478465257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21359551061123372,
                                   -0.41573573101691214,
                                   0,
                                   0.34460664558631027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6160208135931533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11078924592574378,
                                   0,
                                   -0.17194000473974996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67606204437204964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44048976960474973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30730612110706235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34611760683077453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31494905522996502,
                                   0,
                                   -0.50846186389944015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07731181130283292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021588278316913095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34863783927797798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53672475466418723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38752492914482162,
                                   0,
                                   0,
                                   0.057867533730029154,
                                   -0.26733561892183322,
                                   -0.034872554871699303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048987057684021736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64028590897341275,
                                   0,
                                   0,
                                   0,
                                   0.27813624226668454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44202597475717131,
                                   0,
                                   0,
                                   0.54126126315621026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14806666179068412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10938839093200271,
                                   0,
                                   0.67716460936240408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38549515779890031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019596057655018304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17970706733685232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39946913693970043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12237038914804875,
                                   0,
                                   0,
                                   0.33956046800740058,
                                   0.23288741585422959,
                                   0.064102699937523933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1486087179676433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47435124612649021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5200946137030994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4163314699494059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53007671619744279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15095097904731608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068659502167597503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024380192803659197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58654593261888799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38948200783979503,
                                   0,
                                   0,
                                   0,
                                   0.51933915403783693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027230640388180016,
                                   0,
                                   0,
                                   0.095016430779257047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47411480433182496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16724165535640872,
                                   0.47856154955633279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46544364330804316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26509051980221254,
                                   0,
                                   0,
                                   0.052664604028949485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83396549273042941,
                                   0,
                                   0,
                                   -0.10786928313312955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12109324934180554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10857237854629448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95592014003125025,
                                   0,
                                   0,
                                   0,
                                   -0.27811476255731504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76534267697919978,
                                   0,
                                   0,
                                   0.51990667902782639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22274957123966713,
                                   0,
                                   -0.52562742889327962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51256935471510923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87373274496150277,
                                   0.10344414430151783,
                                   0,
                                   -0.36868413718091569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23825923854990488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44289602925096505,
                                   0,
                                   -0.30002511655094755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39419529246847029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33087299916145563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11454747317948125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3496122457317194,
                                   -0.23884740670887397,
                                   0,
                                   0,
                                   -0.49780573206691042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91974053341962958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64392301531577123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83701999575140507,
                                   0,
                                   0,
                                   0,
                                   -0.06612753207046379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23769274986037903,
                                   -0.33190616145733204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089077022117792878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60722726531903648,
                                   0,
                                   0,
                                   -0.10032852503928531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50919730982725608,
                                   0,
                                   0,
                                   0.29408441399595769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42289411822315404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10605295165054193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30068753679323146,
                                   0,
                                   0,
                                   0,
                                   -0.48542308858211175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30944041451519361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36495208049160427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31855417266605685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33485104844181784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5047072751987004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30008807292332196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33870006867128744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37444163725152058,
                                   0,
                                   0.89174925989263565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4938247296177018,
                                   0,
                                   -0.12539921624704981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13434078848747522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11429602116500337,
                                   0,
                                   0.16917266966261238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24585995316327683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28316274998836838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25299742248822654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33587439738300096,
                                   0,
                                   0,
                                   -0.22156071562343424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46033522953160816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43758599150483662,
                                   0,
                                   -0.40670982702753089,
                                   0,
                                   0,
                                   -0.070213646555428277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20446461856195411,
                                   -0.066587370256678172,
                                   0,
                                   -0.077462249224630617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16963981613833085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36568721385187142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064349382995358972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34951739306470564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35436747580733136,
                                   0,
                                   0.30822215553639193,
                                   0,
                                   0,
                                   -0.48129723515884915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15653037528010569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42193501864610394,
                                   0,
                                   0.052898421090034176,
                                   0.037396392054654309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36454188185109504,
                                   0,
                                   -0.089200247532001981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25813517677261505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4427807417442795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44771422858819132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30049499930564821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21039322277160433,
                                   0,
                                   0,
                                   -0.2241929351556661,
                                   0.45603652420740165,
                                   0.056759233685135677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60651284902410141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26696005207233969,
                                   0,
                                   0,
                                   0,
                                   -0.16201040400694344,
                                   -0.038754260650141516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71540185974314707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1202176121334952,
                                   -0.19884974899036431,
                                   0,
                                   -0.09346824368644055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24614242848003659,
                                   -0.1786822595262697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13524304370193121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058955340193180578,
                                   0,
                                   0,
                                   -0.053578736649191772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23515722674921785,
                                   0,
                                   0,
                                   0.98996532292535599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43744349327702581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8787601104782039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27231717848757514,
                                   0,
                                   0,
                                   0,
                                   -0.068727909829604777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051701890675320966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22347767955242157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15661748294098832,
                                   0,
                                   -0.661542860067029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15135991817246414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24090675095704031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23447242403372412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36787633395838565,
                                   0,
                                   0,
                                   -0.059715282177088824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.245674682460299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35952133749211251,
                                   0,
                                   -0.14213114936901669,
                                   0,
                                   0,
                                   0.057050088590045581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11279591391425012,
                                   0.06023038013925365,
                                   0,
                                   0.32467864569039762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091936674610224089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21593867242367451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18443187660562399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29343302180403602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38428361780523418,
                                   0,
                                   -0.10269886934781283,
                                   0,
                                   0,
                                   -0.076719670395376693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45707492725776733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11832544925296377,
                                   0,
                                   0.15208162329566147,
                                   0.54118310824355231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076470176605206455,
                                   -0.558850850427141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22277529341089872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16364963348760433,
                                   0,
                                   0,
                                   -0.043199199474315275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36311459193128665,
                                   0,
                                   0,
                                   -0.32816980716044092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2373602276278298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4819402073583775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42435193649741465,
                                   0,
                                   0,
                                   0,
                                   1.0541942819572059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23033386109781384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14199151721921408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35887199511623097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84780554280541742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41247117911581721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24045063632274277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37217124340541341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56169595169413566,
                                   0,
                                   -0.93682515226173246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20461760871528983,
                                   0,
                                   0.27227538325120915,
                                   0,
                                   0,
                                   0,
                                   -0.32722362835596719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2188785413664566,
                                   0,
                                   -0.18452090415807515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23129643178690731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027046161230380027,
                                   0.58223258576882508,
                                   0,
                                   -0.75060871962389797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36322422395044701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45737058001149089,
                                   0,
                                   0.012491676454234496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12425186400580299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071193291019580621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43075896146593518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18738890759769533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11237629876006679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33519072577948061,
                                   0,
                                   -0.031895570864989467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062629721338043134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041970762668747032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47354035292206376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084293017317704333,
                                   0,
                                   0,
                                   0.28920154939678944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015435728673877196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053691066510501761,
                                   0,
                                   -0.42147668535256322,
                                   0,
                                   0,
                                   -0.61038552329461615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45675139558708183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66266253090594907,
                                   0,
                                   0.035680978003945166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37742594715720768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61013002637682467,
                                   0.47193136104270983,
                                   0,
                                   0.33640941189385498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1234758490724516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43675986821237595,
                                   0,
                                   -0.71143463918712813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14678424446227978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42458811197640922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072039446561538045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15505660082774517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2723476911891155,
                                   -0.69532225811181991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0016278314438505845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064949964708591046,
                                   0,
                                   0,
                                   -1.2353029849475228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018935439983731955,
                                   0,
                                   0,
                                   -0.51879875690048427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0087629828640677712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48766199993685744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23803521141073292,
                                   0,
                                   0,
                                   0,
                                   -0.15265047947991711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26657670402161465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2488766880189312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.342820519430377,
                                   0,
                                   -0.087276158656111019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061865579411809264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047557902088293892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23960508438649189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32362523410293087,
                                   0,
                                   0,
                                   0.66198074750008651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1166487989408036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072980685164189138,
                                   0,
                                   0.42610479588207956,
                                   0,
                                   0,
                                   -0.077249176911896617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1961951337945301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79306062359833274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42067775582928563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24903368210863766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19982044642070523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20278016861450937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083801159840036582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074189795237510833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06056794821388916,
                                   0,
                                   0,
                                   -0.60440519678546134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12599257314803514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46432811554200276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3924496595488718,
                                   0,
                                   0,
                                   0,
                                   0.62990836460255251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21216975375300487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24271285626695033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077601730618834019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48577443702775447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41702035482179067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67548600509859758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6333842654500994,
                                   0,
                                   -0.23394608913231654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73877071533301675,
                                   0,
                                   0.55785849296090562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15540631789066189,
                                   0.0087799392769498247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87657294903634952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49634681754831872,
                                   0,
                                   0,
                                   0.29798134021168998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98779506284906471,
                                   0,
                                   0,
                                   -0.50874592453351331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17783561563031297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19349727968884917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6443220991990336,
                                   0,
                                   0,
                                   0,
                                   0.18561340427935663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4285669197139047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11307822124704425,
                                   0.20362063399249561,
                                   0,
                                   0.072653030537608562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39783061944126574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23633743090750264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33050154098432977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48319385773366547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15530721329300656,
                                   0,
                                   0.17440322774018191,
                                   0,
                                   0,
                                   -0.36115596732965399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23498165615766003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18810456288158042,
                                   0,
                                   -0.29338120889050073,
                                   0.14831940724628562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16804443233832306,
                                   0,
                                   0,
                                   0.48767118512232033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60160309671318024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68983909411345923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43723841410700154,
                                   0,
                                   0,
                                   0,
                                   0.86232337413734572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029247255522028399,
                                   0.041313890601911568,
                                   0,
                                   -0.14356270868420468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071013595480074437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085190794825497615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57513688646764283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12790088067409378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27850508836131871,
                                   0,
                                   0.26675083739637001,
                                   0,
                                   0,
                                   0.03183423299338152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18151189645742505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11703375799244893,
                                   0,
                                   -0.44158119653109962,
                                   0.47540940184621433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27396186412953349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31187239974008796,
                                   0,
                                   0.95070304734073841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40031750819196538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20504586981000902,
                                   -0.018106390037779529,
                                   0,
                                   0.016514292514185125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10102940374483625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55924217785812158,
                                   0,
                                   0.30357716065320584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01436997905583394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31962154249875463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3486131571081923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23458230696738802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72882209301309575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92584245581484714,
                                   0,
                                   0,
                                   0,
                                   -0.048798972893109381,
                                   -0.36450568732759947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56902754640062292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067060591862864782,
                                   -0.28645238994798244,
                                   0,
                                   0.30060715648609149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39112972380717392,
                                   -0.18314884651818614,
                                   0,
                                   -0.10650116113761905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15703278175510885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0050345828227789657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2075510691373639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28957748285263157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19605585047402227,
                                   0,
                                   -0.031284270777571788,
                                   0,
                                   0,
                                   0.38116956201573843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22483566513673822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5496509488143112,
                                   0,
                                   -0.31833169022923713,
                                   -0.10865169782401433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39268322248158671,
                                   -0.60356401624167733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94295536495926924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27146652994208209,
                                   0,
                                   0,
                                   -0.14530156772119762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13763358507211013,
                                   0,
                                   0,
                                   0.51799810935738233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059310543031701204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54504250923684683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6230231759907201,
                                   0,
                                   0,
                                   0,
                                   -0.38468080610824373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37228360758283091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022084516251743527,
                                   0,
                                   0.00035293683807542664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39321626647873509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16930080969655842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49972002363592805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43896719344462237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22829871646766431,
                                   0,
                                   0,
                                   -0.53354286738369039,
                                   -0.067941663548662518,
                                   -0.18003802188491808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22132601837593599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21395993614880729,
                                   0,
                                   0,
                                   0,
                                   -0.33480496298992629,
                                   0.37736545656902537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58444964972606617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44459482103662057,
                                   0.18227169861464521,
                                   0,
                                   -0.75371870554040887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0013352622147946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7626165850532568,
                                   0,
                                   0,
                                   0,
                                   -0.81401168444830552,
                                   0.67421590548265931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32748257694990357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43397975878368467,
                                   0.081758237777233386,
                                   0,
                                   -0.1248901287071835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49548188099545276,
                                   -0.0087071214375864028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66293418225761513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68061224149313559,
                                   0,
                                   0,
                                   -0.12074999993801115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12982025927602764,
                                   0,
                                   0,
                                   -0.06063164734820068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32731363548104436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3514841127957346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3868335148867274,
                                   0,
                                   0,
                                   0,
                                   -0.75044736284825175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32484918304364185,
                                   0,
                                   0,
                                   0,
                                   -0.30126918369153333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048115312947302022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30431651155058737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41080184882233001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12060027971902951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54786866760365083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3684146674283344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4417252832170866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40038465442227472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33710745056813429,
                                   0,
                                   0,
                                   0,
                                   0.64606382537498763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24698046991822162,
                                   0,
                                   0,
                                   -0.035353079622047159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49639000398543237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71012707382811524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34009442175569482,
                                   0,
                                   -0.40279258561887171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41786548355341863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16906072580270665,
                                   -0.35796858873911758,
                                   0,
                                   -0.28618168485856693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037377986122527698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24624951425302563,
                                   0,
                                   0.3019418048003929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21444582351520652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079291435708209568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59972936943828459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22533668284287417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21323530728080051,
                                   -0.25309270269252271,
                                   0,
                                   -0.15037925541186506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17295130789173702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09659352475574344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17938373458986398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5222703578347041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0032494249313895288,
                                   0,
                                   0.56202444760924397,
                                   0,
                                   0,
                                   -0.013219521744405348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10910029903596433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23269719581030243,
                                   0,
                                   0.15790250370249667,
                                   -0.34151529568788702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13266759100827774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26931676763990953,
                                   0,
                                   -0.39680876165037926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43998186086358965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28069657696045042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088732128151085332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033770773341383384,
                                   0,
                                   0,
                                   -0.31392538478817539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14005834684361929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48846549597472932,
                                   0,
                                   0.32376418851869249,
                                   0,
                                   0,
                                   -0.097133184221299462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43769023016155884,
                                   0,
                                   0.16565260238716395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22292105533432399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52745448541082096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12384421157490072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16861300891623707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27978447534755541,
                                   0,
                                   0,
                                   0.016773335076568363,
                                   -0.57497010558173767,
                                   -0.012860459087906437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52892545381140743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15885346393720617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093793538169233442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0081739591449269677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11024331220781942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052678887476896863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48792598660818387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6581329488904355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19266887163201771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67635190272453438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60181802163060605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42027109097282317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75932543154230869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19123918850587315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07244066559185644,
                                   0,
                                   0.12785217887600481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045507680793259481,
                                   0,
                                   0.0074879326613123028,
                                   0,
                                   0,
                                   0,
                                   0.58453009604926665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56679637797055671,
                                   0,
                                   -0.58005879429540652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76215244944911598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19722507876409998,
                                   -0.081480152016028706,
                                   0,
                                   -0.37139602359804103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18594401783433012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4237553911840346,
                                   0,
                                   0.10523450433764894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07128113485083451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38218226738163552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57081062893775014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30519605879460221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90913666865459331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91237343360759571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4385452688974697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30110975005671875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14844992027841611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12977728042376971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1373567279520552,
                                   0,
                                   -0.47294003694022768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4057615462365235,
                                   0,
                                   -0.18545195328513736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37889154175826206,
                                   -0.076469572242500311,
                                   0,
                                   -0.21871384928959842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50415239427254466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22055954406615369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21389612462311411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016339222471146813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11149344976031444,
                                   0,
                                   0.25115734068135631,
                                   0,
                                   0,
                                   0.193652089111541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12769058249161286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23803443639418856,
                                   0,
                                   0.36655920705287454,
                                   0.3654864210996574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020192365560013109,
                                   0,
                                   0.3825447389341935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42065776390687559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34073787562225499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23862301031722874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25112618240296081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29489413782835855,
                                   0,
                                   0,
                                   -0.26774932188127015,
                                   -0.52531363477676807,
                                   0.074729977594196209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039710542769857186,
                                   -0.0083447948191568873,
                                   0,
                                   -0.23262106810503308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030634368113247393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16815640374561253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29177105852369428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29993326733879522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29257998446932737,
                                   0,
                                   -0.32114662233127489,
                                   0,
                                   0,
                                   -0.091360153573044847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62224592574025106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080092885337699038,
                                   0,
                                   0.36820065953083508,
                                   0.11693610955714703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16338532206340117,
                                   -0.46166993587629745,
                                   0,
                                   0.65203472672041951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28257664361473733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10321830376754798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16838824813100306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12066054048909225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13294101897965505,
                                   0,
                                   0.12674838913493428,
                                   0,
                                   0,
                                   0.19914899022021079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27047280999251927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1414952964684901,
                                   0,
                                   0.18706698451773832,
                                   -0.0055109489183303162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45111095376426491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15076750606949424,
                                   0,
                                   -0.076668231928746028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12597791931415747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27424000119962633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28156876201013009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046577884931923219,
                                   0,
                                   0,
                                   0.02098889559106043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6808014431199273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061276193222199113,
                                   0,
                                   0.091260455361610052,
                                   0,
                                   0,
                                   0.34546662059037597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37906235891853657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27076323837522098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023609708452595794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29714465740250956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16826066374120491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53357030197626731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24571128054053051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56636002643288996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023815423774220079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069102507155918855,
                                   0,
                                   -0.080422148134494165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017989574870403591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15034936398610094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11851667039522823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17872248703322982,
                                   0,
                                   0,
                                   0.43462572561480151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2588918915965191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36527056175096762,
                                   0,
                                   -0.39209630322765326,
                                   0,
                                   0,
                                   0.61334071722772565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33424062109502861,
                                   0,
                                   -0.090210973059347471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33687918211239476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043678826752903729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40684414672386782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37971269083954262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11560500353041457,
                                   0,
                                   0,
                                   0.59865604019694652,
                                   -0.093763619417811445,
                                   -0.27294814409060975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15116403775366799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47041414623453526,
                                   0,
                                   0,
                                   0,
                                   -0.16763862932494414,
                                   0.96853835323138182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.533503677777317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58684684203921345,
                                   0.26272492289315946,
                                   0,
                                   0.2599299180593877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29311373792938439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14566032388980893,
                                   0,
                                   -0.23384596238701369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27164363499644173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5202677052743262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32568471824419198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3293448675168989,
                                   0,
                                   0,
                                   0.075840328008442912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012472885620548387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44789807063777792,
                                   0,
                                   -0.029705414021195559,
                                   0,
                                   0,
                                   -0.26790618503929753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41713987487352489,
                                   0,
                                   -0.29803005802903848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52013208798602573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38016042880871231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21711984246862118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0030470440912459852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44401660495264361,
                                   0,
                                   0,
                                   0.17884571199362753,
                                   -0.084773387966732117,
                                   0.19656982669308942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52677674384045048,
                                   0,
                                   0.040863563265379765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042482721960668081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47146896066863209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10101974519624733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096601595841461385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59380996854064227,
                                   0,
                                   0,
                                   -0.28823317026464956,
                                   0.19553734771806261,
                                   -0.057343857880932061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016312204051679456,
                                   0,
                                   -0.050465712588506538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10810670761180624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10681331782186068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31755690834826389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15602537674840139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10048312693102243,
                                   0,
                                   0,
                                   0.031548785330018286,
                                   -0.030849670243566094,
                                   0.91480095306037579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23200026102510246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10664450022391939,
                                   0,
                                   0,
                                   0,
                                   0.73295948034857683,
                                   1.1466732563332134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22033587214521078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36624641838514854,
                                   -0.21280432851080086,
                                   0,
                                   0.73765707044041684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50421257049148538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061535543210528468,
                                   0,
                                   0,
                                   0,
                                   0.42526229243908498,
                                   -0.24881743314596588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.142056280655626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18517646047388819,
                                   1.2058283885503669,
                                   0,
                                   0.42512098345085092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045230205700884221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.772091908263006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64195450858097014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11009218830536593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57473778078605864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51819096737462711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43250353616411574,
                                   0,
                                   0.10208674678679054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089873473552003216,
                                   0,
                                   0.39095461587528557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025615333699129383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21002430039311717,
                                   0,
                                   0,
                                   0,
                                   -0.74485417466158621,
                                   0.021284449562883778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72129879583335788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18940801657784956,
                                   0.23254031166238842,
                                   0,
                                   0.72259865187482131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098322355910799228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56351032096606213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28678486020055233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030874670503949514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21800529485555425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50275200801814512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29616629029915931,
                                   0,
                                   -0.11333134250796896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0191187841415057,
                                   0,
                                   -0.96485824050841185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21456535262940415,
                                   0.10421962327848822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37884739314458893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98750482219923297,
                                   0,
                                   0,
                                   -0.022362188942598865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55591573689250251,
                                   0,
                                   0,
                                   0.14533904424218491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14063558368916168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13958881024917369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26854746239523603,
                                   0,
                                   0,
                                   0,
                                   0.39089977940235643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080054309241557028,
                                   0,
                                   0,
                                   -0.19881606598247592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0300783637918849,
                                   0,
                                   0.23530145087542023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14671390508074236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30824012147850011,
                                   -0.26205870290909411,
                                   0,
                                   0.0020189596989818384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56040326768184578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49899188761910107,
                                   0,
                                   -0.24732343974711779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29316960261561659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2557446289126572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39666692078831767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5448345227996394,
                                   0.18322290324548218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36955848425721294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27187831263464135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77161002722102257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30694785028076571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0083854359619924164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018511330180897359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060458924807960723,
                                   0.089971530841357228,
                                   0.076975346934211722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087792162906903615,
                                   0,
                                   -0.016473462998674721,
                                   0,
                                   0,
                                   -0.18246414690685972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083538673878580105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18994269194300736,
                                   0.39614827068671643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4525521444452153,
                                   0,
                                   0.47465076331464573,
                                   0,
                                   0,
                                   0,
                                   0.37558011576233108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5244701558504159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71717042781663687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51675132196548612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077216131033775171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8292685478070918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58072984169249842,
                                   1.0716319850617353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07844083293177638,
                                   0,
                                   -0.66799256410871954,
                                   0,
                                   0,
                                   0,
                                   -0.63045181037162801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49461722960010263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33826854392301015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19534759185025738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066547020357606124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3887058167667492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19891173766080045,
                                   0,
                                   0,
                                   0,
                                   -0.66437057122765331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44616594343025479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25548804759514038,
                                   -0.32562706456920743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079713150766740848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32558321319209499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11209870599953631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8602893442702535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48993444974202799,
                                   0.24042348078723727,
                                   0.1440006891607625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60610054814829062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12634910774061597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030739682778928717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40895657787813927,
                                   -0.037217345761123885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07602207860206156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46619842375723786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14419298067034853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0820322170267243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20019162127777845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27183812411772729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24401330817294653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3001672707143212,
                                   0,
                                   0,
                                   -0.0034608862525826213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091068903093462078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28673985250779865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39515659350140442,
                                   0.58676110758646138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36043714576179109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23576177941608725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42320329364998499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51564858738754049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30615006583309839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35079507703101948,
                                   0,
                                   -0.43350259223590271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3717462881653486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06074552627953074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091709533241039545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79975758363746841,
                                   0,
                                   0,
                                   0,
                                   -0.35020562828450014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26655001666798911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07628327884514273,
                                   0.67397751939594241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12644911492725358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51596887927845114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36216852660348142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15819117996296678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69324237157090662,
                                   0.20163999200099966,
                                   -0.23331832232637625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14651914029242985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68619831453506941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34887149151752539,
                                   -0.86468750095748348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49389278075818399,
                                   0,
                                   -0.44381261102862468,
                                   0,
                                   0,
                                   0,
                                   -0.49091713225045264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1290388817359113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73711743676598585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29873363855647234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2561234799289806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076627701609275567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59897165178655287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063269115634601414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18761792002303382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.015220986177527,
                                   0,
                                   0.52832044942735579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17053838098383334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22784020396126603,
                                   0,
                                   0,
                                   0,
                                   -0.35626988339258137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32731576305763466,
                                   0,
                                   0,
                                   0,
                                   -0.22264283322452821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52617795015594271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14836764894855964,
                                   0,
                                   -0.31427826331822012,
                                   0.31570601645715213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2668195490328234,
                                   0,
                                   -0.35022303685813988,
                                   0,
                                   0,
                                   0,
                                   0.69447613436368139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043182902907281412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76542655608199694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66314201462266986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70644823374106158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42885713869348774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2991421109311399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096462671337863487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30107513876017666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0386190328321925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28003078090938244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2974560111854872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49496316662415291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23111358283711589,
                                   -0.025576424733082109,
                                   0.49879575763218797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039143774351338645,
                                   0,
                                   0.017531182667812832,
                                   0,
                                   0,
                                   0.16619342701869722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25467773036082858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42093773885176955,
                                   0,
                                   0,
                                   0,
                                   -0.73707313987962753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94606593934980909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24097429992349206,
                                   -0.44923520339256162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061819564662940758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38593002187052533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43817026309146961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72243491060172471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031885970860759963,
                                   0.019346863033074334,
                                   0.38825619565882563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15857727634857366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10171619748033817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2487521400052721,
                                   0,
                                   0,
                                   0,
                                   -0.17321060700930352,
                                   0,
                                   0.53543974330273647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19410558624223467,
                                   -0.21273246393013648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033942144995191825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55405843323656234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037131540506723744,
                                   0,
                                   -0.32669395627213821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23088411246778515,
                                   0,
                                   0,
                                   -0.26101680688055201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028546524436779561,
                                   0,
                                   0,
                                   1.1144642969657468,
                                   0.73902390581846045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34032491592826974,
                                   0,
                                   -0.50911780163918896,
                                   0,
                                   0,
                                   0,
                                   0.065528977933853039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35128139704361883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40739957449319303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10394925866495841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2937726307356745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037180978318226782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0096424102117613764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019826645883871164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11605689208819531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60860518156881427,
                                   0,
                                   -0.87016944240202987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012468208348364318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77291541295284105,
                                   0,
                                   0,
                                   0,
                                   -0.75378018105151645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24044769210910835,
                                   0,
                                   0,
                                   0,
                                   0.25273581316612875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090327461634149273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66225276244497733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28610706468400499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.5659734755320143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25145436674557725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0653293294061046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06469225459131854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1017606336985675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079332556805368409,
                                   0,
                                   0,
                                   0,
                                   0.60026704880952086,
                                   0,
                                   0.46266653158622623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25392933071400392,
                                   -0.089670728194216981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32131674758714374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12044352287320145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26245771302619897,
                                   0,
                                   0.20097865219644978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25878250009979947,
                                   0,
                                   0,
                                   0.052173372553157835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2238002327818967,
                                   0,
                                   0.031573591773979559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46926663662866019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.237514533538462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0082241543593929087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40218433280296995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24743357616572512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084638620653380958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30069872965217331,
                                   -0.010357048028469977,
                                   -0.19831985308714437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22329308853841257,
                                   0,
                                   -0.49725425454676664,
                                   0,
                                   0,
                                   -0.0036614971341087359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25530192168961308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2314779318562781,
                                   0,
                                   0,
                                   0,
                                   -0.26053478694637533,
                                   0,
                                   0.26305596955822741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43548796848484178,
                                   -0.14661354697429538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51823686428992122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067738079232733894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13968650147197711,
                                   0,
                                   0.061256892103801718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22581896700754531,
                                   0,
                                   0,
                                   0.35745310494566679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35072253616802579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91518335689001895,
                                   0,
                                   0,
                                   0,
                                   -0.066200840752889012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54233517706994827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064657965623527672,
                                   -0.68978773176529962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0085070918614535279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36040080700725985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50371666120886072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25679465396817036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08141961166017278,
                                   -0.21577506032718866,
                                   0.56434929109579512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23393241103678963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032425710053726117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00034443220043305078,
                                   0,
                                   0,
                                   0,
                                   -0.49550422128461685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3612692308253474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3102800158644945,
                                   -0.38992426932621516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5235404432350208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30718489722100062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05316849357808727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50673038343478805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50762861214660493,
                                   0.059983160321083015,
                                   -0.57876479864654051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50936268402675733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012675105149328882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23954749330875968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073450021337814697,
                                   0,
                                   0,
                                   0,
                                   -0.43288867156985722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064888233449699101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34293748559386961,
                                   0,
                                   0,
                                   0.79247264241482529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37307232171846871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2686242461781731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0014523423354460235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17839357544271825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19633418256923921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070360356046271819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46212198346465388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23061875069082005,
                                   -0.19917253778348595,
                                   0.12363422904236707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29945211722183185,
                                   0,
                                   -0.40971708756308428,
                                   0,
                                   0,
                                   -0.36481303947200333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031763419826615416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6609754614372304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5340093285321369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21188898569778383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29628139827677574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12279957271036893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42401330716585756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53448701694948442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15474582153218341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13036053309886278,
                                   0,
                                   0,
                                   -0.2112724480186442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06583444413856189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086577759614774902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17021367401381285,
                                   -0.29267983898523148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69438347825372237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14182723015265591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091271966591655984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20316470689935914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5802058284332221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27595361113132438,
                                   0,
                                   -0.20650796743581926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67139673270714462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21308228810545088,
                                   0,
                                   0,
                                   0,
                                   -0.82075005657970179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48110968011048061,
                                   0,
                                   0,
                                   0,
                                   -0.70999887040963849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43703463591273117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49147614084284585,
                                   0,
                                   0,
                                   0,
                                   0.26221309305825385,
                                   0,
                                   0,
                                   0,
                                   -0.068145963770297746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3361835252491282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47477205657487731,
                                   -0.16039175145326018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78492335275643821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10861221500857737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077137437628209182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27593283298669713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032320802495722258,
                                   0.78388486237334076,
                                   -0.1606603797524303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10260245669712527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18123223117240134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73508579352448256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041619612139182756,
                                   0.46391981864280929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062336262866015013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094469751221949172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1796568307054338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21543362398252408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67333284307139907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011072242947638936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19523482967435818,
                                   0.39794191521664379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12127432983416339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8509576966174085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42571369480467414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24678584644417231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71847717872700867,
                                   0,
                                   0,
                                   -0.022165214358083694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052602253618279166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021595625073547099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092999694433335542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24265572906974794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64496952304111999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17532904234880828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32255974784439939,
                                   0.067184713378481795,
                                   0.27245836107820809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53214345914670835,
                                   0,
                                   -0.11536565853199135,
                                   0,
                                   0,
                                   -0.040016776960796689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033752874313554081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22823754903436971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23243384794487149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2315049976681613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47177145444695667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31799747237955261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34905204901608328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049645902703662204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12954587004104845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29260485555661303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59002531725076568,
                                   0,
                                   0.093547653924365495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02628854049330373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2101164742415064,
                                   0,
                                   0,
                                   0,
                                   -0.12484307553398943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29005671723605586,
                                   0,
                                   0,
                                   0,
                                   0.56404875342941119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1583647227382476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021540779641535942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16468117432588053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27671298002954936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090561867358176118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73469181812919915,
                                   0,
                                   0.16066173040976309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32811620650281098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45730848556764148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075716778194818563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18217151020435135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22898587462309508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27164700158713184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5200300410784906,
                                   0,
                                   0.13599701583467938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22963360545226011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58700521154758456,
                                   0,
                                   0,
                                   0,
                                   0.63053445126417629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46794112149511202,
                                   0,
                                   0,
                                   0,
                                   -0.75302427799582949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28594700588442801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052734918510561279,
                                   0,
                                   0,
                                   0,
                                   -0.032832854821226831,
                                   0,
                                   0,
                                   0,
                                   0.44214455084709336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20314902228875237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37687102007392448,
                                   -0.3429182980330503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37895190266197543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43256374725707691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79058981048670196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32622753838850782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41836741032957603,
                                   0.20653344833559101,
                                   0.29110847423506858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3713119138031038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24814268174929524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47074440573753445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26574612081351068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6245093979942431,
                                   0,
                                   0,
                                   -0.18500197249054756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24753527971829345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11174216092489955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19100854545482832,
                                   0.083163864735611076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30119613626910446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27506609234784146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18672153908484895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18816954167512914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074072373544841225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011999640087557346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40559162563608303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030419835976166012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19490455988933073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46575048644397965,
                                   0.24262017148622655,
                                   -0.13825257231062563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040445888557561906,
                                   0,
                                   -0.44782467403251558,
                                   0,
                                   0,
                                   0.026483581979450398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47211527850394125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1741500653434627,
                                   0.40865811987515016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19851951273944535,
                                   0,
                                   0.74066872460438093,
                                   0,
                                   0,
                                   0,
                                   0.24044616163174939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12557590954198364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11473043023758285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0736261905105648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63200517704696202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27879337971070217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098505776739186146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73360114132739507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17448339518502229,
                                   0,
                                   0,
                                   -0.22135475826748305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05685387253766884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24673804858411463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31101258700730694,
                                   0.21113713782054622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38875599743406997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12701425102164399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46409091873689318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17632506748351945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13274091317110842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39169547177132402,
                                   0,
                                   0.20933857500183575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40550960262512936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077599682647173512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60679585490944743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31503591582509599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0121335240379914,
                                   -0.4385149536306463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12813074684474057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53297408666259638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077390975542833973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47163110456536095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69109300255553596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.607134409666508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55350034026904105,
                                   0,
                                   0,
                                   0,
                                   -0.30513679730401128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18879382616032464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36997425256173888,
                                   0,
                                   0,
                                   0.24370609450140721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21990543001925272,
                                   0,
                                   0,
                                   0,
                                   -0.55826208898630791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33327225662279442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66262847630002475,
                                   0.13556903293795911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4779674909352184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68558668820304425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4101689295272597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54459087060891065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5860783432610791,
                                   -0.33299055488923013,
                                   0.06271219737761867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19183420604961196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27754098964660906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065330513344672311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4296463769340243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014075707364172825,
                                   0,
                                   0,
                                   0.31469028951120831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29428438435017978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26981261869847989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10383869311373495,
                                   -0.12712633448094479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17892451669962517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70252978662795373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5672695745403713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50483021056105382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11378390889113138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11868100269962806,
                                   0,
                                   0.011069929209142765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.499716888681141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31923447504963809,
                                   0,
                                   0,
                                   0,
                                   -0.31373908866255057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61765303307473751,
                                   0,
                                   0,
                                   0,
                                   0.15264316343947973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54326325161913791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52287611901915265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2877876140121246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078089834486776338,
                                   0,
                                   0,
                                   0,
                                   -0.62801008972813088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54921991035885498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33140733853423493,
                                   0,
                                   0,
                                   -0.32436131119735928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21331238971284872,
                                   0,
                                   0,
                                   0,
                                   0.025334801246454972,
                                   0,
                                   0.20005407818624077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010127026243817505,
                                   0.042843138239298771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30438884057793353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2407307533825121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038332366115049421,
                                   0,
                                   0.4209237976505345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73342129927125255,
                                   0,
                                   0,
                                   -0.13765177584748639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16059687934513239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10506275812799265,
                                   0,
                                   0,
                                   0,
                                   0.34006707205137116,
                                   0,
                                   0.052270368726730174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034727077169691034,
                                   -0.46249515552167569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41040338081428412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28841263297526726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27641625361397681,
                                   0,
                                   -0.063984043876997035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21783026528810406,
                                   0,
                                   0,
                                   -0.52510395320028036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01339410414827473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14729843625699399,
                                   0,
                                   0,
                                   0,
                                   -0.34960422559519605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06881629484677422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40672981751131132,
                                   -0.045807679546310313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75411549352675966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1304389038500243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023017116524505665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21605939764103244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045145524995465834,
                                   -0.84469589170768911,
                                   -0.37630623158844767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14863584763597246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45981488192515557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79570387288942535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22234393269919706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72531289746215066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6394905664279622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85929548074443141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2508057998868044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5547228130159968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027688586870018982,
                                   0,
                                   0,
                                   0,
                                   0.069814720312682696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64010564268968739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52157759912825041,
                                   0,
                                   0,
                                   -0.069738239071943348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25132254687431399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01811462007637259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47515552051731746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0021957745547381271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32271207915061495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40197232312747044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10989739455033806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20962251916691635,
                                   -0.41423427791663969,
                                   -0.042835429388781002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38175024404466823,
                                   0,
                                   0.24144067681233697,
                                   0,
                                   0,
                                   -0.10309220549059446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030126604759829034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42830678097346681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41308079734643838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094563074266055286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33246339177013001,
                                   0,
                                   -0.53010322240294694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15802721600991443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24987618615765333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39752149444187945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30191080423469563,
                                   0,
                                   0,
                                   0,
                                   -0.0080519999081801186,
                                   0,
                                   0.30079389899027137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14158752845054123,
                                   0.3965082638760406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.359384293555016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15316860849742431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53818597827159909,
                                   0,
                                   -0.017311992562954487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10962521923039721,
                                   0,
                                   0,
                                   -0.1148237622133521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41626734191085191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49989415027679729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12399003039659701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0030619097883725216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072375828390850327,
                                   0,
                                   0.63624623348096698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4883440173130803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03573401561411127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29140797229720772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13800948853253006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085268984871236145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11092617699073253,
                                   0,
                                   0,
                                   -0.08350217580888819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41615287171467163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58089425344830936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46227106264407525,
                                   -0.28108373389599067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0033408272949402296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38867755648580304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36002675296742698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06499219527435611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53706609193144694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50027654580624603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25820046355274817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015300054243723944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13846861811840502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098271537716977317,
                                   -0.25885088068915529,
                                   0.014341881722383501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18026120367879628,
                                   0,
                                   -0.21083841172771881,
                                   0,
                                   0,
                                   0.2767025993200774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10481881539224847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39787616330275105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21240859052554295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096500312117918957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015222844505861449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026373722922294285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015229360123061713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090502309770715494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15752802064550264,
                                   -0.56613706223328653,
                                   -0.47951868168767087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29043908959949355,
                                   0,
                                   0.14916170239919976,
                                   0,
                                   0,
                                   -0.041273949830629146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30715288635078125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17315303796380246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28461981406927328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19333282048792128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14886767565540227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026564363617555584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054522792958772257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11285678603041098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065352844886424261,
                                   -0.26566947948301944,
                                   -0.019223383385755008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068453355855732437,
                                   0,
                                   -0.42595984007259979,
                                   0,
                                   0,
                                   0.52453405317160495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52590012614481951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39211665451151917,
                                   0,
                                   0,
                                   0,
                                   -0.23140438468672586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22278163002100479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.041471460069068,
                                   -0.55812725398328211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1552720625655134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57507589692995098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42327316142077331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14832039016068527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088972972179631349,
                                   0.086161026423485138,
                                   0.20424928156572023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72859604598496497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29973069300525257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22446326649898102,
                                   0,
                                   0,
                                   0,
                                   -0.40797707511577019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66398874862756241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12039280682815097,
                                   0.34065979925617773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10620769043655448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43227131383581519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33056187984764918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45022414478328993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41055245822944259,
                                   0.43392617106963954,
                                   0.049912561960402113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61266071983303294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83913816282720655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32290498384832894,
                                   0,
                                   0,
                                   0,
                                   -0.46249432479350977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28938307139927066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034473181134073279,
                                   -0.073440000755758475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11279025390218975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50567682403994918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050160517584327449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35479890166579331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85804370570224464,
                                   0.6076113619394713,
                                   -0.44989928565536835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30956658216325156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8268663389044868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25302052040566947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84722562968314552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27787527960398284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44124633696410487,
                                   0,
                                   -0.70359807431079813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65296288525566692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79213930034926916,
                                   0,
                                   0,
                                   0,
                                   -0.14168095553549234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13302819736503571,
                                   0,
                                   0,
                                   0,
                                   -0.1239904598597535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3676958309911994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16645127878551846,
                                   0,
                                   0.43578111469694236,
                                   -0.32036256239540151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044120978320147983,
                                   0,
                                   -0.84994216106127707,
                                   0,
                                   0,
                                   0,
                                   0.67834772679148947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51069433392378638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15904889097835745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084518966450305488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26106025658559201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41255889914857186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12724780375316905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035617243786347404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32713128079341897,
                                   0,
                                   0,
                                   -0.55067543659281637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67099112368288072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31422950964447111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095758657207231881,
                                   0.023289404267379923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075611269714588328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088784251774139802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59978036226594378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12319728423284829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49947169701298566,
                                   0,
                                   0,
                                   -0.34426498361129443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025966586276413833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34529248587603062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059406482146411185,
                                   -0.28122277733622142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13886898747158805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18786817303490866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53157585570120258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0454436940652234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9577242075965543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33124243778828011,
                                   0,
                                   -0.041721037550899454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16319749675091738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46632508200074296,
                                   0,
                                   0,
                                   0,
                                   0.19568612972055419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66470293119624091,
                                   0,
                                   0,
                                   0,
                                   -0.12653563030843457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26395537628836807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16918224719534788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097378365008312887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34350213739009383,
                                   0,
                                   0,
                                   0,
                                   0.37999948733227029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4258259038150965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60123127320500447,
                                   0,
                                   0,
                                   0.43048505319492697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25031194735810103,
                                   0,
                                   0,
                                   0,
                                   0.5776887748439653,
                                   0,
                                   -0.32096347494094823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22390531386928925,
                                   0.10796414927925173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30920081588480131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46672221233447059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051535982755896714,
                                   0,
                                   -0.13719133021496546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01392474329193889,
                                   0,
                                   0,
                                   0.16984853704975791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27360116671115242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010573472707344685,
                                   0,
                                   0,
                                   0,
                                   0.24610743242091057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3025178801048144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43022872301966514,
                                   -0.53625720447483072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020067679876308399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044911201101113907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24821564125574583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1214932701225675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15556747313913671,
                                   0.13681320030994937,
                                   -1.0311509990389898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67953373700676245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33734913880890927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41711287563143656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75058914807165755,
                                   0,
                                   0,
                                   0,
                                   0.4193191560280472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25969398195917537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046474440174052403,
                                   0,
                                   0,
                                   0.1311616838568751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036607863567410581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45575417109420591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37353778557880279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011496025279101318,
                                   0,
                                   0.22864382837450639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49229486078275286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10268743482896084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5883098031856322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80071136482293648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31060546783361648,
                                   0.5954774679220618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71634096310496143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51035730286056424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8191435860242926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014866668421219087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11285471594578417,
                                   0,
                                   0,
                                   0.33100853171770317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08577652594040433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31005359292690687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10275281364169928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32876249275170533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26172956114062762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13207390387167547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37530495029867272,
                                   -0.32634443607484892,
                                   0.54319848928389858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15237399946019042,
                                   0,
                                   0.017379068115663979,
                                   0,
                                   0,
                                   0.051191664238108142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11744855378799608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1873950033461976,
                                   0,
                                   0,
                                   0,
                                   -0.15736443294940555,
                                   0,
                                   0.094684457385043649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21487464986539001,
                                   -0.52460700860809228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088530158786553084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028207711368735719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085019285855768373,
                                   0,
                                   0.12433000965414426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12596962477387469,
                                   0,
                                   0,
                                   0.33363841621226364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6717650924659514,
                                   0,
                                   0.24701383904215471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36721059390164412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30751324100529126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21195061095907827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15268870834028331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19039778859119691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20359179184389112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35755598136952138,
                                   0.17128247208958858,
                                   0.0088324543810765974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50538858075136472,
                                   0,
                                   -0.087406982625551161,
                                   0,
                                   0,
                                   -0.36540261041877381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098993271146243206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016518584043867884,
                                   0,
                                   0,
                                   0,
                                   -0.11023265795273274,
                                   0,
                                   0.15893595025345772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33381445983512126,
                                   0.40503626689766137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20357305869932285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069539068113269528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47035092075963852,
                                   0,
                                   0.44258001486647008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36706724804557544,
                                   0,
                                   0,
                                   -0.272309681285622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12063636504365048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26372390357482167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46885300055065204,
                                   1.1049626373221446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0135428559412365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38616024403921212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1062436296676933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011555213778262657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053025465516125969,
                                   0,
                                   0,
                                   0.10577755649079577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037795159689422111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099248926905348311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013966276205952127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13350419907663941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39627510585950682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57929400374502782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2707878902381447,
                                   0.34441821895234626,
                                   -0.23037850843720437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076073902264401583,
                                   0,
                                   0.17012236419354937,
                                   0,
                                   0,
                                   0.4251003519902718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080218076214080267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15472271896822848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36326104090957478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81362588693732674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50728690199598914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97967741213179804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2850137650184674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72811947680242362,
                                   -0.58807634784660401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10806329342215341,
                                   0,
                                   0.048367194056959863,
                                   0,
                                   0,
                                   0,
                                   -0.51296909187881579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0030368479604859638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70479286904127181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40822208329388698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92330076019985419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37189243242596692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062218335223008958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30556567989027361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034080274841816575,
                                   0,
                                   0,
                                   -0.01892726754115133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034317835130523458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21393409492955912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65040165395308291,
                                   0.57898508943149785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28833884570477997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11361312192153908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25908535691452028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29789240156644109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046702899994459271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15409104434986365,
                                   0,
                                   -0.6376737591656958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80160373431788157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36850222259872267,
                                   0,
                                   0,
                                   0,
                                   -0.13029861018546704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086374781629044828,
                                   0,
                                   0,
                                   0,
                                   0.24545135223931749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1985831708369212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9301681154826188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34409456083347539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20511773092478919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80944380096286983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17290425255521027,
                                   0,
                                   -0.065905112523239051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25403665241170748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.251739172995609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14892879624313476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85815777299399676,
                                   0,
                                   0,
                                   0,
                                   -0.10115576360096908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024103131394095069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24677193284000337,
                                   0.55875408401782778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24226694589335054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27506366365315688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64905658907425523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23885197648603995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42591854300672272,
                                   0.01369039711382547,
                                   -0.052640958687606272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46501432759419437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35992150456457744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23695841874739523,
                                   -0.037544073231048122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2571488515922706,
                                   0,
                                   0.52314339952350564,
                                   0,
                                   0,
                                   0,
                                   0.25436445987092088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0039944973946236424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45991882749816054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037088129645086593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22276144182130914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40285511010272396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80568767685014597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2620408767018651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16983422252586639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4006799242157984,
                                   0,
                                   -0.45312958398877895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62804522796645246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2130418423463884,
                                   0,
                                   0,
                                   0,
                                   0.6120515517333851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32490740353221681,
                                   0,
                                   0,
                                   0,
                                   0.33538745525617764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038873952112763288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16212526721795617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11266750380052981,
                                   0,
                                   0,
                                   0,
                                   -0.22774844568702846,
                                   0,
                                   -0.31071462626641461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55006915244454524,
                                   -0.11523941178101935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19179633987040684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012505831424322433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44459831554243817,
                                   0,
                                   -0.080609080924546134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05690940959601834,
                                   0,
                                   0,
                                   -0.52538534575724238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0515824121668602,
                                   0,
                                   -0.37224482383586766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49926832945365002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10778206986667553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18463660137172436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28678609967659818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039451873239876582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1362619380154747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23161833947372781,
                                   0.062834081637126421,
                                   0.129417668199383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12134919531611477,
                                   0,
                                   0.16466376890005607,
                                   0,
                                   0,
                                   0.35042843834547127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47445048206123225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82437683734037948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54310537887789145,
                                   -0.80285869755883776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87750811030597986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4760331770124594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52246439516854748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41030186674572666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35444794260842399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43573394953919276,
                                   0,
                                   0,
                                   0,
                                   0.052215785937370529,
                                   0,
                                   0.22595923794324502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18833571482195322,
                                   0.26191653031528822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20425213279002197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45618217804828454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24120144554780659,
                                   0,
                                   -0.51640996100904968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094269232284066529,
                                   0,
                                   0,
                                   0.05245564054632261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25683548920195959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34154920134413774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68332525675804723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1278828683611835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25937667726480679,
                                   0,
                                   -0.32939892446204072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34466299373025983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45891090796547468,
                                   0,
                                   0,
                                   0,
                                   -0.13713485862964045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15436501302546529,
                                   0,
                                   0,
                                   0,
                                   -0.3188267220858621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21331852710522201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32742500671906827,
                                   0,
                                   0.018782969851912565,
                                   -0.050633152106407446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023929050748979358,
                                   0,
                                   -0.63167003289235624,
                                   0,
                                   0,
                                   0,
                                   0.25268364184228309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2154005361792506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28526600064027319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12260023839202297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.205638072270172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71947119577153174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077522104897495864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077693296048909843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31984095925978906,
                                   0,
                                   0,
                                   0.58651996351351265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4593458678879494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40366658020109369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14651725671618862,
                                   -0.092375560097752107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076812873297054551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36304829670591304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69006901635043205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070856370523152093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3174602058813783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44026654530586312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0376420820139587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81218192724271132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15911203484788145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43663658894063551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27707262741554917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19480040335481458,
                                   0,
                                   -0.00070127850185656981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13915848331065217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80220001903829607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080155884006093026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062904211471649166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25894226748813781,
                                   -0.58954158390250422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30434427708883571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46901189125019704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042001183482970786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35343788113669461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3644117135707845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65570750322925697,
                                   0,
                                   0,
                                   0,
                                   -0.014557236757853413,
                                   0,
                                   0.10940855642453086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37557206852795505,
                                   0.13945924511839827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11577549729597017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27858722514991019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23610461972194827,
                                   0,
                                   -0.40524335081234097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26159022251416619,
                                   0,
                                   0,
                                   0.02029131498018482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13243379681698428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90102298019034943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47655998228075658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16733504286543288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048265760506253218,
                                   0,
                                   0.46196153419417252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27692970602048023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40526828450322494,
                                   0,
                                   0,
                                   0,
                                   -0.033778221148404397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33250170816703811,
                                   0,
                                   0,
                                   0,
                                   0.38492142382301664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44413116042519829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32363064367782868,
                                   0.033529474729279404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49719305088238286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27369958740801009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10106550865929162,
                                   0,
                                   0,
                                   0,
                                   0.25313899472846146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4027608402165801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10057506694980485,
                                   0,
                                   0,
                                   -0.21441162663543056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077460897214211899,
                                   0,
                                   0.20681936880300011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30873119048265762,
                                   0,
                                   0,
                                   0,
                                   -0.23106729337760853,
                                   0,
                                   0,
                                   -0.34617506945544452,
                                   0,
                                   0.25854814992722347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089732307242768719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43550854359880586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22212428660764405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45121650514769157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094039092463425206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73518809658436446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1112105727437942,
                                   0,
                                   0,
                                   0.10995614800167768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67738828126656703,
                                   0.17292542503961275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0074351202449723652,
                                   0,
                                   -0.56215958663232468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25832340528046804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32245015774976105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50415928737791127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0081305131523496943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22529475748215305,
                                   0,
                                   -0.24936011760871657,
                                   0,
                                   0,
                                   -0.70123844742509689,
                                   0,
                                   0.16427923826306604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47502509628332484,
                                   -0.033880505876856565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37359406879617607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1831134809907102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36100006973304999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25665643090511336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37368792825262348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1509396422709611,
                                   0,
                                   0.21725169440691228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057652999655487112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10639778112245368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67975423964083159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35176061823689686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30515789300008783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032702091612642259,
                                   -0.30941844877360142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26314114188867455,
                                   0,
                                   0,
                                   0.077763435663200181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2258789553409255,
                                   0.545395173689458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16742043114273672,
                                   0,
                                   -0.52562220586803865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35595121094482302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38108112119472548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3012093869157712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64206115042911471,
                                   0.26520337492292834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1221449330339537,
                                   0,
                                   0,
                                   0,
                                   0.86999291877731322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25462431683249309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53398450229151118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33546385861707406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33588597513310148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63093185733394441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30190904143194031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016765580392654134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30813917051616724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018024404757665057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047221028093034786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38928816790952858,
                                   0,
                                   0,
                                   0,
                                   0.0080858481492639515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18466093482538981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12638131177371523,
                                   0,
                                   0,
                                   -0.15357163935380236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49106751175477004,
                                   0,
                                   -0.01142878441313332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12748218177857051,
                                   0,
                                   0,
                                   0,
                                   -0.611248455936241,
                                   0,
                                   0,
                                   0.12542994367276344,
                                   0,
                                   -0.17418889903918658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21203171169814522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0058892161892534212,
                                   0,
                                   -0.53808348721881227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15904636368089806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14382892412084275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12615971576402241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34884668793015938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44696696647541179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17514582077494126,
                                   -0.50142368583757424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0800811418934082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088598353478799519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29601098863434916,
                                   0,
                                   0.8585983075108008,
                                   0,
                                   0,
                                   0.17703238911315655,
                                   0,
                                   -0.054134977071466833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3606114529154259,
                                   -0.063366339309974345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19784649848251892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30071612383858648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51106524924256524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27656684123732633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21450428073563801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34294902265914184,
                                   0,
                                   -0.18667894471316546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2693298848215851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038032973519213593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030265666898466211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0062145985313356855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22721093077585833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81681688647401618,
                                   0.088150406411038038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027277402173163608,
                                   0.46947847331437298,
                                   0,
                                   0.1278253351559786,
                                   0.14192472009214444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64123801310174389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30400658893196408,
                                   0,
                                   0,
                                   0,
                                   -0.0047114429172504108,
                                   0,
                                   0.32171056564101519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2960983132619609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09344352054072512,
                                   0,
                                   0,
                                   0,
                                   -0.19623139977676504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018033794331769503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14014434245871221,
                                   -0.52883284012415721,
                                   0,
                                   0.10300460744460928,
                                   0.30714492348083777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30553930324751866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019388911099322004,
                                   0,
                                   0,
                                   0,
                                   -0.3193197860989121,
                                   0,
                                   0.17402418707441467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27966226494858731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47390595026174237,
                                   0,
                                   0,
                                   0,
                                   0.046182892343883203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25463111838401931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6396388099170528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03161134161189498,
                                   0,
                                   0,
                                   0,
                                   -0.67528168849595638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60999009613716915,
                                   0,
                                   0,
                                   0,
                                   -0.21851938088793449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45322716886454617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16113745000497187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13376436275243969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21144603369139961,
                                   0.27491998615663954,
                                   0,
                                   -0.35360243215570608,
                                   0.2522178019330415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072493075113146468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2529097361349929,
                                   0,
                                   0,
                                   0,
                                   -0.099490648984776844,
                                   0,
                                   -0.64115381898660029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099737646048037476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35889776971056692,
                                   0,
                                   0,
                                   0,
                                   0.24416481511388194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049942195783530555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19979510863207978,
                                   0.00090884851595390143,
                                   0,
                                   -0.30432978465646776,
                                   0.3172090001354087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31984792280091801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16225555764363103,
                                   0,
                                   0,
                                   0,
                                   0.58953989173146004,
                                   0,
                                   0.44157221856396156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033811883395828107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25421148390404091,
                                   0,
                                   0,
                                   0,
                                   0.031497135650209646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17003311897076062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23379963610034996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23403678136965306,
                                   0,
                                   0.16154176912721938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17750174205050179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058446377258483416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32731891511676453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73243668896068459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07563142404041584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31114869264036593,
                                   -0.28880984703438062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64320097696794332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.368734370035883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30306667893393607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52893824254480293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024778379314410764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27944305894733534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90627924183148423,
                                   0,
                                   0,
                                   0,
                                   -0.044054139972082365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60127351776758808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16974191132022345,
                                   0.017090408985450115,
                                   0,
                                   0,
                                   0.1015657166680258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17409467188388575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48482493978726637,
                                   0,
                                   0,
                                   0.2225782215002359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35221185985916792,
                                   0,
                                   -0.69180098943420654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059188435760150648,
                                   0,
                                   0.37631061014309047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17176996575845904,
                                   0,
                                   0,
                                   0,
                                   -0.74749823498799295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22149687616314906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025177721832393064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30226052657740848,
                                   0,
                                   0,
                                   0,
                                   0.19090623829675518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030196489875638576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084967191127577391,
                                   0,
                                   0,
                                   -0.37987312580274324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0090602290537318449,
                                   0,
                                   -0.14358125116781043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0045554532720785464,
                                   0,
                                   0,
                                   0,
                                   -0.12436478976428794,
                                   0,
                                   0,
                                   0.060598804775858481,
                                   0,
                                   0.26730677539911596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36309427980298509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1324788761758144,
                                   0,
                                   0,
                                   0,
                                   -0.33577623170985155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14403644419899744,
                                   0,
                                   0,
                                   0,
                                   0.47037473746321279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22037940583654822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01168028401592097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56424714779791707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43221518033349465,
                                   0,
                                   -0.4234724523868173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049528331819543435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088844294959339445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55919463592469154,
                                   0,
                                   0,
                                   0,
                                   0.071928926002508692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26423767576546153,
                                   0,
                                   -0.47271795466354677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46862946023314961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058429427105524324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21527931989243532,
                                   0,
                                   0,
                                   0,
                                   -0.025633085481936595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20992908763235135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4590669809059012,
                                   0.13648492195949077,
                                   0,
                                   0,
                                   -0.74816754829253096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11299385974341238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2397650783631623,
                                   0,
                                   0,
                                   0.34841355888826209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3899613717564448,
                                   0,
                                   -0.60549049363710217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29319339206510636,
                                   0,
                                   0.089962281166533375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52329948276245664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13265345152268354,
                                   0,
                                   -0.6009380636769085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51749582899896707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4735878534759419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51869294453406556,
                                   0,
                                   0,
                                   0,
                                   0.28797836742975202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51545445584785898,
                                   0,
                                   0.15688205332183577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38607852553302308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38767772669146394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73947323520399588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30312936232053567,
                                   0,
                                   0,
                                   0,
                                   -0.31238070309956623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060448639434936585,
                                   0,
                                   0,
                                   0,
                                   0.48564628062519211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1947996474746512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18509698208374639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072040508908194634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56873385296207113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064908079675131708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24207820693137716,
                                   0,
                                   -0.5708113309430769,
                                   0,
                                   0,
                                   -0.12813748611216541,
                                   0,
                                   0.094157301497132362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58830146233208602,
                                   -0.043254312992112964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49111136193888905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42962207598779251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41501790487709012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38618024592744826,
                                   0,
                                   0,
                                   -0.45091629141866973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15043798050524121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35673554544060232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22353116744109136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68030055772260256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36607052751986513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10485579906501563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1473496794488192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22215879825746221,
                                   0,
                                   -0.43854982042732615,
                                   0,
                                   0,
                                   -0.27329319442110434,
                                   0,
                                   -0.10955563710073597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067468023908935831,
                                   0.12319658082169371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12464919643906922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25581995397490409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.158519886469903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48842961016266401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11243485223259958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0727619304837583,
                                   -0.20993224842779634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39165807876054948,
                                   0,
                                   0,
                                   0,
                                   -0.98081312423662093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47497252527132439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44080223592131157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72125007082675696,
                                   0.44602520342492824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90420160249012316,
                                   0,
                                   0,
                                   0,
                                   -0.68683403660254982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12570918090984973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20910280385182042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2566249883605497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62040010116340671,
                                   0,
                                   -0.1281814827608635,
                                   0,
                                   0,
                                   -0.55427020874740074,
                                   0,
                                   -0.12074652729503638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22505775375142742,
                                   0.36629355957659315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53417039164713898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093552209950576809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0034907610491808905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59102597545183444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15424300754992787,
                                   0,
                                   0,
                                   0,
                                   -0.20915619677843328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04686357022859669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0041733966187107591,
                                   0.84636117042704961,
                                   0,
                                   0,
                                   0.51960248908707107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53282131635343344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60177323676762262,
                                   0,
                                   0,
                                   0.033898013848249309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7444440871961735,
                                   0,
                                   -0.51400839561158262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39372851099858353,
                                   0,
                                   -0.049473152150064897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24142296896851795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097823144801886114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11328659214538576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48750119007782333,
                                   0,
                                   0.028641878397236989,
                                   0,
                                   0,
                                   -0.24442661698727511,
                                   0,
                                   0.14215278865449824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14992719701437468,
                                   0.99865182391795526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56305398292410302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012217252289896143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079974759753893912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4928184978091511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16083204931795916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22269633794180366,
                                   0,
                                   0,
                                   0,
                                   1.066081307284376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15924519669213294,
                                   0,
                                   0,
                                   0,
                                   0.47797002830179641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76191436447408467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10417453844035846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98832369742021775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63620439123265848,
                                   0,
                                   0,
                                   0.028415388368192695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.131964104378261,
                                   0.51272880249814967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23370589712909873,
                                   0,
                                   0.20708474389699896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42125717297815135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19791676339127379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43309315693326261,
                                   0,
                                   0,
                                   0.26258214022463466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32726879446143187,
                                   -0.064996792122761701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21473793797863866,
                                   0,
                                   -0.15283602136449009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46129713773311298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59151095469444537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12957332447861769,
                                   0,
                                   0.077528612165025823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72946958773213066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38011049896429605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13202320499268266,
                                   0,
                                   0,
                                   0,
                                   0.34963036091343863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36458948698282845,
                                   0,
                                   -0.098636903597854944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30474150670385103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39094056318822357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09865110540960989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20699052770592188,
                                   0,
                                   0,
                                   0,
                                   0.17850734413831673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0710259644534916,
                                   0,
                                   0,
                                   0,
                                   -0.87155667828630223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058642656999860598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98390209682750629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013728241083546422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29802929398014077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14610149553066334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32522270197775427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42381577983717172,
                                   0,
                                   0,
                                   0,
                                   0.17792345912713625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30486204829076735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033960328370470708,
                                   0,
                                   0,
                                   0.08299523355805466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16466956313142506,
                                   0,
                                   0.28117897682496051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51579130310249666,
                                   0,
                                   0,
                                   0,
                                   -0.025851815900501281,
                                   0,
                                   0,
                                   0.22817682204972184,
                                   0,
                                   -0.21645508639914629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23707031749199525,
                                   0,
                                   0,
                                   0,
                                   0.37330895901657868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12821738903752122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23522538603360019,
                                   -0.29767122584799899,
                                   0,
                                   0,
                                   0.17657298631050344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1474748606980438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18405999195218875,
                                   0,
                                   0,
                                   -0.34966556538408217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1762302587797458,
                                   0,
                                   -0.47665545405373383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37876779134563249,
                                   0,
                                   -0.94939086372520232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088997233333960937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50253404171664928,
                                   0,
                                   0,
                                   0,
                                   -0.16432254692140774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010033807956310398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64516405332016769,
                                   0.51006617871633342,
                                   0,
                                   0,
                                   -0.45367281623915956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76799423392296018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085279563949899995,
                                   0,
                                   0,
                                   -0.16693053874532104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12721753691383592,
                                   0,
                                   0.15634407767146216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10104593488589125,
                                   0,
                                   -0.99605221249438558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20893511547205931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061560770623942315,
                                   -0.23958508817146179,
                                   0,
                                   -0.15400159078661435,
                                   0.30396377190847901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40691962601649478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13310144419017614,
                                   0,
                                   0,
                                   0,
                                   0.43613909316283489,
                                   0,
                                   -0.34887546180895002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10156572106822069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43320245988576817,
                                   0,
                                   0,
                                   0,
                                   -0.29908346257723822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20009231617886519,
                                   0,
                                   0,
                                   0.13868582651352512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.217009445324677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14555695340248154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19598698380229371,
                                   0,
                                   0,
                                   0,
                                   0.046140025966935547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43761993638335306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10318158279564098,
                                   0,
                                   0,
                                   0.15376133017871912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072884326102608601,
                                   0,
                                   0.13989232229823087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073925343239298974,
                                   0,
                                   0,
                                   0,
                                   -0.18069931055854144,
                                   0,
                                   0,
                                   0.59809111042237761,
                                   0,
                                   0.47479907419078082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3896810851107802,
                                   0,
                                   0,
                                   0,
                                   0.83310292346606929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082764421951536438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11538434846381641,
                                   0.63739396175805552,
                                   0,
                                   0,
                                   0.35015677842836801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17320617432533025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23058673492597953,
                                   0,
                                   0,
                                   0.24164074016762793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072774566305920663,
                                   0,
                                   0.40549253901554549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.840574779298077,
                                   0,
                                   -0.1640063108070795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09349395082608386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0416164478491712,
                                   0,
                                   -0.024802433682522357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22961096101103876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21930148284000739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25516538670667238,
                                   0,
                                   0,
                                   0,
                                   -0.23760119597711046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0081917353529478258,
                                   0,
                                   -0.53845099424571885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69263690291925617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19456679392399676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3478862016848112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1148321202512757,
                                   0.038766388641948757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46138911692874629,
                                   0,
                                   0,
                                   0,
                                   -0.36443485144244392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24921011612026189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079741421759296813,
                                   -0.014837724547412525,
                                   0,
                                   -0.075151695005607574,
                                   0.32047849682581853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25095101111942791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054816443666103387,
                                   0,
                                   0,
                                   0,
                                   -0.19002375895007312,
                                   0,
                                   0.0029023846060359584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12509696880609353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083632001709909837,
                                   0,
                                   0,
                                   0,
                                   -0.68943044792169239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53386355211809067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066339325139654265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30837602513483081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31906000570446069,
                                   0,
                                   0.66721297214617614,
                                   0,
                                   0,
                                   0.059235090633312344,
                                   0,
                                   -0.22388387835173093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097444147848075369,
                                   0.4441835052862631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84890638207005642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41227695907148437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20272998923264082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37009988483769107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4664582862116079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35550866687245186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071918483411447451,
                                   0,
                                   -0.49658655540647589,
                                   0,
                                   0,
                                   0.67110544823340412,
                                   0,
                                   0.092230953895522327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5834475950928053,
                                   0.26672438602390108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47643663166324596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34118268591516032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43543625473095193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47715278281471496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20998762220937983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79453405248742448,
                                   0.63293038787830302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017369972695304436,
                                   0,
                                   0,
                                   0,
                                   -0.44107438464324378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71659925374652023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098914455889900277,
                                   -0.00257883001129533,
                                   0,
                                   0.41591588462699508,
                                   0.31059905618623845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34464043501380909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5761850537224843,
                                   0,
                                   0,
                                   0,
                                   -0.14518188387645248,
                                   0,
                                   -0.13728229840046774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082796431673885534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27895361680516906,
                                   0,
                                   0,
                                   0,
                                   -0.022377605359484638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38064406231410042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33539915114820507,
                                   0,
                                   0,
                                   0,
                                   -0.96460126338195773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39064950215518163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31216190348566375,
                                   -0.50735360588314393,
                                   0,
                                   0,
                                   0.073329885718477011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40235519798119906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29196186763839604,
                                   0,
                                   0,
                                   0.54307439444618866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37146457841218711,
                                   0,
                                   0.15005922735836308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054388678376900701,
                                   0,
                                   -0.70536942317997031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0025601785643544362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72916576859876014,
                                   -0.28331302093788802,
                                   0,
                                   0.31480436307010096,
                                   0.26605497687020713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027604005605914056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16888002458010351,
                                   0,
                                   0,
                                   0,
                                   -0.033039234967965819,
                                   0,
                                   -0.036523208752484534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34523228185591553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05786835101184018,
                                   0,
                                   0,
                                   0,
                                   0.10502260279028544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22998298874442172,
                                   0,
                                   0,
                                   0,
                                   -0.29762756581594874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20994195989458961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78635198791303484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16821318218451534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46194976027871759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085437117022430731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42206702172050836,
                                   0,
                                   0,
                                   0.65846769570988306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059623474447300318,
                                   0.36671055084124315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00087249432245644493,
                                   0,
                                   0.4180974012082288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082432188417599042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26200548133256485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11354164073115368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13432634987398503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013109902653433633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0041261069764480856,
                                   0,
                                   0,
                                   0,
                                   0.69795702166624785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19600245757344326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29655512976044701,
                                   0,
                                   0,
                                   -0.033189430849762724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23360685607579659,
                                   0,
                                   -0.10779000253982121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15408160166699125,
                                   0,
                                   0,
                                   0,
                                   0.034653640660108877,
                                   0,
                                   0,
                                   0.12885890769212255,
                                   0,
                                   -0.49651878286708129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11183260625070482,
                                   0,
                                   0,
                                   0.52964130200265314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21000516784502404,
                                   -0.46766876792775991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47886333370842593,
                                   0,
                                   -0.048150579764315721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02780968567096332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46016884190079527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12213648798078111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077071927201178558,
                                   -0.78736339446448267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40447687592600268,
                                   0,
                                   0,
                                   0,
                                   -0.4428928710500013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51411517042053634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33640248661483718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4308987675930625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36729232293890574,
                                   0,
                                   0.028267560348070146,
                                   0,
                                   0,
                                   -0.25328033972540098,
                                   0,
                                   -0.14767472692845751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40949766262621268,
                                   0.16554697186950312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18671564937925136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55699884858941495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32221070921597672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62270619195163734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1064662265887876,
                                   0,
                                   0,
                                   0,
                                   0.48548759639839073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052105661653583185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57289102293206373,
                                   -0.37987490149151054,
                                   0,
                                   0,
                                   -0.0741797288442788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65853617526577934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40028681265250871,
                                   0,
                                   0,
                                   0.65386120443549034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42605165011274992,
                                   0,
                                   0.22906801122942874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50465934775789201,
                                   0,
                                   -0.37490835940410838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29223157148725365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10872313819779514,
                                   0,
                                   0.25019441495690459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039602229448021421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68045205421980315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1024449231455631,
                                   0,
                                   0,
                                   0,
                                   -0.88151475593868056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19406204964635312,
                                   0,
                                   -0.68909349060451552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10002522839410069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47721860169449754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2754383464641661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049642504323225103,
                                   0,
                                   -0.24948230618321979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17650454527881979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81440097129746303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11206093289405364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29875654576170674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14107182487982839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20278535592463706,
                                   -0.046784984127537246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52676859661352382,
                                   0,
                                   0,
                                   0,
                                   0.46727615355534169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22511633990466956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035357137483311804,
                                   -0.18572850504549598,
                                   0,
                                   0,
                                   0.28093013028443087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63981690989817408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32645903133910142,
                                   0,
                                   0,
                                   -0.14353039488391089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72462321669743679,
                                   0,
                                   0.42135126515982918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052482091607181952,
                                   0,
                                   0.19280441647605812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23058638313765328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074442018152981626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059732577049439767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070927899474276745,
                                   0,
                                   0.68465214309369737,
                                   0,
                                   0,
                                   -0.27483846715401866,
                                   0,
                                   1.0588587552412509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18939132545018283,
                                   -0.087943313416302904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3195772186854226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48842252181964335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19865640783856264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039319559957150987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37664389344770521,
                                   0,
                                   -0.083753983543458962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11084558701814773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13610300007465487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51774444384585527,
                                   0,
                                   0,
                                   0,
                                   -0.1403863384882611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13717174869004184,
                                   0,
                                   0.46351034888250398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68733638848500489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41787662620264637,
                                   -0.24597559479256825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51944641061940477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28156001460284968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19629096577177871,
                                   0,
                                   0,
                                   0,
                                   -0.10399235579237345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26954030095319881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22562258664029436,
                                   0,
                                   0,
                                   0.43107471321360613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18503864842752185,
                                   0,
                                   -0.42403355338752502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081707258203962768,
                                   0,
                                   0,
                                   0,
                                   -0.0050012733136868825,
                                   0,
                                   0,
                                   0.043004836586589337,
                                   0,
                                   -0.095255675739082488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034547037160458594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70365052395742189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019552566386529302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20072651787653656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47242690635653317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48971606332357137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029706853787055627,
                                   0,
                                   0,
                                   -0.3818874879763009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48263896525513883,
                                   0.2021031588383651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47816161881034397,
                                   0,
                                   0.37999447676035936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45125273049996106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053198016080013524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10688822984007744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057860256865337349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26647818296195691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24343432624738848,
                                   0,
                                   0,
                                   0,
                                   0.32489934456068198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36990198796078066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24956044223628843,
                                   0,
                                   0,
                                   0.03703399853458253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27030448100699478,
                                   0,
                                   0.015029854462668912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45763812726509506,
                                   0,
                                   0,
                                   0,
                                   -0.023115093779049214,
                                   0,
                                   0,
                                   -0.3533144504370071,
                                   0,
                                   0.37527154792846418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31349807740995422,
                                   0.29935540946769013,
                                   0,
                                   0.13262893858292213,
                                   0.56710815604126219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029414791315740721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34984909483927962,
                                   0,
                                   0,
                                   0,
                                   -0.021375621902328994,
                                   0,
                                   0.13283342429745199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14236679174833811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21197475226711082,
                                   0,
                                   0,
                                   0,
                                   0.45582755990747031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24199499993102241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0070918662152407927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055656532190508035,
                                   0,
                                   -0.68869034182839706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0010931108474525331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42551670973834815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31914811864576131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23386809182618282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18821796585482567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27048491363871885,
                                   0.27632246847894759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48547716474429259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33414259694193826,
                                   0,
                                   0,
                                   0,
                                   0.58064602569257751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2909247781499425,
                                   0,
                                   0,
                                   0,
                                   -0.19948228495846265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73842482454622571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45250133161602751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84654286643847465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0010246758819968827,
                                   0,
                                   0.32760066528141252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8055690859749598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043070587090566569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21311012983995545,
                                   0,
                                   0,
                                   0,
                                   0.73365791318261819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091203271094220578,
                                   0,
                                   -0.18887243063098441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64399278623268408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33057292253716852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13232242874785083,
                                   0,
                                   0,
                                   0,
                                   -0.15363645785638974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74944310267723657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55394618895961623,
                                   -0.41129858428072869,
                                   0,
                                   0,
                                   0.058095550037122509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34773126826954792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31158257629216118,
                                   0,
                                   0,
                                   0.18303469066186273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61180899384517518,
                                   0,
                                   0.12061044363207238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31005476588759084,
                                   0,
                                   0.18111736029254738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71132589933089996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056646173510193652,
                                   0,
                                   0.5295794845738111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24789539113727468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057400199339812469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22395122171356938,
                                   0,
                                   0,
                                   0,
                                   0.093392671023742449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68073689167895812,
                                   0,
                                   0.56862642856682344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053429945953074681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23774443148942931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10762874668654639,
                                   0,
                                   0,
                                   0,
                                   0.26795796105037706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1082157809175603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51537734662076617,
                                   0.12276302731522654,
                                   0,
                                   0,
                                   0.22110128016324126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47027763190712468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23490348676895903,
                                   0,
                                   0,
                                   0.046130506667149601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38727481716566148,
                                   0,
                                   0.060963028862237499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85404839040180236,
                                   0,
                                   -0.16670023319770985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20618139159436516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50336017027511604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86665843610960946,
                                   0,
                                   0,
                                   0,
                                   -0.38903249227996228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51309860401953289,
                                   0,
                                   0,
                                   0,
                                   0.81678457814286376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15864593281003803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15354887184569843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23181434068860762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076900564585041617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14366702542176679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098317742935869604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080616143036047472,
                                   0,
                                   0,
                                   0,
                                   0.097637758201084779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35852754597644082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19706602514447485,
                                   0,
                                   0,
                                   -0.31783768441300764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64157909225825438,
                                   0,
                                   -0.16242354814149623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12593160933616504,
                                   0,
                                   0,
                                   0,
                                   0.45758265334073339,
                                   0,
                                   0,
                                   -0.1081994497243015,
                                   0,
                                   -0.066309022964187281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41224883639442877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46363721154482102,
                                   0,
                                   -0.16741292317844064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21446975312131614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037160985900770868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2810082145510821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11077046904041633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62251939768478359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039239712787743214,
                                   -0.2436806582970521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2827382825349592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17689989927415403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25287791501400947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099187553640094933,
                                   0,
                                   0,
                                   0,
                                   0.13155884047529026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091516690361260589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37342681673237521,
                                   0,
                                   0,
                                   0.17882358346758345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26983975776770186,
                                   0,
                                   0.5288582697574753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46708826704549,
                                   0,
                                   0,
                                   0,
                                   -0.02903602238162814,
                                   0,
                                   0,
                                   0.095301208790537939,
                                   0,
                                   -0.19305480926108612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47289515955182776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17590342051951988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50192275025725641,
                                   0,
                                   -0.42774116341235696,
                                   0,
                                   0,
                                   -0.37405264508100206,
                                   0,
                                   -0.38635865581545126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66931703354118299,
                                   -0.037336161579353891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041944666803722053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26983602984293692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26152319399723256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064883823159994108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24511727371406167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34982928919020817,
                                   0,
                                   0,
                                   0,
                                   0.17868774283416108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45706058349388629,
                                   0,
                                   0,
                                   0,
                                   0.45980095778684837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29520998284073036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.264761810497014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25385604018690028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26707561144905378,
                                   0,
                                   -0.50309777171673697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35191065186218562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19075869307563142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20328613340706314,
                                   0,
                                   0,
                                   0,
                                   -0.6732694467666922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32009227634633297,
                                   0,
                                   0.9647979397424532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48204995622016966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0911633379859511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41571561398011564,
                                   0.049262141700888856,
                                   0,
                                   -0.20341504463993726,
                                   -0.06553133357939718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11905521702311178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23129216391291635,
                                   0,
                                   0,
                                   0,
                                   -0.26056488380206005,
                                   0,
                                   0.27642789976844118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61253436302142839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42984561709218649,
                                   0,
                                   0,
                                   0,
                                   0.076832395061766035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035160546727065839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51035149070429697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73288175492267882,
                                   0,
                                   -0.17397053758735881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032030123318273679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051648209816538726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17655998412090496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0076377978488208209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25303988541712064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18451168262314427,
                                   0.19789129927006971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17670964170054268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31587264288909783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52074640591092658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096326868431221471,
                                   0,
                                   0,
                                   0,
                                   -0.13889922807021193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019705651335244351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56456177094524151,
                                   0,
                                   0,
                                   0.34633489009656693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25475469238845844,
                                   0,
                                   0.10014407523163425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12809077440029476,
                                   0,
                                   0,
                                   0,
                                   0.1276865265395612,
                                   0,
                                   0,
                                   -0.14783461609109955,
                                   0,
                                   -0.026236905884124351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30590655438017805,
                                   0,
                                   0,
                                   0,
                                   -0.40033652619678806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64473603566677451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42652697562539199,
                                   0.27572568836092348,
                                   0,
                                   0,
                                   0.6122926713698531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0383563260901775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63602166982467445,
                                   0,
                                   0,
                                   -0.16074095603372121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19299689413368259,
                                   0,
                                   -0.15800866786675688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24022324613080837,
                                   0,
                                   -0.29079538265241184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4262732178635727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16153373067680776,
                                   0.26255223396386107,
                                   0,
                                   -0.30511591024379259,
                                   0.16201611048949063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15086130754228488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43971413978779011,
                                   0,
                                   0,
                                   0,
                                   -0.41508970853350496,
                                   0,
                                   0.070127806368958837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21107697804621084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063244256255255704,
                                   0,
                                   0,
                                   0,
                                   -0.24096695552593655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53449490651184095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76978890846102677,
                                   0,
                                   0,
                                   0,
                                   0.37988901988715101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28106103693509821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30093031360931505,
                                   0.23001903832371673,
                                   0,
                                   0,
                                   -0.6016711479378406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70307059066454236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18192841475463656,
                                   0,
                                   0,
                                   0.16183259790533333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0058927920517134191,
                                   0,
                                   -0.27428755018892476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0024382109922418266,
                                   0,
                                   -0.1616368006848794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33657702206581602,
                                   0,
                                   0,
                                   0,
                                   0.1743925857891753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24443642749804892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052092687411128422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51562516198923825,
                                   0,
                                   0,
                                   0,
                                   0.070386156011684256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17959832175179136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28743817449494902,
                                   0,
                                   0,
                                   -0.090277864705084532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027208462256097514,
                                   0,
                                   0.34580383710794033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10369840624871438,
                                   0,
                                   0,
                                   0,
                                   0.53276534383078078,
                                   0,
                                   0,
                                   0.24958138900710578,
                                   0,
                                   0.18992315042526869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37534822734887491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17149889625527465,
                                   0,
                                   -0.035574630604126162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31328788725754392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33799754392234149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36524048032333345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24807903917187124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063397142605840007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23042145086986243,
                                   -0.60331383343332623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25983631963626103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13321510609434756,
                                   0,
                                   -0.078923338268078347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83126853485515251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02293552276271088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23666725502619892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015714030463840428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37262343942823573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035900271860093688,
                                   -0.14346127161062341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050695176248873472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20758445764364139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52002182193828184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10867499115103285,
                                   0,
                                   0,
                                   0,
                                   0.30185781486673768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31494329854177017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26218589128650838,
                                   0,
                                   0,
                                   0.1237074697246905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088365540794720199,
                                   0,
                                   -0.45575289430103372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089354876126346405,
                                   0,
                                   0,
                                   0,
                                   0.10618083292907483,
                                   0,
                                   0,
                                   0.33379046296501552,
                                   0,
                                   0.22706702955108529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36678827427088445,
                                   0,
                                   0,
                                   0.22840317505679542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29155947121451375,
                                   0.10718723145914787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64283349519348287,
                                   0,
                                   0.14119220119144382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4528991361846561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2802044893677394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047251448470402767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29867848626053922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16395989030912153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35741481058626456,
                                   0,
                                   0,
                                   0,
                                   -0.34626609967490085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04090555723644089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32463456045795291,
                                   0,
                                   0,
                                   -0.53936114097542454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024089509348931192,
                                   0,
                                   -0.052978606647189563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32845392013510921,
                                   0,
                                   0,
                                   0,
                                   0.028173970668794811,
                                   0,
                                   0,
                                   0.30223120951345173,
                                   0,
                                   -0.18069937428984087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25900737341919233,
                                   0,
                                   0,
                                   0,
                                   -0.070530045494884258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57317050539142944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15676406651923874,
                                   -0.31708588546975403,
                                   0,
                                   0,
                                   0.50147899787720929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044984912631850893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24264503531161374,
                                   0,
                                   0,
                                   0.7857637798760343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1439888476232534,
                                   0,
                                   -0.63269951555032033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28272409564882595,
                                   0,
                                   -0.040787390178430916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90305120638646907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21489328308064087,
                                   0.35422560526257757,
                                   0,
                                   0.54943928230743677,
                                   -0.082287897401524882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044767105241717842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25776805201663389,
                                   0,
                                   0,
                                   0,
                                   0.22673961567557288,
                                   0,
                                   -0.13883714536039468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48062292931092943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25244293553912123,
                                   0,
                                   0,
                                   0,
                                   -0.22518666105679985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18740420929175691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28316998862216053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45230828844274468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35668254291650237,
                                   0,
                                   0.51477659157588085,
                                   0,
                                   0,
                                   -0.49269347562866672,
                                   0,
                                   -0.10163665388541908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088662599521768373,
                                   -0.36121071068203153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26116143494123173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58920639788650786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72235033671697746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30405559069991056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023056297386761328,
                                   0,
                                   -0.02447213752266883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69738076574060603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53750965949533935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50743203114692592,
                                   0,
                                   0,
                                   0,
                                   -0.054340200253303064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3222813398595924,
                                   0,
                                   -0.54176656022573599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083453539782264496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16999993842705974,
                                   -0.069749334927832266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20637997581133108,
                                   0.43267668447283308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38238963206235876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1595532842678376,
                                   -0.019198567383360621,
                                   0,
                                   0,
                                   -0.368567935724878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5107980264348414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12168523123734337,
                                   0,
                                   -0.4262878297586204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97194762413238889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23486606342198693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11582664527730065,
                                   0,
                                   0.31240115248264877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71185796881971053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28822061009588362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37312411042081761,
                                   0,
                                   0,
                                   -0.99845878266125032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02852753182052007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21037246767607362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67819238714225638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34986758256442663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094733899571123062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11715275314478867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87962037036149021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39287431714912058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13492302608459092,
                                   0,
                                   0,
                                   0,
                                   -0.054067031910632196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51965724346070585,
                                   0,
                                   0,
                                   -0.33554101431479011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23175322100816464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33897960356038387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057628869386268294,
                                   0,
                                   0,
                                   0,
                                   0.65138567412832615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045862098853860667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27588782435740433,
                                   0,
                                   0,
                                   -0.015820128560294165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26694112960404703,
                                   0,
                                   0.38691043463857222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12883954567827535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26518272568867268,
                                   -0.12620139569853869,
                                   0,
                                   -0.48689481972182691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06129199796059269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49655838971891764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28894056406088975,
                                   0.040903157122856547,
                                   0,
                                   0,
                                   0,
                                   -0.15866166256138567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39854403105473579,
                                   0,
                                   0,
                                   -0.54212551206038173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48428944228769744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26672634647995425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17007228234311481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2712749106178976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38232305451679532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90782170637547488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79020178567620813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26665991889515173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8229859911853199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089386648339897248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029608506859721752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26000270206241077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66628580789328762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54390594902299683,
                                   -0.16200928386932739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32323411660519158,
                                   -0.31460361015543298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077729024556313059,
                                   0,
                                   0.3515423998195597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015658700466596766,
                                   0,
                                   0,
                                   0,
                                   -0.41096791473016808,
                                   0,
                                   0,
                                   -0.074646023463789513,
                                   0,
                                   0,
                                   0,
                                   -0.27969691370590483,
                                   0,
                                   0,
                                   0,
                                   0.3347129692996817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34524346204391099,
                                   0,
                                   0,
                                   -0.14785152253473899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3436604600019581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010815523023725293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49422271846023841,
                                   0,
                                   0,
                                   0,
                                   -0.55336078745858075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56045607525268959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84275083541207352,
                                   0,
                                   0,
                                   -0.092580637954462128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10341303178142024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076993039737061841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00011995014071892324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1664755618842559,
                                   0,
                                   -0.20521153073256257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20155950796536989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38468193358354197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035786309177866127,
                                   0,
                                   1.056335401855762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046167387410570637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80815080767179615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40591859619288384,
                                   0,
                                   -0.14117667868382558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0049249179054491332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87775685165976536,
                                   0.023422499127915983,
                                   0,
                                   0,
                                   0,
                                   0.20619421460764742,
                                   0,
                                   0,
                                   0.10596996689614563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46234460316164588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28806279538890933,
                                   0,
                                   -0.80330969986176548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037804574233576138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065824494979180387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16480363378710153,
                                   0,
                                   0.30371799659508025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29671540539005575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37556295642596049,
                                   0,
                                   0,
                                   0.11374982747297918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047906572592370314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60191669400654058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40355784608944933,
                                   0,
                                   0.13080239422500078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0091428119531957938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010377771938802016,
                                   0,
                                   0,
                                   0,
                                   0.30628469549101933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048929732478616872,
                                   0,
                                   0.24062271316425654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11797209926999003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47174765520454642,
                                   0.21842779142667229,
                                   0,
                                   0,
                                   0,
                                   0.87360237593389833,
                                   0,
                                   0,
                                   -0.66842163316807113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054587585654047352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10084479005162789,
                                   0,
                                   -0.52767251526608083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73773824302999202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077721127878510335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43769947368490469,
                                   0,
                                   0.30451883938975838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25369129420835124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22996589156076924,
                                   0,
                                   0,
                                   0.34787510808573563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010926517128532372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16462468780823133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54021453924349427,
                                   0,
                                   0.31131288063149209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06457255524211393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13363695075258078,
                                   0,
                                   0,
                                   0,
                                   0.19857036073383025,
                                   0,
                                   0,
                                   -0.16177244730789964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45623569736120889,
                                   0.65289187161180851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087337413764471072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025011443852720236,
                                   -0.1963145066422867,
                                   0,
                                   0,
                                   0.28918903536811685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20320919843192445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36323517410893763,
                                   0,
                                   -0.18908732857933147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53059267528940357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018750300921349772,
                                   0.11821961627466038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63963894626615203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31830302775320607,
                                   0.21497963004610693,
                                   0,
                                   0,
                                   0.18904140909490477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010936681536681765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25057438056241543,
                                   0,
                                   0.2209731556784994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18324736016343218,
                                   0,
                                   0,
                                   0,
                                   -0.011265919478433653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50211438838332501,
                                   0,
                                   0,
                                   -0.30901910730078153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35632624440671296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46699633524938022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48906915427440517,
                                   0,
                                   0,
                                   0,
                                   -0.18557804045974619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39099570266864681,
                                   0,
                                   0,
                                   0.10918744482868267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2786853769408803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97071695090118226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24535574854068976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64042170132792686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066358002000737923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44702453889378913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51895492993601067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11513466347313789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40646019678257173,
                                   0,
                                   -0.31040816636821378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65797637504301487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037917100103537174,
                                   0.58503053311621578,
                                   0,
                                   0,
                                   0,
                                   -0.33940197065977179,
                                   0,
                                   0,
                                   -0.34895622426666134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23150735724723007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20198436948414619,
                                   0,
                                   -0.45788495937457574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6037842214018857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54749733842147219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21811871508741337,
                                   0,
                                   0,
                                   0,
                                   -0.30999616315049222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066678795065260615,
                                   0,
                                   0,
                                   -0.28982155182369868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066048506971443322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60919023346749435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58956520063397577,
                                   0,
                                   0,
                                   0,
                                   0.21171145392675403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14876807012644272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063062698392877301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29757268446291296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48237080656270653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035279201504978791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092361990958642212,
                                   1.1047953333579155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60484882154835873,
                                   0.042401069048895457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14124936252294806,
                                   0,
                                   -0.1578691025560825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32943723173206813,
                                   0,
                                   0,
                                   0,
                                   0.2363859525054624,
                                   0,
                                   0,
                                   0.021242669015492932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43741332749572859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21202076237677769,
                                   0,
                                   0,
                                   0.080777892040479887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65517370522573448,
                                   0,
                                   -0.19077713753999448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21570028742274597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075830228481547274,
                                   -0.13520881755844644,
                                   0,
                                   -0.15736673859413447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29505524779066622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23609686837378502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13038132286160561,
                                   0.16124759552455745,
                                   0,
                                   0,
                                   0,
                                   0.10208452358301714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27736310746133475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50432121095640192,
                                   0,
                                   0,
                                   1.0364802727802942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88476750678965077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30456702831444893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25998646254091623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048030562433366897,
                                   0,
                                   -0.43048525005269656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25782590605569011,
                                   0,
                                   0,
                                   -0.35855507945922077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2839101821527627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13379997035192467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52938809381285568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51116525637647459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13459228349636096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26856989427207084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060619601617824308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2443920217236586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32092425501820099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11221206560972657,
                                   0,
                                   0,
                                   -0.42480511568293966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24262618362025934,
                                   0,
                                   -0.1422764485693373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14181148217151757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052139794969812359,
                                   -0.52528583001689311,
                                   0,
                                   0.060033039784508919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37051752154326345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2847050586709694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049311039709028545,
                                   -0.27977326570124905,
                                   0,
                                   0,
                                   0,
                                   -0.15311286342880498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23304560600302499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83673480509220322,
                                   0,
                                   0,
                                   -0.43594318011095734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3472407866758922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12697770154357446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77788666657669492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23087466915155153,
                                   0,
                                   0.96187970256464672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28074019557108121,
                                   0,
                                   0.47110545323904751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055959069513237814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1136133727703271,
                                   0,
                                   0,
                                   0.45593295218745594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1829042543240349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12785940752994351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14944392810987286,
                                   0,
                                   -0.38056162690274153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39813995107375016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05422354434201454,
                                   0,
                                   0,
                                   0,
                                   -0.31130704205046522,
                                   0,
                                   0,
                                   -0.0566175267571239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58426566324544993,
                                   0.3200318979550284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31232863158693225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26056467900201052,
                                   0.20433641727630544,
                                   0,
                                   0,
                                   -0.33162788786876285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20787990409907198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41247352980644636,
                                   0,
                                   0.14995217203605807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15534578941843832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51600771224212416,
                                   0,
                                   0,
                                   -0.086133597517280905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77788332181312769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27833286845348248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14004671355934767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37470272238809299,
                                   0,
                                   0.42483759982777691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42130859240114216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61095744703109145,
                                   0.41425872609434905,
                                   0,
                                   0,
                                   0,
                                   -0.33754941436754793,
                                   0,
                                   0,
                                   -0.3427811393533704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33125767677735307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19233609989534786,
                                   0,
                                   -0.10278521704746774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71693413393814664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019677451378488114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39959338974184627,
                                   0,
                                   0.57582825506601232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30581346023261308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24698865867406586,
                                   -0.49103819738163601,
                                   0,
                                   0,
                                   0,
                                   -0.81914025171454896,
                                   0,
                                   0,
                                   -0.43331003568962989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40222264793799978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67502701585552094,
                                   0,
                                   -0.065687831943291267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024456896407505542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8688784890115423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15640056165350874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34637400388723794,
                                   0,
                                   0,
                                   0.0799309112485386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098193798689922174,
                                   0,
                                   0.17483889826992713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27638484945602421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59966399203552123,
                                   -0.10534732647541697,
                                   0,
                                   -0.41571898290948234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0073189567834355427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064672857445764564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2442729117655201,
                                   -0.048683472327805059,
                                   0,
                                   0,
                                   0,
                                   0.35040405092500726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1084500194494906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29640668655687052,
                                   0,
                                   0,
                                   -0.19240856322981531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1226967665773803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16821023146061631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44359678705679956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36730567816881921,
                                   0,
                                   0.90677303771192697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30580762994655653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19269725101021354,
                                   0,
                                   0,
                                   -0.16927449628409955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1891957630119675,
                                   0,
                                   0.3311820081040826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51071761805090621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10070776442398953,
                                   -0.23170934842278595,
                                   0,
                                   0.086323210513970475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47715622957711207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12143900871103332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098408776550578586,
                                   0.24494363708844175,
                                   0,
                                   0,
                                   0,
                                   0.22582386423433351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40880155127747725,
                                   0,
                                   0.65476462249526324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35379960725119591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27442997099601785,
                                   0.57613692472296607,
                                   0,
                                   0,
                                   0,
                                   0.58478198002929394,
                                   0,
                                   0,
                                   0.28627326524599234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68081388058378511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010377031907414735,
                                   0,
                                   0.11148675227912616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.283544375859344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28164360170638325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17773898371509225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1218814188667008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16094921035347309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67300836800646713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0032654519574558116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31803429295258528,
                                   0.27109906561901143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41666411723691982,
                                   -0.67277092300890784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65372726781225698,
                                   0,
                                   0.41070509830409996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39786326232889191,
                                   0,
                                   0,
                                   0,
                                   -0.36823336533098394,
                                   0,
                                   0,
                                   0.64587247422753469,
                                   0,
                                   0,
                                   0,
                                   -0.11957029311263914,
                                   0,
                                   0,
                                   0,
                                   -0.49536670793426651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22340626684691275,
                                   0,
                                   0,
                                   0.49877160283953476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57606636529790678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28541847822476013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16576304413974602,
                                   0,
                                   0,
                                   0,
                                   -0.02894384334675093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27909723298909989,
                                   0,
                                   0.40607436693089977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10341521538121262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6185151400901987,
                                   -0.31232930122210256,
                                   0,
                                   0,
                                   0,
                                   0.20016014676962821,
                                   0,
                                   0,
                                   0.64525683402289435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2675811511994467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17454565804429295,
                                   0,
                                   -0.59383466412669583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14593322547310456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62440147518202904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42834482042996985,
                                   0,
                                   -0.21486010729145005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28354260974480439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22678191197255904,
                                   0,
                                   0,
                                   0.20476922558345573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -5.0752170220033643e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071037603529907525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22615612731731843,
                                   0,
                                   0.090366037205555125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44357779116158219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3029586282185418,
                                   0,
                                   0,
                                   0,
                                   0.49365455604333786,
                                   0,
                                   0,
                                   -0.60766126811669008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093082733886039812,
                                   -0.013165645429515843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47754439800560455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0054368636615791041,
                                   0.301596901959654,
                                   0,
                                   0,
                                   0.045637798118661838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50897721222544789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19835621740316806,
                                   0,
                                   -0.048840051949886165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055211995793434027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29125183796394055,
                                   0.12305002933297435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27680318632756074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58017164208045269,
                                   0.54234240382337451,
                                   0,
                                   0,
                                   0.036645243150673398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22590918767495854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33270427859656215,
                                   0,
                                   -0.16296717321584281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14716691160013623,
                                   0,
                                   -0.25107624923482791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20915426894513359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41637087399278816,
                                   0,
                                   0,
                                   -0.11384839677621511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39645972344221003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38334325528323543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1618070618016311,
                                   0,
                                   0.16649712128784322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51035366943073079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24855243733517057,
                                   0,
                                   0,
                                   0,
                                   -0.070403014768843752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66720707851270478,
                                   0,
                                   -0.78317735510320785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20187913605934582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47116295829578536,
                                   0.21307763657411433,
                                   0,
                                   0,
                                   0,
                                   0.38597742879131947,
                                   0,
                                   0,
                                   0.25008754217960749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6920441284164448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47170109277808792,
                                   0,
                                   -0.11622657735717171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24410806644830713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10789027539742017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50271017313074795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18472212189424403,
                                   -0.14857850290141544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16886406864688497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39433622089938924,
                                   -0.32268275198122953,
                                   0,
                                   0,
                                   -0.16932714696128234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38664033081181443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26149494011254498,
                                   0,
                                   0.39547734316539951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11081286615218927,
                                   0,
                                   0,
                                   0.55817137260755401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69418022374141408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39975947449897359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10304284541602168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19865499831464006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64511179871146651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77302923639015897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46490391890891064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022836973240162671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48555572092870369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1303274860650816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079491866600167077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18065429808417893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25251773224268209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21949080706134602,
                                   -0.2066917040982178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50785968355992572,
                                   0.6339801920920799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74152304339276209,
                                   0,
                                   -0.22990874498942845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24737860424300778,
                                   0,
                                   0,
                                   0,
                                   0.25502184696810737,
                                   0,
                                   0,
                                   0.86159123463245946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089219757051274343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47103729941641076,
                                   0,
                                   0,
                                   0.90114154674172864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32901220939853998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87382434252725039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5883811210124239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49135118525297061,
                                   0,
                                   0.56263794536713096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45840376447736675,
                                   0,
                                   0,
                                   0,
                                   -0.62049341141960312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018384522949404014,
                                   0,
                                   0,
                                   0.035179138973153126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43484388664769297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34674924997621281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24051787060042917,
                                   0,
                                   0,
                                   0,
                                   -0.19001383739811767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012207957371496197,
                                   0,
                                   -0.473059761219499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075611065681966474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47771638826506735,
                                   0,
                                   0,
                                   0.22706857009464046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0059016328760750913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19213929824368231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28270646962492835,
                                   0,
                                   -0.56597605098792936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15788320549079185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12263399254581184,
                                   0,
                                   0,
                                   0,
                                   0.11577966804548895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012220110815720039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35345564936209384,
                                   0,
                                   0,
                                   -0.16718830805895768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30797267456167798,
                                   0,
                                   -0.25925272066417826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015407516704988277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14799145125541915,
                                   0.19241474295800098,
                                   0,
                                   0.02634393569588718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44183821286614816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23199317335820713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16010420002253734,
                                   -0.043604802927764336,
                                   0,
                                   0,
                                   0,
                                   -0.59031841494025239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.006762458755862788,
                                   0,
                                   0.08375378000713149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80065127273331305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020032904455070326,
                                   -0.48214109444906333,
                                   0,
                                   0,
                                   0,
                                   0.52252517036163981,
                                   0,
                                   0,
                                   -0.12949253554945653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55878282587639472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56068541809811523,
                                   0,
                                   0.41312238263925921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26261909187892207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33856299618098884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7709255642495938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43854182349751392,
                                   0,
                                   0,
                                   0.47499461192555825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87502723371203761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13649689242682714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63079762287400465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026997156847677173,
                                   0,
                                   -0.19695113577224752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22796812836504673,
                                   0,
                                   0.18875156540333665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12217254870664648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042519380141357838,
                                   0.84503492229167609,
                                   0,
                                   0,
                                   0,
                                   -0.14559974940564729,
                                   0,
                                   0,
                                   0.30794635863882402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35603678550455131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75337270612216267,
                                   0,
                                   0.26656519786854527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34565242525233231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42013919470217054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20317097417759244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.221036480411319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88714413840527784,
                                   0,
                                   -0.44145532541798455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48466677133719904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13952322583533394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0062234740574833806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089593998240194359,
                                   -0.47579396739308566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049354638802151143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1690086051323394,
                                   0.052810544314803948,
                                   0,
                                   0,
                                   -0.12739387195721749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075926191620471248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50565624254706065,
                                   0,
                                   -0.67385704793998558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36450893409767426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16486200619517372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1213957690570091,
                                   0,
                                   0.075513490100090536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36866196921236843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031704667957125683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20970690668327258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35928456437835027,
                                   0,
                                   0,
                                   0.10305609952230455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29152786434976846,
                                   0,
                                   -0.20450607602147264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24048702772824543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27095430391467673,
                                   -0.30609007148719825,
                                   0,
                                   -0.18924834580811065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023298645175856697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12920040484149747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094937843183725362,
                                   0.61518440548391606,
                                   0,
                                   0,
                                   0,
                                   -0.15507705423818341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45135509295734499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20731278423158275,
                                   0,
                                   0,
                                   -0.1524615040052503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10769133525728364,
                                   0,
                                   -0.073138614203435842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41008223582501002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46802554602989221,
                                   -0.12301439825885989,
                                   0,
                                   -0.13854899210915114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04631971754578218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097311236307672286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42756314473359525,
                                   -0.23157661961865988,
                                   0,
                                   0,
                                   0,
                                   0.20859557778623605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051486582058808211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33173818765665264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026710270565990707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11408515663917244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77198278911436835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031968893960082942,
                                   0.20573181385645742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14497841278205392,
                                   -0.077154146517688843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76696067355431286,
                                   0,
                                   0.48064380131483092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8748954404692213,
                                   0,
                                   0,
                                   0,
                                   0.0064022376424417923,
                                   0,
                                   0,
                                   -0.360692183192731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1959181968525302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11916460262642578,
                                   0,
                                   0,
                                   0.11933437316968273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2083279536048484,
                                   0,
                                   -0.33057239560407586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21609636529716894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046488138972499274,
                                   -0.15147022622393491,
                                   0,
                                   0.40695499858500445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19942556513338827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35735993815224787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41780549085036522,
                                   -0.11007440308980394,
                                   0,
                                   0,
                                   0,
                                   0.43465808369783465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054318112461001683,
                                   0,
                                   0.30497235815079932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17478040477957008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25051159512652521,
                                   0,
                                   0,
                                   -0.58119530867322522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11986811515002868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24822187492649925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09928441681805919,
                                   0,
                                   -0.39714141314849005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035172656839401219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43327406309836702,
                                   0,
                                   0,
                                   0,
                                   0.2010583899917146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60724107631198632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53583690049156885,
                                   0,
                                   0,
                                   0.81676311570047233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55102642345564523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36153723033561402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48928419387448913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042314242567493082,
                                   0,
                                   0.53523656444943046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044512095802458324,
                                   0,
                                   0,
                                   0.27177451153327437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58753267943767584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025807229119861545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32142612754633559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88544233501288938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25166402437978003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39686736061632177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16943931210023278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16540832328141525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39139385724521891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64662190173700118,
                                   0,
                                   0,
                                   0.28372467436429605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41890348312993242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95246918124102287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70314174117646466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32656409486379734,
                                   0,
                                   0.57576986783280737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67254739752186021,
                                   0,
                                   -0.13929483109117169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52022174625138229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35623888212952326,
                                   0.15366326155232815,
                                   0,
                                   0,
                                   0,
                                   0.39210851290257775,
                                   0,
                                   0,
                                   -0.48288783548525821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076387545680004498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35510428415959733,
                                   0,
                                   -0.25401848022775603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86264944698300738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46367458048696247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80832730930026875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12752205494399171,
                                   0,
                                   0,
                                   0.48432002244712591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20428748215137998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10095967281923274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20941101093196918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23498603109620053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11388768879481104,
                                   0,
                                   0,
                                   -0.37252933855702763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20518582603239222,
                                   0,
                                   -0.44744586808173176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094766380905036279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11963099113612671,
                                   0.32131671329531369,
                                   0,
                                   -0.48761007249000693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24622210996927579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068746573381291934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11552160784897221,
                                   -0.078048579144739311,
                                   0,
                                   0,
                                   0,
                                   0.31880327472331116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38912783607741297,
                                   0,
                                   0,
                                   0.30937095912430002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52159418605477326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81166738045135056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79227588612442468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32445376486140493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25675273928493686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047654527380951911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33287710360114098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019643445550557248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21835960028124005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54747992997031025,
                                   0,
                                   0,
                                   -0.44183489366457041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48421821814771776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43969004558388147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17196545878004676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80726680622833868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040604253120166973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15423072190947035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49022998387684791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23404410911944917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020521529778118882,
                                   0.31197457683163965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1887725301706733,
                                   0.013990431787986977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13111913788195581,
                                   0,
                                   0.96729348239557855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25534959615801817,
                                   0,
                                   0,
                                   0,
                                   0.0030293274056899981,
                                   0,
                                   0,
                                   -0.0057729842766222617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28281396411965826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32063278457278449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59936204797743253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11939533430433982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31673049749981136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16378744837358949,
                                   0.086364325406791564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31608689491379227,
                                   -0.6340022499343958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19310050115798921,
                                   0,
                                   -0.004389008792747659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46528735966810197,
                                   0,
                                   0,
                                   0,
                                   0.67511336679633782,
                                   0,
                                   0,
                                   0.30091731005685762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36026621698384581,
                                   0,
                                   0.045618680618368518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31601855999668405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28881986272957411,
                                   0,
                                   0,
                                   -0.41479480444793482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16970777161285056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40853559829275571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30232791670044273,
                                   0,
                                   0.28198098100391034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27896381113131702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12189868646430059,
                                   0,
                                   0,
                                   0,
                                   -0.23127951129979032,
                                   0,
                                   0,
                                   0,
                                   -1.1359018475578704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31063762556421537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51527003881784783,
                                   0,
                                   -0.38922293569895905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2160043456868155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21287403633631441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44254319517314594,
                                   0,
                                   -0.00076241837710150362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35023446069731778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39221909061632071,
                                   0,
                                   0,
                                   -0.1661339959210483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10713942928848411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28105194304124903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045663318404073547,
                                   0,
                                   -0.3502470950622254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47662248533576818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15388718318393829,
                                   0,
                                   0,
                                   0,
                                   0.18432841642290948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8264285005895734,
                                   0,
                                   0,
                                   0.30063876228125908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36259722812486384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17279245189027589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2994283160437532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64626060744782865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77527610544053371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37275520080283414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016124713175377933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51050897826791031,
                                   0,
                                   -0.22838032026570304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11185163291084732,
                                   -0.079726874474208481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060462520755096227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40417287883798492,
                                   0.50309155990429311,
                                   0,
                                   0,
                                   0.43757528023657616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42187809096403972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35669777487074017,
                                   0,
                                   0.11034566080542138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3326779186279612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34165159693578839,
                                   0,
                                   0,
                                   0.28112632707856466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034222234501373905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83205890841468466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0086248817618472529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083762595652495594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5092997073604939,
                                   -0.00055491627684318111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013706322035970161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34735721421109328,
                                   -0.35778794391598023,
                                   0,
                                   0,
                                   0.6285021706934405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10549081984317366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13781332263454221,
                                   0,
                                   -0.24414015205820244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11897838666395104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40423693695128415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45733057424022633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74198752567354709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19931421862904597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6234384359334002,
                                   0.84317064582923451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26136152612776187,
                                   -0.062476941928676991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49778582458512222,
                                   0,
                                   0.23578175608779922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19862982929583842,
                                   0,
                                   0,
                                   0,
                                   0.1539669796839144,
                                   0,
                                   0,
                                   0.31247474596633457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015482734859839045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21984753843981658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29504460845714053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053679468137933464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79178054024011424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070569295733043783,
                                   -0.15588883367612902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44430775205565631,
                                   -0.60849594000475038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16793268389700239,
                                   0,
                                   0.041986174856587011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55679978919624351,
                                   0,
                                   0,
                                   0,
                                   0.8124235990995502,
                                   0,
                                   0,
                                   0.12670406624602065,
                                   0,
                                   0,
                                   -0.071827835428305287,
                                   0,
                                   0,
                                   0.26558365218467794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26309866990805647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60114269462076531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34579805613359843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32968293610865645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75688874714652332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61976624764396848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28252590309305003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63014163485211794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037692934901173578,
                                   0,
                                   -0.080791137977727037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19307789438939332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091165507771177254,
                                   0,
                                   0,
                                   -0.049612124347071324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64053417485009367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28492034526735843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26363204842384574,
                                   0,
                                   0.10691171684654391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0089850543736657365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38269203481220976,
                                   0,
                                   0,
                                   0,
                                   0.47441639888114789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20753016229614038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17899304518911147,
                                   0,
                                   0,
                                   -0.27189143725448361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091151248374815849,
                                   0,
                                   0.26486891321977074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33349344198180308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25565980015332779,
                                   0.40328751585434797,
                                   0,
                                   0.27412171275732095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17860699164283464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24614076720090491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30441963241266301,
                                   0.34790549966843631,
                                   0,
                                   0,
                                   0,
                                   0.22791456609966404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38619024983756423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44115561953815452,
                                   0,
                                   0,
                                   -0.36968101495939953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33235687224572408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10529919276695709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63089281730937419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078154638274486377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033342240109673599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92946785236105156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17448639681700717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64493773835607893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18378531475812485,
                                   -0.29207431252884475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28228636676886182,
                                   0.34140558342683608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4304028253321957,
                                   0,
                                   0.15233010837556404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29416698134905916,
                                   0,
                                   0,
                                   0,
                                   0.39978777676293531,
                                   0,
                                   0,
                                   0.13606712313811134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27827024857737953,
                                   0,
                                   0.066901205716468584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18984452544253649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093554699849408715,
                                   -0.49845227568892658,
                                   0,
                                   0,
                                   0,
                                   -0.4377145061951816,
                                   0,
                                   0,
                                   0.13564960997816719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26256540692309693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70033831841324834,
                                   0,
                                   -0.63880031412119065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035266129795465624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61022417076537971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13310096753264886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85838182131698415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12210425152769691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080824336721588258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43672492693917186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74440610463085344,
                                   -0.11976086086298512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13234593391823624,
                                   0.61552198811275383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19623089011057646,
                                   0,
                                   0.0050549800721383497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26363200798361197,
                                   0,
                                   0,
                                   0,
                                   -0.21366926392061769,
                                   0,
                                   0,
                                   -0.27321319309649589,
                                   0,
                                   0.079070506550128539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51283174896486261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047561310833644371,
                                   0,
                                   0.84479113007449469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16970595728007382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70893531956717504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12237738803445133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32618368805068659,
                                   0,
                                   0,
                                   -0.58915276573896269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084051339262653013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12490266429314106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71334542263217604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1691143347550681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49681659764807723,
                                   0,
                                   0,
                                   0.15351158887952213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11200766490954411,
                                   0,
                                   0.34273902099585862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21469449816710168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33378466579415478,
                                   0.092035419126874379,
                                   0,
                                   -0.031533738186008978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11781600418589104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27837084022301267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2368974936818517,
                                   -0.50409466713092144,
                                   0,
                                   0,
                                   0,
                                   -0.049177550752157656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016714093332380064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30510576173337267,
                                   0,
                                   0,
                                   -0.24126538500604763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28229878142664466,
                                   0,
                                   0.10040381043133771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36858984393720756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11673393617588965,
                                   -0.41358990809791096,
                                   0,
                                   0.12304751857276539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41044194984817212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41939339390102998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27363545927242677,
                                   -0.018702944351560724,
                                   0,
                                   0,
                                   0,
                                   0.058193071212897976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54722136197228521,
                                   0,
                                   0,
                                   0,
                                   -0.39546177998877152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013216682910472469,
                                   0,
                                   0,
                                   -0.47046565796997009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24284470817113626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28109092378584977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18287305623060643,
                                   0,
                                   0,
                                   0,
                                   -0.3888674981486655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44853190274179644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58573585426676633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20986799454883229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10581878904665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089357879520749847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60998265536364771,
                                   -0.091734601116550851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30346454384229771,
                                   -0.52962383527181478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35011039263500693,
                                   0,
                                   -0.16777230573039068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40566804845975124,
                                   0,
                                   0,
                                   0,
                                   -0.4156205323646508,
                                   0,
                                   0,
                                   -0.37647991271617059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01622640304479505,
                                   0,
                                   0.27087094924304128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53482558134741687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17558457577220166,
                                   0,
                                   0,
                                   -0.097530136833897038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022735620387830786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030590788049370841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43672287353418443,
                                   0,
                                   -0.097040775453094905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058955103740411581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6273962186048323,
                                   0,
                                   0,
                                   0,
                                   0.0358741537012017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41496569655298809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11451687731616297,
                                   0,
                                   0,
                                   0.63811199270190089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13305491082820842,
                                   0,
                                   -0.17842440153122044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066745530944049711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17387092160753109,
                                   -0.10429084761615226,
                                   0,
                                   -0.062711328524751628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17782555496041777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26705685015732972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44575484104222862,
                                   -0.063223501357666537,
                                   0,
                                   0,
                                   0,
                                   0.053219642556567859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54637693887686367,
                                   0,
                                   0,
                                   0,
                                   0.045046351201699739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55115818876628575,
                                   0,
                                   0,
                                   0.46337263133590922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34196771746510901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12274639561816102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21651389547557129,
                                   0,
                                   0,
                                   0,
                                   -0.045460510688989625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1407433261849626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37582727008587558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54282411196801761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41788625681633029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057421238954291319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40734875844007412,
                                   -0.13673988047510632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020246714390663695,
                                   -0.7438879993073928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63801586368614549,
                                   0,
                                   -0.15832658868382299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18300284810624506,
                                   0,
                                   0,
                                   0,
                                   -0.60454804725680422,
                                   0,
                                   0,
                                   0.41338130389993388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4085177092886853,
                                   0,
                                   -0.29172856725127155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37176975615455282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031663663439258694,
                                   0,
                                   0,
                                   0.047961324209409129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58435226828413023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12533972521876738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046382465972914594,
                                   0,
                                   0.064630017740627432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21283512274058755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21010891591019884,
                                   0,
                                   0,
                                   0,
                                   -0.39184379276307046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97191600227710473,
                                   0,
                                   0,
                                   -0.58548369976674897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15819752506997928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24197408222785466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44154355011388574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44752954257221444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74152325722971368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28164813487962848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014396628422139901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15007776869313272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044648747176336392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58479870874958551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11743305220507202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62052946230787509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2884713252785811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14415377062161955,
                                   -0.081748381451656749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74862735907019529,
                                   -0.0088855985082806309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58762331700975845,
                                   0,
                                   0.1935174434688785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10519829926539656,
                                   0,
                                   0,
                                   0,
                                   0.15968573085156657,
                                   0,
                                   0,
                                   -0.73059686481818287,
                                   -0.079241543573615902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060704844443999255,
                                   0,
                                   0,
                                   0,
                                   -0.29545537272276579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18988688943506143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46523222460713709,
                                   0,
                                   0,
                                   -0.35990960714252468,
                                   0,
                                   0.15225973952088973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024643130122659659,
                                   -0.69058149296237703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14147696948012944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28031655170833242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27712974231898196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10704236178002328,
                                   0.041642545518008951,
                                   0,
                                   -0.12183229929533071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35579173763706196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29379119630469458,
                                   0,
                                   0,
                                   0,
                                   -0.084748154380723736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18956958354497236,
                                   0,
                                   0,
                                   0.64137647105061668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27932248052534736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26679904193763027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10831059656670675,
                                   0,
                                   0,
                                   0.3219568770711484,
                                   0,
                                   0,
                                   0.45346481686108903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68634229699775018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38325605074821112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14920259237041894,
                                   0,
                                   -0.046817070734163586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19125387076253469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18015761864928759,
                                   0.20197252126800896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0097771863765695362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22341940028771071,
                                   0,
                                   0,
                                   0,
                                   -0.50582685524667803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68361793279190197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11520470761561355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72879141734625974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79266488069993302,
                                   0,
                                   0.40849865065216789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22439049847357909,
                                   0.85560954750518914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38893047525458435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64529507959921206,
                                   0,
                                   0,
                                   0,
                                   0.13640559916222361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51149001866688482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54574722535375453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47843849624041834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0022247650571667,
                                   0,
                                   0.49688885922677162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79940290677729786,
                                   0,
                                   0,
                                   -0.067350759473649574,
                                   0,
                                   0,
                                   -0.041643630769774558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16803658714306813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47952906058062988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014616952302560639,
                                   0,
                                   0.24612927101358725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18896292743899176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37206730735278598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34727658246173704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42336766345574911,
                                   0.49137481761540197,
                                   0,
                                   0.032628582230331923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070998841361317594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046774554267498859,
                                   0,
                                   0,
                                   0,
                                   -0.2783368830979604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16141538358833157,
                                   0,
                                   0,
                                   0.06282669675377088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094789782093415237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44218044086132846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45711000106118838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072082078154481644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74900165913209249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24938045585709451,
                                   0,
                                   0,
                                   0.70495258616432011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57516672872743213,
                                   -0.56382243793974984,
                                   0.096811037962469038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21818155423677382,
                                   0,
                                   0,
                                   -0.6841307951756842,
                                   0,
                                   0,
                                   -0.24011879748175316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13741734006083428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33501375289824376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22044647077144364,
                                   0,
                                   -0.47548656755839402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14457857792432616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74709004137406587,
                                   -0.0050398089786935496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65025419186354183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39220365901745591,
                                   0,
                                   0,
                                   0,
                                   0.25627438883596837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15031966413494044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52102144463831013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077251101430306057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6130443804281317,
                                   0,
                                   -0.37822083941254825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46361757506118428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38526895289393726,
                                   0.44380081618777267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10173596775241969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4704239862586076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11711952499057905,
                                   -0.17015235924602154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19547669476429258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76439520046024823,
                                   0,
                                   0,
                                   -0.57701275663345175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36516244151322014,
                                   0.30588219793781979,
                                   -0.082247883267147076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55880826113372573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45299058450916829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55597645845543286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1297131335961625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27304490066815584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21893610896997029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17370530214161217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65302291169172055,
                                   0.71461162178560578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58430637375556704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10876247589234513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25902126118923252,
                                   -0.24379167123736281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51171429189790141,
                                   0,
                                   0,
                                   0,
                                   -0.048448596105076777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24145291601267738,
                                   0,
                                   0.10858735974369296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46430047128109075,
                                   0,
                                   0.014379055403229087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3345746798084514,
                                   0.077504985852600961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11422177368775183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66633973245541722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21392919384034068,
                                   -0.36066771499497086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12009777082997064,
                                   0,
                                   0,
                                   0,
                                   -0.50836832061428749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49090483492539849,
                                   0,
                                   -0.0079142370986793019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73423401529276355,
                                   0,
                                   -0.0044823211736759305,
                                   0,
                                   0,
                                   0,
                                   0.68403697003943109,
                                   -0.32486370799101522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71711593993223821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60455013329318086,
                                   0,
                                   0,
                                   0,
                                   0.017822875692873313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74287440663664839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.250535782390434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51797031312454878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13163640004658328,
                                   0,
                                   0.77898426480660909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37182057673056368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41195951621594551,
                                   0,
                                   0,
                                   0,
                                   -0.24786633963562721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41458638716857604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047222171032124921,
                                   0,
                                   0,
                                   -0.064292496896438373,
                                   0,
                                   -0.40932556835522915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28349099263304889,
                                   -0.26112153989994985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36912970614911034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55396288929789128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37832037654389539,
                                   0.2015308652830019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37708557959355421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19202410672183406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15990746410152731,
                                   0.28111706767787586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32672659069777538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40077408645231816,
                                   0,
                                   0,
                                   -0.29085690750207682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90181636205220383,
                                   -0.090390331166198906,
                                   0.16078062476689414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63249785897347777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20714485810156427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069558029984154807,
                                   -0.54778288997858471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040822624984482872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066180979289581665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67306552652656981,
                                   0.029827335912692932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30390502395515206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15237817139411805,
                                   0,
                                   0,
                                   0.1245214649112578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26897996341571784,
                                   0.11490084299960782,
                                   0.45373682811924587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69332600530006616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035297237733572705,
                                   -0.49658676991088224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40751936921847554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30894427864819479,
                                   0,
                                   0,
                                   0,
                                   0.98333027238108495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03844119675999242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58218422479009813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49500890292467681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35316994155155979,
                                   0,
                                   0.66485107218565664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051836888204953177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0077624631795572205,
                                   0,
                                   0,
                                   0,
                                   -0.25260483263860545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28213996415835052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50480240647979291,
                                   0,
                                   0,
                                   -0.070376585363106037,
                                   0,
                                   0.24250201419440653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39359997401213476,
                                   -0.10225718250198526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60817554141864105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16914183147040496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7820743491887997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53396904521888111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20915962055763124,
                                   0,
                                   0,
                                   -0.30054741620362158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20047189543369592,
                                   -0.56073911982369384,
                                   0.90210322348659477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033955803683361763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074080886510849514,
                                   0,
                                   0.67320939241369904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45758403240497147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56990165206985666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077311705918434628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71588158133842783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23152975659274014,
                                   0.22019519240883367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0045231434171557859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72997227628159123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57773558645555245,
                                   0.43961672618808806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22917618923416605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19449252758453653,
                                   0,
                                   0,
                                   -0.46993309392947707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037718380350799177,
                                   0.021591179822280447,
                                   0.26479907503893096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03230756520280148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19965445504454898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38212065938593137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18471210882699574,
                                   0.15430224222042904,
                                   0,
                                   -0.32658091591693778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6758538838842999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19282530050504776,
                                   0,
                                   0,
                                   0,
                                   -0.2688680752118226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20206261205906684,
                                   0,
                                   0,
                                   -0.013568508803457349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17036743235472396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11511074725553502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24387696167287742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44410372448401425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031532236098449101,
                                   0.0027920215451220209,
                                   0,
                                   0.32308789204570831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28154802701011639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28851687229078682,
                                   0,
                                   0,
                                   0,
                                   -0.29432073616676702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43448976817226104,
                                   0,
                                   0,
                                   -0.34617366180140863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22787418891779915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16801150135198006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59002305959130708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11909603839033941,
                                   -0.1293678008758819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23249717425511238,
                                   0,
                                   0,
                                   0,
                                   -0.10035753146785706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10297078026442782,
                                   0,
                                   0,
                                   0,
                                   -0.3622429512576032,
                                   0,
                                   0,
                                   -0.17215613309263716,
                                   0,
                                   0,
                                   0.10574388091594693,
                                   0.41201384466924185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16785823562285457,
                                   0,
                                   0,
                                   -0.13195970428294235,
                                   -0.29915365783981568,
                                   0.26333593539859762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15909240208161127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28191354918824379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17577965639116735,
                                   0.66331802391192718,
                                   0,
                                   -0.32307333453920917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2325939270028354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26021731117026781,
                                   0,
                                   0,
                                   0,
                                   0.17851000547576262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18222581996744747,
                                   0,
                                   0,
                                   -0.16622319537907371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0071335136098546748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32462685859131429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1245621738673206,
                                   0,
                                   0,
                                   -0.057424224612380941,
                                   0,
                                   0,
                                   0.19749844364931216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032637849659269212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20881445140226929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72037452328049489,
                                   0,
                                   -0.40514162700137746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46306931658173855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27459467775221791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71612971673125281,
                                   0,
                                   0.22260245055784189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19812515810224701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10296480416561898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55888175099953563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01886167481004335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57435261926172143,
                                   -0.20447468793251469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088757887821072648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40202164883679187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34476055189106902,
                                   -0.72507124512607535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0618504867123192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17057585288678373,
                                   0,
                                   0,
                                   -0.20534607783741665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53737154252031627,
                                   -0.1882054623464986,
                                   -0.18916750279282066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065197830875479854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37184383847902625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48921245232306998,
                                   0,
                                   -0.51648291110899369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53264485788287408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26821288386360775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00020762974600974787,
                                   0,
                                   0.20974699658692075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30462295237828579,
                                   0,
                                   0,
                                   0,
                                   -0.24674270017585159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05102276439762473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33860827741320443,
                                   0,
                                   0,
                                   -0.016201599460472175,
                                   0,
                                   -0.3242256940236512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3483522919221147,
                                   0.33832849349961375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58640423336314218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063638034082442854,
                                   -0.48605967159489949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45343554460521779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72057927441686076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26129578161428701,
                                   -0.39086577647390924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37127887523813086,
                                   0,
                                   0,
                                   0,
                                   0.16283630992633061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39163307371095801,
                                   0,
                                   -0.50227417180434264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33251544906092251,
                                   0,
                                   0.13605378859608375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034374013113488602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021726825243195941,
                                   0.34377306007740804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15495241270616336,
                                   0,
                                   0,
                                   0,
                                   0.22100712624408797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11185782209781084,
                                   0,
                                   0,
                                   0,
                                   0.11305437464338158,
                                   0,
                                   0,
                                   0.037591879707284045,
                                   0,
                                   0,
                                   0.1556201116832881,
                                   0.4986010439341918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54547281319282048,
                                   0,
                                   0,
                                   0.24561745510331062,
                                   0.15752968515164603,
                                   0.35369576747160986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39215818113959078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053837201481378813,
                                   0.34533196929985699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37118793969050456,
                                   0,
                                   0,
                                   0,
                                   0.29285335773429272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4621950160253353,
                                   0,
                                   0,
                                   0,
                                   0.002191391041692213,
                                   0,
                                   0,
                                   -0.072470908789151578,
                                   0,
                                   0,
                                   -0.23190226811631492,
                                   0.10450137199698714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013652978419200504,
                                   0,
                                   0,
                                   -0.06271991210048089,
                                   -0.46108994708141821,
                                   0.01453874545873568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78627453755063947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14383229133440373,
                                   0.084609548267744153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55932462764605939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52661323403560856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60817437560450893,
                                   -0.32005253856862209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02962578189087502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19960003030591131,
                                   0,
                                   0,
                                   -0.53901108029615685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57563939351295701,
                                   0.27421031248701178,
                                   0.066279678530860323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071603348504589742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39914692707080496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057519396499623496,
                                   -0.0035590863369167614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039698013870345564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11965898074588766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032349355969550325,
                                   -0.050620191997177967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13665421971527278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18634207073402315,
                                   0,
                                   0,
                                   -0.050578687902112299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28152796948516862,
                                   1.0108990400151081,
                                   -0.048345391667348053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50091430305168516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18447148801774493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41524376716838396,
                                   0,
                                   0,
                                   0,
                                   -0.5555667707172568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43182750400679104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24295328079569772,
                                   0,
                                   0,
                                   -0.27708252455959465,
                                   0,
                                   -0.25113600680108078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075931190822826969,
                                   0.2619068593765983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15868960044187969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27363393931266694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1946035303236415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87313818916104147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57768856678277158,
                                   0,
                                   0,
                                   -0.13404462653106972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90995139460894103,
                                   0.093896681299724838,
                                   -0.18002543310426744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061689267832952033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21215827883995605,
                                   0,
                                   -0.066182014595314032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63637915253688992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6636028088012651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31852178303140311,
                                   0,
                                   0.58493121542865134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23820353615988607,
                                   0,
                                   0,
                                   0,
                                   -0.26697385863634437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14370208336869383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14120435454970959,
                                   0,
                                   0,
                                   0.46932927889617693,
                                   0,
                                   0.49492316142815512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13507808311103281,
                                   -0.021925129089931498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072834341521001891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71430644888886552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32426514754188951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29503538805628227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46828743156012254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3606887656489983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61315198382609437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20484515850284371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024702668274584269,
                                   0,
                                   0,
                                   0,
                                   -0.15330556921994998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29474949660240352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48551740954856065,
                                   0,
                                   0,
                                   -0.26737062355275898,
                                   0,
                                   0.29297962968092406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43058437773754249,
                                   0.49337480475312889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15866790122238325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.853019655552539,
                                   -0.30494255862489716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38868754361885693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77240463808026738,
                                   0,
                                   0,
                                   0,
                                   -0.72568745782335176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1145555285871101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30476042790404823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29478852902458452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18928476113894022,
                                   0,
                                   0.40292506428069785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21947517066406641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28311807084589946,
                                   -0.0048790351536263238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1197816066604085,
                                   0,
                                   0,
                                   0,
                                   0.52270870490998622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19689328867348138,
                                   0,
                                   0,
                                   0,
                                   -0.68828668934344328,
                                   0,
                                   0,
                                   -0.04794854186855009,
                                   0,
                                   0,
                                   0.047609559872003875,
                                   -0.027441140801357403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019508899183224907,
                                   0,
                                   0,
                                   -0.15533166238303181,
                                   0.17973899450456768,
                                   -0.097160009289146296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3302630706789198,
                                   0,
                                   0,
                                   -0.31296368444974698,
                                   0,
                                   0,
                                   0.22752908052731899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43838099631694061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5982373974157863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17764187307703919,
                                   0,
                                   -0.14212285210764228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37334853972606596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15846579720778978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43684516475746538,
                                   0,
                                   0.40558168540185496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070642206949444619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37630040035328161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68772529174168451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33158461919137006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076205579990923283,
                                   0.42763957636251826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89859499480631966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15600072333079215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090717493500303198,
                                   -0.2583070834403095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27411969429724053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28815935160325934,
                                   0,
                                   0,
                                   -0.16675949488248781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28826302193737735,
                                   0.13323972577600149,
                                   0.5408241149774814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64244322568157197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028575224853891426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77791988885284047,
                                   0.00428809438570249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036148489080161182,
                                   0,
                                   0,
                                   0,
                                   0.08642877870636155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12592983558206511,
                                   0,
                                   0,
                                   0,
                                   -0.20033713414323934,
                                   0,
                                   0,
                                   0.25726633931555498,
                                   0,
                                   0,
                                   -0.25933227827386224,
                                   0.22808372308919439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31328647687035682,
                                   0,
                                   0,
                                   -0.062305275805502353,
                                   0.16177546028128026,
                                   0.12479074192560674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44691949902249417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40788414369857479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.003026183946583375,
                                   0.39924562672260372,
                                   0,
                                   0.32739779751459358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12316189098323471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26758619388255767,
                                   0,
                                   0,
                                   0,
                                   -0.03964171107614578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25581627121823047,
                                   0,
                                   0,
                                   0.07170380345837149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20306458360684712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40882346762257399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45049462117537731,
                                   -0.25345856486723489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27021304783586675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45348929133643723,
                                   0,
                                   0,
                                   0,
                                   -0.095369057304132782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13700919247246707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0455603355764815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23772043057513473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11523247255651789,
                                   0,
                                   0.21717613953219755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91974830137060182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079792323928351602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011416829677361504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51463016815118068,
                                   0,
                                   0,
                                   -1.0720486442231201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24866151391102509,
                                   -0.70238420246730882,
                                   -0.33013346926850667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4099652588615712,
                                   -0.2871006836250376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48275152728156268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1094112796595709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3041808523352727,
                                   0.38327437291855043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68980826488466573,
                                   0,
                                   0,
                                   0,
                                   0.17719229711244006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55053472315675755,
                                   0,
                                   -0.2162530801073507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20513891556721725,
                                   0,
                                   -0.87250673345919494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1656150705203481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6359290384493822,
                                   -0.19584912661201326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14666880534869328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1108186535484989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015338241289041083,
                                   0.76516978020050042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90784748216010336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18230342395608015,
                                   0,
                                   0,
                                   0.1711675250612549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35145594565023325,
                                   -0.21478318694770115,
                                   0.28412986136796725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30311004426203791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80106983260872489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11946299464021218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29324303945768831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97277530401355161,
                                   0,
                                   0,
                                   -0.11907950994494126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7255414468217809,
                                   -0.25827059304415589,
                                   -0.22036167963972397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21954810440371783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16892806915148062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58171578883412123,
                                   -0.20246130646449034,
                                   0,
                                   -0.32419463988873914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26405507479393464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28372243019774512,
                                   0,
                                   0,
                                   0,
                                   -0.027017780999636185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15847147602555628,
                                   0,
                                   0,
                                   -0.49631477861316253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08956959894590602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091423145471543149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41837885461549873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68165545040422282,
                                   0.31902263831780608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44326303834267039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22533257254202207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094065899106735337,
                                   0.24548695354536987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79424239179126721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30048865044664624,
                                   0,
                                   0,
                                   0.25379998791256603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22705370165501909,
                                   0.046776536974770716,
                                   -0.39768692385600518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21997872588272932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58730710891116689,
                                   -0.075950709132901736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24131732006316506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26942250232528181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72037760384606941,
                                   0.69782067461839059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58054493065018509,
                                   0,
                                   0,
                                   0,
                                   -0.37027297230892503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2530267767704078,
                                   0,
                                   0.56098921000744639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29714774358771928,
                                   0,
                                   0.23283608899478767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76900406198061211,
                                   -0.67793278811339464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13513008909990987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1269484704168925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0037746815783277444,
                                   0.046007115000498935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16735187359437051,
                                   0,
                                   0,
                                   0,
                                   -0.25922098591838999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10075812553682649,
                                   0,
                                   0.8376554728996678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084333983228948015,
                                   0,
                                   0.74376299393984546,
                                   0,
                                   0.34984313724097155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057616140815565958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37039774839689499,
                                   0.24703567970032186,
                                   0,
                                   -0.012273865221756428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092768905616963299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13237339333407189,
                                   0,
                                   0,
                                   0,
                                   0.13211348319127281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32355637250134434,
                                   0,
                                   0,
                                   -0.36728619056343914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13575928039386861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61181466236270665,
                                   0,
                                   0,
                                   0,
                                   0.46724352465161395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21012628780365925,
                                   0,
                                   0,
                                   0,
                                   0.42157662780525329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24228464204985217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093067278236163287,
                                   0,
                                   0,
                                   -0.6586147012664485,
                                   0,
                                   0.10619312759848029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20923257929182359,
                                   0.03871858724505161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045962010106469019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090000584159017571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67505260861296312,
                                   0,
                                   0,
                                   0,
                                   -0.11187000806191139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37427369947351175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21802070494948309,
                                   0,
                                   0,
                                   -0.21662064510416826,
                                   0,
                                   0.48391247019750927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12203695461958539,
                                   0.12635822504685684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15530595552012694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00058242716471607146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19424342678848788,
                                   -0.36826666498895455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17016286413606893,
                                   0,
                                   0,
                                   0,
                                   0.36491792837914316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083933976772061394,
                                   0,
                                   0,
                                   0,
                                   0.23450062921304449,
                                   0,
                                   0,
                                   0.13625767953113743,
                                   0,
                                   0,
                                   0.4378648150687357,
                                   -0.21131603038174704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17852588029759972,
                                   0,
                                   0,
                                   -0.47791392992742665,
                                   -0.0085552412048645037,
                                   0.29529686814272738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20183359714333418,
                                   0,
                                   0,
                                   0.37778496197304945,
                                   0,
                                   0,
                                   -0.74520268189246641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34827290843962572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1931446249599057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12271577279967025,
                                   0,
                                   -0.16336761731752505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24671376184914204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67916262384867265,
                                   0.053251944936665088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38184243324454725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089653625715125251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65448675710433479,
                                   0.06681155313954619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30615741435828014,
                                   0,
                                   0,
                                   0,
                                   0.35821595982291171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03459166672629535,
                                   0,
                                   0.88394248687638766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040554498902831984,
                                   0,
                                   -0.43022216879677277,
                                   0,
                                   0,
                                   0.081161142017098314,
                                   0,
                                   0,
                                   0.13422276729646665,
                                   0,
                                   0,
                                   0.29682703174820768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38402769540287507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26517455471350559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60216512166735092,
                                   0,
                                   -0.2483258291656803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49520446736866119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091372092413936665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20765365995847929,
                                   -0.21715102532929192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38633740409401168,
                                   0,
                                   0,
                                   0,
                                   0.18072850102148005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36396607073487225,
                                   0,
                                   0,
                                   0,
                                   0.29969116891814618,
                                   0,
                                   0,
                                   0.1013144497585555,
                                   0,
                                   0,
                                   -0.46069764556797177,
                                   0.32752746048783138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12484405297744183,
                                   0,
                                   0,
                                   -0.23205507256175914,
                                   0.11387206618279254,
                                   -0.29152604466381926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018708540326241738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26579525472355703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2464921367976099,
                                   -0.13352928605618994,
                                   0,
                                   -0.46312522065593426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034732369008485711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33833736218264099,
                                   0,
                                   0,
                                   0,
                                   0.27370805711498664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19385047005146072,
                                   0,
                                   0,
                                   -0.013371995283967889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62431443239983475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13345233308149698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19843400252193644,
                                   -0.18212194174671018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93132352234683125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19546159884754472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60118007045928512,
                                   -0.077024259072360532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1443834401556357,
                                   0,
                                   0,
                                   0,
                                   0.13832359775046391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57507469316140714,
                                   0,
                                   0.34835067396323638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17035722207444126,
                                   0,
                                   -0.0068787840083133801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13768304054652844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058301589828538308,
                                   0.070584352175442469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026856460873399435,
                                   0,
                                   0,
                                   0,
                                   -0.16774750833792454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.448915118227875,
                                   0,
                                   0,
                                   0,
                                   0.077347487023766814,
                                   0,
                                   0,
                                   -0.31402290365274765,
                                   0,
                                   0,
                                   0.077738559542891467,
                                   0.29041290437251571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14715254757869994,
                                   0,
                                   0,
                                   -0.32926158725724808,
                                   0.64324263361118517,
                                   -0.058930192169482469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18385625944370917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11746533828443144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38280738939276682,
                                   -0.080699629300741066,
                                   0,
                                   -0.2922288230519639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28408317865384636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10649643100641604,
                                   0,
                                   0,
                                   0,
                                   -0.73493193701987991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24993366595392125,
                                   0,
                                   0,
                                   -0.060008926693337565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099363138096217107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076397129949617434,
                                   0,
                                   0,
                                   0,
                                   0.40526159307490828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064197087608502068,
                                   0,
                                   0,
                                   0,
                                   0.36455920171186029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46590730549510806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20238908368952513,
                                   0,
                                   0,
                                   0.10902576549941052,
                                   0,
                                   -0.077694729926993583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61210251040627173,
                                   0.0054680724771051098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2192827704001209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10943604068847965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27842205191488262,
                                   0.097199255758835895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63119279138466966,
                                   0,
                                   0,
                                   0,
                                   -0.2076755090189393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25894303478148689,
                                   0,
                                   0,
                                   0,
                                   -0.21227756128935477,
                                   0,
                                   0,
                                   -0.20882062224185557,
                                   0,
                                   0,
                                   0.38355649329940888,
                                   -0.059674768550796162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1986642623761094,
                                   0,
                                   0,
                                   0.18643749838429738,
                                   0.1128323592262858,
                                   -0.25723572533728972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046271811134574369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048856603986515666,
                                   0.084038917115062978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12338982266900428,
                                   0,
                                   0,
                                   0,
                                   -0.22104757629962565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16046676978825036,
                                   0,
                                   0,
                                   0,
                                   -0.12224615113454293,
                                   0,
                                   0,
                                   0.64226821283305913,
                                   0,
                                   0,
                                   0.31166649770427202,
                                   0.2852719517631121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11070943847846552,
                                   0,
                                   0,
                                   -0.22291582703183704,
                                   -0.15662447500065713,
                                   -0.45400969791751589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67490543679947579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37236353838367187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1924125472836386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42217343582329564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67080520328826398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29574810475547275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58516562606541078,
                                   0.62851096178689936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084445312452127649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55845203057910864,
                                   0,
                                   0,
                                   0,
                                   0.87916857895457534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32555660943932313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36220920704550008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10097353551879473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28221333228870638,
                                   0,
                                   -0.10999094471807408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49382969731179466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29252646932407084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086072429391104821,
                                   -0.002139917947793897,
                                   0,
                                   -0.24483063340779485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15875846814687822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1982306275836534,
                                   0,
                                   0,
                                   0,
                                   -0.20350498975009756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61318306412476187,
                                   0,
                                   0,
                                   0.17287241017152941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30106113703479648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027845126295286918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29477664121495634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42051183060329472,
                                   -0.41516166048905134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31581678240827332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38238298994762726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66868274189880716,
                                   -0.18340246080269645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54402041307109772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52128295387879864,
                                   0,
                                   0,
                                   0.67850161330338443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059502947946790022,
                                   0.22303682540704625,
                                   -0.22095816695625553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41825531814628591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13499036841071241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30147594241635017,
                                   -0.19906840697706274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18489952269107673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04121112714290559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23357374004007683,
                                   0.13741161562893422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23895381896212092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71472477143688229,
                                   0,
                                   0,
                                   0.12138458553194315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019412929670038645,
                                   0.12603479276277588,
                                   -0.8631411297998649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3255145159149212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13590949424902302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028446227970590293,
                                   0.83760076703901398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85989839888693409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11016763522173184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33015559263459637,
                                   -0.28823025190214574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14174209493832363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11704735149634045,
                                   0,
                                   0,
                                   0.60584093531298377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074553137144149795,
                                   0.17859796205539966,
                                   0.3063104745115296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26365460113551931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25588323531183355,
                                   0.59543913705090679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049951436957205796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43082083264016602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19737376389902062,
                                   0.38348865139931537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60468828520335927,
                                   0,
                                   0,
                                   0,
                                   0.070556261393159708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21253468027739381,
                                   0,
                                   -0.10010149114823798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84555476512446814,
                                   0,
                                   -0.33246849346975432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0962997175950089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8758466658171935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47200272601151133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0099696991406715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59556360086140891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35848380024662208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1823123305865087,
                                   -0.1013063773648083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35466585075423718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28801130549046328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28739809342644335,
                                   -0.33901237251944527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018849422696616325,
                                   0,
                                   0,
                                   0,
                                   -0.40097901024881977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22904902148497755,
                                   0,
                                   -0.0041547263400789902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037261178197038065,
                                   0,
                                   -0.97622566923201448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53950118390919455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42938889705776601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80001984734751064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57630606053604205,
                                   0,
                                   0,
                                   -0.69479229178102464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83316090499093354,
                                   0.21709297283421786,
                                   -0.86839690304002926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29818079050288659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09907587393956592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028869000985944193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18604428663515435,
                                   0,
                                   0,
                                   0.6062291483123593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44412594595442917,
                                   -1.1245091922413322,
                                   -0.61501754206935277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41390431067198946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63415683764180575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43082685505279478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22079987351635061,
                                   0,
                                   0,
                                   0.39760368369015769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34132812456335915,
                                   0.82266027172491518,
                                   -0.68913599759333477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75960222802413102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65032894307492395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085630415917467187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72741821412110941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19332757943325701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79504725841883062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23933619091409214,
                                   -0.15690185587249625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7176156312559181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52019230150093232,
                                   0,
                                   0,
                                   0,
                                   -0.18253522210033815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72834287317333779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17584391093461754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94319347479787052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46861437245447046,
                                   0,
                                   -0.41552904180754902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36014893277092563,
                                   0,
                                   0,
                                   -0.40223334208741046,
                                   0,
                                   0,
                                   -0.027748682413449126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14071252478764401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042645229427520706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02775249811009952,
                                   0,
                                   0.66215385604130395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49688483063453903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044930998084333082,
                                   -0.21612709644267719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69966663742579771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19465811055900265,
                                   0,
                                   0,
                                   0,
                                   0.15082306996143111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83722873095117023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041053063115210855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54942611856700108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6651594895117765,
                                   0,
                                   -0.76970679268832132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19885608284150241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23836491019341197,
                                   0.56162896883660363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31051258331443315,
                                   0,
                                   0,
                                   0,
                                   -0.060857382704257626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10146695120277169,
                                   0,
                                   0,
                                   0,
                                   0.0024805954956556645,
                                   0,
                                   0,
                                   0.40195477074602887,
                                   0,
                                   0,
                                   -0.04071985444860958,
                                   -0.31040382748324696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19773566823744362,
                                   0,
                                   0,
                                   -0.15612603061323291,
                                   0.24532128067508532,
                                   0.30749700036563699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49020157060965891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63994726882419217,
                                   0.22586050139460315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13208810675858904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063051098480837106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55151811694823027,
                                   0.065110351260929816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59779301647968686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46267191738755098,
                                   0,
                                   0,
                                   0.31473609382361167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59137405784391117,
                                   -0.22552759687330556,
                                   -0.3695624390489991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23081544828367057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021395399621332287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72818203612953192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23643407774960978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38401337653181999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20808505652923104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86741647076076156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5828330505528716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22999626018082053,
                                   0.15044849069344554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052132905135361708,
                                   0,
                                   0,
                                   0,
                                   0.26702686867510428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34043269579925284,
                                   0,
                                   0,
                                   0,
                                   -0.0859553521688661,
                                   0,
                                   0,
                                   -0.056356532648240164,
                                   0,
                                   0,
                                   -0.17569064484934532,
                                   -0.27990355514343684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33265411426594688,
                                   0,
                                   0,
                                   0.013724120530522448,
                                   0.14210003798992873,
                                   -0.37952586492286206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095481880312643569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13503438993680333,
                                   0.45105284062024564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26252755065743433,
                                   0,
                                   0,
                                   0,
                                   0.064049759142333795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37876095584629754,
                                   0,
                                   0,
                                   0,
                                   0.2185360423787529,
                                   0,
                                   0,
                                   -0.37331027099232622,
                                   0,
                                   0,
                                   0.18194059032728918,
                                   0.03395278598670165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16718861390953199,
                                   0,
                                   0,
                                   -0.44041882528174647,
                                   -0.25378565342499659,
                                   -0.21216891469075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.134682002145975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070884475647502262,
                                   0.0031450688272209454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088773384100622382,
                                   0,
                                   0,
                                   0,
                                   0.45777636627657053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071717657661611617,
                                   0,
                                   0,
                                   0,
                                   0.27599651916001261,
                                   0,
                                   0,
                                   0.0869029941426811,
                                   0,
                                   0,
                                   0.34844163392500604,
                                   0.14452336682310621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52632874681077901,
                                   0,
                                   0,
                                   0.44347235629502807,
                                   0.075924568539979184,
                                   -0.22082553038724076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099953741252422484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10786922755074269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23018509703970597,
                                   0.085132549950161271,
                                   0,
                                   -0.31049667011064297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27858546332757961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62340171391187216,
                                   0,
                                   0,
                                   0,
                                   0.21989779115033956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062524618100184615,
                                   0,
                                   0,
                                   0.13040274882602751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52347242692790497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11045535245077222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24369549215562625,
                                   0.19910532341607848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57480871615424944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012976312323859263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32095743597826426,
                                   -0.4860391998101124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024308646123119615,
                                   0,
                                   0,
                                   0,
                                   0.56341460834398105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84052948009415429,
                                   0,
                                   0.1905836671850058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33282968308377775,
                                   0,
                                   0.31383208270980206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86963207822681798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080601453509982629,
                                   0,
                                   -0.24820576728735688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24017490126913538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10344817951888302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32749327054287963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29402065871782634,
                                   0.0064962641081539492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43578613645881703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083917839052139037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.003652760904468047,
                                   -0.14319338288936997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057902993873633624,
                                   0,
                                   0,
                                   0,
                                   -0.63728578155756332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76727435208551031,
                                   0,
                                   -0.094757392715708905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10866990822344146,
                                   0,
                                   -0.11266876191272732,
                                   -0.53788182564011766,
                                   -0.16594983020919674,
                                   0,
                                   0.73567877267979154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14810726538134653,
                                   0,
                                   1.0252800200650605,
                                   0,
                                   0.15725866766757066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099273221869761064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050832556093875089,
                                   0,
                                   0,
                                   0.088576822101593733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19438273585031446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63778181016927848,
                                   0.68524509886312723,
                                   0,
                                   0.54166625824926184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81708868766238518,
                                   0,
                                   -0.41354392633536607,
                                   0,
                                   0.4213042570070783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30400146506240727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048605899290388326,
                                   0,
                                   0,
                                   -0.53243248768842566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15128046956740551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21187365814744719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83522005653916354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025915443825608842,
                                   -0.3565733123280887,
                                   0,
                                   0.022424789196890421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44692718279268179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085118746565985531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57808727220069744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6652172102578815,
                                   0.23133551545909509,
                                   0,
                                   -0.42544543326252388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11744414671728615,
                                   0,
                                   0.18625178771876827,
                                   0,
                                   0.20708384919432427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70892964426398764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64294191573221626,
                                   0,
                                   0,
                                   -0.71542596423198457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55862313745369296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37387547088203188,
                                   0,
                                   0,
                                   -0.29825152591150816,
                                   -1.0194557187172804,
                                   -0.13379270899546108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22158322944504369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33315394542783305,
                                   0,
                                   -0.25953170735034042,
                                   0,
                                   0,
                                   0.012053773764076486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13775353256917233,
                                   0.39336908287081607,
                                   0,
                                   0,
                                   0,
                                   -0.11400366717495133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0023346472243605497,
                                   0,
                                   0,
                                   0,
                                   -0.27806384063056189,
                                   0,
                                   0,
                                   0,
                                   -0.21857016088269496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11656934963551244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12248740594343982,
                                   0,
                                   0,
                                   0,
                                   -0.065531750000274266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039667816099773545,
                                   0,
                                   -0.69617097687448204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026070261485721148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078243615378796066,
                                   0.11310948701236151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080025908739012858,
                                   0,
                                   0,
                                   -0.082492723984198477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29916785632271786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59881580423863146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061922121422986531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050891147937538309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56670415897243998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7329420287673728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36322278058977331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057335262015770022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16347625674100352,
                                   0,
                                   0,
                                   0.010789073037773187,
                                   -0.086679654337295992,
                                   -0.23687945278729139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16495762352175525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057636777004777019,
                                   0,
                                   -0.29400057295360799,
                                   0,
                                   0,
                                   -0.33770820408752716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62153133541025751,
                                   -0.64961766409652788,
                                   0,
                                   0,
                                   0,
                                   -0.084980006579437245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13698053100231064,
                                   0,
                                   0,
                                   0,
                                   0.45886557032007758,
                                   0,
                                   0,
                                   0,
                                   -0.6544017372849722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71065377294638277,
                                   0,
                                   0,
                                   -0.18056339394587789,
                                   -0.0039555629491489219,
                                   0.0711926797468935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5506989678667864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072571600069529396,
                                   0,
                                   -0.17847358388496382,
                                   0,
                                   0,
                                   -0.68013226224848156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19865171503556045,
                                   0.37864307884696258,
                                   0,
                                   0,
                                   0,
                                   -0.11210682734986856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2204372980672307,
                                   0,
                                   0,
                                   0,
                                   0.3562273398379589,
                                   0,
                                   0,
                                   0,
                                   0.2917168601983669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64051164107605918,
                                   0,
                                   0,
                                   0.51147425684117409,
                                   -0.097106494537688409,
                                   -0.079151756825191488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040812733109784546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39806888194077139,
                                   0,
                                   -0.035097346761086445,
                                   0,
                                   0,
                                   0.5808292185148114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.542575628353132,
                                   -0.19260573363523936,
                                   0,
                                   0,
                                   0,
                                   -0.21920778584149264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22395499363698762,
                                   0,
                                   0,
                                   0,
                                   -0.2901135927731408,
                                   0,
                                   0,
                                   0,
                                   0.15698101162053268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14259957890109856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29954528181400797,
                                   0,
                                   0,
                                   0,
                                   -0.26753087724450142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29269288597575066,
                                   0,
                                   -0.14868338968049752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29222349728325714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47595815667423419,
                                   0.27942610051483191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15658826362579548,
                                   0,
                                   0,
                                   -0.24683126053161719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017163118868204874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48460244019703114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45314532481995334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11980734126181405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22822278306485086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75827667677307431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2615364293998374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47143713817123928,
                                   0,
                                   0,
                                   0.25894649726172042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21210269547687319,
                                   0,
                                   0,
                                   1.0112899114959648,
                                   0,
                                   0,
                                   0,
                                   -0.19724299827931535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29018643344421891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20687167097428313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73775268606802347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46551550437496048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71412061318918063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72520418665144659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68947807184308907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35823050954676372,
                                   0.46859668314974884,
                                   0.19605255897809845,
                                   0,
                                   -0.24891616489631774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12543232642766983,
                                   0,
                                   0.21425946862624615,
                                   0,
                                   -0.19671807332794916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091605878666989243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2360592758498048,
                                   0,
                                   0,
                                   -0.61299252935527238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15225855659883067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02719308294846521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38127675528639227,
                                   0,
                                   0,
                                   0,
                                   0.0014994013038457221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63925568408086553,
                                   0,
                                   0.20253995551981391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069152084138346809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21283069457064777,
                                   0.14906404476408186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43743926523393428,
                                   0,
                                   0,
                                   -0.2101996791438136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30652508888213276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049217984251789686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34098390074838025,
                                   -0.35459817829020174,
                                   0,
                                   0.025481567082893883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44058369480005355,
                                   0,
                                   -0.6909960118010483,
                                   0,
                                   0.734226626849105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059371628278860694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074442097486017558,
                                   0,
                                   0,
                                   -0.092101408235681553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45337367344021684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10174851184053071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20294433286732269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013934259715079084,
                                   0,
                                   0,
                                   -0.56647104965399575,
                                   0,
                                   0,
                                   0,
                                   -0.13521368925612004,
                                   0,
                                   0,
                                   0,
                                   -0.074446778579026138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.159630164422185,
                                   0,
                                   0,
                                   0.33662375179888765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5219498356715393,
                                   0.17345299352565835,
                                   0,
                                   0,
                                   0,
                                   -0.26489099445185271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069783417897885572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23402780964963465,
                                   0,
                                   0,
                                   -0.18008683507835949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69600967152219073,
                                   0.3477486046106219,
                                   0,
                                   0.70703057545072956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62813538917488554,
                                   0,
                                   0.014719170087218418,
                                   0,
                                   -0.24442982011546269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46389877379834082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40396374721944067,
                                   0,
                                   0,
                                   0.29956656680349764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29824940215101103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095688074549218294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54028564757744824,
                                   0,
                                   0,
                                   0,
                                   0.079594882892878138,
                                   0,
                                   0,
                                   0,
                                   0.4108790269391448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35456092761020402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57408318894343968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071254036236832963,
                                   0,
                                   0.25182572218574861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50889902110089635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52309599036858834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44559196560512582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2781772729220211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072483203623951234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2986324641066665,
                                   0,
                                   0,
                                   0,
                                   -0.1432159612242217,
                                   0,
                                   -0.23312620049627847,
                                   0,
                                   0.10388006079066453,
                                   -0.10664290336253537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02173701073653185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45766111968363227,
                                   0,
                                   0,
                                   0,
                                   -0.060006474576040823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37821132100658839,
                                   0,
                                   0.033920302498583153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023362788803995498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54457169241891479,
                                   -0.37309990165610613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11647072532943635,
                                   0,
                                   0,
                                   -0.38237359745309385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21492953149340616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0011173842294741471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58247562690060262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056666166927018008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1478244373591813,
                                   0.59425544336306424,
                                   0,
                                   -0.50840245290614328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4522794346984968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63169962004528935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35723673692997793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11851177537324936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3644372016189017,
                                   0,
                                   0,
                                   0,
                                   -0.58608067044346102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10180268358035363,
                                   0,
                                   -0.071655152362615174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26647683722820809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3550981729598624,
                                   0.39748446820521394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13464257526487017,
                                   0,
                                   0,
                                   -0.31459173694618264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13308100629499431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065161550887871733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33613139200545195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082252103799295623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24417061096376644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34998233671128587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030808235506170338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57496116152271459,
                                   0,
                                   0,
                                   0.016404462860095004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32726665017277545,
                                   0,
                                   0,
                                   0.048249912957167858,
                                   0,
                                   0,
                                   0,
                                   -0.673965899678175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11798540328835172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99198842744228588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13950237415887715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70674552161633719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12263061719339001,
                                   0,
                                   0,
                                   0.076594783551006809,
                                   0,
                                   0,
                                   0,
                                   0.30897683395105757,
                                   0,
                                   0,
                                   0,
                                   0.092303712913235247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28166694343620124,
                                   0,
                                   0,
                                   -0.087789205310715962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32564906609451838,
                                   -0.31498074798641912,
                                   0,
                                   0,
                                   0,
                                   -0.082018811317973603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058030865047530154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14435401352918606,
                                   0,
                                   0,
                                   -0.18144426535050717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17977951764922109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87338487091964623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89064200489802559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64610395146356436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81276654639027313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27852031159392016,
                                   0,
                                   0,
                                   0.29183334289616669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63396369096891692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45026355777953653,
                                   0.37088551289425425,
                                   0,
                                   0.50604203746479048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016878324777769182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56548586815416835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74649119493270955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10807105057479792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26900626007995793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33485034348114973,
                                   0.51433457957663187,
                                   0,
                                   0.28747039178959721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23058931238292976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74217975258996915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73203682405042958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014759226032175554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056281284363534571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29801125856567112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56629847312266102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83925727563398989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38873194719264714,
                                   0,
                                   0,
                                   -0.88173864565906923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31092076734370722,
                                   0,
                                   0,
                                   0.21641891516008938,
                                   0,
                                   0,
                                   0,
                                   -0.21670093665794166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18742304570696472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31299957101706233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58599276450703852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49576449502993791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33874955365168236,
                                   0.14552364333780546,
                                   0,
                                   -0.56029837868926557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86534029896379472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28929153902574206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.004366738360394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31026400711586538,
                                   0,
                                   0,
                                   0.16046941066156623,
                                   0.44935212257760093,
                                   0.30641534499904721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71645514126388732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11519383229919913,
                                   0,
                                   -0.55813652657933133,
                                   0,
                                   0,
                                   0.53381236663162457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29363339412938494,
                                   -0.0080062332871157771,
                                   0,
                                   0,
                                   0,
                                   -0.54221157391101515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55765048433184072,
                                   0,
                                   0,
                                   0,
                                   -0.049084912241932156,
                                   0,
                                   0,
                                   0,
                                   0.090261601738092459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22594940449445403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044054496311893794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055290416857249468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018106466421379835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20323733900231308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11336013702348463,
                                   0,
                                   0,
                                   0,
                                   0.92636063276907477,
                                   0,
                                   -0.0094506147695420269,
                                   0,
                                   -0.15822692833277421,
                                   -0.078715691552598804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0540081947549726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23229155703195861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42085968842480742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46501838204530493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46746123394646677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93297854194261975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24638044515107768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30192152850557702,
                                   0,
                                   0,
                                   0,
                                   -0.020928890089444062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055510924632627093,
                                   0,
                                   -0.40739759871804959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12260166073749576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15732293490932425,
                                   -0.30681072158781614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65355640281808136,
                                   0,
                                   0,
                                   0.084275259920452553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076727595155583736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32343140746376736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070406872541487669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41053302661237284,
                                   0,
                                   0,
                                   0,
                                   -0.15045641119960335,
                                   0,
                                   0,
                                   0,
                                   -0.024992850078355389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85630661300466171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20452796824681407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12262496836162831,
                                   0,
                                   -0.11451700309094932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66185059641915767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056288057513487658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18548262359894707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56050781521403403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6391856504296366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27066824370621506,
                                   0,
                                   0,
                                   0.1450044787703014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.539489472411112,
                                   0,
                                   0,
                                   -0.2318428929650225,
                                   0,
                                   0,
                                   0,
                                   0.029439021071819518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2683473107783273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1765535835644601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37251617309934743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13073097103938716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10855727344051366,
                                   0,
                                   0,
                                   0.11757661219437254,
                                   0,
                                   0,
                                   0,
                                   -0.4685625939191907,
                                   0,
                                   0,
                                   0,
                                   0.39145576421985673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11184457829318929,
                                   0,
                                   0,
                                   -0.24203127154915047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32389155383536128,
                                   0.12118433803528114,
                                   0,
                                   0,
                                   0,
                                   -0.18846858025325686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43571399893640439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14586543164671936,
                                   0,
                                   0,
                                   0.091761133296234379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086285709768646288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23311521373458549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3192474588465376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16629886933935939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49076419988519637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34664063762240027,
                                   0,
                                   0,
                                   0,
                                   0.084461259013481824,
                                   0,
                                   0.55949775980439342,
                                   0,
                                   0.33005844549998903,
                                   0.13608292694277982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65299335919014856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24202743886454717,
                                   0,
                                   0,
                                   0,
                                   -0.26318980444336043,
                                   0,
                                   0,
                                   0,
                                   -0.054757406525892817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2597611076856442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16516640890886347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019534974224063265,
                                   0,
                                   -0.58959117534271133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10416269561052161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12266038398556854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10716270302347675,
                                   0,
                                   0,
                                   -0.073982080646175716,
                                   0,
                                   0,
                                   0,
                                   -0.17691301677070492,
                                   0,
                                   0,
                                   0,
                                   0.3866854495771167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23147792819260177,
                                   0,
                                   0,
                                   -0.10672674006402644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31163945120792286,
                                   0.3217328285975517,
                                   0,
                                   0,
                                   0,
                                   -0.19645180049733924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67429601479852119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061445155894443715,
                                   0,
                                   0,
                                   -0.11694355879552007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66329204903789196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039249272722818092,
                                   0,
                                   0,
                                   0,
                                   0.041357789459796929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24893708713914436,
                                   0,
                                   0.019365351224678751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31592934393509442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2784572187954979,
                                   -0.056701120808269209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1760594154530585,
                                   0,
                                   0,
                                   -0.49424643285401787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1951435138908704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022929457291848906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10804358896159227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030522224850484447,
                                   0,
                                   0,
                                   0,
                                   -0.57575405515634581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28054862541523895,
                                   0,
                                   0.3502604935416912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1195811054194528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072790840120511111,
                                   -0.17565427779102752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14903238241334882,
                                   0,
                                   0,
                                   0.31351460847746643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51504307415983852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13523423614373281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49689506567425568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11164440933324664,
                                   0,
                                   0,
                                   0,
                                   -0.21487948607737847,
                                   0,
                                   0,
                                   0,
                                   -0.51437457603354264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24328822013700599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32089698300294967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3982484856466072,
                                   0,
                                   -0.33031883610990043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33201922399492567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067315683419235953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011897355407209209,
                                   0,
                                   0,
                                   -0.04872536528044321,
                                   0,
                                   0,
                                   0,
                                   -0.17674485844702259,
                                   0,
                                   0,
                                   0,
                                   -0.082537017917068786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30917406595185326,
                                   0,
                                   0,
                                   -0.35439189615103706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22963880305001244,
                                   0.21879317927632302,
                                   0,
                                   0,
                                   0,
                                   0.32234774388487775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056506336512159534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35359845369265541,
                                   0,
                                   0,
                                   -0.53920818454078168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12394393706104354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61774047409463628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2112057829430237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34896893687846897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58776853335754042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019521700251748382,
                                   0,
                                   0,
                                   0.50705355970250232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15185818914482213,
                                   0,
                                   0,
                                   -0.4763383698708249,
                                   0,
                                   0,
                                   0,
                                   -0.39848317460756844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085318064838551338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43915708079294263,
                                   0,
                                   0,
                                   0,
                                   0.19467747524725845,
                                   0.057591108214068099,
                                   0,
                                   0.61515175262306754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24699336252894605,
                                   0,
                                   -0.080436946646563715,
                                   0,
                                   0.85832999017592637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88969231291673423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46185338749793875,
                                   0,
                                   0,
                                   0.60744388174323916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61133197659906724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29568291420224441,
                                   0,
                                   0,
                                   -0.30978712967110228,
                                   -0.32074519178121658,
                                   0.98676829651301001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27792025454630676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34345307985519102,
                                   0,
                                   0.21658038580891603,
                                   0,
                                   0,
                                   0.47465649463921616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12457793051607308,
                                   -0.14287946751402392,
                                   0,
                                   0,
                                   0,
                                   0.15372865856559564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43896420618800369,
                                   0,
                                   0,
                                   0,
                                   -0.39183982657046446,
                                   0,
                                   0,
                                   0,
                                   -0.4418665161523464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04765696640417412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43064231325268321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0036987274970428918,
                                   0,
                                   0,
                                   -0.073082022911917427,
                                   0,
                                   0,
                                   0,
                                   0.46887640336115127,
                                   0,
                                   0,
                                   0,
                                   0.42564097785212784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25863139087428066,
                                   0,
                                   0,
                                   -0.073903635764156581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11430321492000824,
                                   -0.13770095350943384,
                                   0,
                                   0,
                                   0,
                                   -0.060028448270825048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25745586220327937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17300070533011822,
                                   0,
                                   0,
                                   -0.4491226162009565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46808015969567301,
                                   0,
                                   0,
                                   0.36547464599385887,
                                   -0.14016920164810509,
                                   0.19431724983181972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29718018163694881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44448392497023492,
                                   0,
                                   -0.12810426227449967,
                                   0,
                                   0,
                                   0.46845509492145559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44558539425665467,
                                   0.370691474925119,
                                   0,
                                   0,
                                   0,
                                   0.30486685880930448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23479149768505617,
                                   0,
                                   0,
                                   0,
                                   0.55319474117443534,
                                   0,
                                   0,
                                   0,
                                   0.35408678664887633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82472273441618094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2886213776206879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21499747474690581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22091245700670106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15649807763680923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34207051262149651,
                                   0,
                                   0.05038316241551144,
                                   -0.66013653671563866,
                                   0,
                                   0.90893031983722816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20569169103160451,
                                   0,
                                   -0.14377072166272184,
                                   0,
                                   -0.31619294911866136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37404349523483804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20018474574932679,
                                   0,
                                   0,
                                   -0.53526338033746201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033489205111151166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034982168135590533,
                                   0,
                                   0,
                                   -0.51818579045646518,
                                   0.28686377991742401,
                                   -0.73296137120167337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56833681962657934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22832874208953241,
                                   0,
                                   -0.022828932364724122,
                                   0,
                                   0,
                                   0.64396487184285423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026213668065267495,
                                   -0.067887423308846367,
                                   0,
                                   0,
                                   0,
                                   0.83214685813252898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44610645276536121,
                                   0,
                                   0,
                                   0,
                                   -0.0038934410437251321,
                                   0,
                                   0,
                                   0,
                                   -0.0095385556621564883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58344933271341737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27970560160527341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62934016202160503,
                                   -0.53244457131798684,
                                   0,
                                   0.27484678264103346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0047018150191234058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46500131618708462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050630299409426843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58478958930948088,
                                   -0.84147718162541818,
                                   0,
                                   -0.015931749676780821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46145150508803429,
                                   0,
                                   0.46913010808557237,
                                   0,
                                   0.82715586159082077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54808562905078273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078301747063353327,
                                   0,
                                   0,
                                   0.12142155247856391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56398396005099227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2339961896506137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36367240640609794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22348944352047642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58612795335247991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30831544984447085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4132900122067949,
                                   0,
                                   0,
                                   0,
                                   0.11073614889114282,
                                   0,
                                   0.37110157991521925,
                                   0,
                                   0.042910125885230091,
                                   -0.042514091646684814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28390447229691584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13190669891734622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18209219625296386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044438411764588306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017569571122711816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93089088683084398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24033353526844795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18053783843811838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38970566929407607,
                                   0,
                                   0,
                                   0.39732637344477922,
                                   0,
                                   0,
                                   0,
                                   -0.058886512199626553,
                                   0,
                                   0,
                                   0,
                                   0.38094514404689384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37245490552672073,
                                   0,
                                   0,
                                   0.049323219046209399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12216950636395726,
                                   0.084291490305517192,
                                   0,
                                   0,
                                   0,
                                   -0.068264676824712545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015881911766819214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52638651509712986,
                                   0,
                                   0,
                                   -0.078354043930113637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38170053066355869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27866009192199437,
                                   0,
                                   0,
                                   0,
                                   0.12144338225668777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32090372737493439,
                                   0,
                                   0.079481116244712796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47521340842038479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1528297991740214,
                                   -0.4019742458224923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041024343218408421,
                                   0,
                                   0,
                                   -0.48833181424160094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035473624404061203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020759382375186101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51840572864230539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11131030692376348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022382772688982165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26199293565827747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3952056294436187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32247925718360954,
                                   0,
                                   0,
                                   0.11386638915646319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13469538171427098,
                                   0,
                                   0,
                                   -0.21562368778964403,
                                   0,
                                   0,
                                   0,
                                   -0.034901589121149108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.118543070497577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042557437213799579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29109209262557989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2341537380869064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30459625027439174,
                                   0,
                                   0,
                                   -0.36464988220853423,
                                   0,
                                   0,
                                   0,
                                   -0.059671800918915142,
                                   0,
                                   0,
                                   0,
                                   0.12675191189657384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36986834933688928,
                                   0,
                                   0,
                                   -0.14141049573062259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40401269625270037,
                                   -0.11433007899611333,
                                   0,
                                   0,
                                   0,
                                   -0.45300362480428841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23342794944226208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13982127098192046,
                                   0,
                                   0,
                                   -0.052098060945443912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068583928801327146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18431991096356082,
                                   0,
                                   0,
                                   0,
                                   -0.41269284650583959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093408057452209148,
                                   0,
                                   0.069956389713346001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39993856964961672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062275939241918599,
                                   -0.4124355061980402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11579796266185716,
                                   0,
                                   0,
                                   -0.069196009279268694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56873387190717661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31906174344588256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11661443546745053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25144401545344702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21954573909514891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64633666954623736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50503698730385327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0697819535741671,
                                   0,
                                   0,
                                   -0.67867782733808013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15218583383566339,
                                   0,
                                   0,
                                   -0.56965524560773984,
                                   0,
                                   0,
                                   0,
                                   -0.32448049939885742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014694649776943524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21313274517829542,
                                   0,
                                   0,
                                   0,
                                   0.03365465476198698,
                                   -0.36436313996364511,
                                   0,
                                   0.056873903137364935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73915346846684649,
                                   0,
                                   -0.22223061518789311,
                                   0,
                                   -0.35887703618985251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042217647881425902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20463519454768175,
                                   0,
                                   0,
                                   0.85423953943386477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98112264188158205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096961749415038365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055349783854786797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21283355192725589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3030584340497493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47551944809119223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30957143083132338,
                                   0,
                                   0,
                                   0,
                                   0.15693550846118778,
                                   0,
                                   -0.62668770383328787,
                                   0,
                                   0.33325465401716331,
                                   0.0037646549807363984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46861109531489292,
                                   0,
                                   0,
                                   0.045859588273498619,
                                   0.33587793652606729,
                                   0.28134797394032812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094813023935157462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010823355777034385,
                                   0,
                                   -0.041461176415005463,
                                   0,
                                   0,
                                   -0.47220822613025681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79031647044717679,
                                   0.11007626048404259,
                                   0,
                                   0,
                                   0,
                                   0.00097430050549998128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26010213989778608,
                                   0,
                                   0,
                                   0,
                                   -0.60777809629735691,
                                   0,
                                   0,
                                   0,
                                   0.31107082082348247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058038419467998509,
                                   0,
                                   0,
                                   -0.16480327663227029,
                                   0.44714491773923909,
                                   0.26299783875165073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15717895138733268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3115652634516082,
                                   0,
                                   0.20959047752196552,
                                   0,
                                   0,
                                   0.15149200799991253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21662143453364946,
                                   -0.011806607850837897,
                                   0,
                                   0,
                                   0,
                                   0.095473841975681734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21470110797802094,
                                   0,
                                   0,
                                   0,
                                   0.55456065702599155,
                                   0,
                                   0,
                                   0,
                                   -0.37258668329189076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35570642441082856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044082695972127599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12803344691488056,
                                   0,
                                   0,
                                   -0.32032014409296916,
                                   0,
                                   0,
                                   0,
                                   -0.19101474128782847,
                                   0,
                                   0,
                                   0,
                                   -0.07631836160085953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1016603025982538,
                                   0,
                                   0,
                                   -0.26800815379157478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22172786214406415,
                                   -0.11220441441025124,
                                   0,
                                   0,
                                   0,
                                   0.44913458223910574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11143701321479681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54467443618134725,
                                   0,
                                   0,
                                   -0.23557246911999544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079899531871360924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16126733051008438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41646690195445368,
                                   0,
                                   0,
                                   0.10835382038511415,
                                   0,
                                   0,
                                   0,
                                   -0.28858132115750323,
                                   0,
                                   0,
                                   0,
                                   0.19181031519460193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14160761232452518,
                                   0,
                                   0,
                                   0.14382233967877223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.135704281233058,
                                   -0.66514533166806622,
                                   0,
                                   0,
                                   0,
                                   0.095169933804395479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36511239278015278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0011129645796159188,
                                   0,
                                   0,
                                   -0.13570610291862162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11427982678914253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6934617194744519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078952072504253415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20727371262294061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67096413294951363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081622762821856876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046136586556669704,
                                   0,
                                   0,
                                   0.80023632162700098,
                                   -0.056994723528732354,
                                   0.48003692752047161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16144937227448239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084429271856047761,
                                   0,
                                   0.40915964877834943,
                                   0,
                                   0,
                                   -0.26854704080657532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60762329846735308,
                                   -0.14810382318044585,
                                   0,
                                   0,
                                   0,
                                   0.50948725856524446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59578421792610237,
                                   0,
                                   0,
                                   0,
                                   0.073278578022789267,
                                   0,
                                   0,
                                   0,
                                   0.056123904115303866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63098085363112233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30789497477331829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63978735713198986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28092120108001623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12609183648905287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48894094179298753,
                                   0,
                                   0,
                                   0.35072700607393659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13058293742313029,
                                   0,
                                   0,
                                   0.33674636101382954,
                                   0,
                                   0,
                                   0,
                                   -0.74186235915295584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10219870993700639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18026856661418619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54715183799898937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21124923866184278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30401938550178187,
                                   0,
                                   0,
                                   -0.03037364823387162,
                                   0,
                                   0,
                                   0,
                                   0.067766766658929931,
                                   0,
                                   0,
                                   0,
                                   -0.098356402384329439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44306165593512969,
                                   0,
                                   0,
                                   0.3966988307931909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052011071620453708,
                                   -0.037721401867399723,
                                   0,
                                   0,
                                   0,
                                   -0.17916430412285173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021471064342934668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20798736452946726,
                                   0,
                                   0,
                                   -0.33876351072015792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48749571298398608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42863084257058226,
                                   0,
                                   0,
                                   0,
                                   0.18921160811415536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25384136088404796,
                                   0,
                                   0.1924298353775131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51851942080092817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2510430506410431,
                                   0.067571631674351568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2290234976901174,
                                   0,
                                   0,
                                   -0.069078611930778536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20496171303645855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075325763016896002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26370260408307261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4372354285359199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70587688036132556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29969393486381479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30746945501427719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087758782603603369,
                                   0,
                                   0,
                                   -0.23614498576443049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1567996700015819,
                                   0,
                                   0,
                                   0.23726690930277153,
                                   0,
                                   0,
                                   0,
                                   0.28908257922300673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15816024682802493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13010791277991854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52291738165859603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26881597683402642,
                                   0,
                                   0,
                                   0,
                                   -0.1586491432651996,
                                   0,
                                   0,
                                   0,
                                   -0.42374454426622471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011157674162642017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22465345521389618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35437628831364354,
                                   0,
                                   0.52286725920896771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54559630784542623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013813095737221085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05895294657625548,
                                   0.1153026995443253,
                                   0,
                                   0.87304075460799058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79086214001767852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65094360224008996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63178509349668865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16672082469829896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02889395521038237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11482144768686289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053194709085980674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36409789387078667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034417755138912695,
                                   0,
                                   0,
                                   0,
                                   0.019300079361125929,
                                   0,
                                   0.1704694347154479,
                                   0,
                                   0.63111489661066522,
                                   -0.62758702336105665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19509668740167818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41448187623937977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35199341977077708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27530529480865895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11343772984302129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66863232358845059,
                                   0,
                                   0,
                                   0.4184515831508071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10483042155936381,
                                   0,
                                   0,
                                   -0.0027625815794578845,
                                   0,
                                   0,
                                   0,
                                   0.74107656000641442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29746448543102078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37467280231766509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36301008391551526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077121107933838431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41723272295251895,
                                   0,
                                   0,
                                   -0.083229937816530375,
                                   0,
                                   0,
                                   0,
                                   -0.44302173013901641,
                                   0,
                                   0,
                                   0,
                                   0.10340025782288595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26607094780232116,
                                   0,
                                   0,
                                   0.37841064301099436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25658562608441687,
                                   -0.24258246563067282,
                                   0,
                                   0,
                                   0,
                                   0.14427177626089566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22773871662509973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24995903778886852,
                                   0,
                                   0,
                                   -0.021821781350699787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17368997620439497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6139486884276899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47187076042087489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013603277827120244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60423922281425757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070332766539080577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70816034338134937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28330354277182329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31199187918380833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33041569034545298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14590508689563286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13806787285417749,
                                   0,
                                   0,
                                   0,
                                   0.1241820271075663,
                                   0,
                                   0.090689074682637705,
                                   0,
                                   -0.31978257544687622,
                                   -0.2132532720325255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026940725373094707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50429799108568407,
                                   0,
                                   0,
                                   0,
                                   0.023418241113849513,
                                   0,
                                   0,
                                   0,
                                   -0.5612450043415268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08945759538367247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18716734077009461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54846191105279329,
                                   0,
                                   0.29252114776485516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12123466906421901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0646437429566947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023522840308598164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51731342265537905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48651329649432451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30298202182734851,
                                   0,
                                   0,
                                   0,
                                   0.028861257485590049,
                                   0,
                                   -0.1339340316825347,
                                   0,
                                   -0.17022631415050343,
                                   -0.58027170529484662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24540907306296814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.164695276683428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44798845409329263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40914439305852152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43353268446404813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090523432516494917,
                                   0,
                                   0,
                                   -0.3417434390303451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049831281184627554,
                                   0,
                                   0,
                                   0.60968253136649742,
                                   0,
                                   0,
                                   0,
                                   -0.059770397044496715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38010900863906705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0033008211994615191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13504738751445997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56842665486690591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54508447152178063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19479888045224342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028286713867701367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4284482012836569,
                                   0,
                                   0,
                                   0,
                                   0.14561815766852412,
                                   0,
                                   0.092902097883323181,
                                   0,
                                   0.15579837354150711,
                                   0.29174145410962271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23694953981085401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35550306907975826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43935506732594742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20415647926016856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0079505133525956673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46427578869721436,
                                   0,
                                   0,
                                   0,
                                   0.19871820449728944,
                                   0,
                                   -0.1954937223346157,
                                   0,
                                   0.43418614883052759,
                                   0.31767938162440335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47721647970168474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57378674184846323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59776438874305649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18544089020064003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20011802222984332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1756109589499724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22457903010476782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.136568387293722,
                                   0,
                                   0,
                                   0,
                                   0.15011033104148122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17550939646867222,
                                   0,
                                   0.32963786156488262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23195870871614652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31866367257722972,
                                   0.35391417321760654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44513069776717595,
                                   0,
                                   0,
                                   -0.21261861757270292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27636524967792486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41058880730143088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018191996885777398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33119817080955355,
                                   0,
                                   0,
                                   0,
                                   -0.55049770824028676,
                                   0,
                                   0,
                                   0,
                                   0.053992544868079889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025396065357227937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4764664210900485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59161212361153559,
                                   0,
                                   -0.079647886704138776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021293598371776686,
                                   0,
                                   0,
                                   -0.35180125261046813,
                                   -0.25894360098521613,
                                   -0.28227536850041479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24649060323463493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59323693812945821,
                                   0,
                                   0.49595987836311289,
                                   0,
                                   0,
                                   -0.022833558943228985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068518333856375582,
                                   -0.78025808168348121,
                                   0,
                                   0,
                                   0,
                                   -0.19253621212658015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86637259306006187,
                                   0,
                                   0,
                                   0,
                                   0.19694244805584646,
                                   0,
                                   0,
                                   0,
                                   0.34702909302578316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19514684669532995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17955939469077514,
                                   0,
                                   0,
                                   0,
                                   -0.72582350801895101,
                                   0,
                                   0,
                                   0,
                                   0.2559367422476328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074755781134263677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43106953873854958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21096109005627448,
                                   0,
                                   0.31849457706355555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.087560732706661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03794332505409697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52646807915387184,
                                   -0.45954981805258799,
                                   0,
                                   0.1616793865320838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40013012608989107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26195196831973144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15694138312441894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0077618914421968173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24040185198694308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26079402315004968,
                                   0,
                                   0,
                                   -0.21676272973700739,
                                   0,
                                   0,
                                   0,
                                   0.20680022667174708,
                                   0,
                                   0,
                                   0,
                                   0.48768493472935459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17319989668732327,
                                   0,
                                   0,
                                   0.37947725549509992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036276538615134607,
                                   0.25251423390308286,
                                   0,
                                   0,
                                   0,
                                   0.51701045402918366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050874287812016687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.006814462788609827,
                                   0,
                                   0,
                                   0.19372432193225012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10415764655376876,
                                   0,
                                   0,
                                   -0.017696890716964918,
                                   -0.15932721906860287,
                                   -0.11318239557530629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17714078468248501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25824456393474871,
                                   0,
                                   0.92200139552961957,
                                   0,
                                   0,
                                   0.026422497474980114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26669260235420844,
                                   0.34171037581505337,
                                   0,
                                   0,
                                   0,
                                   -0.75601663946952147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35129854312048414,
                                   0,
                                   0,
                                   0,
                                   -0.014636623795463512,
                                   0,
                                   0,
                                   0,
                                   -0.16390022223065012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52268517273133208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99390011278422985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39137459163823851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21027963045670034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52683196812342048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39104600244702559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037982865648240771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11603761864662006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43855755752054454,
                                   0,
                                   0,
                                   -0.43152270734914477,
                                   0,
                                   0,
                                   0,
                                   0.11788363132904106,
                                   0,
                                   0,
                                   0,
                                   0.1821777101838534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25219740943064833,
                                   0,
                                   0,
                                   -0.34415388941954145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19521551587715824,
                                   -0.29403122706458734,
                                   0,
                                   0,
                                   0,
                                   0.024797884456085592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14961339847963767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21281595044452289,
                                   0,
                                   0,
                                   0.42960924133489564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2039822745683455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10645479146721068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0383614980703804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58753137399810007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31154045490481774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10549222918535853,
                                   0,
                                   0,
                                   -0.083406147474617706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66153841511630718,
                                   0,
                                   0,
                                   -0.22497900480398408,
                                   0,
                                   0,
                                   0,
                                   0.19393736616333446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039806195300309599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35170650655426799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2097458234183949,
                                   0,
                                   0,
                                   0.34584020039253338,
                                   0.43481411179685703,
                                   -0.57332324069591944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55424813914090332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063715243560817647,
                                   0,
                                   0.30875640242739644,
                                   0,
                                   0,
                                   -0.24346866313682219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068480020162823591,
                                   0.46208968149211666,
                                   0,
                                   0,
                                   0,
                                   0.038253259763474268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60895198065417477,
                                   0,
                                   0,
                                   0,
                                   -0.35099666372030808,
                                   0,
                                   0,
                                   0,
                                   -0.49498370156580723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43836996496172576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19719600864145428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60874417436775008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60734788651425486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16724523142771131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039161402937343923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79392222222543973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15168989021826318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55904102821456947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95035249089424578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62859764163563181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20851929796724836,
                                   0.069495165357824351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046936218496532518,
                                   0,
                                   0,
                                   0.217091710567693,
                                   -0.59271892584501018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41166093499690648,
                                   0,
                                   0,
                                   -0.071037436184442637,
                                   -0.20354572552090558,
                                   0.17688655155016744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31127503607496954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33103175705647003,
                                   -0.092992264198085373,
                                   0,
                                   0,
                                   -0.12595232249028623,
                                   0,
                                   -0.13468411653651124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31331547686280481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25755854036553599,
                                   0,
                                   0,
                                   -0.14652612776098445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51652539904868744,
                                   0,
                                   0,
                                   0,
                                   -0.18240182837877064,
                                   0,
                                   0,
                                   -0.16034928145715596,
                                   0.60302601565804759,
                                   0,
                                   0,
                                   -0.18344944400079297,
                                   0,
                                   0,
                                   0.239299281944961,
                                   0,
                                   0,
                                   0,
                                   -0.0796431421665144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58452569305951074,
                                   0,
                                   0,
                                   0,
                                   -0.2270422244272482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57345070079846194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34269978910998466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48497268256037795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15090525474208905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27106557972630962,
                                   0,
                                   0,
                                   0,
                                   0.60207560687394623,
                                   -0.4342975603205671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.150455883926705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055624547995396303,
                                   0,
                                   0,
                                   0,
                                   0.43796141162946445,
                                   0,
                                   0,
                                   -0.038613010314976479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55324721482559924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71252842647549719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19129546236636721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48465170520656586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29790949357068564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31137401554282462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16348362605590072,
                                   0,
                                   0,
                                   -0.62634320201209115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36545999647095379,
                                   0,
                                   0,
                                   0,
                                   -0.62517459608784565,
                                   0,
                                   0,
                                   0.3576873456692784,
                                   -0.0027741596194747406,
                                   0,
                                   0,
                                   -0.47691839082789589,
                                   0,
                                   0,
                                   -0.20988583194874047,
                                   0,
                                   0,
                                   0,
                                   0.6625641404059347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46494028421789679,
                                   0,
                                   0,
                                   0,
                                   0.39737422357055679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7531370835269221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42101603682958544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41787319724751409,
                                   -0.45894471348220361,
                                   0,
                                   0,
                                   -0.24510891991837641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27591648189050261,
                                   0,
                                   0,
                                   -0.30971864233241198,
                                   0,
                                   0.41640721837010664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11630014331287511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13214407501173381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031313915509564111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.231143030403616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27164186102040794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1923449121078846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45174489365601511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20531192752220839,
                                   0.40207800220904794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25634835415810148,
                                   -0.007162563000228531,
                                   0,
                                   -0.11988304733034377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41086838278910237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27291485872602045,
                                   0,
                                   0,
                                   0,
                                   -0.32320396520019362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61104304433679291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46662866270065706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.08065246554695,
                                   0,
                                   0,
                                   0.075537350358509114,
                                   0,
                                   -0.40793826286749235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52549412237715876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18436836633359985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047412505372537751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34108332791216772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52719375638664578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11506175217694058,
                                   0,
                                   0,
                                   0,
                                   -0.43762739944421103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48943327621494137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21777133815409666,
                                   0,
                                   -0.58248636397869125,
                                   0,
                                   0,
                                   0.092562602398368707,
                                   0,
                                   -0.043027153746994354,
                                   0,
                                   -0.047652088003467319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51631356242993198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098272513559583219,
                                   0,
                                   0,
                                   0,
                                   0.18187620426419238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31508302001357186,
                                   0,
                                   0,
                                   0,
                                   0.42689318667263776,
                                   0,
                                   0,
                                   0.50519769778436252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1146239864127149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13597744807909182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67465773765148973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62408098153754765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11787645845434674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1923556558845811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18581039323620763,
                                   0,
                                   0,
                                   0.040004788230449909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67800148127344617,
                                   0,
                                   0,
                                   0,
                                   0.63272676807366113,
                                   0,
                                   0,
                                   -0.38354352881113984,
                                   0.11785221433867853,
                                   0,
                                   0,
                                   -0.53223977066301831,
                                   0,
                                   0,
                                   0.052815144851508011,
                                   0,
                                   0,
                                   0,
                                   0.30503511723133359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.002781835325470508,
                                   0,
                                   0,
                                   0,
                                   0.36308397429451816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10865407664656622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0025606751624079466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11429962452160344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12586642965755271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09471139576299023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52728065538389468,
                                   -0.35647585947462068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01847761319834448,
                                   -0.41881127672931839,
                                   0,
                                   0.55150301529760015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18965578510958445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16366499202288509,
                                   0,
                                   0,
                                   0,
                                   -0.11983769948432148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012529637147993267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43208725343842186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71390970352904115,
                                   0,
                                   0,
                                   1.1558683940548926,
                                   0,
                                   0.22038725102027951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6235668244015794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10107335797668034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010886717197988635,
                                   0,
                                   0,
                                   0,
                                   -0.16999240915857144,
                                   0,
                                   0,
                                   0.14682469863640243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38356599956826853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28048008477877745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096745034289998422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29454289957806568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1813426518730958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27827088405900269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13442161729264521,
                                   0,
                                   0,
                                   -0.47974791378835557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36002323862788843,
                                   0,
                                   0,
                                   0,
                                   0.49549460151385222,
                                   0,
                                   0,
                                   0.37127853879652473,
                                   -0.51943574281854432,
                                   0,
                                   0,
                                   -0.45141738360918482,
                                   0,
                                   0,
                                   0.13240803654750599,
                                   0,
                                   0,
                                   0,
                                   0.78421393953903817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19174671787555314,
                                   0,
                                   0,
                                   0,
                                   -0.40689567299612639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1161568562278953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32605905978008565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90185359746598714,
                                   0,
                                   0,
                                   0,
                                   -0.83667084550340864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41668075211951194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14215307263837701,
                                   0,
                                   0,
                                   -0.8238973889158292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28098719089277352,
                                   -0.1527924478665651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26869328891704758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44990549459469031,
                                   0,
                                   0,
                                   0,
                                   -0.50628477472955657,
                                   0,
                                   0,
                                   0.44874528348390313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4508260923515876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83376918142103507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38377202585386661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10863845654609089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20274066158439522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33915064566235403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61746540336807576,
                                   0,
                                   0,
                                   -0.0041421524731401829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7337674927698441,
                                   0,
                                   0,
                                   0,
                                   0.29944243092054856,
                                   0,
                                   0,
                                   0.63781712200740792,
                                   0.27558477418646671,
                                   0,
                                   0,
                                   -0.33330168781353509,
                                   0,
                                   0,
                                   0.22653636653748005,
                                   0,
                                   0,
                                   0,
                                   -0.48287326546491838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11255903455540611,
                                   0,
                                   0,
                                   0,
                                   -0.47171287789948524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24447882923547254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10144988216252999,
                                   0,
                                   0,
                                   -0.43532005561074127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49051323787286422,
                                   0,
                                   0,
                                   0,
                                   0.081631884705733862,
                                   0,
                                   0,
                                   0.1941303342971249,
                                   0.55413154100727147,
                                   0,
                                   0,
                                   -0.36414362754217333,
                                   0,
                                   0,
                                   -0.012618131447895673,
                                   0,
                                   0,
                                   0,
                                   0.11750398569544014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8320098356294674,
                                   0,
                                   0,
                                   0,
                                   0.40461055835749876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0019032872974276589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48877826974802752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25310082700565956,
                                   0,
                                   0,
                                   0.45023898353637509,
                                   -0.057696474144676262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12977263478265544,
                                   0,
                                   0,
                                   -0.38734681059646986,
                                   0.16608295795787203,
                                   -0.18311001957414352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23870260195330092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087251582310130221,
                                   -0.029690486499420327,
                                   0,
                                   0,
                                   0.33855279572661573,
                                   0,
                                   0.28118510372345296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06200063324404563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17764293341087861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32126762480775356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0071855823416584752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29757766564850341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37408298147630492,
                                   0.071707228236342915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33835203856388218,
                                   0.24831967041022807,
                                   0,
                                   -0.049508462602629533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19500446430380999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61925581750043046,
                                   0,
                                   0,
                                   0,
                                   -0.17732918815816254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19233403437618157,
                                   0,
                                   0,
                                   -0.79680997211199223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018925676770504135,
                                   0,
                                   0,
                                   0,
                                   0.59540693844101744,
                                   0,
                                   0,
                                   -0.33541880910309024,
                                   0.23500133542808971,
                                   0,
                                   0,
                                   1.0536307446183149,
                                   0,
                                   0,
                                   0.039952462668163033,
                                   0,
                                   0,
                                   0,
                                   0.33765918449445009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25089130862835923,
                                   0,
                                   0,
                                   0,
                                   0.17350396544693181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3647207987960181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29068172746492721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051470728786334005,
                                   0,
                                   0,
                                   -0.092626909298539145,
                                   -0.46995729574816941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0066766132184364821,
                                   0,
                                   0,
                                   0.41942052761796894,
                                   0.39929236692828912,
                                   0.11344175466183309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054651362758285055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07781255712402603,
                                   -0.27150621629527827,
                                   0,
                                   0,
                                   0.099562411783001625,
                                   0,
                                   -0.16823519831363354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46279667709216621,
                                   0,
                                   0,
                                   0,
                                   -0.41050894416680533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1620256772084126,
                                   0,
                                   0,
                                   -0.14695216815378595,
                                   0.084182714639480863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17905082176923257,
                                   0,
                                   0,
                                   0.089635458099816503,
                                   -0.059624896371924203,
                                   -0.45077064219070495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0208156991253476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2109702742218397,
                                   -0.40222629039513697,
                                   0,
                                   0,
                                   -0.50411617506545248,
                                   0,
                                   0.011031129788927372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2621504584284855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.128575642389818,
                                   0,
                                   0,
                                   0.055828274420219065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36030189908156823,
                                   0,
                                   0,
                                   0,
                                   -0.19012975519073855,
                                   0,
                                   0,
                                   0.11389722259026355,
                                   -0.45996037274982915,
                                   0,
                                   0,
                                   -0.10809433713629418,
                                   0,
                                   0,
                                   0.11133805167751917,
                                   0,
                                   0,
                                   0,
                                   -0.35274459384697088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.156993689262409,
                                   0,
                                   0,
                                   0,
                                   0.96934306788412727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087976370709726609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11519705916296571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053020618326714314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13311799694587079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075439044415864243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21185183207926964,
                                   0,
                                   0,
                                   0,
                                   0.32957155034630925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16116172755756972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53481647608533578,
                                   0,
                                   -0.49448453786065327,
                                   0,
                                   0,
                                   -0.096317116325470686,
                                   0,
                                   -0.21595411841225912,
                                   0,
                                   0.75820336384112308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45696578985947522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21506949250116364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19964639401787493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15234606422607286,
                                   -0.30967968532345691,
                                   0,
                                   0,
                                   -0.40331631533616735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44775913204182083,
                                   0,
                                   0,
                                   0.58180328079278842,
                                   0,
                                   -0.28121426383971049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10673839647680275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1798005729797274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12876468836921015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10445382488415331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050118313472707607,
                                   -0.44737213592576486,
                                   0,
                                   0,
                                   0.13220727756216419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062371357980004302,
                                   0,
                                   0,
                                   -0.018147095016709386,
                                   0,
                                   -0.36500742070318942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3194809925598614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047663844797585952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72606273396202337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26376339659082554,
                                   0,
                                   0,
                                   -0.14920663648765586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32196301200243194,
                                   0,
                                   0,
                                   0,
                                   -0.86790273700540366,
                                   0,
                                   0,
                                   -0.052176275549136161,
                                   -0.5220933921924914,
                                   0,
                                   0,
                                   0.036598825151964179,
                                   0,
                                   0,
                                   -0.32230552527543388,
                                   0,
                                   0,
                                   0,
                                   -0.11364929895938654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16540677968098716,
                                   0,
                                   0,
                                   0,
                                   -0.20654714907025185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79314297204846351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29102287781895309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076166282301125154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021039676881319899,
                                   0,
                                   -0.34714142662286529,
                                   -0.34650404076267055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58349902067380466,
                                   -0.56601291829202527,
                                   0,
                                   -0.087451488722428722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37871127135257016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11502492899659203,
                                   0.13039057784091071,
                                   0,
                                   0,
                                   0.037911584200366152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054897573897147917,
                                   0,
                                   0,
                                   0.069240378928238089,
                                   0,
                                   0.04988843319507133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81879066643955201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33414348593058568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18039177795740469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053542128822096406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.608006712360037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27501835615491049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031143019644534961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08299658950131987,
                                   0.068622640610741761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52097395653390643,
                                   -0.24612903720872603,
                                   0,
                                   -0.20990529234678784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29987643429568778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10809217570969622,
                                   0,
                                   0,
                                   0,
                                   -0.24818380528096465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39476151115326541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97611661206532407,
                                   0,
                                   0,
                                   0,
                                   -0.54601169878080991,
                                   0,
                                   0,
                                   -0.42494512602660167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26963252699962409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15287420199232118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28611235858012785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11501593572232396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049642913205516219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0091635085794255187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043869169150167461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41503434326186539,
                                   0,
                                   0,
                                   -0.21153008487473474,
                                   -0.18396733334237073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11044244967439087,
                                   0,
                                   0,
                                   -0.14181575475369756,
                                   -0.28543276804696771,
                                   -0.26839332981606812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44172697646337838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41143250378580964,
                                   0.27658782379058294,
                                   0,
                                   0,
                                   0.026118815208551888,
                                   0,
                                   0.12714804663341137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32197496233272344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19042605906286342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41550512778524445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34847543915662632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16072557462380924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68761958633413445,
                                   0,
                                   0,
                                   0,
                                   0.56968040544466969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012876292730226377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079854251625248174,
                                   0,
                                   -0.42364420437087608,
                                   0,
                                   0,
                                   -0.41913833368758602,
                                   0,
                                   0.29648758451573609,
                                   0,
                                   -0.14073656521341921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63831503085525676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48691249138384862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4131570195624612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51716643715174138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055782695359473292,
                                   0,
                                   0.26210389462871952,
                                   0.15913969046315393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44970687971250023,
                                   0.44658676472788794,
                                   0,
                                   0.25105484583520921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13954064205371522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36308303736245839,
                                   0,
                                   0,
                                   -0.22646605150543653,
                                   -0.030753398577863807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20309237893958079,
                                   0,
                                   0,
                                   -0.32354314035693693,
                                   -0.22599351024799633,
                                   0.4240074626282998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22765327168043975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35136506485133595,
                                   -0.47286375509338036,
                                   0,
                                   0,
                                   0.07283632261606221,
                                   0,
                                   -0.096869305277289236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078179639992323108,
                                   0,
                                   0,
                                   0,
                                   0.051533360110608439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43559579793669728,
                                   0,
                                   0,
                                   -0.25873131662655829,
                                   -0.17695219472172677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45743451266312546,
                                   0,
                                   0,
                                   0.15504961033853565,
                                   -0.074544653212525833,
                                   0.030950310414949389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2484428547957313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15992721804729984,
                                   0.17110992714805945,
                                   0,
                                   0,
                                   0.28267473244730856,
                                   0,
                                   0.51791914293636143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069431122650509589,
                                   0,
                                   0,
                                   0,
                                   -0.041992145200209115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064170727673685771,
                                   0,
                                   0,
                                   0.032147897979183784,
                                   -0.25578050962795834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59107639798681855,
                                   0,
                                   0,
                                   0.41482872529175358,
                                   -0.49178541925134855,
                                   -0.11747176835736946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046471768969021228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092382648260453032,
                                   -0.11446352278934593,
                                   0,
                                   0,
                                   0.14674161921497031,
                                   0,
                                   0.25862902953854588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19579778261731443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64131001498729268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14702840415139939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097470007618132293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2168373133762036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2778463045698501,
                                   -0.097613191000751748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25811340827186413,
                                   0.048651039443747678,
                                   0,
                                   0.10607470691950066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35232809533253201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11068136106669696,
                                   0,
                                   0,
                                   0,
                                   0.45522701711011521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40520220647701083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17322380687851074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23085095670223671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47221022156568421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31235832552638298,
                                   0.073467214984290763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12712018988964871,
                                   0.079598027401837232,
                                   0,
                                   0.33240810689586969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055889523811449113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14287520722826849,
                                   0,
                                   0,
                                   0,
                                   -0.5196512002735153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70917817160822261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30635506252321731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16513902077411369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25810446617954097,
                                   0,
                                   0,
                                   0,
                                   -0.49599279208115932,
                                   -0.25162518780974608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46074775860643541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21241312062387696,
                                   0.12344021474557731,
                                   0,
                                   0,
                                   0.60805157445556335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5466021566548187,
                                   0,
                                   0,
                                   -0.11064214584552713,
                                   0,
                                   0.049414983002020407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14659153692000088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021179397350416101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14910693176663861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091340800523437765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45577368876769137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15030650678325189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57474576033305813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13396842614022589,
                                   0,
                                   0,
                                   0,
                                   -0.058225744346490679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31923225738025751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00037779479413729833,
                                   0,
                                   -0.28969219953707831,
                                   0,
                                   0,
                                   0.65349754600791832,
                                   0,
                                   -0.7510764224335853,
                                   0,
                                   -0.21788935026490613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45132382120970116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2751765149931884,
                                   0,
                                   0,
                                   0,
                                   -0.81687742679906805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17735548257482628,
                                   0,
                                   0,
                                   0,
                                   -0.29295759007296374,
                                   0,
                                   0,
                                   -1.0421336948323918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64210933832677208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47110190950405623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19369229576464148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14658299180033399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31487573616719161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66979733350975323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51744400716748618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21495973471574931,
                                   -0.25912221028945032,
                                   0,
                                   0,
                                   0.33369903713517507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10647924044008247,
                                   0,
                                   0,
                                   -0.11845513546270539,
                                   0,
                                   0.012150463373996882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0077232445150034103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64706999177655666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2515319867555959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86250279908787864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02589340088791188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39933066648643045,
                                   0,
                                   0,
                                   -0.13320753661986393,
                                   0,
                                   -0.17236729163452474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99315295545784854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22296957272807857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0013919950427553271,
                                   -0.25429671997014214,
                                   0,
                                   0,
                                   0.49241191066097578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53535822630843555,
                                   0,
                                   0,
                                   0.35536373151261202,
                                   0,
                                   -0.27321577015426612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14715167178284413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15022125222397006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33374782710753587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44726104429905467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42147518318391486,
                                   0,
                                   0,
                                   0,
                                   -1.2277916325915834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24711365178610656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066601886278303726,
                                   0,
                                   0,
                                   -0.43643356636568931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026965953121406483,
                                   -0.65660714740078685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57109239966266179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49197968501368977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5782361064328313,
                                   0,
                                   0,
                                   -0.33060932380418906,
                                   0,
                                   -0.66521585541608252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66464681570050188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41597234087405127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041719010217972405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28479852261088801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19310742233816985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18284709673038602,
                                   0,
                                   0,
                                   0,
                                   0.4264454217270448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11465070049525744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14538726677843053,
                                   0,
                                   -0.22810249513230596,
                                   0,
                                   0,
                                   -0.28109222566954506,
                                   0,
                                   0.49111465415367356,
                                   0,
                                   -0.43064870430224383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62436088217375607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11080107633271363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34878630786286002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14512722253824753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70946181436794797,
                                   0,
                                   0,
                                   0.30194592266061171,
                                   0,
                                   -1.1965717335026775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5405981267327592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2567222341549848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18318596531311709,
                                   0,
                                   0,
                                   0,
                                   -0.11961576925730756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0097462984385681406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40683217828699136,
                                   0,
                                   0,
                                   0.94604833281193768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81930066957280756,
                                   0.37669714040960067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57951106327418822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48672828726111816,
                                   0,
                                   0,
                                   0,
                                   0.92180253594387995,
                                   0,
                                   0,
                                   0.63277553830185673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17295410794912455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24005910435091499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43344067673703635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5831649005504117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42950719511479168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086145603278686284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0057924082646893318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12723095729080819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09397799933352935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42884518476427297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42124826918354596,
                                   0,
                                   0,
                                   0,
                                   -0.28057377549085449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030642462219298006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35727359006305753,
                                   0,
                                   -0.61975215927380356,
                                   0,
                                   0,
                                   -0.2707001528559117,
                                   0,
                                   0.37104235504035932,
                                   0,
                                   -0.13579456851215449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023972072442666671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53052351809312803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16867195765509485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33495823057677454,
                                   0.41188872377975816,
                                   0,
                                   0,
                                   -0.17494189176558361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20691979237070229,
                                   0,
                                   0,
                                   -0.31063261951864757,
                                   0,
                                   -0.65164121477986581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14417371147180363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27228827837415914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014970136779135008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028175832482594657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047309552002570254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1397192255706054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23523807782380041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33600033028669851,
                                   0.48480960096791126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30019900616686873,
                                   0.12035049096952349,
                                   0,
                                   -0.19173545406459358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49817763666613113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40868520347937753,
                                   0,
                                   0,
                                   0,
                                   0.13267336136069791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11314175964689227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41304478138468137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50568640350065241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45774887829061839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068500675266602917,
                                   -0.090802320730171027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11168229251778772,
                                   0.46596425997947466,
                                   0,
                                   0.081176182232216829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20618693690668963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20987937619610303,
                                   0,
                                   0,
                                   0,
                                   -0.12512061567024574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12645143764825437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38156458705685092,
                                   0,
                                   0,
                                   0,
                                   0.022525372522870492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21218817154655079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81232680712399941,
                                   0,
                                   0,
                                   -0.13215404849810905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0439517874010391,
                                   0.18328247209432466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50215157099865637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39642080598295215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1535917402729273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035433088937242681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36490432904653153,
                                   0.14405861454892327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39835422846349522,
                                   -0.14095327980186775,
                                   0,
                                   -0.020523642285137578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30749233290802236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28212247859856809,
                                   0,
                                   0,
                                   0,
                                   0.2425295817646512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013288693701193229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2095516195352686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14289601900230267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18999907546170403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40445584383960242,
                                   0,
                                   0,
                                   0,
                                   0.65107393015000947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90781549625526903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48368928241152143,
                                   0,
                                   -0.4886337993397134,
                                   0,
                                   0,
                                   -0.29923912011242015,
                                   0,
                                   -0.039198909447144596,
                                   0,
                                   0.060219829945907077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16751474739033642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27224851054428406,
                                   0,
                                   0,
                                   0,
                                   0.55346176687907112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58520750716753434,
                                   0,
                                   0,
                                   0,
                                   0.37136063096736416,
                                   0,
                                   0,
                                   -0.69169595495281222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19967102128903075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6019354135298195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12788164787036008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81319907690450777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64943973785776454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24244286153895039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28406893722762272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14480952311358591,
                                   0,
                                   0,
                                   0.39356866112879135,
                                   0.1285613701002927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30684011812339418,
                                   0,
                                   0,
                                   -0.013536577477034961,
                                   -0.30040757775411597,
                                   -0.27175675015169365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27271145877110342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0084450198946056931,
                                   -0.48166841751261913,
                                   0,
                                   0,
                                   0.21280924471871876,
                                   0,
                                   -0.0045302784945351893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34164976565504912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25019868571480475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74926377360657614,
                                   -0.27948786475490711,
                                   0,
                                   0,
                                   -0.037066977948189195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08697012085353871,
                                   0,
                                   0,
                                   -0.35537398904426704,
                                   0,
                                   -0.18428122663644519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24376799392320955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25888193872836446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047542089412426873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16759665504306034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21793025408304198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54016078768889542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35893200571947315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10137997434877669,
                                   -0.096097394071258169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41121715948661242,
                                   0.10034561601379215,
                                   0,
                                   -0.079338004264116024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32015587081491753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040921355129734348,
                                   0,
                                   0,
                                   0,
                                   -0.44120476333329989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18634131363010875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64439636729015626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19006035106674751,
                                   0,
                                   0.055292566705155005,
                                   0.55073487375022756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38558289914577426,
                                   0.06459683678599816,
                                   0,
                                   -0.23386792656605565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53156418815706885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14064329142107798,
                                   0,
                                   0,
                                   0,
                                   0.52464369848671732,
                                   0,
                                   0,
                                   -0.15708867669983176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30409743634410741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14442754401429042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82490787732571202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20659791724610205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65598093329774765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055469800694961595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04254670902430633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015513518769712284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69439689287885009,
                                   0,
                                   0.48780057161863238,
                                   -0.40437305511405869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013148346041126011,
                                   -0.031703743666336194,
                                   0,
                                   -0.33632884459552098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17075610477760983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32029370776347788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27207199051782111,
                                   0,
                                   -0.45063481408439376,
                                   -0.40300334313908398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18399613177950991,
                                   0.51644544466268272,
                                   0,
                                   0.3580184651036355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49999444250801262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02920017549352312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13384184668800497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11150704894089547,
                                   0,
                                   0,
                                   0,
                                   0.3214763169504628,
                                   0.78451158242810648,
                                   0,
                                   -0.34069266697799366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18256691473033154,
                                   0,
                                   0,
                                   -0.44877499819158817,
                                   -0.090785104082468732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0010098485006262078,
                                   0,
                                   0,
                                   -0.43748201132655395,
                                   -0.24024310171763238,
                                   0.047663995533228518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40611889113147764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43857646461847799,
                                   -0.058108211403913965,
                                   0,
                                   0,
                                   0.00063390827355179306,
                                   0,
                                   0.0071329846643210723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1699030463915728,
                                   0,
                                   0,
                                   0,
                                   0.21033540244541191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4422073186215259,
                                   0,
                                   0,
                                   0.046550184357130611,
                                   -0.37751943239367186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1887844206713333,
                                   0,
                                   0,
                                   -0.18275892402719868,
                                   -0.064064660425669689,
                                   -0.43402005854028353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23818229457713833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079015933237116587,
                                   0.28966086084197357,
                                   0,
                                   0,
                                   -0.095356386388824335,
                                   0,
                                   -0.42505042827523887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13178522734142056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25560526419996155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1593165291141976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63867690272172717,
                                   0,
                                   0,
                                   -0.72930662411520897,
                                   0,
                                   -0.89186158371168511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24835479476896116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44315541317702045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36339940036180596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057288899129992195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058052003869131674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21549320974327629,
                                   0,
                                   0,
                                   0,
                                   -0.68959251227685503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24890571428161234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3816050150353425,
                                   0,
                                   0.05046833604992286,
                                   0,
                                   0,
                                   -0.51240043572563387,
                                   0,
                                   -0.14173345461427092,
                                   0,
                                   0.49813357786804247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24216650735010009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13014294756798717,
                                   0.011550533072074844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31399586011768732,
                                   0,
                                   0,
                                   0.28328048325221356,
                                   -0.30032640194363558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11200906931416213,
                                   0,
                                   0,
                                   -0.28185406022002091,
                                   0.15884206242124743,
                                   0.20001574061087951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45358405456363704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45734701043738901,
                                   -0.0085067356775292979,
                                   0,
                                   0,
                                   -0.24227282609295944,
                                   0,
                                   0.24561621250859017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19900746666587144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31673859080324951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17926509999284657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055304886890289041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13117150173319964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71031392041751407,
                                   0,
                                   0,
                                   0,
                                   0.25000840052954343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4139617331464881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28283149503173571,
                                   0,
                                   -0.10852612234434664,
                                   0,
                                   0,
                                   -0.428541527624483,
                                   0,
                                   -0.23472542110977582,
                                   0,
                                   -0.025646867583229427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54466654431559902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45222318699526171,
                                   -0.48372928982207725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076378049088263192,
                                   0,
                                   0,
                                   0.27461586079763989,
                                   0.16616826717378089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15484234838584587,
                                   0,
                                   0,
                                   0.17428451874626086,
                                   -0.43637257028151061,
                                   0.32782865524441074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15997297779475197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24365238525968075,
                                   0.28296391525912379,
                                   0,
                                   0,
                                   0.05983347944385347,
                                   0,
                                   -0.36842387739502003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023666339887286791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13629008172483664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057210296971012542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18255526489273166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16626508885442112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31089919261523885,
                                   0.5125779760953898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0889320124445864,
                                   -0.54288582209183789,
                                   0,
                                   0.17385819988698378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22018273445318642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41930174134971476,
                                   0,
                                   0,
                                   0,
                                   -0.02514005372593088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017789692157283182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4980059452440575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75694936022988923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60351960969132601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040846414861668956,
                                   0,
                                   0,
                                   0,
                                   -0.094863139554990733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20607209137220037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23501546781569763,
                                   0,
                                   -0.192891876999322,
                                   0,
                                   0,
                                   0.061404057211224577,
                                   0,
                                   0.045344793591000861,
                                   0,
                                   0.016943913046039066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5240994290502986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3804322836468601,
                                   0,
                                   -0.71145123869275251,
                                   0,
                                   0,
                                   0.0030230863290105631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4819074196200171,
                                   0,
                                   0,
                                   0,
                                   0.07757332980631193,
                                   0,
                                   0,
                                   0.98374641219141878,
                                   0.4172780882401812,
                                   0,
                                   0,
                                   -0.030663592563024422,
                                   0,
                                   0,
                                   -0.63603785267839441,
                                   0,
                                   0,
                                   0,
                                   -0.45990812555399507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22868765008898403,
                                   0,
                                   0,
                                   0,
                                   0.27434537527160818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25785583947553292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77566825060719602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12724682269176255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036684748057645641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23991300715834496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19664870574629792,
                                   0,
                                   0,
                                   0,
                                   -0.23677155785040088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2404525746987784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029502938754808004,
                                   0,
                                   -0.33333623860024497,
                                   0,
                                   0,
                                   0.68282139040801315,
                                   0,
                                   0.42671456928954554,
                                   0,
                                   0.33083112515965096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3448459703745243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33927115935442692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15575765440387473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088753326552514014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.429826775112991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069500193178634845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023438824582493259,
                                   -0.38790758672530024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16425326585083988,
                                   -0.3705831392241411,
                                   0,
                                   -0.65796633431313434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061487795788499389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052453094820256646,
                                   0,
                                   0,
                                   0,
                                   -0.15328607448560416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13070253270037674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010935529171594153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29306468638674299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40008331077181869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11994317306026429,
                                   0,
                                   0,
                                   0,
                                   0.29935157994890094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36281616598469685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45116011593018923,
                                   0,
                                   -0.021965098142568515,
                                   0,
                                   0,
                                   0.18711950484550649,
                                   0,
                                   0.5937457640787126,
                                   0,
                                   0.57143638222960536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21047761221261721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41269935416550729,
                                   0,
                                   -0.49534367818296665,
                                   0,
                                   0,
                                   -0.42266204360155019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25748615003474817,
                                   0,
                                   0,
                                   0,
                                   -0.15188785379921932,
                                   0,
                                   0,
                                   -0.23633882722276367,
                                   -0.24099427252763944,
                                   0,
                                   0,
                                   0.054283956211024081,
                                   0,
                                   0,
                                   0.76697450048970928,
                                   0,
                                   0,
                                   0,
                                   -0.30959271564634516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027849593676671947,
                                   0,
                                   0,
                                   0,
                                   -0.19586592387847546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10459160098542061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1048179218433627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24603066571559545,
                                   0,
                                   0,
                                   0,
                                   0.81910489405261488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18956332651510871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30524047528031967,
                                   0,
                                   0,
                                   -0.6697394181443157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12610600633779642,
                                   0.021413760921769581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088046271335019161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14665575480771154,
                                   -0.28550008070184996,
                                   0,
                                   0,
                                   -0.053024843335629124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26339731509970898,
                                   0,
                                   0,
                                   -0.43025082950673271,
                                   0,
                                   -0.27563040236993558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28139597665143123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50339910172290214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4726072594656503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23474279408816856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30286449500620155,
                                   0,
                                   0,
                                   0,
                                   -0.54163179097191327,
                                   0,
                                   0,
                                   -0.051897812444407519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3552098804476147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48255055232648647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60689501167733118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50481049541101353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26633564588071335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096948971137809647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53193174723691883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069670247292341447,
                                   0,
                                   0,
                                   0,
                                   -0.0053497894843641518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37023600315155547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039429464158516329,
                                   0,
                                   0,
                                   0.26647288723949741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32069898640228361,
                                   -1.0422236836068899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1941380396072579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06489369267929726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30249764828354581,
                                   0,
                                   -0.21663579246515957,
                                   -0.20729666429942459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042980794664329441,
                                   0.45196243559719063,
                                   0,
                                   -0.75536351348421737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20818576365912406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43638939132979382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50391845611094299,
                                   0,
                                   -0.53441628309965061,
                                   0.42589148863640502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065024307113122848,
                                   -0.036234296927736824,
                                   0,
                                   -0.19940854548106482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50352386275701611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45507862499471186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079457605305848791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83420464795835458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62158780879452047,
                                   0,
                                   0,
                                   0,
                                   0.12192455906060587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055302953604424991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54315536163626676,
                                   0,
                                   0.48704883716434605,
                                   0,
                                   0,
                                   0.23061743134014828,
                                   0,
                                   0.25294054771191204,
                                   0,
                                   0.082988635397576949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38848244505630924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31041124619213878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77323031253717733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11838612602504484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24222682625403305,
                                   0,
                                   -0.18488955312418928,
                                   -0.031872842414765512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51818479170980836,
                                   -0.052085453185862336,
                                   0,
                                   0.15164885706910153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1589917126450299,
                                   0,
                                   0,
                                   -0.62174424698610065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33873134609968303,
                                   0,
                                   0,
                                   0,
                                   -0.10720741299891688,
                                   0,
                                   0,
                                   -0.42010264623488569,
                                   -0.32649516339333906,
                                   0,
                                   0,
                                   -0.088688702209225354,
                                   0,
                                   0,
                                   -0.70715056008736055,
                                   0,
                                   0,
                                   0,
                                   -0.65914869607311455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14218409484991124,
                                   0,
                                   0,
                                   0,
                                   -0.058987973833718801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22863311821890303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24052442829939108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16592762880987599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94850094030475707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10328100665898604,
                                   0,
                                   0,
                                   0,
                                   0.044869390532980141,
                                   -0.047767761999913061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27726382745986383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070647623602044463,
                                   0,
                                   0,
                                   0,
                                   0.056916413741087205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0537105077647282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31618685385409179,
                                   0,
                                   0,
                                   0.7092671636485528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056146181948641252,
                                   -0.40312507187912971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42079293039681065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82968406362331992,
                                   0,
                                   0,
                                   0,
                                   0.011466914744639751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51641078670249463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54895777426783388,
                                   0,
                                   0,
                                   -0.50104269096939913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33353667831353856,
                                   0.15916790863855704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047985062712034038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22938228278066436,
                                   0,
                                   0,
                                   0.20457326104544063,
                                   0.028010344548493649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056703204304878033,
                                   0,
                                   0,
                                   0.072536428575268583,
                                   -0.14256145406392379,
                                   0.20141721994518341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067170652784692905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19544712745219528,
                                   0.11429109507963447,
                                   0,
                                   0,
                                   -0.61756749522638632,
                                   0,
                                   0.36998393216586373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50894528210973144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046055120331165433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76744783636232139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17995125772522397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17594015995120482,
                                   0,
                                   0,
                                   0,
                                   0.52378518664716778,
                                   -0.26686031470137839,
                                   0,
                                   0,
                                   0,
                                   -0.26392358402011939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23148922879490025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0025649694420346869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89769137672262256,
                                   0,
                                   0,
                                   0,
                                   0.10855831379061288,
                                   0.24313737751827158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8168900389068573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78349551913842586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49259182749840885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41186492210488668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45552154893229901,
                                   0,
                                   0,
                                   0,
                                   0.1810460382550263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10040925066349059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18076309880378702,
                                   0,
                                   -0.13527747808252136,
                                   0,
                                   0,
                                   -0.22671709991018202,
                                   0,
                                   -0.12113630415331267,
                                   0,
                                   -0.016781131203552999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0041054447696867932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47704862630846051};

const double rot_30_30[9000] = {-0.44928075995141503,
                                0,
                                0,
                                0,
                                0,
                                0.85641622538384798,
                                0,
                                0,
                                0,
                                -0.096501246802599833,
                                0,
                                0,
                                0,
                                0,
                                0.3498458986818731,
                                -0.38796072214777089,
                                0,
                                0,
                                0,
                                -1.3081824325730698,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10462503150948251,
                                -0.12854508814892887,
                                0,
                                0,
                                0,
                                0.90016532865725085,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.9806069232624246,
                                0,
                                -0.45513720145177528,
                                0,
                                0,
                                0.77352097957923649,
                                0,
                                0,
                                0.22648545711444082,
                                0,
                                0,
                                0,
                                0,
                                -0.8842893251431948,
                                0,
                                0.73015910521036043,
                                1.3731766848445639,
                                0,
                                0,
                                0,
                                0.38341675100855294,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8355901411650446,
                                0,
                                -0.15936558916332971,
                                0,
                                0,
                                -0.088026075904356238,
                                0,
                                0,
                                0.055130215897898738,
                                0,
                                0,
                                0,
                                0,
                                -0.18660714445670373,
                                0,
                                0,
                                0,
                                0.25172497357318208,
                                0,
                                0,
                                0,
                                0,
                                0.18549952619093871,
                                0,
                                -0.57888003813534161,
                                0,
                                0,
                                -0.36572299889393234,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11875265549129223,
                                0,
                                0,
                                0,
                                0,
                                0.076077116066791364,
                                0.26135820505025609,
                                -0.58751257081751562,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21937214057214,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18962923072099422,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1585319025387486,
                                0,
                                0,
                                0,
                                0,
                                -0.86635387714443779,
                                0,
                                0,
                                0,
                                0.37990322575305263,
                                0,
                                0,
                                0,
                                0,
                                0.27741570842951868,
                                0.31116596962029364,
                                0,
                                0,
                                0,
                                -0.0045108283076897016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2515078719203736,
                                0.36185759878830043,
                                0,
                                0,
                                0,
                                0.74745115984507926,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.063739713652336466,
                                0,
                                0.42975875001134989,
                                0,
                                0,
                                0.15597265156216666,
                                0,
                                0,
                                0.78888641926240211,
                                0,
                                0,
                                0,
                                0,
                                0.67484125451464383,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18561751014953248,
                                0,
                                0,
                                0,
                                0,
                                -0.59967467938943031,
                                0,
                                0,
                                0,
                                0,
                                0.031695527334182585,
                                0,
                                0,
                                0,
                                0,
                                0.11698100683932183,
                                -0.61082028689548984,
                                0,
                                0,
                                0,
                                0,
                                -0.46706084563775041,
                                0,
                                0,
                                0,
                                0,
                                0.23992192294150386,
                                0,
                                0,
                                0,
                                0,
                                0.070739799636835771,
                                0,
                                -0.36735745539113251,
                                0,
                                0,
                                0.78800832107290009,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.057064951105300112,
                                0,
                                0,
                                0,
                                0,
                                0.40015373581683922,
                                -0.13470455241029572,
                                -1.2447170262067098e-05,
                                0,
                                0,
                                0.34791357822742092,
                                0,
                                0,
                                0,
                                0,
                                0.20040676069764046,
                                0,
                                0,
                                0,
                                0.050551771767277084,
                                0,
                                0,
                                0,
                                0,
                                1.0024610428994445,
                                0.23481110454236709,
                                0,
                                0,
                                0,
                                1.1001688459087211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34769492981196565,
                                0,
                                0,
                                0,
                                0,
                                -0.23251446877609855,
                                0,
                                -0.23934646139417498,
                                0,
                                0,
                                -0.21590317779410906,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.066097495802012005,
                                0,
                                0,
                                0,
                                0,
                                0.18328161116615391,
                                0.4592861384973585,
                                0.68719688726779149,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11240958195570519,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13296691298032651,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11365448166031233,
                                0,
                                0,
                                0,
                                0,
                                0.1225813009771201,
                                0,
                                0,
                                0,
                                0,
                                0.68034182857749681,
                                0,
                                0,
                                0,
                                0,
                                -0.67142610585265905,
                                -0.071750369575870512,
                                0,
                                0,
                                0,
                                0,
                                -0.23071703140940808,
                                0,
                                0,
                                0,
                                0,
                                0.84179283440987174,
                                0,
                                0,
                                0,
                                0,
                                0.18244447421320387,
                                0,
                                0.27533276656369676,
                                0,
                                0,
                                0.0040932990261590002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.078377647507626227,
                                0,
                                0,
                                0,
                                0,
                                -0.35580812757232017,
                                -0.22196514853348923,
                                -0.016215544575635829,
                                0,
                                0,
                                -0.25689543095708128,
                                0,
                                0,
                                0,
                                0,
                                -0.4071630450194057,
                                0,
                                0,
                                0,
                                -1.290124840983508,
                                0,
                                0,
                                0,
                                0,
                                -0.41673635341406845,
                                -0.25710438197788843,
                                0,
                                0,
                                0,
                                0.12869993427410864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64783153076086097,
                                0,
                                0,
                                0,
                                0,
                                0.69478862705717814,
                                0,
                                0,
                                0,
                                -0.40683681576797054,
                                0,
                                0,
                                0,
                                0,
                                -0.42914656786965633,
                                1.3319421596537755,
                                0,
                                0,
                                0,
                                0.368633227502009,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00081193411908733748,
                                0.029793951458128548,
                                0,
                                0,
                                0,
                                -0.84577890919750598,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.058438136396302992,
                                0,
                                -0.92995234400286264,
                                0,
                                0,
                                0.53284788824836038,
                                0,
                                0,
                                0.59785507883313493,
                                0,
                                0,
                                0,
                                0,
                                0.37365729316855278,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23607236863537656,
                                0,
                                0,
                                0,
                                0,
                                0.57349675083398299,
                                0,
                                0,
                                0,
                                0,
                                0.4215785422893461,
                                0,
                                0,
                                0,
                                0,
                                0.51855308544990364,
                                -0.40781569264676659,
                                0,
                                0,
                                0,
                                0,
                                0.04931434509712973,
                                0,
                                0,
                                -0.13394059450256196,
                                0.64026414108781815,
                                0,
                                0,
                                0,
                                0.077651746077448069,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.99288713806821405,
                                0,
                                -0.6920326391742081,
                                0,
                                0,
                                -0.77082510924804148,
                                0,
                                0,
                                -0.69318344662976283,
                                0,
                                0,
                                0,
                                0,
                                0.66910058740461653,
                                0.59284997492631963,
                                0,
                                0,
                                0,
                                0,
                                -0.5565664750429129,
                                0,
                                0,
                                0,
                                -0.40940086605163983,
                                0,
                                0,
                                0,
                                0,
                                0.41647228328324598,
                                0.97820305151285403,
                                0,
                                0,
                                0,
                                -0.7249657834350588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17811730638491735,
                                0,
                                0,
                                0,
                                0,
                                0.56520879571409333,
                                0,
                                -0.46453320293530342,
                                0,
                                0,
                                -0.14828174469797933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21593386098934941,
                                0,
                                0,
                                0,
                                0,
                                -0.22542639306558493,
                                -0.38218133896914874,
                                0.40930135976444748,
                                0,
                                0,
                                0,
                                -0.80362463861439926,
                                0.081166736274321985,
                                0,
                                0,
                                0,
                                -0.73601488054727082,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3477072396056739,
                                0,
                                -0.37573906078380898,
                                0,
                                0,
                                -0.2122058394734348,
                                0,
                                0,
                                0.26923554210346345,
                                0,
                                0,
                                0,
                                0,
                                -0.59749176258236347,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16308810227079529,
                                0,
                                0,
                                0,
                                0,
                                -0.53007208443432585,
                                0,
                                0,
                                0,
                                0,
                                0.57536496044893026,
                                0,
                                0,
                                0,
                                0,
                                0.28599834051914536,
                                0.35482980154963123,
                                0,
                                0,
                                0,
                                0,
                                0.39202267745795638,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29571172082470232,
                                0,
                                0,
                                0,
                                0,
                                0.11489342686507342,
                                0,
                                0,
                                0,
                                0,
                                0.054727443728972508,
                                0,
                                0,
                                0,
                                0,
                                0.21340841989226009,
                                0.5733023551795291,
                                0,
                                0,
                                0,
                                0,
                                -0.72259272166115773,
                                0,
                                0,
                                -0.63519494243811714,
                                0.76911747417489384,
                                0,
                                0,
                                0,
                                -0.40105494514793139,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.062920381388674215,
                                0,
                                0.46454511609340565,
                                0,
                                0,
                                0.83642845847582759,
                                0,
                                0,
                                -0.90873148197381992,
                                0,
                                0,
                                0,
                                0,
                                -0.31807309349500645,
                                0,
                                0,
                                0,
                                -0.06044534920050304,
                                0,
                                0,
                                0,
                                0,
                                0.17756836897717226,
                                0,
                                0.022641004652012076,
                                0,
                                0,
                                0.29153850691216865,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67375437010844208,
                                0,
                                0,
                                0,
                                0,
                                -0.25148723422421276,
                                0.59683249610794609,
                                -0.076868129716892636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.07917001765918337,
                                0,
                                0,
                                0,
                                0,
                                0.65613712634699484,
                                0,
                                0.29456093597750954,
                                0,
                                0,
                                0.11828133597351487,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55835601287098546,
                                0,
                                0,
                                0,
                                0,
                                0.016187613087961347,
                                0.37680133235219759,
                                0.091961080356091879,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.088981804437397533,
                                0,
                                0,
                                0,
                                0,
                                -0.302868626939854,
                                0,
                                -0.30623795285123689,
                                0,
                                0,
                                0.27872205771781633,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3997444720290857,
                                0,
                                0,
                                0,
                                0,
                                -0.74804596182241101,
                                0.095307081082448966,
                                0.020816350510515585,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.88479120958331237,
                                0,
                                0,
                                0,
                                0,
                                -0.047840005220046923,
                                0,
                                0,
                                0,
                                0,
                                0.15608328451989872,
                                0,
                                0,
                                0,
                                0,
                                0.373184835608523,
                                0.029275311980057547,
                                0,
                                0,
                                0,
                                0,
                                -0.2244323778300199,
                                0,
                                0,
                                -0.56673841191145646,
                                -0.51693977789942103,
                                0,
                                0,
                                0,
                                0.65302094759815088,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.91351293180477611,
                                0,
                                -0.88441708008635078,
                                0,
                                0,
                                0.14504990648859625,
                                0,
                                0,
                                -0.91568720155084482,
                                0,
                                0,
                                0,
                                0,
                                0.00058997946467656548,
                                -0.18865328845895415,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59843977910106749,
                                -1.3921276342965061,
                                0,
                                -0.60017776805861878,
                                0,
                                0,
                                0,
                                0.45361173969136648,
                                0,
                                0,
                                -0.48063960483989532,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35943959369123002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31888382965686879,
                                0,
                                0,
                                0.28466225043392313,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.032992831090029207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.024202951447553744,
                                -0.31496178451923512,
                                -0.60218199683729101,
                                0.54992690697207813,
                                0,
                                0,
                                -0.38728213629995178,
                                -0.055334928249407112,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2883658336993626,
                                0,
                                0.91595655092313577,
                                0,
                                0.57463928948981724,
                                0,
                                0,
                                0.23208988156704577,
                                0,
                                -0.036599386112914821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37418046620417633,
                                0.48438763075004643,
                                0,
                                0,
                                0.28677999322505282,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79123343967143422,
                                0,
                                -0.28947064922077265,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.075762878514662138,
                                0,
                                0,
                                0.41164789298137683,
                                0.29470156502285738,
                                0,
                                0.16767043031393469,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.092867272305537638,
                                0,
                                -0.16015111979495211,
                                0,
                                0.29414103671527442,
                                0,
                                0,
                                0.0087553963621320799,
                                0,
                                1.1639756590935908,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73237497783525107,
                                -0.11153410020883923,
                                0,
                                0,
                                -0.17560347832072343,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40353227540855491,
                                0,
                                0.17185815923407294,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18448483230377732,
                                0,
                                0,
                                -0.69112981310247223,
                                -0.26648547647417153,
                                0,
                                0.47425404028578244,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2190469988022424,
                                0,
                                -0.071510070325748742,
                                0,
                                -0.93310907935703646,
                                0,
                                0,
                                -0.45424031723380359,
                                0,
                                -0.059469145698496317,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38291700545719104,
                                1.1535678611997251,
                                0,
                                0,
                                0.068883181196568138,
                                0,
                                -0.81801438415395267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79882920905694654,
                                -0.028233062113613469,
                                0,
                                0.053142181710699829,
                                0,
                                0,
                                0,
                                0.60974926692763931,
                                0,
                                0,
                                -0.26867881479852701,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29903187378403195,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1369496086530986,
                                -0.96442043592513305,
                                0,
                                -0.10201157565153324,
                                0,
                                0,
                                0,
                                -0.24043586626035757,
                                0,
                                0,
                                0.36113438388816055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44253715788713011,
                                0,
                                0.83063494445581088,
                                0,
                                -0.10185500418460763,
                                0,
                                0,
                                0.67378141355620746,
                                0,
                                0.4800192055735254,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21837300735813198,
                                -0.45086927000205979,
                                0,
                                0,
                                0.78010280227173023,
                                0,
                                -1.1878549973913288,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28196505346782308,
                                -0.43666296241654379,
                                0,
                                0.22668543710542258,
                                0,
                                0,
                                0,
                                -0.83049557129745877,
                                0,
                                0,
                                0.63331423560461642,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.88287004665305413,
                                0,
                                -0.65696668959096882,
                                0,
                                -0.62882182638489581,
                                0,
                                0,
                                0.41930294519424888,
                                0,
                                -0.22218723179364397,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.062669238280836911,
                                0.020163523543529214,
                                0,
                                0,
                                0.62957030354846277,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.030411985199050806,
                                0,
                                -0.16573010008381892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32227384356516892,
                                0,
                                0,
                                -0.5422886778340773,
                                0.72346300085300885,
                                0,
                                -0.22421527852918818,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45738982791624588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42859901783896703,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21180839683232378,
                                0.43212305261934902,
                                -0.52089409355818939,
                                -0.25375473562947637,
                                0,
                                0,
                                -0.19454536766099964,
                                0.043980393539959889,
                                0,
                                0,
                                -0.0040047725959589386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15124706352833173,
                                0.57556982840578119,
                                0,
                                -0.78587865463471873,
                                0,
                                0,
                                0,
                                -0.11289238282188344,
                                0,
                                0,
                                0.95037979786063809,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.071111839715555444,
                                0,
                                -0.12888695257583882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80098056582516874,
                                0,
                                0,
                                -0.16774434183667544,
                                0.026578419937462711,
                                0,
                                -0.55490252860640388,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20204704235843984,
                                0,
                                -0.91749156694448386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.029372763364973607,
                                0,
                                0,
                                -0.1343447632531472,
                                -0.26189071510993828,
                                0,
                                0.1728820290195886,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58513790904326479,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0072784714550244156,
                                0.58076589841376869,
                                0,
                                -0.56686970960140948,
                                0,
                                0,
                                0,
                                -0.66295547667050925,
                                0,
                                0,
                                -0.77275380717931808,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4053474518632546,
                                0,
                                0.028327165619896774,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4625281359933136,
                                0,
                                0,
                                0.11234724698959275,
                                0.49944429692509767,
                                0,
                                0.59907614602262316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21299607753242844,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12085937231162247,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15387200815269481,
                                -0.47875845246995236,
                                -0.25496923622118939,
                                -0.64401039089235768,
                                0,
                                0,
                                -0.037632411672793339,
                                0.45383316204417973,
                                0,
                                0,
                                0,
                                0,
                                0.1531890371352318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15621413628894576,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24247409152672789,
                                0.24098476225140048,
                                -0.4794481511432378,
                                0.10133306914629484,
                                0,
                                0,
                                0.75467890033321217,
                                0.15994923782431422,
                                0,
                                0,
                                0,
                                0,
                                0.44019409065093523,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30101369857771781,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43236896434195432,
                                0.2888571347524963,
                                -0.12593619220553198,
                                -0.27654817490779454,
                                0,
                                0,
                                -0.022036883810882049,
                                -0.59364476616984296,
                                0,
                                0,
                                0,
                                0,
                                -0.53344085162632926,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35104586097332929,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33068838395882799,
                                -0.37197484999306218,
                                -0.23056422671072591,
                                -0.18121059655882105,
                                0,
                                0,
                                0.033523201387100396,
                                -0.50731313507719145,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.010814000555757396,
                                0,
                                -0.3049862217016403,
                                0,
                                -0.19063320518259125,
                                0,
                                0,
                                -0.24296126961645062,
                                0,
                                -0.47769616871987536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.94901969974328548,
                                -0.69871201334429367,
                                0,
                                0,
                                0.44229884098391881,
                                0,
                                0,
                                0,
                                0,
                                0.15682666116470029,
                                0,
                                0.36153009990851737,
                                0,
                                -0.7125072369226092,
                                0,
                                0,
                                0.84096102151557495,
                                0,
                                -0.4572364736367055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73128289413591607,
                                -0.53910802642857736,
                                0,
                                0,
                                -0.64476848583083035,
                                0,
                                0,
                                0,
                                -0.008045481239755823,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59058690616380005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35914562315318882,
                                -0.44908619051774823,
                                0.04362980746216534,
                                0.043447212197864134,
                                0,
                                0,
                                0.47011721414365459,
                                -0.30931695067440723,
                                0,
                                0,
                                0,
                                0,
                                -0.40315385271359527,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46213544960542169,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66842937770295952,
                                -0.057474258586607985,
                                0.015588382925447874,
                                0.31139576595708646,
                                0,
                                0,
                                0.13633994827125634,
                                0.24082726517339226,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4086513718297009,
                                0,
                                0.12411690060456956,
                                0,
                                -0.26308909583527074,
                                0,
                                0,
                                -1.1266519422753176,
                                0,
                                0.14431587560016543,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55699786908895121,
                                -0.90516256472883772,
                                0,
                                0,
                                -0.37270382540843133,
                                0,
                                0,
                                -0.57790598615318489,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.069497032566993078,
                                -0.48749521502220633,
                                0,
                                0,
                                0,
                                -0.062397530012721796,
                                -0.27981620387813061,
                                0,
                                0,
                                0,
                                -0.247866911250023,
                                0,
                                0,
                                0,
                                0,
                                0.252124463208657,
                                -0.12802853997295227,
                                -0.270735471976294,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68224929618965791,
                                0,
                                -0.27548021687216362,
                                0,
                                -0.083919949814771813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87213992071456159,
                                0,
                                -0.36066365130756961,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15326125191170048,
                                0.053598228693718622,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.068029528493965929,
                                0,
                                0,
                                0,
                                0,
                                0.82578991965168358,
                                0,
                                0,
                                0,
                                -0.083573183528714637,
                                0,
                                -1.0511194552825338,
                                0,
                                0,
                                0,
                                0,
                                0.30583542240194767,
                                0,
                                -0.45767732078638579,
                                0,
                                0.86206692090005266,
                                0,
                                0,
                                0,
                                -0.62509286573689815,
                                0,
                                0,
                                0,
                                0,
                                0.54580374413816513,
                                0,
                                0.30191578113917872,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20335021864255187,
                                0,
                                -0.30064752292508162,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59395430213266476,
                                -0.3555603696969275,
                                0,
                                0,
                                0,
                                0,
                                0.095570811152862048,
                                0,
                                0,
                                0,
                                0.24302010392111117,
                                -0.3242809273310488,
                                0,
                                0,
                                0,
                                -0.21576064331508571,
                                0,
                                0,
                                0,
                                0,
                                -0.033251486591281576,
                                -0.0024926092306408187,
                                0.85232813468618152,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22917580690901726,
                                -0.57363107568952854,
                                0,
                                0,
                                0,
                                0.50250110784792279,
                                -0.22113627375331363,
                                0,
                                0,
                                0,
                                0.10239584018647122,
                                0,
                                0,
                                0,
                                0,
                                0.26432406632904215,
                                0.2704993854531717,
                                -0.001096092222164044,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46477471420944233,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22211747893207362,
                                0,
                                -0.12934708086306851,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49901062508684291,
                                0,
                                0,
                                0,
                                0,
                                0.59840538013016797,
                                0,
                                0,
                                0,
                                -0.37515225272790043,
                                0,
                                -0.42293228491901225,
                                0,
                                0,
                                0,
                                0,
                                -0.80236102243109542,
                                0,
                                -0.63173786457744829,
                                0,
                                -0.54668413993061271,
                                0,
                                0,
                                0,
                                0.32410947371730059,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26233259817653043,
                                0,
                                -0.16166393752542246,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35421483783891078,
                                0,
                                0,
                                0,
                                -0.19100032720196977,
                                -0.14596615247135075,
                                0,
                                0,
                                0,
                                0.33604241593577233,
                                0,
                                0,
                                0,
                                0,
                                -0.74480165962140676,
                                0.34987002165865561,
                                0.054247311299793793,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15407396170271023,
                                0,
                                0.75983523804080921,
                                0,
                                -0.43430157328729135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13115359758648706,
                                0,
                                0.043064163828459456,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4582260852070269,
                                0.070750413012011709,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.81321289790454221,
                                0,
                                0,
                                0,
                                0,
                                -0.10624821925306101,
                                0,
                                0,
                                0,
                                -0.24706203731108251,
                                0,
                                1.0929814948447369,
                                0,
                                0,
                                0,
                                0,
                                0.1730289607970884,
                                0,
                                -0.45149976654624124,
                                0,
                                0.54561705605915123,
                                0,
                                0,
                                0,
                                -0.12026286326968483,
                                0,
                                0,
                                0,
                                0,
                                0.16315768367006289,
                                0,
                                0.8135098941079929,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.02869234681587262,
                                0,
                                -0.14211218662095709,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48607818502614081,
                                0.23300235221456822,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.84690523027680509,
                                0,
                                0,
                                0,
                                0,
                                0.77320159260359889,
                                0,
                                0,
                                0,
                                0.41918939812105083,
                                0,
                                -0.2977149891044199,
                                0,
                                0,
                                0,
                                0,
                                0.055193262850525004,
                                0,
                                1.1436231981737659,
                                0,
                                0.18489359472311817,
                                0,
                                0,
                                0,
                                0.71855570953663372,
                                0,
                                0,
                                0,
                                -0.24776830312014192,
                                0,
                                0,
                                0,
                                0.5213766397649906,
                                0.63753719400742748,
                                0,
                                0,
                                0,
                                -0.11187450967493867,
                                0,
                                0,
                                0,
                                0,
                                -0.31832383031276484,
                                -0.34617875972070439,
                                0.037204614055921237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15891415885519528,
                                -0.043574241824882766,
                                0,
                                0,
                                0,
                                -0.040482560775331911,
                                0.31784635555373514,
                                0,
                                0,
                                0,
                                0.73063470300369759,
                                0,
                                0,
                                0,
                                0,
                                0.42976510940793078,
                                0.098872572806135345,
                                0.25302699240569831,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32111147433060899,
                                0.060215142895415991,
                                0,
                                0,
                                0,
                                -0.0046391279884995529,
                                0.39858379339148942,
                                0,
                                0,
                                0,
                                -0.4160685744958178,
                                0,
                                0,
                                0,
                                0,
                                0.11216440660851587,
                                0.79064019358858917,
                                0.003675028873560221,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16329188698584049,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.071345064969585481,
                                0,
                                0.76216914078404319,
                                0,
                                -0.8212710507646882,
                                0,
                                0.61686510882725476,
                                0,
                                0,
                                0,
                                0.3354900874306172,
                                -0.53886648536854465,
                                0,
                                0,
                                0,
                                0.28578631128364573,
                                0,
                                0,
                                0,
                                0,
                                0.73681430334156994,
                                0,
                                0,
                                0,
                                -0.029418869770558437,
                                0,
                                0.41226563377674419,
                                0,
                                0,
                                0,
                                0,
                                1.1454807743088089,
                                0,
                                -0.72892311400712773,
                                0,
                                -0.53938736473586446,
                                0,
                                0,
                                0,
                                0.18139067422867367,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10548887896307663,
                                0,
                                0.28575368236167942,
                                0,
                                0.29393834414097186,
                                0,
                                -0.50857182114653132,
                                0,
                                0,
                                0,
                                0.72173362284347808,
                                0.75807645281050617,
                                0,
                                0,
                                0,
                                -0.10132955310596364,
                                0,
                                0,
                                0,
                                0,
                                0.79026525794760683,
                                0,
                                0,
                                0,
                                0.1670859836973288,
                                0,
                                0.82187837641266126,
                                0,
                                0,
                                0,
                                0,
                                -0.16019026769267136,
                                0,
                                0.75577800305863851,
                                0,
                                -0.50338423436403901,
                                0,
                                0,
                                0,
                                -0.74312637020142125,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56805434614130434,
                                0,
                                0.24117333597054119,
                                0,
                                0.63883932776300556,
                                0,
                                0.49700335969641063,
                                0,
                                0,
                                0,
                                0.059938049585390341,
                                -0.28879168504218627,
                                0,
                                0,
                                0,
                                0.68767586365344469,
                                0,
                                0,
                                0,
                                0,
                                -0.12546849620358699,
                                0,
                                0,
                                0,
                                -0.6057500561711302,
                                0,
                                -0.094896958402486381,
                                0,
                                0,
                                0,
                                0,
                                0.14064701151345352,
                                0,
                                0.19563911899526032,
                                0,
                                -0.55466831264924032,
                                0,
                                0,
                                0,
                                -0.73589686277157673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2139048017040879,
                                0,
                                0.42476802347024567,
                                0,
                                0.0096383138038243638,
                                0,
                                -0.78219353762709898,
                                0,
                                0,
                                0,
                                -0.14958675969163676,
                                -0.52570992179087073,
                                0,
                                0,
                                -0.0020393471588720236,
                                0,
                                -0.21866096195334123,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35963860441282092,
                                0,
                                -0.79267464663800857,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.092995965477358208,
                                0.43111710007728182,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14911319643438081,
                                0,
                                -0.059795338183094626,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22506933279401398,
                                0,
                                -0.35937349146727393,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41089886702572737,
                                -0.79091490207477055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34074876240841434,
                                0,
                                0,
                                0,
                                0,
                                0.10834103321106747,
                                0,
                                0,
                                0,
                                -0.95618544188564414,
                                0,
                                0.14483413128559075,
                                0,
                                0,
                                0,
                                0,
                                0.11117786567511559,
                                0,
                                -0.1287713951756615,
                                0,
                                0.097137376974691769,
                                0,
                                0,
                                0,
                                0.43740584380393327,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36571853025818413,
                                0,
                                0.3455520852872056,
                                0,
                                -0.23092329488552013,
                                0,
                                -0.062730247860840915,
                                0,
                                0,
                                0,
                                -0.61869096486972885,
                                0.71585411026117429,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.95888879042811004,
                                0,
                                -0.94637248653987982,
                                0,
                                -0.17289047478455918,
                                0,
                                -0.59560623638031707,
                                0,
                                0,
                                0,
                                0.30112712388079338,
                                0.62920254776772799,
                                0,
                                0.4814355232307872,
                                0,
                                0,
                                0,
                                0.61201742559405914,
                                -0.28282217583448427,
                                0,
                                0,
                                0,
                                0.22168421657145315,
                                0,
                                0,
                                0,
                                0,
                                -0.11009952387024133,
                                0.18247217654419079,
                                -0.36314561102206178,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2953464026296117,
                                0.37664942844171656,
                                -0.14488678601765304,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0044744251423495807,
                                0.85451692314597461,
                                0,
                                0,
                                -0.22528214185404566,
                                0.12056946941084189,
                                0,
                                0,
                                0.18843591057553333,
                                0,
                                0,
                                0,
                                0.078273252660130452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4030234028686473,
                                0.38848429060873207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32425578360026841,
                                0.45220695812040795,
                                0,
                                0,
                                0.48284061785784887,
                                -0.10669749480799774,
                                0,
                                0,
                                -0.34336159246045289,
                                0,
                                0,
                                0,
                                0.12084099342127122,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22825269581056815,
                                0,
                                0,
                                -1.1011933199699435,
                                0,
                                0,
                                0,
                                0,
                                0.6635359678430276,
                                -0.7197707413536597,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.97791451749615865,
                                0,
                                0.39309523862729423,
                                0,
                                0,
                                0,
                                0,
                                0.36949459585761885,
                                0,
                                0,
                                -0.089843584172534949,
                                0,
                                0,
                                0.51665194866878683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.081065805897185428,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26519772964423999,
                                0,
                                -0.71524201306800583,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.95946625416668829,
                                0,
                                0,
                                -0.38888959515954119,
                                -0.2769650147053519,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18053053725020163,
                                0,
                                0,
                                0,
                                0,
                                0.33875541949971233,
                                0,
                                0,
                                -1.0168089301469132,
                                0.49181500379704696,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.062629858210059355,
                                0,
                                0,
                                -0.25682925484658281,
                                0,
                                0,
                                -1.3046032296657599,
                                0,
                                0,
                                0,
                                0,
                                -1.1642525508091706,
                                0.59196524694454089,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13468543430470442,
                                0,
                                0.18515593943857211,
                                0,
                                0,
                                0,
                                0,
                                -0.19873041054122834,
                                0,
                                0,
                                -0.57018734280743177,
                                0,
                                0,
                                -0.00060658280224298866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76857066606351232,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20723992537951783,
                                0,
                                -0.041749187788512644,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60840243674070726,
                                0,
                                0,
                                0.73827401175308771,
                                0.40078456666969597,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1691906850253084,
                                0,
                                0,
                                0,
                                0,
                                -0.28376839512688617,
                                0,
                                0,
                                0.090500879099758791,
                                0.013195944316120978,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0694862422274789,
                                0,
                                0,
                                0,
                                0,
                                -0.32309158406605942,
                                0,
                                0,
                                1.3069817178767924,
                                -0.063499492442318867,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45410340350445338,
                                0,
                                0,
                                0,
                                0,
                                -0.35457368601705319,
                                0,
                                0,
                                -0.38362786696225726,
                                0.50013249717929298,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36696545356842514,
                                0,
                                0,
                                0,
                                -0.029183420655840869,
                                0,
                                0,
                                0.14984875306345408,
                                0,
                                0,
                                -0.28564276519555576,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27027079333000625,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72779259861627477,
                                0,
                                -0.54071574928767174,
                                0,
                                0,
                                0,
                                0,
                                -0.91482100997955451,
                                0,
                                0,
                                0.45925929042633129,
                                0,
                                0,
                                0,
                                0,
                                -0.47622224199779817,
                                -0.36184556851346128,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19551627762600621,
                                0,
                                -0.14011513772529147,
                                0,
                                0,
                                0,
                                0.20442706495324725,
                                0,
                                0,
                                0.20132065711823088,
                                0,
                                0,
                                0,
                                0,
                                -0.36881630833374074,
                                -0.51996089508535948,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20186686943938881,
                                0,
                                1.4721087658044061,
                                0,
                                0.043250927906405293,
                                0.18659391908864426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23188193425490111,
                                -0.090925633968954533,
                                0,
                                0,
                                0.42089288347434251,
                                0.52463006951813418,
                                0,
                                0,
                                0.66729719650918218,
                                0,
                                0,
                                0,
                                -0.060019051783259558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2610138311981105,
                                -0.33486604666885145,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67624770577465532,
                                0.10595682325979131,
                                0,
                                0,
                                0.42939274317392806,
                                -0.07723797378162589,
                                0,
                                0,
                                0.1820175998142157,
                                0,
                                0,
                                0,
                                0.35738559515517343,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58931375512391126,
                                0,
                                0,
                                0.13814079203331647,
                                -0.43292970171121348,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.97631087905152669,
                                0,
                                0,
                                0,
                                0,
                                0.27061451188719216,
                                0,
                                0,
                                -0.50936959880454868,
                                -0.78041598521281985,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6032525939450778,
                                0,
                                0,
                                0,
                                0.50115977090254493,
                                0,
                                0,
                                -0.28319415017286831,
                                0,
                                0,
                                -0.74862510977272645,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15741604221651317,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25612999919691704,
                                0,
                                -0.13348413957779881,
                                0,
                                0,
                                0.11950536087409258,
                                -0.19218980833347038,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36965255007913683,
                                -0.030544080322224457,
                                0,
                                0,
                                0.15722164243789605,
                                -0.7757327445899187,
                                0,
                                0,
                                0.42781025979966031,
                                0,
                                0,
                                0,
                                0.041280060593793813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54322046085320819,
                                0.44885248539882411,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41589754363936537,
                                0.012590970757145978,
                                0,
                                0,
                                0.34433424936260848,
                                -0.22624752827473529,
                                0,
                                0,
                                -0.088933821166071514,
                                0,
                                0,
                                0,
                                -0.39070504735685885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27050977270234994,
                                0,
                                0,
                                0.18634429213369741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.047940261756879113,
                                0,
                                0,
                                -0.75206059350670795,
                                0.029590378667132329,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42913009947072955,
                                0,
                                0,
                                0,
                                0,
                                -1.1867368237158735,
                                0,
                                0,
                                -0.49611584772053013,
                                0.17761534379463614,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50186109310056493,
                                0.3278304165348408,
                                -0.62787961275399806,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25461822311680693,
                                -0.054264583714240588,
                                0,
                                0,
                                0.45811152554014056,
                                0.19471322030046834,
                                0,
                                0,
                                -0.39768635889207365,
                                0,
                                0,
                                0,
                                -0.15679756774998749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39634415336952389,
                                0,
                                0,
                                0.52846856579057278,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36739928483131556,
                                0,
                                0,
                                0.29717852502333353,
                                -0.80710735818486989,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59868227427006382,
                                0,
                                0,
                                0,
                                0,
                                0.0046464429643614334,
                                0,
                                0,
                                0.43890477153915691,
                                0.65820433255940436,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48917624050260167,
                                0,
                                0,
                                0,
                                0,
                                -0.33241929723250591,
                                0,
                                0,
                                -0.10741130976364612,
                                0.67485926010343589,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26552814590429474,
                                0,
                                0,
                                0,
                                0,
                                0.67147472134239972,
                                0,
                                0,
                                -0.41462561605443171,
                                0.67373530778998025,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76363362768076803,
                                0.45701827051070631,
                                0.22022018787375458,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.096507829701612757,
                                -0.20439974888351428,
                                0,
                                0,
                                0.037855740526786807,
                                0.04487493701364012,
                                0,
                                0,
                                -0.13817918197602047,
                                0,
                                0,
                                0,
                                0.81792667601718438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54304026662610572,
                                0,
                                0,
                                0.45637944631483668,
                                0,
                                0,
                                -0.30079367388467126,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.037759529790009398,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52015273482989988,
                                0,
                                -0.36655638845065064,
                                0,
                                0,
                                0,
                                0,
                                0.10294875383488244,
                                0,
                                0,
                                0.51038082719128863,
                                0,
                                0,
                                0,
                                0,
                                -0.21729759646964997,
                                0.61443595230054093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0172702479313314,
                                0,
                                -0.0047633043057067059,
                                0,
                                0,
                                0,
                                0,
                                0.5263786169370015,
                                0,
                                0,
                                0.59655573920614557,
                                0,
                                0,
                                0.023711125115037091,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55088616992680484,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14449313783002049,
                                0,
                                0.20525775283990683,
                                0,
                                0,
                                0,
                                0,
                                -1.2217163163292455,
                                0,
                                0,
                                0.30310462603871086,
                                0,
                                0,
                                0,
                                0,
                                0.46452457957256355,
                                0.41868502944148878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.064038814803758892,
                                0,
                                0.91347218793580032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23245075000814608,
                                0,
                                0,
                                -0.0010346563293859301,
                                -0.27292112429560422,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12967072293462795,
                                0,
                                0,
                                0,
                                0,
                                -0.62525053340962278,
                                0,
                                0,
                                -0.18809170614411683,
                                0.88052186348221273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1141908815276644,
                                0.76660450407202874,
                                0,
                                0,
                                0,
                                0,
                                0.016306936879128042,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0027470234207818828,
                                0,
                                0,
                                0.33920010754479218,
                                0,
                                0,
                                0.72857064660225557,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43661006572715322,
                                0,
                                -0.36407713623328108,
                                0,
                                0,
                                0.95780287212387394,
                                0,
                                -0.0040406017896126856,
                                0,
                                -0.43679434260027028,
                                0,
                                0,
                                -0.56403984747595193,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18908263725007229,
                                0,
                                -0.39511838335394417,
                                0,
                                0,
                                -0.14783636250184723,
                                -0.2873471134078765,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44131473126737075,
                                0,
                                0,
                                0,
                                0,
                                -0.16664235448586165,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2885363143756297,
                                -0.80552809427305327,
                                0,
                                0,
                                0,
                                0.95658291864579226,
                                0,
                                0,
                                0,
                                0.16506122647042792,
                                0,
                                0,
                                0,
                                0,
                                0.23201799161343675,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57563423042632245,
                                0,
                                -0.0018982166182609506,
                                0,
                                0,
                                -0.36300809598486661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.098539493453316612,
                                0,
                                0.61849635369104505,
                                0,
                                0,
                                0.14749833375405355,
                                0.23925701711134859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25616264713694969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19508632393876985,
                                0,
                                0,
                                0.11851938258575204,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1971114883678475,
                                0,
                                0,
                                0,
                                0,
                                1.0964558166342209,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.036219129732989158,
                                0,
                                0,
                                0.89013266354865628,
                                0,
                                0,
                                0.24886626675992884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45063933036748516,
                                0,
                                0.046232543992922454,
                                0,
                                0,
                                -0.1748342804177323,
                                0,
                                0.37162743870540366,
                                0,
                                -0.70215564928973162,
                                0,
                                0,
                                0.5123908745047836,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1626222019683404,
                                0,
                                -0.15085035022168275,
                                0,
                                0,
                                0.080110364178529028,
                                0.21555775906754243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.065126461733430896,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52090573279087948,
                                0,
                                0,
                                -0.53786609697676491,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59246832552140649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0069589576422047772,
                                0.9824214137907652,
                                0,
                                0,
                                0,
                                0.45418627451937416,
                                0,
                                0,
                                0,
                                0.72294576079826522,
                                0,
                                0,
                                0,
                                0,
                                0.27161954243003994,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2683189033174607,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.096401455392532712,
                                0.18828712273865383,
                                0,
                                0,
                                0,
                                -0.15748155487222143,
                                0,
                                0,
                                0,
                                -0.11394035679532739,
                                0,
                                0,
                                0,
                                0,
                                -0.14830009532599261,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16182854375644151,
                                -0.70817955304509395,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65122376185658515,
                                0,
                                -0.18738724215342464,
                                0,
                                -0.091171425160912534,
                                0,
                                0,
                                -0.069098826184976064,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8036726554656306,
                                0.003217277301388894,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29384302910240978,
                                0,
                                -0.048994404098548258,
                                0,
                                -0.25931623582997076,
                                0,
                                0,
                                -0.44509642150158291,
                                0,
                                -0.37231311405218687,
                                0,
                                0,
                                0,
                                0,
                                0.3664335554799108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73393018770880769,
                                0,
                                0,
                                -0.39885142773578142,
                                0,
                                0,
                                -0.09555997357468915,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3663077499071779,
                                0,
                                -0.51720993414091243,
                                0,
                                0,
                                0.77289667062258305,
                                0,
                                0,
                                0.0049880648452584053,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.033824210432520541,
                                0.5102607724547642,
                                0,
                                0,
                                0,
                                0.54167595266167012,
                                0,
                                0,
                                0,
                                -1.1290289439889918,
                                0,
                                0,
                                0,
                                0,
                                -0.055694815163429195,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60831385558706852,
                                0,
                                0.30037868656538175,
                                0,
                                0,
                                0.17881467943839494,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1798769832175201,
                                0,
                                -0.13035346381728025,
                                0,
                                0,
                                -0.23093499531813672,
                                -0.63645383292406155,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                6.9623527925166684e-06,
                                0,
                                0,
                                0.39152955584873061,
                                0,
                                0,
                                0,
                                0,
                                0.25813955900047125,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41253934242149209,
                                0,
                                0,
                                -0.25943414579740837,
                                0,
                                0,
                                -0.92521542746756014,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.98283497511459439,
                                0,
                                -0.64411893902780104,
                                0,
                                0,
                                -0.050985348391274637,
                                0,
                                0.36652300082179695,
                                0,
                                0.29000254721770014,
                                0,
                                0,
                                -0.2648815220381156,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.026979570436467051,
                                0,
                                -0.62775336354596134,
                                0,
                                0,
                                0.17188595770864717,
                                0.48659253611634257,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22422740785382655,
                                0,
                                0,
                                0,
                                0,
                                -0.36381406802234972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0649544273660987,
                                -0.74084062772008763,
                                0,
                                0,
                                0,
                                0.50335377899192557,
                                0,
                                0,
                                0,
                                0.33070502076445801,
                                0,
                                0,
                                0,
                                0,
                                -0.083932288568648983,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45654382162489016,
                                0,
                                0,
                                0,
                                0,
                                0.22234826171180758,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71825072586116101,
                                0,
                                0,
                                -0.1864037175127648,
                                0,
                                0,
                                0.46686952491754113,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.015335880555989653,
                                0,
                                -0.84274258029331517,
                                0,
                                0,
                                -0.43215318353132448,
                                0,
                                -0.1367507379371708,
                                0,
                                0.061580865075659186,
                                0,
                                0,
                                -0.16881754539482652,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.89203971626289291,
                                0,
                                0.029005040679523808,
                                0,
                                0,
                                -0.19182353833487392,
                                0.16670571687632985,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29638565320081478,
                                0,
                                0,
                                0,
                                0.011700051371267811,
                                0,
                                -0.31654786083919784,
                                0,
                                0,
                                -0.3589328028926515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30864671291378476,
                                0,
                                0.10718928252792427,
                                0,
                                0,
                                0.42264381432680398,
                                -0.32714229306165432,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61516306311740165,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40850980557796884,
                                0.46006954426817198,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50020004815847263,
                                0,
                                0.26928246766309555,
                                0,
                                -0.21119957047334698,
                                0,
                                0,
                                0.50412038150320415,
                                0,
                                0,
                                0,
                                -0.72320327823237751,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.073622008866075644,
                                -0.12980099436530218,
                                0,
                                0,
                                0,
                                -0.087381002010504819,
                                0,
                                0,
                                0,
                                -0.69438061619850588,
                                0,
                                0,
                                0,
                                0,
                                1.2403490318759105,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.083479257797700823,
                                -0.43875564535043837,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38599203917573516,
                                0,
                                0.38244218820668052,
                                0,
                                -0.58703198615903285,
                                0,
                                0,
                                0.40083196328322518,
                                0,
                                -0.80408678357440067,
                                0,
                                0,
                                0,
                                0,
                                0.060741768593692319,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67880229329845077,
                                0,
                                0,
                                0.14497020948929024,
                                0,
                                0,
                                -0.83808410244521547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.091053208464560387,
                                0,
                                0.10265051026408845,
                                0,
                                0,
                                1.1641026352525006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3053156083542154,
                                0.29211248216865582,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12594933572272837,
                                0,
                                -0.52521632420156938,
                                0,
                                -0.70980752264761238,
                                0,
                                0,
                                -0.16096749818710465,
                                0,
                                0.5859907912136415,
                                0,
                                0,
                                0,
                                0,
                                0.85044440374829011,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58089251022587374,
                                0,
                                0,
                                -0.75352385230152785,
                                0,
                                0,
                                -0.0044639556191741238,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40294750212260605,
                                0,
                                0.32004754767442645,
                                0,
                                0,
                                0.056043728831187245,
                                0,
                                0.085436763403379773,
                                0,
                                -0.19457892829325996,
                                0,
                                0,
                                -0.1675432287726803,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.063328262665672944,
                                0,
                                0.12325075982948286,
                                0,
                                0,
                                -0.80726152072618906,
                                0.19251990829046514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46779543609542346,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24668829895636471,
                                -0.09471623750381547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27296649718875687,
                                0,
                                -0.68400168707855979,
                                0,
                                0.17721267031455007,
                                0,
                                0,
                                0.59699277255031202,
                                0,
                                -0.19625567406974881,
                                0,
                                0,
                                0,
                                0,
                                -0.015940962345969853,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29570381367008264,
                                0,
                                0,
                                -0.10321765014084133,
                                0,
                                0,
                                0.59431340013502953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79191523426992194,
                                0,
                                0.90011356797482245,
                                0,
                                0,
                                0.17414122915467128,
                                0.099660807802313553,
                                0,
                                0,
                                0.89986526301383185,
                                -0.63033137213425727,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62023767668033269,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64757909564158189,
                                0.087236395995401769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19577041606302881,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46561853511993873,
                                0,
                                -0.032502750661367319,
                                0,
                                0,
                                -0.066186127592436417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33176489842157253,
                                0,
                                -0.3986875862379145,
                                0.35241579400660905,
                                0,
                                -0.58840433423865846,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72761976486725666,
                                0,
                                0,
                                0,
                                -0.2008434615445705,
                                0,
                                0,
                                0,
                                0,
                                -0.35573391581363223,
                                0,
                                0,
                                0.63956149360486414,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61144696396052312,
                                0,
                                0.26362031249708978,
                                0,
                                0.3346772848292705,
                                0,
                                -0.4026636665446281,
                                -0.4217183063518215,
                                0,
                                0,
                                -0.068438972719423397,
                                -0.16804358399191605,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63475654945800208,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10412994918774626,
                                1.2470649886033838,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.05183882540977941,
                                0,
                                0,
                                -0.44644109966126339,
                                -0.76764397344663371,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52784055144936648,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55715498983451017,
                                0.030154773429693832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20418273633670914,
                                0,
                                0,
                                0.5725142319484896,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.012927445217496447,
                                0,
                                0,
                                -0.71891831877070955,
                                0,
                                0.023678372167976615,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3361034531003888,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17692716599173744,
                                0,
                                0,
                                0,
                                -0.19344653260274952,
                                0,
                                0,
                                0,
                                0,
                                -0.78430553460396502,
                                0,
                                0,
                                -0.069107459502765187,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58445467102365734,
                                0,
                                -0.23829819844344677,
                                0,
                                -0.69510332642562267,
                                0,
                                -0.15270950339295616,
                                0,
                                0.42952377901081162,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74478130298908551,
                                0,
                                0.23427766136458311,
                                0,
                                0,
                                0.039504912358390883,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32299953838197892,
                                0,
                                -5.6884399834564864e-05,
                                0.092570471770792639,
                                0,
                                0.30243259743714329,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24406875320922022,
                                0,
                                0,
                                -0.66191305384864141,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1262303014693425,
                                0,
                                0,
                                -0.66932805268338558,
                                0,
                                -0.13542638551704902,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14151719273457225,
                                0,
                                0,
                                0,
                                0,
                                0.58114275311792152,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3314872566139343,
                                0,
                                -0.28679678924471186,
                                0,
                                0,
                                -0.2510036043462473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.026702717817023377,
                                0,
                                -0.54758936280370685,
                                0.30156495131383554,
                                0,
                                0.12500210490108943,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15869115231790734,
                                0,
                                0,
                                -0.48599543066336354,
                                -0.80124523849990281,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.89485124525639026,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76553551184002899,
                                0.088844716569481869,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0829859188622168,
                                0,
                                0,
                                0,
                                0.62708720789893624,
                                0,
                                0,
                                0,
                                0,
                                -0.68273400411260288,
                                0,
                                0,
                                0.24517089876462711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30526105676826254,
                                0,
                                -0.21401795420054837,
                                0,
                                0.2239758847346793,
                                0,
                                0.16002502383940262,
                                0,
                                -0.57964594925161483,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.022289649186318039,
                                0,
                                0.30021069266093314,
                                0,
                                0,
                                -0.23499886604753706,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22501814691801811,
                                0,
                                -0.53136516795313493,
                                0.019455212214728901,
                                0,
                                0.42988626936103996,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20646814087704282,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30308395743047223,
                                0,
                                0,
                                0,
                                -0.38391038330215332,
                                0,
                                0,
                                0,
                                -0.31140549570190529,
                                0,
                                0,
                                0,
                                0,
                                0.15184521151699876,
                                0,
                                0,
                                0.36439339251916253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.069966407650015758,
                                0,
                                -1.0110332381838425,
                                0,
                                0.31412980442519156,
                                0,
                                -0.030224241119713072,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3968434376904863,
                                0,
                                0,
                                0.14545204292254213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33337656225483392,
                                0,
                                0,
                                -0.11247381008152166,
                                0,
                                -0.4375506728810597,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7114197829818093,
                                0,
                                0,
                                0,
                                -0.13932613518511,
                                0,
                                0,
                                0.43415359058901432,
                                -0.45653021921633374,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0428152865071758,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6387095431596681,
                                0.42486328779653082,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1660994117803836,
                                0,
                                0,
                                -0.19452780610689302,
                                -0.63380437880818596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42083279877199331,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.069946587858858558,
                                -0.8965741129819691,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22723184383259282,
                                0,
                                0,
                                -0.15813802991776607,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40016214800232797,
                                0,
                                0,
                                -0.12633638373967249,
                                0,
                                0.83771441883613007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21331192785675346,
                                0,
                                0,
                                0,
                                0,
                                -0.14594399744818715,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.030787552333007034,
                                0,
                                -0.089185662823328404,
                                0,
                                0,
                                -0.49641365537585447,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1797955036179486,
                                0,
                                0.49153675839739014,
                                0.61378948293404978,
                                0,
                                0.26962852073888299,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79938348877019472,
                                0,
                                0,
                                0.4128250131532612,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.08472806894358223,
                                0,
                                0,
                                -0.077526369917481394,
                                0,
                                0.1416017675972277,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39663749458472852,
                                0,
                                0,
                                0,
                                0,
                                0.25543524882455382,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0034905567746167654,
                                0,
                                0.4995741126535701,
                                0,
                                0,
                                -0.52617049228415103,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4839710648772369,
                                0,
                                -0.0065153680714449339,
                                -0.41623029968894015,
                                0,
                                -0.028157852342379386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.062031533967589154,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10037689097312565,
                                0,
                                -0.29984162068071629,
                                0,
                                0,
                                -0.59218008934201527,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56672664587860377,
                                0,
                                0.088347857825125525,
                                -0.28569313150576203,
                                0,
                                -0.36727280368409121,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50337699265470992,
                                0,
                                0,
                                0,
                                -0.2067103366311554,
                                0,
                                0,
                                0,
                                0,
                                -0.47964782419022384,
                                0,
                                0,
                                -0.62697696209505205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44377020858837635,
                                0,
                                -0.26838670844455331,
                                0,
                                0.53981238901092321,
                                0,
                                0.1636673316588145,
                                0,
                                -0.11433378124555688,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32723689141916057,
                                0,
                                -0.65134116735907066,
                                0,
                                0,
                                -0.043270308158793597,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38278406822994571,
                                0,
                                -0.096896720868708652,
                                -0.37987910395075103,
                                0,
                                0.39179767287642453,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.054797436105891745,
                                0,
                                0,
                                0,
                                0.53951495072388089,
                                0,
                                0,
                                0,
                                0,
                                0.29861957853175924,
                                0,
                                0,
                                -0.18981856441468969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36786097651251998,
                                0,
                                -0.33475106614593481,
                                0,
                                -0.18825721125844194,
                                0,
                                -0.76496646837791382,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22495970057096909,
                                0,
                                0,
                                0.13232588023358988,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83991086999127751,
                                0,
                                0,
                                -0.023126413118045752,
                                0,
                                0.26044563606630072,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39757510570988686,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2214357119313084,
                                0,
                                0,
                                0,
                                -0.6543455096524089,
                                0,
                                0,
                                0,
                                0,
                                0.12318446898174366,
                                0,
                                0,
                                -0.11560325491308435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35267732257461282,
                                0,
                                -0.029897036462167903,
                                0,
                                -0.32628708601443762,
                                0,
                                -0.23031958977234504,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.078869962457109727,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.08848419983573251,
                                0,
                                0,
                                0,
                                0.20424427673280099,
                                0,
                                0,
                                0,
                                -0.32807274292768374,
                                0,
                                0,
                                0,
                                0,
                                0.22837101359494871,
                                0,
                                0,
                                -0.27394857821674162,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46709468589042791,
                                0,
                                0.32846021145320148,
                                0,
                                0.63643778086830616,
                                0,
                                -0.64880849302777244,
                                0.010148248757244356,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50771234140194355,
                                0,
                                0,
                                0.44041061878151905,
                                0,
                                0,
                                0.34730943778139911,
                                0,
                                0,
                                -0.52220243405987832,
                                0,
                                -0.061029787793064227,
                                0,
                                0.38434123224677774,
                                0,
                                0,
                                -0.058323518298075874,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19554512826555087,
                                -0.90761309343998531,
                                0,
                                0,
                                0,
                                0,
                                -0.62125745772037166,
                                0,
                                0,
                                -0.35382721849512422,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1782726394540819,
                                0,
                                0,
                                0.10507524524172403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.99125747011979559,
                                0.10784513151441485,
                                0,
                                0,
                                0,
                                0,
                                0.35482357523597019,
                                0,
                                0,
                                -0.44434206015466116,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14409619304418678,
                                0,
                                0,
                                0.32503301032364418,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26147445086299909,
                                0.80847477654688338,
                                0.13285624743047114,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.071578453527125774,
                                0,
                                0,
                                0.45767015690833873,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21392385845953474,
                                0,
                                0,
                                0,
                                0,
                                0.45491393587183265,
                                0.13852924758949037,
                                -0.80908027723072895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.057766963549366335,
                                0,
                                0,
                                -0.32547604279700248,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.099901886847166388,
                                0,
                                0,
                                0,
                                0,
                                -0.16880688837402411,
                                0.13455924855585677,
                                -0.11132480168327734,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76334369418313341,
                                0,
                                0,
                                0.050471016223175576,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59645948116195502,
                                0,
                                -0.69978808528707548,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4923229843886755,
                                0,
                                0,
                                0.064035476667024874,
                                0,
                                0,
                                0.23189231025493498,
                                0,
                                0,
                                -0.18670786270178907,
                                0,
                                0.060451025361854205,
                                0,
                                0.19710106932243321,
                                0,
                                0,
                                0.36424874044464894,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0068000791624569928,
                                -0.45515687313489211,
                                0,
                                0,
                                0,
                                0,
                                0.12450265551740458,
                                0,
                                0,
                                1.0186746783107736,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25561812295947484,
                                0,
                                0,
                                0.64010822778126786,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25892737597496063,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.037746835212617527,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35875427096448559,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.096502684068258182,
                                0,
                                0,
                                0.032971762615071933,
                                0,
                                0,
                                0.64568975781351468,
                                0,
                                0,
                                0.53986484229177889,
                                0,
                                -0.045805605071371512,
                                0,
                                0.26584202480053964,
                                0,
                                0,
                                0.28241108513726976,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.09160048198150654,
                                -1.285195571384139,
                                0,
                                0,
                                0,
                                0,
                                0.34874788215268759,
                                0,
                                0,
                                -0.14430894832608199,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25037409308099196,
                                0,
                                0,
                                -0.59227106561874832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55432175848139231,
                                0.11951383187081427,
                                -0.079761488409670192,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39003416354626486,
                                0,
                                0,
                                -0.24864860575011591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67685239096690408,
                                0,
                                -0.08186248528365693,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.097443916948301998,
                                0,
                                0,
                                0.59355740610864427,
                                0,
                                0,
                                0.25127315505754427,
                                0,
                                0,
                                0.14057191265343194,
                                0,
                                0.42006971296600237,
                                0,
                                -0.55653674490301408,
                                0,
                                0,
                                -0.24980482170753945,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23107746184634043,
                                0,
                                0,
                                -0.89919063558807366,
                                0,
                                -0.56314245691948639,
                                0,
                                0.66184884688330481,
                                0,
                                0,
                                0,
                                0,
                                1.1784569105207507,
                                0.085634521873470787,
                                0.1842326376561649,
                                0,
                                -0.18019188096945299,
                                0,
                                0,
                                0,
                                0.45704402359550478,
                                0.091129247695999588,
                                0.55443060855135418,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24461996081793919,
                                0,
                                0,
                                -0.64297949048772751,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.046382869606572591,
                                0,
                                -0.48432058813729661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55770040366334728,
                                0,
                                0,
                                -0.40158355549170155,
                                0,
                                0,
                                0.17462069047489076,
                                0,
                                0,
                                0.31889060186078944,
                                0,
                                0.37192331280298091,
                                0,
                                0.049205860200730284,
                                0,
                                0,
                                -0.14213622633665493,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24585847182461934,
                                0,
                                0,
                                0.56599832802877204,
                                0,
                                -0.72245140608980585,
                                0,
                                0.54317200550336442,
                                0,
                                0,
                                0,
                                0,
                                -0.064102652599760723,
                                -0.025021597009169005,
                                0.85034441222296364,
                                0,
                                0.70884473203547205,
                                0.10665561719344406,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26420739934256382,
                                0,
                                0,
                                0.23770137746958456,
                                0,
                                0,
                                -0.39038028698971805,
                                0,
                                0,
                                0.074314521478933568,
                                0,
                                0.40019637239407679,
                                0,
                                0.0050209549043263579,
                                0,
                                0,
                                0.73770951028466547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33196646192290497,
                                0,
                                0,
                                0.4111096203961449,
                                0,
                                0.48358449243543061,
                                0,
                                0.85385668446747531,
                                0,
                                0,
                                0,
                                0,
                                0.30310311719116195,
                                0.68286133004004701,
                                -0.37980284208479742,
                                0,
                                -0.36495999730411821,
                                0.35763742981069468,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20617204893402558,
                                0,
                                0,
                                -0.41924840647514511,
                                0,
                                0,
                                0.234726534386059,
                                0,
                                0,
                                -0.46997480179480361,
                                0,
                                0.6145865591148294,
                                0,
                                -0.010444235664965273,
                                0,
                                0,
                                -0.0045549681241650666,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80386256041510706,
                                0,
                                0,
                                0.083434800371928242,
                                0,
                                0.0080717322877024017,
                                0,
                                -0.31416456906035495,
                                0,
                                0,
                                0,
                                0,
                                0.52053510585122043,
                                0.47459011932834694,
                                0.88106760387238114,
                                0,
                                0.65545581006893849,
                                0,
                                -0.36334099006935033,
                                -0.45114631971731911,
                                0,
                                0,
                                0,
                                0,
                                -0.56857558202239766,
                                0,
                                0,
                                0.013643437948759482,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.82204077283980392,
                                0,
                                0,
                                0.51019272076405575,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.030678515791367836,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24019985131740373,
                                0,
                                0,
                                0.23452055323978932,
                                0,
                                0,
                                -0.32796790867058734,
                                0,
                                0,
                                0.23052137193252345,
                                0,
                                0.37129987287772054,
                                0,
                                0.65610391430383874,
                                0,
                                0,
                                -0.39664086552547212,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53181152804218812,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40938182426132197,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26482312211128767,
                                -0.37795090143016469,
                                0,
                                0,
                                0,
                                0,
                                0.29013432292445884,
                                0,
                                0,
                                -0.67313961973090186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12233917196118921,
                                0,
                                0,
                                0.8856274198814168,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1804965424014731,
                                0,
                                0,
                                -0.23614494861656296,
                                0,
                                -0.42704532517770355,
                                0,
                                0.73021778190402076,
                                0,
                                0,
                                0,
                                0,
                                -0.51370669939528013,
                                0.016501511007111447,
                                -0.43488294655028836,
                                0,
                                0.17629586954057913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.02693980282709011,
                                0,
                                0,
                                -0.17324317351740912,
                                0,
                                0.45728263791066431,
                                0,
                                0.073138451247689529,
                                0,
                                0,
                                0,
                                0,
                                -0.3739665010035117,
                                0.20700662450451363,
                                -0.42871427738204848,
                                0,
                                1.1375964651395991,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37168131728870413,
                                0,
                                0,
                                0.018427854767575733,
                                0,
                                -0.77865263502540816,
                                0,
                                -0.74755909192782333,
                                0,
                                0,
                                0,
                                0,
                                0.2709090172309504,
                                0.81710057105067391,
                                -0.64608953855362494,
                                0,
                                0.48663662086460352,
                                0,
                                0,
                                0,
                                0.42429565812378922,
                                -0.53524190426736584,
                                0.039873754691125647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4437119938653829,
                                0,
                                0,
                                0.45476070106459915,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35806668843613099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.342404293276793,
                                0,
                                0,
                                1.0314319358730226,
                                0,
                                -0.046779660377758353,
                                0,
                                -0.18060960440145413,
                                0,
                                0,
                                0,
                                0,
                                0.57630226399407403,
                                -0.96164814350170769,
                                -0.17987846094422799,
                                0,
                                0.092073291630977688,
                                0.72762923445828587,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0327307350686019,
                                0,
                                0,
                                -0.55968821616218745,
                                0,
                                0,
                                -0.24165123323917237,
                                0,
                                0,
                                0,
                                -0.49415523615998769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68029163535641768,
                                0,
                                0.23106492057406586,
                                0,
                                0,
                                -0.26448755042439881,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44651385258685372,
                                0,
                                0,
                                -0.35743400138231185,
                                0,
                                0.043571748996117599,
                                0,
                                0,
                                0,
                                0,
                                0.0041772982560460414,
                                0,
                                -1.0710790741055822,
                                0,
                                0.19334241890292309,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60281194456708787,
                                0,
                                0,
                                0,
                                0.69276026416020631,
                                0,
                                0,
                                -0.0026237796723876938,
                                0,
                                0,
                                -0.094831822528748264,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20110718838218342,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32750101661681308,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.075243012370325935,
                                0,
                                0,
                                0,
                                0,
                                -0.76068038452378106,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73315185786870318,
                                0,
                                0,
                                0.13883754262294506,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0315792175045708,
                                0,
                                0,
                                -0.87323778289653642,
                                0,
                                0.15272705451857191,
                                0,
                                0,
                                0,
                                0,
                                0.11068371529178628,
                                0,
                                0.55428796942439085,
                                0,
                                0.57061435804780158,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.05025128558390389,
                                0,
                                0.017256314393090971,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32745399224022176,
                                0,
                                0,
                                0.22449219909557611,
                                0,
                                0,
                                0,
                                0.059740517879318056,
                                0,
                                0.43945073114593142,
                                0,
                                0.4956795596808049,
                                0.63021429923111372,
                                0,
                                0,
                                0,
                                -0.028833851941728078,
                                0,
                                0,
                                0,
                                -0.24058064977296673,
                                0,
                                0,
                                0.5249944692018963,
                                0,
                                0,
                                0.067171308007756572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28590744876545354,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76119334821410201,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4714581355196199,
                                0,
                                -0.26607215766976938,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15939729189700738,
                                0,
                                0,
                                -0.35796979429113635,
                                0,
                                0,
                                0,
                                0.2831334909939639,
                                0,
                                0.58586060336908963,
                                0,
                                -0.092030941481916123,
                                -0.34859152110157265,
                                0,
                                0,
                                0,
                                0,
                                0.26179341954748919,
                                0,
                                0,
                                0,
                                0,
                                -0.0087202870443535991,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59307080162983716,
                                0,
                                0,
                                0,
                                0.59081828412694815,
                                0,
                                0,
                                0.28386763565629342,
                                0,
                                0,
                                0.46175781685652112,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.050646410062036906,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.053241004329972086,
                                0,
                                0,
                                0,
                                0,
                                0.29838559916677809,
                                0,
                                0,
                                -0.17128252613832012,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.035028359712160381,
                                0,
                                0,
                                -1.2270428801657829,
                                0,
                                -0.89532198720344602,
                                0,
                                0,
                                0,
                                0,
                                -0.29103264417996455,
                                0,
                                0.19179167914338641,
                                0,
                                -0.0011255444727019948,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22770625052867907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.93421090506257864,
                                0,
                                0,
                                -0.32353455292761074,
                                0,
                                0,
                                0.19906271058058217,
                                0,
                                0,
                                0,
                                0.74772196354129716,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20241512511081355,
                                0,
                                0,
                                -0.48351084880385714,
                                0,
                                0,
                                0,
                                -0.0017552068395948819,
                                0,
                                0,
                                -0.36219786451022584,
                                0,
                                0,
                                -0.39953905802999584,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51420677583573426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45933301435372376,
                                0,
                                0,
                                0,
                                0,
                                0.37898986298922849,
                                0,
                                0,
                                0.97751084638679464,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27278166261968806,
                                0,
                                0,
                                0.055910958468047688,
                                0,
                                0.52964464540624923,
                                0,
                                0,
                                0,
                                0,
                                0.015033105663585226,
                                0,
                                0.26388966071795811,
                                0,
                                -0.81743679514946044,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69233992228725116,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38185166258027353,
                                0,
                                0,
                                0.33724923218875058,
                                0,
                                0,
                                -0.91365885987000484,
                                0,
                                0,
                                0,
                                -0.033266620677944891,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0148489393750939,
                                0,
                                0.56785123189848496,
                                0,
                                0,
                                -0.1971808344429164,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85294651437435054,
                                0,
                                0,
                                -0.96810714744149273,
                                0,
                                0.46982409966229771,
                                0,
                                0,
                                0,
                                0,
                                0.48141223372089564,
                                0,
                                0.22598049015074581,
                                0,
                                -0.02483290660137177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70105016972369705,
                                0,
                                0.11363198322660822,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46950412171616818,
                                0,
                                0,
                                -0.28154278950927997,
                                0,
                                0,
                                0,
                                -0.11930256553364996,
                                0,
                                0.19510124545534707,
                                0,
                                0.16166185364670418,
                                -0.34275912276640702,
                                0,
                                0.74039677255035297,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28383685530236291,
                                0,
                                0,
                                0.58431805960109573,
                                0,
                                0,
                                -0.6083486857084679,
                                0,
                                0,
                                0,
                                0.45842625970765194,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11965726223074787,
                                0,
                                0,
                                0.19516375902157906,
                                0,
                                0,
                                0,
                                -0.30863222126368606,
                                0,
                                0,
                                0.3903803239635284,
                                0,
                                0,
                                0.30914667946962882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.78101143021218067,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.093327050073214957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45507143761008084,
                                0,
                                -0.067815626389959541,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69154834130744181,
                                0,
                                0,
                                -0.034766093785431246,
                                0,
                                0,
                                0,
                                0.41625812803923196,
                                0,
                                0.35540220050031129,
                                0,
                                0.060074626512144014,
                                0.075317486793556404,
                                0,
                                0,
                                -0.1665873923073739,
                                0,
                                0,
                                -0.75782431998702593,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61694384409824665,
                                0,
                                0,
                                0.25958943371643994,
                                0,
                                0.33043847308510826,
                                0,
                                0,
                                0,
                                0,
                                -0.10095974934053742,
                                0,
                                0.53736036867454451,
                                0,
                                -0.70773345392402942,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12099030781199657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35488500495607206,
                                0,
                                0,
                                0.65981109334301902,
                                0,
                                0,
                                0.66839412894264338,
                                0,
                                0,
                                0,
                                -0.45025308773134554,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1434442839781189,
                                0,
                                -0.80701251305085187,
                                0,
                                0,
                                -0.23428643594001791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.066093016464460766,
                                0,
                                0,
                                0.071851889608334343,
                                0,
                                -0.53224118649409036,
                                0,
                                0,
                                0,
                                0,
                                0.68772849050129314,
                                0,
                                -0.76828049225358108,
                                0,
                                -0.32286682078852619,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17129535244924549,
                                0,
                                -0.83556721364536812,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.038151678051145471,
                                0,
                                0,
                                -0.31592334371834618,
                                0,
                                0,
                                0,
                                -0.18510109404645583,
                                0,
                                -0.17554313271644911,
                                0,
                                -0.063906660247707636,
                                0.31946886605863406,
                                0,
                                0,
                                -0.54789047538117042,
                                0,
                                0,
                                -0.20692376889659492,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74324214113074771,
                                0,
                                0,
                                -0.27318043137220405,
                                0,
                                0.11196144473051878,
                                0,
                                0,
                                0,
                                0,
                                -0.74670707038607609,
                                0,
                                -0.49642373692670044,
                                0,
                                -0.52434673765927264,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1667121676546757,
                                0,
                                0.030551322156677357,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12002387502546011,
                                0,
                                0,
                                0.29616076260324509,
                                0,
                                0,
                                0,
                                -0.21847661571378379,
                                0,
                                0.40031772373387486,
                                0,
                                -0.78684776442063975,
                                0.20503908423888551,
                                0,
                                0,
                                0,
                                -0.11037100605291388,
                                0,
                                0,
                                0,
                                0.13371983302255214,
                                0,
                                0,
                                0.60017413983019863,
                                0,
                                0,
                                -0.7197718604319765,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.029331011435229551,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30132442625324563,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0758795871260836,
                                0,
                                0.1857839742595041,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31994794538826371,
                                0,
                                0,
                                -0.27280914837306625,
                                0,
                                0,
                                0,
                                0.70529249725476029,
                                0,
                                -0.30812035444161912,
                                0,
                                -0.30072488688345711,
                                0.31642371414854081,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11725154410130537,
                                0,
                                0.42163373066630472,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22464458318837383,
                                0,
                                0,
                                -0.69212879399044958,
                                0,
                                0,
                                0,
                                -0.38643319239507068,
                                0,
                                0.11518404410341254,
                                0,
                                -0.049392722750334427,
                                0.33753814463311871,
                                0,
                                0.59429753355387138,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.012614964483898095,
                                0,
                                0,
                                -0.57245923325360226,
                                0,
                                0,
                                0.8689151565041946,
                                0,
                                0,
                                0,
                                -0.14022520487534523,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44023489089206425,
                                -0.29697356188078317,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76805472263057684,
                                0,
                                -0.0082884202593354814,
                                0,
                                -0.8004333971196409,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20345703205948334,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4429194796088986,
                                -0.1787748946880586,
                                0,
                                0.52178303500517176,
                                0,
                                0.32221823814474937,
                                0,
                                0,
                                0.44685511583589277,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39851721522737144,
                                0,
                                0.42429940834763608,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14913216513928879,
                                0,
                                0,
                                -0.5791455352692616,
                                0,
                                0,
                                0,
                                -0.47412511932357476,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12647836027319359,
                                0,
                                0,
                                0,
                                -0.56926045503480605,
                                0,
                                0,
                                0,
                                0,
                                -0.058029790474977437,
                                -0.48701011846711761,
                                0.011836539236381456,
                                0.44077566435515114,
                                0,
                                0.013473229820722531,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68438559713032476,
                                0,
                                -1.0573584502829689,
                                0,
                                0,
                                -0.67836585559471596,
                                0,
                                0,
                                0,
                                -0.63856404656349908,
                                0.54597102868380187,
                                0,
                                -0.21738320626396462,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17216768159756826,
                                0,
                                0,
                                -0.2401741613769808,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.042542446468392975,
                                0,
                                0.40304541271749333,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.82629614158376463,
                                0,
                                0,
                                0.25623013788357218,
                                0,
                                0,
                                0,
                                0,
                                -0.73511225792081392,
                                0,
                                0.0036112067768986761,
                                0,
                                0,
                                0.0083446470308945475,
                                0,
                                0,
                                0,
                                0.12258666944251349,
                                1.4314972787423601,
                                0,
                                -0.35819709706595404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33004768812913615,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.055389136589291253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13601717996763746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32317028918197038,
                                0,
                                -0.62915469354016407,
                                0,
                                -0.13589495106989241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24814112868525268,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53800136214704763,
                                -1.2996311629817219,
                                0,
                                -0.18435429481110813,
                                0,
                                0,
                                0,
                                0.57177336916750621,
                                0,
                                0.20775173176461112,
                                0,
                                0,
                                0.21519015600378874,
                                0,
                                0,
                                0,
                                0.089403308123961078,
                                0.72306418727969268,
                                0,
                                0.86059406608980116,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5130441693056873,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.91685130442973695,
                                0,
                                0.34673917022456524,
                                0,
                                0.24081595860681354,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46305163229104984,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13325794157920895,
                                -0.13813571691677132,
                                0,
                                0.28881214165068658,
                                0,
                                0,
                                -0.62412449314459872,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50932564636452315,
                                0,
                                0,
                                0,
                                0.53792256567641517,
                                0,
                                0,
                                0,
                                0,
                                -0.18621120861511598,
                                -0.096910574619972725,
                                -0.11683491432559859,
                                0.042498494820998906,
                                0,
                                -0.046610335698191604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19971223321008866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.071920430234345967,
                                0,
                                -0.614273248173137,
                                0,
                                -0.13369420273473892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.89476658691828392,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85789520139239595,
                                0.22769029871401483,
                                0,
                                0.24097314100318448,
                                0,
                                0,
                                0,
                                -0.27907979214894613,
                                0,
                                -0.047619530571228808,
                                0,
                                0,
                                -1.3949519102784751,
                                0,
                                0,
                                0,
                                0.16055403842148916,
                                0.0036155949379053087,
                                0,
                                0.15718893533391862,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5613914512180509,
                                0,
                                -0.87028349812632899,
                                0,
                                0,
                                -0.2447736934359438,
                                0,
                                0,
                                0,
                                0.14360864696108869,
                                -0.38627943066405257,
                                0,
                                1.1619000802602946,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44607482978672552,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66933792252909796,
                                0,
                                0,
                                0,
                                0.28584803911507156,
                                0,
                                0,
                                0,
                                0,
                                0.19989122142954829,
                                0.14605189492298185,
                                0.3851809387226468,
                                -0.11870631145431654,
                                0,
                                -0.21806349965021843,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19349165850762634,
                                0,
                                0.43233540878489457,
                                0,
                                0,
                                0.2033761495434776,
                                0,
                                0,
                                0,
                                -1.4678630578094545,
                                -0.21142522125092394,
                                0,
                                0.8016666805047743,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17625999496529773,
                                0,
                                0,
                                0.0087020624426436544,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87934332706284346,
                                0,
                                -0.3621329314726387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.018644453238612024,
                                0,
                                0,
                                0.25322741901419765,
                                0,
                                -0.19431580806186149,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25308341169911613,
                                0,
                                -0.065630244854885222,
                                0,
                                -0.035574919282749952,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.043643019422696355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36030663240921113,
                                0.45019852150781159,
                                0,
                                -1.1902919065675892,
                                0,
                                0.16158454333721509,
                                0,
                                0,
                                0.64169493223177954,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.067568316223054314,
                                0,
                                0.2518294133812814,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11425342086806622,
                                0,
                                0,
                                0.69359979406089844,
                                0,
                                0,
                                0,
                                0.15072748121151627,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35709567066256048,
                                0,
                                0,
                                0,
                                0.19609681195300141,
                                0,
                                0,
                                0,
                                0,
                                -0.34777918815062214,
                                -0.0013548268891896004,
                                -0.59862947340421502,
                                0.29681146745632797,
                                0,
                                -0.4938658277661746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26606478777661891,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.070415172935824111,
                                0,
                                0,
                                0,
                                0.19259102614310913,
                                0,
                                0,
                                0,
                                0,
                                -0.66043754591456838,
                                -0.40723703915827875,
                                0.53267568481808447,
                                -0.036701747207550622,
                                0,
                                0.0070545881797124815,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.094261722833640316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36119365462906849,
                                0,
                                0,
                                0,
                                0.13954814744756722,
                                0,
                                0,
                                0,
                                0,
                                -0.092313190761485531,
                                -0.29873118087801448,
                                -0.42838885473464328,
                                -0.37531303088822504,
                                0,
                                0.64733396355774397,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22286434098673796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.080381212326824075,
                                0,
                                0,
                                0,
                                0.42830340192668881,
                                0,
                                0,
                                0,
                                0,
                                0.31790219643679096,
                                -0.081762914243644763,
                                0.098557893448727688,
                                0.70712442689862109,
                                0,
                                0.37807532053379106,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37426435174787431,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30573173232490214,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18608654640284811,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084733380538259184,
                                0,
                                0,
                                0,
                                0.16251151847401107,
                                0,
                                0,
                                0,
                                0,
                                0.50526209173720948,
                                -0.68580536220868626,
                                -0.050138236223912148,
                                -0.24390697312348958,
                                0,
                                -0.37968253499856791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.898852410515662,
                                0,
                                0,
                                -0.3393150284329835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.059967066253914875,
                                0,
                                -0.16348644332893486,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10720995018444807,
                                0,
                                0,
                                0.18738147182608289,
                                0,
                                -0.50077600446327397,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18263549666996653,
                                0,
                                -0.26703203928822505,
                                0,
                                0.023855079111147703,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68037918142674392,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1087661724185365,
                                0.16437835821320529,
                                0,
                                0.20841209261010779,
                                0.38904014035505546,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12051337259709309,
                                0,
                                0.57020556960118696,
                                0,
                                -1.0989169717263629,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72420491648880536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.078097016516577578,
                                0.095546791415732024,
                                0,
                                -0.065547389565174058,
                                0,
                                0.037694695379227913,
                                0,
                                0,
                                0.46438569874079272,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24076535501112672,
                                0,
                                -0.66048336596008161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51971035249403741,
                                0,
                                0,
                                -0.13645493531647909,
                                0,
                                0.84631930836281111,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.095244571738278147,
                                0,
                                -1.0569546665794951,
                                0,
                                -0.52920135909930099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.030485943001907184,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13608213173398206,
                                0.58866105860981777,
                                0,
                                0.21057835578254547,
                                0.11095931531557696,
                                0,
                                0,
                                0,
                                -0.27688427630455298,
                                0,
                                0,
                                0,
                                0,
                                -0.65978297927850849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.069134069594284808,
                                0,
                                0,
                                0,
                                0,
                                -0.4235621415532918,
                                0.3180781288488605,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27145133687727285,
                                -0.34156348817467197,
                                0,
                                0.066301766368769305,
                                0,
                                0,
                                0,
                                -0.55823188315414618,
                                0,
                                0,
                                0.26410460966947447,
                                0,
                                0,
                                0,
                                -0.18371608357243044,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6714478732538729,
                                0,
                                0,
                                0,
                                0,
                                -0.71278453885633142,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5654614297870324,
                                0,
                                0,
                                0,
                                0.47299616622823643,
                                0.46950143011280188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30567375843772449,
                                0,
                                0,
                                0.31468549910959276,
                                0,
                                0,
                                0,
                                0,
                                -0.14897957165927544,
                                0,
                                0,
                                1.1387119311907414,
                                -0.34077451776801643,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.075007263517366252,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42111292498739061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35392172309523495,
                                0,
                                0,
                                0,
                                -0.515841529626343,
                                0,
                                0,
                                0,
                                0,
                                -0.28085839548049846,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.036913736402406333,
                                0,
                                0,
                                0,
                                0,
                                0.39676299687845556,
                                -0.13889920079553561,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14311707228006465,
                                0.575505436929451,
                                0,
                                1.6564189759910231,
                                0,
                                0,
                                0,
                                -0.34602115483331664,
                                0,
                                0,
                                -0.62387671970495484,
                                0,
                                0,
                                0,
                                0.24958346534467124,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42249370991064489,
                                0,
                                0,
                                0,
                                0,
                                -0.43047232547658454,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23494810422029966,
                                0,
                                0,
                                0,
                                0.8078603162324387,
                                -0.0566447600499475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42233260684096141,
                                0,
                                0,
                                0.33187907147978324,
                                0,
                                0,
                                0,
                                0,
                                -1.035189969431531,
                                0,
                                0,
                                -0.43756333154810267,
                                0.17219805508488167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43513025214364176,
                                0,
                                0,
                                0,
                                -0.71419625195006464,
                                -0.093531424329600196,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57835623467675701,
                                0,
                                0,
                                0.59552567642522658,
                                0,
                                0,
                                0,
                                0,
                                -0.57959133817791364,
                                0,
                                0,
                                0.037979395773915708,
                                0.65805920985026556,
                                0,
                                0,
                                0,
                                0,
                                0.59089538125757268,
                                0,
                                0,
                                0,
                                -0.58045826350219842,
                                0,
                                0,
                                0.85950873438926889,
                                0,
                                0,
                                0,
                                -0.05399792396402997,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43930352055805089,
                                0,
                                0,
                                0,
                                0,
                                0.90367278941092577,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068777450412033786,
                                0,
                                0,
                                0,
                                -0.097133155809437377,
                                0,
                                0,
                                0,
                                0,
                                -0.20085160383525757,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.090040813804144845,
                                0,
                                0,
                                0,
                                0,
                                0.29384781675121974,
                                -0.7382137061701286,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10344391199478487,
                                -0.54348821434133487,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51646465917309758,
                                0.24815565591223149,
                                0,
                                -0.0065962861178673338,
                                0,
                                0,
                                0,
                                0,
                                -0.092091759497718625,
                                0,
                                0,
                                0,
                                0,
                                -0.088669476581650794,
                                0,
                                0,
                                0,
                                -0.80950376591390094,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31029094883910829,
                                -0.63293851525441291,
                                0,
                                0.060458788617297116,
                                0,
                                0,
                                0,
                                0,
                                0.46350629217394212,
                                0,
                                0,
                                0,
                                0,
                                0.24794270763484388,
                                0,
                                0,
                                0,
                                -0.47237636340195976,
                                0,
                                0,
                                0,
                                -0.045431314967880332,
                                0,
                                0,
                                0,
                                -0.54290163596428187,
                                0,
                                0,
                                0.11286094480309494,
                                0,
                                0,
                                0,
                                1.4752463557287963,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.011273799832218434,
                                0,
                                0,
                                0,
                                0,
                                -0.45405900556413697,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.020794321179444963,
                                -0.20672759669814961,
                                0,
                                -0.94314244297233751,
                                0,
                                0,
                                0,
                                0,
                                -0.24946886803322615,
                                0,
                                0,
                                0,
                                0,
                                0.054014243544845353,
                                0,
                                0,
                                0,
                                -0.046490586259620714,
                                0,
                                0,
                                0,
                                0,
                                -0.35611108454146195,
                                0,
                                0,
                                0,
                                0.20599265905973435,
                                0.35244413906704208,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39997303283060343,
                                0,
                                0,
                                0.36045513742935587,
                                0,
                                0,
                                0,
                                0,
                                -0.055146340608992345,
                                0,
                                0,
                                0.41556178810493205,
                                1.255148958873743,
                                0,
                                0,
                                0,
                                -0.50815849088658571,
                                0,
                                0,
                                0,
                                -0.34237376154023291,
                                0,
                                0,
                                0,
                                0,
                                0.083251881065442013,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25788986554279197,
                                0,
                                0,
                                0,
                                0,
                                -0.54336707477827006,
                                -0.4027198858237237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0043059707027568381,
                                0.3060514194108333,
                                0,
                                0,
                                0,
                                -0.099075051247958512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34758057625832789,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41123231250649894,
                                0,
                                0,
                                0,
                                -0.086884793090740847,
                                -0.032553858510236323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40538059916221503,
                                0,
                                0,
                                -0.99035589842412985,
                                0,
                                0,
                                0,
                                0,
                                -0.62832423890370148,
                                0,
                                0,
                                0.26404904561113879,
                                0.12997912251065014,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49250677771243567,
                                -0.080570778685422034,
                                0,
                                -0.21411186208413252,
                                0,
                                0,
                                0,
                                0,
                                0.70648939956388701,
                                0,
                                0,
                                0,
                                0,
                                -0.37730445819316533,
                                0,
                                0,
                                0,
                                0.2522213475810956,
                                0,
                                0,
                                0,
                                -0.44432559888739964,
                                0,
                                0,
                                0,
                                -1.5391522347768161,
                                0,
                                0,
                                -0.61844884874790773,
                                0,
                                0,
                                0,
                                -0.42029968451354138,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14270863139990086,
                                0,
                                0,
                                0,
                                0,
                                0.19634203131604389,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20396033500286856,
                                0,
                                0,
                                0,
                                -0.15943662861191932,
                                0,
                                0,
                                0,
                                0,
                                0.082344508791652726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.91377767340623139,
                                0,
                                0,
                                0,
                                0,
                                -0.10624847721610403,
                                0.048196739810060785,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25933206997877228,
                                0.10171087208359106,
                                0.54695562231802275,
                                0,
                                0,
                                0,
                                0.46621182587713977,
                                0,
                                0,
                                0,
                                0,
                                0.0056291026510370094,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.057662295881135202,
                                0,
                                0,
                                0,
                                0,
                                -0.42697335853445323,
                                -0.38436518335803765,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32662741115215099,
                                0.2083294138427485,
                                0,
                                0,
                                0.14497747931107999,
                                0,
                                0,
                                0,
                                -0.4345907297786023,
                                0.44293073755937767,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3142064232417685,
                                0,
                                0,
                                0.22033670776520925,
                                0,
                                0,
                                0,
                                0,
                                -0.67768044645177961,
                                0,
                                0,
                                -0.23534801629743385,
                                -0.38581391953095756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62757923556105055,
                                0.4702739595990999,
                                0,
                                -0.17529074563820418,
                                0,
                                0,
                                0,
                                0,
                                0.26474004067133744,
                                0,
                                0,
                                0,
                                0,
                                -0.47976717675069869,
                                0,
                                0,
                                0,
                                -0.23237045312861176,
                                0,
                                0,
                                0,
                                0.060093969186805568,
                                0,
                                0,
                                0,
                                -0.35635685003160483,
                                0,
                                0,
                                0.6468782922934081,
                                0,
                                0,
                                0,
                                -0.46156949901935362,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.705232319482894,
                                0,
                                0,
                                0,
                                0,
                                -0.15278130224732364,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.91387318434626086,
                                0,
                                0,
                                0,
                                -0.017804747996224765,
                                -1.0597195369572807,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28838624959367931,
                                0,
                                0,
                                0.14361303603980602,
                                0,
                                0,
                                0,
                                0,
                                -0.47174370431327284,
                                0,
                                0,
                                0.27626550840196551,
                                0.34820823513828575,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0799478239640217,
                                0,
                                0,
                                0,
                                -0.51350075952605223,
                                0.62463331190153426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38454399760875602,
                                0,
                                0,
                                0.021310606336632024,
                                0,
                                0,
                                0,
                                0,
                                -0.48698051602002113,
                                0,
                                0,
                                0.13019423561783741,
                                -0.29108241162329218,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.01152198335135543,
                                0.51712866837444371,
                                0,
                                -0.17381835680105562,
                                0,
                                0,
                                0,
                                0,
                                0.38109283383343312,
                                0,
                                0,
                                0,
                                0,
                                0.74512374884172239,
                                0,
                                0,
                                0,
                                0.042322736168260225,
                                0,
                                0,
                                0.1593917620889421,
                                0,
                                0,
                                0,
                                -0.33895113821875611,
                                0,
                                0,
                                0,
                                0,
                                0.61033403532516539,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22176847225180812,
                                0,
                                0,
                                0,
                                0,
                                0.031388764013536616,
                                0.12287720953836836,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59595999584639037,
                                -0.25838947799344686,
                                -0.4830176496351769,
                                0,
                                0,
                                0,
                                0.41584443253304321,
                                0,
                                0,
                                0,
                                0,
                                -0.24333680337604266,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17817826331812994,
                                0,
                                0,
                                0,
                                0,
                                0.29495707632303725,
                                0.085042371915102222,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60498395526855564,
                                0.20632400890221028};

const double rot_30_2[32]
    = {0.29517804222022836,  -2.2387622348196201,  -1.0856511466548657,  -1.9292939555970912,  0.18150495907172931,
       0.98339002935375008,  0.98339002935375019,  -0.18150495907173009, -0.35612024941750303, -0.93444013610012244,
       -0.93444013610012244, 0.35612024941750298,  0.9531012507192469,   0.30265162460724881,  0.3026516246072487,
       -0.95310125071924701, -0.22542943970377105, 0.97425949711298387,  -0.97425949711298299, -0.22542943970377277,
       -0.9948391354907602,  -0.10146474508910669, -0.10146474508910663, 0.99483913549076008,  0.66056278175397565,
       -0.75077081147408076, 0.75077081147408042,  0.66056278175397554,  0.10924797288730878,  -0.99401452726809469,
       0.99401452726809458,  0.10924797288730884};

const double rot_29_50[25000] = {0.21213851585677088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12319668061762618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13471445967659451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36351139762558088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75455088830929606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61759412118972157,
                                 0,
                                 0.32101859697663609,
                                 0,
                                 0,
                                 0.47044187733725468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65161249285700851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097626603953933744,
                                 0.18043375259860334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43712710848539049,
                                 0,
                                 -0.19742626661099816,
                                 0,
                                 0,
                                 0,
                                 0.2439369185749086,
                                 0,
                                 -0.18184520246108565,
                                 -0.09749354387307109,
                                 -0.230990807667942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38447624676899472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26736684084066392,
                                 0,
                                 0,
                                 0.38053713653109278,
                                 0.16249823479461165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37020649826907209,
                                 -0.034181023788841192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32621897486719093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58054901716240748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41907470597578933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36354240335735205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15601351725527404,
                                 0,
                                 0,
                                 0,
                                 -0.85000139980220113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021555749828090442,
                                 0,
                                 0.24157465325063499,
                                 0,
                                 0,
                                 -0.15493591456719186,
                                 0,
                                 0,
                                 -0.20961302689371708,
                                 -0.51219043721336455,
                                 0,
                                 0,
                                 -0.86040561856606668,
                                 0,
                                 0.30955654221628848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16037705170075903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0216999812188436,
                                 0,
                                 0,
                                 0,
                                 0.43604117766073058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47931628865291998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29410845970706045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8258705140602538,
                                 0,
                                 0,
                                 0,
                                 0.066228979336603711,
                                 0,
                                 0,
                                 0.23242564632279628,
                                 -0.477915583580238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33017543232181895,
                                 -0.73370774188421684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23382636524351602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052921058470591087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091490229403168311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46090059557981627,
                                 0,
                                 0,
                                 -0.045760425988823676,
                                 -0.052355588174058082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098019670547560778,
                                 -0.27161610730949504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77306987558839935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040106320585990701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31639658932582765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44812006089852086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16680374485833982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47568722722367468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31812845891642394,
                                 0,
                                 0.63059559849760094,
                                 0,
                                 0.21501176330774405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086761888210248495,
                                 0,
                                 0,
                                 -0.18162219435275628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49573245110459735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17791456542220693,
                                 -0.30326910856770717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32988391648507631,
                                 0,
                                 0.027765283085212353,
                                 0,
                                 0,
                                 0,
                                 0.45836938917971559,
                                 0,
                                 -0.016818087437763807,
                                 -0.49076210985614543,
                                 0.12878920384354395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23067256083353066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0051085740502883354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41619746140966646,
                                 0.10285751915067291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64770905883877072,
                                 0,
                                 -0.01114987918318873,
                                 0,
                                 0,
                                 0,
                                 0.059728602503510461,
                                 0,
                                 0.025109473763276102,
                                 0.22159764646980029,
                                 0.44931267592615337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37594836392158598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19065975358153242,
                                 0,
                                 0,
                                 0.24342204566671913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47705346236030072,
                                 0,
                                 0,
                                 0.27064660497534482,
                                 0.39595135327011211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11958482782334488,
                                 -0.098325135681153114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0020191172974340019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074128129924914479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71618818426154829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45061021272165536,
                                 0,
                                 0,
                                 -0.26184204435438374,
                                 0.26219658126098366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73885303462033058,
                                 0.16451371869447931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18453809409037408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13289721539063337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18696947435039646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23471394857470079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34273050449864029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63417533026738226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11384158535997256,
                                 0,
                                 0.60728705694404372,
                                 0,
                                 0.20858892113869745,
                                 0.85610523143012796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72359379751529995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15460875959187195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41331958386469947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45797344756408986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013020762863903218,
                                 0,
                                 0.25608422780506918,
                                 0,
                                 0,
                                 -0.74573259897388799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66465093444482304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15510773343170842,
                                 0,
                                 0,
                                 0,
                                 0.54723863163821773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60370518474786172,
                                 0,
                                 0.20435556514948278,
                                 0,
                                 0,
                                 -0.96499792234588566,
                                 0,
                                 0,
                                 -0.30857368999147028,
                                 0.057785055555740775,
                                 0,
                                 0,
                                 -0.062381457860871695,
                                 0,
                                 0.027233678324038491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31216142961648319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21913477898664527,
                                 0.54478099943603686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28500991546971777,
                                 0,
                                 0.55319677596656669,
                                 0,
                                 0,
                                 0,
                                 -0.080380684264906799,
                                 0,
                                 0.11791876064718265,
                                 0.20839968601243347,
                                 -0.27909767579179395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16970473775934203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20398420722424315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19981676137867035,
                                 0,
                                 0,
                                 0,
                                 0.20368663742012727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3927226576311158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93001898562827479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55943600360492474,
                                 0,
                                 0,
                                 0.058816456066411865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36608289998674964,
                                 -0.45370260067319218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15063645197347539,
                                 0,
                                 0.031869518523652926,
                                 0,
                                 0,
                                 0,
                                 -0.26856743230213093,
                                 0,
                                 0.31828299797037368,
                                 0.30718712353249911,
                                 -0.085291114721449651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5982473088083291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30531018565397638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91576876086499015,
                                 0,
                                 0,
                                 0,
                                 -0.54755985914921257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15602533875743815,
                                 0,
                                 -0.49500497373135854,
                                 0,
                                 0,
                                 -0.05632957049292063,
                                 0,
                                 0,
                                 -0.13086416709006471,
                                 -0.37670694209226574,
                                 0,
                                 0,
                                 0.39949460275431148,
                                 0,
                                 -0.20621181853456633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44388670399217645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30638634804781301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51523045808660872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44834759149861664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53221062686289233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52813796496683718,
                                 0,
                                 -0.33096497012535453,
                                 0,
                                 0,
                                 -0.11444301482319036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42304383505163778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81733830760730342,
                                 0,
                                 0,
                                 0,
                                 -0.025292008703500124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.99388223708530299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16100562064625662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49402979364922595,
                                 0,
                                 0,
                                 -0.1162278459336098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42564292529608461,
                                 0.13589533852585445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11387581863707891,
                                 0,
                                 0.021539211453272991,
                                 0,
                                 0,
                                 0,
                                 -0.11415250778351566,
                                 0,
                                 0.03922169108691323,
                                 0.14567152628827751,
                                 0.77681723681077508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36631360359561471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45717406262494326,
                                 0,
                                 0,
                                 0.49235254017358682,
                                 0.5582246908503794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32770636049535068,
                                 -0.20254687410950756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23774728462472605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059595280970381123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16874235802432228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12285478023288476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3022399580004283,
                                 0.079771537003349213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011193788093469416,
                                 0,
                                 0.1462634227841999,
                                 0,
                                 0,
                                 0,
                                 -0.42231494542515352,
                                 0,
                                 -0.7511979613755605,
                                 -0.26374414726144518,
                                 0.093147576254818454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21163692123176325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1168806795240849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30260146359610063,
                                 0.1169399881326023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3283058148544955,
                                 0,
                                 0.058705011418493186,
                                 0,
                                 0,
                                 0,
                                 0.65670676437398545,
                                 0,
                                 -0.30444641125992877,
                                 0.44994712032635409,
                                 0.044541164607572306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20366049098424185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043470159463092434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4592484757573897,
                                 -0.52573909123174856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20179811058884392,
                                 0,
                                 0.18135398434383793,
                                 0,
                                 0,
                                 0,
                                 -0.032842561268867275,
                                 0,
                                 -0.42165969064021669,
                                 0.4492445221517079,
                                 -0.11005529545139991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21066444490056618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77639429025426054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69193380153425288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47108777652870082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80696580795366479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18469686154672435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23396524604251173,
                                 0,
                                 -0.46379224397041685,
                                 0,
                                 0,
                                 0.11896804748627897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0104228898297702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.278902766905818,
                                 0,
                                 0,
                                 0,
                                 0.53571889699412978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12102107081455743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42120067386689247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53922804790688483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.006531156202595461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11150341254696065,
                                 0,
                                 0,
                                 0,
                                 0.19246687831262202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36656476600663279,
                                 0,
                                 -0.61008045200929029,
                                 0,
                                 0,
                                 0.56523993410215145,
                                 0,
                                 0,
                                 -0.22602000950371873,
                                 -1.0519610200317087,
                                 0,
                                 0,
                                 -0.068861873916374272,
                                 0,
                                 0.45215650074454805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21806296596031274,
                                 0,
                                 0,
                                 -0.082118363016051188,
                                 -0.13041841857157935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17276563514944943,
                                 0.10283803096515924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36783447617042969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78326075169516785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3734607357171657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29672583450444129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1627973464600079,
                                 0,
                                 0,
                                 0,
                                 -0.45676519219284872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15686803249441811,
                                 0,
                                 0.58762852446470637,
                                 0,
                                 0,
                                 -0.51373112522480768,
                                 0,
                                 0,
                                 0.71902300692152832,
                                 -0.79762679578236884,
                                 0,
                                 0,
                                 0.4833968137362189,
                                 0,
                                 -0.34666961492401782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42961297430950124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16899906916982479,
                                 0.21760482126825428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12266738247797924,
                                 0,
                                 -0.77129295787858143,
                                 0,
                                 0,
                                 0,
                                 -0.15656353470061762,
                                 0,
                                 -0.12036966988496081,
                                 0.26017967821929511,
                                 -0.12956483452526202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078093059604345566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3311711899149512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50332338636346086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18330406685382897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29169955490306543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22476592891399894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61056223325668602,
                                 0,
                                 -0.7122715334911206,
                                 0,
                                 0,
                                 0.74125869993990723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11272252908412241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19953060395234654,
                                 0,
                                 0,
                                 0,
                                 -0.37596536971746947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84347714744685731,
                                 0,
                                 -0.34934992243332541,
                                 0,
                                 0,
                                 0.098007122439959168,
                                 0,
                                 0,
                                 0.30001997057230229,
                                 0.63160602811839417,
                                 0,
                                 0,
                                 0.080243867510721226,
                                 0,
                                 0.50010058949262259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15655729075860655,
                                 0,
                                 0,
                                 0.63883526806938717,
                                 -0.43393734603932177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21651724066523442,
                                 0.54625617121660019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12403636805456969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13545490440143462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0083140164368586816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6427917946954631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67293601262658065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070735638584502575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061961201529412521,
                                 0,
                                 -0.2714884168966723,
                                 0,
                                 0.22677554985588133,
                                 0,
                                 0,
                                 0,
                                 0.040892568310464644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28913581248586867,
                                 0,
                                 0,
                                 0,
                                 0.42237563430558611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67587220403965831,
                                 0,
                                 0.11499034879265718,
                                 0,
                                 0,
                                 -0.25083277353766892,
                                 0,
                                 0,
                                 0.61252981688401897,
                                 0.015029072121708561,
                                 0,
                                 0,
                                 -0.14425825362983158,
                                 0,
                                 0.80665270536188682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63835173974050241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90563996352145149,
                                 0,
                                 0,
                                 0,
                                 0.80078369500938418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21309094790317418,
                                 0,
                                 -0.26143470824417314,
                                 0,
                                 0,
                                 0.57254728600502358,
                                 0,
                                 0,
                                 0.16152290919806006,
                                 -0.00070067619800274344,
                                 0,
                                 0,
                                 -0.60600076714634332,
                                 0,
                                 -0.068780395997396812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48749992395193009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57782560270260441,
                                 0,
                                 0,
                                 0,
                                 -0.048015265110042893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63047156573040319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79955695119182391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24509075384664825,
                                 0,
                                 0.084860627082058757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52323240528244452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66393441606740622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81462937397112267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21466771757561556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096873546863485704,
                                 0,
                                 -0.52033742687043782,
                                 0,
                                 0,
                                 -0.45563759771203738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64708602903143952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059557590291974966,
                                 0,
                                 0,
                                 0,
                                 -0.12159508598290808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020733446852321036,
                                 0,
                                 0.19978729611709395,
                                 0,
                                 0,
                                 -0.38273363202232669,
                                 0,
                                 0,
                                 -0.59720604308635372,
                                 0.084486291022014826,
                                 0,
                                 0,
                                 0.63298144464207318,
                                 0,
                                 0.2793530341710162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029751070881257793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32604774767101896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72994901675656076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1889182714920834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23368141502169332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35445681061667955,
                                 0,
                                 0.24962451246287609,
                                 0,
                                 0,
                                 -0.086407963354285827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25479127168861015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41016626800624834,
                                 0,
                                 0,
                                 0,
                                 -0.067283604275766323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16398215176706479,
                                 0,
                                 -0.61173440178549221,
                                 0,
                                 0,
                                 -0.87969266045552674,
                                 0,
                                 0,
                                 0.038841731296742649,
                                 0.089933925646455234,
                                 0,
                                 0,
                                 -0.042295897904510868,
                                 0,
                                 -0.1873807294810674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56330362892711072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42924260000917192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54737147648097872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030265435139702868,
                                 0,
                                 -0.035010950610304861,
                                 0,
                                 0.44348902521157624,
                                 0.12932026466295313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32153052412991967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26847008708466874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11395033413337502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2354214328101023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89128696072379077,
                                 0,
                                 0.022066664223912257,
                                 0,
                                 0,
                                 0.72790496472575505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.008076209273798882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37327777373267507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25321361566103989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43810280869789775,
                                 0,
                                 0.36801828373208739,
                                 0,
                                 -0.6849159183248047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35117251106544201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3422943467666858,
                                 0,
                                 0,
                                 0,
                                 -0.94946178232756628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18654871685162477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15476150132875768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63311019819045167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11636270243629676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27979265335623915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052982198420301496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83014764892881387,
                                 0,
                                 0.15225779878510043,
                                 0,
                                 0.43936445344067954,
                                 0.015764983523150367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46088042563238873,
                                 0.59005075397719375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38858633283358757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30271319836501348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2381688497650292,
                                 0,
                                 0,
                                 -0.41319297695409529,
                                 0,
                                 0,
                                 0,
                                 0.30579914177856216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20226111595701685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43528695276076512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23269075518658497,
                                 0,
                                 0,
                                 0.36566796208953523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54249073909814405,
                                 0,
                                 0,
                                 0,
                                 0.039533418947357291,
                                 0,
                                 0,
                                 0,
                                 -0.015098996626202899,
                                 0,
                                 0,
                                 -0.14638660950824761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63397501836752501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017281958407417169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59304920953411022,
                                 0,
                                 0,
                                 0.46173386567094898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13666446049136102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11913986571099799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10004886461332949,
                                 0.36018804330855747,
                                 0,
                                 0,
                                 0.7231677919201851,
                                 0.2790980234933671,
                                 0,
                                 0,
                                 0,
                                 1.1464489077151228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.036453344109011382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30827576289454611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3170413006575456,
                                 0,
                                 0.31085891809778898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073382347411923426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52084901637766934,
                                 -0.20376512562556784,
                                 0,
                                 0,
                                 -0.45342346257070065,
                                 0.65193909451342258,
                                 0,
                                 0,
                                 0,
                                 0.67742108642167442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061748287138114366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090712009234303878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77630702047953948,
                                 0,
                                 0.80800831566788256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43004995462519641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14504356408412994,
                                 0,
                                 0,
                                 0,
                                 0.24941833125206053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59977919689267378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12849851184920225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44039109193501846,
                                 0,
                                 0,
                                 0.12235242329832786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26936393744661302,
                                 0,
                                 0,
                                 0,
                                 0.16863788162952006,
                                 0,
                                 0,
                                 0,
                                 -0.21935094365250279,
                                 0,
                                 0,
                                 -0.42717792105791574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36604042522545804,
                                 0,
                                 0,
                                 -0.043049423385995517,
                                 0,
                                 -0.52977025843454661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35089215437581267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41777794546128155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19090074408236807,
                                 0,
                                 0,
                                 -0.12618776352081931,
                                 0,
                                 -0.48319195570202483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73275567108438067,
                                 -0.14536699325956848,
                                 0,
                                 0,
                                 0.36938799538611156,
                                 -0.042640193807736315,
                                 0,
                                 0,
                                 0,
                                 -0.50815287298171541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9147685649567564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48809192099271115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00099937600409669494,
                                 0,
                                 0.76866589765106452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8821901880907741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22117806701838905,
                                 -0.069859174196185314,
                                 0,
                                 0,
                                 -0.33478911269785955,
                                 -0.77250217896294693,
                                 0,
                                 0,
                                 0,
                                 0.24907234455035837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11110145144468528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76954418680467529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48757494313494754,
                                 0,
                                 0.60665367223060018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15598601188917358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45940784916812721,
                                 0,
                                 0,
                                 0.27790406298497994,
                                 0,
                                 -0.12773562140930572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083371265391095198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51471189913472637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47904669551522566,
                                 0,
                                 0,
                                 -0.43391858710614417,
                                 0,
                                 0.075810205106559864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35570178664377955,
                                 0,
                                 0,
                                 0,
                                 0.49042686074042857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071377183640147154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29397772929692956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15451695153044517,
                                 0,
                                 0,
                                 -0.27730125057131066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55786488622990205,
                                 0,
                                 0,
                                 0,
                                 -0.11303349630452923,
                                 0,
                                 0,
                                 0,
                                 0.22665807256148734,
                                 0,
                                 0,
                                 -0.25554836971626727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09215079332834164,
                                 0,
                                 0,
                                 -0.16794474737118212,
                                 0,
                                 0.3927976533968679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45445579951974202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.089638010902177365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52590170854011853,
                                 0,
                                 0,
                                 0.40555147601243591,
                                 0,
                                 -0.39166713309698387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12600723103000488,
                                 1.1944982020995416,
                                 0,
                                 0,
                                 0.040315897170592224,
                                 0.2245845368414735,
                                 0,
                                 0,
                                 0,
                                 -0.48945724690188019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2789023345048669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10603071364992397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57902442106714302,
                                 0,
                                 0.22006067819478242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44727438585981549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075556635865214661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18270249110290854,
                                 -0.19871470380313414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069965406472822622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0874280164391217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82233198156929999,
                                 0,
                                 -0.035634589185573329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61157148595770683,
                                 -0.76578298094865416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61146402050172666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4760105666731963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17844628216062761,
                                 0,
                                 0,
                                 0,
                                 0.30639960173390057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35277317903986799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69597534699776953,
                                 0,
                                 0,
                                 0.4788474197958365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18540895218415182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1833503574678581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19912938888519435,
                                 0,
                                 0,
                                 0,
                                 0.088339615506458358,
                                 -0.0417196833942041,
                                 -1.3134887813517473,
                                 0.27241832087569373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38254514122351785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36868285013033852,
                                 0,
                                 -0.69281277247769557,
                                 0,
                                 0,
                                 0,
                                 0.080109369938796207,
                                 -0.20756604468835932,
                                 0,
                                 0,
                                 1.0130345482949081,
                                 0.39926728017589941,
                                 0,
                                 0,
                                 0,
                                 -0.5770135336339276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55447061620868521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66975738223384296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42341987668423198,
                                 0,
                                 0.03906736534013483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18444251265005998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084244311643338732,
                                 0,
                                 0,
                                 0,
                                 0.41809236556454027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43744927186636989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16559330099006092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13748244552089633,
                                 0,
                                 0,
                                 0.15314389428028538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027241082464152626,
                                 0,
                                 0,
                                 0,
                                 0.06086237661691847,
                                 0,
                                 0,
                                 0,
                                 0.21938421979729705,
                                 0,
                                 0,
                                 0.71020310227716077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0902656948307166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24104215018959479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71644342150701235,
                                 0,
                                 0,
                                 0,
                                 0.47905795088204017,
                                 0.70226716605080175,
                                 -0.038927348052476163,
                                 0.11476422219686343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055599667454289306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.99640297415161083,
                                 0,
                                 -0.39921087893466733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24171269437560133,
                                 0,
                                 0,
                                 0,
                                 0.33480831415284229,
                                 0.98257920779018382,
                                 0.69184849208436006,
                                 -0.064465164173508366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0170799974444842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56291971357673432,
                                 0,
                                 -0.11240587176523412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0122866071354515,
                                 0,
                                 0,
                                 0,
                                 0.50108273245824186,
                                 -0.39676359371207609,
                                 0.2900417195895959,
                                 0.082384876128119094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41381921786143938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023952050595480556,
                                 0,
                                 -0.5795847526353477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19003471386019202,
                                 0,
                                 0,
                                 0,
                                 -0.1932629850097296,
                                 0.09412448349406749,
                                 -0.12157323221307798,
                                 1.4345534127414667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41149712106591446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80914932265775907,
                                 0,
                                 0.39715738571919457,
                                 0,
                                 0,
                                 0,
                                 0.72594290438069542,
                                 0.2020427688202395,
                                 0,
                                 0,
                                 0.8827221883268116,
                                 -0.027698766750124754,
                                 0,
                                 0,
                                 0,
                                 -0.4234584526771078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30077103750216083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47489374091361869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12234457942133714,
                                 0,
                                 0.37929746672693265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67532056263704354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10238719739990212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7506390014542581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16541882624052379,
                                 0,
                                 0,
                                 0.14162600404443693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61531697682046627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0046536270245725528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1850015108261702,
                                 0,
                                 0,
                                 0,
                                 -0.49830542311328418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33849679029537966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42346494498470255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016438298942872812,
                                 0,
                                 0,
                                 -0.093610683696583846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024288256840143803,
                                 0,
                                 0,
                                 0,
                                 0.57383170982387444,
                                 0,
                                 0,
                                 0,
                                 0.28695180196251813,
                                 0,
                                 0,
                                 0.048127378623970318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34783137668442349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9084379197495982,
                                 0.052285588875976452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71822412420411674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096313963326899302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60177938202879622,
                                 0,
                                 0,
                                 0,
                                 -0.37829465604210266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015685269172967198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29110963186103889,
                                 0,
                                 0,
                                 0.36488880019301634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043501982947194817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79803887671720131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17129342254139984,
                                 0,
                                 0,
                                 0,
                                 -0.31703191404256348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098447090410432092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21327672338734677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54695862872726686,
                                 0,
                                 0,
                                 0.31096725272692938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040226892287079,
                                 0,
                                 0,
                                 0,
                                 -0.59758959089608077,
                                 0,
                                 0,
                                 0,
                                 0.14321209930239376,
                                 0,
                                 0,
                                 0.1996620577843321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27172697354105024,
                                 -0.35471333286214435,
                                 0,
                                 0,
                                 0.024625316197311231,
                                 0.23973874560701267,
                                 0,
                                 0,
                                 0,
                                 -0.16725178634125598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62382457729064311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3957329579998306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75220391142362275,
                                 0,
                                 0.45740885398870873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16027519650031954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2624852230932887,
                                 0,
                                 0,
                                 0.69996852011424548,
                                 0,
                                 -0.13496290162892563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52527363112823167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.331124544079752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1693675655854206,
                                 0,
                                 0,
                                 0.089686133742796659,
                                 0,
                                 0.025411957459545192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28469003171687035,
                                 0.083684457663663586,
                                 0,
                                 0,
                                 0.55758181844941124,
                                 -1.0252020662861339,
                                 0,
                                 0,
                                 0,
                                 0.38618164923401277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2756306489788139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82336920613330888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.055608447664287255,
                                 0,
                                 -0.41654419436390605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5071352012545125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1586618782438115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38699084644956094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15635769190038501,
                                 0,
                                 0,
                                 0.52650722892712787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66389339305086736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28749341886531266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44467592537791867,
                                 0,
                                 0,
                                 0,
                                 -0.14348343122087534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060767365963408981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48143369452285589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025816582127013835,
                                 0,
                                 0,
                                 0.58023687057986995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36034892868424689,
                                 0,
                                 0,
                                 0,
                                 0.21676219160355975,
                                 0,
                                 0,
                                 0,
                                 0.0031035377220258453,
                                 0,
                                 0,
                                 -0.17893182895790297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33145632783109014,
                                 0,
                                 0,
                                 0,
                                 -1.0068979996139535,
                                 0.38738592475398026,
                                 0.37821747778230624,
                                 0.37037767671702992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3560632194943113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3601759868302063,
                                 0,
                                 -1.2795616682800754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5471897480572141,
                                 0,
                                 0,
                                 -0.56935446112631372,
                                 0,
                                 -0.11536247170595881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40408434907264673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10279127224298668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33073956038207153,
                                 0,
                                 0,
                                 -0.022984534472001855,
                                 0,
                                 0.28167929440611089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20991536795670415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076649697592321764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2516285122730868,
                                 0,
                                 0,
                                 0,
                                 -0.052570204730965707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044309068568864574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45393657697100342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044794310241666926,
                                 0,
                                 0,
                                 -0.35224531466410497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41525336199048524,
                                 0,
                                 0,
                                 0,
                                 -0.099488728594008966,
                                 0,
                                 0,
                                 0,
                                 0.61728159627351531,
                                 0,
                                 0,
                                 -0.190904513104621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61204345365867419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0042195171933274572,
                                 -0.82638310718652708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97091837608781928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48547527375253707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24070022576192765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0733835387865889,
                                 -0.43248202858159107,
                                 0,
                                 0,
                                 0.18749380899477769,
                                 0.2280951960805882,
                                 0,
                                 0,
                                 0,
                                 0.066680208462390866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38672772961677632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13953574594413506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49011822208385919,
                                 0,
                                 -0.13989122943108778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64892969344017692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50304191546422183,
                                 0,
                                 0,
                                 -0.059538563339773795,
                                 0,
                                 0.17547685993334838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47117208822222056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042069543893110392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23737978304333193,
                                 0,
                                 0,
                                 -0.41105698536216351,
                                 0,
                                 0.51334381513137906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54951559076384726,
                                 0,
                                 0,
                                 0,
                                 -0.045608271022134522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083721251349236595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1314295240759909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2675813135681836,
                                 0,
                                 0,
                                 -0.41350005103855053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12690592362909203,
                                 0,
                                 0,
                                 0,
                                 0.11850567578477393,
                                 0,
                                 0,
                                 0,
                                 -0.56468633020427628,
                                 0,
                                 0,
                                 0.28296311005290692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57046593548951741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40222576329057802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1653935240232306,
                                 0,
                                 0,
                                 -0.35650436492000442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35452010361638359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48233615656238249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050452794297955739,
                                 0,
                                 0,
                                 0.24762383124029086,
                                 0,
                                 0.62374666043094773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035063802106096616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54543859158600905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49760374032150434,
                                 0,
                                 0,
                                 0.016252659878277287,
                                 0,
                                 0.021695589554364486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21914628981989709,
                                 0,
                                 0,
                                 0,
                                 -0.23389930306067022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51571471497735732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015789118112287018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57916063638108572,
                                 0,
                                 0,
                                 -0.11734699752389699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024323210109597926,
                                 0,
                                 0,
                                 0,
                                 -0.44293788856405159,
                                 0,
                                 0,
                                 0,
                                 -0.22222954678934836,
                                 0,
                                 0,
                                 -0.1889077353840721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1501842222898315,
                                 0,
                                 0,
                                 0.11716572397658598,
                                 0,
                                 -0.3120281691165892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031059599571383795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36471312441522469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12436192956695787,
                                 0,
                                 0,
                                 0.67343553724672167,
                                 0,
                                 0.51321890064508058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95276449563266785,
                                 0,
                                 0,
                                 0,
                                 -0.54432983445502048,
                                 0.52935332434445437,
                                 -0.22379518714250046,
                                 -0.73621282533172239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38311534223170551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83101258540285672,
                                 0,
                                 0.26155583483647477,
                                 1.1936170492143017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65529609164313674,
                                 0.18125047457549545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075027950675541799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32411239755055171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026840453858859664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86275708125050987,
                                 0,
                                 0,
                                 0,
                                 1.11459124612531,
                                 0.69389250652676093,
                                 -0.14885570956087535,
                                 0.098308459850750193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40674810083821356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36265262169997742,
                                 0,
                                 0.095273230633163092,
                                 -0.65979547329259436,
                                 0.29272765325712069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045309450634814452,
                                 0,
                                 0,
                                 0.0049557698563532336,
                                 0.24206603236814464,
                                 0.070373857932336359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044647870093566966,
                                 0,
                                 0,
                                 0.016486706792014888,
                                 -0.10326142283946178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63279249309009544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19260089038952183,
                                 0.47612803507746043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43684433385719118,
                                 0,
                                 0,
                                 -0.43224912586341857,
                                 0.33426607648467932,
                                 -0.20802706593188494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20055966135240674,
                                 0,
                                 0,
                                 0.35849758632459983,
                                 0.16548856687262659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08599115899332134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33572653374455336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46293829274257925,
                                 0.23247102016475366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1307435968368226,
                                 0,
                                 0,
                                 0,
                                 -0.20401324227317172,
                                 -0.47805252569670231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57189266382847981,
                                 0,
                                 0.067987712371716746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09550903516600702,
                                 0.14887625144151145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34895727306635621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19375229597420707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89533638798632587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088178839212123855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57925738799600102,
                                 0.57593849081796655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28915597762826428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28166508970786081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17635604199424038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37243506486393652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027379494660877968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24002084694528636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0938554837633205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13794846485395759,
                                 0,
                                 0,
                                 0.19611160687011522,
                                 0.25100512614081705,
                                 0,
                                 0,
                                 0,
                                 -0.093870838228908432,
                                 0.20827601262347939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89301458058083205,
                                 0,
                                 0.75391269719912579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73195100376965994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2267584302136503,
                                 0,
                                 -0.86148671118109132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32698135607880219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0040673433117509941,
                                 0,
                                 1.1072446624475616,
                                 -0.00073642778872398673,
                                 -0.32511185947283372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26383187068718766,
                                 0,
                                 0,
                                 -0.054724934336027604,
                                 -0.1494423479732794,
                                 0.37526778965454632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38595497265825451,
                                 0,
                                 0,
                                 0.68734258072335908,
                                 -0.054794728294688733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18476256739907534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45634754758256157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23785357443108932,
                                 0.56532921559229321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09668027657952824,
                                 0,
                                 0,
                                 0,
                                 0.25118976507734408,
                                 -0.42622417351761471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3855716161761138,
                                 0,
                                 -0.11313522746253225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040536574872032022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26801908263594049,
                                 -0.018293753730399799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023260230037759538,
                                 0,
                                 0,
                                 0,
                                 0.48030600698630543,
                                 -0.2009061432637492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15179850751130286,
                                 0,
                                 0.79469927147492314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29152092150562448,
                                 -0.20931886696535676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51512842751586108,
                                 0,
                                 0,
                                 0.15419237867739419,
                                 -0.13347850567794689,
                                 -0.16634846292486724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1034197084463179,
                                 0,
                                 0,
                                 -0.23263218775882905,
                                 0.68645136775598903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023481993389864193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16866769404746129,
                                 0.1884830933849867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35205279721174598,
                                 0,
                                 0,
                                 0.01097904626222064,
                                 0.45642763997239999,
                                 0.42735924729783448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40926979851041972,
                                 0,
                                 0,
                                 -0.086552743689578909,
                                 0.49375635072343149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047042798990664297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5263450894534516,
                                 0.25427591303073782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056738693353072578,
                                 0,
                                 0,
                                 0.57499666909527669,
                                 -0.15262681649837723,
                                 -0.055195862574736389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14360744530008826,
                                 0,
                                 0,
                                 0.097133338738171204,
                                 0.12362924102617612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50277276838547758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16570188845675737,
                                 -0.388058911846489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21122108105154525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69387228123593403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26806629295744344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47330808141240877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39435616830951237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32370521181874323,
                                 -0.27698016065253883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23662733115881512,
                                 0,
                                 0,
                                 0,
                                 0.49703707585924112,
                                 0.19322738279267279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50572546824952302,
                                 0,
                                 -0.25854732571690292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62602150562622516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1333500644025027,
                                 0,
                                 0.89433043103336296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30563322304253271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16996026719272028,
                                 0,
                                 0.12281959946386328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56492894449621733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19576845060356163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59900600509201729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39823573585453637,
                                 0,
                                 0,
                                 0.063195693726804114,
                                 -0.094367649376611198,
                                 0,
                                 0,
                                 0,
                                 -0.22930560056628876,
                                 -0.93013224798682359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064717383827439259,
                                 0,
                                 -1.1320213279975471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57137375351236508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035958345428370279,
                                 0,
                                 0.189163140616908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23626779008745366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0205101499241742,
                                 0,
                                 -0.38231522331985868,
                                 0,
                                 0,
                                 -0.45792923276815306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17209398896483097,
                                 0.34146170049939389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70339161008538453,
                                 0,
                                 0,
                                 0,
                                 0.12768379160809984,
                                 0.33070252022780666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079775778030777983,
                                 0,
                                 0.13151860859679199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18219039612177956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50070819973238911,
                                 0.62005901492237481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10185784168266915,
                                 0,
                                 0,
                                 0,
                                 -0.078134098071944977,
                                 0.28544123481694195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46384177423662343,
                                 0,
                                 -0.13608427183427863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031258052448651277,
                                 0,
                                 -0.10568133510758321,
                                 0,
                                 0,
                                 0,
                                 -1.0661068618175966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19891157250631047,
                                 0,
                                 0,
                                 0.54612579402261907,
                                 0,
                                 0,
                                 0.70309551307889695,
                                 -0.89593443388246397,
                                 0,
                                 -0.19812797855891898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69200011100610359,
                                 0.23068599093076519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10166838309606213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57036863382112823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0074369110800385774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3636037317480002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64841631917579845,
                                 0,
                                 0.29916149095573819,
                                 0,
                                 0,
                                 0,
                                 -1.1327790285808708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14811994100906484,
                                 0,
                                 0,
                                 -0.51944189570383248,
                                 0,
                                 0,
                                 -0.75677235486270655,
                                 0.17002202936801952,
                                 0,
                                 0.77700514983088442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1753849086645424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8745596503650569,
                                 0,
                                 -0.40708671226245419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091290293840257164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33861925822081584,
                                 0,
                                 -1.0512069222241309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34895327836462914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61726555053226217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64128142419377732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34754839897811823,
                                 0,
                                 0,
                                 0.00094688597705447353,
                                 -0.21672320230112424,
                                 0,
                                 0,
                                 0,
                                 0.70229516393521774,
                                 0.582761530166227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70666411183443345,
                                 0,
                                 -0.34306885996338399,
                                 0,
                                 0,
                                 0,
                                 0.37853965381878074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47481641616521758,
                                 0.1130439903069749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17692683536401047,
                                 0,
                                 0,
                                 0,
                                 -0.35840894475436408,
                                 0.4744661353404932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03706986646558913,
                                 0,
                                 0.48189811407150429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53906489142977798,
                                 0,
                                 0.86325291532290849,
                                 0,
                                 0,
                                 0,
                                 0.14423323000946386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61872313634872589,
                                 0,
                                 0,
                                 0.46377201584357031,
                                 0,
                                 0,
                                 -0.79313191222793256,
                                 -0.49923480575222701,
                                 0,
                                 0.69535946029694529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36836098706737397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21614543726447927,
                                 -0.18830616910164943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61691784034119046,
                                 0,
                                 0,
                                 0,
                                 -0.51640829212055595,
                                 -0.3100639735900052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15028217609708422,
                                 0,
                                 0.12705342876818024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14865630180614325,
                                 0.6650068172874215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0014511173183784087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0025207474654670992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19590594764644265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7051805702528029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37111572796873132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97289350553502063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22611516036195928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17353104799428831,
                                 0,
                                 0,
                                 -0.31492886434366218,
                                 0.89579748075089904,
                                 0,
                                 0,
                                 0,
                                 0.23932343895163211,
                                 -0.41433799116201997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7156829829233412,
                                 0,
                                 0.034424922578806055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42034622412763578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087966563074725529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068242437480811435,
                                 0.38028171098131625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07172481837113534,
                                 0,
                                 0,
                                 0.18607564814560973,
                                 -0.092851389719884797,
                                 -0.43071882593060062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73325663122519535,
                                 0,
                                 0,
                                 -0.0092441152427993334,
                                 -0.23964609365630934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14710239605662012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070119925517991122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18306961507500202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12164763826647676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95617149764021203,
                                 0,
                                 0,
                                 -0.49082446456475881,
                                 -0.45805918450990191,
                                 0,
                                 0,
                                 0,
                                 0.96465664766508297,
                                 -0.86809725020473016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021652752350449944,
                                 0,
                                 0.22144883057609177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74974498235608378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78348693546187176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4422890560112932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15370423072761058,
                                 0,
                                 0,
                                 0.33406092321001624,
                                 0.67327069590260857,
                                 0,
                                 0,
                                 0,
                                 0.68553392907266386,
                                 0.0085149702914542255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12259597519042,
                                 0,
                                 -0.3345321035433137,
                                 0,
                                 -0.057715580200143661,
                                 -0.22555880243374446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29577956073301648,
                                 0,
                                 0,
                                 0.53954616813058187,
                                 0.65327620660550201,
                                 0.029257627141256688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089435631455905426,
                                 0,
                                 0,
                                 0.043038488847098405,
                                 -0.26595834551134478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24286997807243099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059269785390439922,
                                 -0.42641125496202936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39257616371525622,
                                 0,
                                 0,
                                 -0.082379448683695761,
                                 0.27999315841273842,
                                 -0.64107153417820051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053780204935765102,
                                 0,
                                 0,
                                 0.27814972868465021,
                                 0.18588332058943369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22265903243187013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19954383111145141,
                                 0,
                                 -0.24118739875910222,
                                 0,
                                 0,
                                 0,
                                 -0.026364729043541271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95792334736897911,
                                 0,
                                 0,
                                 -0.10208161324053319,
                                 0,
                                 0,
                                 -0.61091817724267905,
                                 -0.090306904268859275,
                                 0,
                                 -0.99084342382433344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5021902924763193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81670506370472462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09519801925276089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4439840493862387,
                                 0,
                                 0,
                                 -0.78937535996235841,
                                 0.86304451592539655,
                                 0,
                                 0,
                                 0,
                                 -0.21376517755102609,
                                 0.16777468889880642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083496929887441285,
                                 0,
                                 -0.259441511125589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41832420911335483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077345199869571724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065999434073645183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32633077701297764,
                                 0,
                                 0,
                                 0.44150039680761843,
                                 0.59533549314355738,
                                 0,
                                 0,
                                 0,
                                 -0.25741921943663049,
                                 -0.76780072963592794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78813949591006272,
                                 0,
                                 0.62702447203033074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14907144338940725,
                                 0,
                                 0.56347392914022154,
                                 0,
                                 0,
                                 0,
                                 0.070396486352948068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0447345401372072,
                                 0,
                                 0,
                                 0.30775101559609153,
                                 0,
                                 0,
                                 0.93402719554461866,
                                 0.6695718209345366,
                                 0,
                                 0.23678342921708992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17704592424236149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052348114800034401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35440213078358818,
                                 0.24617245608355204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3134374499825589,
                                 0,
                                 0,
                                 0.3508614093699135,
                                 -0.21002907452627761,
                                 -0.015639619653665074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24787964165822768,
                                 0,
                                 0,
                                 0.49841630325547714,
                                 0.25678093095674809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41508445342300593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79343505498566302,
                                 0,
                                 0.84556206030225722,
                                 0,
                                 0,
                                 0,
                                 0.12660383755629212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21271778614483738,
                                 0,
                                 0,
                                 0.13594889817283831,
                                 0,
                                 0,
                                 0.13571251430158962,
                                 -0.18561854118340201,
                                 0,
                                 -0.31270208470909511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62752085682977021,
                                 0,
                                 -0.42164658995580839,
                                 0,
                                 0,
                                 0,
                                 0.065138748783127975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78370306679270252,
                                 0,
                                 0,
                                 -0.23387351215448263,
                                 0,
                                 0,
                                 0.27310650766574729,
                                 -0.85627377101921198,
                                 0,
                                 0.10400552198899046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35625684150123388,
                                 0.0095343608653917777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86003763361408314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27629576500963904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23869921116358273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0029604799546976007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55310850851418569,
                                 0,
                                 0.85758436657713999,
                                 0,
                                 0,
                                 0,
                                 0.15480732314179158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21568525232499489,
                                 0,
                                 0,
                                 -0.97215665824700859,
                                 0,
                                 0,
                                 0.1979984181538692,
                                 -0.67759607845007697,
                                 0,
                                 -0.18562631423725739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80268820462309842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23311795766544396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96234046958652164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55045474155145502,
                                 0,
                                 0,
                                 -0.11802720789557392,
                                 0.039670325606391388,
                                 0,
                                 0,
                                 0,
                                 -0.65422789406940418,
                                 0.022855212683092804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5227356469581651,
                                 0,
                                 0.25262825290406271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0084515657195187721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50832368305598363,
                                 0,
                                 -0.029777710376916622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0750975879846161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72772462030999974,
                                 0,
                                 -0.82456763651797882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1886857001014739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093181910941152052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15472088218215582,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1470001665267027,
                                 0,
                                 0,
                                 0.46381774412860316,
                                 -0.15149684120889886,
                                 0,
                                 0,
                                 0,
                                 -0.52021048329801434,
                                 0.062125010083496413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62560848325129215,
                                 0,
                                 -0.5789202243476016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2789428599172419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30904571901444822,
                                 0,
                                 0.409860084184551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37503856430837634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8579041485785539,
                                 0,
                                 -0.19870508942298767,
                                 -0.062272241205324347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17586860365660317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16236576110080086,
                                 0,
                                 0,
                                 0,
                                 0.041753217186666844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24404801977399715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3508895309721487,
                                 -0.23628330810424542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83580723262587309,
                                 0,
                                 0,
                                 0.64276282392774009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27533709975576837,
                                 -0.2860134159632256,
                                 0,
                                 0.18520889760946657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056556495329501723,
                                 0,
                                 0,
                                 1.2881517230579416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88762900102492837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25826299389387974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30893912889573194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2485476043766178,
                                 0,
                                 0.23138817949346688,
                                 0,
                                 0.26431953122469948,
                                 -0.07017421848025561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61387948885419552,
                                 0,
                                 0,
                                 -0.15630766777913213,
                                 0,
                                 0,
                                 0,
                                 -0.64811920570827264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019217048468149589,
                                 -0.65348467044180736,
                                 0,
                                 0,
                                 0.48256292054601257,
                                 -0.041250251743080592,
                                 -0.23596258663151226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11646502894549786,
                                 0,
                                 0,
                                 -0.054628462486333518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28843182663458944,
                                 -0.25257209845984957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34468483761845098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2709338186680833,
                                 0.079156676611238888,
                                 0,
                                 0,
                                 0.35267725254799975,
                                 0.10184330328769493,
                                 -0.012187789646500198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31428970002923168,
                                 0,
                                 0,
                                 0.28937811573618738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13661169696790407,
                                 0.76376858539301318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03007198282096608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31766518205484373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11717462503892659,
                                 0.237466089853271,
                                 0.88136131723379996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13697539674231479,
                                 0,
                                 0.81459270816915519,
                                 0,
                                 0,
                                 0,
                                 0.13718758673481588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14216337698451648,
                                 0.58368382214539394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050444384639515671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17178557316845805,
                                 0,
                                 0,
                                 0,
                                 0.4636320301149478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17235320034866791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44893660166236604,
                                 0.21876936812543432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36495737136571982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09052558878981623,
                                 -0.15098303452960765,
                                 0,
                                 0,
                                 -0.16899999967326237,
                                 -0.63279758393158303,
                                 0.3712882869302353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47058409282635072,
                                 0,
                                 0,
                                 0.17765837905572482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21705906177493162,
                                 -0.13653371949317528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28877757184472197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51853530463331421,
                                 -0.45066090725437286,
                                 0,
                                 0,
                                 -0.39813109200720398,
                                 0.11461024296475483,
                                 0.048711360518744251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11363961704140971,
                                 0,
                                 0,
                                 0.37222978335901802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41627829783331077,
                                 0.0055589175043878336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17094360669822697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13827098156256312,
                                 0.05557382810498207,
                                 0,
                                 0,
                                 0.053475567412048786,
                                 -0.63175635864605051,
                                 -0.42445497715931263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043754393983910657,
                                 0,
                                 0,
                                 -0.12197396472506661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52912980287714195,
                                 0.2096890709080507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23433944362329501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11917656401122495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4027886076695546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45152399713828295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23088654366611172,
                                 0,
                                 -0.70465121827068156,
                                 0,
                                 -0.14110459423890306,
                                 -0.1056141128435963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22182924921435468,
                                 0,
                                 0,
                                 -1.423804116681157,
                                 0,
                                 0,
                                 0,
                                 -0.019697017410884039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49638147456008264,
                                 0.12337149765504625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74770585648142673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16700726600424598,
                                 0,
                                 0,
                                 0.29044362327590206,
                                 0,
                                 -0.25898249412548729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025365923521633034,
                                 -0.24777391282185623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31264701904928721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42052953234861362,
                                 0,
                                 0,
                                 0.27055248758409689,
                                 0,
                                 0.76822702595858494,
                                 0,
                                 0,
                                 -0.048241842278276242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43470112176365944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087557415844442904,
                                 0,
                                 0,
                                 0,
                                 -0.70794424259976008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15355034039200618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33859901923387381,
                                 0.19882463895288344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34942533934465392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36103695700547545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40278439361865453,
                                 0.28212720910765365,
                                 -0.45174476009546954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43912011622510988,
                                 0,
                                 1.1724383942908732,
                                 0,
                                 0,
                                 0,
                                 0.12826246721006451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.004042121885588057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75012047827976958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039949132784081187,
                                 0.32687669994168583,
                                 -0.17550992765747722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45264530569824962,
                                 0,
                                 -0.33646614275767123,
                                 0,
                                 0,
                                 0,
                                 0.75452785321577043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039296976784471416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11477086512342041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55832443764833717,
                                 -0.64947908236284835,
                                 -0.064310127977944193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066991875816355934,
                                 0,
                                 0.85509758770943078,
                                 0,
                                 0,
                                 0,
                                 0.054922565984341906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67361263645692959,
                                 0.67044622946030485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3653021198680611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041329873528341193,
                                 0,
                                 0,
                                 0,
                                 -0.18288526266681426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11692768372128988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4627579146364893,
                                 -0.36812062601144369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13627644991556553,
                                 0,
                                 0,
                                 0,
                                 0.34207120415350983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79752648094076284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50148730956663867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71758266235186086,
                                 0,
                                 0.48780971151076691,
                                 0,
                                 -0.29448946499273271,
                                 0.14111028343275983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21482469467239246,
                                 0,
                                 0,
                                 -0.064212959287977586,
                                 0,
                                 0,
                                 0,
                                 0.01976904089046181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24871457714117851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26299168354877828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68054178249742925,
                                 -0.12292956376071114,
                                 0,
                                 0,
                                 -0.37002057423177054,
                                 0.19972965632488057,
                                 -0.01340988827020851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3277478722699983,
                                 0,
                                 0,
                                 0.3365711035408282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041309349807075325,
                                 0.11538567935174318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33021981415080714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24061327527947285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082310370533063087,
                                 0.90472134913738556,
                                 0,
                                 0.16749431428100595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1300119319956299,
                                 0,
                                 0,
                                 0.3309950095842154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71209011769005015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76540744309142306,
                                 0.29952705142037495,
                                 0,
                                 -0.83018653759471406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47849213582541367,
                                 0,
                                 0,
                                 0.33844634683843022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23382938775720399,
                                 -0.43224393938516364,
                                 0,
                                 0,
                                 -0.087180868809580675,
                                 0.022099861900732379,
                                 -0.37444098517504354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2007942299098488,
                                 0,
                                 0,
                                 0.051308858346866444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034042017443006736,
                                 0.24419685074545086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71165451769033217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37324352294371921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.99281950844232736,
                                 -0.0008427437916755931,
                                 0,
                                 -0.67134672059601652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47161866847950124,
                                 0,
                                 0,
                                 0.94854433824080797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80173890825397631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29726636149783381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26261945309629375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92540475162035762,
                                 0,
                                 0.094965312688495146,
                                 0,
                                 -0.26602341778231209,
                                 0.060372087307937111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48703300809123307,
                                 0,
                                 0,
                                 0.089846858001204427,
                                 0,
                                 0,
                                 0,
                                 0.58523175462595822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.460482938241142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3494810172113747,
                                 0.095337763400522552,
                                 0.74631345192219856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012737090915393316,
                                 0,
                                 0.26551557142863991,
                                 0,
                                 0,
                                 0,
                                 -0.027098714480601475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70880825773722644,
                                 0,
                                 0,
                                 0.16853435732575367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34410160347912355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18584393111024861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23126626160853686,
                                 0,
                                 -0.40642671917851964,
                                 0,
                                 -0.65150623119531037,
                                 0.74156266022856787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79751367966139486,
                                 0,
                                 0,
                                 0.28327558825048926,
                                 0,
                                 0,
                                 0,
                                 -0.27403063763554325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18808307220251216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090979120528396115,
                                 -0.11263150300732991,
                                 0.073804778124895914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0464069984354607,
                                 0,
                                 -0.26976405899032074,
                                 0,
                                 0,
                                 0,
                                 0.75349913264552315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078276364164407461,
                                 0,
                                 0,
                                 -0.43793564704254528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40716076974839749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095970357243509524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59113235947955778,
                                 0,
                                 0.54912426023006145,
                                 0,
                                 -0.34325566354039971,
                                 0.017419105946664154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63356427568192175,
                                 0,
                                 0,
                                 -0.33224356803517285,
                                 0,
                                 0,
                                 0,
                                 0.31072607723792089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17217333068641677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015092671402918346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33920284734701717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79526201913855288,
                                 0,
                                 -0.3232603098701522,
                                 0,
                                 0.29626767625122497,
                                 -0.53466587051458248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63872177530891439,
                                 0,
                                 0,
                                 0.1500109679564523,
                                 0,
                                 0,
                                 0,
                                 0.75783298406622834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30089717873786481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19427640910124816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2930709360175488,
                                 0,
                                 0,
                                 0,
                                 0.29734371745122301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79864471717220886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22317648889847963,
                                 0.029223198775987475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094438233981634256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0413074164385663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30289469914153649,
                                 0.67310208034167485,
                                 -0.089096577068307231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1537030963312744,
                                 0,
                                 0.099936142828141783,
                                 0,
                                 0,
                                 0,
                                 -0.44128787358213006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048035808463792684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2831526043822345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20332966320625537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26170699921446183,
                                 0.10500324125829583,
                                 0,
                                 0,
                                 -0.51741443801428932,
                                 -0.14929270007210316,
                                 -0.41878886007759109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10368924574690538,
                                 0,
                                 0,
                                 -0.16754679341949488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58895541274776753,
                                 0.14045612412012148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22287632652528028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17141613600770811,
                                 -0.046637389384387197,
                                 0,
                                 0,
                                 -0.15912470716511631,
                                 0.32992130372923612,
                                 -0.20412842483386834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6773703012529968,
                                 0,
                                 0,
                                 -0.5070987489580302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21915728760481096,
                                 -0.07111235437137553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15342020547744961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35387730352645619,
                                 -0.14946265237884132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31372541243412488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75385495428909322,
                                 0,
                                 0,
                                 -0.28319162775983997,
                                 0,
                                 0.32482817772834588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60021458221756263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55963084137290187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23172113291832128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078368190739636023,
                                 0,
                                 0.013727696549457796,
                                 0,
                                 -0.85391600641984922,
                                 -0.95926417515117046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071602817561014581,
                                 0,
                                 0,
                                 -0.37392124628804485,
                                 0,
                                 0,
                                 0,
                                 0.13861835678289602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23183780419778094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40745503010091977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032587109180054252,
                                 0,
                                 0,
                                 0,
                                 0.23972630665118758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13907530454424427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43293865377993423,
                                 -0.71748884856197237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011530096410687529,
                                 0,
                                 -0.23091609443630026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58658684133474148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54097636064861188,
                                 0,
                                 0,
                                 0,
                                 0.22577899995843403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22812474158130641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33055487572051245,
                                 0.30207121509190837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080047565416543398,
                                 0,
                                 0,
                                 0,
                                 0.20700019942956371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2454913480200468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96345445259672879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20304357206603202,
                                 0,
                                 -0.7267004093802516,
                                 0,
                                 0.33087561950430522,
                                 0.33807767393444338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39326520210359361,
                                 0,
                                 0,
                                 -0.51186853825639389,
                                 0,
                                 0,
                                 0,
                                 0.38092875678698657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11977318900985361,
                                 0.35009312773480677,
                                 0,
                                 0,
                                 0.12356649339366263,
                                 0.061034868181014224,
                                 -0.51608613580552376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18455651781261459,
                                 0,
                                 0,
                                 0.57196774560886976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 5.9574336981171871e-05,
                                 -0.43873929822282148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15508051610356544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43266879947932757,
                                 0.81058058769767016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27927417190395265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23476729765317098,
                                 0,
                                 0,
                                 -0.14031499208224218,
                                 0,
                                 0.054394638171633744,
                                 0,
                                 0,
                                 0,
                                 -0.23774255135133754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71535735051304838,
                                 -0.64053348868979398,
                                 0,
                                 -0.57363107942975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8369994025627735,
                                 0,
                                 0,
                                 0.38173519983942955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17361278517754275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061320236719075827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60250040790047277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32107741873542428,
                                 0,
                                 0.85686613087919083,
                                 0,
                                 0.17702417605995716,
                                 0.39063751031204169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68826133193473604,
                                 0,
                                 0,
                                 -0.89315058902709255,
                                 0,
                                 0,
                                 0,
                                 0.071819047617396659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56341937185907454,
                                 -0.48038756009283312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35682638529862104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30318270982174655,
                                 0,
                                 0,
                                 -0.0072451128555335864,
                                 0,
                                 -0.48217122174739874,
                                 0,
                                 0,
                                 0,
                                 -0.7431161234255993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2575605592393842,
                                 -0.24002873287529292,
                                 0,
                                 1.025888362953306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083446281508756354,
                                 0,
                                 0,
                                 0.31846415857386334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3508406718972879,
                                 -0.11504512241261622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19860772119454601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28272027489375873,
                                 0,
                                 0,
                                 -0.86168762696456636,
                                 0,
                                 0.0423567649124671,
                                 0,
                                 0,
                                 0.077458501790940895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31027060310098231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74508033188011047,
                                 0,
                                 0,
                                 0,
                                 0.22762204274771103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40530103108225907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0053039947871445703,
                                 0.33819353540085939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11001778269198292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57165895977097891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29360675783751766,
                                 -0.63571100159799476,
                                 0.074786640460066278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26873732680985885,
                                 0,
                                 0.14519685159542978,
                                 0,
                                 0,
                                 0,
                                 -0.17590727439734377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3156812800329165,
                                 0.11209061074067728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76796847369842758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084070520081270805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6163636077707525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054162682131012566,
                                 0,
                                 0,
                                 0,
                                 -0.088060052932938879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093194602790404424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20134775739168004,
                                 -0.23615036193035377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017576877351164921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099049779004929506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013120369451055318,
                                 0.73408675390768807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53192571936552613,
                                 0.94759995940659225,
                                 0.83570586306530847,
                                 0,
                                 0,
                                 0.25986596676324647,
                                 0,
                                 0,
                                 -0.81363363103134556,
                                 0,
                                 0,
                                 0,
                                 -0.1040344657633154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080909934942261827,
                                 -0.056796747527693668,
                                 0,
                                 0,
                                 0.088639751738332245,
                                 -0.19174835406848451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15222636257254862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33106817520208404,
                                 -0.26920456280363247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59136301845149675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50112926076515774,
                                 0,
                                 0,
                                 -0.28786353616567761,
                                 0.40482788100271261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027232023451520038,
                                 0,
                                 0,
                                 0,
                                 0.72895506379198571,
                                 0,
                                 0,
                                 -0.60815522671975564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073279869576218279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43947582365426546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22883068231695525,
                                 0,
                                 0,
                                 0,
                                 0.57406901273073541,
                                 0,
                                 0,
                                 -0.19909816181165946,
                                 0,
                                 0,
                                 0,
                                 -0.31275594125227196,
                                 0,
                                 0,
                                 0,
                                 -0.5315689269742998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013825515196064862,
                                 -0.06876963032981441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34839033079806431,
                                 0,
                                 0,
                                 0.33801945511692277,
                                 0,
                                 0,
                                 0,
                                 -0.12974016712357117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018204439811487644,
                                 -0.017710793362362205,
                                 0,
                                 0,
                                 0.40245621121827113,
                                 -0.42512334239661215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17009751605599879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43087651485704026,
                                 0.43543179299500379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36351034081521411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78672145343890387,
                                 -0.18041290692302714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47546861859416173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16005377355119457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074696377467896591,
                                 -0.6234035540052093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19144462201027301,
                                 -0.14438162409605257,
                                 0.82736770591965125,
                                 0,
                                 0.328304299075039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29281691355565026,
                                 -0.15666502827482437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11111178563064854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78092142692594813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58305409733293956,
                                 -0.6623525321619782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42736212507403054,
                                 0.48300035145076514,
                                 0.4289755249282593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38216765365915512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078757607327582455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00053405109660468325,
                                 0,
                                 0,
                                 0.035832741031176368,
                                 0,
                                 0,
                                 0,
                                 -0.55482355024012175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49367528606001904,
                                 -0.11459723759332065,
                                 0,
                                 0,
                                 0.19786156485070097,
                                 0.56938735081444591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20790478825848777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15980128016465267,
                                 -0.043894628286111882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40510030913436457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35280562872785648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062418249191246333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55397630363680861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61433234461478292,
                                 0,
                                 0,
                                 0,
                                 0.15242019359022602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39382446667452592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48132589544696935,
                                 0,
                                 0,
                                 -0.4793042445682949,
                                 -0.88277348079278728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5641799871629577,
                                 0,
                                 0,
                                 0,
                                 0.27885764245348515,
                                 0,
                                 0,
                                 -0.33171620846355249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42973321259338298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21698854959052274,
                                 -0.71153283603279893,
                                 0,
                                 0,
                                 -1.2465049645121342,
                                 0,
                                 0,
                                 0,
                                 0.57890560976947392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0030663295422688336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34247757796557721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076561917682356123,
                                 0.4058507432387386,
                                 0,
                                 0,
                                 -0.37077834514003483,
                                 0,
                                 0,
                                 0,
                                 0.20048543439759797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57720362667816172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.4034083681816873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19764996710657651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46990416676515701,
                                 0,
                                 0,
                                 0.55422340046085972,
                                 -0.033377902759999079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28057169302760576,
                                 0,
                                 0,
                                 0,
                                 0.27695409187015008,
                                 0,
                                 0,
                                 0.55467585714933887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5726597810599352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39797716229041402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16452075088348783,
                                 0,
                                 0,
                                 0.021032177804489099,
                                 -0.20415645239927932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3151792647300913,
                                 0,
                                 0,
                                 0,
                                 -0.15597852621263439,
                                 0,
                                 0,
                                 0.29247217306356477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66707499154666139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063139331041929841,
                                 0.7686437014759937,
                                 0,
                                 0,
                                 -0.60011737628721429,
                                 0,
                                 0,
                                 0,
                                 -0.57954375388014079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68985270974611357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09721273306691991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29393822404727704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32126927780233416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015675356053682588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33629985222258857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76369709803868613,
                                 0,
                                 0,
                                 0,
                                 0.33735709069062708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31256890080647298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.484778238813801,
                                 0,
                                 0,
                                 0,
                                 0.073690048231435323,
                                 0,
                                 0,
                                 0.4304512979625939,
                                 0,
                                 0,
                                 0,
                                 0.06513739945028299,
                                 0,
                                 0,
                                 0,
                                 0.33014870364600918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60268400738330041,
                                 0.01015569856337916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15370428003139569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42533707946263599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0192526768971479,
                                 0.30019785967458124,
                                 0,
                                 0,
                                 -0.50954549877940181,
                                 0,
                                 0,
                                 0,
                                 -0.21219163357005871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0215996969648726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29780764231668488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073836208472811748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47944105953334432,
                                 0.099846085073731605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34469860031214572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61375222117898254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.074954455948911605,
                                 0.058134516457347664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78722319610267599,
                                 0.42095267260569647,
                                 0.59362048823887215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049795813359957974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39625700081376769,
                                 0,
                                 0,
                                 0,
                                 0.18129775678862967,
                                 0,
                                 0,
                                 -0.062429995626324689,
                                 0,
                                 0,
                                 0,
                                 0.68337778682988992,
                                 0,
                                 0,
                                 0,
                                 -0.10912836020258497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29280608032304117,
                                 0.48896297007057649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55539971050890502,
                                 0,
                                 0,
                                 -0.022887545749860193,
                                 0,
                                 0,
                                 0,
                                 -0.030737392128723902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15228367871838885,
                                 0.46290864451191233,
                                 0,
                                 0,
                                 0.17916800261411037,
                                 0.34719891179519596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54551242319155491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047464723823616509,
                                 0.010141064883098176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25327796902398614,
                                 0,
                                 0,
                                 -0.018623384444950708,
                                 0,
                                 0,
                                 0,
                                 -0.55141405557703504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31305735677544411,
                                 0.027224066224651549,
                                 0,
                                 0,
                                 -0.60436472938472952,
                                 -0.040952031443166739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19933658140558669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21125049755431838,
                                 0.28531435374152192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53264215021895556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16932279472525558,
                                 0,
                                 0,
                                 0,
                                 0.12276208944357395,
                                 0,
                                 0,
                                 0.03070897066580084,
                                 0,
                                 0,
                                 0,
                                 0.017551158058930899,
                                 0,
                                 0,
                                 0,
                                 -0.45551621759975991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61832099067781277,
                                 0.28545515296497598,
                                 0,
                                 0,
                                 0,
                                 -0.40505939600184065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041514801566029567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82977425672936411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039736268048060311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029217676778885482,
                                 0,
                                 0,
                                 0,
                                 0.37847780145742072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061584515311645896,
                                 0,
                                 0,
                                 -0.095796171690957652,
                                 0,
                                 0,
                                 0,
                                 0.23625983883442753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089523686200484759,
                                 0.5920214207395037,
                                 0,
                                 0,
                                 0.16037116454133105,
                                 0.075374646379974444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66020104046710748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30979123465422242,
                                 0.097322175664570409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014931505417161671,
                                 0,
                                 0,
                                 0.34280457803683151,
                                 0,
                                 0,
                                 0,
                                 -0.33292771413274558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38145806351472317,
                                 0.081313608662856404,
                                 0,
                                 0,
                                 0.26296489426064718,
                                 -0.16153976680010806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1463885435273482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12798472302354452,
                                 -0.69731178430908125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48888133789037014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13724611158583888,
                                 0,
                                 0,
                                 0,
                                 -0.57845908908710286,
                                 0,
                                 0,
                                 -0.14266505166208046,
                                 0,
                                 0,
                                 0,
                                 0.36642857615241398,
                                 0,
                                 0,
                                 0,
                                 -0.43292404502137466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22894985395423778,
                                 -0.11436407565069701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57541438045009496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84851361206517151,
                                 0,
                                 0,
                                 0.70828368833287414,
                                 -0.80537187792530807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23042791924679981,
                                 0,
                                 0,
                                 0,
                                 0.44787075433477352,
                                 0,
                                 0,
                                 -0.11895485434561294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52182211444006754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38019188696917766,
                                 0.64330330008561121,
                                 0,
                                 0,
                                 0.11952484881602279,
                                 0,
                                 0,
                                 0,
                                 1.1225451158929971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13722085225307229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18617458189381286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56544708773280317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1649063571794645,
                                 -0.30307194956902939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36234720129736292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67190792402214683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35261962590004531,
                                 -0.44241611896489352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040248525930919002,
                                 0.16371407500348814,
                                 0.036859338124118304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39774873039678277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68393043277803778,
                                 0,
                                 0,
                                 0,
                                 0.36119522842937268,
                                 0,
                                 0,
                                 0.030861024024315342,
                                 0,
                                 0,
                                 0,
                                 0.16003367450722622,
                                 0,
                                 0,
                                 0,
                                 0.26875400379463926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1069692718790089,
                                 0.36515585451360583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54912619828190268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016288632490406463,
                                 0,
                                 0,
                                 0.33440264815962173,
                                 0.12551766695761138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1763090706798916,
                                 0,
                                 0,
                                 0,
                                 -0.72788311804677575,
                                 0,
                                 0,
                                 -0.5634638800369095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19779862970004775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045030512055319348,
                                 0,
                                 0,
                                 -0.21663687476993976,
                                 0,
                                 0,
                                 0,
                                 -0.044055166298760294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37722278643558571,
                                 -0.44129662488260785,
                                 0,
                                 0,
                                 0.51139809618695786,
                                 0.17813425158645113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024536775507405517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46912779860015907,
                                 0.31323688945219547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14131994585172344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20258388246251924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28787580726601264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36874790119926421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1791195579908213,
                                 0,
                                 0,
                                 0,
                                 -0.82949209301121796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39570135912070148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51914516084932971,
                                 0,
                                 0,
                                 -0.92522177581556198,
                                 0.28727380896699939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29321263847112244,
                                 0,
                                 0,
                                 0,
                                 -0.9196480863017068,
                                 0,
                                 0,
                                 -0.030090882549452126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50437462466291383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7108960519330525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017502240866755725,
                                 0.27462106018808896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97200869204641027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24184244764051671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31808565778459802,
                                 0.11552965427383971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20798106578281683,
                                 -0.11118150851519432,
                                 0.40730188761390701,
                                 0,
                                 0.64551116566064803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4507664322561602,
                                 0.65370844001475203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13384643691400797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.016184854590162945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25418012501682147,
                                 0.18873907306404958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15737451857768867,
                                 -0.45171955542998216,
                                 0.5318686960844462,
                                 -0.74356258215569626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37386488829650966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46625378871804118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25010913974210408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059088306631562004,
                                 0,
                                 0,
                                 0,
                                 0.1545998915263147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42055399376917524,
                                 0,
                                 0,
                                 0.21460502574311169,
                                 0,
                                 0,
                                 0,
                                 0.43408148726081158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24197973358105432,
                                 -0.37031298399744322,
                                 0,
                                 0,
                                 -0.19154428073790619,
                                 0.41660892769932584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32802574631892811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22105151265353504,
                                 -0.1620170190760791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50553535229140356,
                                 0,
                                 0,
                                 0.043700904691105547,
                                 0,
                                 0,
                                 0,
                                 0.049857091374780324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52329312876780998,
                                 -0.28164993279069234,
                                 0,
                                 0,
                                 -0.024046289454360621,
                                 -0.31465117219103012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043043337877249746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50102675515814921,
                                 -0.18550472548750835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0417209299833241,
                                 0.52433756944379251,
                                 0,
                                 0,
                                 -0.41533604554614789,
                                 0,
                                 0,
                                 0,
                                 0.0053780355980832667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10519174812560629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24426459408692805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80745612484918805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0088539715453879869,
                                 0,
                                 0,
                                 -0.24661670561389404,
                                 -0.46385634340197474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19973770953818565,
                                 0,
                                 0,
                                 0,
                                 -0.3408798034949394,
                                 0,
                                 0,
                                 0.46053071655461514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47767904423082014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06112243877952156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19860485927670241,
                                 0,
                                 0,
                                 0,
                                 -0.20423906165956024,
                                 0,
                                 0,
                                 -0.73234441864089361,
                                 0,
                                 0,
                                 0,
                                 -0.27640319361000548,
                                 0,
                                 0,
                                 0,
                                 0.29361619498736263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21869680492016635,
                                 0.4102934652761635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14842315136763015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029925513224562189,
                                 0,
                                 0,
                                 0,
                                 -0.33209130235171613,
                                 0,
                                 0,
                                 0.46108241077733442,
                                 0,
                                 0,
                                 0,
                                 -0.4408494004615966,
                                 0,
                                 0,
                                 0,
                                 -0.20777360897664138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23840268654684241,
                                 0.59986623654208959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76567970801045915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63655996292186678,
                                 0.86948951733969204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14583770682964625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11193089744817022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010026892588309022,
                                 -0.06269910035762058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23376467936340498,
                                 0.49597447207058953,
                                 -0.43043274040351409,
                                 0,
                                 0.083833467889717683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58637790034594073,
                                 0.071260998697726397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33171019387338074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0005310869817583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66652221222981789,
                                 0.15770659391780309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3789250620286323,
                                 0.58477537305841887,
                                 -0.25887241871809308,
                                 0,
                                 -0.28002371712566354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2456808104670207,
                                 0.95427627524025627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44480486737774017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043873739193933503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2558407679929805,
                                 -0.40973399771089558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37018479546293587,
                                 0.83069612818085126,
                                 0.12516307929827247,
                                 -0.17703091529009488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18682069840803073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2115289933825617,
                                 0,
                                 0,
                                 0,
                                 0.20853953008805948,
                                 0,
                                 0.67996418895959165,
                                 0,
                                 0,
                                 0,
                                 -0.68633311510428696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58652683595347466,
                                 0,
                                 0.89260272861943668,
                                 0,
                                 -0.20324792972974443,
                                 0,
                                 0,
                                 0,
                                 0.55674000762842302,
                                 0,
                                 0,
                                 0,
                                 -0.36471892658349558,
                                 0.19850255241217793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80280665728541933,
                                 0,
                                 0,
                                 0.25830775119791438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0063450982759391539,
                                 0.31845213236213898,
                                 0.059818339164901958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10641975093162562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14187018102063445,
                                 0.087545734618926299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23104287698442799,
                                 0,
                                 0,
                                 -0.35778612218634293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67306626051584528,
                                 -0.14274157973767732,
                                 0.40465016326158887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39202266719464146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43079943302804818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47580046278482868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0082324201110646252,
                                 0,
                                 0.14030479583889061,
                                 0,
                                 0.83315836100506857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63826703984088895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15616299223456523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22802925002067542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12955717428472319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31522112592363266,
                                 0,
                                 0.11864346468581666,
                                 0.65646299011353992,
                                 0.54057055864709902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0207800832707168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50779350250636313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040125600902454026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28641893315608957,
                                 0,
                                 0,
                                 0,
                                 -0.16972389607600885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17971885846725563,
                                 0,
                                 -0.66162007176044701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041677081838123756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51452631139065552,
                                 0,
                                 0.24905631011115631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19974408866633164,
                                 -0.092377480381327357,
                                 -0.20538587263170968,
                                 0,
                                 0,
                                 0,
                                 0.27039416030789543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33801550019398624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30893840011540458,
                                 0,
                                 0,
                                 0,
                                 0.59521481398988729,
                                 0,
                                 0.31913191564365556,
                                 0,
                                 0,
                                 0,
                                 -0.0062836771019309651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061186183374309588,
                                 0,
                                 -0.85071790562263527,
                                 0,
                                 0.17831615567575318,
                                 0,
                                 0,
                                 0,
                                 -0.27131820977468624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0095631258612369208,
                                 0.82594190283984037,
                                 0,
                                 0,
                                 0.0029935080174368148,
                                 0,
                                 0,
                                 -0.22755531790692057,
                                 0,
                                 0,
                                 -0.26698250101631638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4412011787270847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53034552333446017,
                                 0.37080168597173263,
                                 0,
                                 0,
                                 -0.42095269629237275,
                                 0,
                                 0,
                                 0.49400805764976602,
                                 0,
                                 0,
                                 0.3308407466965827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22480881287475724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039781114773324605,
                                 0,
                                 0,
                                 0,
                                 0.22500516061894502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086416618840077841,
                                 0,
                                 0.21016804125496741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57457425395566397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091624311873415007,
                                 0,
                                 0.66734096476228277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085370567043894896,
                                 0.13260554840870337,
                                 0.29564300559040035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.174470636669738,
                                 -0.26184418186690939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16901530657530964,
                                 0,
                                 0,
                                 0.25452984671967227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31786204533930368,
                                 -0.40306263106056939,
                                 -0.077767543835715672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73355466690330895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45951749395361657,
                                 0.16461268604538123,
                                 0,
                                 0,
                                 -0.16211663022005351,
                                 0,
                                 0,
                                 0.4187940912666232,
                                 0,
                                 0,
                                 -0.59124983213771198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45880244078132049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68740912551173783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12593248712271543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54999362899818016,
                                 0,
                                 0.93114214913131654,
                                 0,
                                 -0.98832865152409743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5266411471458402,
                                 0,
                                 0,
                                 0.13877528001408029,
                                 0.72130296035146801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024609791158240787,
                                 0,
                                 0,
                                 -0.082174719297386511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054774622611419299,
                                 -0.096659707167967818,
                                 -0.62728000708480658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21744325506308487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11342138689680634,
                                 -0.059906284794804338,
                                 0,
                                 0,
                                 -0.64348433640465619,
                                 0,
                                 0,
                                 -0.66680466447221876,
                                 0,
                                 0,
                                 -0.15388788550008348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31806413342713175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23807793237428029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03209759719959443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041923028631886843,
                                 0,
                                 0,
                                 0,
                                 -0.86144639896082287,
                                 0,
                                 0.36110843109381691,
                                 0,
                                 0,
                                 0,
                                 0.48873302844213573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53930913485909115,
                                 0,
                                 -0.31639990120815198,
                                 0,
                                 0.4920969661711575,
                                 0,
                                 0,
                                 0,
                                 -0.30183284600035026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022401819632505399,
                                 0,
                                 0,
                                 0,
                                 0.15305080598467807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41997227014494543,
                                 0,
                                 -0.26503107441231194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071257952842644759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53531878586612391,
                                 0,
                                 0.088210549735676491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47826401478685299,
                                 0.13975562612192088,
                                 -0.42633593429102951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69902194338606993,
                                 0.18943639459126121,
                                 0,
                                 0,
                                 -0.25487191124009195,
                                 0,
                                 0,
                                 -0.037432503978752751,
                                 0,
                                 0,
                                 0.63962582717658978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00030460530401216906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24573249664705996,
                                 0,
                                 0,
                                 0,
                                 0.28209493126335816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54530510675978283,
                                 0,
                                 -0.35959774245727644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10929016488346718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1330525973499867,
                                 0,
                                 0.13036839519279123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62094874543185552,
                                 -0.030035857577242531,
                                 -0.01571765083221556,
                                 0,
                                 0,
                                 0,
                                 0.56352153449826137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66204407520555275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24956124034130869,
                                 0,
                                 0,
                                 0,
                                 -0.21946497589618419,
                                 0,
                                 -0.20472993869542416,
                                 0,
                                 0,
                                 0,
                                 -0.11795438263443983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39796743551601482,
                                 0,
                                 0.22632110468624594,
                                 0,
                                 -0.32900246602495536,
                                 0,
                                 0,
                                 0,
                                 0.60263134788231421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5068924149684304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45571083220158287,
                                 0,
                                 0.20735170481121543,
                                 0.15581811084567537,
                                 -0.55650400700678448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41046085850951625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0547270013410197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.036242090304035746,
                                 -0.55330001752891333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2760982289691517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30148827980185111,
                                 0,
                                 0,
                                 0,
                                 -0.25458311161215169,
                                 0,
                                 -0.37134406182917423,
                                 0,
                                 0,
                                 0,
                                 -0.47855703357862572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2426859626098789,
                                 0,
                                 -0.51952290259689715,
                                 0,
                                 -0.68871469869436519,
                                 0,
                                 0,
                                 0,
                                 0.11146113858754778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85016443329045632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.257402511221613,
                                 0,
                                 0.0093257472915244041,
                                 0.53826593357626162,
                                 -0.74819629751528083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08743846559284367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13109013628788652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23811125990298404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13355953864572642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011298947816757832,
                                 0,
                                 -0.6815870801509023,
                                 0.1533906103209077,
                                 0.012135217046646045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40516297960994829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1670223128475079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2093589544945069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032061540207345002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1763781235652174,
                                 0,
                                 1.1510459183807193,
                                 0.31188631929472121,
                                 0.54172726628964873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38654210772190661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46879396056766065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43068662003343611,
                                 -0.2103368705069075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21218731571543425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3234846672966447,
                                 0,
                                 0,
                                 0,
                                 -0.066647874458440656,
                                 0,
                                 0.37507103309591022,
                                 0,
                                 0,
                                 0,
                                 0.65952869788201807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14826455586044215,
                                 0,
                                 -0.021138543103114631,
                                 0,
                                 -0.066122607221302643,
                                 0,
                                 0,
                                 0,
                                 0.29227952128456353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3046957365335381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098940993543666145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10869625629773866,
                                 0,
                                 0,
                                 0,
                                 -0.64224293528488907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41127522694614238,
                                 0,
                                 0.20421638466630784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38707386943168715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16061606215852089,
                                 0,
                                 0.30844878043564683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1469239732282793,
                                 0.25460702115695877,
                                 0.087645608981606629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42156576281095814,
                                 0.052916863398603735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15090319594223894,
                                 0,
                                 0,
                                 -0.43090401677591489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11133094196615802,
                                 -0.67122206482793145,
                                 -0.0096958692740437506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38471342339791703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29843075744723152,
                                 -0.55660562655737233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32858811019061757,
                                 0,
                                 0,
                                 0.010615354804549351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33458752058628904,
                                 -0.1068712579756574,
                                 -0.58002904799882182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18232513908421677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54056777819657409,
                                 0.014595696536427623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35768332475113118,
                                 0,
                                 0,
                                 0.4795498855759398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56439658376374946,
                                 -0.11639778501959536,
                                 -0.12635459233708393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040131759629841723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2669165974851249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41433860790050336,
                                 0,
                                 0.50011568838959397,
                                 -0.27537091976105993,
                                 -0.63895122745187682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24685879232069924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70700493669297537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42287140614016727,
                                 0,
                                 0,
                                 0,
                                 0.75230653194971153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055849997225809689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8501150616895593,
                                 0,
                                 0.12672267045556587,
                                 0,
                                 -0.90551438885626612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0055043329843624533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43481022398219621,
                                 0,
                                 0,
                                 0,
                                 -0.27481730103883922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13721916906132706,
                                 0,
                                 -0.067020091489062794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015599682426603846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40824240765146091,
                                 0,
                                 0.17662955342103076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16021177678298637,
                                 -0.65081127095315128,
                                 0.25449634710736779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69171836352757676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76352985771413517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48400800210990563,
                                 0,
                                 -0.17832643724830699,
                                 0,
                                 -0.25108877120756884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1552863740251245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48563570520698507,
                                 0,
                                 0,
                                 0,
                                 0.25158755667289184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094728645783447363,
                                 0,
                                 -0.00017229637116790431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20371265087420914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2018820824524718,
                                 0,
                                 0.017339487282306443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4930341976024028,
                                 -0.55287762926349826,
                                 0.24612161024835799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68742020682574689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.413091679403432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038850392290837754,
                                 0,
                                 0.40644044916234179,
                                 0,
                                 -0.24345797202039379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54366804321815831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59552319569342016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67499406338107826,
                                 0,
                                 -0.04768027292365884,
                                 0.49897946137272198,
                                 0.42333649244276911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2474898206788054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10323078192340863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60986056499872476,
                                 0.2375886272842081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58749180610804452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43535082011488363,
                                 0,
                                 0,
                                 0,
                                 0.11768628844543329,
                                 0,
                                 -0.23803665876196639,
                                 0,
                                 0,
                                 0,
                                 -0.37126079990697458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.249366239498931,
                                 0,
                                 -0.56052859495083152,
                                 0,
                                 0.0023477748540464902,
                                 0,
                                 0,
                                 0,
                                 0.88343543256045387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077393519836057661,
                                 -0.33727412567983461,
                                 0,
                                 0,
                                 -0.5634503369975985,
                                 0,
                                 0,
                                 0.2876742471503515,
                                 0,
                                 0,
                                 -0.19205650308808753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66568607625489129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62333621672865558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36449930510542095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17700484658337737,
                                 0,
                                 0,
                                 0,
                                 -0.045797248321634766,
                                 0,
                                 -0.1745878974706665,
                                 0,
                                 0,
                                 0,
                                 -0.060945701404244546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077663800609582431,
                                 0,
                                 -0.28891390828129215,
                                 0,
                                 1.2417904839922818,
                                 0,
                                 0,
                                 0,
                                 0.68194414284891669,
                                 0,
                                 0,
                                 0,
                                 -0.4880186909706748,
                                 -0.22642679289758405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11945527542191385,
                                 0,
                                 0,
                                 -0.56388741685911903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0042565476894643878,
                                 0.4805221397709929,
                                 -0.28400497196580443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25836333697640718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46152410168822483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11477542419389675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72641667649416131,
                                 0,
                                 0,
                                 0,
                                 -0.39467028700458057,
                                 0,
                                 0.059471043509059449,
                                 0,
                                 0,
                                 0,
                                 -0.62180770684556674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31709363884028935,
                                 0,
                                 0.0062550570240527473,
                                 0,
                                 0.0060685632090462169,
                                 0,
                                 0,
                                 0,
                                 -0.58421945178281953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0074573941183770087,
                                 0,
                                 0,
                                 0,
                                 0.2574313307987216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36215709030143062,
                                 0,
                                 0.21270739534038047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50642099017642028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11980440668384865,
                                 0,
                                 0.55356396446473777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13343964709013956,
                                 -0.085516607757395904,
                                 -0.39357806796638151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13560481250961792,
                                 0,
                                 0,
                                 0,
                                 -0.22305749700496635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16595142745917973,
                                 0,
                                 0.3604201313660888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39211272762941896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23422274289539849,
                                 0,
                                 -0.050291653732837699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10516803661167066,
                                 -0.38997528200232706,
                                 -0.63255922180714719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.632719711340331,
                                 0,
                                 0,
                                 0,
                                 -0.38761063549057223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36173383782788754,
                                 0,
                                 -0.31175809059650766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22208652926752365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34665446341228595,
                                 0,
                                 0.17957825951902601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13891259970622019,
                                 -0.00092333052816809952,
                                 0.01848318100027032,
                                 0,
                                 0,
                                 0,
                                 -0.43015249669496403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30712349117919718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2554110052271249,
                                 0,
                                 0,
                                 0,
                                 -0.21182724010415005,
                                 0,
                                 0.73798815395278183,
                                 0,
                                 0,
                                 0,
                                 -0.06460379697483852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64743531938550303,
                                 0,
                                 -0.051150128848990228,
                                 0,
                                 0.086057356720183595,
                                 0,
                                 0,
                                 0,
                                 0.52037936796816808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14067003028306263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96676317945277801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8813270939516149,
                                 0,
                                 -0.52114221495633872,
                                 0,
                                 -0.49443555770015857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20978787911150004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45256001816571745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.9052532868026204,
                                 0,
                                 -0.073742794173503504,
                                 0.96083318293228426,
                                 -0.3222528229014725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15855176276622515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21502079342041253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55976054554328825,
                                 0.54993805001262619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59868566699969417,
                                 0,
                                 -0.35947293283041654,
                                 0,
                                 0,
                                 0,
                                 0.35921339023775822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17657470881567566,
                                 0,
                                 -0.28481821506481297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87351046953801403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67536131015907241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29926648506250053,
                                 0.54108746296748966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38627537445723864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28490900085626425,
                                 0,
                                 -0.11179261914214172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38346259448667697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77332284332859735,
                                 0,
                                 0.10976714098520116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5466491693959995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0030800391314026454,
                                 0,
                                 0.15132272588225604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76844167552900544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33945242743163689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021462816182792693,
                                 0,
                                 -0.35188956441029007,
                                 0,
                                 0,
                                 -0.40390004212913888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11570920570713736,
                                 0.2776054071982999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036054964165089895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21443995954317502,
                                 -0.0043803145353748128,
                                 0,
                                 -0.02505093990201529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62473725919123679,
                                 0,
                                 -0.30378301270527541,
                                 0,
                                 -0.38456016459768672,
                                 0,
                                 0,
                                 0,
                                 0.48077868312581029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065625091968161214,
                                 -0.32889141582306813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64479920559559067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2370377244895277,
                                 -0.3452053520762457,
                                 0,
                                 0.13910664752483537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35935857709931174,
                                 0,
                                 0.35973105117381904,
                                 0,
                                 -0.13516223207237676,
                                 0,
                                 0,
                                 0,
                                 -0.015480502390477824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16969899022607482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59535514262600964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085834148772203661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11055479725970263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4786830651187815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40736170156329304,
                                 0.15417196042067532,
                                 0,
                                 -0.4222731538476292,
                                 0.42778294836898023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67708870316527858,
                                 0,
                                 0.50717824838159908,
                                 0,
                                 0,
                                 0,
                                 -0.35329858685547499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00092402232749658197,
                                 0,
                                 -0.23000633023803463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59720552584020581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65098782389055465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062246779171515935,
                                 -0.19371392945092641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062707870946001137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79426378361442818,
                                 0,
                                 0.92818601164711756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29579995721123498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23910665495784345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70141672232616881,
                                 0,
                                 -0.054369355068704828,
                                 0,
                                 0,
                                 0.41807958121275585,
                                 0,
                                 0.28829294664711802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37804922009034481,
                                 0,
                                 -0.25579316813014419,
                                 0,
                                 0,
                                 0,
                                 0.4181466014071733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16911206493141256,
                                 0,
                                 -0.10612648367196914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15865752474027267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27197879523261886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5012311920342003,
                                 -1.2646416339290116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46555905991866076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14632875098605863,
                                 0,
                                 -0.14342252656079721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5200704086464254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66777069349851281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62724731738691342,
                                 0,
                                 -0.43530680232521446,
                                 0,
                                 0,
                                 -0.07937931587476163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44862145928366337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26232059742481495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043688018096755432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14383848276643979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20544896381371192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23432402581886247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034104697131124004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4481742545983266,
                                 0.80194973871762043,
                                 0,
                                 0.18745171608099148,
                                 -0.32146967057091796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10667191127803932,
                                 0,
                                 -0.151948189349255,
                                 0,
                                 0,
                                 0,
                                 -1.2760733664978572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55771144598528954,
                                 0,
                                 -0.42344658276295444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33830141609755593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31944958925185712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7251293736667016,
                                 -0.28894083882663019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31349657613580623,
                                 0.0098847375860474374,
                                 0,
                                 -0.52364406760025961,
                                 0,
                                 0.73844900585710405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98840433791626781,
                                 0,
                                 0,
                                 0,
                                 -0.33563737869948651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86613387261328756,
                                 0.11287201515822505,
                                 0,
                                 -0.036601755033705899,
                                 0,
                                 0.85735014808155141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15537304433177768,
                                 0,
                                 0,
                                 0,
                                 0.054333791091357095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03533130441793024,
                                 -0.0097987115096712478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10497980395223624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56928630655931567,
                                 0.30896346619547899,
                                 0,
                                 -0.33735249075923596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39165714568471266,
                                 0,
                                 0.2753037579914876,
                                 0,
                                 0.22877037772211861,
                                 0,
                                 0,
                                 0,
                                 -0.41564351912286923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79677768383434577,
                                 -0.23127271745771452,
                                 0,
                                 -0.11018037635018485,
                                 0,
                                 -1.2542547841584919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28241237085115778,
                                 0,
                                 0,
                                 0,
                                 0.11598894412138681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25384514318642631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44465055422991862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72482010438243072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13371493209411789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23878669738331462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019352869771144615,
                                 0.01515369424718005,
                                 0,
                                 0.37010999210619944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2311918409047804,
                                 -0.53789488370935445,
                                 0,
                                 -0.61420874865129826,
                                 0,
                                 -0.054462967360771955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76664142221465159,
                                 0,
                                 0,
                                 0,
                                 -0.46999597068564292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1484710958920783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19901489564338298,
                                 0,
                                 -0.60519667886635098,
                                 0,
                                 0,
                                 0,
                                 -0.52810090648723207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28668517878291161,
                                 0,
                                 0.28248698669652489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41521857374600646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040936165893153756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.004145041401485,
                                 -0.72179638118139744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68409022963456267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30639659676799497,
                                 0,
                                 -0.53878457607959018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10309683004374642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33555494510711703,
                                 0,
                                 -0.15692923958060814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44745835725942096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57202531321712113,
                                 0,
                                 0.62840803628790309,
                                 0,
                                 0,
                                 0,
                                 -0.16731364272104876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43203248368886027,
                                 0,
                                 0.98583497929132968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030576819463430951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10853533321231036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10701495945828277,
                                 0.068536233253245177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51971776052201513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088833403330726479,
                                 0,
                                 -0.64173723977990371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43530322738914018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12761336266009349,
                                 0,
                                 0.32311193234777669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41208243830655267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48747168757923531,
                                 0,
                                 0.36099064391357399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58358805873233699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83853810208228952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42409102147586303,
                                 0,
                                 -0.33202934588784883,
                                 0,
                                 0,
                                 -0.90829448716729411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1780833646570969,
                                 0.51302565627212759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15061801105506178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59040331896527798,
                                 0.13907272181799812,
                                 0,
                                 -0.51937580773427294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11381505820267299,
                                 0,
                                 0.037708737552108462,
                                 0,
                                 -0.048468951741041766,
                                 0,
                                 0,
                                 0,
                                 -0.16736672214550538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26672167494529542,
                                 0.17087678441652981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02755359174913424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095451433226372839,
                                 0.38192084922815089,
                                 0,
                                 0.13767862695746297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18299990135546923,
                                 0,
                                 0.67060056780075128,
                                 0,
                                 -0.16959788910328538,
                                 0,
                                 0,
                                 0,
                                 0.46153442701867953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0045338124028085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057889375641609842,
                                 0,
                                 0.24323193988285949,
                                 0,
                                 0,
                                 0,
                                 0.24448278522719907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11206397205872401,
                                 0,
                                 0.5778515680753159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96482975310439456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56392809132383026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37947484903463191,
                                 -0.36787364220794683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13003752452790696,
                                 -0.027110696975620237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14848472694004011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1586612255555479,
                                 -0.15092212757414666,
                                 0,
                                 -0.14482572987326625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.206682487014542,
                                 0,
                                 0.13108518289721313,
                                 0,
                                 0.77962863635265878,
                                 0,
                                 0,
                                 0,
                                 0.47292746466583213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81839925348740794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059270617902067037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37994853752031388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23428826754331314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35128800166634466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057294489448394513,
                                 -0.0056488795899605343,
                                 0,
                                 -0.027201907947430201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0057514761234454e-05,
                                 -0.061424220484306402,
                                 0,
                                 0.84709621214487119,
                                 0,
                                 0.42631422215638226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47436976494534167,
                                 0,
                                 0,
                                 0,
                                 -0.98682434968226307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22441624167538021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19574344554346562,
                                 0,
                                 -0.52308838352954223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11090859768746431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13392798168007486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29390626911217416,
                                 0,
                                 1.1698735404882661,
                                 0,
                                 0,
                                 0.1697415349854545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24159435279907893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54588171273288577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059237664482614985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03581488552044778,
                                 0,
                                 -0.48726822942612458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79783435443904682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32317558032369809,
                                 0,
                                 0.12959842913014927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0015490062230013799,
                                 1.082051649336661,
                                 0,
                                 -0.21274123617285601,
                                 0,
                                 -0.18766374999840926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020957928361747591,
                                 0,
                                 0,
                                 0,
                                 -0.68914201634781247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31639905417096581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30426495068377657,
                                 0,
                                 -0.32221929901314394,
                                 0,
                                 0,
                                 0,
                                 -0.20706975360855168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0612914598283543,
                                 0,
                                 -0.08068079965045466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21334417833596947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49994249308716299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51122269249981955,
                                 -0.1751739564793772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42648575887929246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42542807231769303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37329931437622371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28693252015099169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41277233780683381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36810244688345722,
                                 -0.035001913410517588,
                                 0,
                                 -0.3291392643255171,
                                 0,
                                 0,
                                 0,
                                 -0.82747850937681688,
                                 -0.2469478128466579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076661154601347634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044997299308973893,
                                 0.18485006811549207,
                                 0,
                                 0.17140516141315532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24120919307348998,
                                 0,
                                 -0.30356193788967045,
                                 0,
                                 0.17955349312366681,
                                 0,
                                 0,
                                 0,
                                 0.01655130771514525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32574326691184385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57295460974986523,
                                 0,
                                 -0.1203634296711467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12565498162905644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38261325278707414,
                                 0,
                                 -0.62365447838468502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036143696161241863,
                                 -0.42266941913583972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26484185433405555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14913395305466526,
                                 0.036519027696043052,
                                 0,
                                 -0.67022421699323997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31568202012647473,
                                 0,
                                 -0.18534601191125633,
                                 0,
                                 -0.14293539127374083,
                                 0,
                                 0,
                                 0,
                                 0.35027004314554977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05556586517527743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6982097982084563,
                                 0,
                                 0.18294595746688364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022577665018932436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14917818722940648,
                                 0,
                                 0.67318823998700139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0046428207623893103,
                                 0.48850366422886549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63766520695481199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29315323524627029,
                                 -0.068865698238695108,
                                 0,
                                 0.18584922281237456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27833135091735489,
                                 0,
                                 -0.25060703476488444,
                                 0,
                                 0.28809864898381582,
                                 0,
                                 0,
                                 0,
                                 0.078939232432093026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35593699246202082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16473391717150476,
                                 0,
                                 0.59822685595498237,
                                 0,
                                 0,
                                 0,
                                 0.33036304398375044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80677590891960305,
                                 0,
                                 -0.55287086785170725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22797285882183382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95026137062052218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18090127702029946,
                                 -0.27912270110571724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23290686299222088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84632560791919675,
                                 0,
                                 0.70889168333919528,
                                 0,
                                 0,
                                 0,
                                 0.13582431672083545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087861147519291027,
                                 0,
                                 -0.68342230137788151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22718657759237476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.211465770427058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.049080772992236954,
                                 -0.54618371971998891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55244475318071862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37993400772792363,
                                 0,
                                 -0.0070900831385609236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26994824610260326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88918651136482951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60404873308765283,
                                 0,
                                 -0.21009075812574021,
                                 0,
                                 0,
                                 0.71122009997004931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41862145844551263,
                                 -0.20801918253138182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20924987069277534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28403656490821072,
                                 0.74640989892844167,
                                 0,
                                 0.20835978010617995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051996297093211512,
                                 0,
                                 -0.21189624137960456,
                                 0,
                                 0.083093060436055244,
                                 0,
                                 0,
                                 0,
                                 0.044409365442747283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95553430263351502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29457976415815884,
                                 0,
                                 0.37717063063992484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3304001602385685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16684448462794299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.038022086572588,
                                 0,
                                 -0.21203602190109824,
                                 0,
                                 0,
                                 -0.5732388817934666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10416394834582902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065593080551306512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036457054101140127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52344683192340413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62873957894348309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15786161365355325,
                                 -0.10093055421889358,
                                 0,
                                 0.52830009751480245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11381413115464564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45680413204029946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23621928431610931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2719820365458655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0045719011371459992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59045957616225697,
                                 0.54477926614718797,
                                 0,
                                 0.056166607769933596,
                                 0,
                                 0,
                                 0.31187436470148994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63825723471952811,
                                 0,
                                 0.63015635450588536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35852998871561409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044976067012885451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10497144706103208,
                                 0,
                                 0.37836360456489082,
                                 0,
                                 0,
                                 -0.15930929280393519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17142061676070086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17226175292123247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29020182994139382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65558990777698878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15349815168777659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34709779310240085,
                                 0.15700165400284205,
                                 0,
                                 -0.50817078963844631,
                                 0.26158372327229074,
                                 -0.28337996951013783,
                                 0,
                                 0,
                                 0.69200398689651266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046036252770293912,
                                 0,
                                 0,
                                 0,
                                 0.43506236287529598,
                                 -0.84723336262204096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029605823686289459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27625057749811738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85475393723895476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032651574473370221,
                                 0.11619038645569979,
                                 -0.038775315600279428,
                                 0,
                                 0,
                                 -0.32784749403418328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15357699973930003,
                                 0,
                                 0,
                                 0,
                                 -1.1098386975521655,
                                 -0.37259785699666431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32498943565995142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62421847643700101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12535979757973525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51055718905325775,
                                 0,
                                 0,
                                 -0.5693949064239765,
                                 0,
                                 0,
                                 0,
                                 0.060038366638583779,
                                 0.45598003408896509,
                                 0.38324840002876182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30001401018946383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4633932270975637,
                                 0,
                                 0,
                                 0.11178113846899175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012288014898309357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38846021249584434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15569702075986813,
                                 0,
                                 0,
                                 0,
                                 -0.16871101998012888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31358520239393323,
                                 0,
                                 0,
                                 0,
                                 0.64744632806755142,
                                 -0.13383401407035431,
                                 -0.20414387548177404,
                                 0,
                                 0,
                                 0,
                                 0.44824630898084084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0022715232171981936,
                                 0,
                                 0.13548094822252199,
                                 0,
                                 0,
                                 0,
                                 0.91192852173964123,
                                 -0.3564114347715685,
                                 0,
                                 0,
                                 0.23943329823071502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19547052274676738,
                                 0,
                                 0,
                                 0,
                                 -0.37982857931751779,
                                 0.37911343644111678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08028282552615823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21009250604792057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13414205371172144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10864526175252291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15977643338037373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85024733119580442,
                                 0,
                                 0,
                                 0.23451793564835019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018452190127567852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21678758457912203,
                                 0.38628352908418956,
                                 0,
                                 0,
                                 0,
                                 -0.59941644497240576,
                                 0,
                                 0,
                                 0,
                                 0.36978924226859089,
                                 -0.26862183762087122,
                                 -0.51612671975358371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15264243753148976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11639457887257867,
                                 0,
                                 0,
                                 -0.2906965561031124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20990345364468235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15712291877968806,
                                 0,
                                 0,
                                 0,
                                 -0.48977165163226766,
                                 -0.091162157053471554,
                                 0.1074599664808423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03399371796747859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1913629420079202,
                                 0,
                                 0,
                                 0.2542826314407084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78303443684761131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27622821933839403,
                                 0,
                                 0,
                                 0,
                                 0.40607830401329248,
                                 -0.015865044730173292,
                                 -0.029373095187014971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37938032028667062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60178346558008733,
                                 0,
                                 0,
                                 -0.067463991454924724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49705105017115236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11177418376793548,
                                 -0.80001617377588541,
                                 0,
                                 0,
                                 -0.012735594678969481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44802254602749253,
                                 0,
                                 0,
                                 0,
                                 -0.42577888445189782,
                                 0.28772713377306097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54492969816673553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.99368575381407021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09274245149475141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30698211506550882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59482688383423588,
                                 0,
                                 -0.13802819865828433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5174408937794247,
                                 0,
                                 -0.45042070037249865,
                                 -0.049413043620503902,
                                 0,
                                 -0.040040513056642621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1047892562516366,
                                 0,
                                 0.43596590072504576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13947253575122071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092805427790299794,
                                 0,
                                 0.60086531630523199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57380555452843685,
                                 0.67544587233082021,
                                 0,
                                 0.38598095072086497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55271839769408104,
                                 0,
                                 1.1362584838647678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15351527605543888,
                                 0,
                                 0.55749737829679791,
                                 -0.52498191455625387,
                                 0,
                                 -0.065484891644124743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030580453532036922,
                                 0,
                                 -0.48066603245584266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23360309436279339,
                                 -0.15827959150629425,
                                 0,
                                 0,
                                 0.72846159584433623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39622971824627906,
                                 0,
                                 0,
                                 0,
                                 -0.2211052408241472,
                                 0.16468822621430171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72224623307184854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25943940230875534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0704536927938355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20475916074582109,
                                 -0.13744105366724407,
                                 0.46913267856551283,
                                 0,
                                 0,
                                 0.29354502619108302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74415943648935179,
                                 0,
                                 0,
                                 0,
                                 -0.019992752649269488,
                                 -0.18666535300455592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47472131939111956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47338546313172297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32875989469517336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27963046050518248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69787828083634917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00079984831209832562,
                                 0,
                                 0,
                                 -0.24121860021234121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62505171088371481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10609749444752498,
                                 -0.22985328512874598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068353094844469969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64643109630492468,
                                 0,
                                 0,
                                 0,
                                 0.084868871565987256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33671299608635885,
                                 0,
                                 0,
                                 0,
                                 0.0033751221568597833,
                                 0.33944758453461277,
                                 0.082921957563526688,
                                 0,
                                 0,
                                 0,
                                 -0.23218838728495098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34071430678796144,
                                 0,
                                 -0.40591444157451206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2708622223115153,
                                 0,
                                 0,
                                 0,
                                 0.57322020269864005,
                                 -0.12181656032390628,
                                 0.38242965157132947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52793059465487036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3104215580506508,
                                 0,
                                 0,
                                 0.14938013834088795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19893179928432442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29860199874858534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36446332006257742,
                                 0,
                                 0,
                                 -0.37756915668172819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12845324959339724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40829555062279832,
                                 -0.67248745163421875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74185736758339538,
                                 0,
                                 0.44392743407010588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50934888164043479,
                                 0,
                                 -0.19508631209137978,
                                 0.51014151711665034,
                                 0,
                                 0.062982300709405789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5561534574949708,
                                 0,
                                 0.98483169491698708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19145257606437008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37713032229222615,
                                 0,
                                 0,
                                 0,
                                 -0.38764097320398999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4144913690492083,
                                 0,
                                 0,
                                 0,
                                 0.14007246385820829,
                                 0.49971970533815202,
                                 -0.043601981023568673,
                                 0,
                                 0,
                                 0,
                                 -0.31338684410630918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13584263800181945,
                                 0,
                                 0.33338305874970864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66019346860085149,
                                 0,
                                 -0.57570470379547578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44050866972636232,
                                 0,
                                 -0.17630804452631338,
                                 -0.063895955601751625,
                                 0,
                                 -0.68079905208712266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22174908222398534,
                                 0,
                                 -0.11047871157448004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58486889311964085,
                                 0,
                                 0.15372391310472577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12401378526665197,
                                 0,
                                 0.45271913771290384,
                                 -0.39538407621918514,
                                 0,
                                 -1.1250814683793062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1866943302677585,
                                 0,
                                 0.69502845710469918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3215731784298737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52255962134009715,
                                 0,
                                 -0.32120519522396962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067853053099814653,
                                 -0.35405735310044301,
                                 0,
                                 0.6907535699332904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10832258349679288,
                                 0,
                                 0.20951366596778967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63250633133284162,
                                 0,
                                 0.71094212245524258,
                                 0.33871576356869865,
                                 0,
                                 -0.15223845505635963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61599856880914927,
                                 0,
                                 0.029098028896149208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51241331362104792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21445957994368733,
                                 0,
                                 0.37096365013918298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67967679467523301,
                                 -0.3202112234263812,
                                 0,
                                 -0.65294666676708424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60053855849989035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13147028127329394,
                                 0,
                                 0,
                                 0,
                                 0.090357795997260251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039767452910766277,
                                 0,
                                 0,
                                 0,
                                 -0.12887037394127165,
                                 -0.16892746137997244,
                                 0.27578454959142557,
                                 0,
                                 0,
                                 0,
                                 -0.41079243602457727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12831828311330398,
                                 0,
                                 0.5530875497882396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68205797153037995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25093784321798551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46328491991031373,
                                 0.75293662761975999,
                                 0,
                                 0,
                                 0.01077020281984617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29302728599125499,
                                 0,
                                 0,
                                 0,
                                 0.14461617881259653,
                                 0.41066808892234175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19723191740311266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56651232338481949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010284928369624233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14604206931897395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52700583842806881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12635471287080824,
                                 0,
                                 0,
                                 0.33814977527332957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68087747572916713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35320367011590259,
                                 0.060059077099116849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40155624544402962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068055459013624614,
                                 0,
                                 0,
                                 0,
                                 0.22492922492000525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17906905240802012,
                                 0,
                                 0,
                                 0,
                                 0.65426939225807934,
                                 -0.29350801033836654,
                                 0.065742587746034087,
                                 0,
                                 0,
                                 0,
                                 -0.47843754261780891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054635869747411678,
                                 0,
                                 0.032204291928355805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10525828958885503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19284610921014392,
                                 0,
                                 0,
                                 0,
                                 -0.72624230983558458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48989573691525246,
                                 0,
                                 0,
                                 0,
                                 -0.002724442750338063,
                                 -0.07803497095481321,
                                 -0.31430611693104582,
                                 0,
                                 0,
                                 0,
                                 -0.21204159169417877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13033363012743879,
                                 0,
                                 -0.13218032690755233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2713254279613978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30249202152604682,
                                 0,
                                 0,
                                 0,
                                 -0.3906017944718948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043009520695043157,
                                 0,
                                 0,
                                 0,
                                 0.044199594872705389,
                                 0.013700104137886904,
                                 0.73921800712923336,
                                 0,
                                 0,
                                 0,
                                 0.242767569530359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21751801438661703,
                                 0,
                                 0.16008363388172528,
                                 0,
                                 0,
                                 0,
                                 -0.10850409373945283,
                                 0.22303941687990708,
                                 0,
                                 0,
                                 0.10172586427094864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51459141996839752,
                                 0,
                                 0,
                                 0,
                                 -0.42586717813006225,
                                 0.085015778157916749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2024503619507235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31829334849720514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83135330417526776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38397202721623824,
                                 0,
                                 0,
                                 -0.12889277968338225,
                                 0,
                                 0,
                                 0,
                                 0.23739368027552107,
                                 0.011802484082292758,
                                 -0.28766655877020325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20941838827136161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043976000203196759,
                                 0,
                                 0,
                                 0.88465154119760248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12546411822586009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11427066737019703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52578528134563118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30721492104749271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14088914814927977,
                                 0,
                                 0,
                                 0,
                                 -0.12207918336793014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20320593541666665,
                                 0,
                                 0,
                                 0,
                                 0.091010040209181617,
                                 -0.026284404530032446,
                                 0.11344760792608388,
                                 0,
                                 0,
                                 0,
                                 -0.36408728088955616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70932040960492215,
                                 0,
                                 -0.41477007166264912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18028505991104624,
                                 0,
                                 0,
                                 0,
                                 -0.26212571672560775,
                                 -0.47609831055666929,
                                 -0.23907065700666771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55254643549890203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52085678547079495,
                                 0,
                                 0,
                                 0.1675185739227732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10149481999004184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44791567327665449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.4517483656600083,
                                 0,
                                 0.11740844339721204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1863644608866053,
                                 -0.44278469003401905,
                                 0,
                                 0.26657688303538973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29181535914663914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18419975359283514,
                                 0,
                                 0.74954587704420872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.138002210268799,
                                 -0.31674770665185176,
                                 0,
                                 -0.091164539382810064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48739207268485724,
                                 0.014061073332771901,
                                 0,
                                 0,
                                 -0.82552540106505501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082476415543631151,
                                 0,
                                 0,
                                 0,
                                 0.11109744288867172,
                                 -0.63547704554256446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49254470030142072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14834822560058847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21076716713657298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20774392673146155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75905840412970926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72421048979374092,
                                 0,
                                 0.37814361136593633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53912368966372082,
                                 -0.60953915161414707,
                                 0,
                                 0.2789527297358354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30498742648377025,
                                 0,
                                 0,
                                 0,
                                 0.035048530858537527,
                                 -0.68535691725400039,
                                 0.53680926169134935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33724255688013371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058040337716451312,
                                 0,
                                 0,
                                 0.028358329883285308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17312008797042758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24282281938952252,
                                 0,
                                 -0.24931893980655212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1856187141952774,
                                 0,
                                 0.21446750557181277,
                                 0.87238152886264508,
                                 0,
                                 -0.23109882690669456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25765081969335396,
                                 0,
                                 0.056988656749490031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20549740226488591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011478045066800679,
                                 0,
                                 0,
                                 0,
                                 0.23456388318182153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53822356773519331,
                                 0,
                                 0,
                                 0,
                                 0.2819344765146336,
                                 0.70108417888668673,
                                 0.041892638219595185,
                                 0,
                                 0,
                                 0,
                                 0.086656505916963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17049065650354145,
                                 0,
                                 0.059973043464118886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47143944485545658,
                                 0,
                                 0.77881159514580001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14351785025326591,
                                 0,
                                 -0.4125964472281145,
                                 0.42224765960881372,
                                 0,
                                 -0.42648890046367788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19188380743329586,
                                 0,
                                 -0.3501417474940739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25410915944434198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49504491977541926,
                                 0,
                                 0,
                                 0,
                                 0.073412928045002601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10006745363095018,
                                 0,
                                 0,
                                 0,
                                 -0.16362961689062866,
                                 0.063035905919482785,
                                 -0.45750621699110128,
                                 0,
                                 0,
                                 0,
                                 -0.073027049836442051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49950102084658554,
                                 0,
                                 0.42433686362576012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22450065034115196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.354538857123741,
                                 0,
                                 0,
                                 0.059126880260927731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30464855084678666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80318608911494027,
                                 -0.28720556320448076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26483683104059896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05081347942012876,
                                 0,
                                 0,
                                 0.79146395888043486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18990724467845874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071975564289810348,
                                 -0.5095282147150455,
                                 0,
                                 -0.059345459534971251,
                                 0.6509972889730018,
                                 0,
                                 0,
                                 0.16418126458287935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062772467307553315,
                                 0,
                                 0,
                                 0,
                                 -0.092263599314507214,
                                 -0.3891218880916314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23956006895769677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08645308364590612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46643249254165597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82405697209984907,
                                 0.50461105969061915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087873253689003228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56127089376681538,
                                 -0.80440984377777769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2772058742890981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52635287502044303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29068711996289515,
                                 0.024895994017312018,
                                 0,
                                 0,
                                 0.34558585941329301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7655866161859799,
                                 -0.045002659640691237,
                                 0.14493631442575236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.360141777503588,
                                 0,
                                 0,
                                 0,
                                 -0.1863064110139242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032703316190808566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14427499598953114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15651030618725364,
                                 0.2682007238684071,
                                 0,
                                 0,
                                 0.47556933599790274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0011027704650185231,
                                 0.74528126023232355,
                                 -0.076908306608667362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088980734211511647,
                                 0,
                                 0,
                                 0,
                                 0.14413995761044535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22092090539322073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19633261820196016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27652666065091758,
                                 0,
                                 0,
                                 -0.27555742948392103,
                                 0,
                                 -0.48193927468246567,
                                 0,
                                 0,
                                 0,
                                 -0.53423272502512309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51684375690953022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25060640650206717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2394742285032096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0015192878335631918,
                                 0,
                                 0,
                                 -0.30092592353715325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21581638953308233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63780166712632469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0494948631040334,
                                 0,
                                 -0.55832674352246647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29077001152849197,
                                 0,
                                 0,
                                 0.0098772852306095883,
                                 0.83434502762027685,
                                 0,
                                 0,
                                 0.018341444910289627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069403404082745992,
                                 -0.31428552526980702,
                                 -0.069624436568477263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0013421027470684813,
                                 0,
                                 0,
                                 0,
                                 -0.33400618355310097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045796389664904305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28519358033219355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12622454725837512,
                                 0,
                                 0,
                                 0.49454918092932509,
                                 0,
                                 -0.50394250166847721,
                                 0,
                                 0,
                                 0,
                                 0.25177514396899048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18102074390415274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62399614860946806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25617664964959541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34904389550066073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98064883893430177,
                                 -0.59809900092852841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24719704314454577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1486366120832585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63471515638639786,
                                 0,
                                 0,
                                 -0.17345813499194573,
                                 0,
                                 -0.50611355929747137,
                                 0,
                                 0,
                                 0,
                                 -0.2612498108649085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3087571011344632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38381714341056189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54723511774959332,
                                 -0.21252513985277957,
                                 -0.18062752750652483,
                                 0,
                                 0,
                                 -0.34856188369285729,
                                 0,
                                 0.32812717358824744,
                                 0,
                                 0,
                                 -0.12081417845204528,
                                 -0.73641178569692389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24717844158518001,
                                 0,
                                 0,
                                 0,
                                 0.7396299643171288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88151174728049286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38249856373435576,
                                 0.087627405172161665,
                                 0.23858518752118216,
                                 0,
                                 0,
                                 -0.94340592935028866,
                                 0,
                                 -0.19731644898304287,
                                 0,
                                 0,
                                 -0.22509918152516334,
                                 -0.48482392181054867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54829484680675755,
                                 0,
                                 0,
                                 0,
                                 -0.16729305224527335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3010022169096736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17512447070221507,
                                 -0.84536798970574933,
                                 0.29449254696985266,
                                 0,
                                 0,
                                 -0.30569163008352346,
                                 0,
                                 -0.12928490731316855,
                                 0,
                                 0,
                                 -0.22220837044526637,
                                 -0.033073314269300352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1047042180497293,
                                 0,
                                 0,
                                 0,
                                 0.081429038264972942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17786129293266678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3329459905451948,
                                 0,
                                 0,
                                 0.11573166650833454,
                                 0,
                                 0.48687905179722329,
                                 0,
                                 0,
                                 0,
                                 -0.64163599004123828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18273943258725542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44001306086252395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76540020891979388,
                                 0,
                                 0,
                                 0,
                                 -0.097708902740679213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81229241421392295,
                                 0,
                                 0,
                                 0,
                                 0.066237441821796486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085859241852263402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32309599526785704,
                                 -0.60505365651233911,
                                 0,
                                 0.13288243053444171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91736741617440942,
                                 -0.41452950007428274,
                                 0.091391279663762245,
                                 0,
                                 0,
                                 -0.24855467403736453,
                                 0,
                                 0.21446152686454367,
                                 0,
                                 0,
                                 0.18959862694959795,
                                 0.29780703284428767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31525717332884606,
                                 0,
                                 0,
                                 0,
                                 -0.10328268812860446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56706461597834956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39970776273518088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59005061316399987,
                                 0,
                                 0,
                                 0.41624256234766083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11907849605748091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25140247171959756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11245336182905596,
                                 0,
                                 -0.15967310266723578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45087909498246309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45881687434895463,
                                 0.74680989672507214,
                                 0.13034977628129743,
                                 0,
                                 0,
                                 -0.33702510500521204,
                                 0,
                                 -0.13616022758192003,
                                 0,
                                 0,
                                 -0.36510153893260178,
                                 0.24302043491470912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16057153301144686,
                                 0,
                                 0,
                                 0,
                                 0.61982458278351293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34867740515229001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3958652466489796,
                                 0,
                                 0,
                                 0,
                                 0.58261214621457147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6017293944588219,
                                 0,
                                 0,
                                 0,
                                 0.55984001464399991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043769796985815804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17024803109228975,
                                 -0.69798589970114877,
                                 0,
                                 -0.59771564302162861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13010217119876491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28820611223793197,
                                 0,
                                 0,
                                 -0.02336772535336791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60014463445047217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0080875999528380316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60896345734321766,
                                 0,
                                 0.3576004700485832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20127352344214711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22572402399534869,
                                 0.36096519558209927,
                                 0.48432651432871038,
                                 0,
                                 0,
                                 -0.11568906368811352,
                                 0,
                                 0.42148593275657287,
                                 0,
                                 0,
                                 0.55333882190361827,
                                 -0.86123633668939914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19126556541124573,
                                 0,
                                 0,
                                 0,
                                 0.047253949525888274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32560595015507376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44825290869328482,
                                 0.31992660351137836,
                                 0.43972535957612569,
                                 0,
                                 0,
                                 -0.28161322756789176,
                                 0,
                                 0.61738516450726877,
                                 0,
                                 0,
                                 -0.72124923638650285,
                                 0.082226724957991659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05566864352355301,
                                 0,
                                 0,
                                 0,
                                 -0.603079521801553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71860523206626259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017137847575062239,
                                 0.12175216584259532,
                                 0,
                                 0,
                                 -0.36158703818670257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22816349105022279,
                                 0.28704233947304464,
                                 0.4810709677899348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69483633016047952,
                                 0,
                                 0,
                                 0,
                                 -0.0032415074361549223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05081835577400718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053533357776773288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64578950633924237,
                                 0.1680161557077918,
                                 0,
                                 0,
                                 -0.10160699523131606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.005884109397981202,
                                 0.13337741073113188,
                                 -0.095850634484286379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026408556820411155,
                                 0,
                                 0,
                                 0,
                                 0.51360689615545529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48256245127610847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14154514418439695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04950934095776155,
                                 -0.32342904482574919,
                                 0,
                                 0,
                                 0.15151280397031058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12528147602363054,
                                 0.07952939202234599,
                                 -0.50896749057126422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40763497390916947,
                                 0,
                                 0,
                                 0,
                                 -0.35476811811987252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37246662941839692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39769333643779436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79339111245709548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18738866397670942,
                                 0,
                                 0,
                                 0.17782061667287563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041994099912845861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22699558350250693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11811017776134251,
                                 0,
                                 0.35915127651206613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32797211269404775,
                                 0,
                                 0.50713196603718158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71467237288291185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16992005034041507,
                                 -0.088868240807224219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76071475056948834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20665186534075178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24904219465050675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21401010637683071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82160205927761909,
                                 -0.86072825587265045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30306280599910029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43548620342834865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27138970053591738,
                                 0,
                                 0,
                                 0,
                                 -0.73970560282725817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43452924484956718,
                                 0,
                                 0,
                                 0,
                                 0.27733432212461767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0681988149673622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26445219186041169,
                                 0.31044586529079088,
                                 0,
                                 -0.071556469284455193,
                                 0,
                                 0,
                                 0,
                                 0.33647825597399755,
                                 0,
                                 0,
                                 -0.60984173617945359,
                                 0,
                                 -0.063102769217944554,
                                 0,
                                 0,
                                 0,
                                 0.052161840047709448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65096718441604529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29054147353456533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31904510238962314,
                                 -0.02667944531778485,
                                 0,
                                 0,
                                 -0.11210679398727175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1206536165198594,
                                 0.39721525558203225,
                                 0.18669014651353674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34274101415501751,
                                 0,
                                 0,
                                 0,
                                 -0.65182505597988616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24342462158863359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27592966231668331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40379986223083719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014784190674920913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44121058709658711,
                                 0,
                                 0,
                                 0,
                                 1.3531243990412176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71021767949193293,
                                 0,
                                 0,
                                 0,
                                 0.11824346304820253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51342867039544593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29762215283465465,
                                 0.56798782670489811,
                                 0,
                                 0.35857637046286572,
                                 -0.64032474398728156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79301377500889725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35525245222248736,
                                 -0.039551924116137976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3039073462119195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12267295801628553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24083319490014993,
                                 0.16993829422013895,
                                 0,
                                 0,
                                 0.038178247681889196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27575244963401407,
                                 0.017406064296277741,
                                 -0.52812335368238517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29004253138742664,
                                 0,
                                 0,
                                 0,
                                 0.013742641922417184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29675737265484209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61969963699510322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45202823988387392,
                                 -0.0077272670227804055,
                                 0.6562439747472526,
                                 0,
                                 0,
                                 -0.0083083278052280829,
                                 0,
                                 0.43878932281492172,
                                 0,
                                 0,
                                 0.74202285131588941,
                                 0.92133731268333308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32584280391614251,
                                 0,
                                 0,
                                 0,
                                 0.52348304857489958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24224172945433758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.138428950721393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3070878402847198,
                                 0,
                                 0,
                                 0.20891346267972144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50971394760821953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32991829295685493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25041873980541574,
                                 0,
                                 0.31907485079979214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55652219631389821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49716766697489279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011229536477393241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64617966387547232,
                                 0,
                                 0,
                                 0,
                                 -0.013060042242589328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27503160017692518,
                                 0,
                                 0,
                                 0,
                                 -0.39165567971055237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73448758875973197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81597773979991373,
                                 0.54854692127214344,
                                 0,
                                 -0.15619521915378021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21235799277373532,
                                 -0.15339000047643597,
                                 1.0530770960564189,
                                 0,
                                 0,
                                 0.38962867616932101,
                                 0,
                                 -0.087872604870153637,
                                 0,
                                 0,
                                 -0.26477347470631846,
                                 -0.37216273767310659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.387131181089164,
                                 0,
                                 0,
                                 0,
                                 0.20700459428132845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10721169032006617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41576011091971676,
                                 -0.19407177102992457,
                                 0,
                                 0,
                                 0.54290661370525894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46989058115705473,
                                 -0.26525653118532982,
                                 0.33162405290347013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020523071716045463,
                                 0,
                                 0,
                                 0,
                                 -0.040076399166893095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23991173668137161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18443002182776849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18311258974395397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26392218769807263,
                                 0,
                                 0,
                                 -0.57972931236467207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5168570369660912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20375276823266408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48224603774133978,
                                 0,
                                 -0.062998946878764159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12466871000460905,
                                 0,
                                 0.54786673953800624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58795884549282529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88182192304198082,
                                 0.85190894132029826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69557585527454879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084292256476100266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28940985108752038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47870430353533433,
                                 0,
                                 0,
                                 -0.36652535370807016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22328456815773712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50671444571915758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13257239066995777,
                                 0,
                                 0.062901773120769541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47391528066931793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52977956784745417,
                                 0,
                                 0,
                                 -0.51390731098545084,
                                 0,
                                 0.12881143219436841,
                                 0,
                                 0,
                                 0,
                                 0.4105308848811659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38421491161875354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34997684836512255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37211842129256156,
                                 0.12807381318982222,
                                 0,
                                 0,
                                 0.42575745600059989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17284839591689033,
                                 -0.093826926630168242,
                                 0.21171794528073196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10344104111765678,
                                 0,
                                 0,
                                 0,
                                 0.12891707730115903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.607427853041409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42902536128529084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33768581546286019,
                                 0.32781822898289881,
                                 -0.089663791727375264,
                                 0,
                                 0,
                                 0.0062528713339909114,
                                 0,
                                 -0.89847567516629556,
                                 0,
                                 0,
                                 0.45444711516917774,
                                 0.13535335634121892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16964614949644488,
                                 0,
                                 0,
                                 0,
                                 -0.10971583271074772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38915133466904123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10758145630780307,
                                 0,
                                 0,
                                 0,
                                 0.078230215290423386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071166561388264105,
                                 0,
                                 0,
                                 0,
                                 -1.0187216035435538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016959254193609597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041215580143578706,
                                 -0.46011626897320357,
                                 0,
                                 -0.71497103808110107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.94863931356841169,
                                 0,
                                 0,
                                 0,
                                 0.062998003873208488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020534053769243638,
                                 0,
                                 0,
                                 0,
                                 0.51021374397264663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08541708027750497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9933640148727223,
                                 -0.067369039338248005,
                                 0,
                                 0.30536396322850867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.006237723016030601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37489334232240901,
                                 0,
                                 0,
                                 0.43582995550670839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022383200693943183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26700679079567402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53597739554810842,
                                 0,
                                 -0.54421847760850728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11928607908538673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1619694389881694,
                                 0,
                                 0,
                                 0,
                                 -0.065398409397223897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61902776310098695,
                                 0,
                                 0,
                                 0,
                                 -0.64926383865374604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048064958669355728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060541494387617266,
                                 -0.49423534118165069,
                                 0,
                                 0.72013683106830539,
                                 0.17334454279570749,
                                 0,
                                 0,
                                 0,
                                 -0.46067794829284531,
                                 0,
                                 0.13067593703427949,
                                 0,
                                 0,
                                 -0.24754773486301268,
                                 0,
                                 -0.60367233587155777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02626077829744472,
                                 0.28589166943160138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065910338788262593,
                                 0,
                                 0.34435918914320202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33105894906149402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37963488038055565,
                                 0,
                                 0,
                                 0,
                                 -0.51052592006505704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67826514437574348,
                                 0,
                                 0.10962337352429873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079334823044072356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34188556315650243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4946804245752735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3985333551761445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45821204751013617,
                                 0,
                                 0,
                                 -0.099173150239992791,
                                 0.19220795017711301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31473803533809763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63311171781630438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42904207481074896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24177397066631673,
                                 0,
                                 0,
                                 0,
                                 0.24727627478905687,
                                 0,
                                 -0.28691668240362422,
                                 0,
                                 0,
                                 0.39701706194410413,
                                 0,
                                 0.021678967997406956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26910274315809529,
                                 0.27649507558831121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5775688911873762,
                                 0,
                                 0.37393958990588505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13305498524607251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35162561000212023,
                                 0,
                                 0,
                                 0,
                                 -0.12873961611284829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27776911057546716,
                                 0,
                                 -0.76132560120861204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34306540911872441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29209470528308945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42099654161642802,
                                 0,
                                 0,
                                 0,
                                 -0.10339405160560398,
                                 0,
                                 0.20386671386824809,
                                 0,
                                 0,
                                 -0.020082082673516678,
                                 0,
                                 -0.40592049718894629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061098344567897096,
                                 -0.010325174952897059,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64701560370219191,
                                 0,
                                 -0.29612397770478932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30850767637281845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19166715358768682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10575942803348179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1463330923961309,
                                 0,
                                 0.38114863919197217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46014304321394811,
                                 0,
                                 0,
                                 0,
                                 0.20696624538571237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36940388568942462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62798495907133178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46346359139781734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61953983839544779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52699823386602562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1861360038772783,
                                 0,
                                 0,
                                 0,
                                 0.44097100923940091,
                                 0,
                                 0,
                                 -0.07896756047815981,
                                 0.3758672355035193,
                                 0,
                                 -0.67316713906309789,
                                 0,
                                 0,
                                 0,
                                 0.14388141701575613,
                                 0,
                                 0,
                                 0,
                                 -0.23217541183043061,
                                 0,
                                 0.73236394924295356,
                                 0,
                                 0,
                                 0.15728633959279836,
                                 0,
                                 0.35310919574318989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29711638080156849,
                                 -0.16909105109940986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19136365852628676,
                                 0,
                                 -0.05215072354247529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28879229562814568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070817159600473703,
                                 0,
                                 0.11928095540646341,
                                 0,
                                 -0.094079013752804849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.21958427066135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34384859595006045,
                                 0,
                                 0,
                                 0,
                                 -0.52280431314795028,
                                 0.30440206963851968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1524603184805754,
                                 -0.048672549968768346,
                                 -0.10228707467269356,
                                 -0.051312724196973906,
                                 0,
                                 0,
                                 0,
                                 -0.066249213392435516,
                                 0,
                                 -0.11370300055410201,
                                 0,
                                 0,
                                 -0.73681120376970166,
                                 0,
                                 0.35762308028069906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42919813354181796,
                                 0.23671574557999164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17694597442618845,
                                 0,
                                 0.059827230659226217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18474333205854593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73357580537627187,
                                 0,
                                 0.21006142811554723,
                                 0,
                                 -0.091255547690300629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29528463490643658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.995006651242339,
                                 0,
                                 0,
                                 0,
                                 -0.18931177823807732,
                                 -0.3580865072223019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6474217330853288,
                                 0.47007299208259495,
                                 0.16498773332586719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79666980486578343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058930616853426834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26963012242301809,
                                 0,
                                 -0.034145983024550144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10149716960303375,
                                 0,
                                 0,
                                 0,
                                 0.26279115894802574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16953397810673237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42411721840366035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5692245397604897,
                                 0,
                                 -0.93016174420293007,
                                 0,
                                 0.18896953472540026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11200852873268941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18725935698942228,
                                 0,
                                 0,
                                 0,
                                 0.24322149583173258,
                                 0.21678149120634649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6100546440980037,
                                 0.081594393807361706,
                                 -0.5490356374711074,
                                 0,
                                 0,
                                 -0.89198418870448792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42595330653352814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84002813815408395,
                                 0,
                                 0,
                                 0.45551889558306802,
                                 -0.75765067227709881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27345509687961794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8723335565493624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12558308452341535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81021909185044849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33053912520946471,
                                 0,
                                 0,
                                 0,
                                 0.41753953668533977,
                                 0,
                                 0,
                                 -0.27314339505894575,
                                 0.081529402883464219,
                                 0,
                                 -0.073638282355528176,
                                 0,
                                 0,
                                 0,
                                 -0.068982081622302016,
                                 0,
                                 0,
                                 0,
                                 -0.014010525971363524,
                                 0,
                                 -0.19188281085117767,
                                 0,
                                 0,
                                 0.20194200370321214,
                                 0,
                                 -0.30802701178474962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76654120125834779,
                                 -0.073861519065628878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26246218813203115,
                                 0,
                                 -0.39808972792294306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04649927661922422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15906292597577493,
                                 0,
                                 0,
                                 0,
                                 0.41698093367772249,
                                 0,
                                 0.24718047213406444,
                                 0,
                                 0,
                                 -0.07218107849436832,
                                 0,
                                 -0.039462682324932587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13169719137891353,
                                 0.66519393338735577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062662011250116612,
                                 0,
                                 -0.48020770875420843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19648714691464639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41514081436871303,
                                 0,
                                 0,
                                 0,
                                 0.20590290705400782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3973502567417988,
                                 0,
                                 -0.59034629179437215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52594713054899422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047389262614330706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059975722114182062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.329002471429231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38353687929151153,
                                 0,
                                 -0.0086361813005694094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16056500630880036,
                                 0,
                                 0,
                                 0,
                                 0.18364516578078077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79007292799617002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23929744133228231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42099154329875876,
                                 0,
                                 0,
                                 0,
                                 0.70222200173628169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013521648620699711,
                                 0,
                                 0.17456261309852372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21836750295139395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50130935910870977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08178894743420223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85956086041438595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31958249017583695,
                                 0,
                                 0.22753054115671884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19916826151469269,
                                 0,
                                 0,
                                 0,
                                 -0.049848478962461786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17137990836081307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17040727653421961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090948693029321195,
                                 0,
                                 0.10547324267688565,
                                 0,
                                 0.67417806027567284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30222647633427885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59869058684920828,
                                 0,
                                 0,
                                 0,
                                 -0.72523125504225561,
                                 0.81308674795515856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093662749438513243,
                                 0.2494478382129702,
                                 0.36182361952274777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1783966166584755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41111318952381681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20696655799738073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51437075650540443,
                                 0,
                                 0,
                                 0,
                                 -0.98658311149246603,
                                 0,
                                 0,
                                 0.058899696268456037,
                                 -0.12953591505184092,
                                 0,
                                 -0.68407302341519183,
                                 0,
                                 0,
                                 0,
                                 0.19472142452738936,
                                 0,
                                 0,
                                 0,
                                 0.10421732750312054,
                                 0,
                                 -0.2896251418626451,
                                 0,
                                 0,
                                 -0.32793061688099467,
                                 0,
                                 -0.059929413566711387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13137595219076958,
                                 -0.44519022414231679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30255378547205014,
                                 0,
                                 -0.31876728923607439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.589579692920707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062483720511399304,
                                 0,
                                 0,
                                 0,
                                 -0.42329690624708211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54715691473481032,
                                 0,
                                 0.068340527455280103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68685239630099015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20272686672788895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80168221802041872,
                                 0,
                                 0,
                                 0,
                                 0.087534470218778609,
                                 0,
                                 -0.038473400739140129,
                                 0,
                                 0,
                                 0.045556156710006249,
                                 0,
                                 0.1400004747940877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017439955291191439,
                                 0.14132474090710195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071640675321189423,
                                 0,
                                 0.18413273077354936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51688833956336233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1399557105316207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.067600504088853985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86750358594636034,
                                 0,
                                 0,
                                 -0.115783427856072,
                                 -0.29971913920539289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037734693512840506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36464469586867954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20995189976112028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16907884027235581,
                                 0,
                                 0.74397161922832533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16401340934396214,
                                 0,
                                 0,
                                 0,
                                 -0.36910168927652798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12728745542238057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24806142250892663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95917918110924683,
                                 0,
                                 0.59984219379022941,
                                 0,
                                 -1.0356799792369047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042040497258921797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01211050635935762,
                                 0,
                                 0,
                                 0,
                                 0.051120280224543499,
                                 0.21766872426287748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075339231739795426,
                                 0.51984158719281526,
                                 0.4581367956335991,
                                 0,
                                 0,
                                 0.60367762944499825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43697666970564852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074482448323626702,
                                 0,
                                 0,
                                 0.39672366470243836,
                                 0.92946486974289089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87646267355619989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041289807046985275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58439997963942758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1405918211853236,
                                 0,
                                 0,
                                 -1.1036686248637977,
                                 -0.54530538795447758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1773392614656617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08798766587401996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19479924749086794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64358250267324513,
                                 0,
                                 -0.079812752537696416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32906561653188982,
                                 0,
                                 0,
                                 0,
                                 0.62192554802584943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12982012018955291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1476959029202691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1297393610608502,
                                 0,
                                 -0.34187334356277105,
                                 0,
                                 -0.31505626691446753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10491834404191548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48092027659257608,
                                 0,
                                 0,
                                 0,
                                 0.018585921376924136,
                                 0.46912207662410299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076707281242227726,
                                 1.1208788503227465,
                                 -0.37104350326589863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22462814985939433,
                                 0,
                                 0.60451660622581782,
                                 0,
                                 -0.44882755150949183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26846385946991752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028470063754628586,
                                 0,
                                 0,
                                 0,
                                 -0.12888662985328872,
                                 0.62116050354423935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74437083832593776,
                                 -0.61053331982436432,
                                 -0.46956730361132554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21711177806730628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82757339026378141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39275252304611497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35113596522423507,
                                 0,
                                 0,
                                 0,
                                 -0.34717190253005237,
                                 0,
                                 0,
                                 -0.57210317404106337,
                                 0.42508327537968282,
                                 0,
                                 0.4775882497007371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61543220372055807,
                                 0,
                                 0,
                                 0,
                                 -0.089985434880823084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073143450005823271,
                                 0,
                                 0.1572093098435354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28273865341761623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70932358385741223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34566552688514851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33433799117979773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25806209207951242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23133470175201368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086713028495752825,
                                 0,
                                 -0.067469471487516267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7375703435510752,
                                 0,
                                 0,
                                 0,
                                 -0.25596491620309342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13138930639654769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49094371740034387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28454132783543351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50111995414773525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1917453368969429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81009977112089104,
                                 0,
                                 0,
                                 0,
                                 -0.13521033122536286,
                                 0,
                                 0,
                                 0.023574472790762774,
                                 0.26829825689207187,
                                 0,
                                 0.71911558261485642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48908017944995963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024593055942033759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63545040181182599,
                                 0,
                                 0,
                                 -0.63006033957432517,
                                 0.60758110863434989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17805154976478854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01592849164817383,
                                 0,
                                 0,
                                 0,
                                 0.68194767623686359,
                                 0,
                                 0.35563398187120965,
                                 0,
                                 0,
                                 -0.23970816625114177,
                                 0,
                                 -0.31325437060897454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16786464655902195,
                                 -0.301625891530309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07763231770457471,
                                 0,
                                 0.35072097746473985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066641702427448032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088806377142322465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97448915510021994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33879642123547909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8745127553974511,
                                 0,
                                 0,
                                 0,
                                 0.77804436537023214,
                                 0,
                                 0,
                                 0.10976492492707894,
                                 0.018139123801271924,
                                 0,
                                 -0.10400617020910358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23370643577726788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33917258961135976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48193726638322565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43647050583015257,
                                 0,
                                 0,
                                 0,
                                 0.40990203523442692,
                                 0,
                                 0,
                                 0.16979297597593379,
                                 -1.287050572506697,
                                 0,
                                 0.72561377728763266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33315278498854217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052080087801748734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4542548580503738,
                                 0,
                                 0.48713351417368672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18254587528743368,
                                 0,
                                 0,
                                 0,
                                 0.51317626566246866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36179301432360356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12281403901133489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40684728305392537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20787726337339885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13043495855603393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21858424537895854,
                                 0,
                                 0,
                                 0,
                                 -0.38075406211153495,
                                 0,
                                 0,
                                 1.2045869342733408,
                                 0.29286934610740722,
                                 0,
                                 0.13222565028482394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36786277292528918,
                                 0,
                                 0.58050610074870457,
                                 0,
                                 0.53444115474252574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097413360561099699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60231027063948051,
                                 0,
                                 0,
                                 0,
                                 -0.51510940462169663,
                                 -0.63764480793379874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.376813527242292,
                                 0.31073182334700139,
                                 -0.42796192643112962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23338996905441833,
                                 0,
                                 0.70718041566951284,
                                 0,
                                 0.66142577897345001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65165154382313151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26867456488763636,
                                 0,
                                 0,
                                 0,
                                 0.88277244717442338,
                                 0.45962650733217303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33321001969550373,
                                 0.1524065892628505,
                                 0.30898358474336796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19816926836038348,
                                 0,
                                 0.14375925195037595,
                                 0,
                                 0.072086274359745101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014862182491332115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39215638431474042,
                                 0,
                                 0,
                                 0,
                                 0.15298191726766286,
                                 0.28095675354250965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48433563307093941,
                                 0.41501608751893065,
                                 -0.9168379447169861};

const double rot_29_20[4000] = {0.32789517277783492,
                                0,
                                0,
                                0,
                                0,
                                0.40504622219887498,
                                0,
                                0,
                                0,
                                0,
                                0.19630530436738006,
                                0,
                                -0.36322304101716707,
                                -0.18682631579509423,
                                0.64020445560767569,
                                0,
                                0,
                                0,
                                -0.2342863488270889,
                                0.24145321079386811,
                                0,
                                -0.49003868762842673,
                                0,
                                -0.27819880649077683,
                                0.43877089498439609,
                                0,
                                -0.03973738678008347,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51330286368650957,
                                0,
                                0.47422433576549716,
                                0,
                                0,
                                0,
                                0,
                                0.022996493394005391,
                                0,
                                0,
                                0,
                                0,
                                0.6109983958845504,
                                0.37544497477683858,
                                0.4581880746438497,
                                0,
                                0.47656848005469166,
                                0,
                                0,
                                0,
                                0,
                                -0.50373709890357743,
                                0,
                                0,
                                0,
                                0,
                                -0.46512390335648079,
                                0,
                                0.57362300377535946,
                                -0.24630061391757738,
                                0,
                                0.25126869112308825,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43955317300109764,
                                0,
                                -0.37095749704777259,
                                0,
                                0,
                                0,
                                0.37889215874196047,
                                0,
                                0.29273212598841292,
                                -0.48823643092110358,
                                0,
                                -0.10608491620383453,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34234314926299581,
                                0,
                                0.63554778001838919,
                                0,
                                0,
                                -0.34638955703170821,
                                0,
                                0,
                                0,
                                0,
                                -0.18179739928106209,
                                0,
                                0,
                                0,
                                0,
                                0.36051243430858493,
                                0,
                                -0.24784955746284565,
                                0.61120396875189187,
                                0.22258933531392905,
                                0,
                                0,
                                0,
                                0.3499085247996907,
                                0.3316822012519402,
                                0,
                                -0.19749820521355438,
                                0,
                                0.66562452011183804,
                                0.37987221284787381,
                                0,
                                -0.29167442199389965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4483876097387095,
                                0,
                                0.29582113186299153,
                                0,
                                0,
                                0,
                                0,
                                -0.51065136706787295,
                                0,
                                0,
                                0,
                                0,
                                1.3343216916922849,
                                0.26284996943775985,
                                -0.064722494993536661,
                                0,
                                -0.35257712906648264,
                                0,
                                0,
                                0,
                                0,
                                0.54478333758074915,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.568793784231163,
                                0,
                                0,
                                0,
                                0,
                                -0.75061115370744169,
                                0.95993569880740959,
                                0.30415474941665704,
                                0,
                                -0.45720206530214696,
                                0,
                                0,
                                0,
                                0,
                                0.16045025780388003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.8751935619368213,
                                0,
                                0,
                                0,
                                0,
                                -0.3295621226251218,
                                0.27471489380213493,
                                0.49754214018901616,
                                0,
                                0.10753236565862062,
                                0,
                                0,
                                0,
                                0,
                                0.22879000816738604,
                                0,
                                0,
                                0,
                                0.22415444502333612,
                                0,
                                0,
                                0,
                                0,
                                0.37181849903271103,
                                0,
                                0,
                                0,
                                0,
                                0.429430607155871,
                                0,
                                -0.034497691781317508,
                                0.45328466565151138,
                                -0.19794796720106633,
                                0,
                                0,
                                0,
                                -0.14985802083091843,
                                -0.59899686076944181,
                                0,
                                0,
                                -0.1667799333651617,
                                0,
                                0,
                                0,
                                0,
                                -0.032690063387641438,
                                0.34006569443842843,
                                -0.81959601930236103,
                                0,
                                0.70854865423669589,
                                0,
                                0,
                                0,
                                0,
                                0.36980155373314394,
                                0,
                                0,
                                0,
                                -0.54732654371379597,
                                0,
                                0,
                                0,
                                0,
                                -0.18270818862064644,
                                0,
                                0,
                                0,
                                0,
                                0.1832537033781311,
                                0,
                                -0.24966197751950969,
                                -0.098486679168836785,
                                -0.090889139282120376,
                                0,
                                0,
                                0,
                                -0.74311062610644785,
                                -0.031056163495408143,
                                0.15562904991182341,
                                0,
                                0,
                                0,
                                0,
                                -0.4492246196800449,
                                0,
                                0,
                                0,
                                0,
                                -0.37082535208466755,
                                0,
                                -0.57557304096269557,
                                0.077053479196283914,
                                0.22846557253102895,
                                0,
                                0,
                                0,
                                0.080097456896358443,
                                -0.49054226482093588,
                                0.0057717647505559147,
                                0,
                                0,
                                0,
                                0,
                                -0.074423768099578902,
                                0,
                                0,
                                0,
                                0,
                                -0.36316631702789137,
                                0,
                                0.52713446966363098,
                                0.47186805825825162,
                                0.47179917986171716,
                                0,
                                0,
                                0,
                                -0.37115246600948454,
                                -0.040733070039452979,
                                0,
                                0.59885349942963251,
                                0,
                                0.25379956139524246,
                                0.60322484474094273,
                                0,
                                0.20553780577367206,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37335542694336343,
                                0,
                                -0.17731325701540884,
                                0,
                                0,
                                0,
                                0,
                                0.67782178384134228,
                                0,
                                0,
                                0,
                                0,
                                -0.48396872738691288,
                                -0.38519195433893283,
                                0.81960489916592405,
                                0,
                                0.5173532906932119,
                                0,
                                0,
                                0,
                                0,
                                0.602731905613486,
                                0,
                                0,
                                0,
                                0,
                                0.048285777989020069,
                                0,
                                -0.019993921141526594,
                                -0.016068149027276171,
                                0,
                                -0.89258681228185055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29269202755342594,
                                0,
                                -0.33857155948987799,
                                0,
                                0,
                                -0.034208789948485932,
                                0,
                                0,
                                0,
                                0,
                                -0.40250777630236156,
                                0,
                                0,
                                0,
                                0,
                                0.54103842571634386,
                                0,
                                0.36597062507387979,
                                -0.35654175831541313,
                                0.38902820409806471,
                                0,
                                0,
                                0,
                                0.14814448936593411,
                                -0.33128298092702824,
                                0.63028843715907468,
                                0,
                                0,
                                0,
                                0,
                                -0.51176344038666199,
                                0,
                                0,
                                0,
                                0,
                                0.22666859585775845,
                                0,
                                0.0053714592945435791,
                                0.14366730225263746,
                                -0.25887078230696026,
                                0,
                                0,
                                0,
                                -0.28615827199369936,
                                0.34624590949917361,
                                0.11442133924831979,
                                0.39218278708137999,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0084473483017832446,
                                -1.0298268597612463,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.95786422025272411,
                                -0.38007991034879507,
                                0,
                                -0.43672366395180534,
                                -0.24525133869304622,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30513751701786562,
                                -1.4084503732562916,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44678970146445263,
                                1.0483323947233005,
                                0,
                                0,
                                0,
                                0.02648736886378545,
                                -0.43834935826858151,
                                0.69630701347900015,
                                0,
                                -0.27655403347724961,
                                -0.039074134019650868,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0071693763408653688,
                                0,
                                0.49398517454312513,
                                0,
                                0,
                                0,
                                0.01493748200710171,
                                0,
                                0,
                                -0.40687190035521914,
                                -0.16680968602288873,
                                -0.2339444287789833,
                                0,
                                -0.18387323437653075,
                                -0.075073866060982736,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46298965284356836,
                                0,
                                0.12241393820426265,
                                0,
                                0,
                                0,
                                -0.6950609663916103,
                                0,
                                0,
                                -0.32886115573567876,
                                0.15579593591370344,
                                0.22133349528578281,
                                0,
                                0.76067466897453939,
                                0.23278771024832129,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30137896395454228,
                                0,
                                0.28933912607330675,
                                0,
                                0,
                                0,
                                0.10595739998786016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76443209994170003,
                                0,
                                0,
                                0,
                                0,
                                -0.042665178303707932,
                                0.22945941054940397,
                                0.38130138346677167,
                                0,
                                -0.24223765357796406,
                                0,
                                -0.39636069457594236,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50369423041778694,
                                0.36874413664413219,
                                -0.22987164225966522,
                                0,
                                0.08528372852768018,
                                -0.16844354617820839,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10363071903483562,
                                0,
                                0.66507356174706167,
                                0,
                                0,
                                0,
                                -0.26224073092480638,
                                0,
                                0,
                                0.080339877284052161,
                                -0.040410178670520491,
                                0.27567275136733466,
                                0,
                                0.27241098205528613,
                                0.28383088596078221,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54376658476419237,
                                0,
                                -0.24239610987034607,
                                0,
                                0,
                                0,
                                -0.63773926331641606,
                                0.079149462364439746,
                                0.51633360072926682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.94606073435319971,
                                -0.14853603788826486,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27959924237797174,
                                -0.38265125287635116,
                                0,
                                -0.054844427503232394,
                                0.88306570730952982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16923406419762141,
                                0.55623170893979601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53336624166543167,
                                0.48668064402014566,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1484786911658878,
                                0,
                                0,
                                0,
                                0,
                                0.90283798332352161,
                                -0.29237956916366398,
                                0.02153373807728657,
                                0,
                                -0.21666486949939495,
                                0,
                                0.17304471711924777,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0037316992379618774,
                                0,
                                0,
                                0,
                                0,
                                0.2715493293980874,
                                -0.024243183621842218,
                                -0.32597248573827253,
                                0,
                                0.56349431801679661,
                                0,
                                -0.7084316454510764,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27497545782084476,
                                0,
                                0,
                                0,
                                0,
                                -0.26481662777328108,
                                -0.48692357883470272,
                                -0.66115684307598299,
                                0,
                                -0.41023413394710212,
                                0,
                                -0.10837741381063137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49278252278490231,
                                -0.33793214554137302,
                                -0.18582354369715581,
                                0,
                                -0.012947701985488294,
                                0.69689875583892036,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3496577743016015,
                                0,
                                -0.011841163150980771,
                                0,
                                0,
                                0,
                                0.014162263396989547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19496755358097018,
                                0,
                                0,
                                0,
                                0,
                                0.16307406589213899,
                                0.74242666425100889,
                                -0.55736350056108874,
                                0,
                                -0.028760929458061947,
                                0,
                                0.26965883533119284,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4556136018791529,
                                -0.22700699604549102,
                                0.19338530118497413,
                                0,
                                0.35817220921885923,
                                -0.56067781314522624,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3658539378114754,
                                0,
                                -0.333155086266959,
                                0,
                                0,
                                0,
                                -0.12648255961579935,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52911233959911941,
                                0,
                                0,
                                0,
                                0,
                                -0.11226407626784574,
                                -0.27015349540176803,
                                -0.010249328194868828,
                                0,
                                0.63853909148776256,
                                0,
                                0.4760428322109454,
                                0,
                                0,
                                0,
                                1.182020629154972,
                                -0.16385018036429344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.044728405338555891,
                                0.13347335950633199,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.039952616727353368,
                                0.7050100769354366,
                                0,
                                -0.66150997142042478,
                                -0.66478258816708014,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63399976207687403,
                                0.30573311540128673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68304746095601543,
                                0.56836780481683424,
                                0,
                                0,
                                0,
                                0.12256946447818473,
                                0.67261910693485205,
                                0.45899164395405428,
                                0,
                                -0.31803540099888594,
                                0.17229719244693167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36363280093091038,
                                0,
                                -0.21228543031150773,
                                0,
                                0,
                                0,
                                -0.11730378295276543,
                                -0.027502155044933061,
                                -0.44619242259118963,
                                -0.15778989562479778,
                                0,
                                0,
                                -0.14912474319592239,
                                0,
                                0.60677638323285932,
                                0,
                                -0.52385269883178354,
                                0,
                                0,
                                0.29634282865894235,
                                0,
                                0.15033898987115452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.073946551339111724,
                                -0.00094605138480993722,
                                -0.10084332835083119,
                                0,
                                0,
                                0.25285770221747333,
                                0,
                                0.60043225374244025,
                                0,
                                0.73473803361448631,
                                0,
                                0,
                                0.14108630318941717,
                                0,
                                -0.012665060864088945,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12048590167637552,
                                -0.17434070418255554,
                                0.029793048972625413,
                                0,
                                0,
                                0.52246312399862593,
                                0,
                                -0.13566778898843598,
                                0,
                                -0.030151412392946553,
                                0,
                                0,
                                -0.17364899454311111,
                                0,
                                0.79483601749841393,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10839636042057019,
                                0,
                                0,
                                -0.24368301071675888,
                                0,
                                0,
                                0,
                                0.33734797870071292,
                                0.29974499148329914,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.78325969463026057,
                                -0.33424893634912473,
                                0,
                                0,
                                0,
                                0,
                                -0.094316899190690487,
                                0,
                                0,
                                0,
                                0.22464757781182565,
                                0,
                                0,
                                0,
                                0,
                                0.20004998764912335,
                                0,
                                0.51873711999136329,
                                1.3225535025833799,
                                -1.0800302767433185,
                                0,
                                0,
                                -0.18386741082113667,
                                -0.4911171430693268,
                                0.24145131979296969,
                                0,
                                0,
                                -0.16582119019229408,
                                0,
                                0.14767591834735053,
                                0,
                                0.093478911452509875,
                                0,
                                0,
                                -0.76071986580449757,
                                0,
                                -0.17308992489196368,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47687837556232449,
                                0,
                                0,
                                0.267491056785715,
                                0,
                                0,
                                0,
                                -0.33984077656782119,
                                -0.5924015980351085,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41750495614839894,
                                -0.24554786555670513,
                                -0.078991227192469995,
                                -0.098993429801783467,
                                0.76750291062776999,
                                0,
                                0,
                                -0.38372931213901063,
                                0,
                                -0.043762200561878684,
                                0,
                                0.1996547912277804,
                                0,
                                0,
                                0.36494397370681458,
                                0,
                                0.26961178435443733,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.82787088943644149,
                                0,
                                0,
                                0,
                                -0.0074197792920567274,
                                0,
                                0,
                                0,
                                0,
                                -0.59444268822042279,
                                0,
                                0.36704581245214474,
                                -0.18895446934202659,
                                0.45033894097349547,
                                0,
                                0,
                                -0.6698630786610944,
                                0.22843904712843077,
                                -0.3902462757228185,
                                0,
                                0,
                                -0.5038078754958184,
                                0,
                                -0.040393311725911415,
                                0,
                                0.10171392643504948,
                                0,
                                0,
                                -0.058343532461920887,
                                0,
                                0.27857353826851272,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59875836385087899,
                                0,
                                0,
                                0.5985035945639734,
                                0,
                                0,
                                0,
                                0.29955486822444455,
                                -0.33519905350206347,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19231992773462608,
                                0.21024602222902192,
                                0,
                                0,
                                0,
                                -0.61197053920471367,
                                0,
                                0,
                                0.28277337648481049,
                                0,
                                0,
                                0,
                                0.71278705073972703,
                                0.079120787185977384,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10352561556983711,
                                0.14313715433314689,
                                0.44913463575060364,
                                -0.50426666606435766,
                                -0.40422559233840838,
                                0,
                                0,
                                -0.3325066731875575,
                                0,
                                -0.325301213272362,
                                0,
                                0.35264172518733172,
                                0,
                                0,
                                0.1023574687950722,
                                0,
                                0.17140616713587861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79802195335502046,
                                0,
                                0,
                                0,
                                0.19423638992316888,
                                0,
                                0,
                                0,
                                0,
                                -1.2125596103299687,
                                0,
                                0.47529806072950137,
                                -0.094771232379235931,
                                -0.46660080548879013,
                                0,
                                0,
                                0.53737638819600064,
                                0.4615752698715645,
                                0.031550013154099561,
                                0,
                                0,
                                -0.31895009362016463,
                                0,
                                0.34888676443970301,
                                0,
                                -0.039077007270228219,
                                0,
                                0,
                                -0.36927194894295046,
                                0,
                                0.36856419105435445,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1819126856274868,
                                0,
                                0,
                                0,
                                1.0798372446458511,
                                0,
                                0,
                                0,
                                0,
                                0.47461150917438932,
                                0,
                                0.38133823828618962,
                                0.06178994710663132,
                                0.45895584165938885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13424327900659716,
                                0,
                                0,
                                0,
                                -0.16846547485196495,
                                0,
                                0,
                                0,
                                0,
                                0.82454063609637451,
                                0,
                                1.2281988609773784,
                                -0.53700803667243147,
                                0.40476231577598915,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45917580936835078,
                                0,
                                0,
                                0,
                                0.46687595683973593,
                                0,
                                0,
                                0,
                                0,
                                0.5707951903448425,
                                0,
                                0.087263875563578022,
                                -0.74129598628624149,
                                -1.1860823179270681,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16677891301984421,
                                0,
                                0,
                                -0.18188121807921853,
                                0,
                                0,
                                0,
                                0.34686464552181706,
                                -0.3898532581231034,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38676913056613277,
                                -0.71917522978818038,
                                0,
                                0,
                                0,
                                -0.0015871372475057544,
                                0,
                                0,
                                0.63072895302426035,
                                0,
                                0,
                                0,
                                -0.22932729178217187,
                                0.53722362143088931,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12206143665133236,
                                -0.49606375428509736,
                                -0.33062214772388437,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58982286703708031,
                                0,
                                -0.0024162455621690865,
                                0,
                                0,
                                0,
                                0,
                                -0.0035408085832446673,
                                0,
                                0,
                                0,
                                -0.73169513720105195,
                                0,
                                0.086033897871149886,
                                0,
                                -0.22949829528521765,
                                -0.57624350994097917,
                                0,
                                0,
                                -0.1481794034376723,
                                0,
                                0.45391652669511129,
                                0,
                                0,
                                0.45610425106025487,
                                0,
                                0.0069982864122937645,
                                0,
                                -0.38558448083718566,
                                0,
                                0.17470301998407095,
                                0,
                                0,
                                0,
                                0,
                                -0.4348245526051755,
                                -0.30431761924110817,
                                0,
                                0,
                                0.54239723903623649,
                                0,
                                -0.41287755341047128,
                                0,
                                0,
                                -0.031878435486174458,
                                0,
                                0.22636416680575999,
                                0,
                                -0.19715197206887941,
                                0,
                                -0.40314995385517105,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44906874337189739,
                                -0.74863087685270191,
                                0,
                                0,
                                0,
                                0,
                                0.70493664941314771,
                                0,
                                0.68523669827472644,
                                0,
                                0,
                                0,
                                -0.72357640170519966,
                                0,
                                0,
                                -0.74646296293407155,
                                0,
                                0,
                                0,
                                0,
                                -0.36944054885138428,
                                -0.73079010919719167,
                                0,
                                0,
                                0,
                                0,
                                0.0086988230116623634,
                                0,
                                -1.1232355635657467,
                                0,
                                0,
                                0,
                                0.34497555839706445,
                                0,
                                0,
                                0.23890711319361888,
                                0,
                                0,
                                0.1475131667520318,
                                0.036577098751010534,
                                0,
                                0,
                                0.36123062059261135,
                                0,
                                -0.14430484878043998,
                                0,
                                0,
                                0.088596575850531989,
                                0,
                                -0.84192947930418816,
                                0,
                                -0.30816237298790772,
                                0,
                                0.11803339081411823,
                                0,
                                0,
                                0,
                                -0.81786773034348836,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.081475054886477258,
                                0,
                                -0.22915590475363432,
                                0,
                                0,
                                0,
                                0,
                                0.02346852610121631,
                                0,
                                0,
                                0,
                                0.34990615994301527,
                                0,
                                0.385949050947336,
                                0,
                                0.38284095049187505,
                                -0.34133299361286162,
                                0,
                                0,
                                -0.22620303756072363,
                                0,
                                -0.45537592149210571,
                                0,
                                0,
                                -0.35896838841763767,
                                0,
                                0.2014929614321963,
                                0,
                                -0.42623568851093113,
                                0,
                                0.35672814645190998,
                                0,
                                0,
                                0,
                                -0.032524647749566898,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3558326562859721,
                                0,
                                0.51811426545521033,
                                0,
                                0,
                                0,
                                0,
                                -0.70787292704652971,
                                0,
                                0,
                                0,
                                0.31195564314161861,
                                0,
                                0.07404371551801997,
                                0,
                                0,
                                0,
                                0.57699308314356323,
                                -0.44792155538279432,
                                0,
                                0,
                                0,
                                0,
                                -0.8839911340839105,
                                0,
                                0.30035477781286934,
                                0,
                                0,
                                0,
                                -1.0421930873661878,
                                0,
                                0,
                                0.53391878146634841,
                                0,
                                0,
                                0.085811423122659714,
                                0.093856887046651058,
                                0,
                                0,
                                -0.46403897588541582,
                                0,
                                -0.51551936651784092,
                                0,
                                0,
                                0.62479489198373683,
                                0,
                                -0.060677069367827872,
                                0,
                                -0.030650210135117789,
                                0,
                                -0.32824548259263175,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74963381731709111,
                                0.53014893043581091,
                                0,
                                0,
                                0,
                                0,
                                0.2163520844009954,
                                0,
                                -0.76712311489970419,
                                0,
                                0,
                                0,
                                -0.073519530157452245,
                                0,
                                0,
                                -0.1364203043633454,
                                0,
                                0,
                                0.37262304371646149,
                                -0.38169089193608019,
                                0,
                                0,
                                0.37604895003958538,
                                0,
                                -0.14462183265740791,
                                0,
                                0,
                                0.35311061815727274,
                                0,
                                0.098790399799969036,
                                0,
                                0.58173247628402258,
                                0,
                                0.2833311089271135,
                                0,
                                0,
                                0,
                                0.27937978061419033,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28292250894955095,
                                0,
                                0.3314138892764793,
                                0,
                                0,
                                0,
                                0,
                                0.51814102022619579,
                                0,
                                0,
                                0,
                                0.17557479985482513,
                                0,
                                0.65785256625112631,
                                0,
                                0.56279541477057293,
                                -0.30092515641582146,
                                0,
                                0,
                                -0.0018650765951190951,
                                0,
                                0.29501489176220669,
                                0,
                                0,
                                -0.16009643403575452,
                                0,
                                -0.064653554932702487,
                                0,
                                -0.039816097447310364,
                                0,
                                -0.68867396822068572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38406653288633807,
                                0.47465185666007215,
                                0,
                                0,
                                0,
                                0,
                                0.88312026876671013,
                                0,
                                -0.40500325094426526,
                                0,
                                0,
                                0,
                                -0.65315880631556933,
                                0,
                                0,
                                0.58534440353020722,
                                0,
                                0,
                                0.35634337546882461,
                                0.46090682918745168,
                                0,
                                0,
                                0.3813715531472377,
                                0,
                                0.14693983574541425,
                                0,
                                0,
                                0.33698425257684778,
                                0,
                                0.42619748279447361,
                                0,
                                -0.44144916672267409,
                                0,
                                0.058895407832543406,
                                0,
                                0,
                                0,
                                -0.060184452551088452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60860320482463703,
                                0,
                                -0.16936586168647966,
                                0,
                                0,
                                0,
                                0,
                                0.32933133336965237,
                                0,
                                0,
                                0,
                                0.45426509967684381,
                                0,
                                -0.53148778699050092,
                                0,
                                0,
                                0,
                                0.34846575686436576,
                                -0.19952981492089758,
                                0,
                                0,
                                0,
                                0,
                                1.1772011030710154,
                                0,
                                0.39278066163963188,
                                0,
                                0,
                                0,
                                0.32725595201637686,
                                0,
                                0,
                                0.83459716323660516,
                                0,
                                0.37289179159790647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26155480243869622,
                                0,
                                -0.7352002311585385,
                                0,
                                0,
                                0,
                                0,
                                -0.34845855726573266,
                                0,
                                0,
                                0,
                                0.087682900350586832,
                                0,
                                0.35058488278729383,
                                -0.54567058661865642,
                                0,
                                0,
                                0,
                                0,
                                -0.97660319424905628,
                                0,
                                0,
                                0,
                                0,
                                0.73919405026033214,
                                0.23792664426841081,
                                0,
                                -0.43082433318906838,
                                0,
                                0,
                                0,
                                -0.9444252419782504,
                                0,
                                0,
                                0,
                                0.33806082141986266,
                                -0.26997274472868149,
                                0,
                                0,
                                0,
                                0.53973877052605934,
                                0,
                                0,
                                -0.34971240066050091,
                                0,
                                0,
                                0.63124347033325034,
                                0,
                                -0.027286914474028173,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14390460586290624,
                                0.37367124758290793,
                                0,
                                0,
                                0,
                                0.78263662085881225,
                                0,
                                0,
                                0.43709030475572214,
                                0,
                                0,
                                -0.1897403355111334,
                                0,
                                0.0095840179802572263,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22620562738318728,
                                -0.49853811346161758,
                                0,
                                0,
                                0.24814665112235265,
                                0.087703842282278593,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51402864110217161,
                                0.36588742720002665,
                                0,
                                -0.42746113322195101,
                                -0.22405348798936647,
                                0,
                                0,
                                0,
                                -0.5523477021617601,
                                0.31470891526273359,
                                0,
                                0,
                                0.35173316976742908,
                                0.56224378996730739,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37032681155850411,
                                0.0072812745066971954,
                                0,
                                0.043536821800800943,
                                0.13017524084590198,
                                -0.14510929918602383,
                                0,
                                0,
                                0,
                                0,
                                0.22856823416935104,
                                0,
                                0,
                                0,
                                0,
                                0.70154552345097654,
                                -1.4290406918262279,
                                0,
                                0.46060346431534316,
                                0,
                                0,
                                0,
                                -0.24362874479950547,
                                0,
                                0,
                                0,
                                -0.11422080826621328,
                                -0.47746320409491333,
                                0,
                                0,
                                0,
                                0.013386690133880884,
                                0,
                                0,
                                0.37135042943141705,
                                0,
                                0,
                                0.017197517313807687,
                                0,
                                -0.787785755253949,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65736296446803077,
                                -0.29789395929734064,
                                0,
                                0,
                                -0.30974648532758309,
                                -0.25850887804848599,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12918085108851798,
                                0.44664584326418577,
                                0,
                                -0.15187862281182601,
                                0.27769781975545538,
                                0,
                                0,
                                0,
                                0.24517226496612254,
                                0.56682687252380781,
                                0,
                                0,
                                -0.56714817127802597,
                                0.16307447422530746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19607454023735194,
                                0.4289755941592065,
                                0,
                                -0.21856030501044768,
                                -0.010659836236938003,
                                0,
                                0.42176662036743218,
                                -0.60546135648443433,
                                0,
                                0,
                                0,
                                0.15957525071733686,
                                0,
                                0,
                                0.1315560744481199,
                                0,
                                0,
                                -0.53286842000457701,
                                0,
                                0.35890033344090044,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40202612231992296,
                                0,
                                0,
                                0,
                                0,
                                -0.0045507249616219062,
                                0,
                                0,
                                0,
                                0,
                                0.43424688364581349,
                                -0.34073786793011035,
                                0,
                                -0.45071377184606398,
                                0,
                                0,
                                0,
                                0.77804180713314797,
                                0,
                                0,
                                0.28558742649758784,
                                0,
                                0,
                                0,
                                0,
                                -1.1217273182547869,
                                0,
                                0,
                                0,
                                0,
                                -0.22500387703485203,
                                0.16574959619595719,
                                0,
                                0.36195364633766713,
                                0,
                                0,
                                0,
                                0.0030023776458549811,
                                0,
                                0,
                                0,
                                -0.70700479378968328,
                                -0.42598678320821876,
                                0,
                                0,
                                0,
                                0.036531128997368316,
                                0,
                                0,
                                0.17944096625855668,
                                0,
                                0,
                                0.28416566398012549,
                                0,
                                0.45210150823396783,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0183848260089796,
                                0,
                                0,
                                0,
                                0,
                                -0.31259939650328455,
                                0,
                                0,
                                0,
                                0,
                                0.42058830852193363,
                                -0.01769749913627261,
                                0,
                                -0.13834166818207488,
                                0,
                                0,
                                0,
                                -0.87850037898273792,
                                0,
                                0,
                                0,
                                -0.41739321016713415,
                                -0.10707572509611224,
                                0,
                                0,
                                0,
                                0.26302849994183802,
                                0,
                                0,
                                -0.70657349212796916,
                                0,
                                0,
                                -0.44781207444257404,
                                0,
                                -0.21295997658101898,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.011219837844888319,
                                -0.16040305920719039,
                                0,
                                0,
                                -0.30552880471111099,
                                -0.20376437250560653,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63403473371351393,
                                -0.062114724757680644,
                                0,
                                0.65785008760743513,
                                0.025537883093673545,
                                0,
                                0,
                                0,
                                0.24306523068990732,
                                -0.40383893802616277,
                                0,
                                0,
                                -0.18031760659948601,
                                0.67012067651371443,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28209264907369402,
                                0.19487834094891951,
                                0,
                                0.30856081738064645,
                                0.28895265523536462,
                                -0.77119186269102791,
                                0,
                                0,
                                0,
                                0,
                                0.30168385665345865,
                                0,
                                0,
                                0,
                                0,
                                1.0907371444846161,
                                0.61012183153547495,
                                0,
                                0.96199658856146264,
                                0,
                                0,
                                0,
                                0.056618382607888193,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30058554287699601,
                                -0.13235028192183687,
                                0,
                                0,
                                -0.31869255657404605,
                                0.256918477996604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1338239275335027,
                                -0.10883008037449558,
                                0,
                                0.045183634151119756,
                                -0.83232523304706107,
                                0,
                                0,
                                0,
                                0.04415046744627317,
                                0.18987603136100309,
                                0,
                                0,
                                0.41192213838497432,
                                -0.16180570938159894,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20979642836152163,
                                0.65489007533481447,
                                0,
                                0.46317137773807737,
                                -0.28055946959184941,
                                0.7293573227025778,
                                0,
                                0,
                                0,
                                0,
                                0.29016766389572135,
                                -0.55303409415969729,
                                0,
                                0,
                                0,
                                0.19767427056744913,
                                0,
                                0.18850417615540976,
                                0,
                                0,
                                -0.058180509399521602,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37160142034254556,
                                -0.20173069075634109,
                                0.26771622901534953,
                                0,
                                0,
                                0,
                                0,
                                -0.13846175519962253,
                                0,
                                0,
                                0,
                                0,
                                0.68987836227097354,
                                0,
                                0,
                                0.2035492073668437,
                                0.22595603107662179,
                                -0.40243373783264913,
                                0,
                                0,
                                -0.068478035735202628,
                                -0.19613497061391233,
                                0.036449686306811113,
                                0,
                                0,
                                0,
                                0,
                                -0.85056307208379589,
                                0,
                                0,
                                0,
                                0,
                                -0.3116334071475006,
                                0,
                                0,
                                -0.10500153336567779,
                                -0.24908287339419477,
                                -0.24874230123127056,
                                0,
                                0,
                                0.25397651334468607,
                                -0.58742925048552586,
                                -0.2056086333374626,
                                0,
                                0,
                                0,
                                0,
                                0.11562382027911058,
                                0,
                                0,
                                0,
                                0,
                                0.2549391572439097,
                                0,
                                0,
                                0.29475935370316469,
                                -0.60502356990285489,
                                0.12980160936868906,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3725130369802605,
                                0,
                                0,
                                1.315145408963289,
                                0,
                                0.271128649116121,
                                0,
                                0.3773872499882025,
                                0,
                                0,
                                -0.87350573850830815,
                                0,
                                0,
                                0,
                                0,
                                -0.51700347202722274,
                                0.36087190425805826,
                                0,
                                0,
                                0,
                                0,
                                -0.24405734940403906,
                                0.54675523580711238,
                                0,
                                0,
                                0,
                                0.69595421867188123,
                                0,
                                -0.15891317207769953,
                                0,
                                0,
                                -0.040749482077208188,
                                0,
                                0,
                                0,
                                0,
                                0.55627668544541076,
                                0,
                                0,
                                0,
                                0,
                                0.04144868465409067,
                                0.42525484268343394,
                                0,
                                0,
                                0,
                                -0.66284914547376628,
                                0,
                                -0.25528916201340995,
                                0,
                                0,
                                0.058779491727893957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41632218725036929,
                                0,
                                0,
                                0.45835480466760331,
                                0,
                                0.6574747630573855,
                                0,
                                0.21203429667822099,
                                0,
                                0,
                                0.27847206994028068,
                                0,
                                0,
                                0,
                                0,
                                -1.0496286668530492,
                                0,
                                -0.22522067702057752,
                                0.0035755769259016024,
                                0.17357599712637323,
                                0,
                                0,
                                0,
                                0,
                                -0.30866865251054776,
                                0,
                                0,
                                0,
                                0,
                                0.29069964024511008,
                                0,
                                0,
                                -0.16976251372259615,
                                0.0046352201113144809,
                                0.84291803925495756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2766914312467823,
                                0,
                                0,
                                0.39872801801785734,
                                0,
                                0.7575279624853104,
                                0,
                                0.015722042618131121,
                                0,
                                0,
                                0.59904498527669714,
                                0,
                                0,
                                0,
                                0,
                                0.79449535629254397,
                                0.1083577778295991,
                                0,
                                0,
                                0,
                                0,
                                -0.4766521929891348,
                                -0.15031399265629042,
                                0,
                                0,
                                0,
                                -0.02027073351405035,
                                0,
                                0.15550376329183632,
                                0,
                                0,
                                0.84491103642873755,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43370570033490652,
                                0,
                                0,
                                -0.29921418267534222,
                                0,
                                0.5273540453848562,
                                0,
                                0.0021014024700090062,
                                0,
                                0,
                                -0.69570678816841136,
                                0,
                                0,
                                0,
                                0,
                                0.081914057336168161,
                                -0.02537736797677086,
                                0,
                                0,
                                0,
                                0,
                                0.43044678675198245,
                                0.43722401180467746,
                                0,
                                0,
                                0,
                                0.0066272362606924077,
                                0,
                                0.7677721638049243,
                                0,
                                0,
                                0.18272575269167154,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48462148046216141,
                                -0.34585740485221134,
                                0.22212507112484636,
                                0,
                                0,
                                0,
                                0,
                                0.36863944996389453,
                                0,
                                0,
                                0,
                                0,
                                -0.17175504044604992,
                                0,
                                0,
                                -0.59610964100042285,
                                -0.25652367345433508,
                                -0.098179386007826511,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.91607339687181166,
                                0,
                                0,
                                -0.049265250095819287,
                                0,
                                0.470278929135927,
                                0,
                                -0.51206655517821353,
                                0,
                                0,
                                -0.26853913886902064,
                                0,
                                0,
                                0,
                                0,
                                -0.47770225999506388,
                                -0.12641279581419285,
                                0,
                                0,
                                0,
                                0,
                                0.66486013135483013,
                                0.024722230924956859,
                                0,
                                0,
                                0,
                                0.19169975408300494,
                                0,
                                -0.5102790483245867,
                                0,
                                0,
                                0.49420250830286228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58517544739975569,
                                0.0035135998791037265,
                                -0.049788428892539718,
                                0,
                                0,
                                0,
                                0,
                                -0.092197936210669851,
                                0,
                                0,
                                0,
                                0,
                                0.41232227568641561,
                                0,
                                0,
                                -0.67254402366788235,
                                0.056483637783052064,
                                -0.14512918089577648,
                                0,
                                0,
                                0.056159291403469348,
                                -0.65153704179757255,
                                -0.25974489133827461,
                                0,
                                0,
                                0,
                                0,
                                -0.020288964833029166,
                                0,
                                0,
                                0,
                                0,
                                -0.20207840916498393,
                                0,
                                0,
                                -0.027083492138341297,
                                0.66889884084640228,
                                0.12438532148807158,
                                0,
                                0,
                                0.40193602818998403,
                                -0.17781925071082966,
                                0.85750222201373028,
                                0,
                                0,
                                0,
                                0,
                                0.062597542209073084,
                                0,
                                0,
                                0,
                                0,
                                -0.19263196434805002,
                                0,
                                0,
                                0.15311540451182246,
                                0.06637870993732399,
                                0.051397435247749035,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37450024875471533,
                                0,
                                0,
                                0.25412589885618381,
                                0,
                                -0.27850167521962343,
                                0,
                                -0.90977570399804641,
                                0,
                                0,
                                -0.13978008142844101,
                                0,
                                0,
                                0,
                                0,
                                -0.014761935188369713,
                                0.37202725892134375,
                                0,
                                0,
                                0,
                                0,
                                -0.16735205867838637,
                                0,
                                -0.1098283467259006,
                                0,
                                0,
                                -0.61627622843611385,
                                0,
                                0.19120828569709922,
                                0,
                                0,
                                0,
                                0.13978175960287251,
                                -0.5466271889686567,
                                0.29466849006793644,
                                0,
                                0,
                                -0.21880845991811704,
                                0,
                                0,
                                -0.28001478250172385,
                                0,
                                1.0217536260520086,
                                0,
                                0,
                                0.99792270825577845,
                                0,
                                0,
                                0,
                                -0.46434578601752047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52798606791420355,
                                0,
                                0,
                                0.52457518192533803,
                                0.30892833014781373,
                                0,
                                0,
                                0,
                                0,
                                -0.047717309872603739,
                                0,
                                0,
                                0.33650685233048994,
                                0,
                                0,
                                -0.63052214660470263,
                                0.3410457222341724,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22499051044028515,
                                -0.49733309318021263,
                                0,
                                0,
                                0,
                                0,
                                -0.31545269596434378,
                                0,
                                0,
                                0.44189696258116895,
                                0,
                                0,
                                -0.42745177003982188,
                                -0.47385727809099798,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.86042677912221432,
                                0,
                                0,
                                -0.62784254856019051,
                                0,
                                -0.89717666463209889,
                                0,
                                0,
                                1.1127485235483765,
                                0,
                                0,
                                0,
                                -0.32706716923223128,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23922495867695348,
                                0.3036257510174355,
                                0,
                                0,
                                0,
                                0,
                                0.093656308960010842,
                                0,
                                0.44637865737172322,
                                0,
                                0,
                                -0.027871761432484179,
                                0,
                                -0.15050410664613775,
                                0,
                                0,
                                0,
                                0.4422603036896986,
                                0.45988340005240508,
                                0.51891305079746841,
                                0,
                                0,
                                -0.70872740129248368,
                                0,
                                0,
                                0.63691662236235813,
                                0,
                                -0.96386208973241827,
                                0,
                                0,
                                0.5349959618315715,
                                0,
                                0,
                                0,
                                -0.31592234171391248,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4480336282031841,
                                0.76079596082443324,
                                0,
                                0,
                                0,
                                0,
                                0.17068340086942504,
                                0,
                                -0.4286029055822117,
                                0,
                                0,
                                0.39233028118506691,
                                0,
                                0.1393899801470489,
                                0,
                                0,
                                0,
                                0.04746246555710712,
                                0.083738786879551275,
                                -0.16043299480591183,
                                0,
                                0,
                                0,
                                -0.30866667274202431,
                                0.17976435130266552,
                                0,
                                0,
                                0,
                                0,
                                -0.81990956582379881,
                                0,
                                0,
                                -0.30553338846473155,
                                0,
                                0,
                                -0.10175055282516308,
                                0.31057066916043768,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17738975545454233,
                                0,
                                0,
                                -0.3796534276555788,
                                0,
                                0.88402129370816962,
                                0,
                                0,
                                0.36189616900419153,
                                0,
                                0,
                                0,
                                -0.43154279196949596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0720990083029933,
                                -0.0062357812088157938,
                                0,
                                0,
                                0,
                                0,
                                -0.12732513680040622,
                                0,
                                0.059748798601986397,
                                0,
                                0,
                                0.50913394788265898,
                                0,
                                -0.54744809862149901,
                                0,
                                0,
                                0,
                                0.19610951893562456,
                                -0.58665318244877729,
                                0.19657519724465861,
                                0,
                                0,
                                0,
                                0.11690919266943342,
                                -0.2825295363501838,
                                0,
                                0,
                                0,
                                0,
                                0.19602244745773542,
                                0,
                                0,
                                -0.75874811453966817,
                                0,
                                0,
                                -0.52682700944918692,
                                -0.12181585549154139,
                                0,
                                0,
                                0,
                                0,
                                0.19966083337579213,
                                0,
                                0,
                                0,
                                0,
                                -0.63357078933849909,
                                0,
                                0.1695917832836204,
                                0,
                                0,
                                -0.15003344800570748,
                                0,
                                -0.23304267207485793,
                                0,
                                0,
                                0,
                                0.28865004418497781,
                                0.13794977159952287,
                                -0.59227892376374103,
                                0,
                                0,
                                -0.5674533576180627,
                                0,
                                0,
                                -0.19202890342060622,
                                0,
                                -0.14534314713971844,
                                0,
                                0,
                                -0.69062346078654335,
                                0,
                                0,
                                0,
                                -1.1660562318370402,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.031235014754546986,
                                0,
                                0,
                                -0.15296039778912973,
                                -0.63114987748747531,
                                0,
                                0,
                                0,
                                0,
                                0.15040806586999297,
                                0,
                                0,
                                0.12194045693273851,
                                0,
                                0,
                                0.014874994698492967,
                                0.7352139974679065,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73611167035699032,
                                0.38305972445287678,
                                0,
                                0,
                                0,
                                0,
                                0.40609552156100653,
                                0,
                                0,
                                0.087013705673048294,
                                0,
                                0,
                                -0.36277495583094049,
                                0.085523272162169567,
                                0,
                                0,
                                0,
                                0,
                                -0.38717139481157703,
                                0,
                                0,
                                0,
                                0,
                                -0.041770890994514517,
                                0,
                                -0.53198436730431542,
                                0,
                                0,
                                0.040341767036210958,
                                0,
                                0.17861371040286358,
                                0,
                                0,
                                0,
                                0.7221173866946714,
                                0.086636023034242393,
                                0.053446237319342241,
                                0,
                                -0.010028177203291216,
                                0,
                                0,
                                0,
                                0,
                                -0.66935731385984087,
                                0,
                                -0.32388444491456408,
                                0,
                                0,
                                0.13692616322790907,
                                0,
                                -0.0020411305578078576,
                                0,
                                0,
                                0,
                                -0.35774384186306724,
                                0.27277518313714655,
                                0.47520436768824137,
                                0,
                                0.026287664061962229,
                                0,
                                0,
                                0,
                                0,
                                0.25822723403884329,
                                0,
                                -0.42981808386743298,
                                0,
                                0,
                                -0.40422775868744198,
                                0,
                                -0.73173971284064754,
                                0,
                                0,
                                0,
                                -0.10678122420641095,
                                0.19388035801512424,
                                -0.0070112617027265449,
                                0,
                                0,
                                -0.92179823803935246,
                                0,
                                0,
                                -0.70709541893834249,
                                0,
                                0.085425874526908641,
                                0,
                                0,
                                0.1944023393970124,
                                0,
                                0,
                                0,
                                1.1174335373691346,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48834287929805509,
                                -0.24287750689962723,
                                0,
                                -0.51302045361544413,
                                0,
                                0,
                                0,
                                0,
                                -0.58475958950072937,
                                0,
                                0,
                                0.042036920233779765,
                                0,
                                -0.16059071147589365,
                                0,
                                0,
                                0.13341257190642503,
                                -0.2224897795968401,
                                0,
                                0,
                                -0.49093752928305623,
                                0,
                                0.69598105662819165,
                                0,
                                0.29871273981089952,
                                0,
                                0,
                                0.82435196041112158,
                                0,
                                0,
                                -1.1999270079628093,
                                0,
                                0,
                                0,
                                0,
                                0.19572715139455962,
                                0,
                                0,
                                0,
                                0.56874002703138327,
                                0,
                                0.60929971591325605,
                                0,
                                -0.23642426338940026,
                                0,
                                0,
                                0,
                                0,
                                -0.27422706500598992,
                                0,
                                0,
                                0.072455028407473684,
                                0,
                                0.086495438294999963,
                                0,
                                0,
                                -0.53246548137970928,
                                -0.35963530042676894,
                                0,
                                0,
                                0.26845616127340904,
                                0,
                                0.81196991402140972,
                                0,
                                -0.66022011699860705,
                                0,
                                0,
                                -0.35599496228269889,
                                0,
                                0,
                                -0.012238459115823441,
                                0,
                                0,
                                0,
                                0,
                                0.55339257171152667,
                                0,
                                0,
                                0,
                                -1.2247129613385708,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32559831983668358,
                                0.18279124522559415,
                                0,
                                0,
                                -0.50244787931330459,
                                0,
                                0,
                                -0.2554986842667879,
                                0,
                                0.72579596308863903,
                                0,
                                0,
                                0,
                                0.12672752528219819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18007105957847927,
                                -0.076144086647982834,
                                0,
                                0,
                                -0.0083711997804201948,
                                0,
                                0,
                                -0.30322812571750535,
                                0,
                                -0.3266657682323939,
                                0,
                                0,
                                0,
                                0.87352652748731863,
                                0,
                                0,
                                0,
                                0.60286828559746453,
                                0,
                                0.43926232145097188,
                                0,
                                0,
                                -0.75603569784404445,
                                0,
                                0,
                                -0.5392248680137891,
                                0,
                                0,
                                0,
                                0,
                                -1.2185792426671471,
                                0,
                                0,
                                0,
                                -0.31005617875725,
                                0,
                                0.37969185495147717,
                                0,
                                0.16517848278722508,
                                0,
                                0,
                                0,
                                0,
                                -0.30597318452539274,
                                0,
                                0,
                                -0.078839318398554376,
                                0,
                                0.58933677102515103,
                                0,
                                0,
                                0.089122192439890696,
                                0.47375686394594946,
                                0,
                                0,
                                -0.38601654800009932,
                                0,
                                0,
                                0,
                                0,
                                -0.33249949792457906,
                                -0.32827592529956162,
                                0,
                                0,
                                -0.82316619642710176,
                                0,
                                0,
                                0.037503934030764803,
                                0,
                                -0.3122899971010536,
                                0,
                                0,
                                0,
                                -0.07172744559229316,
                                0,
                                0,
                                0,
                                -1.0498496143989164,
                                0,
                                -0.69385231139768566,
                                0,
                                0,
                                -0.16244794535103332,
                                0,
                                0,
                                -1.1858309642644178,
                                0,
                                0,
                                0,
                                0,
                                -0.16659288831678892,
                                0,
                                0,
                                0,
                                -0.41271017602598292,
                                0,
                                0.27905541567297476,
                                0,
                                -0.55365729578178091,
                                0,
                                0,
                                0,
                                0,
                                0.34314865450153698,
                                0,
                                0,
                                0.0028201627048344002,
                                0,
                                0.28043088320164877,
                                0,
                                0,
                                0.61048714965576723,
                                -0.13561255155332344,
                                0,
                                0,
                                0.16764819450387553,
                                0,
                                0,
                                0,
                                0,
                                -0.74841037760386775,
                                0.51815298777971508,
                                0,
                                0,
                                0.040020293292580791,
                                0,
                                0,
                                -0.3939091968770892,
                                0,
                                0.078165729695124503,
                                0,
                                0,
                                0,
                                0.09232241001752324,
                                0,
                                0,
                                -0.17813832023738069,
                                0,
                                -0.23183520627226711,
                                0,
                                0,
                                0,
                                0,
                                -0.44146103536888942,
                                0,
                                0,
                                -0.092350048257612907,
                                0,
                                -0.062365992535949266,
                                0,
                                0,
                                0.083635899895251997,
                                0.51948375020304571,
                                0,
                                0,
                                0.6560144444539624,
                                0,
                                0,
                                0,
                                0,
                                -0.20647270469408618,
                                -0.73498232299495914,
                                0,
                                0,
                                0.2519755846423688,
                                0,
                                0,
                                -0.51294055611201816,
                                0,
                                0.28726348070348517,
                                0,
                                0,
                                0,
                                -0.089721738697970427,
                                0,
                                0,
                                0,
                                -0.17718229980419661,
                                0,
                                -0.43417125528700451,
                                0,
                                0,
                                -1.407897099881229,
                                0,
                                0,
                                -0.16532885463234259,
                                0,
                                0,
                                0,
                                0,
                                0.33489349493542975,
                                0,
                                0,
                                0,
                                0.96514547555549146,
                                0,
                                -0.1624277317716406,
                                0,
                                0.42760839785982557,
                                0,
                                0,
                                0,
                                0,
                                -0.35082459513067343,
                                0,
                                0,
                                -0.30110866371855233,
                                0,
                                0.32528024863592014,
                                0,
                                0,
                                0.31841623588254447,
                                -0.55173304950889923,
                                0,
                                0,
                                0.25577034380408475,
                                -0.50109846432864324,
                                0,
                                -0.16521230280054355,
                                0,
                                0,
                                0,
                                0,
                                0.097787826355132446,
                                0,
                                0,
                                0.46161626439352971,
                                0,
                                0.62979763959153512,
                                0,
                                0,
                                -0.30315863003403487,
                                -0.060073492789736664,
                                0,
                                0,
                                0.082426592673558965,
                                0,
                                0,
                                0,
                                0,
                                -0.38503916737503352,
                                -0.21057735335506234,
                                0,
                                0,
                                0.069138596431022076,
                                0,
                                0,
                                0.6504568483421056,
                                0,
                                0.4246816041405006,
                                0,
                                0,
                                0,
                                0.44628835507345499,
                                0,
                                0,
                                0,
                                0.54092281021169242,
                                0,
                                -1.0466935612818964,
                                0,
                                0,
                                0.31590778630126393,
                                0,
                                0,
                                -0.46822643084978199,
                                0,
                                0,
                                0,
                                0,
                                -0.41845898209007487,
                                0,
                                0,
                                0,
                                0.24618629197639308,
                                0,
                                0.19624179717719353,
                                0,
                                0.28844694437710616,
                                0,
                                0,
                                0,
                                0,
                                -0.2096591264159024,
                                0,
                                0,
                                0.82126429389101507,
                                0,
                                -0.18554791454905936,
                                0,
                                0,
                                0.3431548538593937,
                                -0.021044457841093333,
                                0,
                                0,
                                0.085025737772739418,
                                0.17572365020578248,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23474655206995396,
                                0,
                                -0.3309611065579296,
                                0.73498037259479954,
                                -0.36200401556481454,
                                0,
                                0.2165299481637678,
                                -0.13505514291966658,
                                0,
                                -0.26098244295369449,
                                0,
                                0,
                                0,
                                0.82918995699613107,
                                -0.21194749035157553,
                                0,
                                0,
                                0,
                                0,
                                0.25356675534042183,
                                0,
                                0.67097710643848196,
                                0,
                                0,
                                0,
                                -1.0773426682685765,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26380012003436926,
                                0,
                                -0.3584757916538317,
                                -0.88327060661806955,
                                0,
                                0,
                                0,
                                0,
                                0.12053860501792667,
                                0,
                                0.97392407407501835,
                                0,
                                0,
                                0,
                                0.42551539973778574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45371287498255575,
                                0,
                                0,
                                0,
                                -0.27836074511336273,
                                0.4183710832167179,
                                -0.27210335432009658,
                                0.029118105612391629,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.81944809940834884,
                                0,
                                0.033130728596675457,
                                0,
                                0,
                                0,
                                0,
                                -0.57372349027354863,
                                -0.14539331343699957,
                                0.31125969563488093,
                                -0.72265979551938175,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.015418704173545836,
                                0,
                                -0.17419709093702573,
                                0,
                                0,
                                0,
                                0,
                                -0.23377660286899374,
                                -0.019003972828489757,
                                0.8006203677444792,
                                0.50154066270036057,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17221615606822954,
                                0,
                                0.15097329223285891,
                                0,
                                0,
                                0,
                                0,
                                -0.308178688666013,
                                -0.17128166340645673,
                                -0.21608298024886993,
                                -0.033863704761562932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12422815502080112,
                                0,
                                0.90134191530158536,
                                0,
                                0,
                                -0.21266353529934323,
                                -0.53844920234081317,
                                0,
                                0,
                                0,
                                0,
                                -1.649154976672657,
                                0,
                                0.058373591793440538,
                                0,
                                0,
                                0,
                                -0.39360683782445277,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25236148189373009,
                                -0.12309815398297158,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38036842245870761,
                                0,
                                0.62858214916851729,
                                0.042493749154904017,
                                -0.24527078084785545,
                                0,
                                0.16629751976645046,
                                -0.06020122482223457,
                                0,
                                -0.59313460717059874,
                                0,
                                0,
                                0,
                                0.501686579870668,
                                -0.74326506935219105,
                                0,
                                0,
                                0,
                                0,
                                -0.18269198475497134,
                                0,
                                -0.91827734704222352,
                                0,
                                0,
                                0,
                                -0.36904867740972058,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.085171759178327949,
                                -0.38771992449264781,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10570248135622023,
                                0,
                                0.05764849879066497,
                                0.005125931831290953,
                                -0.31093598083890217,
                                0,
                                0.4873606416421622,
                                0.6529723222843431,
                                0,
                                0.27308641146178969,
                                0,
                                0,
                                -0.059572743389994146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34296146403631134,
                                0,
                                -0.066964938169184182,
                                0.00085150045333076685,
                                0.1721291902597907,
                                0,
                                0.67148882282754041,
                                -0.5322230911978989,
                                0,
                                0.33250019294427563,
                                0,
                                0,
                                0.21202152131361324,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.005515714895170859,
                                0,
                                -0.48335757415774977,
                                -0.49104807682864315,
                                0.1008001106540275,
                                0,
                                0.3639020844936649,
                                0.17911404902124795,
                                0,
                                -0.55279875286834634,
                                0,
                                0,
                                0,
                                -1.2199475892019014,
                                -0.38455421209549567,
                                0,
                                0,
                                0,
                                0,
                                0.19562365665083306,
                                0,
                                -0.48946307839682707,
                                0,
                                0,
                                0,
                                -0.92871154338071915,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26174534761999169,
                                0.4496845119663434,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58240144237206692,
                                0,
                                0.49956476223497914,
                                0.0069735458912081605,
                                0.32150506370214471,
                                0,
                                0.3227862461850885,
                                0.033534630621942813,
                                0,
                                0.017256287202285031,
                                0,
                                0,
                                0.43228256791255326,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.039989807645606446,
                                0,
                                0.065661625385316613,
                                -0.39450207929333658,
                                -0.74308239353827032,
                                0,
                                -0.020353241725975829,
                                -0.19456596298398654,
                                0,
                                0.24728049895044596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65845189050551434,
                                0.097212619530893718,
                                0.35725953383291925,
                                -0.46707343847595512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29502036509915597,
                                0,
                                0.35236604153372902,
                                0,
                                -0.60502469975789164,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57497590489110839,
                                0,
                                -0.0055344489356814325,
                                -0.24731032790168217,
                                -0.1295688333548686,
                                0,
                                0.0035128321475123708,
                                -0.44434144581343399,
                                0,
                                -0.16707797590183471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10085710674570712,
                                -0.87445844300188114,
                                -0.11729434907948433,
                                0.077894621724375931,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44287585303742283,
                                0,
                                -0.095842150739759907,
                                0,
                                0,
                                -0.19405204686368552,
                                -0.10560112052179212,
                                0,
                                0,
                                0,
                                0,
                                0.46797556460016504,
                                0,
                                0.43742809582654535,
                                0,
                                0,
                                0,
                                -0.058097965412654884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.4910736964160076,
                                0.62722556989356226,
                                0,
                                0.22417285747491783,
                                0.60720037007829941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.038411293012601738,
                                0.28698297668897199,
                                0,
                                0.30532310918100036,
                                0,
                                -0.09128488476705221,
                                0.047460904889729913,
                                0,
                                0,
                                -0.55582681522347366,
                                0,
                                0,
                                0,
                                -0.29922273378389397,
                                0.72205790199945097,
                                0,
                                -0.28195280520177407,
                                0,
                                0.018864957283204226,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.017361516383333584,
                                0,
                                0,
                                0,
                                0.35754623260675178,
                                0,
                                -0.23992663872237677,
                                -0.38768953001685091,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43295615961844208,
                                0.57625628216926805,
                                0,
                                -0.16103022488443014,
                                0,
                                0.33275083191366739,
                                -0.090091839468114318,
                                0,
                                -0.19048503899704552,
                                0,
                                0.59590945119400485,
                                0.022572663358620987,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.034085148365984419,
                                -0.00058263418984624837,
                                0,
                                0.13795736155018801,
                                0,
                                0.76638542275927812,
                                -0.023597968965888449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60238643567805661,
                                0,
                                0,
                                -1.046402886320017,
                                0,
                                0.4873451643643173,
                                0,
                                -0.31504887695135025,
                                0,
                                0,
                                -1.0263747222646395,
                                0,
                                0,
                                0,
                                0,
                                -0.32502271114536302,
                                0,
                                0.31564156244480812,
                                0,
                                0,
                                0,
                                0.68464033979773409,
                                0.33483768018960808,
                                0,
                                -0.50858437741390339,
                                0,
                                -0.24638299303240244,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.012613044802602773,
                                0,
                                0,
                                0,
                                0,
                                -0.62983942266857829,
                                0,
                                0,
                                0,
                                0.64013711285483743,
                                -0.12388274609976369,
                                0,
                                0.27418456324425944,
                                0,
                                0.22590101670557547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22797236575319613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19755432029910786,
                                0,
                                0,
                                -0.034600757196952187,
                                0,
                                -0.41764811592141521,
                                0,
                                -1.5355657603304895,
                                0,
                                0,
                                0.54505680269593193,
                                0,
                                0,
                                0,
                                0,
                                0.022828721244421785,
                                0,
                                -0.26053986785660582,
                                0,
                                0,
                                0,
                                -0.020925650129600723,
                                -0.10826637159652495,
                                0,
                                0.19431021093366296,
                                0,
                                -0.93897129588324635,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.023150262190539259,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.81409714329550575,
                                0,
                                0,
                                -0.43349717969835044,
                                0,
                                0.069383344901522065,
                                0,
                                0.20231414635677802,
                                0,
                                0,
                                -0.66068948550736994,
                                0,
                                0,
                                0,
                                0,
                                0.66341579740015,
                                0,
                                -0.22669489186192998,
                                0,
                                0,
                                0,
                                0.10548488402629352,
                                -0.15501933190447373,
                                0,
                                -0.11505490987299632,
                                0,
                                0.077929341090103785,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.94559016359781201,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67946759393105383,
                                0,
                                0,
                                0.21773904545508882,
                                0,
                                -1.1015141298378706,
                                0,
                                0.027416834381325975,
                                0,
                                0,
                                -0.92525690629975887,
                                0,
                                0,
                                0,
                                0,
                                -1.0043824412665883,
                                -0.084167416474708726,
                                0,
                                0.07700162191149712,
                                0.09439838861120825,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77725661621076003,
                                -0.26787741675553334,
                                0,
                                0.17845970841650702,
                                0,
                                -0.065450659724747062,
                                0.51580783846026645,
                                0,
                                -0.16999293965204518,
                                0,
                                0.34820637136958532,
                                -0.010988665323617169,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40304326370166665,
                                0.056167676750864967,
                                0,
                                0.12703323310662537,
                                0,
                                -0.34045674471685,
                                -0.74302560856062783,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6659709284205888,
                                0,
                                0,
                                -0.10491396178173945,
                                0,
                                0.5357499264082386,
                                0,
                                0.12772173726642111,
                                0,
                                0,
                                0.83122491192795234,
                                0,
                                0,
                                0,
                                0,
                                -1.22949405108351,
                                0.14569760829436787,
                                0,
                                -0.54483284298531265,
                                0.25333781852195447,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12468597381401368,
                                -0.46974299743143888,
                                0,
                                0.23724878592895693,
                                0,
                                0.40242871817426296,
                                -0.4041143334632088,
                                0,
                                0,
                                0.27469557777549508,
                                0,
                                0,
                                0,
                                0.1428036899489018,
                                0.56161960330938288,
                                0,
                                0.73189704303880698,
                                0,
                                0.012968734983958702,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22998129743555767,
                                0,
                                0,
                                0,
                                -0.21767506451946367,
                                0,
                                -0.18331249059800633,
                                -0.28717388887275025,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14062847030515929,
                                0.26005370841167275,
                                0,
                                0.85903318723928668,
                                0,
                                -0.061140057531524974,
                                0.086399266747037615,
                                0,
                                -0.58126779167169185,
                                0,
                                -0.28186954630909405,
                                0.56992483230619007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.089538039365451627,
                                0.47156080803523936,
                                0,
                                -0.14001613843749822,
                                0,
                                0.08783947704747333,
                                0.012491990642096107,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15963298264627709,
                                0,
                                0,
                                0.93808919190294704,
                                0,
                                1.181294626882099,
                                0,
                                0.19480208285808978,
                                0,
                                0,
                                -0.35974813362585362,
                                0,
                                0,
                                0,
                                0,
                                -0.056602375994431117};

const double rot_29_10[1000] = {-0.48774541947168826,
                                0.33900054105026439,
                                0,
                                -0.06212415402400337,
                                0.10138560709798511,
                                0.39363587880307782,
                                0,
                                0,
                                0,
                                0.69144441716678751,
                                0.19616771960406612,
                                0.33980165741402657,
                                0,
                                0.63291286002519409,
                                -0.40913692890414088,
                                -0.41525054883994778,
                                0,
                                0,
                                0,
                                0.3250358843478065,
                                0,
                                0,
                                0.21883329852770719,
                                0,
                                0,
                                0,
                                0.51853948255709392,
                                -0.73430540918323406,
                                0.81538193402801951,
                                0,
                                -0.31249900792606999,
                                0.21825525989188069,
                                0,
                                0.42541839235329815,
                                -0.29066526909726209,
                                0.53454317153636699,
                                0,
                                0,
                                0,
                                -0.55091333449712743,
                                0.45158602843560852,
                                0.7114216832364384,
                                0,
                                -0.043644082540086754,
                                0.49855660984555938,
                                0.10638408086540467,
                                0,
                                0,
                                0,
                                -0.16783377407347502,
                                0.053556081526151912,
                                0.37828602227735253,
                                0,
                                -0.64043537192006861,
                                -0.65949020987971307,
                                -0.052883120227580425,
                                0,
                                0,
                                0,
                                -0.078421964669040667,
                                0,
                                0,
                                0.079370235757825133,
                                0,
                                0,
                                0,
                                -1.0126736833415664,
                                -0.44048385276580482,
                                0.37302572503926401,
                                0,
                                0,
                                0,
                                0.38273479499467211,
                                0,
                                0,
                                0,
                                0.66851173734602454,
                                -0.21489357098251158,
                                0.2343781567723042,
                                0,
                                0,
                                0,
                                1.067997182566067,
                                0,
                                0,
                                0,
                                -0.095315916600315576,
                                1.5068296684838349,
                                0.031652359925641568,
                                0,
                                -0.64743247267052284,
                                0.26973502235795638,
                                0,
                                -0.050187857116073084,
                                0.23314288166914257,
                                -0.61054662172868568,
                                0,
                                0,
                                0,
                                -0.28005822513555734,
                                -1.0705704037524404,
                                0,
                                0,
                                -0.94212106532683904,
                                -0.36858072405552023,
                                0,
                                0,
                                -0.77862713989898513,
                                0,
                                0,
                                0,
                                -0.25957193410429313,
                                0.057971407738111769,
                                0,
                                0,
                                -0.57517794829189373,
                                0.2906393502307909,
                                0,
                                0.148244044097358,
                                0.70141608635390651,
                                0,
                                -0.6457836754162094,
                                0.28680734649520512,
                                0,
                                0,
                                -0.057884409488337549,
                                -0.68319281906445328,
                                0,
                                -0.17465679608840501,
                                0.0098468908491363173,
                                0.62510481035783716,
                                0,
                                0,
                                0.19538397010109876,
                                -0.68687699014908976,
                                0,
                                0,
                                -0.61121711319563143,
                                0,
                                0,
                                1.0859302170471681,
                                0,
                                0,
                                -0.79442931602776656,
                                -0.21066267794522561,
                                0,
                                0,
                                0.52543952313321829,
                                0,
                                0,
                                0,
                                -0.4777288303875033,
                                -0.8310545791877374,
                                0,
                                0,
                                -0.10539404790766083,
                                0.11547605267890718,
                                0,
                                -0.028412202690496657,
                                -0.23637591605171654,
                                0,
                                0.38699743072079262,
                                -0.36372313292347891,
                                0,
                                0,
                                -0.036348547745040982,
                                -0.34370298380383929,
                                0,
                                -0.64785506020297234,
                                0.42281122757372575,
                                -0.56219466495866044,
                                0,
                                0,
                                -0.46533758354360066,
                                0.4472407330237293,
                                0,
                                0,
                                0.004437783860930189,
                                0,
                                0,
                                0,
                                0.32348542377395834,
                                -0.0034294762904002324,
                                0,
                                0,
                                -0.78867161944539665,
                                -0.27219658114087225,
                                0,
                                0.099883746021346198,
                                -0.43505718529349457,
                                0,
                                -0.18152462485614743,
                                0.30236214968318303,
                                0,
                                0,
                                -0.17716567771652142,
                                0.49317228376445243,
                                0,
                                -0.71903999329537538,
                                -0.28982900168441855,
                                -0.50114037171838277,
                                -0.4880107022177016,
                                0.34059311971817696,
                                0.28435842372831233,
                                0,
                                0,
                                0,
                                0,
                                0.28231460339818776,
                                0.4838790765454295,
                                0.20355663567242932,
                                0.2805237548440932,
                                0.4419289391532138,
                                -0.564694301433604,
                                0,
                                0,
                                0,
                                0,
                                0.57818237172217313,
                                0.17718753550672209,
                                0.62264136685100702,
                                0.15582035512738016,
                                0.31178604066586924,
                                0.68259371115950962,
                                0,
                                0,
                                0,
                                0,
                                0.094928160394220543,
                                0.12602253730761304,
                                0.29813588313242034,
                                -0.61142284088122878,
                                -0.27763015607392133,
                                -0.0016452212190457977,
                                0,
                                0,
                                0,
                                0,
                                0.53148024238651093,
                                -0.42157401067412192,
                                0,
                                0,
                                0,
                                0,
                                -0.61456268249454782,
                                0.52293447378600855,
                                0.61885176893425475,
                                0.59097979279845569,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0472049548035883,
                                -0.69395741768018149,
                                0.56997610543177557,
                                0.25881830970809844,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.99413483441700445,
                                0.49917987973775146,
                                0.543359476267396,
                                -0.55100356077377988,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.92767802166050783,
                                0.42423572895679901,
                                0.35540765830208709,
                                0.57913912608281248,
                                0,
                                0,
                                -0.47143751505754622,
                                0.49725289862764244,
                                -0.075347443707607764,
                                0.36353702191761988,
                                0,
                                0,
                                0,
                                0,
                                0.4658102035879102,
                                -0.41913085648536685,
                                0.092749214437698235,
                                0.19435446707567264,
                                -0.71325231408706546,
                                0.046525103020414627,
                                0,
                                0,
                                0,
                                0,
                                0.27846339128901859,
                                0.60430837765095302,
                                0.5099245101939941,
                                0,
                                0.43737180091165018,
                                0,
                                0,
                                -0.18427364827324355,
                                0,
                                -0.71115492849502404,
                                0,
                                0,
                                0,
                                -0.31510753729805946,
                                0,
                                -0.10442083103571098,
                                0.077701540283148227,
                                0,
                                0.69513090992733095,
                                0,
                                -0.60360324316436731,
                                -0.19032115890370449,
                                -0.027140324374517688,
                                0,
                                0.88554102530842704,
                                0,
                                0,
                                0.58091880479083124,
                                0,
                                -0.37573658938861543,
                                0,
                                0,
                                0,
                                0.01846614764049441,
                                0,
                                -0.28653751003498751,
                                0.78314919173315756,
                                0,
                                -0.18884889224239951,
                                0,
                                -0.22408038954547232,
                                0.46728650220388229,
                                0,
                                0.24006221161136646,
                                0,
                                0.0043152559086581388,
                                0.095829566131172272,
                                0,
                                -0.52217970050266083,
                                0,
                                -0.51750831785163276,
                                -0.62664320686905906,
                                -1.2247247047971264,
                                0,
                                0.53956077797208712,
                                0,
                                0,
                                0.24120491755288917,
                                0,
                                0.42191745820484239,
                                0,
                                0,
                                0,
                                -0.67988119064856389,
                                0,
                                0.53372259584948822,
                                -0.084990059789977396,
                                0,
                                -0.36441963328666555,
                                0,
                                -0.24162772000127522,
                                0.23343697826408755,
                                0.11777565307587169,
                                0,
                                -0.37789454716831622,
                                0,
                                0,
                                -0.76584573120473787,
                                0,
                                -0.43023303233558652,
                                0,
                                0,
                                0,
                                0.51691432173950236,
                                0,
                                0.76681840936678691,
                                0.22718319411204246,
                                0,
                                0.25718986201661365,
                                0,
                                -0.1143279685706271,
                                0.11814989559123604,
                                0,
                                0.33659697929187177,
                                0,
                                -0.1846717132943706,
                                -0.559125204610189,
                                0,
                                -0.097515024977992276,
                                0,
                                -0.49616671124379008,
                                0.53318594502029593,
                                -0.56756368534101997,
                                -0.66635123997216339,
                                0,
                                0.25814002488329774,
                                0.21100103585804636,
                                0,
                                0,
                                0.27056121850297571,
                                0,
                                0.22245540121999025,
                                -0.0090940788329174869,
                                0.31957837477425832,
                                0,
                                -0.32413486744498143,
                                -0.068854418574982673,
                                0,
                                0,
                                0.77487354379422979,
                                0,
                                0.43307459863598685,
                                0,
                                0,
                                -1.5311973056179045,
                                0,
                                0,
                                -0.37446631984981132,
                                -0.78238734741013816,
                                0,
                                -0.062512841846538617,
                                0,
                                -0.67443437974331821,
                                0.6437454376330265,
                                0,
                                0.15873582605621847,
                                0.24955796243741024,
                                0,
                                0,
                                -0.20486512396583223,
                                0,
                                0.035834631848399301,
                                0.013181883425668429,
                                0.12064302758329291,
                                0,
                                0.67113821185500344,
                                -0.69594720515171771,
                                0,
                                0,
                                0.046406405289813185,
                                0,
                                0.21988390487379805,
                                0,
                                0,
                                0.23706968269547349,
                                0,
                                0,
                                0.76491206828748681,
                                0.44145815120704224,
                                0,
                                0.37258833785498968,
                                0,
                                0,
                                0,
                                0.45924528073710763,
                                0,
                                0,
                                0.060885923568617745,
                                -0.30673833371171866,
                                0,
                                -0.85006599407439198,
                                0,
                                0.30697406717726639,
                                0.0024091616312788555,
                                0,
                                0.10498291084554506,
                                0.33610974039022645,
                                0,
                                0,
                                -0.37192723048207565,
                                0,
                                0.80214717109270284,
                                0,
                                0,
                                -0.28883398324998888,
                                0,
                                0,
                                -0.472529178246894,
                                0.63295693625243765,
                                0,
                                -0.86399757646370867,
                                0,
                                -0.35849712448295179,
                                -0.15772429973418114,
                                0,
                                -0.58451290986973869,
                                -0.53957963763465866,
                                0,
                                0,
                                -0.3793606198940942,
                                0,
                                0.26436121109203342,
                                0.70864134548499225,
                                -0.53443737900130073,
                                -0.15657705190412075,
                                0.3018406960594342,
                                0,
                                0,
                                0,
                                0.23886963220341331,
                                0.19879952521527205,
                                0,
                                -0.63178258263485865,
                                -0.65346710042025369,
                                0.25840542180005438,
                                0.21100599360714939,
                                0,
                                0,
                                0,
                                0.22613687014654973,
                                0.10675552235876486,
                                0,
                                0.17134914265569823,
                                -0.40670954349756999,
                                0.22747753458158484,
                                -0.1670250837306051,
                                0,
                                0,
                                0,
                                -0.46314814821291339,
                                -0.71489663869091824,
                                0,
                                -0.17463057682488053,
                                0.024306251327928484,
                                -0.42096084404622003,
                                0.67467319963256611,
                                0,
                                0,
                                0,
                                -0.5794226559957163,
                                0.028121077157759182,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2144269577487396,
                                0.4393350588854979,
                                0.60666240703969743,
                                0,
                                0,
                                -0.046693288617524961,
                                0,
                                0,
                                0,
                                0,
                                0.64575476281310706,
                                0.034824659875242664,
                                0.40247924928689571,
                                0,
                                0,
                                -0.50483919372024544,
                                0,
                                0,
                                0,
                                0,
                                0.55488597155381281,
                                -0.62539636446380187,
                                0.941961924481174,
                                0,
                                0,
                                0.39259960461711879,
                                0.12883235294634474,
                                0.34682220487150417,
                                0.59558664201153277,
                                0.61137817420654628,
                                0,
                                0,
                                0,
                                0.24149282737625186,
                                -0.27620839474841297,
                                0,
                                0.14907739443564808,
                                -0.032685595864495931,
                                0.57011644047453636,
                                -0.086626139648637329,
                                0,
                                0,
                                0,
                                -0.53221030394287894,
                                0.60076861677230498,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37691766568184765,
                                -0.45438025472199267,
                                -0.55213642969060561,
                                0,
                                0,
                                -0.39328248767593593,
                                0.62601907487463759,
                                -0.32128434564814246,
                                0,
                                0,
                                0,
                                0.20652113851904699,
                                -0.62012078999610287,
                                0.057205865000230116,
                                0,
                                -0.27276950215067963,
                                -0.22370294950677011,
                                -0.64914616586446638,
                                0,
                                0,
                                0,
                                0.1379459637583296,
                                0.13643054636858284,
                                -0.69349134416709668,
                                0,
                                -0.099968086863262168,
                                0,
                                0,
                                0.022309956731729627,
                                0.4510094716065095,
                                -0.091678102819799379,
                                0,
                                0,
                                0,
                                -0.12789592905072528,
                                0,
                                0,
                                0,
                                -0.16320921929657203,
                                -0.074122736921478416,
                                0.063576118819137911,
                                0,
                                0,
                                0,
                                1.2818292665693882,
                                0,
                                0,
                                0,
                                -0.071693736626811111,
                                0.60226287757168806,
                                1.1513669094115238,
                                0,
                                0,
                                0,
                                -0.21272272176642565,
                                0,
                                -0.17646275621517934,
                                -0.068523172945743893,
                                0,
                                0,
                                0,
                                0.68696959655716971,
                                -0.19393745294974429,
                                0.12402183187900195,
                                0,
                                0.66275568153371567,
                                -0.33831341499216289,
                                -0.54886252159031013,
                                0,
                                0,
                                0,
                                -0.51559754892200205,
                                -0.28705838740974665,
                                0.43174437878444066,
                                0,
                                0.22281698045983581,
                                -0.30605637028743216,
                                -0.20009685625998988,
                                0,
                                0,
                                0,
                                0.44706131466904142,
                                0.2491019718350905,
                                0.50870402650112978,
                                0,
                                -0.58787358190102923,
                                0,
                                0,
                                1.0605890571248269,
                                0.675113066295006,
                                0.29390007106675187,
                                0,
                                0,
                                0,
                                0.39876120960459061,
                                0,
                                -0.56461627269043413,
                                0.35972403292350441,
                                0,
                                0,
                                0,
                                0.026230751145791778,
                                -0.64402706932327825,
                                -0.23501666877445335,
                                0,
                                -0.28480753469977899,
                                -0.017832121567215573,
                                0.42143198183235475,
                                0,
                                0,
                                0,
                                -0.29001580719593584,
                                -0.28325201692028462,
                                0,
                                -0.75021360801502068,
                                0.30808402906582977,
                                -0.23673393446167049,
                                -0.68106167204353052,
                                0,
                                0,
                                0,
                                0.39924042731999887,
                                -0.42871392081611559,
                                0,
                                -0.26220919050587693,
                                0.26109354425883335,
                                0,
                                0,
                                0.65873110986650152,
                                -0.92083240201646621,
                                0.21270475048928139,
                                0,
                                0,
                                0.50427485364810498,
                                0,
                                0,
                                0,
                                0,
                                0.61899956508812826,
                                0.26654356038505889,
                                0.43581531168832,
                                0,
                                0,
                                -0.68056402187729037,
                                0,
                                0,
                                0,
                                0,
                                -0.95293860535305364,
                                0.67436254832932185,
                                0.53912849409175478,
                                0,
                                0,
                                -0.42632062995203546,
                                0,
                                0,
                                0.27337779763670461,
                                0.42865395675491536,
                                0,
                                0,
                                0,
                                0.73735271537456848,
                                -0.29844104264200355,
                                0,
                                -0.07038008114293795,
                                -0.32219703054571691,
                                -0.54245658501691418,
                                0.016814227351090436,
                                0,
                                0,
                                0,
                                -0.27072990220701404,
                                -0.3950893923295834,
                                0,
                                -0.0071637150561528612,
                                -0.68993949621440531,
                                0,
                                0,
                                -0.268755524201783,
                                -1.1706685678632716,
                                -0.66376003810003792,
                                0,
                                0,
                                -0.61286911424578483,
                                0,
                                0,
                                -0.012907041662433394,
                                0.24094140105075862,
                                0,
                                0,
                                0,
                                -0.14480944543347929,
                                -0.61997868465465111,
                                0,
                                0.59887187583734325,
                                0.42165125513084839,
                                -0.75794320441661456,
                                0.34127758780611872,
                                0,
                                0,
                                0,
                                0.3443028179725135,
                                0.32624594360443426,
                                0,
                                0.069091855231329102,
                                0.28159754313282054,
                                0.40452553837131422,
                                0.19140419284015242,
                                0,
                                0,
                                0,
                                -0.78931980781062216,
                                0.084063291307591631,
                                0.070554006260930863,
                                0.40577488835740927,
                                0,
                                -0.82531764402242025,
                                0.22297921598350892,
                                0,
                                0,
                                0,
                                -0.23655753831345019,
                                0.28090584993105572,
                                -0.27120018805544738,
                                0.24640200535901838,
                                0,
                                0,
                                0,
                                0.22401205197564167,
                                -0.5813521460617358,
                                0.1070990264925854,
                                0,
                                0,
                                0,
                                0,
                                0.53057195546701108,
                                0,
                                0,
                                -0.70373990051384738,
                                -0.84010041314225348,
                                0.31977377976531213,
                                0,
                                0,
                                0,
                                0,
                                0.59637250947867915,
                                0,
                                0,
                                0.21022814801313228,
                                -0.2281650739210225,
                                -0.50973952117196286,
                                0,
                                0,
                                0,
                                0,
                                0.95523332336602984,
                                0.14080200193830147,
                                0.50532048290365184,
                                0,
                                0,
                                0,
                                0.36302961686606894,
                                0.62644401777414316,
                                0.43073290705117667,
                                0.12277034847426795,
                                0,
                                -0.0074561803943862803,
                                -0.57307389269078601,
                                0,
                                0,
                                0,
                                -0.27810591573865096,
                                0.64537267643252805,
                                0.088027194247091434,
                                -0.41222947506046531,
                                0,
                                0.10639840432860591,
                                0.5682999485907162,
                                0,
                                0,
                                0,
                                -0.20601513783733588,
                                0.0026847169331467718,
                                -0.32694335918715539,
                                -0.71859108201284339,
                                0,
                                -0.35214834438217496,
                                0.083170882576946825,
                                0,
                                0,
                                0,
                                -0.26351305841643513,
                                -0.32416054654035448,
                                0.78822649406047574,
                                -0.27065466929663856,
                                0,
                                0,
                                0,
                                0.27670348848759485,
                                -1.0585737242202533,
                                0.30682935503084574,
                                0,
                                0,
                                0,
                                0,
                                -0.84933893102410818,
                                -0.24547479351608889,
                                -0.43226283655349396,
                                1.1595422808628293,
                                0,
                                0,
                                0,
                                0,
                                0.18378527180312881,
                                0,
                                0,
                                0.07463682463423843,
                                0.97898743464807336,
                                0.01116586249027629,
                                0,
                                0,
                                0,
                                0,
                                0.59735442680860618,
                                0,
                                0,
                                0.68349417982208294,
                                -0.50960607548089099,
                                -0.44232974143447235,
                                0,
                                0,
                                0,
                                0,
                                -1.2720088579088178,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29278470287224406,
                                0.35865257399399686,
                                -0.32007525820615057,
                                -0.51982903992094409,
                                0,
                                -0.56808714270459704,
                                0.30041978224536814,
                                0,
                                0,
                                0,
                                -0.15464567439261134,
                                0.38120138368841255,
                                0.31968728383598183,
                                -0.048103987104649408,
                                0,
                                -0.37883307134181382,
                                -0.76337524946885127,
                                0,
                                0,
                                0,
                                0.9275444331874716,
                                0.071817135144636612,
                                0.04561771154830932,
                                0.21001109990696243,
                                0,
                                0.18077177624673263,
                                -0.23588037388497124,
                                0,
                                0,
                                0,
                                0.023261037239829335,
                                -0.33714232844773034,
                                -0.22462315402959493,
                                0.64043090780514889,
                                0,
                                -0.65186699737845699,
                                0.016002601220884888,
                                -0.67420427518515669,
                                -0.51824021372139428,
                                0.34801101987063054,
                                0,
                                0,
                                0,
                                0,
                                -0.61205364001357732,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.075922540734177174,
                                -0.70429309340620849,
                                -0.26594936247836842,
                                -0.49085219274722769,
                                0,
                                -0.034202346686115367,
                                -0.4305487978644591,
                                0,
                                0,
                                0,
                                0.15400600499199005,
                                -0.33347027497258785,
                                0.81980867847448413,
                                -0.17964267532656139,
                                0,
                                -0.27383148919365291,
                                0.29281099972769997};

const double rot_29_100[100000] = {-0.88043650298064557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51273351240686948,
                                   0,
                                   -0.07999498355339979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0023373729822338263,
                                   0,
                                   0,
                                   0,
                                   -0.10018693809461862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62267477075578503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0092353203292782314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40061120124295663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24478530606117305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10987925441438211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46796067214234527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3572066163163875,
                                   0,
                                   0.61670958624697092,
                                   0,
                                   0,
                                   0.59937648810141597,
                                   -0.059052519611075625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11713900712882697,
                                   0,
                                   -0.051174686409568425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45225404393818902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30164511026863694,
                                   0,
                                   -0.69579465796768281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029238341944484686,
                                   0,
                                   0.6547778119683948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17383067948432979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096459591305643008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72321465978605093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18823719565599215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26842038101367194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37986182071873231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096328970204122025,
                                   0,
                                   0,
                                   0.53125552536098297,
                                   -0.23470149992752354,
                                   0,
                                   0,
                                   0,
                                   -0.5843657362581155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16888371922698717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32888899579631764,
                                   0,
                                   0,
                                   0,
                                   0.40957155948080537,
                                   0,
                                   0,
                                   0,
                                   -0.033814983866933289,
                                   -0.11097901708743009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11492296012280186,
                                   0.47549081616034644,
                                   -0.039859023853797512,
                                   0,
                                   0,
                                   0.34093475469260059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13489116577563351,
                                   0,
                                   -0.20189850385151217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25370186629917219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46378514191722248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21021506532375828,
                                   0,
                                   -0.28070988623286208,
                                   0,
                                   -0.016091902751361617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34357060564844305,
                                   0,
                                   -0.28138763170696213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5671358259254955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17648180727044949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011892680358400302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52556599119442604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48866421013830941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25580583414553865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063649549950661147,
                                   0,
                                   0,
                                   0.25968932156406921,
                                   0.049769251991057716,
                                   0,
                                   0,
                                   0,
                                   -0.3643592275366152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94089424340145134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035020972479162985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58285843477312294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61863026377938346,
                                   0,
                                   0,
                                   0,
                                   -0.028860302889399142,
                                   0.10807930180524704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062694668861794561,
                                   0,
                                   0,
                                   0,
                                   0.43267229203323071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21034408318674508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17227310312363381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56014988363006202,
                                   0,
                                   0,
                                   -0.76623609990555652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38945624495074604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21446586997994338,
                                   0,
                                   0,
                                   0,
                                   0.55180886691608322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11072996058446523,
                                   0,
                                   0,
                                   -0.58421213243599701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24324004530115306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071110003451137341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36556443157969587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28975133485990368,
                                   0,
                                   0,
                                   0,
                                   0.420635350980127,
                                   0.10265165823754377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21265438038759055,
                                   0.0055012153489388538,
                                   0.15766585432512592,
                                   0,
                                   0,
                                   -0.075585496729666787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36669211040886801,
                                   0,
                                   -0.17741127205551616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0074455248189807741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11201208421689332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24708888577819457,
                                   0,
                                   -0.60399508175153671,
                                   0,
                                   0.21987697086202349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22054025784229284,
                                   0,
                                   0,
                                   0,
                                   -0.0096797553246925593,
                                   0.21752785142708253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.345638947976463,
                                   0.023214223643579855,
                                   -0.077978076203326113,
                                   0,
                                   0,
                                   -0.24195316197663214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27859590246867078,
                                   0,
                                   -0.26813202552135135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22768362207199411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14575984380498153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48221969618737864,
                                   0,
                                   0.17199061152083378,
                                   0,
                                   -0.4843655703226285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41419603683372408,
                                   0,
                                   0,
                                   -0.85344466415952569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93788956323389261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049888123606800949,
                                   0,
                                   0,
                                   0,
                                   -0.10320585823236567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014398986069555354,
                                   0,
                                   0,
                                   0.15289303779361382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09149892007461996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87998773065176017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22854154809251562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14296424448284739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54499211420486227,
                                   0,
                                   0,
                                   -0.15066916954283677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30056828185282258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10035496054399251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25693154586764066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041899781867556454,
                                   0,
                                   0,
                                   -0.61854412388594782,
                                   0,
                                   0,
                                   0,
                                   0.19124759341082248,
                                   0,
                                   -0.067536965557447731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21406957811366745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14866842061869318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3284810758725783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48687820158439943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011596844307028288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13132338254761938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59250488296166004,
                                   0,
                                   -0.36945031356123315,
                                   0.016945570458135224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24643790919165451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13272021900356229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26735829800614253,
                                   0,
                                   0,
                                   0,
                                   0.62321569233683993,
                                   0,
                                   0.16486556614723452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48321038173944209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52101989647322333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11710749367488407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28663054059868748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19154749049064343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38529878699007419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44973799044544183,
                                   0,
                                   0,
                                   0.019229952465436739,
                                   0.34663234844991497,
                                   0,
                                   0,
                                   0,
                                   0.46913017925953537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36470451150612243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03001607083472338,
                                   0.940292595118286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46168127552396959,
                                   0,
                                   -0.91936602548656865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80098965689837986,
                                   0,
                                   0,
                                   0,
                                   0.0084462483258268897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18379393586492726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8102472152656981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41997712227562295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38700807329733827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44088672607884449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42807422454657851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57577767188783158,
                                   0,
                                   -0.32157311252554577,
                                   0,
                                   0,
                                   -0.070634147349291743,
                                   -0.039186303079842097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017258391686645197,
                                   0,
                                   -0.087898484657348716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35174724961974313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73218056784094399,
                                   0,
                                   0.55544523958227598,
                                   0,
                                   0,
                                   0,
                                   -0.5445102671401022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063844352439021465,
                                   0,
                                   0.057634053401877203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7731188736893877,
                                   0,
                                   0,
                                   0,
                                   -0.21329155189729615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28335957576744941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27648814334779898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5480258364275884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36877140785339646,
                                   0,
                                   0,
                                   0,
                                   -0.1454638418784969,
                                   0.44226631144590361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13533599782049702,
                                   0.28620053432276638,
                                   -0.10682606284089996,
                                   0,
                                   0,
                                   -0.19009296994835198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37492605730945577,
                                   0,
                                   -0.10007713101177834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21209949967245889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36256549535072974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37360744025379927,
                                   0,
                                   -0.069357231260880614,
                                   0,
                                   -0.16750177436272934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1056339006385332,
                                   0,
                                   0,
                                   0,
                                   -0.26838412498440412,
                                   0.22563804652779929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057957062590585279,
                                   -0.21807017813491511,
                                   0.77116319427513991,
                                   0,
                                   0,
                                   0.32580549831297301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15068755085155849,
                                   0,
                                   0.022485157902526001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13590853847269965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020508963672202604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20513842111506636,
                                   0,
                                   -0.16016269664070046,
                                   0,
                                   -0.065616033702138782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12345487598184654,
                                   0,
                                   0,
                                   0,
                                   -0.26243737119811161,
                                   0.16570375640978582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40197450486677172,
                                   0.050951457151417738,
                                   0.068440103505897215,
                                   0,
                                   0,
                                   0.19822670594211791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33239193390090133,
                                   0,
                                   0.25608854742541598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3953550697609543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082677742567952739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44286980634637735,
                                   0,
                                   0.072731190101364307,
                                   0,
                                   -0.3736842023792501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22915616509291684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72733273523580311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19557182954486441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0056148233007990468,
                                   0,
                                   0.74041755950980348,
                                   0,
                                   0,
                                   -0.12108323070916421,
                                   -0.25300461730045287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34314166349174974,
                                   0,
                                   0.17959032988205789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50165979653838866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88451349893342757,
                                   0,
                                   0.10430871058306034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20785715052282591,
                                   0,
                                   0,
                                   -0.44271925388192612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3716800742819632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35700231519538062,
                                   0,
                                   0,
                                   0,
                                   -0.66846515716841748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44807948817993998,
                                   0,
                                   0,
                                   -0.22072028003800351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0407687706379256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34026628839740469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61725507969778493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4501395088520091,
                                   0,
                                   0,
                                   0,
                                   -0.30252631150663778,
                                   0.31978917101269422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27936052113642856,
                                   0.30095893367829796,
                                   0.032987841927853895,
                                   0,
                                   0,
                                   -0.31051890446647712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12420543013929822,
                                   0,
                                   -0.0076067290230240753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047112873138804301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52082466268583238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048266588531763563,
                                   0,
                                   -0.21087970794005292,
                                   0,
                                   0.041178309509557615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20757762985164632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44024391861070328,
                                   0,
                                   0,
                                   -0.31329513020972144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41887633099119603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17835058649757823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1346784709166518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090180931605846781,
                                   0,
                                   0,
                                   -0.25698098522924234,
                                   0,
                                   0,
                                   0,
                                   0.47276894122391144,
                                   0,
                                   0.05158085796854367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19877198479424613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31572961909317854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3078095216121135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1444703025270184,
                                   0,
                                   -0.65303824320927117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40641479471229441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25446413785753624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47749104722728231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025640559384422352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14572667085604252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37717915517735368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0668435573405504,
                                   0,
                                   -0.23083029173065353,
                                   0,
                                   0,
                                   0.76088553596282527,
                                   0.0090298257487681569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33867327794266111,
                                   0,
                                   -0.059392885280189531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20744919443872223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25599677154644801,
                                   0,
                                   0.40729713928573996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30198460088818802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26905258592477455,
                                   0,
                                   0,
                                   -0.18929842091901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064062449564508905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5662933362792909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21840845167279954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17151182964335321,
                                   0,
                                   0,
                                   -0.23330649718625776,
                                   0,
                                   0,
                                   0,
                                   -0.33082945838132471,
                                   0,
                                   0.23068250089484127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17310438031418904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3893736254263041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60974115460331801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012331717864154268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24427973221004079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36281902956078532,
                                   0,
                                   -0.3323510225119648,
                                   0,
                                   0,
                                   0.42392145569712858,
                                   0.70499903355811555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53954119706950521,
                                   0,
                                   -0.31303724794002935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21651554666711592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13622606022882586,
                                   0,
                                   0.45224943588861377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3418122191907299,
                                   0,
                                   -0.021833351465345482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.168390173519543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41912237827881865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24542026904621037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10080489639152029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6984314062438195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58226843339458467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023246168367690525,
                                   0,
                                   0,
                                   -0.55213632463733908,
                                   -0.21842648281789759,
                                   0,
                                   0,
                                   0,
                                   -0.02730405036166654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025544485938305453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19666628601738126,
                                   0.29337066048664978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36714959168572303,
                                   0,
                                   -0.73716100242416227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43131341098430431,
                                   0,
                                   0,
                                   0,
                                   -0.17409169781236672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0052573100892225125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70739040186102564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33006672865223347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85912977312653394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47737179909526095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61168600321993938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048082445155575561,
                                   0,
                                   0.19934531601381744,
                                   0,
                                   0,
                                   0.37603118260108648,
                                   0.31292704095669338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2550471682619983,
                                   0,
                                   -0.77302345092220637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16835701015312943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15259343996148322,
                                   0,
                                   0.0035925182299968786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24333462789840377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0121363965093996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28717623544799026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019215502038289579,
                                   0,
                                   0.51317342757912066,
                                   0,
                                   0,
                                   0.56679182138436546,
                                   0.12717531736226023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0659016977152689,
                                   0,
                                   -0.20069045225770354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52109872318170947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36728687709828578,
                                   0,
                                   0.083233631572000241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76309466516077784,
                                   0,
                                   0,
                                   0,
                                   0.26137919225012307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21296627433330972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.147784766296079,
                                   0,
                                   0,
                                   -0.083837002877717892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91315104190110818,
                                   0,
                                   0,
                                   -0.65523450201201938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12599920321938363,
                                   0,
                                   -0.28801619053094618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059826033758612479,
                                   0,
                                   0,
                                   0,
                                   0.9125459022088489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083656078014829258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35850643079482752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46063264853841168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0043608843038183687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010130013701002735,
                                   0,
                                   0,
                                   0.56462268176838848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41716201440469064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072966677757070303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13719583784584918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073482235784662731,
                                   0,
                                   0,
                                   -0.24063301200804066,
                                   0,
                                   0,
                                   0,
                                   -0.27498058045687734,
                                   0,
                                   0.22921881856233972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51889614531247918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1489829890297171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10339252004440314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12095469836890338,
                                   0,
                                   0,
                                   0,
                                   0.03584978716395408,
                                   -0.40974864600778599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31018452163810356,
                                   0,
                                   0,
                                   0,
                                   0.22176700770544008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71635251613854323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38333381933757771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76982534315801976,
                                   0,
                                   0,
                                   0,
                                   -0.16428936555295576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9667030774490516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1449135288989722,
                                   0,
                                   0,
                                   0.38691892221753599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022192386508309958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13906771017191888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20199381215039663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012320104089665683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63654079549482756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15145558537864623,
                                   0,
                                   0.35154647772900383,
                                   0.38454463152818807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21642535553089684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14792495491209667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41400806968088411,
                                   0,
                                   0,
                                   0,
                                   -0.57193393021994787,
                                   0,
                                   0.48628716977322711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22757769714496634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19664608963296132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17923844435177316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26004204886014232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20307699639325294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28808854913774695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23550436810328884,
                                   0,
                                   0,
                                   -0.46085391083324256,
                                   0.51481586164934878,
                                   0,
                                   0,
                                   0,
                                   0.12861795755453015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23328811261278146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32122336331731172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28297566689287623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10887642244675107,
                                   0,
                                   0,
                                   0,
                                   0.38084044785004906,
                                   0.51676615030437745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53797063815555435,
                                   0,
                                   0,
                                   0,
                                   0.41863243434523506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014074779353242729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17640967588412357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046274849952689545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2985531174542313,
                                   0,
                                   0,
                                   0,
                                   0.6216463398718195,
                                   -0.10683768000244961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53114491639783845,
                                   0,
                                   0,
                                   0,
                                   0.3377889342770854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085091511471131392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32773367375984402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25295590846299454,
                                   0,
                                   0,
                                   0,
                                   -0.35507043900123086,
                                   0.17346895744043789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016033534548320055,
                                   0.16097390418813584,
                                   0.029134303278769993,
                                   0,
                                   0,
                                   0.040946611568870049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32529570008730579,
                                   0,
                                   -0.30284155631056697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25396346115626095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13484081082116384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10802542572400953,
                                   0,
                                   0.33120593194619619,
                                   0,
                                   0.59124873047727866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40954335273733222,
                                   0,
                                   0,
                                   -0.81707527915996758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036798856353711558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50117925026803323,
                                   0,
                                   0,
                                   0,
                                   -0.12756678611277555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41657617652562423,
                                   0,
                                   0,
                                   -0.10319487657238585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57579756126584059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62460721672817532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0239730518631542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074396180882780716,
                                   0,
                                   0,
                                   0,
                                   0.23548717226023486,
                                   0.55633586473139196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2167294956320675,
                                   -0.039035095242327914,
                                   -0.36802024498225877,
                                   0,
                                   0,
                                   0.40934559605689136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073589373768200572,
                                   0,
                                   0.36709338621866444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14534893501913471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016359504700923434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32100573056093806,
                                   0,
                                   -0.11086046367263686,
                                   0,
                                   0.033191218989596288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48282369930138719,
                                   0,
                                   0,
                                   0,
                                   -0.093899799987289367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5298715328005128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41823238929702461,
                                   0,
                                   0,
                                   1.0619114691839822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0368573274299098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66799386034468822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44993806493533106,
                                   0,
                                   0,
                                   0,
                                   0.19984126935309354,
                                   0.048054178269752702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39879246710267724,
                                   0,
                                   0,
                                   0,
                                   -0.35279226451480961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044112649251561553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15378707271710107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46978677854973927,
                                   0,
                                   0,
                                   0.33740698988706314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29519270097687456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4454210200608042,
                                   0,
                                   0,
                                   0,
                                   -0.83082859284221822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73964673773259293,
                                   0,
                                   0,
                                   -0.17528717388977499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41974273385317862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18641111741376937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56242692362507174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19516322047021051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27697162973862499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71245020113711899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42521693502692687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11652289371623034,
                                   0,
                                   -0.11168945250943114,
                                   -0.34599647244051429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22059404687378303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039401890715450312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028694646719726366,
                                   0,
                                   0,
                                   0,
                                   0.090555832623028854,
                                   0,
                                   0.35611792233741746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69188704349203534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4767992506941528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0011181744087898496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23933646347794479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52610233076842383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20364774685841544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02774702829274173,
                                   0,
                                   0,
                                   0.16130749855126558,
                                   -0.47619900492953116,
                                   0,
                                   0,
                                   0,
                                   0.34791383692172489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029549398026152876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16179019606029699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20646585153093483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16826158353424486,
                                   0,
                                   0,
                                   0,
                                   -0.30218211843926474,
                                   0.5974716632412127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38633063072245832,
                                   0,
                                   0,
                                   0,
                                   0.13418859806889588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5589042366959176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033787404379987895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27721448731260478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27921385197007825,
                                   0,
                                   0,
                                   0.023938214846956796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60033079181731575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042746873574894595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35551153764113247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084470513358671159,
                                   0,
                                   0,
                                   -0.05947037110185148,
                                   0,
                                   0,
                                   0,
                                   0.16173783301853922,
                                   0,
                                   0.40444278464866168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36869473096314581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14023200979674733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32316477384882081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39786898905016582,
                                   0,
                                   0.33881416531003539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18352416624123946,
                                   0,
                                   0,
                                   0,
                                   0.16216566596386578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7961865515048675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28724854156573021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5740560625394906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42843282691240542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44184579420106729,
                                   0,
                                   0.50577274593337895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13371079871405978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25496587442345064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53153114831439185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57925325823732565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15274803971372664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16650187542680286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15064498044488647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1294215866990977,
                                   0,
                                   0.057549868002788322,
                                   0.049738855087626141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75259093097824137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039488037594973227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015119917694755748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059663306395481251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3776693353291215,
                                   0,
                                   0.52338519280510654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7271083823498361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21923108499940525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05590379826960265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088484186076276658,
                                   0,
                                   -0.13906285709023467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36912709267759319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17626244559555176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86809240278051136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01492521018793512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24516486483626887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26043853504922948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050924391096900265,
                                   0,
                                   0,
                                   -0.55125324178173618,
                                   -0.30104541536011792,
                                   0,
                                   0,
                                   0,
                                   0.12513618704778107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27286102643939314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27299640828024541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31580498018213943,
                                   0,
                                   0,
                                   -0.36023970742897804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63494104981466903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17883934956339959,
                                   0,
                                   0,
                                   0,
                                   -0.22998829370165341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33858657314901008,
                                   0,
                                   0,
                                   0.36345746473985319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63833988537923625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80680147558041604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26287787355257486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29295334721718286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.008760464603902356,
                                   0,
                                   0,
                                   0.2867037753054068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040054968194115317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47828487741100179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43113723872333981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54169805628452394,
                                   0,
                                   0,
                                   -0.15752588161374112,
                                   0,
                                   0,
                                   0,
                                   0.17751905297228235,
                                   0,
                                   -0.11380545211307216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11309457893523935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2003899357371538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19518068679700548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43960649465718837,
                                   0,
                                   0,
                                   0,
                                   -0.33831188985394017,
                                   -0.39596174531475925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05925158441438938,
                                   0,
                                   0,
                                   0,
                                   0.55936339218997655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0826502292582703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41734970422066503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87577539042140939,
                                   0,
                                   0,
                                   -0.2543633572514894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06818370910146096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70360311407738707,
                                   0,
                                   0,
                                   0,
                                   0.41496761134746174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49590894869692992,
                                   0,
                                   0,
                                   0.8520443272016226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41352366768760757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10762042372771298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22896960135129674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062333690076504154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16199118268656404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08201877161446805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092174885221120495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42151466046855046,
                                   0,
                                   0.57804250978040228,
                                   -0.09182480301884649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0024765042126866301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61582983914328349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23485742280291882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1520023586330316,
                                   0,
                                   0,
                                   0,
                                   0.33964130904433015,
                                   0.20839795731186589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10035840533679771,
                                   0.079701757492833591,
                                   0.10065286473325483,
                                   0,
                                   0,
                                   0.31852672922049063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046473592914995851,
                                   0,
                                   -0.080854280940009043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48266877128690339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23804900866256717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33779274285310912,
                                   0,
                                   0.50999601643376657,
                                   0,
                                   0.13251921628447796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039363805712541527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60262933653846029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13016181738494875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049178863809448213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50247375410182127,
                                   0,
                                   -0.15836475705050801,
                                   0.23556358136497485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25511295712601872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17681406600273727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43189397849490446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4334363251354349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20311974393564222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39330490700366616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39815612681663476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04796710575445666,
                                   0,
                                   0.14258822679502003,
                                   -0.013548904502070885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077076779163818901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37167671352635023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5392198463981025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50177144884322777,
                                   0,
                                   0,
                                   0.23043397985296252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027117785621387381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55799049427678094,
                                   0,
                                   0,
                                   0,
                                   0.82163344431313556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32199760446769171,
                                   0,
                                   0,
                                   0.39627524705407757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095008735110033937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26703341075741932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79047547716740585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10884487148838468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03624528800769751,
                                   0,
                                   0,
                                   -0.083138146167173521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21192143908949332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.243002201108383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11064942608837783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33437515498425568,
                                   0,
                                   0,
                                   -0.078747313231310179,
                                   0,
                                   0,
                                   0,
                                   0.41986859787760306,
                                   0,
                                   0.32623856478627145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32124308563022747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59983065593732554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13826874650074741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15633506365193878,
                                   0,
                                   0.16387514108862683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47136895413771118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82905055685186713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14167753176127823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20107211695293942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27869055501812778,
                                   0,
                                   0,
                                   0,
                                   -0.46977947658995689,
                                   0.16092256358028628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1285693314590293,
                                   0,
                                   0,
                                   0,
                                   0.13748904144970719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33764603142187211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69704705593513949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29586167373344263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22186891076615145,
                                   0,
                                   0,
                                   -0.20791547104567182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16280034405367852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27539471678766314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46238944690572203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51291187220561996,
                                   0,
                                   0,
                                   -0.14725983645883017,
                                   0,
                                   0,
                                   0,
                                   -0.44610504419384572,
                                   0,
                                   -0.017080205145408395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11940689026184005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074414469656734011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25069093404577369,
                                   0,
                                   0,
                                   0.40071614881333173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88335182787900357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12506036036086898,
                                   0,
                                   0,
                                   0,
                                   0.30205242033959706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1690567599739497,
                                   0,
                                   0,
                                   -0.31204394587046269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57841435384113715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13091283700047465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17186001940303644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42369563211666356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17386377446445647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23722329322683972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39714700660161073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044768050942386589,
                                   0,
                                   -0.36913050593540503,
                                   -0.50502239432277518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36483707875888727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14299059496509395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17143871121079918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62962042231067061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32392733949779301,
                                   0,
                                   -0.0032194010257116379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12375014016625495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14209728244597075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68053883292766804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35540440788732225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26209039168048648,
                                   0,
                                   0,
                                   0.43168347318125561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10642412757660492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31070341406421076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036056052261605048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071353825401384005,
                                   0,
                                   0,
                                   -0.36560178025307799,
                                   0,
                                   0,
                                   0,
                                   0.12699742815838402,
                                   0,
                                   -0.50367333407308124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31000641329219275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069338203451281388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21459625122945705,
                                   0,
                                   0.22820225153535978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34736598841800476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2002636044806016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010064873686952122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90198863936479923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22493806402551003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21649141462043864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94216959997703298,
                                   0,
                                   0,
                                   -0.018039422214798869,
                                   -0.57653645120612296,
                                   0,
                                   0,
                                   0,
                                   0.49990308734795935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033317522176354891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27134333205636557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37186553018792712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27386956968314968,
                                   0,
                                   0,
                                   0.14899006000698151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2174719669933641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25785195009400319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41041737648902188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28083679729122996,
                                   0,
                                   0,
                                   0.39080004542370772,
                                   0,
                                   0,
                                   0,
                                   0.27008843644475122,
                                   0,
                                   -0.27228558683775117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29874489643555591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11983171990898878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27418149943799897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14309532913211301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052082194087575556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68186917767358679,
                                   0,
                                   -0.26410969580488747,
                                   0,
                                   0,
                                   -0.24089333728326814,
                                   0.15735511379344411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18658588652860647,
                                   0,
                                   0.12617519575206099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70102920411033631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63586997509866916,
                                   0,
                                   -0.69875651024967644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21803163600593883,
                                   0,
                                   0,
                                   0,
                                   -0.38820818516834482,
                                   -0.13062502868903103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4921096837138294,
                                   0.092447680585561909,
                                   -0.29642506128914886,
                                   0,
                                   0,
                                   0.22600728591402575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28276299391546211,
                                   0,
                                   0.18752464085156745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23229595439381959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35918546508536886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020238630755611005,
                                   0,
                                   -0.19788338241836395,
                                   0,
                                   0.23950916940426625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52750677543661861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49391983628038943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68138190295312506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12478835311651719,
                                   0,
                                   0.46532897156698899,
                                   0,
                                   0,
                                   0.69683039147139092,
                                   -0.6008103392573666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41218296337445204,
                                   0,
                                   0.81637862812399042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12635383782967952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053261154306993408,
                                   0,
                                   0.058999980185875461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020186098582451351,
                                   0,
                                   0,
                                   0,
                                   1.61882498709278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29234452980272868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28813830851178263,
                                   0,
                                   0,
                                   0.11179269982439483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25542391180694179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0039675367335703926,
                                   0,
                                   0.62977707276186201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083777241313149814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22550012582652124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079211339652317664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095704519079244155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56177858568855199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31792867861915003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49659704220365186,
                                   0,
                                   0,
                                   -0.42650298672469811,
                                   -0.059041581446173858,
                                   0,
                                   0,
                                   0,
                                   -0.76557377026946194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39601339854172507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45067710447112169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54423734309178684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3904312226191648,
                                   0,
                                   0,
                                   -0.14824836415053028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11767493534136879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24372143830259929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022990072336266223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3374715318716498,
                                   0,
                                   0,
                                   -0.3070432508004402,
                                   0,
                                   0,
                                   0,
                                   -0.15235885322140175,
                                   0,
                                   -0.17847461301602913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062941601137938938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43407934586595298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10304298814091151,
                                   0,
                                   0,
                                   0,
                                   -0.0038382176821135094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73198944216575368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52504105155862402,
                                   0,
                                   0,
                                   0.93410696917464531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70949249839332462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39924070577481702,
                                   0,
                                   -0.0055678889234656789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75623895858712786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5043137344888643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11254805336375084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1580702915265845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40727066707789966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28972653500786999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032898561927357253,
                                   0,
                                   0,
                                   -0.39401837651615296,
                                   -0.11649069396455863,
                                   0,
                                   0,
                                   0,
                                   0.37152134607219456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5864304583323765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43908993666159318,
                                   0,
                                   0,
                                   -0.16551929789981942,
                                   0,
                                   0.78566453892667532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39104807404996555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42542032589976736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41151663984622316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51107825940402263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3501662191142762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27253696837143265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44409495662589826,
                                   0,
                                   0,
                                   -0.11007731127417172,
                                   -0.77960914708362838,
                                   0,
                                   0,
                                   0,
                                   -0.052188998752120588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085320375869609819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36168821562469,
                                   -0.26176095707516228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41315169040625033,
                                   0,
                                   0.23021071144965569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70811068782501219,
                                   0,
                                   0,
                                   0,
                                   -0.96668580644733038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40095192704419313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41756344498372633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60050427699688746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55008979144242509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71546972373781492,
                                   0,
                                   -0.13014413517227119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22529769006088046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33861729621944675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056089904616503622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1237187591151739,
                                   0,
                                   0,
                                   0,
                                   -0.23276046967468608,
                                   0.083711230485866567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0063089032999159994,
                                   -0.47045716316098807,
                                   -0.11067679183117114,
                                   0,
                                   0,
                                   -0.25149452416429185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35633072804412824,
                                   0,
                                   0.33070731015230914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49237118411717373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32602028636819924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061251702202822604,
                                   0,
                                   -0.048253240702504113,
                                   0,
                                   0.1884208073837555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076893618310136885,
                                   0,
                                   -0.083967818263639346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071646856575678514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28698544998154246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17356342832834484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.656959535070754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20325373156180779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054295011364243188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41348288030768843,
                                   0,
                                   0,
                                   0.038535233305441424,
                                   -0.28729911297314076,
                                   0,
                                   0,
                                   0,
                                   -0.084021647804592869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29481486923700539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89671165038862055,
                                   0,
                                   0,
                                   0,
                                   0.34049328941021051,
                                   0,
                                   0,
                                   0,
                                   0.21907783377164683,
                                   0.3363873827977657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5101099211095147,
                                   -0.025427155159871512,
                                   0.15051723281998003,
                                   0,
                                   0,
                                   -0.33678235831916903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37233954481003906,
                                   0,
                                   0.088959622372055458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19423178790775808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17290491802883037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17210989439855645,
                                   0,
                                   0.052731709452280597,
                                   0,
                                   0.28178216256596927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41688648088167346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.745380271325077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0029993303488408569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35882321099289982,
                                   0,
                                   0.54067112242725035,
                                   0,
                                   0,
                                   -0.15213295949880229,
                                   -0.47002704438082638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19985812217039095,
                                   0,
                                   -0.68606554885468896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36991105425506932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4208440425081742,
                                   0,
                                   -0.1821464950092852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25146318628899517,
                                   0,
                                   0,
                                   0,
                                   0.13594067687753797,
                                   -0.18257968092344723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03285507462614299,
                                   0.53515406953527411,
                                   0.29394577175024356,
                                   0,
                                   0,
                                   -0.20750361712014675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14690881963437818,
                                   0,
                                   0.62789539188144983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09512011745518445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028737855860062222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13961359369663789,
                                   0,
                                   0.1422615492119455,
                                   0,
                                   0.050803809337377756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.843545828002364,
                                   0,
                                   0,
                                   -0.18833027103799535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15123190338854828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92579428811239017,
                                   0,
                                   0,
                                   0,
                                   0.080070870014942425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62872532110432588,
                                   0,
                                   0,
                                   0.37179081651036561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16239550534755101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36956984190616282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11150167522930386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08383440910214901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40127942276612594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095294369710170163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20851880117217775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097807428816550121,
                                   0,
                                   -0.45423551657826994,
                                   0.5499858099770305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072551481722907846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50404288569576405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041011857122231279,
                                   0,
                                   0,
                                   0,
                                   0.37011210073996825,
                                   0,
                                   0.77352309242955708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50427909930848469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017363292634835409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030441141286394524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15429781572180484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84304600594116952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36725313511051044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39949760909631427,
                                   0,
                                   0,
                                   0.4247051514541556,
                                   0.24378499345298693,
                                   0,
                                   0,
                                   0,
                                   0.4910092306968018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29342354903509804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016767704072171069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14972512461307069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10939774616275839,
                                   0,
                                   0,
                                   -0.40133922557068025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22403020634775422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21025520994178459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37514912655771654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28634029842985159,
                                   0,
                                   0,
                                   0.046099345523402682,
                                   0,
                                   0,
                                   0,
                                   -0.097931684942859101,
                                   0,
                                   -0.49405875468265326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3999376566027974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26768821241452706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52537206080642129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74461696342398631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34840913302115728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11111476564379343,
                                   0,
                                   -0.16995987439928723,
                                   0,
                                   0,
                                   0.05194525511557524,
                                   -0.56067078987297481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054991645098249164,
                                   0,
                                   -0.70214539713663049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78663503382617672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0050186533246345333,
                                   0,
                                   0.54856296289661977,
                                   0,
                                   0,
                                   0,
                                   0.18296487710867942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76185038324128329,
                                   0,
                                   0.36338104248906677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067966856308829024,
                                   0,
                                   0,
                                   0,
                                   0.60862819130481927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40187208015652126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36050905042841835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25655608886873871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29296851838278243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06963113837116798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046438557017300146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21721619486891641,
                                   0,
                                   0.85684027969235843,
                                   0,
                                   0,
                                   -0.2215331965418825,
                                   1.0813976484628485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024050543478820463,
                                   0,
                                   0.42527244853159074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37972788861245038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11152406276281641,
                                   0,
                                   0.3607107722753905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1004247681583303,
                                   0,
                                   0,
                                   0,
                                   -0.25146442807779201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82798603159294837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40350947341141757,
                                   0,
                                   0,
                                   0.049775834551498699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056261189518453047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34538253008568154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013718281613740647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46977838327584553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058461322021396596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38941730849828127,
                                   0,
                                   -0.044764293294394034,
                                   0.32865359162230734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26071859177904549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36637823640938438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43879744698811513,
                                   0,
                                   0,
                                   0,
                                   0.5371893644168978,
                                   0,
                                   -0.37996509019330371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10608289336273123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22060569951597417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19139625668232693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52823428714117071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13954869040369788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75633042200857781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28253549640594605,
                                   0,
                                   0,
                                   -0.34302287351671695,
                                   0.020521981224560122,
                                   0,
                                   0,
                                   0,
                                   -0.41432352230554764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29053277166135055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20412304450701901,
                                   -0.28663117991083503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052673278630343136,
                                   -0.037241363385836029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61812892165927591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24535356370050887,
                                   0,
                                   0.41314460937620223,
                                   0,
                                   0,
                                   0.11982061825495634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01054393901694714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20455081615496595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49437008243516245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89593256343189265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3002314406758016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067568611926301925,
                                   0,
                                   0.32437038137516644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037245300945145318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57155047916504287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39444673644501277,
                                   0,
                                   0.51900129600010636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9875582440538957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2296237790676024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75096831187265511,
                                   0,
                                   0,
                                   -0.32533944175514629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69319893678439182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036778157893453484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064463006028253583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43826878697918104,
                                   0,
                                   0.16967532369391825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20051565946438515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081481662434634727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83918138610822335,
                                   0,
                                   -0.24480997661782528,
                                   0.014971014031782193,
                                   0,
                                   0,
                                   0,
                                   -0.58851392083529364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24423547258023795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098416267816222744,
                                   -0.5978620384338581,
                                   0,
                                   0,
                                   -0.5588386748880213,
                                   0,
                                   0,
                                   0.46682270161345502,
                                   0.67364775212439032,
                                   0.23976786832360944,
                                   0,
                                   0,
                                   0,
                                   0.046977937527346351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2329773454442263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042932099003440936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13093652653787052,
                                   0,
                                   0,
                                   -0.07710377008235729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018983893729388048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68495282489836962,
                                   0,
                                   0,
                                   0,
                                   -0.56816273577493059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41426588583600965,
                                   0,
                                   0,
                                   -0.7082178238142709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026612510820488794,
                                   0.45080415989362094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66253904404207165,
                                   0,
                                   0,
                                   -0.82167944470583976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030351300600761241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54596818988579721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029421116439284568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15232994390905738,
                                   0,
                                   0.017184213959615401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67802585953021988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65164790560611374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1975242898109929,
                                   0,
                                   0.10943061760430603,
                                   0.26275298436259353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025301044832048043,
                                   0.43854848033955052,
                                   0,
                                   0,
                                   -0.47912879646584317,
                                   -0.35157811321033849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25596967672035409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41868169361315277,
                                   0,
                                   0,
                                   0.049120766919355782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16582702676629854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32978960982449729,
                                   0,
                                   0,
                                   0.052873369007908282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23915179145779461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11994526442931563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19415256313785445,
                                   -0.30658568642078432,
                                   0,
                                   0,
                                   0.2720078248040243,
                                   -0.0024769558856635593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18938179021936496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48543776418619522,
                                   0,
                                   0,
                                   0.41557444378841429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20014498531467406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37961686113704396,
                                   0,
                                   0,
                                   0.10042313208098785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1699474466926818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35632048334121802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.068489281464738,
                                   0,
                                   0,
                                   0,
                                   0.17013350443212466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48404214951443625,
                                   0,
                                   0,
                                   0.45557797100783876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35557021734662198,
                                   -0.62861492537296004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03813208574072486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03974847207837047,
                                   0,
                                   0.018389439634352966,
                                   0,
                                   0,
                                   0,
                                   -0.59754601763269244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041557871449095479,
                                   -0.1347749137653709,
                                   0,
                                   0.080298263702304071,
                                   0.51744458139364102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45773005507705916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027096182514498829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24313030449211789,
                                   0,
                                   0,
                                   0.15786393233030296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20716529657931182,
                                   0,
                                   -0.09097645668488416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19785001541952105,
                                   0.64951000397147229,
                                   0,
                                   0,
                                   -0.040972307784759188,
                                   0.29610561277257463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20556816809375617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024019484854575862,
                                   0,
                                   0,
                                   0.20935278049998704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35989747510832798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38032716925344923,
                                   0,
                                   0,
                                   0.029260063089920754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27907238374597548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10029243843026181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099077869815522968,
                                   0.11452653084770806,
                                   0,
                                   0,
                                   -0.21781214005325095,
                                   -0.12626367338369407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14323550108028416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33329083572311857,
                                   0,
                                   0,
                                   0.30562186447432033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49571291249796334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068707741643064035,
                                   0,
                                   0,
                                   0.20396605650115077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32982423484003442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53650765922868404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52772007311381586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0085033406870707456,
                                   0,
                                   -0.56718869101411162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033735342946978927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3484005935511803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0069552795222193736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44988406135263703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27344307431834275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30194453950938471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1982854514131549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098842344571893545,
                                   -0.51836779003284883,
                                   0,
                                   0,
                                   -0.28719138297002106,
                                   0,
                                   0,
                                   -0.26575925938377637,
                                   0.16464503791594023,
                                   -0.55265789281864364,
                                   0,
                                   0,
                                   0,
                                   -0.078104004367715835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25781667907545369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52376682337915625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56167970323323091,
                                   0,
                                   0,
                                   -0.13455545528438617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32081958963171192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32345443927065987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0654058702436429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96677673845726664,
                                   0,
                                   -0.58461538916878053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061387547216273847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10185839309887101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49712372690833034,
                                   0,
                                   -0.45016001806232497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056194647192001956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16683128135753872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42384421841352804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030175722999569578,
                                   0,
                                   0.12016981985662986,
                                   0,
                                   0,
                                   0,
                                   0.2155542639659144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57150469545034621,
                                   -0.20732381858384277,
                                   0,
                                   0.32923784786615307,
                                   0.16827367414543354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13142656588893284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43556668657805042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10147313651133412,
                                   0,
                                   0,
                                   0.061974667058202981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16895385306301181,
                                   0,
                                   -0.050520920968413825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45803301453479511,
                                   0.093133109851341184,
                                   0,
                                   0,
                                   0.26427558739844731,
                                   0.16356008132112881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60750418375572601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038029442351424116,
                                   0,
                                   0,
                                   -0.30291153184488434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036328977666929198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22495959904248555,
                                   0,
                                   0,
                                   -0.27046783648372114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30820731957389375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051032431132951424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18228090128956798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61575205710231484,
                                   0,
                                   -0.28521527287806747,
                                   0,
                                   0,
                                   0,
                                   0.23158104673468577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10322089127128227,
                                   0.046398439337116119,
                                   0,
                                   0.194980466267966,
                                   0.010621900574112234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42905958179275305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022160719720090882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089560806251081149,
                                   0,
                                   0,
                                   -0.39545068713985265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10826619493671745,
                                   0,
                                   0.20248652887430638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14160787603199659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066991738584967847,
                                   0,
                                   0.45669438731896822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12180654659149126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83045937110689838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20337024805218226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13136733461941333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061425701044395264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71068928172283563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37244408578745919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67447427192227793,
                                   0,
                                   0,
                                   -0.54402723842992384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025577726918315648,
                                   -0.40495548639219214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70566071784707174,
                                   -0.032252422004329206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036456892937682811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56868643006523378,
                                   0,
                                   0.42869716039073491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36266963551779829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099835270075903815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31376200627967304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42015351951568314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27388585517712394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040970297986460437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018824013686458033,
                                   0,
                                   -0.56711836323151865,
                                   0,
                                   0,
                                   0,
                                   -0.35614199834246207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17568166127278492,
                                   -0.032489994318713036,
                                   0,
                                   0.21343235666114882,
                                   0.080093219796773432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30830038331004672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14761973346916685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31242063384594188,
                                   0,
                                   0,
                                   0.071476079075717569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093367212651323597,
                                   0,
                                   0.4871808277616092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55918521442225999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29829720051186082,
                                   0.019201160694929498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16381937377597067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34473769455652636,
                                   0,
                                   0.17914987178575442,
                                   0,
                                   0,
                                   -0.28393851749649313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010858617866873033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52554235733869537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25150087291246687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047937621371337003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026964002932112353,
                                   0.045515807955643556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38701955884558542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28748439847140139,
                                   0,
                                   0.40425109298141093,
                                   0,
                                   0,
                                   0.40828852165488283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57209646723453844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32329882248687264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023170248172003402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29151389797749494,
                                   0,
                                   0,
                                   0.14896865866617889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46913195940811936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052431386997377094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050541231313109974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43612047001984983,
                                   0,
                                   -1.142663652984639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18090418388866397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40712023720556928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36458625910329817,
                                   0,
                                   0.34853967380250972,
                                   0.36090801319573657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010184203098437091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80072749832813672,
                                   -0.30921123546385632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087187557432726173,
                                   0,
                                   0,
                                   0,
                                   0.42570662433056861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27256626189115235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2988052560470012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38372095125412525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018095385915474459,
                                   -0.0022119550473107957,
                                   0,
                                   0,
                                   -0.61914435484159724,
                                   0,
                                   0,
                                   0.2901671695968922,
                                   -0.69346846519027228,
                                   0.34849526193557145,
                                   0,
                                   0,
                                   0,
                                   -0.55805374962562326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26752898211291926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25699894460501738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050942734821431503,
                                   0,
                                   0,
                                   0.24313418928569835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28107826548212222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48695511859463048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31187310233539539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42712634397660931,
                                   0.46605816290306523,
                                   0,
                                   0,
                                   -0.28032565399946668,
                                   0,
                                   0,
                                   0.14368681496746277,
                                   -0.12458130634478665,
                                   -0.84473822071144444,
                                   0,
                                   0,
                                   0,
                                   0.21645212738559844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52893311748370642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17883778927299898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10258745503682405,
                                   0,
                                   0,
                                   -0.070508263229893051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.003152618751511807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10030299396647407,
                                   -0.47438719338300728,
                                   0,
                                   0,
                                   -0.69189062840615745,
                                   0.22515798414827315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14999869355670581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083209259187084481,
                                   0,
                                   0,
                                   -0.10594154854419055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34717581788364171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13832145868322487,
                                   0,
                                   0,
                                   0.081989999334281513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2168261734268806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037954131965298316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52129250752728284,
                                   0,
                                   0,
                                   -0.21128338927760315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5839059620121605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11166420675803568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93707045280234147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12387869346546954,
                                   0,
                                   -0.13286336660062534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50455889374344587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65575786902815236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20981326214545293,
                                   0,
                                   0.18243075095866568,
                                   0.26673463347786597,
                                   0,
                                   0,
                                   0,
                                   -0.041307908111832034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10870634801107454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0020864624839247031,
                                   0.20851273770177883,
                                   0,
                                   0,
                                   -0.0041404390869346497,
                                   0,
                                   0,
                                   0.33736680916057632,
                                   -0.80594630212416773,
                                   -0.62603717054693486,
                                   0,
                                   0,
                                   0,
                                   0.37592645944438047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56415057683480441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4674326392241186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28880415140026056,
                                   0,
                                   0,
                                   0.24348956014226364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43337836078786524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.001846833584649217,
                                   0.0029157818672292529,
                                   0,
                                   0,
                                   0.11202451630235655,
                                   -0.68802713154075379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28060887958215253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42845947026276782,
                                   0,
                                   0,
                                   -0.0052344090354241521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31082713039119886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34438140117443466,
                                   0,
                                   0,
                                   -0.034460242495258787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019012604321661832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18694908274358948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48711154646666233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2792707432265058,
                                   0,
                                   -0.28035974645428458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36949347382273057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20733517262413509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37418344738855563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26436037177387434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46552727780011804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42857800055182405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99930217328614845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46022052513386624,
                                   -0.21763296255757139,
                                   0,
                                   0,
                                   -0.70422168595454859,
                                   0,
                                   0,
                                   0.039000896824949963,
                                   -0.11392982531706541,
                                   -0.11419956059737978,
                                   0,
                                   0,
                                   0,
                                   0.21521315616389142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0225949225112533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086276834892615506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092696516773187132,
                                   0,
                                   0,
                                   0.48612821425068231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057471199283604148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16147430816660607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2685288637768331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88720613936170944,
                                   -0.37515909819204984,
                                   0,
                                   0,
                                   0.12901520668536984,
                                   0,
                                   0,
                                   -0.37884856956327084,
                                   -0.090601062376972408,
                                   0.28101319297548877,
                                   0,
                                   0,
                                   0,
                                   0.53552844949682998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12442977865782716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16941516766119644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47413375422492787,
                                   0,
                                   0,
                                   -0.027197828800667262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26230853697559731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43723156241708194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1491846573590333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16069248581678122,
                                   0.22186111848437798,
                                   0,
                                   0,
                                   -0.48443312796956695,
                                   0,
                                   0,
                                   -0.37561564870939135,
                                   -0.27846670854134298,
                                   0.35415775152533191,
                                   0,
                                   0,
                                   0,
                                   0.076492040073529971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1917686945822204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3338640599345658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74759960544919601,
                                   0,
                                   0,
                                   0.58030344998739625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70958990538692279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0217582214564127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30987634642126038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28658645664809723,
                                   0,
                                   -0.54899358923028885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21801269253386002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.220256544320832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78460049926675346,
                                   0,
                                   0.53977743973445225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17897931193995123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0042187655378150592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19959956639579068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11847731250916775,
                                   0.13604776369827529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26235293923727221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25752218386446973,
                                   0,
                                   -0.027022302413253894,
                                   0,
                                   0,
                                   0.61144264809004811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074915705894313733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32717775426067391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55246487942254574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21515643103951071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16037377644539116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08919815505255782,
                                   0,
                                   -0.59317095940708953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95023266604027101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8280223786309977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10933321048922118,
                                   0,
                                   -0.13662677392766334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056800062658818234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13164515804981186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23071227606937342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38300825670000138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6194237960383695,
                                   0.41042078725564152,
                                   0,
                                   0,
                                   0.14275304607338052,
                                   0,
                                   0,
                                   -0.63195272452574469,
                                   0.49524505500774529,
                                   0.15435703099739567,
                                   0,
                                   0,
                                   0,
                                   -0.49900944843716971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68132091292352814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14879050037098954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43098307951096043,
                                   0,
                                   0,
                                   0.46849811605407687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030141909395160441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5384084835130335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02484987639966392,
                                   0,
                                   0.10958960520881839,
                                   0,
                                   0,
                                   0,
                                   -0.15925312085005272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41171653997096802,
                                   0.31643985731479524,
                                   0,
                                   -0.10300743936474187,
                                   -0.0079376844318630006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098246400925505017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36242680950046924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16271201408859867,
                                   0,
                                   0,
                                   -0.46267465667311597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10129424597317788,
                                   0,
                                   9.5963450514155403e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29687068646081088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45000055207549561,
                                   0,
                                   -0.13288293839071205,
                                   0,
                                   0,
                                   0,
                                   0.13171647471568099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043085612433354611,
                                   -0.38917343652780689,
                                   0,
                                   0.45109710384435719,
                                   -0.35880225227004892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3196882206898814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1344567367896114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2239872089027044,
                                   0,
                                   0,
                                   -0.0064415086129947195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02309490486518985,
                                   0,
                                   0.13340126185600107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47909330738776512,
                                   0,
                                   0,
                                   0.12966251551030103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47988718494035182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097871148077141673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60815893454344594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32726393014088184,
                                   0,
                                   0.36076864362995492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84608965986971962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60034431450230163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13153202390514729,
                                   0,
                                   0.42753597538119986,
                                   0.029667979746249691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22441760466740859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021029088316953697,
                                   0,
                                   -0.16819405863128448,
                                   0,
                                   0,
                                   0,
                                   -0.30499416092009607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27993915017539611,
                                   -0.25294020864185085,
                                   0,
                                   -0.024340613120135284,
                                   -0.30056479075234782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034425070527373959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24451756531994959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011999349919248866,
                                   0,
                                   0,
                                   -0.19975597498293782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41484312258158851,
                                   0,
                                   -0.56700293230810439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29232004227435171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2913163998427965,
                                   0,
                                   0.035534038238372284,
                                   0,
                                   0,
                                   0,
                                   0.13783952865625121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13762648506437336,
                                   0.26929982963267812,
                                   0,
                                   0.30264398476278109,
                                   -0.072063302635890031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19978120212858008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07268433565890732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22029964964280663,
                                   0,
                                   0,
                                   0.64601075318762569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26075649253541233,
                                   0,
                                   -0.20523176450570541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087006137602965383,
                                   -0.04710284479187668,
                                   0,
                                   0,
                                   -0.0047232216892895834,
                                   -0.35162012358630418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47831597764741568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24108061582673307,
                                   0,
                                   0,
                                   -0.46445241503717316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10568605448330601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11165462481046723,
                                   0,
                                   0,
                                   -0.23422622802202969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32551242097414557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42364323529144077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1250422146087262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29954542234095743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80832531246093164,
                                   0,
                                   0,
                                   0.44766988252361528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030989729779943083,
                                   0.3902815844846107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6623338842056824,
                                   0.076305661278288348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2448109789550364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14655122781445964,
                                   0.78709434186852534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24656039022757337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27291988664627614,
                                   0,
                                   0.14577070606528775,
                                   0,
                                   0,
                                   -0.27063941454686641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034126163444364449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10639072423976664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23836349544923796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41818870554270238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68713135593432439,
                                   0,
                                   -0.014367264572034827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25012434493164715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070106414045072507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2457314857804912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41314762141741823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23283099139201968,
                                   0,
                                   0,
                                   -0.35935806886030286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49268146909049904,
                                   0.16052488434920234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16190567166546641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30135244418009044,
                                   0,
                                   -0.31651979478448516,
                                   0,
                                   0,
                                   -0.22625406880639679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32732213696226586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47182791564625537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064766660121072558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24889462974659196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066842736456329141,
                                   0,
                                   -0.23635686832195069,
                                   0,
                                   0,
                                   0,
                                   -0.30122104785313186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31706101960039712,
                                   0.4782786807513762,
                                   0,
                                   0.2403746774762143,
                                   -0.31887922217729509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061225751817805575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42508915391484631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010853120312615382,
                                   0,
                                   0,
                                   0.024591907310535715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22884825849398716,
                                   0,
                                   -0.24637214426758863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096283758937264791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61695794788743397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32991158907109569,
                                   0,
                                   0,
                                   0.26898988382236821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78187913385828767,
                                   -0.68134224566789414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18457397057846289,
                                   0.55257080073742804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24660594640708564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67099065752978548,
                                   -0.2919188915670799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18663379933964219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18989606598905392,
                                   0,
                                   -0.23537097996661738,
                                   0,
                                   0,
                                   -0.29261864599928267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4171057017711669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049696376170201277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12399858090003883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49085230600650587,
                                   0,
                                   0,
                                   0,
                                   0.86528673573669035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26557875677589471,
                                   0,
                                   0,
                                   -0.65231344854440676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0413348317751039,
                                   0.15526500023766376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56947675181106161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0830854136007639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23035347806233647,
                                   0,
                                   0,
                                   -0.56246623045593547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070642550875359589,
                                   0.17522429792075067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77276641703352356,
                                   0.38727574967913192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40674087297887201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046561130987768137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65760416618577966,
                                   0,
                                   0.30695833824724478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10599937354022752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019158883650804363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26616212059085753,
                                   0,
                                   -0.25463129999453493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024650628776873372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93213101019736955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55818485860154676,
                                   0,
                                   0,
                                   0,
                                   0.61508698892825286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94515341173261769,
                                   0,
                                   0,
                                   0.22680388228026385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0026901368817471294,
                                   0.80044220735766891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00050014974033198276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060081356370508793,
                                   0,
                                   0.15469109024342922,
                                   0,
                                   0,
                                   0,
                                   -0.1144606432522159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38285752202746087,
                                   -0.218149965627286,
                                   0,
                                   0.05192111690645896,
                                   0.23667775780884065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20528460588024958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47490339697436917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012738344528442479,
                                   0,
                                   0,
                                   0.035023620088918996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65938252385139873,
                                   0,
                                   0.051271016166783104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30694947460002686,
                                   0,
                                   0,
                                   0.53254391257751388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43771612926619535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66968729188867571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30779620093648002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24344506091937149,
                                   0,
                                   0.024759971155942955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60871330561210724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25683267683904587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077982295220711678,
                                   0,
                                   -0.16546930764062392,
                                   -0.63455310120746167,
                                   0,
                                   0,
                                   0,
                                   0.46017722799522542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29860394267657209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11077137321994264,
                                   0.40306893867269139,
                                   0,
                                   0,
                                   -0.401689861884101,
                                   0,
                                   0,
                                   -0.075404852982370249,
                                   0.49822009143902835,
                                   0.29012831741787504,
                                   0,
                                   0,
                                   0,
                                   0.50103460662267618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1570857049305211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31871521585013007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4924385235323851,
                                   0,
                                   0,
                                   0.091278260045174558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2019428330073538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30007809308130839,
                                   0,
                                   0,
                                   -0.21753413372871166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74513820505717021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18711843635477343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59262904929296067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39593091882750675,
                                   0,
                                   0.11277217496412599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28851956680317603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47345204762805887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46164871703591887,
                                   0,
                                   0.41017653356481426,
                                   -0.62694588232222559,
                                   0.46781496779740611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3474971214866634,
                                   -0.47491766267054336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30764983688352432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18155227822162001,
                                   0,
                                   0.23066626936878826,
                                   0,
                                   0,
                                   -0.16294149207322844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17197528510750665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041130828068638728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44296090901550211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046750086204358249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45709788887038821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044109591132957537,
                                   0,
                                   0.67052908792955124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85052858371924089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12098008786769263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55039252863270127,
                                   0,
                                   -0.33082028375976585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58066134014937076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013440117586391177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.294317674347637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33590932471268126,
                                   -0.54281677311595466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17040228244625219,
                                   0,
                                   0,
                                   0,
                                   0.54054776031737906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42972452096037611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55998161941671509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33111622333270396,
                                   -0.12558006716450876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1644097525250241,
                                   0,
                                   0,
                                   0,
                                   -0.2209942429556436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69652225890304542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094810350677380778,
                                   0,
                                   0,
                                   0.24024107059680652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54580242768119813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20453098272728856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68808940234836025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87339067610854937,
                                   0,
                                   0.80380067973350078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083402072722135734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22731812425224202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18535979202602892,
                                   0,
                                   0.36950874488213897,
                                   0.25446039065722692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61438977382564641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65029119394183876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62286121588261301,
                                   0,
                                   0,
                                   0.53728578152747797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7404076014244857,
                                   -0.61231079051359705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79038752949885149,
                                   0.26281596528781431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14777183673344874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12883218559623072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48714374426397705,
                                   0,
                                   0,
                                   -0.39761970359846399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64854433672505285,
                                   -0.71770746528732932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08368372833782195,
                                   -0.92579421584210975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11758875395332977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55412660217787535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04278861937570809,
                                   -0.22472837741466897,
                                   0,
                                   0,
                                   0.33330160646953877,
                                   0,
                                   0,
                                   0.55206254361154627,
                                   0.38091730341576852,
                                   0.37206398680336028,
                                   0,
                                   0,
                                   0,
                                   -0.23507000988712862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49171427106120869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58534500227077557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048203708204478994,
                                   0,
                                   0,
                                   0.34541322742077107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2501291437145905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39670475544361194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14074262613736432,
                                   -0.49992458496358017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37462823029045883,
                                   0,
                                   0,
                                   0,
                                   -0.64449951295873287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13102032823485402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085286958649195097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024442415380892629,
                                   0,
                                   0.053225308858205353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47008382650618163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021483435280801946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61236418752384769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2802182291050016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56066324428576253,
                                   0,
                                   0,
                                   -0.29147060694342219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19815299462732128,
                                   -0.13055146831830391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35375706745266805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35199888700617427,
                                   0,
                                   0.43673018023586913,
                                   0,
                                   0,
                                   -0.13144183079354121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50055845272760746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21595353564233732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32324048560971069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43261952607182758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36068350708182839,
                                   0,
                                   -0.37564446896670006,
                                   0,
                                   0,
                                   0,
                                   0.11586367288661953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063172030343470881,
                                   -0.33898922859734326,
                                   0,
                                   -0.096469045617945601,
                                   0.048979270943591641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34868350054260183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18600761269667535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15886736170134036,
                                   0,
                                   0,
                                   0.037072183007010998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30343199046601804,
                                   0,
                                   -0.35034522062726775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63398412886112954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34073716943823146,
                                   0.53504525597636332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1135914953990409,
                                   0,
                                   0,
                                   0,
                                   0.02893056523680048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42655465574846668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31750798103909889,
                                   0.08707371436269791,
                                   0,
                                   0,
                                   -0.081205738773569777,
                                   -0.047996089302479478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053745788772229831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20862893245430769,
                                   0,
                                   0,
                                   -0.44143234140202431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40433794767508191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40549986111931763,
                                   0,
                                   0,
                                   0.46904548028168885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17141908952751178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25322760555874452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.005505823323609332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33554500505760304,
                                   0,
                                   0.34922735735214622,
                                   0,
                                   0,
                                   0,
                                   -0.30728467792103503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10451611701573452,
                                   -0.37450067988482871,
                                   0,
                                   -0.1146164351270048,
                                   -0.45018973614438518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10911609393889934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11282578434282547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42210379396788333,
                                   0,
                                   0,
                                   0.068879143735142867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23810759637615633,
                                   0,
                                   0.19941503217197534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061440258464575244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06774108776824056,
                                   0,
                                   0.28739086911035966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65743636946960371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.356014311802683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35301273349491635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29940856425005219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36852473397890906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67429256819415195,
                                   0.15550423617538731,
                                   0,
                                   0,
                                   0.12221116750104807,
                                   0.23419394357553036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31645175099712758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012588104733989566,
                                   0,
                                   0,
                                   -0.36759129760244108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13830793491895463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21759391146866441,
                                   0,
                                   0,
                                   0.20798238798344604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013659118171598844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32561114659502627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24534046031574766,
                                   0,
                                   0,
                                   0.46474304974453956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024121423244291729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0123430111673797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048655176504724389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18303402367212332,
                                   0,
                                   -0.20890787123683538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14048900507045728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29144839577780973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16876877455349501,
                                   0,
                                   0.65306352385830757,
                                   -0.44716632315043026,
                                   0,
                                   -0.15899558070240105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20361717993187181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71718158111791031,
                                   0,
                                   0.32428058502783541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32721812127673788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41972163943720658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11433532898873625,
                                   0,
                                   -0.65933760744533298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77384372235208354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10380729145553989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34359507302554171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43737345083504658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13645442399194574,
                                   -0.35438676886190579,
                                   0,
                                   0,
                                   0.55655219889884555,
                                   0,
                                   0,
                                   0.1017831113130479,
                                   0.051378285858031961,
                                   -0.016572009129688359,
                                   0,
                                   0,
                                   0,
                                   0.098804699180785632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021381605920184843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52981571135744532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35775184142200972,
                                   0,
                                   0,
                                   1.2037902202318589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14556649155268231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -2.2270530139239381e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29207070694862458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60685281757586762,
                                   0,
                                   -0.12984286932908104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04416089027178171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11918331112959578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20750330803305142,
                                   0,
                                   0.36207442918082638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49540064534453304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61721113903737357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096567963340874766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13791577603361799,
                                   0.067608139694382008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17560328248293844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56015093857372611,
                                   0,
                                   0.46075389154857205,
                                   0,
                                   0,
                                   -0.33252241403973365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32318474413914933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43088143401976475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097493211955058057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29911027264024492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012680683760982268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44349165593158968,
                                   0.29498994579903459,
                                   0,
                                   0,
                                   -0.27401226569360881,
                                   0,
                                   0,
                                   0.42051192118166125,
                                   -0.10380750705242429,
                                   0.075653395663000236,
                                   0,
                                   0,
                                   0,
                                   -0.15070241711769966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59041402859495951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050119405608236384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47555029876203408,
                                   0,
                                   0,
                                   0.2192734077266448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85240324276830315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47672157937200044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67250836508086032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22953870173330354,
                                   0,
                                   0,
                                   -0.60765563001034939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80137815902486476,
                                   -0.6344329772982229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45464191370984774,
                                   0.20189954541775551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15670519623091955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53976661036451679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86391118480375606,
                                   0,
                                   0,
                                   1.1855424858070758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4231411210345048,
                                   -0.16310652400045961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28261139301947191,
                                   -0.74970947840194224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0263978208604118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044797577070394612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35432893073832328,
                                   0,
                                   0.024205380619456703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8871021124279308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1852945545509401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31491376209277055,
                                   0,
                                   -0.52089162253323018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59401692344071666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052004063142800004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20095630333458139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021263588344899415,
                                   0.24035389080278113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88491891520247856,
                                   0,
                                   0,
                                   0,
                                   0.24804623276404422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23829815581576877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12532281876918736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032094685177219945,
                                   0,
                                   -0.24011763700484123,
                                   0,
                                   0,
                                   0,
                                   -0.012841103599511461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27363570067529119,
                                   0.035816461374565886,
                                   0,
                                   -0.55975615223653874,
                                   -0.25620591038284968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14863378371968228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29636570805955126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37808143984545678,
                                   0,
                                   0,
                                   0.35934351619644289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14407506234985856,
                                   0,
                                   0.25992194734158702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.001889018879584866,
                                   0.09337583218441442,
                                   0,
                                   0,
                                   -0.2472388720385571,
                                   0.14592610471267448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085740123936049323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080995876980682252,
                                   0,
                                   0,
                                   -0.045670086767868406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24710512467732701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39027878957051909,
                                   0,
                                   0,
                                   -0.7027910493176428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41600515334664023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1118231509117056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072954767247956701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27890541851473449,
                                   0,
                                   -0.3500164147547945,
                                   0,
                                   0,
                                   0,
                                   0.22232349267424553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15673059139501502,
                                   -0.12151406655312563,
                                   0,
                                   -0.31472679704550655,
                                   0.21133242923626877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37369721187887933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17710440077650053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59414274002934153,
                                   0,
                                   0,
                                   0.036448706976732456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023125837405552799,
                                   0,
                                   -0.18979241640670944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43690531294603202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09278032944232513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68758367665882802,
                                   0.0014206878012236902,
                                   0,
                                   0,
                                   0.44342418300140685,
                                   0,
                                   0,
                                   0.05257358078106325,
                                   -0.56623477685766832,
                                   0.42556379006829537,
                                   0,
                                   0,
                                   0,
                                   0.63191722263005046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010257767648327299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1723676059656995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33028912526933901,
                                   0,
                                   0,
                                   -0.18679428019935918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36723941692925838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23011584824375014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19320075935880765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62623515169731381,
                                   0,
                                   -0.90114102866089485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26693890470581888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47831087651279636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55949534916471333,
                                   0,
                                   -0.92740776697856364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11329186052684508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3608033126235225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32294725147494402,
                                   0,
                                   0,
                                   0,
                                   -0.17401613067561916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96094948943324654,
                                   0,
                                   0,
                                   0.987273745909241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28563665307925107,
                                   0.8205792202551343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52194446467150135,
                                   0,
                                   0,
                                   0,
                                   0.44099357136593997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6471220184025559,
                                   0,
                                   0,
                                   -0.4114538130826777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61115753104921888,
                                   0.43676164346440427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36026354347013589,
                                   0.047689258134531121,
                                   0,
                                   0,
                                   0.059526894066432245,
                                   0.1409068023989421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16238606200900804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42081334994802022,
                                   0,
                                   0,
                                   -0.19198343038110452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28960801813185266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18127495536763941,
                                   0,
                                   0,
                                   0.22707060100746407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52564469437030581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39953744941359526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095446568434808962,
                                   0,
                                   0,
                                   -0.13711835482391954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081776962585486501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22963865447582002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19287740374711859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84816402750201947,
                                   0,
                                   -0.12124354668400253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42708433500459958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18939783493172263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7240840152724366,
                                   0,
                                   -0.78426920587054605,
                                   -0.59966756837087465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52623322397520511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34162495436674112,
                                   0,
                                   0.34887178042329348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014381528011667397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062262885458752665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40017554414850176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44167054153307533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35406586494124564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82514242919463288,
                                   0,
                                   0,
                                   0.25579817216470846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13147711710609181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089258922169582297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36505290115337663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082333199503361459,
                                   0,
                                   0.17653311492361318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34652785460979341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57927475891829583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88178436310949992,
                                   0,
                                   0.17947294019679458,
                                   0.28340428468719686,
                                   0,
                                   0,
                                   0.2585238199306733,
                                   0,
                                   0,
                                   -0.8491532843585311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24196207272089754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36313577297829547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27483868437840708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14998283784527366,
                                   0,
                                   -0.2899702910199532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15272824930328163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069065827794267953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39174554461808248,
                                   0,
                                   0.59108633567506219,
                                   -0.62007437319898062,
                                   0.2265837555411922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079672746169723557,
                                   0,
                                   -0.14647002316747687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44444183892457773,
                                   0.52118580868722342,
                                   0,
                                   0.70007521727816924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58164854146528255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21924936135932141,
                                   0,
                                   0.027828936719262995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30441054636656895,
                                   0,
                                   0,
                                   -0.36113247080454203,
                                   -0.32634065682006902,
                                   0.11571987747252441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17054000140893893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087123482372016836,
                                   0,
                                   0,
                                   0.39451287546478353,
                                   0,
                                   0,
                                   0,
                                   -0.024342643115018534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22715003140441725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32198035635341526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66710417622521567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32004695221893087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36530809658671637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26610097188755211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21766044865374809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25916506487998126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20184399432884798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48327411992587799,
                                   0,
                                   0,
                                   0,
                                   -0.60119896871411083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094670435865311431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47699484344230403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44746101139775318,
                                   0,
                                   0,
                                   0,
                                   0.025980536597055612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5149908207752224,
                                   0,
                                   0,
                                   0,
                                   0.65119618473579144,
                                   0,
                                   0,
                                   -0.77405193072006495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067172468717516282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10457140491763889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2854318790986457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59965964369599023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56704128363468431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072833503878512826,
                                   0,
                                   0,
                                   -0.41184352430370097,
                                   0,
                                   0,
                                   0,
                                   0.18680092830513317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60100510058440548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15639675488399268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24993791977060609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53021385027233581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24682552290968068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010063366704093945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38623414952986129,
                                   -0.53027480753355016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12099527401733899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65858842998007627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11189245340869421,
                                   0,
                                   0.024558304376425311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29082515620591531,
                                   0,
                                   0,
                                   0.63564314071863171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58205682790391655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19560503652345484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13217587037083658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10838007745787406,
                                   0,
                                   0,
                                   -0.24739908776151098,
                                   0,
                                   0,
                                   0,
                                   -0.16865101523515491,
                                   0,
                                   0,
                                   -0.034222936299244403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52180183227291077,
                                   -0.20931440853416458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22817557408609709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17582304463723836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38117382455353432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20218493415789959,
                                   0,
                                   0,
                                   -0.47712638518113365,
                                   0,
                                   0,
                                   0.091438402293754051,
                                   0,
                                   0,
                                   0,
                                   0.12906494391136528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2439774697296811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56379522923327752,
                                   0,
                                   0,
                                   0,
                                   -0.63845824929597772,
                                   0,
                                   0,
                                   -0.76391106726264013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082172569180103086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088051890837880967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0067712042033959141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10795401092378018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52118150508359185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67026788456306408,
                                   0,
                                   0,
                                   -0.41295478480163444,
                                   0,
                                   0,
                                   0,
                                   -0.11344755594699622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44601644368224902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069900539624849822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36441972598259209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17429307995907303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018503859078270332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02060029120589231,
                                   0,
                                   0,
                                   -0.36149258147276903,
                                   0,
                                   0,
                                   0,
                                   -0.02930120481029188,
                                   0,
                                   0,
                                   -0.092229004084513344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040638993109666455,
                                   -0.18662294898248141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37935762546824314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015787608741662199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65327744283042044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13430189433793396,
                                   0,
                                   0,
                                   -0.38864056181198142,
                                   0,
                                   0,
                                   0.12161507709721461,
                                   0,
                                   0,
                                   0,
                                   -0.21629424970470629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14652491410686228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93108575293615758,
                                   0,
                                   0,
                                   0,
                                   0.71976527166715121,
                                   0,
                                   0,
                                   -0.05801645276995307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49080389217895465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85814092226208227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37180135051437346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097675313165763417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69087746992853249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12174297527159965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072371440462500047,
                                   0.75419914168743096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44231347953421718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18753291992261722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53418912357825277,
                                   0,
                                   0.57653838301781724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12433033964634668,
                                   0,
                                   0,
                                   0.46228733895793817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050965576224201906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38084352160099866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0019743477163099623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6881839575097296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76329891795441573,
                                   0.0041322541070269898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033403847848361347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17562040690207287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35257416469102165,
                                   0,
                                   -0.61895158842134212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4042729666319454,
                                   0,
                                   0,
                                   0.0035037506767018767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64187174748560127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74584861881940767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11810612510882053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11963763138117085,
                                   0,
                                   0,
                                   0.0077803898274334676,
                                   0,
                                   0,
                                   0,
                                   0.4538116669855532,
                                   0,
                                   0,
                                   -0.25345411956356684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4865411333210804,
                                   -0.058889220400996034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21488331721116533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37846644350794156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13430581624881482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1332008741704708,
                                   0,
                                   0,
                                   -0.10405040237851579,
                                   0,
                                   0,
                                   0.30632642527670073,
                                   0,
                                   0,
                                   0,
                                   -0.078648269106928514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37311116152720081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082450279366032497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98958999982767815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91842226504810554,
                                   0,
                                   0,
                                   0,
                                   0.54146860652601003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12361363230672084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0442176541111292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070042766169099921,
                                   0,
                                   0,
                                   0,
                                   -0.29355290148616814,
                                   0,
                                   0,
                                   0.62678983630012752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46959545352586668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72311696746365595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48715850116776332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56732106383988112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83618278708394134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026802874065707243,
                                   0,
                                   0,
                                   0.33630509921783874,
                                   0,
                                   0,
                                   0,
                                   -0.20536136861035548,
                                   0,
                                   0,
                                   0.51397274398741111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16919716034408425,
                                   0.10631413807911955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12282763895329679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3778408232417414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085821340069588678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22587902664363091,
                                   0,
                                   0,
                                   0.016064341038228194,
                                   0,
                                   0,
                                   0.23997216595595103,
                                   0,
                                   0,
                                   0,
                                   -0.50250398943645735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11539896578663333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34770945385441104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10707446690745122,
                                   0,
                                   0.7683931897591455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25554768645184689,
                                   -0.34883539053499069,
                                   0,
                                   -0.56643575262286283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82372454884124191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16593366989940017,
                                   0,
                                   0.62940099714282272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056907966227275383,
                                   0,
                                   0,
                                   0.52765586232166672,
                                   0.47734869237971911,
                                   -0.1115711776153733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12600595325636987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45280815623235116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071767737751294775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53137473252527456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46749973918737464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7624684810203588,
                                   0,
                                   0,
                                   0,
                                   -0.078473094634810614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028695372902672933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84870632899534049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67690941423468054,
                                   0,
                                   0,
                                   0,
                                   0.2205148646365514,
                                   0,
                                   0,
                                   0,
                                   -0.023227872182245313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66362732865190699,
                                   0,
                                   0.25373285321496231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35257214935917913,
                                   -0.36244665433591955,
                                   0,
                                   0.15079387016342571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24256332472070624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59541047250546941,
                                   0,
                                   -0.099408546449859969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22915862421797037,
                                   0,
                                   0,
                                   -0.55677943109910499,
                                   0.50880038507733372,
                                   -0.08384423530207552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46292911828285954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20657575615995238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50906662919662682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05841302170453358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35475961720698157,
                                   0,
                                   0,
                                   -0.16756974195409316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30120581172608374,
                                   0,
                                   -0.29642094636510802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30377695010928912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21652113534776549,
                                   0.22534861901886058,
                                   0,
                                   0,
                                   -0.16376008079985377,
                                   0,
                                   0,
                                   0,
                                   0.38141842953958571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18865895573154645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22344770400628156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79557783974703333,
                                   0,
                                   0,
                                   0.47736961692947666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16710230596074538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16040539602910078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44701959162275218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29274635127129511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041485760306622571,
                                   0,
                                   0,
                                   0,
                                   0.58014194035568756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0315255064862889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16579154537116111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19037550548452026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64076289166776867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41557540105833468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3486029499698079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13995230253942587,
                                   0,
                                   0,
                                   0,
                                   -0.75727368984111743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71031433847337677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13986092214161805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31915524499802916,
                                   0,
                                   0,
                                   0,
                                   0.27998745579199708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22746462960933189,
                                   0,
                                   0,
                                   0,
                                   -0.37148063286483646,
                                   0,
                                   0,
                                   0.22581460604026149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26168906670066105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090823122487921487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.312274284403995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075093312880015944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58631053344117268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93213044336249318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51981406178078526,
                                   0,
                                   0.018782265035146951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20073594504594261,
                                   -0.048930319428151958,
                                   0,
                                   -0.35903930295927911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22878449332912643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21248503130202995,
                                   0,
                                   -0.47858346865431073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28102920325608072,
                                   0,
                                   0,
                                   -0.4861196042650785,
                                   -0.0180141947426527,
                                   -0.21491121854249298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21253013844563967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4023328827802673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0043609946767450454,
                                   0,
                                   -0.38043879278547477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42013389662957379,
                                   0.37944713966213878,
                                   0,
                                   0.10340545912340511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082907806658138614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27987639789172636,
                                   0,
                                   0.50859481110665117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5528584903272955,
                                   0,
                                   0,
                                   0.18560988881472013,
                                   0.53556834823435417,
                                   -0.13737423321314701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80162875115824783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17003999110784812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37647733215676638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14707648550810079,
                                   0.55066684108803798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0067568984139957863,
                                   -0.23704595785152294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025054807609451613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29777708563304151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0055205689547658254,
                                   0,
                                   0,
                                   0,
                                   0.59909924280449089,
                                   0,
                                   0,
                                   -0.60376423907422949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26315516392310173,
                                   0,
                                   0.40043604917616316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36823347633018538,
                                   0.4970883916667454,
                                   0,
                                   -0.60799573945446406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0052729971795352788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29106781195049114,
                                   0,
                                   -0.087769488244188967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51511918283393121,
                                   0,
                                   0,
                                   -0.70966657940337785,
                                   -0.2278741665042836,
                                   0.23582871429036492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016219986267389519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29403348919799832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067694665287006711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25146989330121022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41582061836507972,
                                   0,
                                   0,
                                   0.0014775561243806773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17336483201928393,
                                   0,
                                   0.18567385359333813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18905334981940633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37452480945044242,
                                   0.33361703303944662,
                                   0,
                                   0,
                                   0.13119702266522054,
                                   0,
                                   0,
                                   0,
                                   -0.55114656136442053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32946187980466668,
                                   0,
                                   0,
                                   0.57517823943990409,
                                   0,
                                   0,
                                   0,
                                   -0.28554792920007599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15127644092562742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19045523237630638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19183446917639468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61172681579962662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094442177594330837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017965468889832859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12969733297786226,
                                   -0.28796416766930477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41741135353114772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21700766424959214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59757791401271498,
                                   0,
                                   -0.018307105134328115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62789231695138437,
                                   0,
                                   0,
                                   -0.64673257328494904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04949590228103716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30963325655155083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48378316666803944,
                                   0,
                                   0,
                                   0,
                                   -0.064652659994721251,
                                   0,
                                   0,
                                   0,
                                   -0.25291200731338936,
                                   0,
                                   0,
                                   0.55753761970819238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83308780776469094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32568513410014177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10955569573600876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75327945019025833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30831399880447208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042862045546965752,
                                   0,
                                   0,
                                   -0.15848249409112225,
                                   0,
                                   0,
                                   0,
                                   0.29927385929196648,
                                   0,
                                   0,
                                   -0.005884022214073692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36262484348198198,
                                   0.30699586629885234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29243681218994355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2717634610531231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049598801339411705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49745304746261526,
                                   0,
                                   0,
                                   0.10161584827296119,
                                   0,
                                   0,
                                   -0.30804747375998232,
                                   0,
                                   0,
                                   0,
                                   -0.17741709522850474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33423546297385365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38167586041227858,
                                   0,
                                   0,
                                   -0.27838917181586104,
                                   0,
                                   0,
                                   0,
                                   -0.49660333120695271,
                                   0,
                                   0,
                                   -0.0015132630490039068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37299448214260039,
                                   0.23386665009571431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27664373027315325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056515478898442939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057810873098913099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30357099148685668,
                                   0,
                                   0,
                                   -0.23038052010064627,
                                   0,
                                   0,
                                   -0.13018089707641778,
                                   0,
                                   0,
                                   0,
                                   -0.095480970063825901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28640057943793157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.301870270523527,
                                   0,
                                   0,
                                   -0.11502125378989014,
                                   0,
                                   0,
                                   0,
                                   -0.10763263619948552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53990946976422849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0038057146414253451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062169755900140129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32703243089578493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69406603299980851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45094282635797428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17632321282874264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56560664893714585,
                                   0,
                                   0,
                                   0,
                                   0.46494754455807458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75866372646001579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17985929781924401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21895700981806029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76843696427378538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14656664631243227,
                                   0,
                                   0,
                                   0.37276622143252525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016939404928628152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44815073211758993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50781706278548699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49367935416471792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46813543270178876,
                                   0.056467309118111542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16621103964013895,
                                   0.0015231789753658229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21790913878731272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27535921166544264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35292551680297812,
                                   0,
                                   0,
                                   0,
                                   0.023900779618096488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62264814859999951,
                                   0,
                                   0,
                                   0,
                                   0.25831251836881652,
                                   0,
                                   0,
                                   -0.096260607448171623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57876870774683975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96392007960237425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28650191608478753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4983484616526388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06243360408221621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34528593705474231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10173910997226503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64503533423901394,
                                   0,
                                   0,
                                   0,
                                   -0.39529360571095695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023215865948841258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90552736440155912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58799836570942565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52255379522575418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36004407277686012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96639735687113959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088631518357889155,
                                   0,
                                   0,
                                   0,
                                   0.075788500936222858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69716951653480708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0085156637221034948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27027239738541919,
                                   0,
                                   0,
                                   0,
                                   1.0580432019319059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068737826369783955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053785771142634636,
                                   -0.48897351731591066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24379483808092173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58093750563929936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52078262259437635,
                                   0,
                                   0.38468455853449746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53616557752181682,
                                   0,
                                   0,
                                   0.1320412611109574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18697398717340047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017950108001432291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41439352193489642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43432677164826888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12599047254818008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054324705230258293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22052498789835137,
                                   0,
                                   0,
                                   -0.069939251596426374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38322016182832813,
                                   0,
                                   -0.31739970814910462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23294146409740646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34839051912134056,
                                   0.27560078480456912,
                                   0,
                                   0,
                                   -0.14451845556076393,
                                   0,
                                   0,
                                   0,
                                   -0.46790318464397918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37954448939667723,
                                   0,
                                   0,
                                   -0.11854325610217009,
                                   0,
                                   0,
                                   0,
                                   0.33135908590397634,
                                   0,
                                   0,
                                   0.34756787482455848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059596688881343451,
                                   -0.098574311277692173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11031660712339296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31174164240350244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052056641047239754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3233661013025112,
                                   0,
                                   0,
                                   -0.019372536119187767,
                                   0,
                                   0,
                                   -0.60668734697827653,
                                   0,
                                   0,
                                   0,
                                   -0.11017905180037101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028463222787258297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26196913041697806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1053568912751444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43810004103697681,
                                   -0.19997327741940935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0072374445681992541,
                                   -0.10080419649324504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70085590730987712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20447494686430018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20434634196775439,
                                   0,
                                   0,
                                   0,
                                   0.32151336164227057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11852305314266401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14830233180161562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37542586895121738,
                                   0.33115242625878161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48734590593457294,
                                   0.51989033304157728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017216258256266312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33032775995852359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071813692502662591,
                                   0,
                                   0,
                                   0,
                                   -0.30164576304233987,
                                   0,
                                   0,
                                   -0.1128283839761248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52882119122783067,
                                   0,
                                   0.041964832703183304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14723665938006797,
                                   -0.42382367347578481,
                                   0,
                                   0.26464788847805654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32395377892463462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55036904965246791,
                                   0,
                                   -0.77101950509519412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40609293377526912,
                                   0,
                                   0,
                                   -0.086397809745795737,
                                   0.35492371479136853,
                                   0.59784915566595997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62188538162796658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13433356151491779,
                                   0,
                                   0,
                                   0.29776302572165336,
                                   0,
                                   0,
                                   0,
                                   0.62567654296581676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23086656703355893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15725459663801306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38824202391112833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24062565679490525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46385297516553081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18280292584159163,
                                   0,
                                   0,
                                   0.01876844687420931,
                                   0,
                                   0,
                                   0,
                                   0.16771428540618621,
                                   0,
                                   0,
                                   0.30890070539857045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17851429768686877,
                                   0.63698933916441391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15289495919226356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18906668894506057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058501469881251988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20168184265210931,
                                   0,
                                   0,
                                   -0.49392954580083609,
                                   0,
                                   0,
                                   0.071639412603533154,
                                   0,
                                   0,
                                   0,
                                   0.20230624825700197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10868692150853318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33518615702944249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25664173161939857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40206926304435864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17449342424770953,
                                   0,
                                   0,
                                   0.2517601418884563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0057938329663468607,
                                   0,
                                   -0.064165398414925037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43477996138840275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11567755058650064,
                                   0.36380772520584964,
                                   0,
                                   0,
                                   0.44376499992040652,
                                   0,
                                   0,
                                   0,
                                   0.17448590725389551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63561907252397731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24357593062228347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031330254455265327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63058727625857214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47441352038309514,
                                   0,
                                   0,
                                   0,
                                   -0.20090157339043063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67424477053133069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025495729434414305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24903795330440881,
                                   0,
                                   0,
                                   0,
                                   -0.25476265310121282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071820540251862686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47044109007364238,
                                   -0.36385709315741538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47222987564506336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46147267295439953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00046447454049060538,
                                   0,
                                   -0.31680453130645769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026676237035157035,
                                   0,
                                   0,
                                   -0.071704702220681774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52411616584642295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56232129678099907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44163978537920012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14340108353041384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1748229822030265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23827088963779111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48734237775576339,
                                   0,
                                   0,
                                   0.44916528622364066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17133310563630888,
                                   0,
                                   0.17450676850771585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11440520253921245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32983926114980172,
                                   -0.29018412425818479,
                                   0,
                                   0,
                                   -0.41904961658532119,
                                   0,
                                   0,
                                   0,
                                   0.10652909811166321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070601079850521026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04317456332661368,
                                   0.058381650027816895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65965877602395262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056679289052420603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089124568433608595,
                                   0,
                                   0.65989788937514471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49464872922471104,
                                   0,
                                   0,
                                   -0.0029319673920923488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14132113245813657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56576198405248712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24642123018506823,
                                   0,
                                   0,
                                   -0.73352709740222288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12748487870136976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50123362321831388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59758960042679099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059819126123884209,
                                   0,
                                   0,
                                   0,
                                   0.29062837167155431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1716855114509622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44286004299330139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48316150044443323,
                                   0,
                                   0,
                                   0,
                                   0.027387267572881902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33779585935220691,
                                   0,
                                   0,
                                   -0.1229096236258064,
                                   0,
                                   0,
                                   0,
                                   0.098615251893379538,
                                   0,
                                   0,
                                   -0.20220145767613051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2932363566790212,
                                   0.38122630121272838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40974235917010804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38157345172884383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027308306941592812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18624243595388165,
                                   0,
                                   0,
                                   0.21131299780948345,
                                   0,
                                   0,
                                   0.18622895930703365,
                                   0,
                                   0,
                                   0,
                                   0.36527368778442776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16485559426828916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71137203268187021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37346087420488833,
                                   0,
                                   0.13950997894472947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37941929525270773,
                                   0.093489707466929542,
                                   0,
                                   -0.02555663627515934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32459240297500441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13812462246566093,
                                   0,
                                   -0.075745934086716898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41625385031450601,
                                   0,
                                   0,
                                   0.47293125704894118,
                                   -0.085694146857655223,
                                   1.0368273902039742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1303534139681447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58820049145782805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02488325265320207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33641045121517044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063623481981747498,
                                   0,
                                   0,
                                   -0.25736107380600615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1762288977451727,
                                   0,
                                   -0.2188622107828776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034729403997518282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060860168119676872,
                                   0.048483818282990108,
                                   0,
                                   0,
                                   -0.61113937061174051,
                                   0,
                                   0,
                                   0,
                                   -0.10117781331631368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42108946213201659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43870707038445256,
                                   0,
                                   0.43856186824048726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68283595695547805,
                                   0.30795876108437076,
                                   0,
                                   -0.18797022374315095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19268073183682868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087959102555922708,
                                   0,
                                   0.05038716034458933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77388597196758191,
                                   0,
                                   0,
                                   -0.77481894507501547,
                                   0.2505433964325946,
                                   0.48642094342998526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25080610840779977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13481981179239505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018101931646089316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26416367454661055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054347243807534515,
                                   0,
                                   0,
                                   0.17863667651934359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27943991967882242,
                                   0,
                                   -0.27848366356970899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59375256413773625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16106247237573157,
                                   0.42561866895663403,
                                   0,
                                   0,
                                   0.00047319867662498627,
                                   0,
                                   0,
                                   0,
                                   0.4019630381850946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1639928547417254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0732925871622609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44417118907788555,
                                   0,
                                   0,
                                   0,
                                   0.86357292027411203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061110463232127502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16579928959037635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33978520306015764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034922813140720307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063843773688676192,
                                   0.12339830541004126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43590301251333213,
                                   -0.076626571957347789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3150924814915545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72685781778816416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16045647441051303,
                                   0,
                                   0,
                                   0,
                                   0.12160730441122093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037743972527519043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44159108208395914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09154271597472155,
                                   0.56074009746326436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49287991515334573,
                                   0.14740144734904481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25605510807026655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042945330616218011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36174831519846468,
                                   0,
                                   0,
                                   0,
                                   -0.13354782749601504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11727378518194692,
                                   0,
                                   0,
                                   -0.41073967768584929,
                                   0,
                                   0,
                                   0,
                                   -0.030295612794138449,
                                   0,
                                   0,
                                   -0.05264424012403434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17018725818114797,
                                   -0.073089337345921837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52172307598168632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20444801530286591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58807037912512172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069480340813813032,
                                   0,
                                   0,
                                   0.13558542821817579,
                                   0,
                                   0,
                                   -0.068389306860295485,
                                   0,
                                   0,
                                   0,
                                   -0.27805312926987907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12050927913718709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030296720663204324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28362045327923635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060469211817038168,
                                   0,
                                   0,
                                   0.25952991237424067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61640378909638061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68386812690138465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73478934754499037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083949140479754936,
                                   -0.19734862181803783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39913323573685977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28316443223018595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08490447509659961,
                                   0,
                                   0.19558233152526913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1028459860104633,
                                   0,
                                   0,
                                   0.53790864279656214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71868667430823485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14658939288465991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72479985452091056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30996181194434191,
                                   0,
                                   0,
                                   0.35393268857813703,
                                   0,
                                   0,
                                   0,
                                   0.12241890998756401,
                                   0,
                                   0,
                                   -0.25503211332751935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036427892722637842,
                                   -0.12937322009946112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17109850144738792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19592573106847017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16955497958819071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3924774241589204,
                                   0,
                                   0,
                                   -0.43159939534430469,
                                   0,
                                   0,
                                   -0.39903148926938342,
                                   0,
                                   0,
                                   0,
                                   0.051852104764111645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28621900734517236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77851645342163334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0060972721454179493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031936009362112022,
                                   0,
                                   0,
                                   0.51351112482783723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35016631897157702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080900680257674551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0087148293711192121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63829887023702558,
                                   0.27404454121286126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38435341467224143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35565982858074979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53604509343699647,
                                   0,
                                   -0.51197057903950649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065873214674350589,
                                   0,
                                   0,
                                   0.16710601872161851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26576951051465986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58425987581794181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44957488831290005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44444934584244061,
                                   0,
                                   0,
                                   -0.37127469965311055,
                                   0,
                                   0,
                                   0,
                                   0.1855585942022033,
                                   0,
                                   0,
                                   -0.13922153221386868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12515737900223167,
                                   0.24487894086513204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25350976973155914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28683767649911063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022251569422765193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23467491637207219,
                                   0,
                                   0,
                                   0.067586406469648197,
                                   0,
                                   0,
                                   0.076911581823506145,
                                   0,
                                   0,
                                   0,
                                   -0.36556353417082643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43467766018880033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37892610337074228,
                                   0,
                                   0,
                                   -0.26723765470211264,
                                   0,
                                   0,
                                   0,
                                   -0.041610137326316875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069732510778365439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83040640828070567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042603571612451034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17087169570836511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24045376662418549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04429042930410973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21891980381252188,
                                   0,
                                   -0.83545959780037227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68112404247093217,
                                   0.58103937144033035,
                                   0,
                                   -0.035859611830042153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90583369945120495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12465559814763184,
                                   0,
                                   0.17751676904420521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55894779594549759,
                                   0,
                                   0,
                                   -0.33537022179063719,
                                   0.29034003754563237,
                                   0.21441761938795473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055689623780309033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54979401889827351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15640372669051861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48572527176205954,
                                   -0.038147970774250611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28478208212480932,
                                   -0.46591305060261978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076430716442709101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053926860074990542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18214242810773501,
                                   0,
                                   0,
                                   0,
                                   -0.30948129825052323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47377315579923185,
                                   0,
                                   0,
                                   -0.28804733050207498,
                                   0,
                                   0,
                                   0,
                                   -0.2257516320255831,
                                   0,
                                   0,
                                   0.27210533397064562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15018455898847155,
                                   -0.055010077614746744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068538726401597208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36684470181348255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085791468950107225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18564094349566357,
                                   0,
                                   0,
                                   0.20882624398775843,
                                   0,
                                   0,
                                   -0.20003351450262305,
                                   0,
                                   0,
                                   0,
                                   0.44465690725889517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2820358294829462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23308103599970775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1760814794175154,
                                   0,
                                   0.54633781449906904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61006919576854557,
                                   -0.082332000734702301,
                                   0,
                                   0.34853535054291684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010116637821933436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14920795583859991,
                                   0,
                                   0.33203397637241827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28955529189481061,
                                   0,
                                   0,
                                   -0.27435459744950808,
                                   -0.27451810261912413,
                                   -0.27608273866750288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56166595998357349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095420942951200405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031845369839779911,
                                   0,
                                   0.23880554674292684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0076220313675443591,
                                   0.63771208951985825,
                                   0,
                                   -0.39066138808664275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10754087198030345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94320130950682668,
                                   0,
                                   0.058777958275088686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098800644659408313,
                                   0,
                                   0,
                                   0.043221977560508641,
                                   -0.14261108137417641,
                                   -0.36749096663630987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25565589291939073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20186929425286548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092217455934526488,
                                   0,
                                   -0.14503813776242425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20939832655076648,
                                   -0.24411100628470075,
                                   0,
                                   -0.31435456717128185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035409344970766095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34996233122408327,
                                   0,
                                   0.63871427270038861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042356189339932876,
                                   0,
                                   0,
                                   -0.56529081847478657,
                                   -0.52522310308221054,
                                   0.35090413950499472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31043188820011719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35948398480727523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24711388227114489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29039258708511168,
                                   -0.36772922431056543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011706180366925473,
                                   0.24279317786356189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27884499650723843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15925975258416897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46173933100106385,
                                   0,
                                   0,
                                   0,
                                   0.46340736320267362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10671026585864327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35665880500745289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48387392738862445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50731085327845016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54583116122124875,
                                   0,
                                   0,
                                   0,
                                   0.72224005602393049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53829161888597221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34738662993713781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24597368289778554,
                                   0,
                                   0,
                                   0,
                                   -0.21773137901186651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42017193435558942,
                                   0,
                                   0,
                                   0.008612128939132685,
                                   0,
                                   0,
                                   0,
                                   -0.68214188902932515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12536455765490329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34116144222867328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40803044259071397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13344434234897251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2041082641179448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32120179639514945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41946603532301791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42238126151315597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3069748664787203,
                                   0,
                                   0,
                                   0.15056893605378288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00092323612123931809,
                                   0,
                                   -0.22782379589407592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28587928830330539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50198703930169997,
                                   -0.16659794465171376,
                                   0,
                                   0,
                                   -0.095790391901358768,
                                   0,
                                   0,
                                   0,
                                   0.054899764848971543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19203040961165604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78834081399448253,
                                   -0.56954088923910229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5876886377254017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091247432217558877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09568611948340304,
                                   0,
                                   0.30482951146578902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34106832529148184,
                                   0,
                                   0,
                                   -0.31748740035002776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21786192781712788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37983188625306075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081158585322162177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53407416061400692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33110133143299636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39597131335605379,
                                   0,
                                   0,
                                   -0.50503012814446568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35721992680242493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25628482563053923,
                                   0,
                                   0,
                                   0,
                                   0.4115087159567638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34274931947502707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97353973616346323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41170893524902252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24438390237089855,
                                   0,
                                   0,
                                   0,
                                   0.3992881727721157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3512630009560489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24302040438402389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3278756196836663,
                                   0,
                                   0,
                                   0,
                                   0.63344030770739945,
                                   0,
                                   0,
                                   0,
                                   0.25707837377281867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63254844781856068,
                                   0,
                                   -0.18959645267104919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25826980122200011,
                                   -0.054919758387880248,
                                   0,
                                   -0.22281380395301242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47110992431377496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37852100691976953,
                                   0,
                                   -0.43859285851176211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18747947016925823,
                                   0,
                                   0,
                                   0.11202757235805909,
                                   -0.12215366611649542,
                                   -0.4011524049285361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60865514757017047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11791118069898979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06027179383509295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094939281480789076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46281355021769249,
                                   0,
                                   0,
                                   -0.63390674008355508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018397407041388203,
                                   0,
                                   -0.033157815813445242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22033805542908746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34031377589666723,
                                   -0.30284966884680647,
                                   0,
                                   0,
                                   0.30369255083794888,
                                   0,
                                   0,
                                   0,
                                   0.087574781482750705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10766905681034979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41418715635367698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010681289083861248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22583688179341091,
                                   0,
                                   0,
                                   -0.20880661120829547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70538327802838752,
                                   0,
                                   -0.053593505092165733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12242932321611483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2341729704737896,
                                   0.34133116864822138,
                                   0,
                                   0,
                                   -0.18481471087778942,
                                   0,
                                   0,
                                   0,
                                   -0.034822258353723434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75511780944414897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33548823241301751,
                                   0.023970367868393665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2268929315208412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36347109997635818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050501318375531082,
                                   0,
                                   0.36757109652204034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51253545961562597,
                                   0,
                                   0,
                                   -0.008963950637941448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13699766195139865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027047774284129716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63653513502093839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043376849681246617,
                                   0,
                                   0,
                                   -0.21916839859970705,
                                   0,
                                   0,
                                   0,
                                   0.37074026495336898,
                                   0,
                                   0,
                                   0.49349110622434877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013511461775269342,
                                   -0.33432252943266749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082712387418431177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17384751706912455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086142762055213012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32307459839796321,
                                   0,
                                   0,
                                   -0.070645374867136318,
                                   0,
                                   0,
                                   0.30963037242516794,
                                   0,
                                   0,
                                   0,
                                   0.19854226794382238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40988400092536703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013444306913728919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4783960211352995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38584659160686813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026633485806067274,
                                   0,
                                   0,
                                   0.36643299469644486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28406586652145188,
                                   0,
                                   -0.31017513961663107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29224361424295808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30748992420516619,
                                   -0.14151259783979278,
                                   0,
                                   0,
                                   0.11551324375853922,
                                   0,
                                   0,
                                   0,
                                   -0.31123766000798708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99037830863896981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79257440257127865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27727474279686587,
                                   0,
                                   0,
                                   0,
                                   0.424355437627218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52896961413123278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1162924486914766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032618456845715418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81491102102342117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026854936841090415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30392451101045492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31853222399926595,
                                   0,
                                   0,
                                   0,
                                   0.32258112258624155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30911452654447391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20565848093486472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20754512086292801,
                                   0,
                                   0,
                                   0,
                                   -0.60717495767260909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28362299467745022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49039606644061307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18910015832282934,
                                   0.20744716106510974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44142871029359193,
                                   -0.54011016342474527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30472710780864665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1002869827036557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096730882479833302,
                                   0,
                                   0,
                                   0,
                                   -0.03775251956302382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23730607551774929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2074171955314271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43886377254545117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13233989483030115,
                                   0,
                                   0,
                                   0.03696202755160901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12341719684135603,
                                   0,
                                   -0.68176948844355401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17656491807094685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14987331311196841,
                                   -0.32540971801065249,
                                   0,
                                   0,
                                   0.20039493801898886,
                                   0,
                                   0,
                                   0,
                                   -0.097232955001208821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40169230366700925,
                                   0,
                                   0,
                                   0,
                                   -0.0075908234433504883,
                                   0,
                                   0,
                                   -0.47069493951192093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71997722003082343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33070988699124726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2685037027525326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55363801429159087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73231801431013466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63503964318395101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37135836392632843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17205258943454654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21320888951153011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56110113948658336,
                                   0,
                                   0,
                                   0,
                                   -0.20931671463815771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58447736384930993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1332736970893362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35224374385777807,
                                   0,
                                   0,
                                   0,
                                   0.42287248316151405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04135092998297768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24333900698138944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24056108288426198,
                                   -0.18589044791688963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16040760481082456,
                                   -0.26080288454534661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3450944428721604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34071078101004776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64510030827500708,
                                   0,
                                   0,
                                   0,
                                   -0.31870703199508482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15564272455569103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41166725105280366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42907389086205316,
                                   0,
                                   0,
                                   -0.21693020056915402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58447730293319111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48324795221602102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61051095351241957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43869529037255367,
                                   0.24707567424426258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21542941182851671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4522349813802039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3282744972358938,
                                   0,
                                   0.31103558419219568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35423194171008848,
                                   0,
                                   0,
                                   -0.22463767938119866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088065291538445861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1485573086888583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14785783677829223,
                                   -0.34793773787914017,
                                   0.040987800395966188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14277413402074302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99172987378530575,
                                   0,
                                   0,
                                   -0.19600054371763892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16664746455921514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14541760753247066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46477264885981007,
                                   0,
                                   -0.44929099583992366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46299019995217056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034612540352697244,
                                   -0.094529835921534841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94616727474281626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13958562394846097,
                                   0,
                                   0,
                                   -0.011412814787620806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1313660426416228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51426034473647697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086226335948736341,
                                   0,
                                   -0.13579746617889202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21686140864005296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14321747900181964,
                                   0,
                                   0,
                                   0,
                                   0.030213964583774403,
                                   0,
                                   -0.21531309893255707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58027817813322502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12474400643056681,
                                   -0.079576290593066201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16514599923839923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43173049095551241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16431790604750698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53006898786664935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049500675788798756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11017768607685596,
                                   0,
                                   0.064085895291953965,
                                   0,
                                   0,
                                   0.18238847792258209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25005088342394599,
                                   -0.45980536549340134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16762396953763306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057960880011294083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031492480624244396,
                                   0,
                                   0,
                                   -0.18261942196440145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30274241990790218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03375735235929006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43791702114166797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53431513068710634,
                                   0,
                                   0,
                                   -0.15838655995770143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25517030168234395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61187653742260428,
                                   0.20741702625097211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28827999978674346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14567382482369307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41645794987245327,
                                   0,
                                   0,
                                   -0.026862067101189574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25446453082345893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14591905572296374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12175139971095625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26410959203344297,
                                   0,
                                   0,
                                   0.32814046151281051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16063079813170805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49290300267427051,
                                   0,
                                   0,
                                   0,
                                   0.1661958289122579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20179911195044559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21130650397988071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53484024923900919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17256641266580214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11709314949381686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25046099440636521,
                                   0,
                                   0.49344707494679546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091035520876878995,
                                   0,
                                   0,
                                   -0.32465345656680888,
                                   0,
                                   0,
                                   0,
                                   -0.2590713290608847,
                                   0,
                                   0.28657252629154328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28486754080152932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051201873108497865,
                                   0.1201577646505789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28141986046293527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16178068720489533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27454530326971699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12083996682189839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25356869520228736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33579401173124274,
                                   0,
                                   -0.022872402899247871,
                                   0,
                                   0,
                                   0.52366395015774425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047015554761838468,
                                   0,
                                   0,
                                   0.16014460447210008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22836768208631791,
                                   0.15152324642620096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52262800793316078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18687642065521362,
                                   0,
                                   0,
                                   0,
                                   -0.23322463795454501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74721472277739909,
                                   0.37621234705040096,
                                   0,
                                   -0.80726432922369717,
                                   0,
                                   0,
                                   0.079113638831469588,
                                   0,
                                   0,
                                   0.19943821854410076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32877628869618925,
                                   0,
                                   0,
                                   0,
                                   0.16881757351152871,
                                   0,
                                   -0.17126833175404171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12089041101127412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0065119765770309777,
                                   -0.26090749205912994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19002183641337583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21085629822564245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.150092455494866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.008538448733705406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28085873466538969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29782482999818582,
                                   0,
                                   -0.52495087731324475,
                                   0,
                                   0,
                                   0.45279168694356392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20856185039465991,
                                   0,
                                   0,
                                   0,
                                   0.034997895725519285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12135540802634756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53262622009263172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26780971430424177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063075091582006582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4440668480795571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3032667822767679,
                                   0,
                                   -0.32257364010489836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43351921079370725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61299225010779079,
                                   0,
                                   0,
                                   0.045917170076797964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0084056491172530556,
                                   -0.63087018067936795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098598681677805611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73942326117990231,
                                   0,
                                   0,
                                   0,
                                   0.36164156869331254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35207112666661378,
                                   -0.81779001072414936,
                                   0,
                                   -0.35683575558992447,
                                   0,
                                   0,
                                   0.17174368478136776,
                                   0,
                                   0,
                                   -0.0039506824222769188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45123750281647501,
                                   0.77616099988060649,
                                   0,
                                   0,
                                   -0.055452127120086125,
                                   0,
                                   0,
                                   0,
                                   0.004529584560256511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062581040713536179,
                                   -0.36514725656776115,
                                   0,
                                   0,
                                   0.12311876350533138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055696959398823034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077296947902657842,
                                   -0.44037059149032021,
                                   0,
                                   0,
                                   0,
                                   -0.4175044819371217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62533800114141858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10885239506964803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15886331781587412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44498301781321714,
                                   -0.17974070887015911,
                                   0,
                                   0,
                                   -0.26761824463640033,
                                   0,
                                   0,
                                   0,
                                   -0.012608110580671544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070039591991889041,
                                   0.17196434083850332,
                                   0,
                                   0,
                                   -0.11647177186490194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30225586657770181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93088205557367643,
                                   -0.11454104000975637,
                                   0,
                                   0,
                                   0,
                                   0.15563511444596945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27917312680021922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6859782605596364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25834167941176855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50613721084176455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039809867579659805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35140848455540596,
                                   -0.63919927413043964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29415748751581072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35163622639965131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033135521147185931,
                                   -0.39252140750827841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38152291117879622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12501065870530931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25450957773482935,
                                   0,
                                   0,
                                   0.08487248342049003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047766934889333264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025027851703219004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63972155225597793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13611569299166698,
                                   0,
                                   0,
                                   -0.36371985767426018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22066211080617784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32351449498032347,
                                   -0.48638553774518134,
                                   0,
                                   0,
                                   -0.18944923252663748,
                                   0,
                                   0,
                                   0,
                                   0.49764418966368257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13261334123016127,
                                   -0.4357479469554264,
                                   0,
                                   0,
                                   0.28203784806029697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49986718043171913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20194881916923885,
                                   0.25420167644411157,
                                   0,
                                   0,
                                   0,
                                   -0.051624903489164278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049625196315182821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25649509885524735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1922087781749843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08171661661064529,
                                   0.26357760007677866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01560431607897271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14587600691742747,
                                   0,
                                   0,
                                   -1.323654567493437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18333736404147655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27854125520192802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46814062300263792,
                                   0,
                                   0.59919325603407525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11574288674234913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57481520980206935,
                                   0,
                                   0,
                                   -0.2110808783732171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23329952851111724,
                                   0.48346470134651254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37952879658697425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53784149111782298,
                                   0,
                                   0,
                                   0,
                                   -0.21518845083230276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090642837462579048,
                                   -0.095686851298758716,
                                   0,
                                   -0.35054917321408874,
                                   0,
                                   0,
                                   0.49201942326864712,
                                   0,
                                   0,
                                   1.0572765429032136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.254416833118561,
                                   0,
                                   0,
                                   0.53356010529017261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43848862947937756,
                                   0.26969115022077195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24298574526147518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16295046619170983,
                                   0,
                                   0,
                                   0,
                                   0.7709554583746796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51155739790177102,
                                   -0.23816834121928343,
                                   0,
                                   -0.52488089791412795,
                                   0,
                                   0,
                                   0.32034751740088518,
                                   0,
                                   0,
                                   0.54650100154305314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14010377268207391,
                                   0.23557505309195423,
                                   0,
                                   0,
                                   -0.24391936986072335,
                                   0,
                                   0,
                                   0,
                                   -0.11147271478055246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85325060911720629,
                                   0.1338552720026584,
                                   0,
                                   0,
                                   -0.13876389064508093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023104671777937888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11178382286469692,
                                   0.49347700124576616,
                                   0,
                                   0,
                                   0,
                                   -0.61669006925544401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2575542063937345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11129657929221938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39107680358259417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033207069586502991,
                                   0,
                                   0,
                                   0,
                                   0.072760324990609554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073095018983591054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39845052845291817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14025628439411753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23709450416545846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68570259849133763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15308978409272347,
                                   0,
                                   -0.27244371531279676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43100090186661355,
                                   0,
                                   0,
                                   0,
                                   0.12735226652552029,
                                   0.042115742934104722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38721756429555942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10773291157291612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04650050648254983,
                                   0,
                                   0,
                                   -0.30092466688403696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23912392196976162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31696234726591321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50912873314747009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16892067458504806,
                                   0,
                                   0,
                                   0.048247268483508243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52917525457385328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48614288075370637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77752791596998272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33219083602784982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55347830688641941,
                                   -0.50320700656551243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083139426220348409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17846029952049461,
                                   0,
                                   0,
                                   0.14187056716013893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35552525202231511,
                                   0.47149585260575555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4066021935676124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41181914542606296,
                                   0,
                                   0,
                                   0,
                                   -0.09332965595620929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24632299965330887,
                                   -0.33479547824513045,
                                   0,
                                   0.09045664447681509,
                                   0,
                                   0,
                                   -0.78899324095150636,
                                   0,
                                   0,
                                   -0.23716732288182973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3521397641169528,
                                   0.42157936481541719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14557741868248664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63705548212227825,
                                   0,
                                   0,
                                   -0.083860389596031232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10582218182657445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22422532653449009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61647083959837534,
                                   0,
                                   0.73112696640531971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50767385236770235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082893753737572962,
                                   0,
                                   0,
                                   0,
                                   0.27272154943352683,
                                   0,
                                   0.026952241483064375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29353511188184178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18423606872983214,
                                   0.064413154714999699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21065160744632552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083257153499737904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4796519940972544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36221457046782218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26306764543508426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55591482751547361,
                                   0,
                                   0.037881620717756886,
                                   0,
                                   0,
                                   -0.038963197664985808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32387860960055043,
                                   0,
                                   0.57174570987029172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40072759927924873,
                                   0,
                                   0,
                                   -0.73659558907426903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34344696891291038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11180298707236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88005888326782933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045459475658630309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38610549134899619,
                                   0.73683168576378821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43421093637326535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55745904965325455,
                                   0,
                                   0,
                                   0.65259537625346498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035864458988036224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12663785493662219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3627872638093943,
                                   0,
                                   0.31537933532597995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029535807238404627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079017413034316933,
                                   0,
                                   0.15895685474789301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2276669110655289,
                                   0,
                                   0,
                                   0.97746085343475109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23703136516778123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10193931471698529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5363795493236273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30965382857968737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28191952898729861,
                                   0,
                                   0,
                                   0.24354842220044642,
                                   0,
                                   -0.14912694351710601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51841105621900585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16609021004982855,
                                   0,
                                   -0.18215323289263549,
                                   0.68620753039650673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19639283038309979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22103285969486927,
                                   -0.13009867606521999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61251425895455658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050416968308540915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21396783598514163,
                                   0,
                                   0,
                                   -0.031637325194094838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09479476216284996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09188647604275102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1408918235998439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32011352836783152,
                                   0,
                                   0,
                                   0.53765093736092684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28442782434910668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22096243083379449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14432457395976539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6356475777886017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099028989090090419,
                                   0.66289368901154799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99417528511921138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059853728906341691,
                                   0,
                                   0,
                                   0.22562748259560139,
                                   0,
                                   -0.00046175881619281434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60517020221809759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32569141800020329,
                                   0,
                                   -0.36186555071572268,
                                   0.060164986314498757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58192540864588138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046953856490267967,
                                   0.17403641717341856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0030131730186788329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69990814310011529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25267669894635097,
                                   0,
                                   0,
                                   -0.12062754805912521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43219613266457368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38017053093226422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12673635569731967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14914434908249158,
                                   0,
                                   0,
                                   0.1236207904805654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11965902845253953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05101977883894647,
                                   0,
                                   0,
                                   -0.58393994706566621,
                                   0,
                                   -0.10019697750018977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3878779034869439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11599970433344668,
                                   0,
                                   -0.43193642527643367,
                                   -0.30255387984673976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45206035103537423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65766053498540511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35066210933467268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23140645990556863,
                                   -0.26616621481643005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31642912363804954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46903935007373576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18904706508456459,
                                   0,
                                   0,
                                   0,
                                   0.12558056024330444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74873081871617941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19201244671088902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24869329971812038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34925290465527054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1805728034400742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18895379553422256,
                                   0,
                                   -0.10526637170523942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29632259371970804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80543804642961769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89151276423056247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63672427842663659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42402914938915398,
                                   0.48474554467200526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31540953339320477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31789810036283961,
                                   0,
                                   0,
                                   0,
                                   0.55027438648898941,
                                   0,
                                   0.19548841102309472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12880805366265954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1648698059997834,
                                   0.39288148794123146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39658664179957731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0022008701753063256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15624729508335775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24381441082958138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087233363392288266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18529852398992144,
                                   0,
                                   0.2658046437909839,
                                   0,
                                   0,
                                   -0.077794238571798804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36873964021235528,
                                   0,
                                   0,
                                   0,
                                   -0.22380918399281452,
                                   0,
                                   0.16997111944844812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06814790923448491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26437488697402406,
                                   -0.039603004542148004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29304701004886041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39562767950175526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16229291606552215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53964056681846695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1955257393301586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072960940796656215,
                                   0,
                                   0.20541356432758873,
                                   0,
                                   0,
                                   0.25148884708003366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.423954312773757,
                                   0.53302142708538336,
                                   0,
                                   0,
                                   -0.58870185978418332,
                                   0,
                                   0,
                                   0,
                                   -0.093569538081341844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76913419252698845,
                                   0.0095275001450483947,
                                   0,
                                   0,
                                   0.30300665627337364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093702635471187276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11827470996327416,
                                   -0.57412360951539709,
                                   0,
                                   0,
                                   0,
                                   0.061596237291030385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34032896961168302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34782085593086187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31949014599425357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3866775085124905,
                                   -0.052863473151341572,
                                   0,
                                   0,
                                   0.386291385223274,
                                   0,
                                   0,
                                   0,
                                   -0.049654538567852291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036344052476189076,
                                   -0.56135449481814836,
                                   0,
                                   0,
                                   0.37099606020420578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25920318924136443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.665097052671486,
                                   0.27360370038883264,
                                   0,
                                   0,
                                   0,
                                   -0.40963554518764772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72350419048084524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17824647249730957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14390914601938046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69346783623960895,
                                   0,
                                   0,
                                   -0.14682052038743323,
                                   0,
                                   0.1696377048659376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12370077330969029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074075714479586705,
                                   0,
                                   0.49089742731211478,
                                   0.29324642817572627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34785959726530807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31447130709025944,
                                   0,
                                   0,
                                   0,
                                   0.28294469090219349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27504425593647591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097932411451241125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62070227025299729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17366718847119833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28124487607396009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41399347809357795,
                                   0,
                                   0.26002982050946455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04768239241192658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13631390946964689,
                                   0.60566202770999733,
                                   0,
                                   0,
                                   0.42395304933138417,
                                   0,
                                   0,
                                   0,
                                   0.17511758787624968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2247733051251381,
                                   0.23659948472908265,
                                   0,
                                   0,
                                   0.045348115986520124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021645635714220936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082695274195808979,
                                   0.52030833968040791,
                                   0,
                                   0,
                                   0,
                                   0.68641683317882807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3710660244124635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88225427256926792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30377250761687374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3190223809447687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27165594500535872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40342993554179379,
                                   0.43177577775287185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01051746303462317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68929755245868929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37894503588357636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32521545974898236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70333154542018994,
                                   0.16174397740897042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31387108271211567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36233152077255099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20258523213797619,
                                   0,
                                   0,
                                   -0.64871714890866139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27851779463724707,
                                   0.43495418262493907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18067426087968419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68272479445833623,
                                   0,
                                   0,
                                   0,
                                   0.0070373445040807503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013444704046126795,
                                   -0.85688349884912074,
                                   0,
                                   0.15479110753385128,
                                   0,
                                   0,
                                   0.22899722807666889,
                                   0,
                                   0,
                                   -0.29139541846029648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20238018887877807,
                                   0,
                                   0,
                                   0,
                                   0.11207064842698498,
                                   0,
                                   -0.41790612287459011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06102123542916231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2311129069458307,
                                   0.6939530437343896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24268280273840381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03648837744428416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099124503341777387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2639271854281488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12716942037993959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14064188886181644,
                                   0,
                                   -0.061137297146361978,
                                   0,
                                   0,
                                   0.23179681888882284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15231069071556574,
                                   0,
                                   0.50282375772213139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36517505491483893,
                                   0,
                                   0,
                                   -0.45868449953908508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69537191296680956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40243412302880888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83249204024489321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72136154636504535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26872845628425235,
                                   -0.21448588211473638,
                                   0,
                                   0,
                                   0.29451471582703481,
                                   0,
                                   0,
                                   0,
                                   -0.57132616331787867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5137751980087808,
                                   -0.03230492954112623,
                                   0,
                                   0,
                                   0.23890482311427647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52426777695999405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45150610440252398,
                                   -0.053359525788097134,
                                   0,
                                   0,
                                   0,
                                   -0.64528057617841017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11119966139466959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42781928927117335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39392066416306981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51461676815496282,
                                   0,
                                   0,
                                   -0.26655666954342699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072990264726914916,
                                   -0.81070038887720897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61176610589976266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061360478231297928,
                                   0,
                                   0,
                                   0,
                                   0.026000110690126838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63179331551698792,
                                   0.25786729722486607,
                                   0,
                                   -0.43712654399903317,
                                   0,
                                   0,
                                   0.41583081655917525,
                                   0,
                                   0,
                                   -0.25261956465488278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1914510780979055,
                                   0,
                                   0.19012953073550365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61076544962583035,
                                   0,
                                   0,
                                   0.48804906609206022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27603730663207549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60733274842356721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.282210184183808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034346163689695536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63534719407398843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11833195277890658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96208078420894871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64339618659464559,
                                   0.33417177562447548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23824685682719549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60848771146846148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52100559592857765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59097851975634252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55301501982838219,
                                   1.1441606256947781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11662088398987747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19226403347743831,
                                   0,
                                   0,
                                   0.16404436810137354,
                                   0,
                                   0.43356240650216427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087729492270495368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79313769149135382,
                                   0,
                                   0.016849759624542007,
                                   0.13215512483821099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30599815929932767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080033580286149653,
                                   0,
                                   0,
                                   0,
                                   0.082675509159460508,
                                   0,
                                   0.0082734807789100195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46873648554409014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35432532388385934,
                                   -0.12958838550246793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23334953999985386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43497622232110955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49665751088473392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23369417015721389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0071209221955085139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044210903526164858,
                                   0,
                                   0.25739257327088516,
                                   0,
                                   0,
                                   0.10697307913557746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61055318057856112,
                                   0,
                                   0,
                                   0.36281117843758848,
                                   0,
                                   0.09477944209250011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15423757460089824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16979248838197275,
                                   0,
                                   -0.58144599091178595,
                                   0.0015307284276757302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30969213395911888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081372526241920526,
                                   0,
                                   0,
                                   -0.50410333912745087,
                                   0,
                                   0.61123930221623934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17442414128329578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21330875750829295,
                                   0,
                                   -0.25232372211247328,
                                   0.37509881139055407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29215417974131253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23254055396247231,
                                   0,
                                   -0.55046537163955922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18272778169886517,
                                   0,
                                   0,
                                   -0.12988718355644693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6212381010306508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4848843403023621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30190352032500978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0891361218366045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12138504166233244,
                                   -0.69624059376766556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31657713309358143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49282004216384956,
                                   0,
                                   0,
                                   0.18188737147105052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031002991791854621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62734300571262336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42903147143623699,
                                   0,
                                   0.25022226402253639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81287468127405749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011703061135496712,
                                   0,
                                   0,
                                   0,
                                   0.20078092477525333,
                                   0,
                                   0.16246323898115334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12982191202891444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31886634182658846,
                                   0.16629141208241274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11748662188107087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37153112203639521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03023040912967619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039019399021662959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68196973240835179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2707737332539108,
                                   0,
                                   -0.3023584800605385,
                                   0,
                                   0,
                                   0.053635761917068724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31715710100571232,
                                   0,
                                   0,
                                   0,
                                   -0.22276649224809375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15967754309160556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51956311409930211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18685233951423358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47188365764913054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24229097031149016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16715436934905958,
                                   0,
                                   0.12077277121757993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44218115407601344,
                                   0,
                                   0,
                                   0,
                                   -0.057382346127411804,
                                   -0.23948023959075054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21441733036483454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44048348536853116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17972406923728232,
                                   0,
                                   0,
                                   0.09203110781481573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62695000042184867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041753029236072138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087790572136747791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23699884263075507,
                                   0,
                                   0,
                                   0.023988403928559443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44645808864847591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55459486534236979,
                                   0,
                                   -0.6640066629388951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58887472217931014,
                                   0,
                                   0,
                                   0.43709383190314111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80295826036423845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26569671780748894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2852450654310712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021740454955798447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093040785767654621,
                                   0.063224391750045697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30249626589571676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52259172854263714,
                                   0,
                                   0,
                                   -0.089287225002141507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52008042887875761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2363316931245047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11113913323917614,
                                   0,
                                   -0.61828091105855842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21362046702545981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24583017366268153,
                                   -0.0099704241351898041,
                                   0,
                                   0,
                                   0.74595985758842809,
                                   0,
                                   0,
                                   0,
                                   0.090285930492750424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42278062452381171,
                                   0.031021465948181517,
                                   0,
                                   0,
                                   -0.29299463356118371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23173131821642234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015380242436101366,
                                   -0.28569182251466829,
                                   0,
                                   0,
                                   0,
                                   -0.0034437467838039255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40225705471758971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060424384286157526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55482656697326282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.003371256237221,
                                   -0.26430770375182955,
                                   0,
                                   0,
                                   0.273024232605516,
                                   0,
                                   0,
                                   0,
                                   -0.0071185202820768512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043482569978154251,
                                   -0.086272398498267205,
                                   0,
                                   0,
                                   0.26775894883286688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15556281897529606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0015238782866674461,
                                   -0.34583148782839512,
                                   0,
                                   0,
                                   0,
                                   0.16961465364925432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68240756915898693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017192463360208868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37764240187477116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15180855058638373,
                                   -0.18061150973082871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11197840214234783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27456756242096164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092591417176072097,
                                   0,
                                   0,
                                   0.80976731259486368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15222240017868521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33400638692683643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095047555549726132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022271054289418481,
                                   0,
                                   0,
                                   0.021933784737169441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21764147662514347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16886845300893316,
                                   0,
                                   0,
                                   0,
                                   -0.17099849268492176,
                                   0,
                                   0.35675213030931091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29603233180996069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57173061939625058,
                                   0.10649320746527682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076362746840631074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.224078755919184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034190209937934021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096910919257318734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48379082713789495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017973054008823951,
                                   0,
                                   0.00029456251840266276,
                                   0,
                                   0,
                                   -0.2968822934815214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07521217298457783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23672031563350848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22966083719952476,
                                   -0.37570912732068573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84540760372391432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17231121922800532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55488328314738167,
                                   0.11618127159110772,
                                   0,
                                   0,
                                   -0.19940519492929457,
                                   0,
                                   0,
                                   0,
                                   -0.81951993542095836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10062074958548223,
                                   0.053386364805732625,
                                   0,
                                   0,
                                   0.40417477656659079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26810530417670558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056382860233265775,
                                   0.16659329898945949,
                                   0,
                                   0,
                                   0,
                                   0.31377667404998588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11451141452516736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25845362926246829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57057689941825129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0256151934082605,
                                   0.65765669534969584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35800812841347984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56579046256709498,
                                   0,
                                   0,
                                   0.180971107082951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39530887848522583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13613056643597338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58478381890717546,
                                   0,
                                   -0.073310999652763609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03829760102204903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27269437293445109,
                                   0,
                                   0.54395895624095036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53682212608761137,
                                   0,
                                   0,
                                   0.018494689063450566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44355535536136093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3589039515049821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.290786491853678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47502686323907162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39939156691519695,
                                   0.59419216780893114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046505409143599213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19075218886320383,
                                   0,
                                   0,
                                   -0.21069458392795759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17775762072987072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4263161190629261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20227679374046392,
                                   0,
                                   -0.22708801324366015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0169188502800963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50352385948405975,
                                   0,
                                   0,
                                   0.50508096003014091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78079508870164527,
                                   -0.27905121020652524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037909438856143896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44129802912636068,
                                   0,
                                   0,
                                   0,
                                   -0.43062016785039847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50138460436176968,
                                   -0.38375880336904639,
                                   0,
                                   -0.22319254454762033,
                                   0,
                                   0,
                                   0.10398515872134795,
                                   0,
                                   0,
                                   0.31661632836123732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15842511972739565,
                                   0,
                                   0,
                                   -0.12423409844291955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2540306207949638,
                                   0.22439974141237748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49823560950744694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055867766050958639,
                                   0,
                                   0,
                                   0,
                                   0.49997896996490387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41302233223683071,
                                   -0.031898725653534285,
                                   0,
                                   -0.83396972026606841,
                                   0,
                                   0,
                                   -0.23812773523498051,
                                   0,
                                   0,
                                   -0.1278276218327897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1439662043553733,
                                   -0.070658863795678165,
                                   0,
                                   0,
                                   0.20196863486180194,
                                   0,
                                   0,
                                   0,
                                   0.53781849100789358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25742732028023252,
                                   0.18920330174699282,
                                   0,
                                   0,
                                   0.59238671060871506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56639588522353823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20736560361907994,
                                   0.22390897039374438,
                                   0,
                                   0,
                                   0,
                                   -0.21042347387087465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17449609168548819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035076161211450602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82852191141183407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6498290686425735,
                                   0,
                                   0,
                                   -0.26707963026140313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37042708618309017,
                                   -0.33117041389931662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39578428795886622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23024245783615482,
                                   0,
                                   0,
                                   0,
                                   0.77981055990756165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19014942084361691,
                                   -0.1510071627132718,
                                   0,
                                   0.024012863015889216,
                                   0,
                                   0,
                                   -0.44600847546000311,
                                   0,
                                   0,
                                   0.40180130510965084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60147227922820024,
                                   0.52896757444412112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11097201234484766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025743805677314539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1618465280414749,
                                   0,
                                   0,
                                   0.096624819863082009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19459294995253151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43179469650956592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053240910795580312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19734272480184717,
                                   0,
                                   0,
                                   -0.074188225818040937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1957562321609774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32527706166040982,
                                   0,
                                   0,
                                   0,
                                   -0.073198936387965013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084899505477575327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28894656095529675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014970989227379723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28699053024646271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37534821931889539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29413630880278624,
                                   0,
                                   0.68635436438964137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13063784047019406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78539018559752716,
                                   0,
                                   0,
                                   -0.86871218790181459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32456321411206951,
                                   -0.10137449161389632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0091574912387697577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21375708371737032,
                                   0,
                                   0,
                                   0,
                                   0.055551795242807525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16897293253096538,
                                   0.38306854954981689,
                                   0,
                                   0.28034478902781407,
                                   0,
                                   0,
                                   -0.68925326347472227,
                                   0,
                                   0,
                                   0.28271098564605018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052256297692313047,
                                   0.28438429234940787,
                                   0,
                                   0,
                                   -0.49074802824819852,
                                   0,
                                   0,
                                   0,
                                   -0.39766195842240432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64616815855769172,
                                   -0.26367919784419352,
                                   0,
                                   0,
                                   -0.54356503480309926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14420745880455943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30503245721492245,
                                   0.069707061172216825,
                                   0,
                                   0,
                                   0,
                                   0.12821809335936907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43309461529718674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62513498416058699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3262129858609818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099978420910973309,
                                   0,
                                   0,
                                   0,
                                   0.19522540653329745,
                                   0,
                                   0.45562398425012895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014411344862908633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19772540034219288,
                                   0.087028977196180857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43476976768028147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44384695596163887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22885941290842224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019792089093491304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037115690735486179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11417324355282368,
                                   0,
                                   -0.4937610351133504,
                                   0,
                                   0,
                                   0.020366261022513092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085995631681734852,
                                   0,
                                   0,
                                   0.43992657725510853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76291646756475362,
                                   0.64079516753802945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54843588628898698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36805556924250293,
                                   0,
                                   0,
                                   0,
                                   0.52930250428341252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30235091397837766,
                                   0.10144018142918428,
                                   0,
                                   0.27175886640216251,
                                   0,
                                   0,
                                   0.26240069346841333,
                                   0,
                                   0,
                                   -0.48969738746771263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46847514985078886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22072943408562332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0087486591801472433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79364156992930046,
                                   0.38658557520247683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3182285008440735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31765820873313988,
                                   0.15101520083718453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30531014578772769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055000102986704345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66039686485593718,
                                   0,
                                   0,
                                   -0.15784288972772414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018280642801962968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35365276637941651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10414330447635842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034547689845401429,
                                   0,
                                   0,
                                   -0.41403638624998584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10069765237091781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057165916461824715,
                                   -0.1348142485915165,
                                   0,
                                   0,
                                   -0.051680647978378215,
                                   0,
                                   0,
                                   0,
                                   -0.04450701708828389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10363578355847579,
                                   -0.98876893400649701,
                                   0,
                                   0,
                                   -0.53539767878543287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42395138902074342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32178057900473384,
                                   0.20349949734113451,
                                   0,
                                   0,
                                   0,
                                   0.64673694613787358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2856641500510278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36136996492262202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19142861991527799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59494534830192314,
                                   0,
                                   0,
                                   0,
                                   -0.42417431982934706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15328836136577312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17753855697242282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1245279504021608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07620387221621551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012813499441042205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49262739253479654,
                                   0,
                                   -0.032894600133974536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38191188650724184,
                                   0,
                                   0,
                                   0,
                                   -0.014122523485727012,
                                   0.31106285148235208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1383550032332885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42739449813536623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22643587733922516,
                                   0,
                                   0,
                                   0.39236729379955732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037736947704106204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51405991044138299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21505021463283697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38012264834705867,
                                   0,
                                   0,
                                   -0.034447935945241495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1959562231114447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079092903168320489,
                                   0,
                                   0,
                                   0,
                                   -0.64304573300521461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17817253754510914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086285139167792124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23186106259641689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48450359802811782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033384389766463088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49190993403526245,
                                   0,
                                   -0.0078365471780794654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096908815650918551,
                                   0,
                                   0,
                                   0.40127568358316457,
                                   0,
                                   0,
                                   0,
                                   0.24638665461117557,
                                   0,
                                   -0.2556569009093459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32422948821309117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28578767419268908,
                                   -0.19286709676938199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35952064540219197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011588029857359062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046986400026778521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14030628919132229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073512601192603166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46961745523688719,
                                   0,
                                   0.25120436133339741,
                                   0,
                                   0,
                                   0.22041478402652431,
                                   0,
                                   0,
                                   0,
                                   0.29367614798619524,
                                   0.046947675608571278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74666678623724092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17492448444590336,
                                   0,
                                   0,
                                   -0.37382114731862459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68381649988602222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11782601904552419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36870477360411491,
                                   0,
                                   -0.50651046136884037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10622861267357742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45771232094895065,
                                   0,
                                   0,
                                   0,
                                   -0.48700682917042054,
                                   0,
                                   0.025938266187995471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1408473618659653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32830301663875161,
                                   0.3988229155747206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16029576408725885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05904658271854353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34393892901405476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25436928949446724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10936867289832675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074962746614053055,
                                   0,
                                   0.064879217557992447,
                                   0,
                                   0,
                                   0.17888888106054601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65028478714771376,
                                   0,
                                   0.8922560055284916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57374299704210341,
                                   0,
                                   0,
                                   0.095172140614858805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6230229560916305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47636178585229405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28367977346813261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36368533368931388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13067562767924804,
                                   0,
                                   0,
                                   0.33848426216126809,
                                   0,
                                   0.6069362147166496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37061891413032044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37947132524158689,
                                   0,
                                   0.079331884146580781,
                                   -0.43566115656968468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15009882906798488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2560478108376163,
                                   0,
                                   0,
                                   0,
                                   0.22639957153824894,
                                   0,
                                   0.41514391161277275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083773104104028981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12120964068273499,
                                   -0.099471597511405233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30485052920049543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010689941382139367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40351329075076731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050286985494872739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07227847236166314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32114140984316464,
                                   0,
                                   0.36468098720723841,
                                   0,
                                   0,
                                   0.42365775657905003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07410297424666229,
                                   0.23054801244385817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18690035420023815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0023429768423911057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30747421431525807,
                                   0,
                                   0,
                                   0.014899817029949284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36399274464038028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1855415795492365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11121465046321032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48133118272848624,
                                   0,
                                   0,
                                   -0.49909293158719287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38935610694041628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24551222738286177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79990793468381338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33583932390184784,
                                   -0.40844956751987171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0020717688748461971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14229423503111555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10585570785512145,
                                   0,
                                   0,
                                   0,
                                   0.47076235080739182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46369418939203122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27209465530060328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26651019437197365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46076258628937461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079565408640407134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12511613755742049,
                                   0,
                                   -0.11279314865002624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40011590110573125,
                                   -0.54642693020798294,
                                   0,
                                   0,
                                   0.55021620096448776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027748314365895629,
                                   -0.053197592634740061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14928344526191883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0098662849649532383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30229449943618297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05351956914766054,
                                   0,
                                   0,
                                   0,
                                   0.22567329136059194,
                                   -0.1299742560520607,
                                   0,
                                   0,
                                   -0.34484533318979727,
                                   0,
                                   -0.3028374886889208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089825968457255739,
                                   -0.48940246398802489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10722183673975169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3611849098756405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42405652250329945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051286218212874435,
                                   -0.037514930927912929,
                                   -0.40449840541378779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50509966225935243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088652427727274996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45569591596380415,
                                   -0.082796054797432239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24185116739108808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22944600741803622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3577972350368015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45430296581251428,
                                   -0.24219262074818845,
                                   0.057286298060006346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5108559487798594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13048278030180077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30388790585291459,
                                   0,
                                   0,
                                   0.47483915622911849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10271267993523012,
                                   -0.40692891682611654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.001880063673986198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1107379784974297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27180601525344822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39200465923463856,
                                   0,
                                   0,
                                   0,
                                   0.087140552259218351,
                                   -0.12706575129343273,
                                   0,
                                   0,
                                   -0.23921404984264188,
                                   0,
                                   0.4304227439001474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26108048350136731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060941549492472137,
                                   0,
                                   0,
                                   0,
                                   0.25607353461171578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27688585521402986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14635084568128634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37443358249176784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36848985809333468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3262371069883796,
                                   0,
                                   0,
                                   0.31021441739255912,
                                   0,
                                   0,
                                   0,
                                   0.72868678114820762,
                                   0,
                                   0,
                                   -0.34464004224406386,
                                   -0.14208235950612697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19261599256116407,
                                   0.97046945833382381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016238517372673074,
                                   -0.27753185386213336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49479176627933941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43055350164990569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21474479438067068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54999421350045896,
                                   0.33612561158420762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22231661789432702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65576078471748167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61381591818628434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15543553260937121,
                                   -0.18267260701665738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39982324061645075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077416011234260354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.155886023723417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16881644689298439,
                                   0.38537650502243675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13847780111907099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44540392096006876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47284569662198872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19397886718763468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010576582312586884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02990493491679079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33419511205634622,
                                   0,
                                   0,
                                   -0.38496812901204019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.643576108644349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18048940393033594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50469056265447121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2992133251366097,
                                   0,
                                   0,
                                   -0.027117905350105866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23470953929997732,
                                   -0.42098979251730445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.211612120589279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021420641302341281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47634836930418623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47849428842936592,
                                   0,
                                   0,
                                   0,
                                   0.088062238926343669,
                                   -0.39360832124834266,
                                   0,
                                   0,
                                   0.11420011000598961,
                                   0,
                                   0.024244833872989743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11830507722975056,
                                   0,
                                   0,
                                   0.016089130700436952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26110700947131055,
                                   0.15332241407384645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54320517096150223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43112176390717494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31624546296573908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22031274847861917,
                                   0,
                                   0,
                                   0,
                                   0.50194085464905769,
                                   -0.079926678180688757,
                                   0,
                                   0,
                                   0.048444874082496855,
                                   0,
                                   0.062400971021470727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40719930509163738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34658467213925043,
                                   0,
                                   0,
                                   0,
                                   -0.59763452747665935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30838439437552162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0040103910126531497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41401100806668506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48272533764545583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40235316904134699,
                                   0,
                                   0,
                                   0.53393937327810859,
                                   0,
                                   0,
                                   0,
                                   0.13604321204971695,
                                   0,
                                   0,
                                   -0.025733345816439549,
                                   -0.1388437131875456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18664735996726781,
                                   -0.4943158954198264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0183730861394946,
                                   0,
                                   0.042228685136344243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12531140612485681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14974815504628519,
                                   0,
                                   0,
                                   0,
                                   0.14177592082920404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1887226555983478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66428331232231919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55959910031087301,
                                   0,
                                   0.21201144934918503,
                                   0,
                                   0,
                                   0,
                                   -0.76933419527416558,
                                   0.19946200738723474,
                                   -0.036983493064237379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23542586661640166,
                                   0,
                                   0,
                                   -0.27816217849475083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10012583224743149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25023114206461999,
                                   0,
                                   0,
                                   0.19958527985370059,
                                   0,
                                   0.42339115605414396,
                                   -0.12583750012420691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11863797941339124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25776366997054923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12501757019480914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12033832537429905,
                                   0,
                                   -0.15957685905951904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013759262334252603,
                                   0.65065224910818964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26702620766046936,
                                   0,
                                   0.2723059217522123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47164947211826108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14390173551706884,
                                   0,
                                   0,
                                   0,
                                   -0.8978987450019198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064700406354440701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49887955386284893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44394185414860088,
                                   0,
                                   -0.29141632202223422,
                                   0,
                                   0,
                                   0,
                                   -0.059549948356662587,
                                   0.48008521195595283,
                                   -0.043206702144490537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089337722989797669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89263514514941411,
                                   0,
                                   0,
                                   0,
                                   -0.3175112321008482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036118716483946212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30600785851188073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010918658464781621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36986441423012878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39101211977950628,
                                   0,
                                   0,
                                   0.04195777638623141,
                                   0,
                                   0,
                                   0,
                                   0.052036002309789733,
                                   0,
                                   0,
                                   -0.049988623247435922,
                                   0.53051984459050872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82094761413122019,
                                   -0.25310634770107837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017935855864321438,
                                   0,
                                   0,
                                   -0.36493009799281095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011945828250886786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31552285949183562,
                                   0,
                                   0,
                                   -0.21238659437627083,
                                   0,
                                   -0.016476978832032314,
                                   -0.44296207100756324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45842297387314479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33708554998631257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2886329740008351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23126392703173235,
                                   0,
                                   -0.058265480088979846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12670026380381608,
                                   -0.21258853848794632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35854163079001494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1798802227289138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12080530464978328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45003983329254738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6060705816345624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53650313956482065,
                                   0,
                                   0,
                                   0.29240459465439311,
                                   0,
                                   0,
                                   -0.16969397390001489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023763598723309305,
                                   -0.10703504368448186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089190124805496027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52347638252626849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27278698555383168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1259631316184695,
                                   0,
                                   0,
                                   0,
                                   0.52722638220363582,
                                   0.10974449841667283,
                                   0,
                                   0,
                                   -0.33857721866497426,
                                   0,
                                   -0.3110858427873916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39486806123833368,
                                   0,
                                   0.56993338959592843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86975777264567111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072236661446439795,
                                   0,
                                   0,
                                   0,
                                   1.0107192195634191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45529939681574422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55459047888372137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41870530615138402,
                                   0,
                                   0.36023474733730676,
                                   0,
                                   0,
                                   0,
                                   0.27067454872365004,
                                   -0.37997567922258979,
                                   -0.29365247850287884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58879108092812193,
                                   0.13835338356284571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18107557430858232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14247977995384115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15111240175423787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39324650288620261,
                                   -0.4134903359465717,
                                   -0.21420702044975537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12372738701653171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41406450118798704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57667479442151937,
                                   -0.42097668879080663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55475829348751049,
                                   0,
                                   0,
                                   -0.10167427613205908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41443795558717672,
                                   -0.019276081609215328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14325629803260176,
                                   -0.64397651306288561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063491397416129386,
                                   0,
                                   0,
                                   -0.1399288571283093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37469711902393599,
                                   0.63305822014206437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93971404357626009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58423604978243771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59013963156731231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0670974889794971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37743292865682926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65545070649327919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68827490673570357,
                                   -0.15346021578082517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53081003693341433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.210253799370831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46445913291041235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.614339994598044,
                                   0.39654349357585922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37538655231879603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.244656014843185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75101791251079419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12193629867793683,
                                   0,
                                   0.98281824152626585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42948372400974733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23030448805428588,
                                   0,
                                   0,
                                   0,
                                   0.075085518863863304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0040143539193911448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22769005706814402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070804129010405226,
                                   0,
                                   -0.84441768650402427,
                                   0,
                                   0,
                                   0,
                                   -0.061893997945451557,
                                   -0.093498387985356465,
                                   0.17344292813964954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048971391415666511,
                                   0,
                                   0,
                                   -0.016119717420356609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24916726454913821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32724131501651216,
                                   0,
                                   0,
                                   -0.65121556384155443,
                                   0,
                                   0.10524203485192583,
                                   -0.28643866879791008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23005920895772297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078759692710334173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12944840057443352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42690143057842733,
                                   0,
                                   -0.20887637239518222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041978559337431144,
                                   -0.086269687794812921,
                                   -0.30767985396027397,
                                   0,
                                   0,
                                   -0.028736655741909825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13080258450196824,
                                   0.14079750930392887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40460005027622337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23954369826669131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12596831388708574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32664503668498085,
                                   0,
                                   0,
                                   0,
                                   0.25514057676596591,
                                   -0.14225688112044022,
                                   0,
                                   0,
                                   0.17853810383256602,
                                   0,
                                   0.63774374832621128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3419525253287749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11734862826620174,
                                   0,
                                   0,
                                   0,
                                   -0.085640300155513854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2960121505495843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24760508945802151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68060416020601144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19035481676171478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42945419786310973,
                                   0,
                                   0,
                                   -0.81831208681714362,
                                   0,
                                   0,
                                   0,
                                   -0.43277651329400663,
                                   0,
                                   0,
                                   0.47568992312313108,
                                   0.1108393059751136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39433277326493726,
                                   0.38669709847543832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62264161382483374,
                                   0,
                                   -0.056437316298544329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6042265673047359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52315658884313609,
                                   0,
                                   0,
                                   0,
                                   -0.47793804478702734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57934216581913434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091631339409535079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43487541811451069,
                                   0,
                                   -0.52001811242216478,
                                   0,
                                   0,
                                   0,
                                   0.21605727278038242,
                                   0.044076163809094668,
                                   -0.74668836348650436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081991272724360936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16784623066642315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25818557147749072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62259811006817123,
                                   0,
                                   0,
                                   0.13231038077294449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31743439809064022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62324223304405368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064151095604809777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18857532664680487,
                                   0,
                                   0,
                                   0.14872148016039857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25003760740823155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20074334827987222,
                                   0,
                                   0,
                                   -0.43791013760643982,
                                   0,
                                   0.024819665064829896,
                                   0.25771128432262946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10977694299825341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02231724437628832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05482389193845566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41668062515711568,
                                   0,
                                   0.54076527594636703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2877627200471316,
                                   0.12765678291729088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042860451115070218,
                                   0.50309257500558713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57436539672091214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43479366851322521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012203291266479474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8679572077072002,
                                   0.59262346063679294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13531557665111549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79178297261962194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55452273037450794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20380816285980924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058617934412880553,
                                   0,
                                   0,
                                   0,
                                   0.28941723129203462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0611664876749201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091927798636572106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34502871607590635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10553996792632915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50395820414291648,
                                   0,
                                   0,
                                   0.18282745326759367,
                                   0,
                                   0,
                                   0,
                                   0.44212323936005415,
                                   0,
                                   0,
                                   0.16001704840790418,
                                   0.36213839835117789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025795249908541037,
                                   0.034761519301393026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014551205499137201,
                                   0,
                                   0,
                                   -0.29746694625350018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030912493728436928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33468909454901757,
                                   0,
                                   0,
                                   0.15696316454962742,
                                   0,
                                   -0.19697557383600373,
                                   -0.20728647103466896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035461611645047714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15566675247357875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57989174170459779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11411049449134132,
                                   0,
                                   0.075937004580723014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54229501466069763,
                                   -0.13148840584705096,
                                   0,
                                   0.11660136801836012,
                                   -0.081687284758483678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57946270762900798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086025363585927411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012860692802499296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37738357062116146,
                                   0.47290411914266539,
                                   -0.19688829490333545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0074988207558996448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48115550510546146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0090361954378805343,
                                   0,
                                   0,
                                   -0.32580957334134775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51753975805494212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0015813783455577747,
                                   0,
                                   0,
                                   0.11390953350160196,
                                   0,
                                   0.31399169863087761,
                                   0.24666850637153298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23456415804954156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072966210682475163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24327648382286587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16673532423747905,
                                   0,
                                   0.21523833060842457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43067970396758049,
                                   -0.27269758351245099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46814090218335203,
                                   0,
                                   0,
                                   -0.089866192642233153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20905359010094526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59177735961592814,
                                   0,
                                   0,
                                   -0.054455853948138719,
                                   0,
                                   -0.023788168221893523,
                                   0.23052756162739296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35208890416819749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11293307575991979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034055653887842444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29380000521089539,
                                   0,
                                   -0.035125776353533797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31105639002797375,
                                   0.0011991597580252034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65976837265036381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49161723886359487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28447548303546916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28633371796235246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1335960700424939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54611671591306155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23236893261086636,
                                   0.4851412006981497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3718770841398405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70647687120376512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.534753349929174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86030956338198927,
                                   0.59002205299078292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21358959520118187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13974808178325124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35863048829141969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061344360852325933,
                                   0,
                                   0.18251915664475701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42461133008096996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12032952259526733,
                                   0,
                                   0,
                                   0,
                                   -0.27330968033638281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80147446633592945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2857566323229066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10617034436879237,
                                   0,
                                   0.88222768693966147,
                                   0,
                                   0,
                                   0,
                                   0.79847906881437303,
                                   -0.1946922709973184,
                                   0.14510607592021296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68521495189827752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50870145671938338,
                                   0,
                                   0,
                                   0,
                                   -0.69281331191616391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13850000883928604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44469726721685421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62816596077285136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015598460940817391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071579605066756577,
                                   0,
                                   0,
                                   -0.16613823085837803,
                                   0,
                                   0,
                                   0,
                                   0.072817314098762104,
                                   0,
                                   0,
                                   0.33182998256504304,
                                   0.20982433120409824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026453227227853451,
                                   -0.060983642348100789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33484227706177772,
                                   0,
                                   0,
                                   -0.25706985939433186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3002930558268998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060421434191988851,
                                   0,
                                   0,
                                   -0.19389451361825605,
                                   0,
                                   -0.090828939278396581,
                                   0.24718031675451177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54897786671453641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38605678598020071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10151613707657681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27178149067314955,
                                   0,
                                   -0.17002409419162287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010328373044610439,
                                   0.23963277610569547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15022522756038467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37976884962973312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087786288572554189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048380423698371991,
                                   0,
                                   0,
                                   0.59671756169255497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10269183616104482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0070146599068763651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67564357237875849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0042609998112581038,
                                   -0.95359239032775067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50263189299963851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0011251279183757401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15566352226966998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52516406357267331,
                                   0.21967318949150266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38301152001040673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50352716640686079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45452907696111888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19640490921640733,
                                   -0.13157786683037806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51261205670970755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1438546899646929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47351087607752818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34319567863922512,
                                   0.23222727253584485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61239912862066348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046583308285818747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0036818242905477042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07416767794885662,
                                   0,
                                   0,
                                   -0.13972945622935024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44049057079313142,
                                   -0.143012033689361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074692157304633619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15213530502376627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29026759078260589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2688074843166493,
                                   0,
                                   0,
                                   0,
                                   -0.070763157645468838,
                                   0.46919650061006679,
                                   0,
                                   0,
                                   -0.478684687424342,
                                   0,
                                   0.34779567557948443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50929782947684477,
                                   -0.06121276905033643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02388974967056972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37591235053075467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23349412286827587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21758491077972894,
                                   -0.22127058299200705,
                                   -0.54946429349115711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35964624266736572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11361383268477709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40687326634525467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7216598997017617,
                                   0.060031135178215463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40807541509849266,
                                   0.3477013367104187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35630205133805892,
                                   0.44231339521120522,
                                   -0.11271783136892416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49484278384980485,
                                   0,
                                   0.11300951935014178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12315647939387347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14573482114186415,
                                   0,
                                   0,
                                   0,
                                   0.47788046333192347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17393029452410674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21089180999690776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084815962379902007,
                                   0,
                                   -0.10095310187572221,
                                   0,
                                   0,
                                   0,
                                   0.21292504538279913,
                                   0.63275445317811585,
                                   -0.75221149631942197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082363757071763272,
                                   -0.20532355245059258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070550390966886686,
                                   0,
                                   0,
                                   0.97102536505100834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05096124398182536,
                                   0.024367697960477247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61880006648390484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27439621986227747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88519708805304553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49267529736623789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   6.9673621842653022e-06,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2897781178620502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24613931351768334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73307866758437878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2041632037654765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047947149010577311,
                                   0,
                                   0,
                                   0.38746023890449766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30597365437889223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32635016726931315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088203271034145825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68493644359852457,
                                   0.28420180593751654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47968539616133066,
                                   0,
                                   0,
                                   0.14011665459151018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032857705761062533,
                                   0.44640902401296412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0234018255299573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25903104545738642,
                                   0,
                                   0,
                                   0,
                                   -0.12043374134725587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033889003277990104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29662469834732424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50187826637685129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29253137310686356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17535074515016047,
                                   0,
                                   0,
                                   0.085849698214329404,
                                   0,
                                   0,
                                   0,
                                   0.55348390050293872,
                                   0,
                                   0,
                                   -0.13337801289021362,
                                   -0.27520659785717116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059228550094701293,
                                   -0.61891196514343516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3871611061861967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29939105426856932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28139267898257347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22465562356455704,
                                   0,
                                   0,
                                   0.2158321247198528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48729441228868375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52988668779686299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25690471635077849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37938560684760181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078579594377937392,
                                   -0.26263507763810573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037896982458600639,
                                   -0.25386165606584032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93072392970913953,
                                   0.53728195597464434,
                                   0.5023845114706933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.690246438365404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21739982623372348,
                                   0.71349337180764871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5196573277353338,
                                   0.10520461179165375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20785161124539331,
                                   -0.09739036841152901,
                                   0.42775287339622869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61517788315628275,
                                   0,
                                   0.34042838334287634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33408507342889149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06516528078012615,
                                   0,
                                   0,
                                   0,
                                   -0.64662435072452473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64911184993285476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21884780137479379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049453561151525008,
                                   0,
                                   -0.078791595967465669,
                                   0,
                                   0,
                                   0,
                                   -0.52301701269176382,
                                   -0.71341525789960003,
                                   -0.50314986927640637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69924541699876241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23137602780746369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29671118436845345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95641886017300493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28158165726001982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35821622537458947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30210023739796821,
                                   0,
                                   0.55334540915052799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076662035854599811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055543690259212006,
                                   0,
                                   0,
                                   0,
                                   -0.37292310048395089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34688160679142288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24522795464428343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27896356257707772,
                                   0,
                                   0.78242789111888777,
                                   0,
                                   0,
                                   0,
                                   0.11165882232514501,
                                   -0.061266146131281382,
                                   -0.17149899282171568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12653286134918457,
                                   -0.81619669294909136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010503608334069575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30336533405478283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035252641673814616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15727176291844169,
                                   0.0073973339262117521,
                                   0.2964853873127351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32462051444944279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07973457046020202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22642529206020454,
                                   0.0043151857019375628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40251436714262012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20369626988367495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37475204740860962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084233762023722472,
                                   0.55421581753813998,
                                   -0.48824865132865014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041928169723981987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2244296484766008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25458652570788431,
                                   -0.11272193754546769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17084228850084382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38236054972134265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25460667327132264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61277147912285312,
                                   -0.0043931513506213025,
                                   0.0023117677377788304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37911690755829291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40376363240693974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56895641387152507,
                                   0,
                                   -0.1633189049265408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56215776147651308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5624647809654495,
                                   0,
                                   0,
                                   0,
                                   -0.062133240877000298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15694411163291211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40501863237963509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60210869439764536,
                                   0,
                                   -0.23977509723101059,
                                   0,
                                   0,
                                   0,
                                   0.64981315183240562,
                                   -0.25176178097963237,
                                   -0.05285955925492606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32588231748640528,
                                   0,
                                   -0.21712324362617591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18636886774290329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88953474115118192,
                                   0,
                                   0,
                                   0,
                                   -0.28735097808217358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16794877363948557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2645322090659239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23169661101462224,
                                   0,
                                   0.12678732955184374,
                                   0,
                                   0,
                                   0,
                                   -0.33202910838148408,
                                   0.32449202220594192,
                                   -0.15086935220296135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24476716411769101,
                                   0,
                                   0.24066579069063476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37400944115536383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13358151724518463,
                                   0,
                                   0,
                                   0,
                                   -0.31107108684459761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73394084847403374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48858183589791826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3588010840341278,
                                   0,
                                   0.31539258645319135,
                                   0,
                                   0,
                                   0,
                                   -0.12642778821382361,
                                   0.49064462448804241,
                                   0.83120300406601699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29370285301835025,
                                   -0.25637824247055357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48297910506163211,
                                   0,
                                   0,
                                   -0.086415649571964084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77657469010501179,
                                   0.064839040614438737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29110260808416444,
                                   0.46841717220521339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46890065619361643,
                                   0,
                                   0,
                                   0.0095736909539694826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28477767369675039,
                                   0.62832063468937205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78225571278500461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32378090703717505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1530161269148137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27099924812408394,
                                   0,
                                   0,
                                   -0.016641709540851035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31603706181876967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0039612709564458802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29362447763513094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.00378866636412,
                                   0.43018032482693913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42641926618025194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74610390677779814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16824362141666271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70120505376448417,
                                   0.40906878976363181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3097534536004054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43617166228264515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21386738732133573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089647017642383531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58277439880416648,
                                   0,
                                   0,
                                   0,
                                   -0.21473846818684533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44274503188727882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35252115765803865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43780500380741533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03372418609604666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20810334050652196,
                                   0,
                                   0,
                                   0.037698572343505835,
                                   0,
                                   0,
                                   0,
                                   0.29344652871895216,
                                   0,
                                   0,
                                   0.12077358068018731,
                                   0.55151200119895338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60727682536671246,
                                   0.049650899036540838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64469092372322012,
                                   0,
                                   0,
                                   -0.12795416223286038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27514506010402184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22559213607069581,
                                   0,
                                   0,
                                   -0.16945369531263921,
                                   0,
                                   -0.2665506458170992,
                                   0.25125844189175417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079853161944923409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10621362151586419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11183995574170864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023161462690482248,
                                   0,
                                   -0.17346029797273982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10378325604128448,
                                   0.45491558984870895,
                                   0,
                                   -0.048317411476524158,
                                   0.21065477692108225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052010141114385046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59064546616600022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58673994123914097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14612029728797254,
                                   0.26890522627278518,
                                   0.18647017678757372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28123430864310567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22345936408335951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055295055931259857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36915528236287987,
                                   0,
                                   0,
                                   0,
                                   -0.67791930488541785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36399964497774451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22333322655267029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12173141737265888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34565229545967358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27722531626421876,
                                   0,
                                   0,
                                   -0.13193292529509451,
                                   0,
                                   0,
                                   0,
                                   -0.046094844309833419,
                                   0,
                                   0,
                                   -1.1167443950585061,
                                   -0.031663287707138887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53696303921692223,
                                   0.10772897568509379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62256105409406226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16944946295859564,
                                   0.23663300250318917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36164311315672382,
                                   1.1718191529251623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68753098932575007,
                                   -0.27975008875896223,
                                   0.51920534847508171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.513902005785144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25712718339405372,
                                   0.75953073745338984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66925848220960582,
                                   -0.33180353914663596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44229501752277744,
                                   -0.1630560971591998,
                                   0.091729748764264152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1369331832460961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27949822958331211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80431689600332767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020230536783240792,
                                   0,
                                   0,
                                   0.29586296043609583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20670346263753536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25308170440978955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24795874100259963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51089124494338689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098739640065946627,
                                   0,
                                   0,
                                   0,
                                   0.35090495539747973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1418619059028115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096122078400339178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093896529564739498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24250694659594865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11852228642571326,
                                   0,
                                   0,
                                   -0.75873303238654899,
                                   0,
                                   0,
                                   0,
                                   0.49924198654137431,
                                   0,
                                   0,
                                   -0.11376025809656871,
                                   -0.52792312826704824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027342646586468823,
                                   -0.65230103067802747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23680121492679904,
                                   0,
                                   0,
                                   0.22943035741945411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2501092565600524,
                                   -0.31057401345513097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45367701513146597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56109362056939738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0057220589999925214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0083503649906304656,
                                   0,
                                   0,
                                   0,
                                   -0.10151805306164108,
                                   0.2784342050156639,
                                   0,
                                   0,
                                   0.33489994700518494,
                                   0,
                                   0.10740198262494663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10956589024632354,
                                   0,
                                   0,
                                   0.15771411264224683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19603092950288273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08541939813826066,
                                   0,
                                   0,
                                   -0.052708807677766548,
                                   0,
                                   -0.34947453235607434,
                                   -0.027519692500330928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088147788998335558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59108483031839565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036667740386495722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39939234522900496,
                                   0,
                                   0.38367704348571013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29415471196653864,
                                   0.19995956741266477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065277075681254709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069380199256378061,
                                   0,
                                   0,
                                   0,
                                   -0.80492933046910065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042107247761238045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62439435139618638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19833293950930753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29593510487967573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2092456899033408,
                                   0,
                                   0,
                                   -0.35163598901619264,
                                   0,
                                   0,
                                   0,
                                   0.45230814325173957,
                                   0,
                                   0,
                                   -0.092557732485927913,
                                   -0.090624724613058899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62485752461619803,
                                   -0.078245277400684932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17137600710061884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19271194676145478,
                                   0,
                                   0,
                                   0,
                                   0.25889565061257258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56324849171737568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90278558651493701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69670553856395867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10054812522107376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3314015651435393,
                                   0,
                                   0,
                                   0.026758319226769092,
                                   0,
                                   0,
                                   0,
                                   -0.34257016528901274,
                                   0,
                                   0,
                                   -0.19133985005136886,
                                   -0.21438679891657281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29879007121025863,
                                   0.1846947417024922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075259515260030468,
                                   0,
                                   0,
                                   0.14571372193227858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4746140249100711,
                                   0.1995782635231631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3272490697347924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089706488240616389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29248634053149125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39186710154902576,
                                   0,
                                   0,
                                   0,
                                   -0.42267330662463853,
                                   0.086009440485553479,
                                   0,
                                   0,
                                   -0.40688511115504034,
                                   0,
                                   0.046480390243926278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19202848249178578,
                                   0,
                                   0,
                                   0.30174933799167242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42638790383727032,
                                   0.14606790593166757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047633649835489081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17325340491733257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19709174157052836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044171093047891657,
                                   0,
                                   0,
                                   0,
                                   0.29782683815668459,
                                   0.64939786466918381,
                                   0,
                                   0,
                                   0.29171253111478396,
                                   0,
                                   -0.018258184749267076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15708999708392321,
                                   -0.71465558507678006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46248170830721658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55868539585929611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072357448235182739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16204467006053497,
                                   0.27982669850883884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1362620816735025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2166403836513664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25172161278671445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30319800564170968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13228275497289074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36542497894631104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60969304540904656,
                                   0,
                                   0,
                                   -0.44011461428236376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02860270521764606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35720178360407118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25139434081338891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27599575138615584,
                                   0,
                                   0,
                                   -0.41647464440471393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36420607496650625,
                                   0.034739391047327303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34458201325640603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085488327713242288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33079910267096846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45663278753015163,
                                   0,
                                   0,
                                   0,
                                   0.23489622969896135,
                                   0.018644223105663965,
                                   0,
                                   0,
                                   -0.25137934804800482,
                                   0,
                                   0.23199210338792275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082134930412088844,
                                   0,
                                   0,
                                   -0.28671502344377536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21220968176026189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039396726943913857,
                                   0,
                                   0,
                                   0.31333963252260671,
                                   0,
                                   -0.28832692281630856,
                                   -0.22454013969762801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058158934415423545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43379716230990395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45657042544776349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20739379117984469,
                                   0,
                                   0.41314192183428777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064297712926755679,
                                   0.12198058118853922,
                                   -0.38090610197598113,
                                   0,
                                   0,
                                   -0.28857396940086544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22681029091064375,
                                   -0.64828656025445275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16341314948673002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29421553036424591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31532575500224042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084013186653242838,
                                   0,
                                   0,
                                   0,
                                   -0.029512882954749006,
                                   0.215012901380323,
                                   0,
                                   0,
                                   0.082577844928974159,
                                   0,
                                   -0.16199195000591535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35802212119020171,
                                   0,
                                   0,
                                   -0.033135768851372642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3499762147768184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13510801088172866,
                                   0,
                                   0,
                                   0.015027675708090845,
                                   0,
                                   -0.61321351384325185,
                                   -0.040667353320273464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082889893973442513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019103463636014357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069471578778983703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34574697026272594,
                                   0,
                                   -0.33292064414117117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33096785219216629,
                                   -0.0097651827494624199,
                                   0,
                                   0.17375149852872393,
                                   -0.028128892099914902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60568563909941975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1389413237462247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2527195699259967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13380737381500624,
                                   0.34179367495226487,
                                   0.29235570877810946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096081197608811411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53810912443045467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16343396592173845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07789099537625771,
                                   0,
                                   0,
                                   0,
                                   0.45835397886426088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053999215684793593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11008579198647578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26334300270176092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90420894607745395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040497296284986467,
                                   0,
                                   0,
                                   0.40634280646575299,
                                   0,
                                   0,
                                   0,
                                   -0.057657337377140044,
                                   0,
                                   0,
                                   0.5456928769817081,
                                   -0.40739648008673673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1861604019126,
                                   0.20254037823524149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55281000668263303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44705179507546122,
                                   0,
                                   0,
                                   0,
                                   0.60621578554215783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13440099246844908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024249841885602919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020252844951183749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093011405754669735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63565594902577061,
                                   0,
                                   0,
                                   -0.32389503216844456,
                                   0,
                                   0,
                                   0,
                                   -0.044406174929768949,
                                   0,
                                   0,
                                   -0.45440259297594726,
                                   0.54222754904262449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58027018471201075,
                                   0.086372638973646387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14333799351117055,
                                   -0.22187174153256356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17465840976492117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33185833309982138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95557651239019237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07936698924980537,
                                   -0.78291270298214655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42317827699330779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16555454555754073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85028887208850679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23507841668746424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040087657822237249,
                                   -0.31422956428954901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70129672775908003,
                                   -0.071788920969609649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26994289315286613,
                                   -0.26113104476749549,
                                   0.70103441981121639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21827496015088835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10418427781017142,
                                   0.22397524167357552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1004034277949627,
                                   -0.23886064943920143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87653314756259504,
                                   0.66705824539176239,
                                   0.27285909005096332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30534242857650001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1740952633583932,
                                   0.15950997325936578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050015530873776914,
                                   0.9534983370611837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076826910316173058,
                                   0.309893217286552,
                                   -0.4109693269069819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27159925441647337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8706114785372312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0461525906401103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058881004715002447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79446890079748078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6229568086038253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078264738713599957,
                                   0,
                                   0,
                                   -0.57402719184893591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41692245019644014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077655587982849633,
                                   0,
                                   0,
                                   -0.28151697097758333,
                                   0,
                                   -0.047434714381096782,
                                   0.089141697653622495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45108340748722325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05017499272635001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12053823690481721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22697256413301747,
                                   0,
                                   0.21683339551237374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27478238145978739,
                                   -0.022421733457153505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077737014175739944,
                                   0,
                                   0,
                                   -0.21028049104222044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08410183632526616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37489931213185418,
                                   0,
                                   0,
                                   0.1090191613508108,
                                   0,
                                   -0.089306350025888132,
                                   0.545460102181343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0360281617558652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2648680543935521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48240113339760637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032283400320490617,
                                   0,
                                   -0.21682316278019997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19047117607919198,
                                   -0.31021153247956917,
                                   -0.11157896699673486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46215433614136936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020453382968551051,
                                   0,
                                   0,
                                   0,
                                   0.10726330596833471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45774218572409725,
                                   0,
                                   0,
                                   0,
                                   -0.18580071544241958,
                                   -0.29748863821602289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2070130582210587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50684573135870037,
                                   0.19702503883603212,
                                   0.19144817780419685,
                                   -0.050311958692880333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095812770823264018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20630266378731238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22590104849352569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40284748871330311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40542585705800538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19503694884326064,
                                   0,
                                   0.14026814531771259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7665139781246022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15077626502995797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58882998711649748,
                                   0,
                                   0,
                                   0.82837070709354232,
                                   -0.30486313051472291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23116474965338346,
                                   0,
                                   0,
                                   0,
                                   0.10637087138635681,
                                   0,
                                   0,
                                   0,
                                   -0.43275679844540943,
                                   0,
                                   -0.25062964392607834,
                                   0.29332162721033445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59629990048432568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47919787493790045,
                                   0,
                                   0,
                                   0,
                                   -0.60631952302088099,
                                   0.30357091060762448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29685150911306557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38456511121450082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12758743337670214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076227495767159786,
                                   0,
                                   -0.12507369639578092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27434071279349936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40016384556631512,
                                   0,
                                   0,
                                   0,
                                   -0.26037238963233356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32110772213108069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19162259016761207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17300456712932602,
                                   0,
                                   0,
                                   -0.53889964718714967,
                                   0,
                                   0.0019783379759015091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27868523612814033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6279841142890531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11845531168785506,
                                   0,
                                   0.35172315070266968,
                                   -0.21605140324970704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058331510347875079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54602304787962475,
                                   0,
                                   0,
                                   0,
                                   0.036888583394641683,
                                   -0.10308930170519445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70443236784429608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23201988191341522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40030485088456097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30720924636977381,
                                   0,
                                   0.54478026117605294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68840404989607928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077500842675608056,
                                   0,
                                   0,
                                   -0.18941268437517267,
                                   0,
                                   -0.16573059620300101,
                                   -1.262412046183272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17547374681023864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20476629005004865,
                                   0,
                                   0,
                                   0,
                                   0.00072122839807686745,
                                   0.113119157221924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50153085658201202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065610751560307073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30750575964266941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19335713551181835,
                                   0,
                                   -0.10175194606839053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68237680770075193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58014743633433741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13123520315259854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20697684482565268,
                                   0,
                                   0,
                                   0,
                                   0.39292569843590064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4402583088508113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063632822822081408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76659688755935451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012787933039879414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25027569703995739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47046593984546359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14902075992689312,
                                   0,
                                   0,
                                   0.038926063213531627,
                                   0,
                                   0.19220619624722091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11988921722961118,
                                   0,
                                   0,
                                   -0.47849075480481795,
                                   0,
                                   0,
                                   0.30582118532318775,
                                   0,
                                   0.43733888661366677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1397498577577789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32794198846875938,
                                   0,
                                   0,
                                   0,
                                   -0.62801264742473029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54619419441056727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042172168332750004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0082796049122459414,
                                   0,
                                   -0.2873591283953415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26704128573966546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12604456855329199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37130440725652641,
                                   0,
                                   0,
                                   0.16176822294079671,
                                   -0.49340265138651218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78592400744999491,
                                   0,
                                   0,
                                   0,
                                   0.32782122118368284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36884445996945669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04805895485351612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9060443655349909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42680513838319273,
                                   -0.013931152545242097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092147194276430505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13640441842523338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46611634346278352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17450664440081162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51298895740946271,
                                   0,
                                   0,
                                   0,
                                   0.069531964481475209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42204925648323055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50566037635581873,
                                   0,
                                   0,
                                   0,
                                   -0.23194781368362416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11316406333244483,
                                   0,
                                   0,
                                   0,
                                   0.00016179242975160324,
                                   -0.23481565786340461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26610936143232566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15318448828186132,
                                   0.37542157757675138,
                                   0.2326818912665051,
                                   -0.25161530148197764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047453051140111592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29099664399406872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21592386795865484,
                                   0,
                                   0.30835493781176926,
                                   0.092845056054804254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38944901472937987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38243653344086076,
                                   0,
                                   0,
                                   0,
                                   0.46964757811081603,
                                   -0.79255319533680002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4812683457164838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23850601879692807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37631837036683546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23789430222079036,
                                   0,
                                   -0.36409835325679352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70793685006227736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063669539447514745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26961025041724312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77097240268142941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13719951648801482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070398512614829711,
                                   0,
                                   0,
                                   0.076450442620814074,
                                   0,
                                   -0.12917067566089355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20431970373167146,
                                   0,
                                   0,
                                   0.0015256099991779459,
                                   0,
                                   0,
                                   0.066282822300329058,
                                   0,
                                   0.34501432293081141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043731528207343898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34570632725669892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42545447696413702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27308878551306298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18721394229445054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52585278305486471,
                                   0,
                                   0,
                                   0.40216602828338949,
                                   0,
                                   0.42181505575456213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17341302963070726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25120362101298566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25662250391644803,
                                   0,
                                   -0.17085349088254653,
                                   0,
                                   0.26957444555003263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46309617226168104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74266260179217891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055757528222787595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036625996845497444,
                                   -0.97262823543991217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07989264239085303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088296091307794977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067864922711066006,
                                   0,
                                   0,
                                   0,
                                   0.26833072935069291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14323488544131788,
                                   0,
                                   0,
                                   0,
                                   0.082632703455274348,
                                   -0.12616587036565385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59274448096399601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02245649854052488,
                                   0.23052689710217117,
                                   -0.21641735172428755,
                                   -0.44383291248374201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46534414631452525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024278628511516791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41391891360129396,
                                   0,
                                   -0.24360932324447621,
                                   0,
                                   0.0070997249112971159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75316441331810668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97572242462463188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19294355699107291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84610398832178502,
                                   0.26660642010168339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1608775722334117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15654906372210342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083494303082304294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21697845020294457,
                                   0.16309215743065639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2415411515113455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15474876611765795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41788723637495068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83983522467838756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79032143193309057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06463126501217234,
                                   0,
                                   -0.38213958432890421,
                                   0,
                                   -0.15810343399887916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59609052889399505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89590724653819109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51318951609051022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55273581093433055,
                                   0.1928697119893773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28732290701757973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20501544501102786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04534608219347,
                                   0,
                                   0,
                                   0,
                                   0.5929112731061521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42009948679437237,
                                   0,
                                   0,
                                   0,
                                   0.16036792449770124,
                                   0.0082404968081611924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30181220257849278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025130950276588553,
                                   0.066460640519894643,
                                   -0.13022649939262315,
                                   -0.37736505282061961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21840592514553292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12783252428298572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52899620916493728,
                                   0.25342399133533394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22297040194943707,
                                   0,
                                   0,
                                   -0.53182469081410655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3965945964301596,
                                   0,
                                   0.34036037165561828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038409782467484298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12900876180303542,
                                   -0.17445345988927366,
                                   0.041242589760338497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24615890153748257,
                                   0.282719960196122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20576457853601221,
                                   0,
                                   0,
                                   -0.331884136215994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64251713040764058,
                                   0,
                                   -0.29307773854908259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21009725251613004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38860736535058826,
                                   0.040449997620209996,
                                   -0.1071144795127377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41435345122441986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36025662244836204,
                                   0,
                                   0,
                                   0,
                                   -0.50409032678146348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44406168460154077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14756444056469026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47481920984258963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64989948931424668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02295078547605334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076564753430067689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75695475598530204,
                                   0,
                                   0.32711302356532929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76274210006586662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42226870817327267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58898615969986023,
                                   0,
                                   0,
                                   -0.23902820950825279,
                                   -0.45046743939240813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057548746197249256,
                                   0,
                                   0,
                                   0,
                                   0.064731162317879246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25533410225997794,
                                   0,
                                   0,
                                   -0.24506358007943618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11568855477543571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18639661245957134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70892206939968905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.5483573012239416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60978551408018744,
                                   0,
                                   -0.17503831521622748,
                                   0.27333610472590164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025181598902952247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34530228059765911,
                                   0,
                                   0,
                                   0,
                                   -0.10557049505744026,
                                   0.70162335539409348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33611402389982514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37792717097829731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28275280989459617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034461699229445655,
                                   0,
                                   0.16607948855837648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70453346958363228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18739978413363778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18858091353336595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39675611704426494,
                                   0,
                                   0,
                                   0,
                                   -0.60790552551786203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63295203873232164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0062870759136565146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19184599037974176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42222978477456485,
                                   0,
                                   0,
                                   1.1174205308974885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089221486537942041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2153240470552062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099179500068137014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31791965865007593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30517234008196509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27391678164505612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11965168938499517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48173445493892636,
                                   -0.98659854988827889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056254096969849274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16164466209781703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043823680402873974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068253944590463439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070610866727720809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4387703756602791,
                                   0,
                                   -0.66205206873429356,
                                   0.25010342318517559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4591670904888504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54612974531803793,
                                   0,
                                   0,
                                   0,
                                   0.45407290847491388,
                                   0.12131936508460395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2171887099818402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24757228751105814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15986538535106704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20901007758890483,
                                   0,
                                   -0.56244016715536505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13822307715534504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37522675938845623,
                                   0,
                                   0,
                                   0.38628629847253571,
                                   0,
                                   0.34296759628571188,
                                   -0.041661030941026495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54244504038386454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60573057863578783,
                                   0,
                                   0,
                                   0,
                                   -0.29562696879805955,
                                   -0.099234313805522695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048662251970731554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83169150813056325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18207846338585643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25359220920653364,
                                   0,
                                   0.49173988262280444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63483272873548025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038061830466551858,
                                   -0.13959063762688428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047104766435358075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36710689769217408,
                                   0,
                                   0,
                                   0,
                                   0.39768069991942845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22653455448707363,
                                   0,
                                   0,
                                   0,
                                   -0.43434202771232305,
                                   0.17154720888993974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33127363166111101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0143521548325172,
                                   0.17518409145561004,
                                   0.32259730942273201,
                                   0.3702586134535728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071842949397437433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1703504963588188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69041410602709552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42960190204344512,
                                   0,
                                   0,
                                   0,
                                   0.40089961695915666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21752864528776542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12651761255370067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3387102704000034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41050482843164771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43296869454954234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034845666512398954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38407996537658423,
                                   0.13908741742495914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42241689605485255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34685310084179044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0093877018106395815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50916476578315839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93263356977975964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70415016838142341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17929525074006145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13546010473992948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083392642075123785,
                                   -0.13153085153503025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54108779463522938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27301005348006174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72218043129729903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50486204335989326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22326751239513859,
                                   0,
                                   0,
                                   0,
                                   -0.024158601722946704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088963115619591221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22773517271212071,
                                   0,
                                   0,
                                   0,
                                   -0.023740535427598426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28986392241666104,
                                   0,
                                   0,
                                   0,
                                   0.23939490129270755,
                                   0.27604979623398479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24238465282173868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39983963435711745,
                                   -0.076577610623432282,
                                   -0.24328973601324314,
                                   0.20516012754973448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55341325180359646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29917806970482785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4923190362941986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26695487920240318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15174556435717068,
                                   0,
                                   0,
                                   0,
                                   -0.35712828302924227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2294046774493983,
                                   0,
                                   0,
                                   0,
                                   0.12823929038069815,
                                   -0.1464759877633536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073241386216471416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26502310954534414,
                                   0.53307065910684304,
                                   -0.033121042430266062,
                                   0.21621939795428044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18996126876629266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039543691321851787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26655236023290407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047448138054075023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7298903583398314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0997683526173623,
                                   0,
                                   0.25454887964967798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080648654662270225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14565684702247583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45235525850093439,
                                   0,
                                   0,
                                   0.21179010174421348,
                                   -0.055039089935154578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084169055039864049,
                                   0,
                                   0,
                                   0,
                                   0.07328281572287873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74524923249095065,
                                   0,
                                   0,
                                   1.164481860158296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45479102001541349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41315060921182001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051702509596464108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47971941246766192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47723967456659733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27027364863432918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65118660019833585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086530767445826259,
                                   0,
                                   -0.058015930795665034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21837111189088121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48443091820906081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24522745453497535,
                                   0,
                                   0,
                                   0.15850510400908613,
                                   0.8398655898964239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59553334245842737,
                                   0,
                                   0,
                                   0,
                                   -0.17224104224563405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21389916755099725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014912554739977709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2328109055857811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40316761077943769,
                                   0,
                                   0,
                                   -0.38984835323860439,
                                   0,
                                   0.10271933934190643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27873436016736974,
                                   0,
                                   0,
                                   -0.45612269996465277,
                                   0,
                                   0,
                                   -0.47135119214665078,
                                   0,
                                   0.010842769660983714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23928151182306939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097266672811760019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28357995509201706,
                                   0,
                                   -0.30233912095303095,
                                   -0.0083421035543075131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41316847279665875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12641056758253927,
                                   0,
                                   0,
                                   0,
                                   0.79996111664442204,
                                   0.32836548483273931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30179340240627306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28545316778288954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46281969067495821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67145955142121749,
                                   0,
                                   0.49668703539425835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045512843993697205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060761111415851159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065815390352997799,
                                   -0.48898732139252843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30188900386675832,
                                   0,
                                   0,
                                   0.045903542639843281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15078145219992339,
                                   0,
                                   0.35016580704974964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41243457383775994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55929388543956926,
                                   -0.16386195918107987,
                                   -0.090563897992956638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00051270236174523476,
                                   0,
                                   0.93948270603459572,
                                   0,
                                   -0.76574740635988281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49126939970467315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33972031571321004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29674515549595565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084614564053552083,
                                   0.39513815506400601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53374281068328377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46492650376234379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025830402788869763,
                                   0,
                                   0,
                                   0,
                                   -0.10024233197216414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34093313161562172,
                                   0,
                                   0,
                                   0,
                                   0.29318281835971421,
                                   0.12254629877984174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17476694861828609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088836573808749111,
                                   0.066114013129907223,
                                   0.46479034858891882,
                                   -0.077817721642760573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03136719554679588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071840169469766901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022441754792648677,
                                   0.0341371754368585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016266287539058899,
                                   0,
                                   0,
                                   0.035015799089591862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031649634422655941,
                                   0,
                                   -0.10623611091391867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014874493393655569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23269650119363539,
                                   -0.044673738745791947,
                                   0.96342506549426687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13790495407493858,
                                   0,
                                   0,
                                   0.072492154652476201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29356977173007626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66061837930914868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2549010460589516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46320957503907906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43742011864507535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068947781591849056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.133617641556492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32358486918779217,
                                   0,
                                   0,
                                   0.46354257024887102,
                                   0,
                                   0.17423261512591923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53442006766147432,
                                   0,
                                   0,
                                   0.3626552589326914,
                                   0,
                                   0,
                                   0.070507890884992014,
                                   0,
                                   0.097113521768060901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063113173204371653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024717725201734958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90866574637784692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2546577993765099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25213040107059276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41934736165915271,
                                   -0.13486056006524272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21204890416526834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66949205193485273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087557151296825619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050280948798075133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56160083790263304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19490599444126083,
                                   0,
                                   -0.2378679415847014,
                                   0.1670719725866642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7545913212394324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045722727354324116,
                                   0,
                                   0,
                                   0,
                                   -0.21046315300103682,
                                   0.084921212589327527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5907904622412935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27165459207237619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36616966057826073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74245566884649417,
                                   0,
                                   -0.1002534531035921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093410451453751084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34230344528957884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15312940010982887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32521968194922679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38545287121373112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48544309298324428,
                                   0,
                                   0,
                                   -0.14389600603677327,
                                   0,
                                   0.41972222588372343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2512830566988874,
                                   0,
                                   0,
                                   0.19651321869843949,
                                   0,
                                   0,
                                   -0.022395609178378545,
                                   0,
                                   0.33381054504487978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057985416522186313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2694955544320457,
                                   0,
                                   0,
                                   0,
                                   -0.33779053712446816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0077102885687209584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46405511897030033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010691532172123569,
                                   0,
                                   -0.28507472722102745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47700040288609125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10516182170275963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39536913257624856,
                                   0,
                                   0,
                                   0.30708734364879992,
                                   0.042675763863109464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44187357823800599,
                                   0,
                                   0,
                                   0,
                                   -0.44808442832189171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055495421845435149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13761572833732505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16410507323556311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16574694968190951,
                                   0,
                                   0,
                                   -0.064732322734430026,
                                   0,
                                   -0.40473130730167106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22786316107350033,
                                   0,
                                   0,
                                   -0.034128447680742434,
                                   0,
                                   0,
                                   0.27274768226984536,
                                   0,
                                   -0.30631518843449029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59812760642184515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42014121534610571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068893767781232212,
                                   0.37988365553445153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19497115781912636,
                                   0,
                                   0,
                                   0.2638034986417519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19110442734155442,
                                   0,
                                   0.10762886810313672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50692607557194247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63538220405425549,
                                   -0.048867763558987934,
                                   -0.179327894383849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48316181496862876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40558060334606794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083601162724958267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38062573020153873,
                                   0,
                                   0,
                                   -0.29606303207970364,
                                   0,
                                   -0.19167425565526927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56589166920577461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07462046182860918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21269645278706434,
                                   -0.11667374215288173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2645389184005667,
                                   0,
                                   0,
                                   0.24654475666297804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15474881103159058,
                                   0,
                                   -0.57417348230123444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084191556617958963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069293346266823319,
                                   -0.65977642265195813,
                                   -0.09780186221976335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26200176184017027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2520035365478579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56340127829456044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59429169650451663,
                                   0,
                                   -0.22989950568729983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55156637850808798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63942730665821845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49630022550642661,
                                   0,
                                   0,
                                   -0.65670314332506452,
                                   -0.56607487658068856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54157314630977038,
                                   0,
                                   0,
                                   0,
                                   0.12687807487399141,
                                   0,
                                   0,
                                   0,
                                   -0.50579962713791304,
                                   0,
                                   -0.78498503275960085,
                                   0.46382337714970717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021082954737454994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11125515538705359,
                                   0,
                                   0,
                                   0,
                                   -0.00040695790489631012,
                                   -0.75695487444198406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31466308544033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31471081068922413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58131542781411838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23694353457988737,
                                   0,
                                   0.45273735462369019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27358846151753863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50718360821675779,
                                   0.25550581944357853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010093062697855334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18010843114992173,
                                   0,
                                   0,
                                   0,
                                   0.11796004375818156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080756792369259353,
                                   0,
                                   0,
                                   0,
                                   -0.10655826295913048,
                                   -0.10327321986596143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11096880820271197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40140723223960484,
                                   0.20873954892202548,
                                   -0.406301375797403,
                                   0.42052134122471446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1092275378384923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53745316388136211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48335557870749335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1524435595875214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24012485458186472,
                                   0,
                                   0,
                                   0,
                                   -0.16493287201532744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026044445277377693,
                                   0,
                                   0,
                                   0,
                                   0.0067772194138850939,
                                   0.27044799315231571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2778450451400285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45535358320547731,
                                   -0.2468047368285724,
                                   0.32804708416059619,
                                   -0.16593295401495825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032226443800656854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32055370139517969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10407424858934566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1723067389641639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36105177432202651,
                                   0,
                                   0,
                                   0,
                                   0.13656958078030229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49727170032366264,
                                   0,
                                   0,
                                   0,
                                   0.3862999335406555,
                                   0.47864415324341297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059705113734100999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16012681582831911,
                                   0.11576819186882198,
                                   0.0032098912200415851,
                                   0.15499949944555325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030298643292261673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34249316534033025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15102521179073211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088336665941080847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27077261487188392,
                                   0,
                                   0,
                                   0,
                                   0.13610520160544565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056319347307941012,
                                   0,
                                   0,
                                   0,
                                   0.26246771100605365,
                                   -0.59989237058296641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088012351189861171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08969512491150898,
                                   -0.50506824413734064,
                                   0.13455200711414622,
                                   0.27033505419153825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17498303261020762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23005193549343173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25235210744317049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060442682615258439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25763371137848717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022569240842592125,
                                   0,
                                   0,
                                   0.34794205502417996,
                                   0,
                                   0.27538816389136928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35278537078768396,
                                   0,
                                   0,
                                   0.12289545983448331,
                                   0,
                                   0,
                                   -0.50146190103623667,
                                   0,
                                   0.088679649784901851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51449534826827226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072690356266978451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88734004945787226,
                                   0,
                                   0,
                                   0.81802136819612348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1725507890884423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68242877231568955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17024182521868969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23927369319365366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5405913833153092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51382927534491096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038200872183673518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13677944958524979,
                                   0.19286043602955422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88482975912376172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4558395109257608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45807276027088673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33101910896661291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035125684842503155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17764920053129113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14814359167124699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039931540095430554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5148855695442337,
                                   0,
                                   0,
                                   0.4121050785054754,
                                   0,
                                   -0.01463094930226988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2142722765100899,
                                   0,
                                   0,
                                   -0.55742298567134851,
                                   0,
                                   0,
                                   -0.026556441526799184,
                                   0,
                                   0.059750800441292211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13632849302414235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36090725343890878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54321142574525194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65873674100682322,
                                   0,
                                   0,
                                   0,
                                   -0.24503825852034691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39581740265602972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14632954609799428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18127259181195854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17280312828738428,
                                   0,
                                   0.62252891551943401,
                                   -0.15181580090367497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16041573975084114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050682961862513434,
                                   0,
                                   0,
                                   0,
                                   0.33827990189656093,
                                   0.011115973784347616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78168532439534066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20616387724511265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23133237788158717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35763739611721779,
                                   0,
                                   0.20263042110559604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10132497546629085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91398151596522814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.364846819459684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19876408481319804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17328846900423983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07333295922776123,
                                   0,
                                   0,
                                   0.10431383354813392,
                                   0,
                                   -0.61271290832108205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26362643013693421,
                                   0,
                                   0,
                                   0.11101401530761873,
                                   0,
                                   0,
                                   -0.25363703735091953,
                                   0,
                                   0.49126504617000777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.008474388903978454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13456085163773918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55007504535823482,
                                   0,
                                   0.12585560368040882,
                                   0.24954861663626066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10717143429876629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48847941993145538,
                                   0,
                                   0,
                                   0,
                                   0.79612731516581126,
                                   -0.065322243968574653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12414345829205868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86870885833764189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19273606004793897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11512412121503304,
                                   0,
                                   -0.26276355006386237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1182769885113919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33971456916371134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53837512425611744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28159052665563361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21205950809875745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.349687468227595,
                                   0,
                                   0,
                                   -0.10726533236059714,
                                   0,
                                   0.21446347761642762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16311969646413174,
                                   0,
                                   0,
                                   0.037257280086233399,
                                   0,
                                   0,
                                   -0.19252797411212424,
                                   0,
                                   -0.29585871314419798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22328260690671736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45128410553846382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1328528629221721,
                                   -0.19555243517643728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45418890015539054,
                                   0,
                                   0,
                                   -0.0019523886692953858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31285866426471293,
                                   0,
                                   -0.36546079365399736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2051907451673966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085431642942696118,
                                   0.67437161998434958,
                                   -0.046871827378509756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1153193346770387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089745571361821888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28060991050122275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33536798778978255,
                                   0.18404626391276846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31416292915783595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71152997955849417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63943996181493701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16537943304792169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079668666853950049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091572635012702686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00022831181723014654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52473540764717419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026681129700832876,
                                   0,
                                   0,
                                   -0.53654000221151443,
                                   0,
                                   0.53182969389646462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16334185995471168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34373930408549697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089455441319806844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4122837003027337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47978038292084912,
                                   0,
                                   0,
                                   0,
                                   0.36898874722666342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13068722776280944,
                                   0,
                                   0,
                                   0,
                                   0.25026683197736665,
                                   -0.068037566819162953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21249388579436043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08424546372581504,
                                   0.21794869384653803,
                                   0.40942030162096604,
                                   0.22748278187199955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22757856686176375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020450612463639654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76324576963239876,
                                   0,
                                   0.11399361911115979,
                                   0,
                                   -0.01267659320952641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36890048040125534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037520532906578821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72114026393973885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31630803560814674,
                                   -0.018059043840276769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43062880947267723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067577585914766175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22185214232498962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52712847485136249,
                                   0,
                                   0,
                                   0.24910889095926755,
                                   0,
                                   0.45894565556110811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24274136002834992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38897245930654378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071279240219259202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34285416813631325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36214258608044153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7260976587643263,
                                   0,
                                   0.42907117070573225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26104181737952048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68758465177475492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035518627433955063,
                                   0,
                                   0,
                                   0.15174356656603846,
                                   -0.76089255218265328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34989522595227673,
                                   0,
                                   0,
                                   0,
                                   -0.058677546711887046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13517582138074252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5927589833043172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5905400225340075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2406692502767365,
                                   0,
                                   0,
                                   -0.18269729492968526,
                                   0,
                                   0.21840564571710114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33558145922543231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17323635689786288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21721794158337093,
                                   0,
                                   0.79366368974678692,
                                   0.14265801906129233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58347932683089576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6910869616936014,
                                   0,
                                   0,
                                   0,
                                   -0.57674306149107013,
                                   0.081463124955366201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25611798436712296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03944859152518148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036627008450972151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29889608260051459,
                                   0,
                                   -0.6608958605805334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35315784160153207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26368563690040642,
                                   0,
                                   0.13977548654734917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38017025515134739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04643367117709063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29757374329616115,
                                   0,
                                   0.49212533946773651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44550424113511983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37204936244037201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014809563897564396,
                                   0,
                                   0,
                                   0.009665339855997844,
                                   -0.12511887205294545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75194370900340457,
                                   0,
                                   0,
                                   0,
                                   -0.83909728121874638,
                                   0,
                                   0,
                                   0.39798994692525047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45714736610378137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50842560000355497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17125824943499104,
                                   0,
                                   -0.73762661161554455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36386382552277996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021352191381578844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52780208617425206,
                                   0,
                                   0,
                                   -0.08517107672045883,
                                   -0.43747550146486519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026601184171694433,
                                   0,
                                   0,
                                   0,
                                   -0.70037046417174786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061444992484715244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22686658432752393,
                                   0,
                                   0,
                                   0,
                                   -0.034481284520534811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066056268855927705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96784142816343932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049866282268853368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38114494336926713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23935851685706969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16793445979848448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052851388451268654,
                                   0,
                                   0,
                                   -0.24446891720767078,
                                   0,
                                   0.23779949436535941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34012929936056618,
                                   0,
                                   0,
                                   0.085227265455922407,
                                   0,
                                   0,
                                   0.46305971092551934,
                                   0,
                                   0.21504649602990128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4696178560966926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2143951499900148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16140206907053084,
                                   0,
                                   -1.1147059319712773,
                                   0,
                                   -0.58796189454051595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50279045534889355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19722853900374446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28837630769112138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72387820405321479,
                                   0.26788417052547492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28794416991256466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4428656811818984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6059474236212008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63326308191039626,
                                   -0.64598559682810353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2012361153232694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21398951824638257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012535740841033011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3295678678589456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36678584608165604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1187848058458831,
                                   0,
                                   0,
                                   0.0083453058781316966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72686450729619356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70988480566539858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40197671953832731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30418305461681139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25887404127327152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54458613890449437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29190693773178128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43125366154618572,
                                   0,
                                   0,
                                   -0.25950388082784354,
                                   0,
                                   -0.12453949825657296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26368905901161399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46134208191087578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60169914642008271,
                                   0.13562597654044004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036687352402125221,
                                   0,
                                   0,
                                   0.63743438892469406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076993947705297258,
                                   0,
                                   0.16444868174530938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35256214083528103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12381420942294176,
                                   0.19679646212229002,
                                   0.023766860425035258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16121677871821671,
                                   0.33659241690942721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31966435372570257,
                                   0,
                                   0,
                                   -0.1049393323560268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49170181663164692,
                                   0,
                                   -0.36439135950979423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58740123621690932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12918406305780752,
                                   0.075993231099530004,
                                   -0.07390323149982353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44616676245619902,
                                   0.5363933147475255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63145084185948552,
                                   0,
                                   0,
                                   0.23657324138962774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010016615979536923,
                                   0,
                                   0.17237421021143823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092490665383789222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13249371204224383,
                                   -0.045928386703798577,
                                   0.022105275073914771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93333388256251504,
                                   0,
                                   0.39711208807855297,
                                   0,
                                   0.48827972294993682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35962667536103599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29386938501797666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0570296337127152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29133744140858953,
                                   0.31629847818952828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62233931029369538,
                                   0,
                                   0.036022948018373246,
                                   0,
                                   -0.6237149893367161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52651684542494448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32068011842727207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085832494451721031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3807068967958675,
                                   -0.51813038571694081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48850217639474347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072888016744885376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40339777978543145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16184746988260362,
                                   0,
                                   0,
                                   -0.097700346594461987,
                                   0,
                                   0.47816741196060297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55161427858769752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15703771681279133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0506542579630838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3260707895421649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12399318758930872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16693281553147302,
                                   0,
                                   0.57658929804982195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27155997441262603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41759806585801007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10998934141698732,
                                   0,
                                   0,
                                   -0.64662893332680405,
                                   0.27845404165706833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077361384351455856,
                                   0,
                                   0,
                                   0,
                                   -0.43429021097788356,
                                   0,
                                   -0.076755248649529678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17347526829595916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054205326949383695,
                                   0,
                                   0,
                                   0,
                                   -0.020023810510080842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041654937691962962,
                                   0,
                                   0,
                                   0,
                                   0.5407555986074204,
                                   -0.14444366358244215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3058070938239042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26653591240870295,
                                   0.13079947788790386,
                                   -0.081179451407385944,
                                   0.097732384077347273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52870285105633896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41027279684765317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62613556268213211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6701781304330523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52768307663274405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1530614641367026,
                                   0.15550810294666434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11136671009292257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054608844755554498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20242347210816919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27883359636880617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33754285969357944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.007479573264806319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10765124869541064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5840456667518853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21538265196319886,
                                   0,
                                   0,
                                   0.47732981893967774,
                                   0,
                                   0.10712737068623004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28870848722560588,
                                   0,
                                   0,
                                   -0.21188614269842612,
                                   0,
                                   0,
                                   0.17902925284579141,
                                   0,
                                   -0.29722008880513234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049405304297829966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33234882382863928,
                                   0,
                                   0,
                                   0,
                                   0.077939763406612086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87826040669940886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17386978191754376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16249365791300244,
                                   0,
                                   -0.7293305142154165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025022872349750393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68887082262695609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14286044566498102,
                                   0,
                                   0,
                                   -0.27646413846830492,
                                   0.097275080246052692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18098707145012044,
                                   0,
                                   0,
                                   0,
                                   -0.16177911146687954,
                                   0,
                                   0,
                                   0,
                                   -0.56277048917017891,
                                   0,
                                   -0.17407471572890498,
                                   -0.87694008364422715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0081218973682574275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17833819697187248,
                                   0,
                                   0,
                                   0,
                                   -0.28899104971995637,
                                   -0.7096741597486137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6209186894978499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059134803360944205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85886497893937075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35136422764451769,
                                   0,
                                   0.026556652484148138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20868479787837818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067926085602140876,
                                   0.19093202197807577,
                                   -0.52454183017471823,
                                   0,
                                   -0.22594353756562197,
                                   -0.10826910103122268,
                                   0.37496320670678684,
                                   -0.17976750328244803,
                                   0,
                                   0.481876794611585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094339273845823149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86702208704470929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80415049500858582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25026836848024742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17549843923591801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24422352469829589,
                                   -0.59558932095584693,
                                   0,
                                   -0.25061465075385636,
                                   -0.11539421973452746,
                                   0.02320228571353139,
                                   0.31055131029150013,
                                   0,
                                   -0.57083218959164173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28748274806278173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23163018606001579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022655027422625623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53528199303127755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52896538471948318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36696762570614194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6182051183992292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53208401515270887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28910780110872325,
                                   -0.029734389935532665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.189626396150741,
                                   -0.31837217807430257,
                                   0,
                                   0.0047508001173867352,
                                   0,
                                   0,
                                   0,
                                   0.024921788690241732,
                                   -0.43099916385316839,
                                   0,
                                   0.082364406995814238,
                                   0.3018460229158394,
                                   -0.1060006330934441,
                                   0.48355535257412563,
                                   0,
                                   0.5022223958600387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82473599234180783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39267995180295301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49533624101835533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40181522176177153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059307180768911325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55448964889815755,
                                   0.47149819484047051,
                                   0,
                                   0.15525650919633885,
                                   0.07963862333055885,
                                   0.64725882741148932,
                                   -0.068251593891460793,
                                   0,
                                   -0.20716408923479088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041787727858087736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64866166035028505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3108925301588229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43287565891781421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18585622272546595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057358138042923543,
                                   -0.064567108028870474,
                                   0,
                                   -0.042312766125995743,
                                   0.7370943417733582,
                                   0.26014645786078677,
                                   -0.60414905886859571,
                                   0,
                                   0.33084379138851677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13759641250122814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42985449697666478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41559954858163861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14400836466333516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30248297207504932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01833782187143353,
                                   -0.11042843636433394,
                                   0,
                                   -0.92404914547234551,
                                   -0.55827869190506363,
                                   0.65785080497932569,
                                   0.074241700551432172,
                                   0,
                                   0.033977481792077234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18800948244740356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3605903488392132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3964195443058498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054269197767587124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81298157669491289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0051727053934372269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09499834884407099,
                                   0,
                                   0,
                                   0.18187170175891398,
                                   0.19621414348226626,
                                   0,
                                   0.49939264400700878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5318029217447805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57723319020226693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23230526144917074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26514871685075903,
                                   -0.1754785864023993,
                                   0,
                                   -0.59240288487619697,
                                   -0.017060196995547644,
                                   -0.59897533360312405,
                                   -0.51586655930596093,
                                   0,
                                   -0.20781280510529893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42358342723585118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33915646814496081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49723186856565521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28459024817755163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12346385318085781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35641355156962162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088787682682158822,
                                   -0.35996011762611096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12800976165850059,
                                   -0.71160251022765808,
                                   0,
                                   0,
                                   0.44844286225910535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42086387747915044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53903108139554134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4960571217376073,
                                   0,
                                   0.032111899593944032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11070354188656556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5220894471183728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11025454976996553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20116985853345379,
                                   0,
                                   -0.27918787923067551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19583564373305704,
                                   0.58723899047448269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25154594976012584,
                                   0,
                                   0,
                                   0.27064593109650931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1811497847565347,
                                   0,
                                   0,
                                   -0.09931831371348239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14896609439349956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14575259521808423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31800238247026213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085332971687630682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41775116305423676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83292136631309277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045551212709995771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06309742160272902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30723704506589561,
                                   -0.20673005416434803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6018614037287614,
                                   0,
                                   0.43272674279781354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16884684961524526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011083106521290728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43195971813684675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57113841486958039,
                                   0,
                                   0,
                                   -0.40081692538762087,
                                   0,
                                   -0.16755012562094151,
                                   0,
                                   0,
                                   -0.1642112925607877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57850426545424327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20818153930988437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040059408713451115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63037524323237359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69143552081931414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68187004063348167,
                                   -0.40086907867170141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18046395239493157,
                                   -0.035787500360088514,
                                   0,
                                   0.19490381479765609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078149378482464824,
                                   0,
                                   0,
                                   -0.27445605166479792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.193454238503591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094297576281007184,
                                   0,
                                   -0.14843573212520625,
                                   0,
                                   0,
                                   0,
                                   -0.70637987409604563,
                                   0,
                                   -0.12755021090697349,
                                   0,
                                   0,
                                   0,
                                   0.069346509887807717,
                                   0,
                                   -0.083565667565690588,
                                   0,
                                   0,
                                   0,
                                   -0.2928237418552444,
                                   0,
                                   -0.32462656368664627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16047224957468847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11759014470195876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30409888485323144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34591232978336495,
                                   0.81069062657579938,
                                   0,
                                   -0.63581813152876376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73001478859409308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017908295916902538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19106653463788667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1152808246568073,
                                   0.14818491960205432,
                                   0,
                                   -0.095238499653609754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26493175857515139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5237442212448381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25692778554367957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08747475573094507,
                                   0,
                                   0,
                                   0.41936118887893387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017760148647186697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13413423900547355,
                                   0,
                                   -0.024397335717926648,
                                   0,
                                   0,
                                   0,
                                   -0.35837803397272655,
                                   0,
                                   -0.21646667082682475,
                                   0,
                                   0,
                                   0,
                                   -0.40888872662895109,
                                   0,
                                   -0.017732814493059659,
                                   0,
                                   0,
                                   0,
                                   -0.31571041762001451,
                                   0,
                                   0.032835161972520004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24647665114981329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13599321326284103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52420275263483807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31200258240123985,
                                   0.93960218819956975,
                                   0,
                                   0.46105836655426785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58747917128556382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36301118752165723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23226406060587285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42756937647158472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31552222607379654,
                                   0.82230793727513973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37405760470330496,
                                   0,
                                   -0.37126256339158381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020784617946394364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35947510760854606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042228864458964593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33982101026176392,
                                   0,
                                   0,
                                   0.44316725234927823,
                                   0,
                                   0.28436267509037322,
                                   0,
                                   0,
                                   -0.23650632665853241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0036525239776522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67752891508696322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24466097094309489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040713947170411463,
                                   0.050089257609986802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40405618378723113,
                                   0,
                                   -0.47908275198950673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33836812208419126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21717372519203143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42285787359328614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97279608801176121,
                                   0,
                                   0,
                                   0.10176585231172397,
                                   0,
                                   0.063681746547896281,
                                   0,
                                   0,
                                   -0.16123796582969066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21374255088484792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39921332217938882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45543109206001875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27303168827751295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82232037233875865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10837570643148531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15796207548366636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071610835649113747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33032616897820771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28977455071719915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067637506790320323,
                                   -0.33970432688625263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36249258094447534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10585528733193073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34488326054746632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16889860190878023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54473072299768788,
                                   0.31643718967386003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65825320633033213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56161619685349495,
                                   -0.070859296617565737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67210855371655276,
                                   0.54823943012519538,
                                   0,
                                   0,
                                   0.55621523426409269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29506235215016596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29622439643418785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26065146579243453,
                                   0,
                                   0.14055359177358859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96318528368140399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010934567065135188,
                                   0.1792085344620056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26968600753825545,
                                   0.51072754303539381,
                                   0,
                                   0,
                                   0.75636012693201027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0050686192419861775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53682373953065976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19457626993052385,
                                   0,
                                   0.11400247683540002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16801236453772611,
                                   0.075449831293919065,
                                   0,
                                   -0.98257163238258571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77824650620208569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031075479096943651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21097663034924824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042899410802406418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53249742546419943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57012791321300915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5837056148805897,
                                   0.34440816727043111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47068558002534056,
                                   0.74088122632926978,
                                   0,
                                   0.44562082082356513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10968689896135418,
                                   0,
                                   0,
                                   -0.21321310604701357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43600621321776711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16013431814824802,
                                   0,
                                   0.29321182115669953,
                                   0,
                                   0,
                                   0,
                                   0.087865618427481459,
                                   0,
                                   -0.40502821745407092,
                                   0,
                                   0,
                                   0,
                                   0.50659073288991552,
                                   0,
                                   0.15224175766882381,
                                   0,
                                   0,
                                   0,
                                   -0.33020560305636604,
                                   0,
                                   -0.088694544614616455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035175818219558674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06254400555872644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25915220452476018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41956517172842561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17460234407387948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044265904705652531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58615601215550284,
                                   0,
                                   0.04567224736325283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32299739036570541,
                                   -0.023217371758420091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01631365424901083,
                                   0,
                                   0,
                                   -0.20412022838903407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31553379708207235,
                                   0,
                                   0,
                                   -0.41843992192330226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15621678586041751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22819954902211176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34995255337278469,
                                   0.33953793362899776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39863274239502816,
                                   0,
                                   -0.4388154825873552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035059573155176597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13124936826162759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19932259228033317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25351250768482597,
                                   0,
                                   0,
                                   -1.0528897742748757,
                                   0,
                                   0.0043916488143456341,
                                   0,
                                   0,
                                   -0.42669861543732995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25714228961188917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032665894876191669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12384421342273286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43538136872934674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40287240124656276,
                                   0.41963453661271977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021074126357965781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1608281291695432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46999985976100911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36807390750133412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17441773469992156,
                                   -0.20879831630133691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37631195955220792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1277904232489176,
                                   0.089045331856240195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13416470465660249,
                                   0,
                                   -0.24086948388598162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3470221740690182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075655583565948689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34758730722221454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23080307930505542,
                                   0,
                                   0,
                                   -0.44201856758860869,
                                   0,
                                   0.60530729807363526,
                                   0,
                                   0,
                                   0.60125046771960888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59617794409421365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46051814640606492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78506087901205146,
                                   0.6548048246710344,
                                   0,
                                   -0.6434526725225046,
                                   0.056520085643055842,
                                   -0.10259917232971191,
                                   0.29724758984877964,
                                   0,
                                   0.18806670835846415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057348743135838084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0099012861456838699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063176255473468834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81125822171498496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27177489454685261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0052889059240856656,
                                   -0.55181112472099514,
                                   0,
                                   -0.16726822533639865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75245893979838985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40182943416237915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0088740349425813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22107027190407039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39327683592838003,
                                   0.049813671927865455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93677389442912273,
                                   -0.19446889295900138,
                                   0,
                                   0,
                                   0.2098223558575075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14507174861678102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0032080920379953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02274359569050062,
                                   0,
                                   -0.30869086173454136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18332478375290934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076282222221714033,
                                   -0.66978542990843892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73553363100206703,
                                   0.12753711254250519,
                                   0,
                                   0,
                                   -0.64250903496905587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18514994943440322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37361527283638457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51852329566583544,
                                   0,
                                   -0.11675160175295403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13130213588216572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23839190967680687,
                                   0,
                                   0,
                                   0.76705743764437695,
                                   0.076085648505002587,
                                   0,
                                   -0.49553483630957357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26870779254373739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11394766922056657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031940332943774713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0026952148803778466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036181222188852079,
                                   0.45102277280193792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25459026690865955,
                                   0,
                                   0.10713964952139723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24486726444296225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30997104961977573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21147111812027919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030659971610492016,
                                   0,
                                   0,
                                   -0.48731939246477413,
                                   0,
                                   -0.84970561607754158,
                                   0,
                                   0,
                                   0.68803696710505369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058373417464807516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54608606600812859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21908929814213207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48944191453498592,
                                   0.2226881299470477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29664301935896958,
                                   -0.19601452517444573,
                                   0,
                                   0,
                                   0.14994525108925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97040661609631895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38200614598067029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92603638671500232,
                                   0,
                                   0.15948128375232157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57552525322765802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34176423164967551,
                                   0,
                                   0,
                                   0.0013661636939100927,
                                   -0.33813965010663793,
                                   0,
                                   -0.43423397405833231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065665024544730444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3506336397570109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3490166392601734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24355257771728728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026080028255425269,
                                   0,
                                   0,
                                   -0.14607503316383641,
                                   0.62395794743945088,
                                   0,
                                   -0.29792407542586313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10661732304329735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39740623965841015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52084816493492669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76203310704776472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056390220360848411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45532079740141629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088034493315390858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13765065733352666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42674451699684884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30568941077948664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46006919899882637,
                                   0,
                                   0,
                                   -0.46308168457491161,
                                   -0.40330437275693976,
                                   0,
                                   -0.33628985753461821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34300569791866647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24539278210489149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16379822343895611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025568311818570544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7315633857752043,
                                   -0.18249790314239878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41657190703833336,
                                   0.099459653241611656,
                                   0,
                                   0,
                                   0.030208273014814511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04327744205352986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13903712562885465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40100545831466849,
                                   0,
                                   -1.2902277796252972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27942314109892463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17345854114244208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48937325059173165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44082385201096613,
                                   0,
                                   0.19563114506239929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10957048530593952,
                                   -0.29383406218354313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2479678169791385,
                                   0,
                                   0,
                                   -0.053616342056316026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10243053621178369,
                                   0,
                                   0,
                                   -0.066903896710714172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49201260860077789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40998834309469739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15091382228635802,
                                   0.08961842169729034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75347460524167253,
                                   0,
                                   0.40215632644070781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084642410368019061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26327907354048835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30800543231729832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2892978152378845,
                                   0,
                                   0,
                                   0.1619169740648779,
                                   0,
                                   0.71812547524836223,
                                   0,
                                   0,
                                   -0.17988167284702083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14324001838502065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77646463323903403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08775922417623451,
                                   0,
                                   0,
                                   -0.50537437096843396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29372372570975924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55589994331080272,
                                   0,
                                   -0.071759634952168555,
                                   0,
                                   0,
                                   0,
                                   -0.0035789367357441093,
                                   0,
                                   -0.084673720894080207,
                                   0,
                                   0,
                                   0,
                                   -0.15661929147336973,
                                   0,
                                   -0.15768550819587313,
                                   0,
                                   0,
                                   0,
                                   0.07605242513615959,
                                   0,
                                   0.33392408013325525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28379850013946339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042993846832486263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28318042402395338,
                                   0,
                                   0,
                                   0.34596880886853859,
                                   -0.24232462610481878,
                                   0,
                                   0.075771920125768222,
                                   0.082698871236032936,
                                   0.40343036550504835,
                                   0.36873623168136827,
                                   0,
                                   -0.36649558720466968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67204476840075367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020177517135827428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38480328303041145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8705081823690628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56648016044011018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14589839645573635,
                                   0,
                                   0,
                                   -0.27467054754160569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68977911873052011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12601046199263796,
                                   0,
                                   -0.13473304435277508,
                                   0,
                                   0,
                                   0,
                                   -0.32534720638421177,
                                   0,
                                   0.17424597233138539,
                                   0,
                                   0,
                                   0,
                                   -0.12002360616375086,
                                   0,
                                   -0.24050782970011153,
                                   0,
                                   0,
                                   0,
                                   0.37901797241508611,
                                   0,
                                   -0.02857250803996576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058769299566556077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17122015113590369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087974756042910385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21237280215445248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31427432818457279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16745531098737715,
                                   -0.24593928951184679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25052655478538377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040365798068384362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46176999668997987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25337893492094621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32737914384643874,
                                   -0.56444623624312906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042270798082507006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2008578457512801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099869039526126038,
                                   0.32286281258561472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0082750461577133921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82799133797428637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28636167985372529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12232790450399225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2462308406340013,
                                   0.02049872399395071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10408424274582118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47572990781240937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24741087094102981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087451725497151744,
                                   0,
                                   -0.65427111214795086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37263288001842143,
                                   0.17889533557133896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071061286146382713,
                                   0,
                                   0,
                                   -0.077792769166911441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1554892774972193,
                                   0,
                                   0,
                                   -0.13936359773658974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20089186197341666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66464771519500787,
                                   0,
                                   0,
                                   -0.27021932997798637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1098647746448386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20338010845065346,
                                   0,
                                   -0.20843045862774168,
                                   0,
                                   0,
                                   0,
                                   0.025738183406254139,
                                   0,
                                   0.32655115204164498,
                                   0,
                                   0,
                                   0,
                                   -0.052558292449697376,
                                   0,
                                   0.13847590946091237,
                                   0,
                                   0,
                                   0,
                                   -0.20460204948987465,
                                   0,
                                   0.33986490758614102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10571949429856337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27075402594324632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13136729575172601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12045448205361201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28274031574418951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42940031393284206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25103190656115171,
                                   0,
                                   -0.085621147347728854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49007790459859724,
                                   -0.063458469164871023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18416232706605307,
                                   0,
                                   0,
                                   0.19240182835499914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3261954558796803,
                                   0,
                                   0,
                                   -0.39391617516246802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27222236935117861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24123257917929969,
                                   0,
                                   0,
                                   0.071285281657284927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0774122284536303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20865158430149666,
                                   0,
                                   -0.056503996064539097,
                                   0,
                                   0,
                                   0,
                                   -0.18614509967648846,
                                   0,
                                   0.23831445894173009,
                                   0,
                                   0,
                                   0,
                                   0.11047555061536606,
                                   0,
                                   0.36296433432099384,
                                   0,
                                   0,
                                   0,
                                   0.1260755895352132,
                                   0,
                                   0.0041049286659889505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63633402504346825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015737251059615209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47700327156378208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80780930670963669,
                                   -0.029644136805427962,
                                   0,
                                   0.041057788885945197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57635493686559458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2046057226651923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62646153103067581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25097375131819977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52598582345191203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26221638880014592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13791399613519773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16200578749532044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73913970912780591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14483311104845659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32452269452903354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55915748430207135,
                                   -0.5464547325273309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40621124672782299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1114015236071402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013010220452619022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27937783768987945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040179302675561863,
                                   0.072007144818732841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19090752117282353,
                                   0,
                                   0,
                                   0.17276895497459452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.115665087601733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28545678004196012,
                                   0,
                                   0.55909613728283114,
                                   0,
                                   0,
                                   0,
                                   -0.091742355370864059,
                                   0,
                                   0.023880408267426829,
                                   0,
                                   0,
                                   0,
                                   -0.18489906193888084,
                                   0,
                                   -0.30201197026602861,
                                   0,
                                   0,
                                   0,
                                   0.20206283429949976,
                                   0,
                                   -0.074559902695530436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12717720692520582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57147192664096647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052193199913417324,
                                   0,
                                   0,
                                   0.16051818854313377,
                                   0.49528061293935993,
                                   0,
                                   -0.30415374909363585,
                                   0.58823742105315235,
                                   0.037280002687968883,
                                   -0.12659003034684876,
                                   0,
                                   -0.61844909757274369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82347583389055035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2421507486562372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58890731756390358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2834117333594221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2137634947897305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36520659706233577,
                                   0,
                                   0,
                                   -0.098488949904537174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21624573105247086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056831625948218556,
                                   0,
                                   -0.3748778451479674,
                                   0,
                                   0,
                                   0,
                                   0.19547157361678674,
                                   0,
                                   -0.39204461450598843,
                                   0,
                                   0,
                                   0,
                                   -0.29502858718010161,
                                   0,
                                   0.19151923794670203,
                                   0,
                                   0,
                                   0,
                                   -0.10214022395069849,
                                   0,
                                   0.002842027114801326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083047964848058667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57691666878218451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024464428385528723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.108180637532289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.345430632053222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26445786804088794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01046958574948216,
                                   0,
                                   -0.18211176316116962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15910338134109925,
                                   -0.11821705348045027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018149471600600695,
                                   0,
                                   0,
                                   -0.65939768204468829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34948639171503471,
                                   0,
                                   0,
                                   -0.19214032603450978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36370297036256027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58862327072887877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34292670567940353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12428763227085653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27609089243794777,
                                   0,
                                   0.094624848882433832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23234874635345507,
                                   0.2527490976922761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21269950509340424,
                                   0,
                                   0,
                                   -0.033444826174887574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084847890978464388,
                                   0,
                                   0,
                                   -0.0082534828729284547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5136160963944294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50410456118804192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88488815957464761,
                                   0.0022990323471173968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25626963323891028,
                                   0,
                                   -0.34879429385480415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31899466413923194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34630905189254946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095520276390821363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41386700424928247,
                                   0,
                                   0,
                                   0.028543692841851646,
                                   0,
                                   -0.048360423952532386,
                                   0,
                                   0,
                                   0.17483538796931145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50903136754433176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086696148275102039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27845364452586241,
                                   0,
                                   0,
                                   -0.0028943569224404771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20136938543829988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46309251904541204,
                                   0,
                                   -0.085715355733038498,
                                   0,
                                   0,
                                   0,
                                   0.22648847816978429,
                                   0,
                                   0.08910200577064753,
                                   0,
                                   0,
                                   0,
                                   -0.45857158271313081,
                                   0,
                                   0.28447732478811527,
                                   0,
                                   0,
                                   0,
                                   -0.065407868795161542,
                                   0,
                                   -0.44991106028654165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045958257852417875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27744832523322022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1544811596199559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37946584763736535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40316963050473037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28923666633186257,
                                   -0.063370904747975784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35231382478915779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025279042967939484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42323162190589708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40375012956653838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048732641760493141,
                                   -0.36947001822366832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042748891010897024,
                                   0,
                                   0,
                                   -0.17742513475584151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13738019397357798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19553726986821152,
                                   0,
                                   0.25767126524368411,
                                   0,
                                   0,
                                   0,
                                   -0.21640420530427187,
                                   0,
                                   -0.019639373474439593,
                                   0,
                                   0,
                                   0,
                                   -0.030804272810962981,
                                   0,
                                   0.6581262532015667,
                                   0,
                                   0,
                                   0,
                                   0.38203328477579174,
                                   0,
                                   -0.15014552385637955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41202035731893277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15108116016667861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028553057359851208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66722265834066863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68815104800858462,
                                   -0.79018893326315154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58439976508834635,
                                   -0.20686678248259288,
                                   0,
                                   0,
                                   -0.11678399731853678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091395170528058067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53941459041183815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45694593574110298,
                                   0,
                                   0.45901517155088573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10241428898316957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24482591956792593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38468590974581601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083588866059401828,
                                   0,
                                   -0.3405233690890353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21986514323887829,
                                   -0.24452432743941011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09804878942548205,
                                   0,
                                   0,
                                   0.23794752233906571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48183132879486945,
                                   0,
                                   0,
                                   0.33265076256176934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3761139378972469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65582215132811883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11017309791312521,
                                   1.031000403354513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48834391575290687,
                                   0,
                                   -0.022217266611566089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12827604760174025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25187203984133555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36312196459518564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19065467085267943,
                                   0,
                                   0,
                                   0.24583084340163663,
                                   0,
                                   -0.08080855091388757,
                                   0,
                                   0,
                                   -0.34396799068036515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036839208351221286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24116508409541498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17854195366659506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47291181020874773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052471046414356806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75617494724472312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21612740204859826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35101620343987994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08535777789562643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14993260985822249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13675079040435692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096509215684361868,
                                   0,
                                   0.0071739171386573375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10644206415044814,
                                   0.48126714042389152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61694080786890348,
                                   0,
                                   0,
                                   -0.33130484970836649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17800551279423535,
                                   0,
                                   0,
                                   0.39385817211926888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14842819853921338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31980574652349114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065214358362759281,
                                   -0.27822938211312537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30087216075129658,
                                   0,
                                   -0.62460492458529482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10509394456700996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053131037938269315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72323859326595796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33594904265334452,
                                   0,
                                   0,
                                   0.095672487445927878,
                                   0,
                                   -0.37926755594620548,
                                   0,
                                   0,
                                   -0.14601471493532533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39297998409550006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017983334873562639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45038826055098735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060454349443544809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13909074379281516,
                                   -0.25103048372212783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51765744459717522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23244050860049559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12373102349751756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095487202206108568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5916746478742162,
                                   -0.12095150574221347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37884143093407679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096532527840810817,
                                   -0.3274760849142368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31193954647201327,
                                   0,
                                   -0.041969721963678402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47519893507535826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36827324853404764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5318710524123107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20476703003769225,
                                   0,
                                   0,
                                   -0.037849789337531539,
                                   0,
                                   -0.29002259245022338,
                                   0,
                                   0,
                                   -0.51672165074468945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38590705190772001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37908396619938733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3058590735106041,
                                   0,
                                   0,
                                   0.17664087839538081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15256033296666116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24994383516223082,
                                   0,
                                   -0.066704701442577063,
                                   0,
                                   0,
                                   0,
                                   -0.062095178170710835,
                                   0,
                                   0.5929168238392557,
                                   0,
                                   0,
                                   0,
                                   0.19677252164181924,
                                   0,
                                   0.084245786181315549,
                                   0,
                                   0,
                                   0,
                                   -0.36711707325787118,
                                   0,
                                   -0.0494045133357272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42654077816645564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25267054112075543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028878988817963847,
                                   0,
                                   0,
                                   0.50179095905174775,
                                   -0.049616086701766093,
                                   0,
                                   0.54639679031334376,
                                   -0.650470958401687,
                                   -0.048632154156128288,
                                   -0.44492393324230828,
                                   0,
                                   -0.094509726201624733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80196853194507045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25094793020296202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26103702888673513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26439845189271888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45512200854498064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055491660122036018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87308579064926417,
                                   -0.066921682233635038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2393644849624777,
                                   0,
                                   0.71528349400235613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27235551777089129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.001255813090269689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3607715245642254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26626732161543792,
                                   0,
                                   0,
                                   -0.30708528386755257,
                                   0,
                                   -0.2806389117737077,
                                   0,
                                   0,
                                   0.15331158983759982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42711597485267361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34802444336742561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49529980754147213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30929853477728952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38026322011197627,
                                   -0.40707336179252351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1931747077894323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45547340949658055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2539067931855199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074028321885643872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18272890222475349,
                                   0.024340918631158139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079007468201737874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43884124815854009,
                                   0,
                                   0,
                                   0.22496284278101628,
                                   -0.15646936902433717,
                                   0,
                                   0.06091095598196055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70717935566562296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43671712497287468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17762489106304877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038742782487600672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00720285653078203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28505634743003194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032800896639436701,
                                   0,
                                   -0.4880044046445603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32882850830613974,
                                   -0.33853108169582269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48046828232420408,
                                   0,
                                   0,
                                   0.13863862341767544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42120204710803727,
                                   0,
                                   0,
                                   -0.070828620370587736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15078467878605822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38537681699246817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043372542400574546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024608357001910407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64708218893204983,
                                   0.41517063722785208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29591650550935777,
                                   0.70688113966458843,
                                   0,
                                   -0.76823989226380529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41006951502287792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14289598456118602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64234094777989215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19948229004926332,
                                   -0.35584802575108432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63073242919395878,
                                   -1.0633514654638139,
                                   0,
                                   -0.07187943029021103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24553361113703065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039917176128249292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40880225431607531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35352449255748164,
                                   0,
                                   -0.22365157893810655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17685136379453525,
                                   -0.16382458194337621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40120692839403777,
                                   0,
                                   0,
                                   -0.4257358895766743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24117647590599875,
                                   0,
                                   0,
                                   0.35081550175460796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12012673194096191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25650167477110353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22403552043777675,
                                   -0.20578605904623654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19274563020151955,
                                   0,
                                   -0.28634303698598429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92552440089113897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29832761024870419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28690699235294648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37479538222811376,
                                   0,
                                   0,
                                   0.23541073393112183,
                                   0,
                                   0.036757922143221489,
                                   0,
                                   0,
                                   -0.054686941216843643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26756096854707206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059580574599761627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22628639805093531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43017872494907361,
                                   -1.2418414353293639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22806934608417656,
                                   0.22073999017482687,
                                   0,
                                   0,
                                   0.24564426377158363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11419811173295338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25565987702824378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17668405244540927,
                                   0,
                                   -0.32694287115933685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10581188024820919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21393375278740195,
                                   0,
                                   0,
                                   -0.30228642047541937,
                                   0.51314442874986455,
                                   0,
                                   -0.27215190416098739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0079904096387898721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1543525092804994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70027616548754323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05151778152959785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54756020618916257,
                                   -0.28021250327384217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11717793869462106,
                                   -0.60318457211913445,
                                   0,
                                   0,
                                   0.33697806426893051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81983865256599109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17964011272021491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83357409593886889,
                                   0,
                                   -0.24446816060224102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20357245337049365,
                                   0,
                                   0,
                                   -0.42377607035770309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17559946494813053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3697784436774606,
                                   0,
                                   0.27875602046992526,
                                   0,
                                   0,
                                   0,
                                   0.2409340486556486,
                                   0,
                                   0.23650524836807962,
                                   0,
                                   0,
                                   0,
                                   -0.21233292058184003,
                                   0,
                                   -0.192415120224807,
                                   0,
                                   0,
                                   0,
                                   -0.26829602460979318,
                                   0,
                                   -0.42489139802722814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066472214515738759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00075795428657000246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28402205420814003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52014122069046476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19900227714700913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018860148302859696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36368797136173558,
                                   0,
                                   -0.00066777543386959196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43348444781187551,
                                   -0.14674118377441986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091587195986726821,
                                   0,
                                   0,
                                   0.19069168789084512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31270788472717326,
                                   0,
                                   0,
                                   0.45290239930581222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011226411738728055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30948213529301821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56642886427152006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19411289335367585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46386181006682636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43518426865572246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37569430094762535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57519276964800814,
                                   0.5000809834222526,
                                   0,
                                   -0.43159404725530848,
                                   -0.52611719329177409,
                                   0.12731960966773478,
                                   0.22302767609315116,
                                   0,
                                   0.70181172377867163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079979005281963667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28925236886410699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30462038244309131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0024629168269888757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6025477328218487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69375894020919027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6055152299275226,
                                   0,
                                   0,
                                   0.027852872598872543,
                                   0.039934390658102198,
                                   0,
                                   -0.19200688110779657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10715982968489171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31333359584393117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056138109703399386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020224795263915601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38142528662645458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71587109568872676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20181512579012467,
                                   0.9819057132271729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080571220556252682,
                                   -0.90644319460804401,
                                   0,
                                   0.27699502087811989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38789630477704062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26372356905526456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27040073629683797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91680999204264535,
                                   0.44227906486404894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0036311495258544019,
                                   -0.56156292114156536,
                                   0,
                                   0.38672150786428028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36068984648060415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043048651534865694,
                                   -0.14829139055548618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032672591996767052,
                                   0,
                                   -0.20883679788502932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62492817901387721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0092247698324635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025300163946871117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1477313043968243,
                                   0,
                                   0,
                                   0.097778889875857047,
                                   0,
                                   0.061233111328261897,
                                   0,
                                   0,
                                   0.30431939448101714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34684845310372125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042727550575689381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8864205953313864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73822241944459566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43652215286186186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14431277154869596,
                                   -0.15826637690629763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20500739473190605,
                                   0.42381726121363023,
                                   0,
                                   0.66812855056570497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24717383200977977,
                                   0,
                                   0,
                                   0.11214989814351939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13547483971504709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032522412400664752,
                                   0,
                                   -0.46091442424528678,
                                   0,
                                   0,
                                   0,
                                   0.13052812721996471,
                                   0,
                                   -0.042252981886193641,
                                   0,
                                   0,
                                   0,
                                   0.31810907842142561,
                                   0,
                                   -0.22322199587939301,
                                   0,
                                   0,
                                   0,
                                   0.30017072438502734,
                                   0,
                                   -0.49428902063528829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17569298145644727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18970335762391799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35121277328260075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3523941527250754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30541925299179001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47470092017947518,
                                   -0.016385857474729707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22281056682325995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029043098665033587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31202549093223553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20886031535351435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30912581739551687,
                                   -0.51951768161728762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30221535761392537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35622967823934554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097476320998841223,
                                   0.11026843549353617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40157206631769793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01877417761773276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092135348681962395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67641931310005821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14840284423612404,
                                   0.33232141815019822,
                                   0.20017387820569951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75280730950645214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42408601371795296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021061626776427859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014468137737377394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18915543243587543,
                                   0,
                                   0,
                                   -0.21748864085692651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36003974857327797,
                                   0,
                                   0,
                                   -0.24226272139307928,
                                   0,
                                   0,
                                   0,
                                   -0.12080239536652709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036680048240404751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45397517786825647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0979413332235122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89014017107118548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05661176934122026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30614233581328409,
                                   0,
                                   -0.97873504502885322,
                                   0,
                                   -0.91307726148447177,
                                   0,
                                   0,
                                   0,
                                   -0.08036787520756318,
                                   0,
                                   0,
                                   0,
                                   -0.18735416885862216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67486371774423615,
                                   0,
                                   0,
                                   0.20269066045649886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20703134804553175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27173683013731642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23128628524931844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1677555015283331,
                                   0,
                                   -0.3825570899946133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25420589936321919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43675247962628283,
                                   0,
                                   0,
                                   -0.58181501482006048,
                                   0,
                                   0,
                                   -0.0065897844290903314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24776285127337666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034838250152053246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0036689716870330485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48345168293309965,
                                   0,
                                   -0.072274469104418246,
                                   0,
                                   0.21792912795881383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37037753092477421,
                                   -0.3116689741409901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36732291233022502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39600127575422039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11043341330354033,
                                   0,
                                   -0.012412703475345441,
                                   0,
                                   0.41703811622661546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17221271897715407,
                                   0,
                                   0,
                                   0,
                                   0.58036079423038389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030777799670129863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35913196364375427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84611012281326159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0610626958008655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18079880011472799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27010288757847717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66012666494605787,
                                   0,
                                   0,
                                   0.090081364062137292,
                                   0,
                                   0,
                                   0.09065142834282397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26047453402092519,
                                   0,
                                   -0.24471296406444429,
                                   0,
                                   -0.25502200910856426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034452868622529567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33123350894882597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0057773167299909577,
                                   -0.22529394502220476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2587750428666763,
                                   0,
                                   0,
                                   0.14432994962919293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07224243722247764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0049317094605485501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35549484945397097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60885162732157661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18812054463422742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40437533764439193,
                                   0,
                                   0,
                                   0.34201304487343548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42637793159757875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28276311622350214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085417008082674328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49846405711071085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24373167002569351,
                                   0,
                                   -0.069217235036017732,
                                   0.74986662597842291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7309003136532205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24200726187718785,
                                   0.461481916935227,
                                   0,
                                   -0.54459001942252927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72263945635105531,
                                   0,
                                   0.09917043659589439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090769204604412457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44907626365012587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17018208647106745,
                                   0,
                                   0,
                                   0,
                                   -0.22597342484494723,
                                   0,
                                   0.052827802941770502,
                                   0.48868621183299121,
                                   0.42453041018339571,
                                   0,
                                   0,
                                   0,
                                   -0.88554822978623726,
                                   0,
                                   -0.049003109756678813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71682171779790893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39970681537274672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11155062206732502,
                                   0,
                                   0,
                                   0.57941805985102446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4659288806969199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5315643658731789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037001704475182862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52227407744763998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37297214118581601,
                                   0,
                                   0.21767577278194472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46381040222978509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086031628856899606,
                                   0,
                                   0,
                                   0.073855302174809206,
                                   0,
                                   0,
                                   -0.16338356718987573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04624608742042971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33828946569915119,
                                   -0.49221938326819359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05691157992406129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01841231611598243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99045555415143782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52862193400154889,
                                   0,
                                   0,
                                   0.10141889913854371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081136007341651772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76896518617322573,
                                   0,
                                   0.38793700039046619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04672587441226117,
                                   0.89005376387369473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51826508608787658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15100575472091249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095634715188722602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21861629559239359,
                                   0,
                                   0,
                                   1.0702725428356774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29259844123088591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0044230282815229394,
                                   0,
                                   0.50590892043571034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24376120197199527,
                                   0,
                                   0,
                                   0,
                                   -0.091670453882058148,
                                   0,
                                   -0.29913659663472753,
                                   -0.15888225089717883,
                                   0.93703023658985274,
                                   0,
                                   0,
                                   0,
                                   -0.12975855373366221,
                                   0,
                                   -0.83883160143850766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61165142660547289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079911408587034077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27272543777392322,
                                   0,
                                   0,
                                   -0.61626813886439502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030927656945655274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0020620708632776222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78566071747684396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15441324751482391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53021369346315128,
                                   0,
                                   -0.25936809984078446,
                                   -0.081772839850286369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09927225241634538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39934357147696858,
                                   -0.062338663476673745,
                                   0,
                                   -0.27880993955225392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46159944576869349,
                                   0,
                                   -0.082667771189456507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48888261922712295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77573586717761067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089519390724600356,
                                   0,
                                   0,
                                   0,
                                   0.3369148424642226,
                                   0,
                                   1.014200393273831,
                                   -0.55717382443323493,
                                   0.61080016719280894,
                                   0,
                                   0,
                                   0,
                                   -0.47396902516261513,
                                   0,
                                   -0.16598175274505469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66238289534911388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42192457009300172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011390026845846238,
                                   0,
                                   0,
                                   0.28801113744231804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2336081506416105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20068087852215166,
                                   0,
                                   0,
                                   0,
                                   -0.86845573348156757,
                                   0,
                                   -0.16256705422103701,
                                   -0.37064679227721686,
                                   -0.026057282800632232,
                                   0,
                                   0,
                                   0,
                                   -0.61404627552637803,
                                   0,
                                   0.16620620218822496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21331813746154554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44407370246675304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16063383114275345,
                                   0,
                                   0,
                                   -0.72359080475670146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53021715315773432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24989541410978705,
                                   0,
                                   0,
                                   0,
                                   -0.13815465956311013,
                                   0,
                                   -0.13655603384743695,
                                   -0.91774459070759662,
                                   0.01281449379999397,
                                   0,
                                   0,
                                   0,
                                   0.25030009310530416,
                                   0,
                                   -0.47795582363103906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071498456827160675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32703175934610379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31601323488824962,
                                   0,
                                   0,
                                   0.42779568645307509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13172172800773155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41322672999208654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68206265925311971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21787138122998331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21675243584123,
                                   0,
                                   0.1849177768818796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15755611893635568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2994785827777231,
                                   0,
                                   0,
                                   0.16584106657450179,
                                   0,
                                   0,
                                   -0.22328274886192112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20861509917731175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49941792800694901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31790468062825267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27019450058628952,
                                   0,
                                   -0.051858916768306708,
                                   0,
                                   0.66611484174755431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0098926823977840486,
                                   0.17395460739321317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049751089535274198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1941545084194285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2152532576481202,
                                   0,
                                   0.0032371291402760183,
                                   0,
                                   -0.11507080797049871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41515822529863677,
                                   0,
                                   0,
                                   0,
                                   0.33554436324821235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21955205000503278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060566018480584322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19701294095320673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79016971854165263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0067355649512937993,
                                   0,
                                   0,
                                   0,
                                   -0.44381071957067963,
                                   0,
                                   0.60190432294621221,
                                   -0.21755871261191648,
                                   -0.30922137047338277,
                                   0,
                                   0,
                                   0,
                                   0.21905650651511174,
                                   0,
                                   0.25634896814192026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88436473516759362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41286365458645524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38067714864174784,
                                   0,
                                   0,
                                   -0.49161401530208432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68300660464222918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5199902593142488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50630236068081669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095699171907022956,
                                   0,
                                   0,
                                   0.096440912532720524,
                                   0,
                                   0,
                                   -0.17958740255542832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39870421426374586,
                                   0,
                                   -0.15256802747114895,
                                   0,
                                   0.27050782824878961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12355735280243429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11303937366760999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25674419522500225,
                                   -0.23297944355762837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014501780871360873,
                                   0,
                                   0,
                                   0.13670797677385096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30767335411116331,
                                   0,
                                   0,
                                   0,
                                   -0.022733300165209608,
                                   0,
                                   0.079084599330739913,
                                   0.3245138323600803,
                                   0.71550475212216624,
                                   0,
                                   0,
                                   0,
                                   0.5535856647325671,
                                   0,
                                   0.11277654155394452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22886894209729314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75101652477012382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2956770911172073,
                                   0,
                                   0,
                                   -0.26955659123408887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45303274185639242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47768198985203347,
                                   0,
                                   0,
                                   0,
                                   -0.33143073074438978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27342088425146149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40934111579487276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6278808107849938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15943696469820662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76693219026337045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14485014952285497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.141873468926804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27491904884773305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14377905259252766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11984894970352221,
                                   0,
                                   0,
                                   0.28596001471214122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42227428099845005,
                                   0,
                                   0,
                                   0,
                                   0.54395164543336638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1985077010413623,
                                   0,
                                   -0.0292854633947493,
                                   0,
                                   0.1400506827692464,
                                   0,
                                   0,
                                   0,
                                   0.38695621710276429,
                                   0,
                                   0,
                                   0,
                                   0.13837597970440685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1283353297661094,
                                   0,
                                   0,
                                   -0.81747384845518622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098120066275855913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47699043121141571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12085979162759854,
                                   0,
                                   -0.20951237854015659,
                                   0,
                                   -0.50554271748683688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24343438324000871,
                                   0.045749406884752999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22274619929000608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40026612839087111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011425394014650758,
                                   0,
                                   0.41857492198373203,
                                   0,
                                   0.04752852804354344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53287694761693472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041668478727328921,
                                   0,
                                   0.29119039884878717,
                                   0,
                                   -0.54196509236392165,
                                   0,
                                   0,
                                   0,
                                   0.54817592703941498,
                                   0,
                                   0,
                                   0,
                                   -0.61365001698562982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0765037168930411,
                                   0,
                                   0,
                                   -0.076312691882216566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32677813700534558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32722485869419993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056450565320159241,
                                   0,
                                   -0.34308435371050394,
                                   0,
                                   0.32198864847182529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20096270006334205,
                                   -0.17313055883576153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25631724317327437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03064768967305484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12839387767713939,
                                   0,
                                   0.52305650822893668,
                                   0,
                                   -0.36674051497189397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51961537679063796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35661923378845839,
                                   0,
                                   -0.25694113768318044,
                                   0,
                                   0.050194537901977948,
                                   0,
                                   0,
                                   0,
                                   0.5337158593703949,
                                   0,
                                   0,
                                   0,
                                   -0.21475081256900103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83772175181941411,
                                   0,
                                   0,
                                   0.025679800701807781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23613095430411424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25127578623927788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096206184462387406,
                                   0,
                                   0.086709734568133912,
                                   0,
                                   0.14703381361986828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44550836096712582,
                                   0.23707793450794093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58415000962057273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35215912491984891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043413016514089256,
                                   0,
                                   -0.26771688621014716,
                                   0,
                                   0.22185930323712516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26144242921212513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11746021524754373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020721871193412636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50867718463577716,
                                   0,
                                   -0.18898158076912175,
                                   -0.10399642081008861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82539167696675808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20853583944683593,
                                   0.27057506619567079,
                                   0,
                                   -0.3584564991566398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6766042317210349,
                                   0,
                                   0.3569094253448033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024563741976085494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16815846022626096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14881544036818148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049414784040854406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24984536982761996,
                                   0,
                                   0,
                                   0.30227899732007163,
                                   0,
                                   0,
                                   -0.23150997011280047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017430806339743893,
                                   0,
                                   -0.030421924506184791,
                                   0,
                                   -0.38994247187076764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29634768885618007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40924196937229718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31854766761964354,
                                   0.35744466125552637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027102405821264282,
                                   0,
                                   0,
                                   -0.35980652253267215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39214597822601782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27809351460433002,
                                   0,
                                   0.45283571414846557,
                                   0,
                                   -0.73164238005565563,
                                   0,
                                   0,
                                   0,
                                   -0.47178496288824784,
                                   0,
                                   0,
                                   0,
                                   -0.64322653724438239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41405040605531562,
                                   0,
                                   0,
                                   -0.33860872443117901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80081247391514343,
                                   0,
                                   0,
                                   0,
                                   -0.75476493346734153,
                                   0,
                                   0.19966667626027382,
                                   0.1472850852486087,
                                   0.12213884223223823,
                                   0,
                                   0,
                                   0,
                                   0.048235737557285947,
                                   0,
                                   -0.23600353391560183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64215164287002569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0093585679296673413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58278915488616356,
                                   0,
                                   0,
                                   0.1518984851666797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26102992577413847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15027679644795072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32309123995769257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018390575001467874,
                                   0,
                                   0,
                                   -0.054004766854005418,
                                   0,
                                   0,
                                   0.10596798166478355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31422641121257766,
                                   0,
                                   -0.075513022786536266,
                                   0,
                                   -0.1238957909937613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33266842879005348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0806828079803599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10898768231208303,
                                   -0.68597858866516725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052007207318207592,
                                   0,
                                   0,
                                   -0.36935983147743173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26414736859504362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29084041995991672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64758721128117158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043834735304834546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37673522718995534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4904955769075362,
                                   0,
                                   0,
                                   -0.12547889804441767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16151483313157033,
                                   0,
                                   0,
                                   0,
                                   -0.87850995571088364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77259025536807091,
                                   0,
                                   0.39586504545803519,
                                   0,
                                   -0.53718905214018697,
                                   0,
                                   0,
                                   0,
                                   0.63296916457504582,
                                   0,
                                   0,
                                   0,
                                   0.64344276045035687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092296572029144999,
                                   0,
                                   0,
                                   -0.6326585017725429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.469394406972867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36009811442554296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064509090123708507,
                                   0,
                                   0,
                                   -0.18703464689076174,
                                   0,
                                   0,
                                   0.14230917705486926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49149424656326018,
                                   0,
                                   -0.095856160401087728,
                                   0,
                                   -0.13570133436760012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12405956947459122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099097616326715404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10758168514581624,
                                   0.20001910453486429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4939449848113377,
                                   0,
                                   0,
                                   -0.025668685415052368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25872782133176209,
                                   -0.77392852549217783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66339065985185219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23012909644823315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11249574370399403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51040598853976227,
                                   0,
                                   0,
                                   0.10428533160173925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82309285516031616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047695010306925974,
                                   0,
                                   -0.13359556144119505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13856984859163388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10398670010597572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21197780918846304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079413019636105447,
                                   0,
                                   0.0087641610310458164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44153884306651403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16543393959213709,
                                   0,
                                   0,
                                   0.22292475556798069,
                                   0,
                                   0,
                                   0.48879592067673366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6385338647612715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62318559898774473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011144024940787485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043322639142763367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082722082599572408,
                                   0,
                                   -0.32409249485282293,
                                   0.27973734160944747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080413729113671312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15802830108071964,
                                   -0.017555980429929601,
                                   0,
                                   0.90457473334194616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083979058448172508,
                                   0,
                                   -0.38588131726082187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39995833313165408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15480056247919097,
                                   0,
                                   0,
                                   0,
                                   0.29181739274832791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13328441743795272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018222813805805357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45319117159725664,
                                   0,
                                   0.33749348950756203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27862589999766585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39819491425337039,
                                   0,
                                   0,
                                   0.3942514843139861,
                                   0,
                                   0,
                                   -0.42685420110139122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060260975537043765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1740176451134921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14578394631720853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52360545682621173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037927267295075437,
                                   0,
                                   0.98692649358983398,
                                   -0.33877797770851137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050376392252038063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23753977161172934,
                                   -0.4721670814293884,
                                   0,
                                   -0.20074034482037242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10128529892301763,
                                   0,
                                   -0.28871922612887535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10997953033492584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57133880356264388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31403567210642896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23249904395344526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025163528695895325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038031314364458349,
                                   0,
                                   -0.28016093550026849,
                                   -1.0353889608222118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055688080326045344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22065646216274881,
                                   0.84232841103720435,
                                   0,
                                   0.36878367565028514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086869730631294328,
                                   0,
                                   -0.58718589350406469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14861476971958199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38999895568511689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063841986037649096,
                                   -0.69698446438463646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51020566432279513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48434048753287939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084242664082078089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24878171763808091,
                                   0,
                                   0,
                                   0.051673393105712756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23901486705964503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83502216077684244,
                                   0,
                                   0.45151558029225242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0042461717709168807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27510493357974775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21058071595388453,
                                   0,
                                   0,
                                   0.3468516325730685,
                                   0,
                                   0,
                                   -0.31448561800399116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10440099292409653,
                                   0,
                                   -0.310402045614462,
                                   0,
                                   0.16193819330574397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13320890964687479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13923810156504599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48678585486210985,
                                   -0.17301691441594674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2274429585355725,
                                   0,
                                   0,
                                   -0.4141464594505801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22222314118601905,
                                   0,
                                   0,
                                   0,
                                   -0.6625355806475679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15971528209987446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69420157756536016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019142838762848301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062227244764902268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45432802652635634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053651392882121007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017634402216268257,
                                   0,
                                   0,
                                   0.30997313331562798,
                                   0,
                                   0,
                                   -0.37460319270894266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094835289361040187,
                                   0,
                                   0.14789825046111826,
                                   0,
                                   -0.029166868582557452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49646749994619799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19080620095626222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45120943455678736,
                                   -0.079451240601941156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16723542084096465,
                                   0,
                                   0,
                                   0.038861931898105009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32013738145552256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51285504812389826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44534621909829342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19869779265600573,
                                   0,
                                   -0.50063634240636712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1203463523357127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13104131154724433,
                                   0,
                                   0,
                                   0.22524163129047797,
                                   0,
                                   0,
                                   -0.22286749812062334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11824617356008443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25518378227073651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23192389508665634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05316560505910968,
                                   0,
                                   0,
                                   -0.22678582777859146,
                                   0,
                                   0,
                                   -0.14636743507672967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12111735231485353,
                                   0,
                                   -0.33182988715413492,
                                   0,
                                   -0.25921800239662962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075467386188716179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53088287338680284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088493843116875026,
                                   -0.32743942029803419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29771459827339281,
                                   0,
                                   0,
                                   0.34960348562336602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53714241545862484,
                                   0,
                                   0,
                                   0,
                                   -0.47953169758257513,
                                   0,
                                   -0.67388461745318207,
                                   0.14235391747760587,
                                   0.82265457260335972,
                                   0,
                                   0,
                                   0,
                                   0.51859089799452218,
                                   0,
                                   0.65175863118153832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19745815883050502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39143986482183224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12259432462045823,
                                   0,
                                   0,
                                   0.65633394610955975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3289729088489986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24277860107160909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21525780572970646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18007832915698316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69968537700390521,
                                   0,
                                   -0.083047449445304622,
                                   -0.56557125688888987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032209465647145261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062489028860563067,
                                   0.25306393051020432,
                                   0,
                                   -0.66276136774753669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18511877941894656,
                                   0,
                                   0.047397793107216438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57907207707117281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5196255687615744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0018986515237586037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040866781475233899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38227337933527339,
                                   0,
                                   0.31442079328748729,
                                   0,
                                   0.24371904505274899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53349600500810879,
                                   0.028811976919737168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45167251375759215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19276761865309452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31171960720339886,
                                   0,
                                   0.23655911474994357,
                                   0,
                                   0.11911799371901051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038833672331852351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.008715980944477706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58943094378744676,
                                   0,
                                   0.054640072652031038,
                                   0,
                                   0.12518194372971794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13949829405848455,
                                   -0.6107482403313591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034544542848131798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14189456156584943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19336313394460033,
                                   0,
                                   0.094823348706973704,
                                   0,
                                   0.41490930974775275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88094104176061816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4110721498821881,
                                   0,
                                   -0.3362092157713471,
                                   0,
                                   -0.53797859465228093,
                                   0,
                                   0,
                                   0,
                                   0.045810304994961637,
                                   0,
                                   0,
                                   0,
                                   0.78960698616001435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15395847533095547,
                                   0,
                                   0,
                                   -0.67661577438533471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56970498601685471,
                                   -0.22634568732981214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2450263802940178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14720955314856365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59591611861022087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88464639069241635,
                                   0,
                                   0,
                                   0.17666440428763525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90232647458896131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29995206592867651,
                                   0,
                                   0.58109713655575723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40728472255335102,
                                   0,
                                   0,
                                   0,
                                   -0.5452100018122199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17554594635688109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39572076011722668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16848433191999387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56662769022167492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54685015554457761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16886094038370508,
                                   0,
                                   0.8278105182636647,
                                   0,
                                   -0.27062551874192575,
                                   0,
                                   0,
                                   0,
                                   -0.0014586995334732317,
                                   0,
                                   0,
                                   0,
                                   0.93526911445006611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2113036077631818,
                                   0,
                                   0,
                                   1.2280349240276649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089996120071286378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14462430055618813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42672833170528152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6384237381829363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2826365101728352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28903192930802318,
                                   0,
                                   0,
                                   -0.46434787610338346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047547538541753809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43078136368761322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24981132671154424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20830997664056408,
                                   0,
                                   0.20143682367400156,
                                   0,
                                   -0.1919236010249977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28201934979746357,
                                   -0.23725113128458308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074490358886573238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14405909916755777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65803789955692904,
                                   0,
                                   0.070850232552268716,
                                   0,
                                   0.17623485901991415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086700626906748374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20471096090346871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54533371136141273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27940250890953156,
                                   0,
                                   0.48406328417189437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33935781600726084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0071881509132018604,
                                   0,
                                   0,
                                   -0.17651674969690276,
                                   0,
                                   0,
                                   0.42027344128014144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13342120070191396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27384399734836251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78867251596506294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010349313885680125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47807495883652995,
                                   0,
                                   -0.18601383828025514,
                                   0.08080430929512461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70026818877347219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12457747533249552,
                                   -0.18840294125555077,
                                   0,
                                   -0.16767348366139193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39053968915674991,
                                   0,
                                   -0.11493139805711151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074972202938470067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47355859406495554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56685428646881642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25705341823053535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15661647206080917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068061099010405482,
                                   0,
                                   0.033426353844933157,
                                   -0.19258069725286517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45315431615687063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096339135837700471,
                                   -0.40969856000078847,
                                   0,
                                   0.081259397891485605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76388589247909278,
                                   0,
                                   0.58763145182945165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30882982310486479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45892240246703375,
                                   0,
                                   0,
                                   0,
                                   -0.3438441097415581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15849472295725087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043534159858973576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069225135173018926,
                                   0,
                                   -0.16900209809528258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51058019927020748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51500062213580555,
                                   0,
                                   0,
                                   0.36055916007123456,
                                   0,
                                   0,
                                   0.047386316087859315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40402406842299055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12493388259170829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59656327057636827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3589033453619967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43618505256929452,
                                   0,
                                   -0.040384896261528427,
                                   0.38644585640559903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60032308821541758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7400155919539626,
                                   -0.52767054005787672,
                                   0,
                                   0.017655997309934002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53156452839502755,
                                   0,
                                   0.096664839827769716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20114369474290578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.243101670837711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59165421740980506,
                                   0,
                                   0,
                                   0,
                                   -0.14030553165905246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1641178869820541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33310671357145893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.694794101544571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09811237338940948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24699233094574438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20737555980546596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1801642943403079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11939592356123513,
                                   0,
                                   -0.14989980285438217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15648718807156176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30783744017971365,
                                   0,
                                   0,
                                   0.3861104311623057,
                                   0,
                                   0,
                                   0.52149837847855007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53526787856208269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89528442112380713,
                                   0,
                                   0,
                                   0,
                                   -0.023986451208693138,
                                   0,
                                   0.065062171088060589,
                                   0.43142463941688985,
                                   -0.3262449586271573,
                                   0,
                                   0,
                                   0,
                                   -0.11590428160007127,
                                   0,
                                   -0.10198788675730047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27435316282628758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15626610967492008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40309360281678386,
                                   0,
                                   0,
                                   0.10476542021045464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63089175551397358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087438522024557555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13515405679319692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068706121315086979,
                                   0,
                                   0,
                                   0.26230581979142353,
                                   0,
                                   0,
                                   -0.14491579365835627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30222833735871735,
                                   0,
                                   0.34838301081215972,
                                   0,
                                   -0.088514923371580789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16930383462768073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29179246077640958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31844439912883205,
                                   -0.13531153851476563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39016665146893337,
                                   0,
                                   0,
                                   0.52274482327785377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12666743938345656,
                                   0.061635601651059913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12521680788182538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91133296747210801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40097523675433477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065816746762079353,
                                   0,
                                   0,
                                   -0.91708203866420335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23210202864193105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27042675279395023,
                                   0,
                                   0.29426695379002943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054862903830346699,
                                   0,
                                   0,
                                   0,
                                   0.41010399211358362,
                                   0,
                                   -0.52506199148721833,
                                   0.053443374768732975,
                                   0.3430967073652223,
                                   0,
                                   0,
                                   0,
                                   -0.10844234380729244,
                                   0,
                                   -0.19829896479587406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84730870182739393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32327025223323946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0025957850226892,
                                   0,
                                   0,
                                   -0.16419229609717439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16282022737820731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036865707329586633,
                                   0,
                                   0,
                                   0,
                                   1.5465713369892602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0057018701119457837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55166848164357229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17863141348283523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3278003338863178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83411878057102606,
                                   -0.10286541174864845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093686367300288509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28234361204545766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74633754891199966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17842954894223764,
                                   0,
                                   0,
                                   -0.43858095027509636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27034794861373662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51074147662638048,
                                   0,
                                   0.29755002962845167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18736319286357203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13939160761816918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36385244087058649,
                                   0,
                                   0,
                                   0.020651699608225833,
                                   0,
                                   0,
                                   0.20301058412456074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14707958017297773,
                                   0,
                                   -0.14817715844965818,
                                   0,
                                   0.71503508285627193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11261361905901035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33776197052674872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2398537213850058,
                                   0.036105398510118097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17599370894836261,
                                   0,
                                   0,
                                   -0.00064273211028029881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13488012017366566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23771124592475912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12971831641134904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080271159347166221,
                                   0,
                                   -0.18831537348421246,
                                   -0.25857028254269954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20503820205973175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22996243056059215,
                                   -0.66762178546396056,
                                   0,
                                   -0.36322828840181093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091968751390463718,
                                   0,
                                   -0.94211605873097248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16980877848005393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24034066025213613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18478333760146606,
                                   0,
                                   0,
                                   0,
                                   -0.14720960259565791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89094213389406307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28160393359619557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23549803953619683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12508582277198221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067543742207040069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22456922796834666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89421398449316536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12633951239761498,
                                   0,
                                   -0.33355167480678449,
                                   0.14457811535613352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22093314455289642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7237870879995294,
                                   0.1662575015810028,
                                   0,
                                   -0.46345747631890655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25621624607634097,
                                   0,
                                   -0.49551747444291816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18284452115872019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33801194807538792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17480787295137507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50099738676679773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21748196626943328,
                                   0,
                                   -0.040113000203006115,
                                   0,
                                   0.0054724790697843126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087442633836546435,
                                   -0.56206342354649852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13946263807535664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0023429522183703207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17505158945629037,
                                   0,
                                   -0.34065057496507434,
                                   0,
                                   -0.42403269119474379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10048436533959108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19305023542119171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091087046431849228,
                                   0,
                                   0,
                                   -0.17342414820827318,
                                   0,
                                   0,
                                   -0.55406637508746348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23890367408042479,
                                   0,
                                   -0.46369507245392944,
                                   0,
                                   0.1259053422108036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31318610551309611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32522157502990645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10263648324781299,
                                   0.23643038071113609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068612538700391704,
                                   0,
                                   0,
                                   0.21056130265250744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29664099880065897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1348054023839263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012443443250930997,
                                   0,
                                   0,
                                   0.6567536479749454,
                                   0,
                                   0,
                                   0.22864009158167081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23011491918740987,
                                   0,
                                   -0.0597646114736088,
                                   0,
                                   0.073381635907423082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25268888377703652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13030076152180159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12811179570014794,
                                   -0.018047914510092494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46434904687543321,
                                   0,
                                   0,
                                   0.1870220038891757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89793483524790718,
                                   0,
                                   0,
                                   0,
                                   -0.51355395371668822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0291223398894744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62916463444966109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064262452657139452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77093492493087845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38317821989816225,
                                   0.75866563736222481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2116139058590136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41933244784615309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52159030118862615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35057474458716786,
                                   0,
                                   0,
                                   -0.17432086826890103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3076852272048255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80292051771507467,
                                   0,
                                   -0.15313099620211523,
                                   0,
                                   0,
                                   0,
                                   -0.41932602364256077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22283955028030358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16087172782023004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010870640339176479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43512532032103951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11786913897739111,
                                   0,
                                   0,
                                   -0.42776582171622862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60191325002646467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15716828118514661,
                                   0,
                                   0,
                                   0,
                                   -0.26007877510614386,
                                   0,
                                   0.55150595022025595,
                                   0.43590579706256216,
                                   0.19698375854463923,
                                   0,
                                   0,
                                   0,
                                   0.38900184624025402,
                                   0,
                                   -0.45442656241449964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14152634144432263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41336698274270078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34793850100309653,
                                   0,
                                   0,
                                   0.22081195092694672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36077336888130213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042770465411402087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38419850211776713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13724058054768473,
                                   0,
                                   0,
                                   -0.095717271097111839,
                                   0,
                                   0,
                                   -0.34414579956668878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38634674539629754,
                                   0,
                                   0.41720433377279442,
                                   0,
                                   0.16532343334188218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51109198465165284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1359853501371569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20076691927493495,
                                   -0.17805711484055259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041446189102890732,
                                   0,
                                   0,
                                   0.0061222313269738288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15747903532234891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38820707577376884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034691659352534966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06149536769576755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14610406219925859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66489163045949673,
                                   0,
                                   0,
                                   0.57734416735620619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15085378168944202,
                                   0,
                                   0,
                                   -0.55021052231014911,
                                   0,
                                   0,
                                   0,
                                   -0.32909456917917962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31533796452272478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2397271722466194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028064195185505784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49977586067309854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13280870388178068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24719631799209241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52561822858128204,
                                   0,
                                   0,
                                   -0.21377160913061641,
                                   0,
                                   0,
                                   -0.27181696926487853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16046983911908475,
                                   0,
                                   0.36975190949400222,
                                   0,
                                   0.11841268120283641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18774399557978061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12490465889237801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36681307098819832,
                                   -0.074940898406727921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33439940820801423,
                                   0,
                                   0,
                                   -0.21463928010704555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33199863971107285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24072899747347304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22566642051765939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6614268733334514,
                                   0,
                                   -0.34944013818597669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089549132262647047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38602824444010803,
                                   0,
                                   0,
                                   0.24985518931100811,
                                   0,
                                   0,
                                   0.042137024502166609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0081977837873635911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18121395047040142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34540012959557753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27230393198995756,
                                   0,
                                   0.29983127868272569,
                                   0,
                                   -0.038140288125908646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23970262701587813,
                                   -0.014409942949580496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19547897596483865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64233422890358438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067984450788880241,
                                   0,
                                   -0.37307555236769313,
                                   0,
                                   -0.17343530538837598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4297485380309628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22254584032754757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68078044308737451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28561641616172623,
                                   0,
                                   0.34884618340838347,
                                   0.079506602699018075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030334477701132345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12162501370914816,
                                   0.4085348470879403,
                                   0,
                                   -0.18854012104321735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.107413675265388,
                                   0,
                                   -0.54802787208783632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87603567747996125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27798333237320022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53674194950446008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14543003946747429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068972344814275999,
                                   0,
                                   -0.12909624467517336,
                                   0,
                                   0.11634790425925112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061095869038186527,
                                   0.19502287912430358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32463788996199416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15696264952248529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55508517233239896,
                                   0,
                                   0.020547973532276477,
                                   0,
                                   0.4188829125180179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8994757866240326,
                                   -0.11194864480032615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45325660975040066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36132367731946785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047106966816214291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21364295532375724,
                                   0,
                                   0,
                                   -0.36275835041976556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23840621250753949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042490845669425077,
                                   0,
                                   0.77844587195089865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19653562721981566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21350963388073929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055318847120036013,
                                   0,
                                   -0.7565511943695874,
                                   0,
                                   -0.031673592717896319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33488754841005108,
                                   0.0063714328598692242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17958635590593125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070966491602176357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10960608304762823,
                                   0,
                                   -0.39210738275656315,
                                   0,
                                   0.15528947807596796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39058402302817802,
                                   -0.60568046954576737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86210063093189993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3716974643501027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12303640292095241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59710156057057739,
                                   0,
                                   0,
                                   -0.0043683518983130068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48612286113862596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19006794697860127,
                                   0,
                                   -0.84196142443440092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82495261743192283,
                                   0,
                                   0,
                                   0,
                                   -0.081798676533291176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1835569295091675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17729678218900058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46136436559137317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11314724192874942,
                                   0,
                                   0,
                                   0.29668058523025248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32620351030435596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21236029398122919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37399119749255483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71500744614889866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078978836634941846,
                                   0,
                                   0,
                                   -0.079239185479687127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31121284798474824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13973405440995035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1143708240608598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51526707821375417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4823035619433681,
                                   0,
                                   0.42346345799223739,
                                   0.21238918274779603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15614857469596749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64992272561679221,
                                   0.48249231848410057,
                                   0,
                                   -0.14277208734193514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26738747391379392,
                                   0,
                                   -0.11049487605451785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65254269705242685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28411045490618098,
                                   -0.47268167157399049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23413357154683989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45790897193393154,
                                   0.012159529197768698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38996144087822826,
                                   0,
                                   -0.13671046858333169,
                                   -0.18420266551991307,
                                   0.37285818061665105,
                                   -0.0074956125780816923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023290185340606544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089363755161490491,
                                   0,
                                   0,
                                   0,
                                   -0.072133504004824101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37074530062408867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13027542693384675,
                                   0,
                                   -0.2725906720612738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29669297070957851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014428926799353073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49819377115224961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.4632909457271999,
                                   0,
                                   0,
                                   0,
                                   -0.45991577566455188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17599015846990268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30044424251489277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01223046030899469,
                                   -0.046645020760421922,
                                   0,
                                   0,
                                   -0.82398958660543464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097376600946287056,
                                   -0.12223321005327456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039339411813563263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08317845702220357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29489225087359283,
                                   0,
                                   0,
                                   -0.16662004843162737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22330126523426028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67132525618514227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0036086269993634706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1611768023863577,
                                   -0.17274055902377364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60264738989613797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36098232548307441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28405483167794504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23199299617762453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16364419593719509,
                                   0.29685505409777513,
                                   0,
                                   0,
                                   0.20527041083290498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1040244101214633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27159745973205046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78985287029932894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15233633637859903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49789690791825869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048889442489168308,
                                   -0.097654774279039874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36177417316012317,
                                   0,
                                   -0.048540779816603416,
                                   0.48980169249175781,
                                   -0.067034467840898337,
                                   -0.18583852031046344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24612309430749574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31770629796429162,
                                   0,
                                   0,
                                   0,
                                   -0.32530032868039532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18630928595065768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052424429806368904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065757559886998607,
                                   0,
                                   0,
                                   0,
                                   0.23389337986897588,
                                   0,
                                   0,
                                   0,
                                   0.15413136206545222,
                                   0,
                                   0,
                                   0.075872323461356916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33098655856581194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073951487566905283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24849002431333239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56955938089861502,
                                   0,
                                   0,
                                   0,
                                   0.18520245887309542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27503743552477494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016321779909788225,
                                   0,
                                   0,
                                   0,
                                   0.19102412558479248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030580524446229482,
                                   -1.3292970481286797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65768591537572174,
                                   -1.011402217379241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6825918688286674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03852256912573937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33394557228588445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25005371863686465,
                                   0,
                                   0,
                                   0,
                                   0.10040628399418494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032231353613530439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0135608140743393,
                                   0.43221256487944854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16846236551189234,
                                   -1.0038720593604156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41301464863965998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34687597765075212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48084358936551225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027323715046767571,
                                   0,
                                   0,
                                   0,
                                   -0.067933318581798449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33489730540619239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49145056086430194,
                                   -0.79103836063836208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75674865097910693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60121795726334426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73493737555116512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032509846677998694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35294508413340409,
                                   0,
                                   0.0062972314938824908,
                                   0,
                                   -0.62240173041639157,
                                   0.043817650480885748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43836591909398415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16998301621319764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23730304350393408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32570040750938406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42797791416230185,
                                   0,
                                   0,
                                   0,
                                   -0.037771153956668801,
                                   0,
                                   0,
                                   0,
                                   0.51320539493517481,
                                   0,
                                   0,
                                   -0.039140225951564175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021856102454174201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54739257327972046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04545705493825368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38407347151535659,
                                   0,
                                   0,
                                   0,
                                   -0.089376214966829182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07316814787678913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28601535559231295,
                                   0,
                                   0,
                                   0,
                                   0.031740825215714856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85721595776145065,
                                   0.19510365480039815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016536990219451968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22748551835759462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55217959001956018,
                                   -0.14657599926963771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016289511749898143,
                                   0,
                                   -0.0011257160451659466,
                                   0.35431393392881433,
                                   -0.13052663014957197,
                                   0.043061213266552475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17902291212851573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3970940012801556,
                                   0,
                                   0,
                                   0,
                                   -0.21609163562415207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48604791968408018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064981313378759092,
                                   0.42387424581773386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19837294519950138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29628490553047249,
                                   -0.4786525288360744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3044147668277854,
                                   0,
                                   0.016182990840440108,
                                   -0.4519919520932385,
                                   0.16724484419106914,
                                   -0.045207933356040994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24249635299683767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085057330588080321,
                                   0,
                                   0,
                                   0,
                                   -0.1138268362352407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17196302677641448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16815822445170833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15433088703238812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63372837186777831,
                                   0,
                                   0,
                                   0,
                                   0.36671134364581337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22351802796462794,
                                   0,
                                   0,
                                   0,
                                   0.91625906382060263,
                                   0.27149725984580608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69120678150068504,
                                   0,
                                   -0.036193510029271139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67266433241995116,
                                   0,
                                   0,
                                   0,
                                   0.0083323809907032004,
                                   0,
                                   0,
                                   0,
                                   0.42035590629139336,
                                   0,
                                   0,
                                   -0.27725275825151252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090486604932456222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63004135811233697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012199003528678471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29327103575136398,
                                   0,
                                   0,
                                   0,
                                   0.43618151129797939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23221404826068962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27356791212394493,
                                   0,
                                   0,
                                   0,
                                   -0.38527755703267214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21188164028015954,
                                   -0.12865525997938912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18917276892862339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47037977188154156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60762450916986355,
                                   -0.5854612380705766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16340052874283706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065455293751215962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52606921455210975,
                                   0.48647903670972303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4593950405291975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10725432608703681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35802387615831355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19595685358724579,
                                   0,
                                   0,
                                   0,
                                   -0.22147640919365008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1035411684077907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60820250619729366,
                                   0.27381232485040652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031871739815228894,
                                   0,
                                   0,
                                   0,
                                   0.15581104799464857,
                                   0,
                                   0,
                                   0,
                                   0.29834564088626903,
                                   0,
                                   0,
                                   0.13448941376591708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0195790952002739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017872680414732639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096847064413572354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74602430780865425,
                                   0,
                                   0,
                                   0,
                                   0.23876719520952844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58984737581014468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58981984221143602,
                                   0,
                                   0,
                                   0,
                                   0.052461675086327098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26663111858758409,
                                   -0.088147269221498292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019594029503163378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036260615290521582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18669317478390696,
                                   0.1278163844695217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022547151032392097,
                                   0,
                                   0.79549669350858987,
                                   -0.094710545487883574,
                                   0.020065991909058136,
                                   0.37530482902941953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10488689000469517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36537751392377682,
                                   0,
                                   0,
                                   0,
                                   -0.056117115944645406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11226051216345606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057502364422841845,
                                   0,
                                   0,
                                   -0.35307100220146759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0047706678680025094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02587802372811987,
                                   0.51458135874568445,
                                   0,
                                   0,
                                   0.12124795899071397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29937779170940371,
                                   0.23764207949644861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00096721290921639169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15489233707112285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071533395116417847,
                                   0,
                                   0,
                                   -0.4407586940995642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47505236443038923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25909370797496278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06105849259112682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33574102271478579,
                                   -0.2111624651045409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22933276948950437,
                                   0,
                                   0.47332316069169245,
                                   -0.11621378542032995,
                                   -0.19344525853289554,
                                   -0.38595693106904855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13670124692476282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42480272389869433,
                                   0,
                                   0,
                                   0,
                                   -0.1509888366899243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089641945112211879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25560711937845876,
                                   -0.13574029023208845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021562165937371681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21334755925321244,
                                   -0.66025084257206512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19409544354594191,
                                   0,
                                   -0.004201846669053412,
                                   0.023679428833678878,
                                   0.10339992369640444,
                                   0.32265007114220545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25778660877004211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022239690931912796,
                                   0,
                                   0,
                                   0,
                                   -0.10858731079295536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016511712404165393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51730347527017262,
                                   0.32732524798857088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24428445615251326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20243180661372442,
                                   0.2477586883181514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023217056515872019,
                                   0,
                                   0.14298162444181894,
                                   0.1712691412128973,
                                   0.61513202018353408,
                                   -0.11921348668896299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26824933881944568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23095611473059888,
                                   0,
                                   0,
                                   0,
                                   -0.12295846913711159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13811378913686712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35834688629587619,
                                   0.097247922761874286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18113496054742392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1500948059804138,
                                   -0.13880273508285298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2941071363634537,
                                   0,
                                   -0.10945580731365381,
                                   -0.27876078159458811,
                                   0.20452697348391105,
                                   -0.33458881804727097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082219335492808646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4168961530356769,
                                   0,
                                   0,
                                   0,
                                   -0.023140799316004646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63322704787623141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062416267292817296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24905702159589263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00086119906371176502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26631365620793057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28981774727283294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42523439028558579,
                                   -0.64633368878939201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028359879205412442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15065746681091599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37155124120698002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15142246983287852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024121088506335046,
                                   0,
                                   0,
                                   0,
                                   0.54268117883332267,
                                   0,
                                   0,
                                   0,
                                   -0.052467946110911406,
                                   0,
                                   0,
                                   0.36137036985847426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52279430726937437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27417841192275216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25297073526177061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17338814515248696,
                                   0,
                                   0,
                                   0,
                                   0.0090539301916292766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45268317077340742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63130593872732055,
                                   0,
                                   0,
                                   0,
                                   0.3686798625953509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28279681810837121,
                                   -0.16090988725654728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27183724574769186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35254066185935318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18801977009964291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48051722261871355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071988429586721914,
                                   0,
                                   0.49382300471258028,
                                   0,
                                   0.046037307963966212,
                                   -0.01009513113007901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020277708265415195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0027299845668232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5180629503536418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34835910727355729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60483309562850196,
                                   0.11378153955232365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35495370455753422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36815677830107141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010003953594459533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83038270060607156,
                                   0,
                                   0,
                                   0,
                                   0.52681717049298182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09175630889594627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44586595681776386,
                                   -0.47163306626771251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52299390410526769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30419132796276271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16928218928748118,
                                   0.052593206045278784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2666857438342935,
                                   0,
                                   -0.17793261827321197,
                                   -0.11589789542148649,
                                   0.080369797452621461,
                                   0.12626806440176397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63665963163309713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012682856324736029,
                                   0,
                                   0,
                                   0,
                                   -0.0071876067489050899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16444773043241645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17696015086600028,
                                   0,
                                   -0.31907641350438309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016329848274970929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38499152786356022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89894675126433454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36080814409215667,
                                   0,
                                   0,
                                   0,
                                   0.25982244352808598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45899621231018195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47497702586101137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098917152737952166,
                                   0.12100097654915055,
                                   0,
                                   0,
                                   0.18563516367239224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099828974109425331,
                                   -0.35073397356174529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40755649119957726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021603236285273462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37387008238181202,
                                   0,
                                   0,
                                   -0.22744944695075195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11735340441752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34905312441121539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1022505027967156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22536420588944167,
                                   -0.4890920659950117,
                                   0,
                                   0,
                                   0.13592376663961239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11484895977065239,
                                   -0.48504854660000202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37221763668193442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026476166923157431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12728313581053924,
                                   0,
                                   0,
                                   -0.22979043346004854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32018343773674013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74249088045512757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051230990799728704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15942395025047423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38508959914605406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13481665138826363,
                                   -0.24285648883625674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36214678988472415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049940766551020324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0096120965608668119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24795384467574721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37036006086531215,
                                   0,
                                   0,
                                   0,
                                   0.16826340422133507,
                                   0,
                                   0,
                                   0,
                                   0.30519797270009019,
                                   0,
                                   0,
                                   0.23263608392957763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29329454776269881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4402267781208194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30295643942204437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099241055208784956,
                                   0,
                                   0,
                                   0,
                                   0.90837577257795776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31086076710910593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11656327362327032,
                                   0,
                                   0,
                                   0,
                                   0.027933518291611309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12628505399262865,
                                   -0.17895308997310311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34367152079825752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11543785645187354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23670185564064708,
                                   -0.010215904546813273,
                                   0,
                                   0,
                                   -0.0066002838702092642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14604361825343412,
                                   0.02517127270976266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072980044463039295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25186378910612245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24531470617879947,
                                   0,
                                   0,
                                   0.52732152970625845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61920691441469189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010001722065423241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7203244217151189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23437826795755401,
                                   0.37724565879388416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31124254333691459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43233472296828013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080567777013786063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26226138652240644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27382329632934743,
                                   -0.57213670536828187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10310483405247267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71538631829178279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2964717609814238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30052858041675967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39743707291547525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087832100223751666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14079468339381387,
                                   -0.46934873143404066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039684226131976169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59317802590967172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24957484582654255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016804049216922481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037573729849830977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75380087431357246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53470886959106834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11380962469917534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090157143813199753,
                                   0,
                                   0.37776793507482537,
                                   0,
                                   -0.35671020026130307,
                                   0.12663319505601114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87192292123017789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15639724671327321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46132381812908607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28217268103771959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42257224075869543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32757316394654573,
                                   0,
                                   0,
                                   0,
                                   -0.068572341867541298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12382744320874471,
                                   0,
                                   0,
                                   0,
                                   0.59115152935953619,
                                   0.81138932459505309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16071002961320513,
                                   0,
                                   -0.70450643427448945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29570913372204216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17940396593342806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30085584981605995,
                                   -0.1783157739073106,
                                   0,
                                   0,
                                   0.041302519986070853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38739399939226299,
                                   0.236048739691229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18750728783506676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021588923384679982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46648361040453817,
                                   0,
                                   0,
                                   -0.53282814026351544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11585637996656568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091123592052443275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18552294478278233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20219925261211519,
                                   0.12769695154570149,
                                   0,
                                   0,
                                   -0.11005839513820356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10879774237245629,
                                   -0.39697872490625352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10669990273224485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79362789659407007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21878513310189546,
                                   0,
                                   0,
                                   -0.025942232278186723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16963115942626333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25247472937799248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041740139827172312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1220585313308902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6320729666277447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30068148785345938,
                                   0.058553072098345496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42436052856791623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23356034796282796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35841856068451011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25132801905165053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66345203703062205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078939186782342408,
                                   0,
                                   0,
                                   0,
                                   0.33161568871607028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70767836176959453,
                                   0,
                                   0,
                                   0,
                                   0.013140032427663161,
                                   -0.87260612120841263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25603372932856816,
                                   0,
                                   -0.55575817229654678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59943192334940043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17332334851776016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88324175099793856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74753500235557957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37188710479376164,
                                   0,
                                   0,
                                   0,
                                   -0.4966031091714343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69379938053071821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076141983660646145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30594787361371928,
                                   0.44700351486342627,
                                   0,
                                   0,
                                   -0.20894583498135799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26099389443730803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28818965670879576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15684106957954791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082774052091871955,
                                   0,
                                   0,
                                   0,
                                   -0.023519575729692217,
                                   0,
                                   0,
                                   0,
                                   0.042751586381326694,
                                   0,
                                   0,
                                   0.57905405320741532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37144087919515234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5446177536915886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38971559601766137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20498962442679236,
                                   0,
                                   0,
                                   0,
                                   -0.16183192083995215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1756152173698165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16914972199108377,
                                   0,
                                   0,
                                   0,
                                   -0.93577192411734045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070817319291315614,
                                   -0.43821187772016851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027724155988511773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74575431747829302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44145851748609155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38799648625791161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35465278596563365,
                                   0,
                                   -0.45042012381680196,
                                   0,
                                   0.60343462660041858,
                                   -0.35324559341724088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71123175349596357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19213236482996823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3503950050407903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27641146014978935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12347386494891578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49964683720333375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083859356500730134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027809823086716763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46846821778218301,
                                   0.0089571195313054575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39230813777790396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031432234833944223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5931532666224637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032160623343096384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080684407313181841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17413569634588869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63183850220314541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37919285099844319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07455660891793342,
                                   -0.12431997787176625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.003071285041235515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44223318139748719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22470284247935343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.391247418891914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60655581407803505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16738076722271045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45427925957891457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26179441731049269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44331463938707788,
                                   0,
                                   0,
                                   0,
                                   1.0985155600113052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21919799515146951,
                                   0.49766993602828241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71835781920466468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077988744426263454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.25975468623114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22449284376782169,
                                   0,
                                   0,
                                   0,
                                   0.55787063837453688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016410519294192398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055040231624146133,
                                   0.37351491405784187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15585524828269659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33285222993643448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18255892038616009,
                                   -0.2075485727435824,
                                   0,
                                   0,
                                   0.43721936179817955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75516618064705276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15980405181742488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039246648864483827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06649689314416532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58330054226063477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072954042150383064,
                                   0.094303859376349969,
                                   0,
                                   0,
                                   0.61152187605528985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035270233147070687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46727987426521811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21810468887101103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15693397080939336,
                                   0,
                                   0,
                                   0,
                                   0.34139920413038588,
                                   0,
                                   0,
                                   0,
                                   -0.05932250044911732,
                                   0,
                                   0,
                                   -0.18017967399978513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1741260063429016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070234235667524458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6784644454208939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58578588468928916,
                                   0,
                                   0,
                                   0,
                                   0.43475195794665916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23716964026836132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6689639415228984,
                                   0,
                                   0,
                                   0,
                                   0.16864514125070273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41564415647039715,
                                   0.35843103490075412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16370446995705723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43247148408146729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50432235849285323,
                                   -0.3613358827249088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57828081524940944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25856507743031942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34608035669805542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41575067230727081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19202243141654202,
                                   -0.47384667341949571,
                                   0,
                                   0,
                                   0.023590002684296479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31726707993625136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57754327591814425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10585536032613302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0209917109518797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32655794018358697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18020140380661986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1243869033754836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29630931129447513,
                                   -0.30939222251324294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038228549913194666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23715616082331667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068552626096295102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77398186516741962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091072024440972232,
                                   0,
                                   0,
                                   0,
                                   -0.84023840908065639,
                                   0,
                                   0,
                                   0,
                                   -0.1800601040189202,
                                   0,
                                   0,
                                   -0.47676642656683399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064085190230660047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18563603346146745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53159416493096923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60004768952077059,
                                   0,
                                   0,
                                   0,
                                   0.44302078106062343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39007599849034452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030114220906203443,
                                   0,
                                   0,
                                   0,
                                   -0.055311159236715063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14443286072123801,
                                   -0.31352090725546805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17952715997869512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36776132855715526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0096625025454997876,
                                   0.014149406639035782,
                                   0,
                                   0,
                                   0.24807151409582842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41557639619167897,
                                   0.309488044236505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2526473520317567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27714213392013298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58955597899515788,
                                   0,
                                   0,
                                   0.093632680321885056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072250879619008557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086541885196329549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48030724815678255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24448688903719823,
                                   0.23577995812801955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38480782284417109,
                                   0,
                                   0.046785528885023284,
                                   -0.32035763811685403,
                                   -0.058938783580214912,
                                   -0.17369396406498594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097216393158905859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30066091198541012,
                                   0,
                                   0,
                                   0,
                                   0.29692990173135558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11014351949768275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39970503310201227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2930875109177819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16008680576673978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40684816655323686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4876181301295196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0560547347374187,
                                   0,
                                   -0.052440283087128295,
                                   0,
                                   -0.33850217418022954,
                                   0.023063195519860191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59652829171401267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15332619890218094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24721451750283979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21963444879029231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15914461113416842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41958908304273518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25149944121907686,
                                   0.39788977146535803,
                                   0,
                                   0,
                                   0.52662041438019935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3971673013318931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27436721930301344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25826625379779639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22087351333195337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22951299498458444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22369293994978784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80456977334064095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036263999164782762,
                                   0,
                                   0.12211314959706698,
                                   0,
                                   0.21373400201089751,
                                   0.29017967865323957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57399101914515938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14993861201648367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51478940413993179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99876850606504464,
                                   0,
                                   0.1062274536856255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13460409108215113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.006109643840717844,
                                   -0.27111752908717396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20396413898874921,
                                   0,
                                   0.046431341465501354,
                                   0.24213212623997368,
                                   -0.00099191309804563376,
                                   0.11134169176954199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35757897623214152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014933521401245318,
                                   0,
                                   0,
                                   0,
                                   0.79490253325664917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076515396810390643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12830387582131569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.717315153112427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.291470509594289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44210809244098409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16985461552755077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27952426072389763,
                                   0,
                                   -0.49134446410608873,
                                   0,
                                   0.53225354711630823,
                                   0.90322926187832542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39046823369174444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25423223492393754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44074750025154863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11380823008906837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33638242999212969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12389979022395642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19457604824536642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72957637037820133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16420137125742937,
                                   0,
                                   -0.23555776830950048,
                                   0,
                                   -0.19588473449046473,
                                   -0.19286728856351024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010588336305554412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89345154719646924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099311062104465303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1449458561754067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4257711072849481,
                                   0.1311730171828133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18088197974803788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87397021749820136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45210231308939158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64249556483765868,
                                   0,
                                   0,
                                   0,
                                   0.69650914498366856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022096332928189383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0096887402767387165,
                                   -0.92930374126360016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20839633697210219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0681572041711625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2750237810112558,
                                   -0.36760683766723529,
                                   0,
                                   0,
                                   0.15056188655208619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67796015915472363,
                                   0.15313179814510591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0450153969257392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30697879528881039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1788702655094063,
                                   0,
                                   0,
                                   -0.18371264766785458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27091919982623075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083016171552391882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019180186796255272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5217043293859227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32964230094120878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50887915950200813,
                                   -0.31362585295357304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23897254123057943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25714854272590654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30278048948622754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19917965234257887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75551637122783288,
                                   0,
                                   0,
                                   0,
                                   -0.4008090173856832,
                                   0,
                                   0,
                                   0,
                                   0.67421251785504754,
                                   0,
                                   0,
                                   -0.074661236695946542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2393170712962546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12156415239021864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29584446607868631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64595056900119863,
                                   0,
                                   0,
                                   0,
                                   -0.23661646521284643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011292236614146297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16174849724668039,
                                   0,
                                   0,
                                   0,
                                   0.022395661734555886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39445557154297906,
                                   0.16700082775018504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81468385272639809,
                                   -0.29503937707384653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27826993606183936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2466886408545072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48473315702823488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048542012318693394,
                                   0,
                                   0,
                                   0,
                                   1.0023603698119257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2070292534073028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20282603206197519,
                                   -0.13945084141883735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27339789294192185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27707936981219083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13476241426208541,
                                   0.15670338133988496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36568388993782686,
                                   0,
                                   -0.22167415935616999,
                                   -0.3012008604632449,
                                   -0.43744788793761369,
                                   0.39084822805400332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33630959517460407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039934875299677583,
                                   0,
                                   0,
                                   0,
                                   -0.22903263439784147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13164116429787912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05975269404399268,
                                   0,
                                   0,
                                   0.35701057499201949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068867146003162072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29360914437910901,
                                   0.49120460529412069,
                                   0,
                                   0,
                                   0.047443476131514527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078832253567203456,
                                   -0.31107561945439266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57963795716985933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12167011403309082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099977014782116666,
                                   0,
                                   0,
                                   -0.140852768733325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23336739057919251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36036216516504771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33414207974828636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25634476777981147,
                                   -0.47375988957335541,
                                   0,
                                   0,
                                   0.26493363287287852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24471872471171169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33728466494577769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47380278414449267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32885750537914032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32948230896102926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64947642559172847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35823770136833616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1086396851167695,
                                   0,
                                   0.059898638659002912,
                                   0,
                                   -0.49305122295967146,
                                   0.66099859886314105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27601817961098257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11583993849105703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25999859038131173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22486963403993865,
                                   0,
                                   0,
                                   0,
                                   -0.23779684642898857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48878981032543051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57932126043238164,
                                   0.13994932594743809,
                                   0,
                                   0,
                                   -0.32985078394192091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23625027242056235,
                                   0.22263260448936645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026017855388791783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23903047003467165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15475029438929383,
                                   0,
                                   0,
                                   0.063605238396019864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22215189103793126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37488124952845892,
                                   0.10959612692865546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9546651307911217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45236275899550005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40425641136022106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39772546065856301,
                                   0,
                                   0,
                                   0,
                                   -0.092133717412267641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23057918118608658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16225483453416212,
                                   -0.70794047826003825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15533633476638445,
                                   0,
                                   0,
                                   0,
                                   -0.46876321830638129,
                                   0,
                                   0,
                                   0,
                                   -0.20082602323444501,
                                   0,
                                   0,
                                   0.64102379941271959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13504231380070519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57271763296576605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16370428658573918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30228893669169238,
                                   0,
                                   0,
                                   0,
                                   0.50344962278223104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055873539046414532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018000216023384877,
                                   0,
                                   0,
                                   0,
                                   -0.083087127401302086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28773094929366649,
                                   -0.075166473069487399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36644653952899925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16969669673403082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82166246173228441,
                                   0.22978236115755804,
                                   0,
                                   0,
                                   -0.031789028912571127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17678699031026698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27694615716536869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0052415641603461571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45135048353621421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13386754577629684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061614508142503015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30245299012478721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20144147920616015,
                                   -0.29977828054532113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68226617495323083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022023236569618444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2938479542851255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017988847852122972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020680172250783432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43493907344554178,
                                   0,
                                   0,
                                   0,
                                   0.89446378186878306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94872375122486141,
                                   0,
                                   0,
                                   0,
                                   -0.10450326835887971,
                                   0.16968683856831906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64654841773734417,
                                   0,
                                   0.71039282298199924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19076798816326848,
                                   0,
                                   0,
                                   0,
                                   0.14487306831026242,
                                   0,
                                   0,
                                   0,
                                   0.57079682103095242,
                                   0,
                                   0,
                                   0.33016664171258175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71329518024940486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51184022696068543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38977066481567557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44582755983266953,
                                   0,
                                   0,
                                   0,
                                   0.018535071022760616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34852375844447325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0062026949407408757,
                                   0,
                                   0,
                                   0,
                                   0.41329739067070681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20140243126567892,
                                   0.078747721423066533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28840646078772092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0063638002920916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43401421974007093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095853436166987604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40265582625976326,
                                   0,
                                   -0.10829102983597941,
                                   0,
                                   0.48295537261344973,
                                   0.39372252844582811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18442669769020617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28077786172897345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26508908101886153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61365488890088971,
                                   0,
                                   0,
                                   0.81690397544699955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92534523698377613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087243796837357515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61989126335225553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33700661060337944,
                                   0,
                                   0,
                                   0,
                                   -0.096736133783668174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71925854384866228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64681985170455014,
                                   0,
                                   0,
                                   0,
                                   -0.32542233769532902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40090608379731585,
                                   0,
                                   0,
                                   0,
                                   1.0565676221888867,
                                   -0.40168269558743153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49300378169120035,
                                   0,
                                   0.68674191788392391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56639437732529196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070026519433428983,
                                   0,
                                   0,
                                   0,
                                   -1.0431430570580738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48595077100293854,
                                   0,
                                   0,
                                   0,
                                   0.53115946193467345,
                                   -0.02646148930390857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42277139834597394,
                                   0,
                                   0.22347183011827149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047260277566420109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70740107905906435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12692495112805324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017504198893276996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28001901423254888,
                                   0.0083287002311969727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091745218311137577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49898499803169349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29336247497897033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24287665318823481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.06796717576977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68393683012369966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58910141480435307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66335333643040217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052414518155042944,
                                   0,
                                   0,
                                   0,
                                   0.89749735680964404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34842424385697962,
                                   -0.33275562783376217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85143144074666699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58621877846208692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02609707748787865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3940905315920249,
                                   0,
                                   0,
                                   0,
                                   0.27240566425034429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74110512278370677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0392208311031166,
                                   0.5548692349253217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094199639029623639,
                                   0.22210444502314777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23328673479518525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53399830608455368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46450321231710812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94478814513490794,
                                   0,
                                   0,
                                   0,
                                   -0.3172744269717252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034816307696019289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57901833386528012,
                                   -0.4444691788679066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1930671961122758,
                                   0,
                                   0,
                                   0,
                                   -0.010021064651865717,
                                   0,
                                   0,
                                   0,
                                   0.44488265103715235,
                                   0,
                                   0,
                                   -0.14033979612372602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034633390194330815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44897711384678229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45078649286042194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42736019015775017,
                                   0,
                                   0,
                                   0,
                                   -0.47876012425152703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58127022117690264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57502551513600364,
                                   0,
                                   0,
                                   0,
                                   0.10387143848507507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27483677876010826,
                                   -0.079493623710452266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65658041900165964,
                                   0,
                                   0,
                                   0,
                                   0.45056286777901872,
                                   0,
                                   0,
                                   0,
                                   -0.31509967109527642,
                                   0,
                                   0,
                                   -0.39187888093102402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20480495608701893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14727248772777518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10303400225799225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017593884253394559,
                                   0,
                                   0,
                                   0,
                                   0.13346406351934945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5995940094588712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45552894564667124,
                                   0,
                                   0,
                                   0,
                                   -0.57295857266648287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29221929110332689,
                                   0.10884184363046989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4147592371163662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44216941686093669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094496404420308683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19897529867901381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99512859963713063,
                                   0,
                                   0.44003212793914659,
                                   0,
                                   -0.2184268709687672,
                                   0.10621833256140258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1081075135144195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32347163860055667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43612055058982868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2728147015303497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89638162426335577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62207990184483619,
                                   0,
                                   0,
                                   0,
                                   -0.22833017146823142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27363747780702913,
                                   0,
                                   0,
                                   0,
                                   0.11930537914852488,
                                   -0.39668105651109931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98418475068334788,
                                   0,
                                   -0.72760449403081018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1957863240519776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45844274557999798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5036165904815515,
                                   0.18646130874101594,
                                   0,
                                   0,
                                   0.21043126229243925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011506343908518735,
                                   -0.30131154708458396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48930472390635599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17661372381099028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11302485981039123,
                                   0,
                                   0,
                                   0.21067337775731618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011344719506516054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73705635163044936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84884950660767056,
                                   0,
                                   0,
                                   0,
                                   -0.49135388581722073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14177910981616329,
                                   0,
                                   0,
                                   0,
                                   0.045748754705763443,
                                   -0.17815916711759339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098655304977638525,
                                   0,
                                   -0.017038700388143369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69292547166538232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063639265334746592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4696393114394754,
                                   -0.16485606185981994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41012822602765681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31600722912473878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22749882179516387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12038529786375747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075390436445396725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43187478181836347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48401950203843475,
                                   0,
                                   -0.82313659073798129,
                                   0,
                                   -0.2319220945208833,
                                   -0.043379432962247298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057486033937152139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12695922926701467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18150574266533154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2766412691454111,
                                   0,
                                   -0.061985078111738437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30011219563763503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17892169347096912,
                                   -0.076129290551379736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22754873369620021,
                                   0,
                                   0.065229604182417703,
                                   -0.0289860201634832,
                                   -0.37609367667979521,
                                   -0.47974601570334158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13196124642887344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30362307863154286,
                                   0,
                                   0,
                                   0,
                                   0.058198381409209576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24228414255767827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51779944671767464,
                                   -0.10863989455843437,
                                   0,
                                   0,
                                   0.41767683164001373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1450747027401833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18171356527640214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23823487729037199,
                                   -0.38454033576473728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3565717105974664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1495883983956412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48257158551956486,
                                   -0.26924690915669397,
                                   0,
                                   0,
                                   0.64589878991929817,
                                   0,
                                   0,
                                   0,
                                   0.1791013969032281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62887357567277391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54831815476068069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1448617662290459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16093077367928985,
                                   0,
                                   0,
                                   0.37672032664974942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10528283848548525,
                                   0,
                                   0,
                                   0,
                                   -0.36615211611899767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1473199136588848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32500081409104054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22937492434298998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23599194901002188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45230897087503014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16349651630119769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13883163122275899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41094123902360602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31974411854221579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097074912541613365,
                                   0,
                                   0,
                                   0,
                                   -0.29852428983944568,
                                   -0.27718927678489663,
                                   0,
                                   0,
                                   -0.33251134489950224,
                                   0.16715051250042318,
                                   -0.20886026427767015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095694482398334391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23654331785093835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16902308036371533,
                                   0,
                                   0,
                                   -0.31417135623874354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09448762580501141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18746734392771094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.145319433610786,
                                   -0.0092507420176604956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25205781732779037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46482371268290612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64438932093250256,
                                   0.18152415721697554,
                                   0,
                                   0,
                                   -0.88489364276855198,
                                   0,
                                   0,
                                   0,
                                   -0.89689446956834318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08226014470154501,
                                   0,
                                   0,
                                   0.058053315295751633,
                                   0,
                                   0,
                                   0,
                                   -0.34031578490275066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093985905584167306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55052938686313146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71776316509920046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076857782000874911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12621271097839093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15499742261763011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032975175762478909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38649666116022519,
                                   0.22621770668075983,
                                   0,
                                   0,
                                   0,
                                   -0.29923594962788408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03865464939136929,
                                   0.58010457416599837,
                                   0.28547174210212678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4083125355255563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90970233689587721,
                                   0,
                                   0,
                                   0,
                                   -0.43554071713170384,
                                   -0.40550609856818187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59777793862476492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079827040305835817,
                                   -0.15723528871421033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5314854874532966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038779351776816497,
                                   -0.38854723186529033,
                                   0,
                                   0,
                                   0,
                                   0.66074987577577504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2782752908771553,
                                   -0.17462943114548213,
                                   -0.74589365350305348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058699401999275515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40101293013624817,
                                   0,
                                   0,
                                   0,
                                   0.046858371513806868,
                                   -0.174895445118259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14286726494705615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65523397213803514,
                                   -0.26534167135598602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1505094631979437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26338378673491758,
                                   0,
                                   0,
                                   -0.69232168705572883,
                                   0,
                                   0,
                                   0,
                                   0.25968630246411384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06373341907874483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10513751893141129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087121613003862133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18824355671971077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064099171786739628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11015761775806471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55632510599713414,
                                   -0.45750220107366335,
                                   0,
                                   0,
                                   0.090125466850190711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097434706559764342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76554876971462293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043758523984616493,
                                   -0.56513601126777868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035031708322850671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058556395336918074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19738898216516451,
                                   -0.61175885708492339,
                                   0,
                                   0,
                                   0.014976691866402204,
                                   0,
                                   0,
                                   0,
                                   0.27484650942437411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084852366685820704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11986330045558585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43063663335338209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60062589960033941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53605399938568343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2043893111060836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2565707216242521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19307011127686718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17162927227034719,
                                   -0.43448516200912379,
                                   0,
                                   0,
                                   0,
                                   -0.10386647139201083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29182413647996885,
                                   0.22509148509581309,
                                   0.35593847697116254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7580204680999667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1904622629292439,
                                   0,
                                   0,
                                   0,
                                   -1.1022673075449592,
                                   0.58665493703955496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32997579858645748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34090599441079777,
                                   -0.17103859967918017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20803641097794295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20040812778205547,
                                   0,
                                   0,
                                   -0.38216260604665514,
                                   0,
                                   0,
                                   0,
                                   -0.57794730043076825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25976979893935603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10707693988314868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031707650629188802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24273514488560846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45833829760969325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35801492551162584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051429715842760695,
                                   0,
                                   -0.69715446564246353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016953912626898326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17537615425984401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050571370907347382,
                                   0,
                                   0,
                                   0.099425454327915053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27779391480645488,
                                   0,
                                   0,
                                   0,
                                   0.11748124856669133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1362696164126373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3395978621728355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71708437113180945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04437711014131844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33455590775065874,
                                   0,
                                   0,
                                   1.2379360681951115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14411866120271455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034866073596311421,
                                   0,
                                   -0.90651770790724195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38329119859075583,
                                   0,
                                   0,
                                   0,
                                   -0.17675830394447223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02943114047597032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088657893243424865,
                                   0,
                                   0,
                                   0,
                                   -0.61084170247464675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24440552525942658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074919483044328342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74350454654751719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057815582573329416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20496118716831943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24787538266272574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18140969476360708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.239471680534105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12116769243570119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54316766052011045,
                                   0,
                                   0,
                                   0,
                                   0.14035965607727582,
                                   -0.037656993848443676,
                                   0,
                                   0,
                                   0.54644059033795278,
                                   0.16913928588302396,
                                   -0.1896562634245853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29980911118633302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13805029567036747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85790461476983959,
                                   0,
                                   0,
                                   0.32254987609819052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74096778683760567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015506949495262129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59064415787185021,
                                   -0.32363391320464152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30864662782101682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10850915804614236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30525234346556429,
                                   -0.58301020596393349,
                                   0,
                                   0,
                                   -0.56641668234180764,
                                   0,
                                   0,
                                   0,
                                   0.022544157613625659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2497017911949965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13118897933925561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39830682908816228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0038773235628237622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084131924006613942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86122308605835984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082573391102699623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078570693789213289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51841458302355614,
                                   0,
                                   0,
                                   0.026358996018881843,
                                   0,
                                   0,
                                   0,
                                   -0.38035096561278603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24255832552155338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47075067294754946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47178302659115928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16032879936844463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073771960279172766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21198378693477038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08234046940198915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59137376197414737,
                                   0.40993144096752809,
                                   0,
                                   0,
                                   0,
                                   0.4789512411736927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48308442255755046,
                                   0.2561123301570899,
                                   -0.90422156408961751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5010033994698917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010369574381202978,
                                   0,
                                   0,
                                   0,
                                   -0.44899285224585428,
                                   -0.20562271653129927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19780806658671757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6213916903221014,
                                   -0.13878735719612678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23846525777430685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15591058959921081,
                                   0.71597979970028613,
                                   0,
                                   0,
                                   0,
                                   0.4733554504313095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03785034857162313,
                                   -0.87444875626443486,
                                   0.027897954165220853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34555174544563844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064213558139435425,
                                   0,
                                   0,
                                   0,
                                   0.22612392444310203,
                                   0.70919819010995044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11072116305241175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14310002656881743,
                                   0.11789275934308811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77523043375447021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93020726953730826,
                                   0.093051685205448986,
                                   0,
                                   0,
                                   0,
                                   -0.51339853354401055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017403867950790838,
                                   -0.52455933159460766,
                                   0.010766421988059327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54649444008588599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29737852160958012,
                                   0,
                                   0,
                                   0,
                                   -0.29943806859191618,
                                   -0.68887433379980945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36494141864211427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28321898598539164,
                                   -0.060344209481508912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0098727153037370362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08883291005929915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061768057230433493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12573460941958409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26514213692988764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21186945861491074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17519043117732927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19361263135846932,
                                   0.0079026089085094398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69908601548677707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0099893768885489925,
                                   0,
                                   0,
                                   0,
                                   0.07966781386208234,
                                   0,
                                   -0.54211365434785153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98960488893357001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022041995381297141,
                                   0,
                                   0,
                                   -0.013788253890809732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63108180633829158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36156111457015694,
                                   0,
                                   0.057208131739140966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29371612220407856,
                                   0,
                                   0,
                                   0,
                                   -0.9401811927899224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28646667830064709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24446406333965803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55524565561900407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022290316300439896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017054721889463872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072834439354855757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25100606823270211,
                                   0,
                                   0,
                                   0,
                                   0.33111487271109558,
                                   0.20785092278490802,
                                   0,
                                   0,
                                   -0.35870713418481509,
                                   -0.07390716032046149,
                                   -0.36722857637376427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12438725333941419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20851533443906792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39647875943914462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88430697960370053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11007731511927145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61190328416648943,
                                   0,
                                   0,
                                   -0.96117053056524315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11458066587195043,
                                   0,
                                   0,
                                   0,
                                   -0.12678753457802511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93925983667695823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29393653032121148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049893426330297697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079987818366971844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40096189059523674,
                                   0,
                                   0,
                                   0.30577407441784565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43439420042017635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0076897635277426,
                                   0,
                                   0.18877967197470069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3062854185031265,
                                   0,
                                   0,
                                   0,
                                   0.1410577657159775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06842076091221018,
                                   0.41269946212431818,
                                   0,
                                   0,
                                   0,
                                   0.2619761556494441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14197984003474598,
                                   0.25161037890685461,
                                   0.74077862108379322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40510631425119031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30642996782092308,
                                   0,
                                   0,
                                   0,
                                   -0.12268529907669673,
                                   -0.12568085247983768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59766933829454294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36660302797464206,
                                   0.23218002587707687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46819654682180079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43425676895533671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10081819958779317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39074942573633037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05252898748287739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37628752921380815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093582279090855341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16662942007387169,
                                   -0.33052299249968736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076264639106085941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46383007456121284,
                                   0,
                                   0,
                                   0,
                                   0.36359519243618105,
                                   0,
                                   0.072770076227658409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21049474400267748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90926232078555347,
                                   0,
                                   0,
                                   0,
                                   0.00068608099498025589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15260628531043899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31013206135298593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09727769654182028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38538191988479459,
                                   0,
                                   0,
                                   -0.20258228190080244,
                                   0,
                                   0,
                                   0,
                                   -0.31304509455462259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26548810568209541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037421503711185786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36687475312074569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1046637750236166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65095203665544676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26184690048594833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052016505676679793,
                                   0.69821164297465155,
                                   0,
                                   0,
                                   -0.12367609310890472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11439069784567356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083068074398891967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025955423493989827,
                                   0.21153831211904756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054710203766426033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28368084441043939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91902798884785541,
                                   0.12599346654503263,
                                   0,
                                   0,
                                   -0.36971274372861807,
                                   0,
                                   0,
                                   0,
                                   0.7039092826851342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093913546618838162,
                                   0,
                                   0,
                                   -0.48044884664426896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56950319013413253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34635237746426228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2052092423465361,
                                   -0.1384384710576283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14003201870960469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0508333035165285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077393245030631178,
                                   -0.064183232281075475,
                                   0,
                                   0,
                                   0.032499446996667569,
                                   0,
                                   0,
                                   0,
                                   -0.44250256878981525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65121760647666493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10985314640922408,
                                   0,
                                   0,
                                   0,
                                   -0.27629263630451228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47506728341816701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50493583814586329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082832179400982697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079252533941994996,
                                   -0.041527438662440547,
                                   0,
                                   0,
                                   0,
                                   -0.22244823114777135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55592052941492798,
                                   -0.1923033523886733,
                                   0.03294803812517727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44602506421608323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20017733689390199,
                                   0,
                                   0,
                                   0,
                                   -0.49439427829756738,
                                   0.30642490835567443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68171108907304157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01959477599162792,
                                   1.1533544201217107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12049833904926506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20120511912170017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034130302091398598,
                                   0,
                                   0,
                                   0.43183159996731801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88802927831522638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0420291592085456,
                                   0,
                                   0.34226449920996149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47302046085322352,
                                   0,
                                   0,
                                   0,
                                   0.072925462412256753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13121424438603388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43048770711106465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31945247271670679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68154001794688646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11593763124736758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1233723911267872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33677138063356798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29805911102190469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51867377633410827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46772909616074715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29854003349116559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2006254707068566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25647569150610044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35190766618172092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15247345493250866,
                                   0,
                                   0,
                                   0,
                                   0.15823914391436159,
                                   -0.12570144658172466,
                                   0,
                                   0,
                                   0.11495351852981288,
                                   -0.12964792308584641,
                                   0.16096083054703347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073149557661195436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26046249723500575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69341726374845825,
                                   -0.33705024756879393,
                                   0,
                                   0,
                                   0,
                                   0.250052753823861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50115537026809531,
                                   0.3642957100809438,
                                   0.04056674656766654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42749655973117806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41210484857661522,
                                   0,
                                   0,
                                   0,
                                   0.2154360060672669,
                                   0.43195974056871889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51119425015594389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42559856905345794,
                                   -0.42977999206387563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52212249964994395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082770738633143617,
                                   -0.33604520786049469,
                                   0,
                                   0,
                                   0,
                                   0.76843857474118715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5901571039072645,
                                   0.035960558875740255,
                                   0.51769323754755148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075230448425206348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45916788835250416,
                                   0,
                                   0,
                                   0,
                                   -0.20771213081739914,
                                   0.16335151434317391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18545057471935966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.869237237650895,
                                   0.35857500952471311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015642179651466401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27026679799763087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42587704586865294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27497939670919525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2877752258860331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31930181343503106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38903122402773965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016506615867310892,
                                   -0.014431846479735182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27857191755597493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3406887001643516,
                                   0,
                                   0,
                                   0,
                                   -0.088215686441340896,
                                   0,
                                   0.36321281854796073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26561743663102183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0075210429312616775,
                                   0,
                                   0,
                                   0,
                                   -0.25370424685174253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77256592276614477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5104300149365758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087338772790352542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42064558409679087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058352581297247942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21130244093693085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56612873936189445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021879394280503964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28517321740211449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066460329115467565,
                                   0,
                                   0,
                                   0,
                                   -0.046509364234073515,
                                   0.3741010405981734,
                                   0,
                                   0,
                                   0.015550824105637212,
                                   0.36609269926982074,
                                   0.25911105768730547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15379953013731573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033303344896842092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23856859018520427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20971293114076373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41012286411088672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59667915173414099,
                                   0,
                                   0,
                                   0.094552582680330538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99955291398003665,
                                   0,
                                   0,
                                   0,
                                   0.66012962303469891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072717001135407328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18271356400714001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06970401471364554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69367297964930663,
                                   0.10057599423765841,
                                   0,
                                   0,
                                   0,
                                   -0.4546627964761637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61312295566360764,
                                   -0.077675233708642488,
                                   -0.032728867805442874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37195449760419569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43396095084289427,
                                   0,
                                   0,
                                   0,
                                   -0.60678918268638471,
                                   -0.091923184997008328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20890325470601148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37095593974528296,
                                   -0.28716729742523306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58608213917684515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38610953955686372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.177528702065328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41799633329552155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34019496684008227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26680733285208613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37235084547909963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25146696409539393,
                                   -0.19007683753908808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084248435719147363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091509318237398746,
                                   0,
                                   0,
                                   0,
                                   0.43236597134793409,
                                   0,
                                   -0.13168600030550803,
                                   0,
                                   0,
                                   -0.14516325889188897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4655773222777308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13999742439571758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15366018192032682,
                                   0,
                                   0,
                                   0.25190122922501151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22106038956821866,
                                   0,
                                   0,
                                   0,
                                   -0.91840669551920873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065158408178235344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18424768914505965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27423807279677648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89015901692591404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0448586521087799,
                                   0,
                                   0,
                                   0.29568255292525625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32012134569141376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19298671408198614,
                                   0,
                                   -0.66555986338130824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17437392966681248,
                                   0,
                                   0,
                                   0,
                                   0.47938877712713873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33344756859618574,
                                   0,
                                   0,
                                   -0.031394676100921254,
                                   0,
                                   0,
                                   0,
                                   0.093588531301930705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17463960143329907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088586755385932026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078222633243165196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45903429409523666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51671700170112189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51862094761888156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29652363453333397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74516683632957781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50422316266798883,
                                   0,
                                   0,
                                   0.027404338728971425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32464704956631119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69928115602444685,
                                   0,
                                   0.42418499897545031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96512652004352151,
                                   0,
                                   0,
                                   0,
                                   -0.028295995624854992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12489383409035842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17876804185973094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10602372330141377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06345132907130592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48856037000985209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042822151744602799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26606853576695227,
                                   0.017105842299347192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088043785630607829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24452441920469956,
                                   0,
                                   0,
                                   0,
                                   0.73188600830843864,
                                   0,
                                   0.14955045980829576,
                                   0,
                                   0.20266185189763194,
                                   0,
                                   0,
                                   0.14897207733129547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51111684996179618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26966237932211939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43666226894026683,
                                   -0.074323526079457233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63480433263418246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64533194853975939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12619444547470648,
                                   -0.42578821607356332,
                                   0,
                                   0,
                                   -0.37956830331397073,
                                   0,
                                   0,
                                   0,
                                   -0.122002458803308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73791026222788159,
                                   0.65203947084945912,
                                   0,
                                   0,
                                   0,
                                   0.24752506580610101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56469566336759114,
                                   0.835581754456447,
                                   -0.50421045484068672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060750173625735468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53123733728988043,
                                   0,
                                   0,
                                   0,
                                   -0.27222495641762806,
                                   0.10446760854762317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047802732603458381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34060158881646929,
                                   0.45252721392955531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16132156970723782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18752239870083198,
                                   -0.13454849126758395,
                                   0,
                                   0,
                                   0,
                                   0.78327263177069539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4458298654669488,
                                   -0.31278501877305803,
                                   0.44876849804424118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5764840113817834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54192728070128982,
                                   0,
                                   0,
                                   0,
                                   -0.37688952361398553,
                                   -0.87109994539627567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33961182032074622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36693762859007117,
                                   -0.019530196999482025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04069269443005652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30097193901758773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79849228263919181,
                                   0,
                                   0,
                                   0.42534745734961255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92354665888676313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79885030954881942,
                                   0,
                                   0.75713736783594454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41932098503718929,
                                   0,
                                   0,
                                   0,
                                   0.13544329006789216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64437880715615414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38411177225365883,
                                   0,
                                   0,
                                   0,
                                   0.080928279689177263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19979584104282966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61858148442083138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090129250992248722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0256752683064765,
                                   -0.14921502066780845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3233851592579331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11131938700176694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76428654716441535,
                                   0.400343583954337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1077722335122364,
                                   -0.3802863185792929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031589298521291109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31805072338270995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.426576912059622,
                                   -0.78174657119794821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42144608728330074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74837210163854928,
                                   0,
                                   0,
                                   0.96852808592805006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30426990187838343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42545052573286041,
                                   0,
                                   0.59489805973639986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075271903244920668,
                                   0,
                                   0,
                                   0,
                                   -0.49406687691319778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21661042638605948,
                                   0,
                                   0,
                                   -0.24714739335676386,
                                   0,
                                   0,
                                   0,
                                   0.24973840926982471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56455984389130476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092648977750461131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022272632408997503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0082046575827573569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21411964672240599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46252821796743104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49190873500200538,
                                   0,
                                   0,
                                   -0.25827948175572324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27944373997687172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1498596689361231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061349311886790409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040838039986737892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25989461675349712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041942219747784712,
                                   0,
                                   0,
                                   0,
                                   -0.20199518943449557,
                                   -0.0075658139303249952,
                                   0,
                                   0,
                                   0.3081889737386086,
                                   -0.72440046579516215,
                                   0.028788494335156817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29594347321296588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094879116287409929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087995964657322123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11342656375292225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15997871960787818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13015416192056861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45687799586366595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1229755473759743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060471157777457388,
                                   0.059743152418082653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47440974186914431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2650313191670412,
                                   0,
                                   0,
                                   0,
                                   0.0040074855097183455,
                                   0,
                                   0.64066299366056245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017709525799079417,
                                   -0.76571008773424998,
                                   0,
                                   0,
                                   0,
                                   -0.0681846009994896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26307671788012466,
                                   0.21858939826107499,
                                   -0.12461543950574622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63054307831355905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38797093565106633,
                                   0,
                                   0,
                                   0,
                                   0.38362533827324014,
                                   -0.4512314335074345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11552512841210462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2357434685285032,
                                   0.63667903309868246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79103169816304852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65960949550298742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49447673760277522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055424934471027587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25316133804536917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14858343101621177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022383188725213859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12838378468409617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46280130044123824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12802224273107529,
                                   0,
                                   0,
                                   -0.78201107642353673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40392819752868941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84650357505839879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60993863354749456,
                                   -0.49801049370596268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33412736519063513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19609577422360822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058515030793527392,
                                   -0.38540598519446789,
                                   0,
                                   0,
                                   0.32219215642648219,
                                   0,
                                   0,
                                   0,
                                   -0.36324720112641951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8047825722276345,
                                   -0.27092514720186089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0494254246215897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048421481614261908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16593083363181901,
                                   0.25270245417422466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20342592071593402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46323427746656509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41565040295499806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0037041782509038071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016413831787652173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50860355527695744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43805669154855315,
                                   0.06995743061038194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020709094313216547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28118412450979519,
                                   0,
                                   0,
                                   0,
                                   -0.18962164282575214,
                                   0,
                                   0.0082750972079978259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25891735770161717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64214094416568868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048371681190284593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088938147366647513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17119166388536439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16974310232843662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2094966130858697,
                                   -0.44178073942189183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13334592215465363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36800911629504363,
                                   0,
                                   0,
                                   0,
                                   -0.21471756586418347,
                                   0,
                                   0.11778437585658391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21204888582096171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075602093348530436,
                                   0,
                                   0,
                                   0,
                                   -0.69254537151769791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2334777377279886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0079449305107870682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64430235600797203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14371898149793189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26630542756414033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19465448016496928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46021569561730274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34579430325293292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23779961857863452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36218340063700977,
                                   0,
                                   0,
                                   0,
                                   0.13499592001311395,
                                   0.12873805868112748,
                                   0,
                                   0,
                                   0.17646958663821252,
                                   0.2617059140054443,
                                   -0.16707584162544337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43378015821136257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030492571084839326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56147825098557347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60675315910585248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21313285156953451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014487516357168887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059444356822131422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14755230149021001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41401890602621971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27247074935979065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097347231002417142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15242102261900956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051634944843085548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90240088408868513,
                                   0,
                                   0,
                                   0.65785964541779474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53331682080514664,
                                   0,
                                   0,
                                   0,
                                   0.26422883997660679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3698873530029449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44027895991252458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099540036476269356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052504963620963713,
                                   0,
                                   0,
                                   -0.48332546357558209,
                                   0,
                                   0,
                                   0,
                                   -0.048936101483806477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62661034459926679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20784233843665678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21128136654169127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25068057341842542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10616524993107099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29663768125773626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34447130714841789,
                                   0,
                                   0,
                                   0.014391289109491917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080601507289856406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29954315858656844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011248346038596715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45123222461225698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36653064959040565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023111862437886828,
                                   0,
                                   0,
                                   0,
                                   0.29221709605165908,
                                   -0.027761287049532041,
                                   0,
                                   0,
                                   0.16842474336069735,
                                   0.015285914532397443,
                                   0.20502869176694824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54598965169947022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33173894106573065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051327383090590276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29491099985435743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23928591824606857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11049060545525834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12355882326616828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50566539961213675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48300259779433846,
                                   0,
                                   0,
                                   0,
                                   0.067962690861672184,
                                   0.0047508454094593935,
                                   0,
                                   0,
                                   0.42947220156843113,
                                   0.1020166236972178,
                                   0.15646804679589713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18526078701187329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27995038580626808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71439434860714546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50534242112156413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11371328562980111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47745355414182816,
                                   0,
                                   0,
                                   0.34049446219860702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37082187763304719,
                                   0,
                                   0,
                                   0,
                                   -0.2236185548972435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36840280634543554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18888419463063291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61398779194019826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26893264656665511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22260229124506156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021703487872063568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21199367222502241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28311700446458143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11910145702427104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50268360129315948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69690737892669652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025299029989734649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08637295043722229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34803598143201731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22550972434914923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38378753006025518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15805669049575716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12483627720296021,
                                   0,
                                   0,
                                   0,
                                   0.10431674368629759,
                                   0.27578877477627328,
                                   0,
                                   0,
                                   -0.01732005494581516,
                                   0.19768359636606228,
                                   0.28902747143600332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27839829439655112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58710680559145367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14690581429113811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28627751317543365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3530900544163979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33589085765343252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069860725485889508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19748728423412687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045948397928748858,
                                   0,
                                   0,
                                   0,
                                   0.63774680599993294,
                                   0.10107110616043836,
                                   0,
                                   0,
                                   -0.052376686424837213,
                                   -0.2326532267478193,
                                   -0.29039183228274235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013598716875541816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23378637493444873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54376583603746065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32768087136265495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10302560635268976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39790798056413834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28486953489082983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11474188945538064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36755615491006782,
                                   0,
                                   0,
                                   0,
                                   0.19056954763258538,
                                   -0.055640214290686503,
                                   0,
                                   0,
                                   0.08082195397241794,
                                   0.14558600336313499,
                                   -0.15089175799466692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25466420181373128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2093389800228935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22294982826065574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6168572001969016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18585741835075598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11576735001658936,
                                   0,
                                   0,
                                   0.23644460489075461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30657440996348106,
                                   0,
                                   0,
                                   0,
                                   -0.15151018589176246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22269415350692115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49541277761932362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1366648688098775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24683333471977711,
                                   0.18430403844829724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51621555178216771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2290154380843321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14138462714265895,
                                   0.97232700014518725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56036906187565916,
                                   0,
                                   0,
                                   -0.51789711850823272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44648280314238964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50854114553300722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030713318764477054,
                                   -0.61498827390574651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25729144771227141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36057374717432356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31767120534801285,
                                   0.96564216680222548,
                                   0,
                                   0,
                                   0.20095441442485323,
                                   0,
                                   0,
                                   0,
                                   0.051335239015947623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14241487105441838,
                                   0,
                                   0,
                                   0.22933178598955831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31474633197769192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34410959533882746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50926561476092913,
                                   0.17973572629264919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16673628410026711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26091669514954435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51604386163931681,
                                   0.93607959450717249,
                                   0,
                                   0,
                                   0.16201926823316518,
                                   0,
                                   0,
                                   0,
                                   -0.21324546585199194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033273705192318856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10879792822659975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074908569543812017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046778862085963914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0022581236325196069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098824023455721333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052523906654583022,
                                   0,
                                   0,
                                   0,
                                   0.38882382951925959,
                                   -0.54221311580335307,
                                   0,
                                   0,
                                   -0.23613921738141194,
                                   -0.0029169846364392737,
                                   0.53800963462592621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32300583086529711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26830926607789729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10308579020700827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20293424129184079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57806756757404332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11634091578756406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71682469734029175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1706752669649409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2302796610107691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067061736151488416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62214995742013579,
                                   0,
                                   0,
                                   -0.3181585642354281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0057444973978997352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39551504731739134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079493811120799673,
                                   -0.0048938321523971165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04377022246253863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2195842534536801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17812569658458366,
                                   -0.36401288564123252,
                                   0,
                                   0,
                                   0.69066801906961039,
                                   0,
                                   0,
                                   0,
                                   -0.93144774497698446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61268500260646508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045491903249795518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5047840056665297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0065456195209804419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12557262063725913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43101391316377397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26066414948377398,
                                   -0.030411905751882157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050220852140716227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26006082720895435,
                                   0,
                                   0,
                                   0,
                                   -0.16470083941677027,
                                   0,
                                   0.0023544071896314384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21394492411729898,
                                   0,
                                   0,
                                   0.18027344659508293,
                                   0,
                                   0,
                                   0,
                                   -0.10613822387790181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21907029220161628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43355515871741557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21124790055105649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53008731167040457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031634027530937921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38360202366132856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44803170090670186,
                                   0,
                                   0.47576660069859927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095340980411118742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61732403616428677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061782443454667088,
                                   0,
                                   0,
                                   -0.59786094058536188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47366127370594802,
                                   0,
                                   0,
                                   0,
                                   0.020463248221952168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85434801121513382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39176201133370564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017267109007468695,
                                   0,
                                   0,
                                   -0.11897144937412656,
                                   0,
                                   0,
                                   -0.89402118903526262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57528247986446535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26588004278993238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22744475021506019,
                                   0.62988267015337518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78479896858917852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26550921197261579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76201458441858472,
                                   0.029951081121405945,
                                   0,
                                   0,
                                   0.21116342227412571,
                                   0,
                                   0,
                                   0,
                                   0.66047366687828912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28273300478110952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28233286818685216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41318662580596371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22794653335238185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26930065410571069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36838996460534845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56597222641390854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29851100539332587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22081086620574619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01846856080694545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14927181879671911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76013344826908524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066501773212656809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18728615850190317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.164070338994183,
                                   0.32735495408073262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09918435699687364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25805084247405929,
                                   0,
                                   0,
                                   0,
                                   0.11174227267759591,
                                   0,
                                   0.29719269166578638,
                                   0,
                                   0,
                                   0,
                                   0.061008016481927142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14270938329760058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019867833228797774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18567138411544515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36576409240323715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26751326406427983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2873376158961497,
                                   0,
                                   0,
                                   0,
                                   0.014254850079968462,
                                   0.56745387938148772,
                                   0,
                                   0,
                                   -0.21080677082184823,
                                   -0.26241322194146111,
                                   0.34227915770460121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037796018229349075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3147109411404907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13790545970045268,
                                   -0.74950081031909099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17267329762657974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36203976450131692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49871876913307744,
                                   0.93779014705076946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18125866358202475,
                                   0.84014020678069057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36526505295946515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.525179173191471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.4470847492202907,
                                   0.15136136197556316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085210130400226389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23734257055217159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27653165426968679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25362639122510922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30318484421739728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13227131562155345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53202318842405516,
                                   -0.53899382464610113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25099287431012129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21804473833394705,
                                   0,
                                   0,
                                   0,
                                   -0.035952959387374181,
                                   0,
                                   0.028254607706759347,
                                   0,
                                   0,
                                   0.11793352177706212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.997700924847993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37948370664679837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075685761150616884,
                                   0,
                                   0,
                                   -1.0887609060811017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76818637423871916,
                                   0,
                                   0,
                                   0,
                                   0.07633092984324398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20611133824738587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15279135189962256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16890063358521173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13506248097028078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20648490632012617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12519212951749167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23943937425425915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22641216922733953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35744706721727842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42789649730729945,
                                   -0.50182467748920367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30721153798768525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36609388986058766,
                                   0,
                                   0,
                                   0,
                                   -0.089948474389357658,
                                   0,
                                   0.12517642576490265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50969536798946391,
                                   0,
                                   0,
                                   0.036991622369190152,
                                   0,
                                   0,
                                   0,
                                   -0.39404678613557209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021136514781494121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45143271993999418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15219670748134953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5553953159531958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12486529385061847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064195170387606207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16730502954444812};

const double rot_29_30[9000] = {0.50589067520932718,
                                0,
                                0.59539729473944725,
                                0,
                                0.62741205462167926,
                                0,
                                0,
                                0,
                                0,
                                0.8916686835690989,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.035233222048192292,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.064168085783718354,
                                0,
                                0,
                                -0.78805816238835014,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39005470929472602,
                                0,
                                0,
                                -0.085197998868041469,
                                0,
                                0,
                                0.14883737421004667,
                                0,
                                -0.34013693959524594,
                                0,
                                0,
                                0.28586230216665998,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.072069326943754286,
                                0,
                                -1.3388519611174436,
                                0,
                                0.72572458060693323,
                                0,
                                0,
                                0,
                                0,
                                -0.064354502256883411,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69512840142344756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54746890859810038,
                                0,
                                0,
                                0,
                                0,
                                -0.039191618368561706,
                                0,
                                0,
                                0,
                                0,
                                -0.36781804764285597,
                                0,
                                0,
                                -0.24940184870768239,
                                0.11936652714049412,
                                0,
                                0,
                                -0.72927177338132254,
                                0,
                                -0.20496906822696148,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13229979125278252,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44200834583903348,
                                -0.19847137066190701,
                                0,
                                0.14439732777307154,
                                0,
                                -0.48521585079393559,
                                0,
                                0,
                                0,
                                0,
                                0.34559950226807568,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41600591025227251,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1334579739898585,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46239324709869173,
                                0.29369662224243792,
                                0,
                                0,
                                0,
                                -0.22195616008337016,
                                0,
                                0,
                                0,
                                1.1685198468003308,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50515247200593838,
                                0,
                                0.32796172253079964,
                                0,
                                0,
                                0.62849330327069119,
                                0.33639770437119143,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22693536982186785,
                                0.0983333780903691,
                                0,
                                0,
                                0,
                                -0.97045628965496156,
                                0,
                                0,
                                0,
                                -0.38692660455460215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3798073579872312,
                                0,
                                0.27439723979008296,
                                0,
                                0,
                                0.38460706190258831,
                                0.3291059444843088,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12137033270870336,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.007003905212808418,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34242441772669574,
                                0,
                                0,
                                0,
                                0,
                                -0.040011173358637214,
                                0,
                                0,
                                0.25658566007521133,
                                -0.651871059377652,
                                0,
                                0,
                                0.014682470574577042,
                                0,
                                0.37921418718101541,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34920988222222338,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35271238792738047,
                                0.20382622359058816,
                                0,
                                0.60643918011207398,
                                0,
                                0.51470067266715569,
                                0,
                                0,
                                0,
                                0,
                                -0.86995129469323718,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.043616171041830742,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13047657427339904,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87473030200583912,
                                0.035333898872550867,
                                0,
                                0,
                                0,
                                -0.45268687785044609,
                                0,
                                0,
                                0,
                                -0.68342345232792145,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23601791036177688,
                                0,
                                0.49373717016025775,
                                0,
                                0,
                                0.355554291597456,
                                -0.04201945377181325,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52960499235902891,
                                0,
                                0,
                                0,
                                0,
                                -0.28572046940335538,
                                0,
                                0,
                                0.36985269997603037,
                                0.041817837212164762,
                                0,
                                0,
                                -0.33101624114867478,
                                0,
                                0.56240191534999273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.03206099625836048,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26915987901067334,
                                0,
                                0,
                                0,
                                0.45118308615203451,
                                0,
                                0,
                                0,
                                0,
                                -0.055053109968117492,
                                0,
                                0,
                                -0.52145763166981351,
                                -0.56334215573255675,
                                0,
                                0,
                                0.010847408070060252,
                                0,
                                -0.18998297457857657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27778751040152749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30125310616561229,
                                0,
                                0.12298552519163657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.075468931141484327,
                                0,
                                0,
                                -0.56126358651818786,
                                0,
                                0,
                                -0.23187480712655012,
                                0,
                                0.40315987443292378,
                                0,
                                0,
                                0.66922221790799374,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51226574216734633,
                                0.39848326160478531,
                                0,
                                0,
                                0,
                                0.41953559414684716,
                                0,
                                0,
                                0,
                                0.20243378884190782,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20755162977011626,
                                0,
                                1.4665100682447649,
                                0,
                                0,
                                -0.042725702300329717,
                                0.016282989805548813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.074954288314461923,
                                0,
                                0,
                                0,
                                0,
                                0.34304586251074465,
                                0,
                                0,
                                -0.38032946349558877,
                                0.42991194038543856,
                                0,
                                0,
                                0.074894794615339447,
                                0,
                                0.46064665102541646,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55871844529122994,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13136112483783785,
                                0,
                                -0.28451141433389832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.052910581033025712,
                                0,
                                0,
                                -0.67022183095446619,
                                0,
                                0,
                                0.024171670923447922,
                                0,
                                0.23935886482835694,
                                0,
                                0,
                                -0.63967138985057348,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32410574984278395,
                                0,
                                0,
                                0,
                                0,
                                0.46414827956592108,
                                0,
                                0,
                                -0.28318993035277085,
                                -0.18540138542290074,
                                0,
                                0,
                                -0.48461773014749215,
                                0,
                                0.29026072025904653,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39572596439744845,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29874229383869422,
                                1.0144581278269997,
                                0,
                                -0.00058028342613325457,
                                0,
                                -0.83304565035045897,
                                0,
                                0,
                                0,
                                0,
                                0.31814351297981036,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.020270075991544123,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16994555922243004,
                                0,
                                0,
                                0.030062202864051008,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.045444672136190356,
                                0,
                                0,
                                0.038802905208034061,
                                0,
                                0,
                                0.91657525994378786,
                                0,
                                0.37410121355288606,
                                0,
                                0,
                                0.12435214175094217,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57027555292441334,
                                1.1965028658250376,
                                0,
                                0,
                                0,
                                0.30395697685347955,
                                0,
                                0,
                                0,
                                -0.66755632732301151,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.055628548199317722,
                                0,
                                -0.19327921141996326,
                                0,
                                0,
                                -0.30262143110553452,
                                0.53014111275010034,
                                0,
                                0,
                                0,
                                0,
                                0.16877252035840101,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53321640036812046,
                                0,
                                0,
                                -0.41209692273807397,
                                0,
                                0,
                                0.23314974778775774,
                                0,
                                -0.66079597617316677,
                                0,
                                0,
                                0.1623641154935502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83534149675867908,
                                0.20043244665347956,
                                0,
                                0,
                                0,
                                0.33712613052043017,
                                0,
                                0,
                                0,
                                0.46301011642020562,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63702173386440597,
                                0,
                                0.073299062447159086,
                                0,
                                0,
                                -0.71455710498087943,
                                -1.0259919084582327,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48954561691176129,
                                0,
                                0,
                                0,
                                0,
                                0.64029664446039969,
                                0,
                                0,
                                0.28576744161501455,
                                -0.12307633371585769,
                                0,
                                0,
                                -0.16529864979774944,
                                0,
                                -0.21534528316931342,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068284188813987193,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4185624402605812,
                                0,
                                0.50349205428784405,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74362442587438882,
                                0,
                                0,
                                -0.23916029262168786,
                                0,
                                0,
                                0.17037672419827371,
                                0,
                                -0.29643426200373502,
                                0,
                                0,
                                -0.13935321706680867,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.032024944496249222,
                                0.3037739384240335,
                                0,
                                0,
                                0,
                                -0.50392146140760952,
                                0,
                                0,
                                0,
                                0.027907215817909801,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49229425754839296,
                                0,
                                0.24765507450120239,
                                0,
                                0,
                                -0.92527086950142345,
                                0.44772874974301885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0781662831068088,
                                -0.78346840878798796,
                                0,
                                0,
                                0,
                                0.28187646000785538,
                                0,
                                0,
                                0,
                                0.31418683472771941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.062257272572055954,
                                0,
                                0.10747421313619576,
                                0,
                                0,
                                0.040171247854787817,
                                0.6323863878875231,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31799709770106083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.034086449521893269,
                                0,
                                0,
                                0.12678949540449058,
                                0,
                                -0.66774076745964628,
                                0,
                                0.78289125766161671,
                                0,
                                0,
                                0,
                                0,
                                -0.030453646859155387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3105430594856475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3087529212452752,
                                0,
                                0,
                                0,
                                0,
                                -0.21643547901744081,
                                0,
                                0,
                                0,
                                0,
                                0.18801084055031281,
                                0,
                                0,
                                0.39590828162021025,
                                0.085830671010591456,
                                0,
                                0,
                                -0.30078309324546687,
                                0,
                                -0.34492698137756905,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55581232851361628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48510297826768556,
                                0.024350467137838266,
                                0,
                                0,
                                0,
                                0.51866307494780783,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2351791703788596,
                                -0.50036315342774962,
                                -0.092128029507729775,
                                -0.46999505435276523,
                                0,
                                0,
                                0.07489981059490905,
                                -0.43558034320136008,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11843588150378991,
                                -0.5491324893612316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14965923498209116,
                                0,
                                0,
                                -0.9050634785264583,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87650375688506832,
                                0,
                                0,
                                -0.67492600427310667,
                                0,
                                0,
                                0,
                                0,
                                0.79253764736168542,
                                -1.5812322297734882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32393481828517268,
                                0,
                                0,
                                0.76671935019656645,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20674984624150375,
                                0,
                                0,
                                0.024547952954125575,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56895346916735812,
                                0,
                                -0.61906425601454618,
                                0,
                                0,
                                0.48306440390425104,
                                0.1541718326118473,
                                -0.099348257095752374,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1614346566554361,
                                0,
                                0,
                                0.48200661619666851,
                                0,
                                0,
                                0,
                                -0.62284744716119067,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49498225670312795,
                                -0.10955299435700944,
                                -0.1194926120783938,
                                -0.2667244572810637,
                                0,
                                0,
                                -0.18873515487355311,
                                -0.040987892670613757,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34842207039986434,
                                0,
                                0.093171960189052244,
                                0,
                                0,
                                -0.42662151405188331,
                                0.76790506744319442,
                                0.26800962841685821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16250469812132284,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79624829833443822,
                                -0.42739968436850168,
                                0,
                                0,
                                0,
                                -0.44417330803439536,
                                0,
                                -0.18599868824402052,
                                0,
                                0,
                                0.5425759716310099,
                                -0.62495380135424683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44840018978881385,
                                0.56045998693020838,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33806584441648535,
                                -0.32577475630242136,
                                0,
                                0,
                                0,
                                0.7650879744503275,
                                0,
                                -0.83374892654143973,
                                0,
                                0,
                                0.078863706584019561,
                                0.24971668578418965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.070406862411129548,
                                0.64788239396092284,
                                0,
                                0,
                                0,
                                0.027585338815494756,
                                0,
                                0.3653765401893575,
                                0,
                                0,
                                0.41768778175176297,
                                0.32380900281189062,
                                -0.62357558955370629,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44449652838650822,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30904947543976213,
                                0,
                                -0.20690579340926535,
                                0,
                                0,
                                -0.31337881201474937,
                                0.31362989579814093,
                                -0.5702237316904899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58305515934849561,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67313721135142623,
                                0,
                                -0.44799900622970057,
                                0,
                                0,
                                0.25971833433996772,
                                0.34213820190311556,
                                0.30536632168632788,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26157681911392827,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14924645925977853,
                                -0.3267618843234984,
                                0,
                                0,
                                0,
                                -0.69448785219500542,
                                0,
                                -0.32489364181387126,
                                0,
                                0,
                                -0.89501495927373731,
                                -0.26280312081442025,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45881166142037733,
                                0.42524476614499251,
                                0,
                                -0.82960841312011169,
                                -0.36014327506380295,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10488162868609741,
                                0,
                                0,
                                0.061272755077890234,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83566814735207962,
                                0,
                                0,
                                0.6533945736210125,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73774758595392198,
                                0.67942910079791641,
                                0,
                                0,
                                0,
                                0.032509896102650537,
                                0,
                                -0.052373803720494452,
                                0,
                                0,
                                0.46190375044759346,
                                -0.27506476277394926,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61974985567875729,
                                -0.31843306846985486,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21367292104410898,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47154495211697417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.075740945459197073,
                                -0.21717873688169931,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.4955606433803175,
                                0,
                                0,
                                0.0056446081090041622,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16720774228952573,
                                0,
                                0,
                                0.54989870411082697,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.037428641711036673,
                                -0.57209671805905393,
                                0,
                                0,
                                0,
                                0.24117300893518226,
                                0,
                                -0.12903341146155875,
                                0,
                                0,
                                -0.05814617271407635,
                                -1.2171283036380094,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20419894841725394,
                                -0.66338021022861959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54807822360373148,
                                0.26668620730056514,
                                0,
                                0,
                                0,
                                0.4890236349668135,
                                0,
                                0.31899557368276488,
                                0,
                                0,
                                -0.45560355899176969,
                                0.40246854336964472,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60756458504600652,
                                -0.39298955836603577,
                                -0.068599202659221814,
                                0,
                                0,
                                0,
                                -0.041799678493519316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3741097180981644,
                                0.18758632107783821,
                                -0.81588453069836386,
                                -0.36689867092020478,
                                0,
                                0,
                                -0.10928762933940288,
                                0.078576326961893511,
                                0,
                                0,
                                0,
                                0,
                                0.22084673372877311,
                                0,
                                0,
                                0,
                                0.011324920880420614,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49399083712791841,
                                -0.37544605767875622,
                                0.36355636835890531,
                                -0.33411499180368404,
                                0,
                                0,
                                -0.39709363159996475,
                                0.40573681617026391,
                                0,
                                0,
                                0,
                                0,
                                -0.15299037165155416,
                                0,
                                0,
                                0,
                                0.34613442433012936,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54319393334285315,
                                0.088255710626174239,
                                -0.10075772080906117,
                                -0.1130019779786397,
                                0,
                                0,
                                -0.093103152369175907,
                                0.72273537652875341,
                                0,
                                0,
                                0,
                                0,
                                -0.034301463904822631,
                                0,
                                0,
                                0,
                                -0.12080804434034934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.026439198719699672,
                                -0.71906666270953079,
                                -0.37456684220822001,
                                0.52139756203595811,
                                0,
                                0,
                                0.11545716964645511,
                                0.20245205443718164,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37848695787437081,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19392629493422522,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.4009995451054997,
                                -0.55834471166835298,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.067494754627619696,
                                0,
                                0,
                                0.17796490344170895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1582715363447687,
                                0,
                                0,
                                -0.59656589219462641,
                                0,
                                0,
                                0,
                                0.083575078510752229,
                                0,
                                0,
                                0,
                                0.25751662851983259,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.094587853914875869,
                                0.08227464565306393,
                                -0.12629329883333645,
                                0.37488365304952009,
                                0,
                                0,
                                -0.83101060387810277,
                                -0.25282017018096464,
                                0,
                                0,
                                0,
                                0,
                                0.82585114172984275,
                                0,
                                0,
                                0,
                                0.37477428946961144,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10484632787808817,
                                0.17283354084645366,
                                -0.11397678059946928,
                                0.19118742702697905,
                                0,
                                0,
                                0.27670334790553142,
                                0.10267354495621477,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39113756224442592,
                                0.7627592282692407,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.030046067005276622,
                                0,
                                0,
                                0.83298883022206005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.9879194714435916,
                                0,
                                0,
                                -0.67612346887119379,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.074214394074188228,
                                0,
                                0.48069252096289061,
                                0,
                                0,
                                0.49448952404680713,
                                0.2574457659054335,
                                0.33324248288118574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58444688366927344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14365954735040509,
                                -1.1431159756940854,
                                0,
                                0,
                                0,
                                0.049480935761399919,
                                0,
                                0.21326301509046647,
                                0,
                                0,
                                0.12988358777036196,
                                0.58432403288892865,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55816043595370601,
                                0.48001895241579007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3510197361766727,
                                -0.2040047412736283,
                                0,
                                0,
                                0,
                                -0.68497100730900373,
                                0,
                                -0.62636645547752545,
                                0,
                                0,
                                0.26211693160074739,
                                -0.031725326430771916,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1154786542074526,
                                -0.95087480900995636,
                                0.31223804222722107,
                                0.14032849459210717,
                                0,
                                0.39901798363850649,
                                0,
                                -0.29311421608243321,
                                0,
                                0,
                                0,
                                -0.096717702430527325,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6498896207957322,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42332159295212757,
                                0,
                                -0.16362157380394554,
                                0.25715450095924319,
                                0.23124734748678286,
                                0,
                                -0.6229762124367928,
                                0,
                                0.50215034591477825,
                                0,
                                0,
                                0,
                                -0.37825065156495502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25031092406566402,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17888004948238873,
                                0,
                                -0.049139694072764306,
                                0,
                                0,
                                -0.18906280318991667,
                                0,
                                0,
                                0,
                                0,
                                -0.33009641082164498,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10603637618801837,
                                0.57134005856396353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70507267702377752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14314663996127391,
                                0,
                                0.51614986106945859,
                                -0.27070249237323241,
                                0,
                                -0.14429912296803088,
                                0,
                                -0.36361499678795767,
                                0,
                                0,
                                0,
                                -0.26368990797690273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53071621081692311,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22128993382945183,
                                0,
                                -0.32727676354343305,
                                0,
                                0,
                                0,
                                0,
                                -0.058452633225956153,
                                0,
                                0.45477635087257673,
                                0,
                                0,
                                0,
                                0.40329150914537149,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55318306323649025,
                                0,
                                0.23528515398722216,
                                0,
                                0,
                                0,
                                0,
                                0.58707577282951307,
                                0,
                                1.0027416453545333,
                                -0.68146559240670623,
                                0,
                                0,
                                0,
                                0.26820077594792013,
                                0.70144061197022023,
                                0,
                                -0.16568374218444687,
                                0,
                                -0.39154847145750526,
                                0,
                                0,
                                0,
                                0.11928175795254504,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.026936191251725305,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48917291668044527,
                                0,
                                -0.032315091548268511,
                                0,
                                0,
                                0,
                                0,
                                -0.019867109511745272,
                                0,
                                0.26796311863295691,
                                0,
                                0,
                                0,
                                -0.48862538743786066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58533611033363031,
                                0,
                                0.67543888095936133,
                                0,
                                0,
                                0,
                                0,
                                -0.25020291405773465,
                                0,
                                0.18234443796107802,
                                1.2495698718745354,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39297782933305792,
                                0,
                                0,
                                0,
                                0,
                                -0.28778594549008085,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12932509919387275,
                                0.66931101238784252,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.516174646416381,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17778975516840018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38005689812765792,
                                0,
                                0,
                                0.45302528579768475,
                                0,
                                1.2959480316329948,
                                0,
                                0,
                                0,
                                -0.55042610461852526,
                                0,
                                -0.62006703892005832,
                                0,
                                0,
                                0,
                                0,
                                0.34861690465319484,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12887024652930534,
                                0.024986857474955718,
                                0,
                                0.24245065745991143,
                                0,
                                -0.13872999477759049,
                                0,
                                0,
                                0,
                                -0.83627599856961621,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.029634410781548697,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23376362148962301,
                                0,
                                0.38711575651392283,
                                0,
                                0,
                                0,
                                0,
                                0.34798090362659184,
                                0,
                                0.40409410463232992,
                                0,
                                0,
                                0,
                                0.52173756194822374,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3140852208640226,
                                0,
                                0.27469385337374774,
                                0,
                                0,
                                0,
                                0,
                                0.12661763503243056,
                                0,
                                0.69264957452749132,
                                0.79425549696459219,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13388046304728857,
                                0,
                                0,
                                0.4963013820115561,
                                0,
                                -0.5914507383181935,
                                0,
                                0,
                                0,
                                0.35923184003259601,
                                0,
                                -1.1094184053655844,
                                0,
                                0,
                                0,
                                0,
                                0.38527781306250597,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2328568463915679,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.032647929261084924,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3156012626229443,
                                0,
                                0,
                                -0.79207099379111268,
                                0,
                                0.47174984178305457,
                                0,
                                0,
                                0,
                                0.60124842842036297,
                                0,
                                -1.1501978089826304,
                                0,
                                0,
                                0,
                                0,
                                -0.17583962167100178,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3610416553882666,
                                0,
                                0,
                                0,
                                0,
                                -0.24279763471125937,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59212090436482001,
                                -0.2157210546881746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19341223488678155,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61330840547609267,
                                0,
                                0,
                                0,
                                -0.65079869500533638,
                                0,
                                0,
                                0,
                                0,
                                0.17108472683402273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57901068341851114,
                                0.25652557573092361,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36935369290381964,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.098540254946574424,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.026472881641931567,
                                0,
                                0.024133655583406244,
                                0,
                                0,
                                0,
                                -1.0448484702728527,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.042882056146712033,
                                0,
                                -0.68351854126695244,
                                0,
                                0,
                                0,
                                0,
                                1.0489393165335581,
                                0,
                                0.03646572400489595,
                                0.013196638503562758,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72467524670493833,
                                0,
                                0,
                                -0.27659788576001676,
                                0,
                                -0.010928136058425839,
                                0,
                                0,
                                0,
                                -0.21204009105541849,
                                0,
                                0.19955278961539291,
                                0,
                                0,
                                0,
                                0,
                                1.1310018120738687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.012848214564068,
                                0,
                                0.2918005555817007,
                                0,
                                0,
                                0,
                                -0.26463053791197721,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64576809414811009,
                                0,
                                0.76980855513287039,
                                0,
                                0,
                                0,
                                0,
                                -0.18163286631384901,
                                0,
                                0.069607259575574704,
                                -0.85978941744159243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72336010533668171,
                                0,
                                0,
                                -0.070375665350577335,
                                0,
                                -0.34918242553884671,
                                0,
                                0,
                                0,
                                -0.44896512136880179,
                                0,
                                -0.71422885467636954,
                                0,
                                0,
                                0,
                                0,
                                -1.0670020438443073,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27882885088340809,
                                0.16098833238610444,
                                0,
                                -0.37669878499801968,
                                0,
                                -0.43390630530475427,
                                0,
                                0,
                                0,
                                0.092896282134162109,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.081227751461178999,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54684119407878928,
                                0,
                                0.50189402662819871,
                                0,
                                0,
                                -0.37719068339227524,
                                0,
                                0,
                                0,
                                0,
                                -0.82795312962346201,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16542766384479046,
                                -0.32289529748021228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20143885445981208,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0039378068417331574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16370813427232589,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12852465416963613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37112916815546215,
                                0,
                                0.073541196281629223,
                                0,
                                0,
                                0,
                                -0.024911912319140868,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21608558852533458,
                                0,
                                1.1493056381326554,
                                0,
                                0,
                                0,
                                0,
                                1.1029689268293665,
                                0,
                                -0.74285705592531814,
                                -0.071859002684388135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40820546809817598,
                                0,
                                0,
                                -0.41660898508658312,
                                0,
                                -0.43259874165036794,
                                0,
                                0,
                                0,
                                -0.93290522733398584,
                                0,
                                -0.49744332518615464,
                                0,
                                0,
                                0,
                                0,
                                0.16710516892324997,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0579760659847774,
                                0,
                                -0.65805073525250291,
                                0,
                                0,
                                0,
                                0.26355067537256405,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27831661602721414,
                                0,
                                -0.13551835406292603,
                                0,
                                0,
                                0,
                                0,
                                0.26457468419149338,
                                0,
                                -0.10248605087289278,
                                0.39291220063701965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55315062034391982,
                                0,
                                -0.93012156553342951,
                                0,
                                0,
                                0,
                                -0.32605081850848761,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11713999923352847,
                                0,
                                0.44403142781424931,
                                0,
                                0,
                                0,
                                0,
                                0.11113446295421756,
                                0,
                                0.095866650044358265,
                                -0.21543923444644189,
                                0,
                                0,
                                0,
                                0.63429748907509609,
                                -0.13063050924463879,
                                0,
                                0.15191185120179329,
                                0,
                                0.2038978183543107,
                                0,
                                0,
                                0,
                                0.23423139296461964,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.047219978945592711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.03916305250683727,
                                0,
                                0.67625662140853771,
                                0,
                                0,
                                -0.33713625156391702,
                                0,
                                0,
                                0,
                                0,
                                0.18571092889355847,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50872827401244169,
                                0.094820823671775648,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14841899932211661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74968456968892727,
                                0,
                                0.036745872543318563,
                                -0.5638509468211943,
                                0,
                                -0.42502993035796888,
                                0,
                                -0.35680246842528074,
                                0,
                                0,
                                0,
                                0.030984105764497616,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47211947103558349,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38121767096324444,
                                0,
                                0.059830469242804676,
                                -0.92660647237406746,
                                0,
                                0,
                                0,
                                0,
                                -0.82439447494345119,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20102462819434194,
                                0.60129907396388804,
                                -0.14858259092697068,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52645699517155087,
                                0,
                                0,
                                0,
                                0,
                                0.05446826581508931,
                                0.27206046582722465,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12152877752420031,
                                0,
                                -0.44592553275927593,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3350786360867089,
                                0,
                                0.6497580748994316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21371134867648103,
                                0,
                                0,
                                0,
                                -0.35952982853712762,
                                0,
                                0.318142638577533,
                                0.29700767480043572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63156799601202018,
                                0,
                                -0.1234888691835308,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45591763651251616,
                                0,
                                -0.18838146979321269,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38531110351780035,
                                0,
                                0,
                                0,
                                0.068051100586126234,
                                0,
                                0,
                                0,
                                0.011319975524558518,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10386564122456486,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22340227915713073,
                                0,
                                -0.50816170715533837,
                                0.43880488944054225,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32541281751296519,
                                -0.52959477103671659,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.099301568424130016,
                                -0.65852072832751674,
                                0.70351402073023139,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.85813547950120783,
                                0,
                                0,
                                0,
                                0,
                                -0.64938309271606809,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43637455090913957,
                                0.10539192458589697,
                                0.60285851793227629,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.074011060160861786,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12768755631280121,
                                0,
                                0.12812139519796045,
                                0.46609543462688624,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44034848919221142,
                                -0.44299489636087452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18121595937022633,
                                -0.17240943967386313,
                                -1.2134003453706637,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.072525112641177156,
                                0,
                                0.46145630725437337,
                                0.55084566385645628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.84692206141190163,
                                0.76445659016657674,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29847914516117457,
                                -0.50160553121476381,
                                0.26744644332053996,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34231889972073859,
                                0.54920058728748056,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.010961024992199142,
                                0,
                                -0.29743347830154021,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.011779442561215214,
                                0,
                                -0.26736608923006161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4218912983576551,
                                0,
                                0,
                                0,
                                0.49294423535172532,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42485134100781058,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26539788049796009,
                                0,
                                -0.079796345349020747,
                                0,
                                -0.76951358242682244,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.031453291366192293,
                                -0.38672649671682069,
                                0,
                                0,
                                0.36819826015974688,
                                0.12889774979237401,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.055695554521559845,
                                0,
                                -0.55190573733489523,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67341070745292819,
                                0,
                                -0.034386716331713356,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29223773246384155,
                                0,
                                0,
                                0,
                                -0.0067936859818572403,
                                -0.14592320949301199,
                                0,
                                0,
                                0,
                                0,
                                -0.60927065044179607,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33919407014024283,
                                -0.11339235652742977,
                                -1.1555623878588728,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.91705572548211745,
                                0,
                                0,
                                0,
                                0.0067388168029610118,
                                0,
                                0,
                                0,
                                0,
                                -0.2989214038334751,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29224967729980483,
                                1.3479660120825643,
                                0.50935115259403507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48857454398715472,
                                0,
                                0,
                                0,
                                -0.84469042233649927,
                                0,
                                0,
                                0,
                                0,
                                -0.28353562267053295,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32641402175634798,
                                -0.54545242635436653,
                                1.1054064450785743,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18951542973639957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76958722826604298,
                                0,
                                -0.022732107368554751,
                                -0.25892618208639817,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39843112083682858,
                                0.042882698814978533,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0575161655354646,
                                -0.92018175564380722,
                                0.096846635216792237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37777700367348876,
                                0,
                                0.33432316045271265,
                                0.97881667276754181,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33134703628174489,
                                -0.20340969674862236,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13333292533446062,
                                0.64212149434652754,
                                0.34034392252948176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63293312135135205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1688631540165022,
                                0,
                                -0.35955923016513774,
                                0,
                                -0.15840786208336427,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52210349873136475,
                                -0.3793585967890189,
                                0,
                                0,
                                0.30944553406829767,
                                0.062918180696220974,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30453229395793008,
                                0,
                                0.20901756423585599,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10544067489000501,
                                0,
                                0.44693287927190806,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23106171984749188,
                                0,
                                0,
                                0,
                                0.70682405935726089,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48417663570166031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62161574877047021,
                                0,
                                -0.28200845087724719,
                                0,
                                0.30711513578275673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.042883354448794903,
                                -0.45108689987553713,
                                0,
                                0,
                                -0.67406963258321584,
                                -0.094070796185971195,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14491694895715496,
                                0,
                                -0.27459207467481372,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12743588434637351,
                                0,
                                0.057841806278696097,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64631797523174195,
                                0,
                                0,
                                0,
                                0.055376726920386241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20027534901627475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36603668548573298,
                                0,
                                -0.82782384483588145,
                                0,
                                0.16022840717819881,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.079209036165141411,
                                0.32964738357689727,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90290207258415744,
                                0,
                                0.9072772674459354,
                                0.18269213849787247,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.096137248122276447,
                                0.11301136055421318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16387596140534999,
                                0.32094029651495853,
                                -0.009855145555995537,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3364037168460034,
                                0,
                                -0.95974606452140887,
                                0.48279781233727936,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39323138174981886,
                                0.5466710407820502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58256565676433636,
                                0.098780778916483986,
                                -0.050889660981346771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17510578396257087,
                                0,
                                -0.024927790521976446,
                                0.16291835462265655,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1681751086447341,
                                -0.4507448739760937,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75220113531596611,
                                0.59157365929837036,
                                -0.49004321941486501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39383692080957639,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11012178446887692,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18811933285952992,
                                0.64860444268607631,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.097335329242764029,
                                0,
                                0.52035584757569908,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33194914425656807,
                                0,
                                0.22264115096840306,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20775305133796079,
                                0,
                                0,
                                0,
                                -0.24649213433680192,
                                0.83615818874504977,
                                0,
                                0,
                                0,
                                0,
                                0.055305216513517663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1583223011385186,
                                0.33437443946678008,
                                -0.38184660966254241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.88977264088343166,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35078131195160989,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25643404243496015,
                                0,
                                -0.31521000929613208,
                                0,
                                -0.30289834153143641,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.78631227354009448,
                                0.042453577978984795,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14598713348387304,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56116110688678422,
                                0,
                                -0.013086973159594104,
                                0,
                                -0.41354025353597346,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31625714546222861,
                                0.62656250826056203,
                                0,
                                0,
                                -0.23989787436769913,
                                -0.29332216731055383,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67817068449422324,
                                0,
                                -0.054543045054973538,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29781337321003132,
                                0,
                                0.46582833616996938,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16789841935076763,
                                0,
                                0,
                                0,
                                0.24421705858673989,
                                0.38427542485404753,
                                0,
                                0,
                                0,
                                0,
                                0.036979757055664399,
                                0,
                                -0.22765978078878454,
                                0,
                                0,
                                0.97372213154532783,
                                -0.52042144887875386,
                                0,
                                0,
                                0,
                                0.76340488881221946,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29930894099744815,
                                0,
                                0.72771140719773619,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69730100193856726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70114217870525164,
                                0,
                                0.47091870134811287,
                                0,
                                0,
                                0,
                                0,
                                0.29656030432129704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35675746760938315,
                                -0.57544671935834812,
                                0,
                                0,
                                -0.73953168098742106,
                                0,
                                0,
                                0,
                                0.35042641282995096,
                                0,
                                0,
                                0.21581076161553459,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27237191997837296,
                                0.31476731881600417,
                                0,
                                0,
                                0.075409362267363278,
                                0,
                                0,
                                0,
                                -0.15727499554170316,
                                0,
                                0,
                                -0.28290106618823591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79028197776845577,
                                -0.38041633917873546,
                                0,
                                0,
                                0,
                                0.23973362985610064,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.052371603182450335,
                                0,
                                0,
                                -0.29479060401337848,
                                0.28917348803403914,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37280338024749426,
                                -0.024103733354358389,
                                0,
                                0,
                                0,
                                -0.10094894876104084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44469471458423887,
                                0,
                                0,
                                -0.61013413962086127,
                                0.52936651003668389,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66091749814058365,
                                0,
                                0,
                                0,
                                0,
                                -0.39788497387612731,
                                0,
                                -0.8333012705490892,
                                0,
                                0,
                                -0.063935034156384768,
                                0.5676134130216689,
                                0,
                                0,
                                0,
                                -0.66701996897990545,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31531548826307998,
                                0,
                                0.22586535627100868,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20170234180883867,
                                0,
                                0,
                                0,
                                0.58614670761298493,
                                0,
                                0,
                                -0.19318307345360664,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41636748339275487,
                                0.50103751153859621,
                                0,
                                0,
                                -0.030122666521670421,
                                0,
                                0,
                                0,
                                -0.22105909430392418,
                                0,
                                0,
                                0.32288316026986408,
                                0,
                                0,
                                0.19251120275997868,
                                0,
                                0,
                                0,
                                0,
                                -0.05889415673033857,
                                0,
                                1.1464405900172709,
                                0,
                                0,
                                0.41452698185329645,
                                -0.39205193564446356,
                                0,
                                0,
                                0,
                                -0.70651273301859652,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18215461648385189,
                                0,
                                -0.41313350039328794,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.033201678548996888,
                                0.25883003906348195,
                                0,
                                0,
                                0,
                                0.045616548759555509,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48177538689139121,
                                0,
                                0,
                                -0.71839120031111248,
                                -0.42618112323330515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42054766875904215,
                                0,
                                0,
                                0,
                                0.13402881037776909,
                                0,
                                0,
                                0.59101097013006143,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21066840500158224,
                                0.11322571689793109,
                                0,
                                0,
                                -0.57109883216131552,
                                0,
                                0,
                                0,
                                -0.15813051751694462,
                                0,
                                0,
                                -0.21799447923473364,
                                0,
                                0,
                                -0.32677711284883459,
                                0,
                                0,
                                0,
                                0,
                                1.0149469173918684,
                                0,
                                -0.051805034843163462,
                                0,
                                0,
                                0.29430970002188234,
                                0.12812043034394172,
                                0,
                                0,
                                0,
                                -0.40368370370220841,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61151512740604319,
                                0,
                                0.11909910733848218,
                                0,
                                0,
                                0,
                                0,
                                -0.073713744981855858,
                                0,
                                0,
                                0,
                                0,
                                -0.1323895692668019,
                                0,
                                0.065087145426071802,
                                0,
                                0,
                                -0.48265618878904537,
                                -0.0001618374104838307,
                                0,
                                0,
                                0,
                                -0.14789894153673674,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42058337071775787,
                                0,
                                1.5246311484414128,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27731544757836468,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68665540051264429,
                                0,
                                -0.53242101500145445,
                                0,
                                0,
                                0,
                                0,
                                0.92435652258119116,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85788286308431849,
                                0.77543064793089522,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48153124117318002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17475377008119375,
                                0,
                                0,
                                0,
                                0,
                                0.23162836012571403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0817548299477597,
                                0,
                                0.0052973286406300391,
                                0,
                                0,
                                0,
                                0,
                                0.41720706481646685,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47691428980770473,
                                -0.37708368441722862,
                                1.0929174264127715,
                                0,
                                0,
                                0,
                                0,
                                0.47999991286041976,
                                0,
                                -0.035685017316427786,
                                0,
                                0,
                                -0.58520294806306916,
                                0.097523482320417867,
                                0,
                                0,
                                0,
                                0.33103732706760003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4537101505232658,
                                0,
                                -0.13994895197168711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27194471028940737,
                                0,
                                0,
                                0,
                                -0.27222207105741281,
                                0,
                                0,
                                -0.030530570683019093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.05348349692452084,
                                0.63168728994105472,
                                0,
                                0,
                                0.31848330972799993,
                                0,
                                0,
                                0,
                                0.30495173129195108,
                                0,
                                0,
                                -0.50467079281347726,
                                0,
                                0,
                                0,
                                0,
                                0.16032797919994329,
                                0,
                                0,
                                0,
                                -0.18068456425905496,
                                0,
                                0,
                                0.42974135334924229,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28769407050291051,
                                0.14024849131331682,
                                0,
                                0,
                                0.57295664216626607,
                                0,
                                0,
                                0,
                                -0.33945269841354725,
                                0,
                                0,
                                0.45937504368964571,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.013718387493726916,
                                0.57143653855676502,
                                0,
                                0,
                                0,
                                0.77796018553202539,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.031836362887643493,
                                0,
                                0,
                                0.090700006547216078,
                                0.24250771695810663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0052087986196749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21659180961557106,
                                0,
                                -0.31091232223256565,
                                0,
                                0,
                                0,
                                0,
                                -0.44740366753550337,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.098633299854156642,
                                0.25443446296590144,
                                0,
                                0,
                                0.06307865831748298,
                                0,
                                0,
                                0,
                                -0.1911506227670226,
                                0,
                                0,
                                -0.56973885357015974,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62742636451445932,
                                0.28788733539446631,
                                0,
                                0,
                                -0.28858365579462469,
                                0,
                                0,
                                0,
                                -0.23455333844687859,
                                0,
                                0,
                                0.14156767030816861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.034898083889515985,
                                -0.19363539065014929,
                                0,
                                0,
                                0,
                                0.32587104670853656,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66729327748568379,
                                0,
                                0,
                                -0.12582560862451028,
                                -0.62768074542905439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48369785343472543,
                                0.6509032552481625,
                                0,
                                0,
                                0,
                                -0.46780576907877913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34799774483046819,
                                0,
                                0,
                                -0.026274318196763003,
                                -0.041549140819034935,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.034890201293312939,
                                0,
                                0,
                                0,
                                0,
                                -0.15065048121639812,
                                0,
                                0.39048876338228095,
                                0,
                                0,
                                -0.08001805132314016,
                                1.00438866757419,
                                0,
                                0,
                                0,
                                0.81831868641677219,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68289490655285956,
                                0,
                                -0.27642191498139213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19474655703149923,
                                0,
                                0,
                                0,
                                0.070878498251960798,
                                0,
                                0,
                                -0.21135911865445184,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.09326862811804279,
                                -0.27654846183028325,
                                0,
                                0,
                                0.24642157004219262,
                                0,
                                0,
                                0,
                                -0.70080823217817512,
                                0,
                                0,
                                -0.52473181985568695,
                                0,
                                0,
                                0.26302267319976919,
                                0,
                                0,
                                0,
                                0,
                                0.69445714158587191,
                                0,
                                0.40347540971500501,
                                0,
                                0,
                                0.22428342315648142,
                                0.67644007610240442,
                                0,
                                0,
                                0,
                                0.38316112383130507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1839921115182006,
                                0,
                                0.28780067001860554,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.062008996134300318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13442670106503851,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30656906472539092,
                                0,
                                0,
                                0,
                                0.60609863430250843,
                                0,
                                0,
                                -0.10921201242248658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46912603486686355,
                                -0.24291200641299618,
                                0,
                                0,
                                0.30583840176871468,
                                0,
                                0,
                                0,
                                0.38343324358907299,
                                0,
                                0,
                                -0.084195787646953402,
                                0,
                                0,
                                0,
                                -0.0904233275733555,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14908597122868042,
                                0,
                                0.8127853598232827,
                                0,
                                0,
                                0,
                                0,
                                0.27580336472339195,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3053662819572428,
                                0.8587611402326899,
                                0,
                                0.25500735076575226,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41501656573717921,
                                0,
                                0.96852994729179231,
                                0,
                                0,
                                0,
                                0,
                                -0.61839347191691618,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65363734151965758,
                                -0.29777838690198516,
                                -0.11569866395811164,
                                0,
                                0,
                                0,
                                0,
                                0.33202973261905433,
                                -0.56932591257572218,
                                0,
                                0,
                                0,
                                0.26826336172289533,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6441347873579456,
                                0,
                                0,
                                0.25566232721602405,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32146986614846174,
                                0,
                                0,
                                -0.051692989976163707,
                                0,
                                0,
                                0,
                                -0.25623544817314164,
                                0,
                                0,
                                0,
                                0,
                                -0.31047243013434805,
                                0,
                                0,
                                0,
                                -0.094573632006623415,
                                0,
                                0,
                                0,
                                0.12879532197387855,
                                0,
                                0,
                                1.0500153017097418,
                                -0.037374181213985551,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1343277389957753,
                                -0.02563016224802183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13850908553992736,
                                0,
                                0,
                                0.45731286875627009,
                                0,
                                -0.59448082471864594,
                                0.23437891938922653,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39919000375175762,
                                -0.43044829968844806,
                                0,
                                0,
                                0,
                                0,
                                0.23290568556397129,
                                -0.27974028802536693,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.08502673685565118,
                                0,
                                0,
                                -0.40084625652192835,
                                0,
                                -0.0057623112654272141,
                                -0.25058462255168917,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79208051278556957,
                                0.096827937674796111,
                                0,
                                0,
                                0,
                                -0.084207917401950952,
                                0,
                                0,
                                0.7419939660676329,
                                0,
                                0,
                                0,
                                -0.80837179753556465,
                                0,
                                0,
                                0,
                                0,
                                0.58202454914488044,
                                0,
                                0,
                                0,
                                0.481425353792856,
                                0,
                                0,
                                0,
                                -0.97131756389311885,
                                0,
                                0,
                                -0.030352264122225858,
                                0.11789839222459492,
                                0,
                                0,
                                0,
                                0,
                                0.24065094789370925,
                                0,
                                0,
                                0,
                                0,
                                0.80950282241210625,
                                -0.048897944008138766,
                                0,
                                0,
                                0,
                                0.22885098933080958,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46903811185852129,
                                0,
                                0,
                                -0.10968941226469162,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58119423127350278,
                                0,
                                0,
                                0,
                                0,
                                -0.36829795793516329,
                                -0.40345588508920033,
                                0,
                                0,
                                0,
                                0.17127520099291973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32386415713518563,
                                0,
                                0,
                                0.47913468017879007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40143309039048447,
                                0,
                                0,
                                0,
                                0.26905503394388419,
                                0,
                                0,
                                0,
                                0,
                                0.21523394535502391,
                                0,
                                0,
                                0.66932490884016493,
                                0,
                                0,
                                -0.024513378373097403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3692787873329373,
                                0,
                                0.243863231393882,
                                0,
                                0,
                                0.25769629691067319,
                                0,
                                0,
                                0,
                                -0.30785248129931753,
                                0,
                                0,
                                0,
                                0,
                                -1.134830975738629,
                                0,
                                0,
                                0,
                                -0.0097209183906862527,
                                0,
                                0,
                                0,
                                -0.097306013804774272,
                                0,
                                0,
                                -0.67156836182037638,
                                0.50573918030334086,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55539005740948311,
                                -0.19021444483757474,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40560392163066217,
                                0,
                                0,
                                0.58582616807629095,
                                0,
                                0.15624243117560671,
                                -0.26642026905826394,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0015736468142764429,
                                0.2286035328503554,
                                0,
                                0,
                                -0.5844223812268613,
                                0,
                                0,
                                0,
                                0,
                                -0.17694176907697776,
                                -0.59155970127373725,
                                0,
                                0,
                                0,
                                0.053458586703751754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45808382645174966,
                                0,
                                0,
                                -0.25396967920781938,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3006405034174515,
                                0,
                                0,
                                0,
                                -0.20499979522654316,
                                0,
                                0,
                                0,
                                0,
                                -0.097897777155041776,
                                0,
                                0,
                                0.3615565275191634,
                                0,
                                0,
                                -0.10196957921076574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0150761716865526,
                                0,
                                0,
                                -0.1396284634572649,
                                0.53695586444728205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37237828708384013,
                                0,
                                0,
                                0.40670267233659163,
                                0,
                                0.48176241994655422,
                                -0.12413841597066209,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36895260048483525,
                                -0.066919671652134555,
                                0,
                                0,
                                0,
                                -0.40761886387982438,
                                0,
                                0,
                                -0.23538363842395946,
                                0,
                                0,
                                0,
                                -0.25871968728508743,
                                0,
                                0,
                                0,
                                0,
                                -0.60720259289890444,
                                0,
                                0,
                                0,
                                -0.40263621234929914,
                                0,
                                0,
                                0,
                                -0.39738806477242783,
                                0,
                                0,
                                -0.21502474546220948,
                                -1.2193137968791699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.013685636392637063,
                                0.60311511714625121,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55178610278917195,
                                0,
                                0,
                                -0.28423680592067974,
                                0,
                                -0.1475895752800444,
                                -0.43831513042969866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0080905786086090531,
                                -0.19193254022643327,
                                0,
                                0,
                                0,
                                0,
                                -0.36803437466754702,
                                0.17420816070188133,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.071807622453998632,
                                0,
                                0,
                                0.11794280953931197,
                                0,
                                -0.33193412824113488,
                                -0.006807395265263666,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13119543274910575,
                                0.82927469944987897,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5354437550342509,
                                0,
                                0,
                                0,
                                0.46271667994782872,
                                0,
                                0,
                                0,
                                0,
                                -0.53470941692511997,
                                0,
                                0,
                                -0.75160161514162915,
                                0,
                                0,
                                0.76320575444420058,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43325418052253611,
                                0,
                                0.34685543540631381,
                                0,
                                0,
                                1.0235607855690037,
                                0,
                                0,
                                0,
                                0.88002166629804779,
                                0,
                                0,
                                0,
                                0,
                                -0.42307256852965291,
                                0,
                                0,
                                0,
                                0.13019966989939002,
                                0,
                                0,
                                0,
                                0.31687103602663513,
                                0,
                                0,
                                -0.15549318086899763,
                                -0.66859741335726652,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.035992854257143832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53376663798821966,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49734520669318927,
                                0,
                                0,
                                0,
                                0.4318688870729353,
                                0,
                                0,
                                0,
                                0,
                                1.0008315809130239,
                                0,
                                0,
                                -0.6546640289066189,
                                0,
                                0,
                                0.17336242984632216,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22437499954098589,
                                -0.2689371414221709,
                                0,
                                0,
                                0,
                                0,
                                0.25420523417393748,
                                -0.012216534377861131,
                                0,
                                0,
                                0,
                                -0.65840593977623429,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16739208297530564,
                                0,
                                0,
                                0.63354934945480101,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87558454096418348,
                                0,
                                0,
                                0.028411700065424733,
                                0,
                                0,
                                0,
                                0.8081184946456994,
                                0,
                                0,
                                0,
                                0,
                                -0.24735071054065044,
                                0,
                                0,
                                0,
                                -0.28634492910752246,
                                0,
                                0,
                                0,
                                0.075120065361657051,
                                0,
                                0,
                                -0.41828292801424805,
                                0.60123384465765717,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22700932892055298,
                                0,
                                0,
                                0,
                                0.39885351638950656,
                                0,
                                0,
                                0,
                                0,
                                0.69128035496450957,
                                0,
                                0,
                                0.55541696478870484,
                                0,
                                0,
                                1.3127494412774561,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0014921919130149314,
                                0.42075824442946541,
                                0,
                                0,
                                0,
                                0,
                                0.053752773128698333,
                                -0.40075955540100283,
                                0,
                                0,
                                0,
                                -0.64028946339861548,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14948154255009269,
                                0,
                                0,
                                -0.47660212901114618,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48098842229521871,
                                0,
                                0,
                                0.21157869421333078,
                                0,
                                0,
                                0,
                                -0.30536399734389152,
                                0,
                                0,
                                0,
                                0,
                                0.13203419621596299,
                                0,
                                0,
                                0,
                                0.67181212043084393,
                                0,
                                0,
                                0,
                                0.83118140625654013,
                                0,
                                0,
                                -0.12120762632557007,
                                -0.53420390374207027,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.043357932955039286,
                                0,
                                0,
                                -0.57004968163291536,
                                0,
                                0,
                                0,
                                0.67786689124525701,
                                0,
                                0,
                                0,
                                0,
                                -0.25397038965647828,
                                0,
                                0,
                                0,
                                0.94667804143196022,
                                0,
                                0,
                                0,
                                -0.1143166951950898,
                                0,
                                0,
                                0.21529239622785976,
                                -0.3209479379696194,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67137908925221834,
                                -0.41362104349643136,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40417576267398336,
                                0,
                                0,
                                0.073815801822420757,
                                0,
                                0.38252676906408606,
                                -0.20450050126128386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084652930338745797,
                                -0.11852269182877945,
                                0,
                                0,
                                0,
                                0,
                                0.11563000227437584,
                                0.17721917289301628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44432338707528241,
                                0,
                                0,
                                -0.14641726350703249,
                                0,
                                0.33430964832792404,
                                0.7495977680007897,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22952883642326627,
                                0.10009264943779661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25843559844123765,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16601228217039671,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2979221575640047,
                                0,
                                0,
                                0,
                                -1.2467475492222726,
                                0,
                                0,
                                0,
                                0,
                                -0.035501302348280195,
                                0,
                                0,
                                -0.1723623590262105,
                                0,
                                0,
                                0.58114862628005048,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.022019694549196028,
                                0.14068438283939788,
                                0,
                                0.13122451447375333,
                                -0.44932472943091073,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.064249851369005392,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13333153816045706,
                                0.42831201314989742,
                                0,
                                -0.74470079010382706,
                                0,
                                0,
                                0,
                                0,
                                0.034051855883484639,
                                0,
                                0.36860329489846821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55117214564878159,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47111552410635193,
                                0,
                                -0.57083281625321658,
                                -0.099663522336351368,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37429326321904,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42273038887370135,
                                0.2206752505519684,
                                0,
                                0.11675140734791768,
                                0,
                                0,
                                0,
                                0,
                                0.24726980255900252,
                                0.52470735085366915,
                                0,
                                0.3099726367827062,
                                -0.24607229373993417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24550676517798212,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31544036342863957,
                                0.26332356773075949,
                                0,
                                0.54114108408906003,
                                0,
                                0,
                                0,
                                0,
                                0.2147054210307256,
                                0,
                                0,
                                0,
                                0,
                                0.048795503314100028,
                                0,
                                0,
                                -0.35387988894343581,
                                0.61167729243174163,
                                0,
                                0,
                                -0.48592336368399963,
                                0,
                                0.38750122516609992,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33460453987039268,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31494383519904329,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16053143021398258,
                                0,
                                1.2844405666286489,
                                0,
                                -0.21560412338195312,
                                0,
                                -0.10051409438619474,
                                0,
                                0,
                                0,
                                0,
                                0.078857316638699715,
                                0.072880012743007871,
                                0,
                                -0.18908786020050555,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59804829059707687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.044579828404608335,
                                0,
                                0,
                                -0.26621823293689445,
                                0,
                                -1.0569124677890813,
                                0,
                                -0.18974436191713068,
                                0,
                                0,
                                0,
                                0.56694181487937345,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43089511773702804,
                                0,
                                0,
                                -0.75510056479545917,
                                0.0081500889253601737,
                                0,
                                0,
                                0.26299505603278017,
                                0,
                                -0.071018435588393533,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41216027576098579,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35526300440350839,
                                0,
                                0,
                                -0.14423279338986697,
                                -0.43015258099734799,
                                0,
                                0,
                                -0.059721649839034913,
                                0,
                                0.76352226619132257,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28534352918025169,
                                0,
                                0,
                                0,
                                0.34033820684732902,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41443232486497728,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24232376636519809,
                                0,
                                -0.48519799982488959,
                                -0.45717027556382539,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64721514464197227,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17634994458428987,
                                -0.12802373325393862,
                                0,
                                0.13305416625125935,
                                0,
                                0,
                                0,
                                0,
                                -0.11303627081385396,
                                0,
                                0,
                                0,
                                0,
                                0.31967536382344658,
                                0,
                                0,
                                -0.15506814911501715,
                                -0.42268166535984308,
                                0,
                                0,
                                0.2862077908070399,
                                0,
                                0.18781127017943428,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76020639824850134,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15922236188437261,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14964767356688929,
                                0,
                                0,
                                0.020192819817142701,
                                0,
                                -0.064408518788045238,
                                0,
                                1.0265013638036089,
                                0,
                                0,
                                0,
                                0.26822600577553202,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.055875526463935787,
                                0,
                                0,
                                0.21268818505741161,
                                0.51109825060716962,
                                0,
                                0,
                                0.75162835367548153,
                                0,
                                0.3536981723649939,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.019304417173297117,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45931872778555921,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.091260867555452346,
                                0,
                                0.66424280453925877,
                                0,
                                0.71712848489877778,
                                0,
                                0.95321954538134557,
                                0,
                                0,
                                0,
                                0,
                                -0.15720368394275763,
                                -0.27336920077632842,
                                0,
                                0.49868525070555669,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0491587423181972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11674438233457146,
                                0,
                                0,
                                0.44056047549508015,
                                0,
                                -0.22237966105009371,
                                0,
                                -0.28000183702499465,
                                0,
                                0,
                                0,
                                0.88298215084710829,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53143216564523099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24369754263915566,
                                0,
                                0.26194115852026212,
                                0,
                                -0.40863186274167751,
                                0,
                                0.53961823811727483,
                                0,
                                0,
                                0,
                                0,
                                0.2856083279978574,
                                0.81661348104491571,
                                0,
                                -0.6785977272476269,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63953489196607427,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8816242853967049,
                                0,
                                0,
                                -0.14112988202941304,
                                0,
                                -0.8547922940957553,
                                0,
                                -0.22467223049882468,
                                0,
                                0,
                                0,
                                -0.75617656770209962,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.081596773359985358,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.140054599211926,
                                0,
                                0.07834019623275916,
                                0,
                                -0.5524691133607772,
                                0,
                                0.37752001636272348,
                                0,
                                0,
                                0,
                                0,
                                -0.41960220032907042,
                                -0.50486167465189213,
                                0,
                                -0.045733587396193154,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80030136905715543,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.039119622489522936,
                                0,
                                0,
                                -1.5148972275585586,
                                0,
                                0.21601361019512222,
                                0,
                                0.32518293863308262,
                                0,
                                0,
                                0,
                                -0.39364024748145332,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38193142660052559,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.036596162396712428,
                                0,
                                0.42275778132593433,
                                0,
                                0.55520719987332323,
                                0,
                                0.045227434651558845,
                                0,
                                0,
                                0,
                                0,
                                -0.73260499544777324,
                                -0.2635962181345452,
                                0,
                                -1.0790849319335767,
                                0,
                                -0.50644062838489234,
                                0,
                                0.46525023514700742,
                                -0.2828676025972876,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10119758921439673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37754248982737859,
                                -0.062071974622660828,
                                0,
                                0.15656561267248392,
                                0,
                                0,
                                0,
                                0,
                                -0.51565591553351142,
                                0.17511370836321011,
                                0,
                                -0.0067078484304886575,
                                -0.23525530033810227,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40105703140013815,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21920208879718844,
                                -0.80914802354340176,
                                0,
                                -0.21471476652958393,
                                0,
                                0,
                                0,
                                0,
                                0.065006803005215691,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22869462046792538,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2502095493458008,
                                0,
                                0,
                                -0.057043969217819242,
                                0,
                                0.26590424134167262,
                                0,
                                -0.67527628516167526,
                                0,
                                0,
                                0,
                                0.59441091775760002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34434439758824004,
                                0,
                                0.16488323122321522,
                                -0.55547642634922445,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.035905156232748314,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53691340881604166,
                                -0.085681148534227605,
                                0,
                                0.17205740520411017,
                                0,
                                0,
                                0,
                                0,
                                0.46816257536351868,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1059680475176982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19102185615252304,
                                0,
                                0.09799497965607834,
                                0,
                                0.65188019556228438,
                                0,
                                0.32812735234699453,
                                0,
                                0,
                                0,
                                0,
                                1.1547576405276641,
                                -0.65202709097147959,
                                0,
                                -0.53468519414139426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.9698078077141985,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15670007088740273,
                                0,
                                0.2710491471016504,
                                0,
                                -0.33343768475521518,
                                0,
                                -0.71360559314871275,
                                0,
                                0,
                                0,
                                0,
                                0.012122828324919316,
                                -0.16175927887649974,
                                0,
                                0.41396210720790544,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76185443581804724,
                                0,
                                0,
                                0.46314864528026412,
                                -0.029529832883464169,
                                0,
                                0,
                                -0.21044079476490304,
                                0,
                                0.31852387821114064,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24177748215528239,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.053793022987091967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80928119928379083,
                                0,
                                -0.34492091008674514,
                                0,
                                0.25909462985798298,
                                0,
                                -0.37566308616067345,
                                0,
                                0,
                                0,
                                0,
                                0.21059478112633109,
                                0.85942919085937608,
                                0,
                                -0.048150241850458519,
                                0,
                                -0.13601275859196676,
                                0,
                                0.28590318576037566,
                                0.27332222387833965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4519276709423995,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44051776070325738,
                                -0.12730735381226974,
                                0,
                                -0.14503029108493407,
                                0,
                                0,
                                0,
                                0,
                                0.62411488916799029,
                                -0.12886237130193315,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46084770725531793,
                                0,
                                0.49745894171813376,
                                0,
                                -0.42080026396258274,
                                0,
                                0,
                                0,
                                0,
                                0.40269677313634944,
                                0,
                                0.085826064112785622,
                                0,
                                0,
                                0,
                                0,
                                -0.31342512642214215,
                                0,
                                0.28055214289931574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44233657783908908,
                                0.39085937126288395,
                                0,
                                0,
                                0,
                                0,
                                -0.74917452788190952,
                                0,
                                -0.47913489153210925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36624165455658947,
                                0.10314266355487578,
                                -1.2104169862181526,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34637188553094456,
                                0,
                                0,
                                0,
                                0,
                                0.7118917284412426,
                                -0.16915768684107654,
                                0,
                                0,
                                0,
                                0,
                                -1.0648247711194232,
                                0,
                                0.24026375177548401,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.083787529417039194,
                                0.4356519221285764,
                                -0.17054556569077525,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42713922265717497,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21143635684472933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37190014653963777,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24939841274671237,
                                0.88926074384546361,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24224630717979245,
                                0,
                                0,
                                0,
                                0.13518299512730289,
                                0,
                                0,
                                0,
                                0,
                                -0.72205856265213897,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5287156293752644,
                                0,
                                0,
                                0,
                                0,
                                -0.24107875104128418,
                                -0.59607570864186832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3631057106955153,
                                0,
                                0,
                                0,
                                0.63131701480637581,
                                0,
                                0,
                                0,
                                0,
                                0.21344317359019291,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20219334519407459,
                                0.32907979954463051,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46671432585603567,
                                0,
                                0.30212136713019949,
                                0,
                                0.45621181731663707,
                                0,
                                0,
                                0,
                                0,
                                -0.1550235372074022,
                                0,
                                -0.58969256886000221,
                                0,
                                0,
                                0,
                                0,
                                0.011965138202168102,
                                0,
                                -0.050644777097375332,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3598655232331367,
                                0.75129845652357941,
                                0,
                                0,
                                0,
                                0,
                                0.091386221624847774,
                                0,
                                -0.65667265832692123,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47504092712917789,
                                0.084170031630303871,
                                0.21548124003325356,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49466119474658227,
                                0,
                                0,
                                0,
                                -0.18716693147415206,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55083405296518828,
                                0,
                                0.29384028625204184,
                                0,
                                0.16510635087178471,
                                0,
                                0,
                                0,
                                0,
                                0.17379286423057547,
                                0,
                                -0.29605827763291581,
                                0,
                                0,
                                0,
                                0,
                                -0.59428950090042865,
                                0,
                                -0.27733317623518577,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50933195119620478,
                                -0.19708163914550181,
                                0,
                                0,
                                0,
                                0,
                                0.039896631863118856,
                                0,
                                -0.66918511588315077,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34511158176499057,
                                0.7354852746804621,
                                0.0511350850659286,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55304101640663816,
                                0,
                                0,
                                0,
                                -0.24923091160353181,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11214702589158425,
                                0,
                                -0.072852435344218591,
                                0,
                                0.047287894558707771,
                                0,
                                0,
                                0,
                                0,
                                -0.72902193116168001,
                                0,
                                0.098514647303122677,
                                0,
                                0,
                                0,
                                0,
                                -0.48566339670639741,
                                0,
                                0.37512175120779512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.065499520830194974,
                                0,
                                0.19431208957184556,
                                -0.47971512706010389,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26847117631994771,
                                0,
                                -0.65692968873777535,
                                0,
                                0,
                                -0.47348984469280786,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58003798969581355,
                                -0.51998450623879133,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13582841142896246,
                                0,
                                0,
                                0,
                                0.65471524268439574,
                                0,
                                0,
                                0,
                                0,
                                -0.48497896897057036,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90155266593809225,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15675200859878374,
                                0,
                                -0.53280202141673338,
                                -0.44591290571757902,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19571322140344194,
                                0,
                                0.44031013083170695,
                                0,
                                0,
                                -0.5104270936616202,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38740158558571935,
                                0,
                                0.35961463841183089,
                                -0.48707499188240144,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41472767293030777,
                                0,
                                0.51450295877945273,
                                0,
                                0,
                                0.21596976251632566,
                                0,
                                0.22486590936637701,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30614908453054279,
                                0,
                                -0.69376839566390303,
                                0,
                                -0.096343326590190209,
                                0,
                                0,
                                0,
                                0,
                                0.25002289567336516,
                                0,
                                -0.12136898435498754,
                                0,
                                0,
                                0,
                                0,
                                -0.50008217276746403,
                                0,
                                -0.19438976105065808,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53924928892429702,
                                -0.51335353792163507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.04079221679874151,
                                0,
                                0,
                                0,
                                -0.099112890736455295,
                                0,
                                0,
                                0,
                                0,
                                -0.49501186320397472,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73034158147564954,
                                0.65834526627690337,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.040246150860452357,
                                0,
                                0.29050525103332037,
                                0,
                                -0.14310137631109465,
                                0,
                                0,
                                0,
                                0,
                                -0.25721231830227764,
                                0,
                                0.46840160636120665,
                                0,
                                0,
                                0,
                                0,
                                -0.20479292203867694,
                                0,
                                -0.36413194104104391,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60778043603753762,
                                1.3330171948023664,
                                0,
                                0,
                                0,
                                0,
                                0.15316142190513771,
                                0,
                                0.26888941023442026,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14228625710371251,
                                0.39785423746773435,
                                0.35613684751776054,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46479580866264375,
                                0,
                                0,
                                0,
                                0,
                                -0.72272919613370468,
                                -0.34094956758673201,
                                0,
                                0,
                                0,
                                0,
                                -0.14335237461666375,
                                0,
                                0.40565562584829873,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31081580066449099,
                                0.74670726108553287,
                                1.0636237915325386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64195655400634344,
                                0,
                                0,
                                0,
                                0,
                                0.471584945732827,
                                0.016280172431852011,
                                0,
                                0,
                                0,
                                0,
                                0.35002671133674579,
                                0,
                                0.60040979063870714,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1283471632433231,
                                -0.25268679501386837,
                                -0.14959550806470276,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.092572774012504411,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70698965744746811,
                                -0.99968706424595211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.78508305168068149,
                                0,
                                0,
                                0,
                                -0.010835897981886562,
                                0,
                                0,
                                0,
                                0,
                                -0.54449265735969865,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50236860855203802,
                                0.28294368693501559,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13762679626716243,
                                0,
                                -0.037174906448306892,
                                0,
                                0.58763661079398211,
                                0,
                                0,
                                0,
                                0,
                                0.34501010630084761,
                                0,
                                0.34418982924083635,
                                0,
                                0,
                                0,
                                0,
                                -0.14147281040972071,
                                0,
                                0.54478418375554705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.048063497321967866,
                                0,
                                -0.65670011196404932,
                                0.11238633748827866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70752491063698186,
                                0,
                                -0.12302029808576687,
                                0,
                                0,
                                0.19513759608178199,
                                0,
                                -0.46250748151481591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3735155549199301,
                                0,
                                0.050177966263589877,
                                0,
                                0.45850282081318555,
                                0,
                                0,
                                0,
                                0,
                                0.066516746373032037,
                                0,
                                0.44152439083703648,
                                0,
                                0,
                                0,
                                0,
                                -0.023145265001700666,
                                0,
                                -0.48365930802540347,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39786036509361716,
                                0,
                                -0.13327948129705691,
                                -0.55864198214078531,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22388878646690449,
                                0,
                                -0.22482885193501717,
                                0,
                                0,
                                0.64123992715249301,
                                0,
                                0,
                                -0.019424283009931737,
                                -0.15801448040074104,
                                0,
                                0,
                                0,
                                0,
                                -0.34121341494480167,
                                0,
                                -0.20797661485008667,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50407856720768995,
                                -0.8566651499933764,
                                0.4507564134580716,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47324845801496823,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58131548579266012,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19754187960289693,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.81268423275567947,
                                0,
                                0.3162651932666421,
                                0.095296781701997138,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40853743020877581,
                                0,
                                0.21017866624734968,
                                0,
                                0,
                                -0.13914483507648781,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.098683193222955129,
                                0.39541053465952269,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52524902691253184,
                                0,
                                0,
                                0,
                                -1.0278466384109217,
                                0,
                                0,
                                0,
                                0,
                                -0.12281526493870383,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41692466283990148,
                                -0.4235462377559277,
                                0.055116207781048546,
                                0,
                                0,
                                0,
                                0.24495335957625286,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35262062797645199,
                                0,
                                0,
                                0,
                                0,
                                -0.14007243327607125,
                                0.51259374813303271,
                                0,
                                -0.47549841527890302,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35320808648547042,
                                0,
                                0,
                                0.6462511215376685,
                                0.059827745018657411,
                                0,
                                0,
                                0,
                                -0.2154646566974146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1205269242885416,
                                0,
                                0,
                                0,
                                0,
                                -0.40522318468671625,
                                -0.03739394145409683,
                                0,
                                -0.073839803991421385,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58887343135387582,
                                0,
                                0,
                                0,
                                0,
                                0.30374752035171682,
                                0,
                                0,
                                0,
                                0.78040683933088684,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55384082332942386,
                                -0.63749417115712381,
                                0,
                                0,
                                0.74909427032749187,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.060791620837056026,
                                0,
                                0,
                                0,
                                0,
                                -0.51378411439402771,
                                0,
                                0,
                                0,
                                0.6957728295255462,
                                -0.68750245909875574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5850243009842564,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38036920470671709,
                                0,
                                -0.46951792170970669,
                                -0.17411300774162897,
                                -0.099503981291080651,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.068643607459249967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4071669125849407,
                                0.097420421580595412,
                                0.42878839910601546,
                                0,
                                0,
                                0,
                                -0.62281934050449161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.232947570600261,
                                0,
                                0,
                                0,
                                0,
                                0.45354547809145934,
                                0.38766198900734072,
                                0,
                                0.036144240636602903,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.084791179651007034,
                                0,
                                0,
                                0,
                                0,
                                0.40219356615136609,
                                0,
                                0,
                                0,
                                0.24797693600339324,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.91390381669449017,
                                -0.62098463385059832,
                                0,
                                0,
                                -0.35030549596998156,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0234095462105461,
                                0,
                                0,
                                0,
                                0,
                                0.53995405704236088,
                                0,
                                0,
                                0,
                                -0.065985242090083981,
                                0.5277978113108972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15019304059724772,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50003670910082454,
                                0,
                                -0.46732857250366794,
                                -1.0846052555705141,
                                -0.31261277184893826,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.057613767228902268,
                                0,
                                0,
                                0,
                                -0.49093916324263631,
                                -0.19547699400128182,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64564106673799393,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.080099342086755843,
                                0,
                                -0.97585918287203488,
                                -0.021613410093311108,
                                0.21091778241771258,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52315255731161692,
                                0.059168979772982001,
                                -0.40619727938311467,
                                -0.095946085448615576,
                                0,
                                0,
                                0.38112602113844152,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63509960520454034,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.033546055971666267,
                                0.15658168790004087,
                                0.73714295947013897,
                                -0.37327085455390874,
                                0,
                                0,
                                -0.15074247601082355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51857754435903425,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18697005993140536,
                                0.24532126737525281,
                                -0.51138265685738737,
                                -0.48380738958342617,
                                0,
                                0,
                                -0.63034715067930325,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10927181769825813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32384157237659228,
                                0.4024993913415672,
                                0.086357800173900046,
                                -0.57044419722477191,
                                0,
                                0,
                                0.33536523351237668,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53645762584124335,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31257843232434618,
                                -0.68252495197949137,
                                0,
                                0,
                                0,
                                0.12543207803157774,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.065925329822362475,
                                0,
                                0,
                                0,
                                0,
                                0.51877940399594258,
                                0.3465010976300204,
                                0,
                                0.0013575772925838705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16485792238847885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12210202159504344,
                                0,
                                0,
                                0,
                                0.86099771441645812,
                                0.20253796744548611,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49575111622999618,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43926174413809471,
                                0,
                                0.074623088469963933,
                                -0.16079949136205585,
                                0.37992417091236125,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.75294539557152074,
                                0.29322455381779744,
                                -0.14189004983205505,
                                -0.078864168749705255,
                                0,
                                0,
                                0.54172397979860887,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16515259211780906,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2431727773313028,
                                0,
                                0,
                                0,
                                -0.25920135030212621,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47118153041505989,
                                -0.44006960484983315,
                                0,
                                0,
                                -0.55789250556915326,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6398043452110036,
                                0,
                                0,
                                0,
                                -0.45727603314687554,
                                0,
                                0,
                                0,
                                1.107480041496558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.88271017496044246,
                                0.37814513906620872,
                                0,
                                0,
                                0.0077275009483437976,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61611458184778922,
                                0,
                                -0.43079203878551581,
                                -0.37235760823393443,
                                0,
                                0,
                                0,
                                -0.64597735857568139,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40969273272279361,
                                0,
                                0,
                                0,
                                0,
                                -0.20769995476066699,
                                0.022458741770896129,
                                0,
                                -0.054858268275394993,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20971421502456217,
                                0,
                                0,
                                0.28832831764101691,
                                -0.23006859318684325,
                                0,
                                0,
                                0,
                                -0.14400855251876032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.06329377885400056,
                                0,
                                0,
                                0,
                                0,
                                -0.40447001907484331,
                                0.27603549318890186,
                                0,
                                -0.39057370153762083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66846933502735728,
                                0,
                                0,
                                0,
                                0,
                                0.023403970107953271,
                                0,
                                0,
                                0,
                                -0.78685896265438049,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.84744812377694279,
                                -0.41548154475237675,
                                0,
                                0,
                                0.43343625984108813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63082235596588621,
                                0,
                                -0.12610648326760665,
                                -0.35144044294297017,
                                0,
                                0,
                                0,
                                -0.22763965109881198,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72755948684563121,
                                0,
                                0,
                                0,
                                0,
                                0.10838938249670452,
                                -0.50584311060771059,
                                0,
                                -0.10474116673678316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.028773763983344747,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.305752346391216,
                                0,
                                0,
                                0,
                                0.26621371322939852,
                                0.17875627916177231,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64751667161354831,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.040689147429041644,
                                0,
                                0.10538286821612328,
                                0.52660359752525165,
                                0.072345767511354783,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13575024082708131,
                                -0.81474676042830629,
                                -0.050213045104056303,
                                -0.53457224801906411,
                                0,
                                0,
                                0.16955064561993344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.026894772838888109,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11002379315604419,
                                0,
                                0,
                                0,
                                0.33340686104628814,
                                -0.94928978405233133,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55039219741909917,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24226291968001251,
                                0,
                                0.23987117060550495,
                                -0.067201835278786953,
                                -0.56180197770550211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27670970186909011,
                                0,
                                0,
                                0,
                                -0.2609601090501375,
                                0.36208164034719031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12598546144355591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2511783405687269,
                                0,
                                0.3711243090842255,
                                0.43361466841116569,
                                -0.88726415632635436,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31919284510814028,
                                0,
                                0,
                                0,
                                -0.075961792546020507,
                                -0.80466346631689234,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.420725735540322,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38479562007483659,
                                0,
                                0.56968767791271113,
                                -0.43728028557133169,
                                0.72463269471505465,
                                0,
                                0,
                                0,
                                0.10561350738432443,
                                0.16908847496706944,
                                0,
                                0,
                                0,
                                -0.0095223157610948087,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31831460679606,
                                0,
                                0,
                                0,
                                0,
                                0.35050647290010861,
                                -0.36459192668823459,
                                0,
                                -0.77499208597643243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.049449139698112862,
                                0,
                                0,
                                0,
                                0,
                                0.093090960659188024,
                                0,
                                0,
                                0,
                                0.38572583791838105,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35326368547102682,
                                -1.0657728884032278,
                                0,
                                0,
                                -1.0801405096982071,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58664728632958552,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16784941374160195,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61176916458650832,
                                -0.47028485126126363,
                                0.55199141824740205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30483934312988203,
                                0,
                                0.12521667858541513,
                                0,
                                0,
                                0.56034050554356862,
                                0,
                                0,
                                0,
                                0,
                                -0.22704605036588826,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34061578712329754,
                                -0.14680893793604027,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50863453252840218,
                                0,
                                0.53823803744123955,
                                0,
                                0,
                                0.55470100904055009,
                                0,
                                0,
                                0,
                                0,
                                -0.079533258734192355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33842660332038793,
                                0,
                                0,
                                0,
                                0.28679075636502116,
                                -0.37076194757203823,
                                0,
                                0.60048420808087588,
                                0.32849870425994165,
                                0,
                                -0.19055894097856918,
                                0,
                                0,
                                0,
                                0.35779002366756796,
                                0,
                                0,
                                0,
                                0,
                                0.1814799729537743,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5328683004525796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17915784082187453,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.84714409945761204,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59639091727460203,
                                0,
                                0,
                                -0.86397463557734011,
                                0,
                                0,
                                0.082718606960119706,
                                0,
                                -0.30621347431560314,
                                0,
                                0.41101506057853354,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30146975581096641,
                                0,
                                0,
                                -0.46794847198937167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27613795743757913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.82806335567308598,
                                0.084531079288234459,
                                -0.59559373932303372,
                                1.1924847084110706,
                                -0.037192928951177345,
                                0,
                                0,
                                0.25527112368201071,
                                0,
                                0,
                                0,
                                0.17229287122355608,
                                0.49215721867669882,
                                0,
                                0.48238498467350821,
                                -0.17174627369557635,
                                0,
                                0.36040555904584343,
                                0,
                                0,
                                0,
                                -0.45638406400774667,
                                0,
                                0,
                                0,
                                0,
                                0.2501248792222236,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1846118743373644,
                                0,
                                0,
                                0,
                                -0.34549067521036747,
                                0.2599417109372027,
                                0,
                                -0.073283564453161087,
                                -0.13381514683456974,
                                0,
                                0.42618927567233256,
                                0,
                                0,
                                0,
                                0.70901715819817723,
                                0,
                                0,
                                0,
                                0,
                                0.26714294385688958,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45677256344752953,
                                0,
                                0,
                                0.11881879930036472,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18335140701258201,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.010112551591268976,
                                -0.32084219849104267,
                                -0.94848976106750982,
                                -0.53692784307213859,
                                0.94219858993536265,
                                0,
                                0,
                                0.58976344703611161,
                                0,
                                0,
                                0,
                                -0.43653051313640823,
                                -0.34875657340755228,
                                0,
                                0.089101993734138504,
                                -0.26166843276112139,
                                0,
                                0.12282744866708059,
                                0,
                                0,
                                0,
                                -0.17680988888833715,
                                0,
                                0,
                                0,
                                0,
                                -0.46608066597976211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.023525400073284047,
                                0,
                                0,
                                0,
                                -0.053747798173969991,
                                0.52494043918557376,
                                0,
                                0.2946145400917462,
                                -0.26113893717206349,
                                0,
                                -0.56509981353549443,
                                0,
                                0,
                                0,
                                0.26628560051299444,
                                0,
                                0,
                                0,
                                0,
                                -0.41923522396293933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25697677745880337,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40880394729599029,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22273352203784064,
                                0,
                                0,
                                0,
                                -0.55884036708696816,
                                0.25166976772410143,
                                0,
                                -0.074288894148730383,
                                0.57362695435646227,
                                0,
                                -0.33691599083768042,
                                0,
                                0,
                                0,
                                -0.22375422823822907,
                                0,
                                0,
                                0,
                                0,
                                0.27677515819467102,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17030088102997681,
                                -0.17083165888109861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31352049203256388,
                                0,
                                -0.69092342651435779,
                                0,
                                0,
                                0.49266687677664572,
                                0,
                                0,
                                0,
                                0,
                                0.35131641370822619,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27875397702158344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71494524649903335,
                                0,
                                0,
                                -0.1936804523955804,
                                0,
                                0,
                                -0.8343848247991037,
                                0,
                                -0.1407049611702392,
                                0,
                                0.68327319726598135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12479408367617367,
                                0.64320364590538825,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67170028556990258,
                                0,
                                -0.022591413478264794,
                                0,
                                0,
                                -0.33576838845896539,
                                0,
                                0,
                                0,
                                0,
                                0.079268217385500217,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50945317458635309,
                                0,
                                0,
                                0,
                                0.49069723297389384,
                                0.28903157797541984,
                                0,
                                -0.44950645701916148,
                                0.32469102945508471,
                                0,
                                0.083337130896969841,
                                0,
                                0,
                                0,
                                0.081399467271009773,
                                0,
                                0,
                                0,
                                0,
                                -0.30835558243694283,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7818788946660461,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.97511258914947829,
                                0,
                                0,
                                -0.48059362419352453,
                                0,
                                0,
                                -0.15507155923940452,
                                0,
                                0.02741272893201474,
                                0,
                                -0.25905377027278265,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24830294994985719,
                                -0.009618542400279595,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13328568915295536,
                                0,
                                0.42664440939386233,
                                0,
                                0,
                                -0.018656625704771043,
                                0,
                                0,
                                0,
                                0,
                                0.85913592172926223,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21398038677080131,
                                0,
                                0,
                                -0.43716549471858912,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.041546416016633364,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.730140245514314,
                                0.9081030565199969,
                                -0.43549910268743453,
                                -0.65433891885281326,
                                -0.41183568012945743,
                                0,
                                0,
                                0,
                                0,
                                0.66837103592349956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.83176434372793873,
                                0,
                                0,
                                -0.019389072045333217,
                                0,
                                0,
                                -0.2729977065773086,
                                0,
                                -1.0843791762020092,
                                0,
                                -0.52184890980978438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35874143416780568,
                                0,
                                0,
                                0,
                                0.14889048623061438,
                                -0.093148376322186449,
                                0,
                                -0.31470807802061879,
                                -0.52301937312586788,
                                0,
                                -0.44415760789575898,
                                0,
                                0,
                                0,
                                -0.046184073970940043,
                                0,
                                0,
                                0,
                                0,
                                0.51813144870113248,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15658433877602174,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58420606804391073,
                                0,
                                0,
                                -0.92446575875593207,
                                0,
                                0,
                                0.15315781699110265,
                                0,
                                0.54067825690440852,
                                0,
                                -0.62301288176703951,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7460447278029545,
                                0.48038079456131028,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28482001282871272,
                                0,
                                -0.18630510760340091,
                                0,
                                0,
                                0.15005391222057432,
                                0,
                                0,
                                0,
                                0,
                                0.27258640269554357,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16960039899819832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.055706122798203694,
                                0,
                                0,
                                0.095788502339553425,
                                0,
                                0,
                                -1.1054134724148659,
                                0,
                                0.17811568009206125,
                                0,
                                -0.89027524097642241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61499295092366735,
                                0,
                                0,
                                0.25013164873083671,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56365459003070584,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28437648375838537,
                                -0.77521708667430222,
                                -0.26169629916250747,
                                -0.14029549160305593,
                                -0.39229668851417615,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3739467497019347,
                                0,
                                0,
                                -0.38657115167921474,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37690707671452361,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79979869069970866,
                                0.0045276503011665581,
                                0.66598307581054272,
                                -0.085348431102163655,
                                0.24859404493626147,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90473268176215516,
                                0,
                                0,
                                0.52641424564007011,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.082503452378420439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.020165735539659446,
                                1.1997314742931064,
                                0.0095162889251214772,
                                -0.33197229282406554,
                                -0.20716064783605825,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48827043022884897,
                                0,
                                0,
                                -0.65700521646525112,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1431427577744966,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54649215334385126,
                                -0.24878910023812395,
                                0.13160205178705348,
                                -0.054510829037342973,
                                -0.28419413088015089,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.86599731867622909,
                                0,
                                0,
                                -0.82247880678683638,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.90209410283560876,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53819281601934399,
                                0.45473061574917228,
                                0.052412743666977291,
                                0.3902038197680055,
                                0.13415128050402014};

const double rot_29_2[32]
    = {-0.53308319089529932, 1.2313192911414299,   2.7626060502303957,   -0.75344736118607614, -0.97600849664721367,
       0.21773243780485652,  -0.21773243780485674, -0.97600849664721379, 0.79570910292857511,  0.60567897727806508,
       0.60567897727806475,  -0.79570910292857477, 0.45037081454748373,  0.89284160375949984,  -0.89284160375949995,
       0.4503708145474839,   -0.38627289980199464, 0.92238454392870117,  0.92238454392870128,  0.38627289980199475,
       0.88265681685200714,  0.47001802482956168,  0.47001802482956168,  -0.88265681685200681, 0.79755547924878534,
       -0.60324560298458929, 0.60324560298458918,  0.79755547924878512,  0.17356780055707255,  0.98482192228330323,
       0.98482192228330312,  -0.17356780055707255};

const double rot_28_50[25000] = {0.18325182066601059,
                                 0,
                                 0,
                                 0.4424520016949624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46514986485136411,
                                 0,
                                 0,
                                 0,
                                 -0.36250557333188849,
                                 0.075006786707977516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49786646163042936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00689585345709752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.221083950725351,
                                 0,
                                 0,
                                 0.32826251593726596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11270018566726032,
                                 0,
                                 0,
                                 -0.36151191195970078,
                                 0,
                                 0,
                                 -0.77383374166657937,
                                 0,
                                 -0.0038463023955357736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17427016478777363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31705031191854915,
                                 0.22675125993127024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30738351365170524,
                                 0,
                                 0,
                                 -0.36938908861771225,
                                 -0.84485361123637914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91228196870872236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58676974048182196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13821600730720879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039603044109136842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36004835566141302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36743804171513744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60859154854655628,
                                 -0.27504894621869996,
                                 0,
                                 0,
                                 -0.045466039076094623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42083559087148442,
                                 0,
                                 0,
                                 0,
                                 0.0754229776023677,
                                 0.071549016790647013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15198430628694717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22824787889198686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62398103097564372,
                                 0,
                                 0,
                                 -0.39213210312757618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34066728296029197,
                                 0,
                                 0,
                                 -0.2774745379089637,
                                 0,
                                 0,
                                 -0.63523779174701345,
                                 0,
                                 0.015821094569100684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.079797286879179335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45286131516680617,
                                 -1.0361355645142543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31266385344192432,
                                 0,
                                 0,
                                 0.46551495998882597,
                                 -0.079762309394355344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39083853280047098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028361220378477294,
                                 0,
                                 -0.11532149462798021,
                                 0,
                                 0.47053556684500858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25163097248253541,
                                 0.64422501696674817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16292618185098687,
                                 -0.37877786493264148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34078034552402442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27418345816776973,
                                 0,
                                 0,
                                 0.50588224330645448,
                                 0,
                                 -0.32636993471695203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58064460885364177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030831593709622074,
                                 0.038879313200012852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25361669843998186,
                                 0,
                                 0,
                                 0.13128856926959132,
                                 -1.056696906244921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3031010756371158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29271617501818631,
                                 0,
                                 -0.77194477615834722,
                                 0,
                                 -0.25121886063811971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3561177387049872,
                                 0.063895163728398749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34892895461209944,
                                 -0.04852093078025832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017304786781039264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25364972103856243,
                                 0,
                                 0,
                                 0.060936710117282744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1273213575996518,
                                 0,
                                 0,
                                 0,
                                 0.24940639627366187,
                                 -0.22758376207571282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14846764426072268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51851340544975244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15060424659254013,
                                 0,
                                 0,
                                 -0.54327251287211442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43933407977968231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31499830375992111,
                                 0,
                                 -0.28944911878929303,
                                 0,
                                 0.34008491873256907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65287664154689429,
                                 -0.3336241103503525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11650043150287964,
                                 0.37941305730967745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.079107203395681891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0411174095620379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19205813580756104,
                                 0,
                                 -0.29261170615060417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6583063589593855,
                                 0,
                                 0,
                                 0,
                                 0.3353651293257548,
                                 0,
                                 -0.016637205803297583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0046018496946050869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43642727864877573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7223101424760201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044820696393282011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41681317235245002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3347177856570992,
                                 0.24203759058754432,
                                 0,
                                 0,
                                 0.43105373111679757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088347962419611389,
                                 0,
                                 0,
                                 0,
                                 -0.13793620920719932,
                                 0.54341952750623057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55467108784533248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27161192745133456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14763454404336285,
                                 0,
                                 0,
                                 -0.1328980736347399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11217411059397565,
                                 0,
                                 0.13692367829081584,
                                 0,
                                 0,
                                 -0.022971971526135185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12827888316224273,
                                 0,
                                 0,
                                 0,
                                 -0.18334634942866987,
                                 -0.40929145450500631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61308490949901595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19887831496138464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2416612145402639,
                                 0,
                                 0,
                                 0.26626546346054303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46734378602939769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17380400347042016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046096165687529125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46934116636845202,
                                 0,
                                 0,
                                 0.50378776152757865,
                                 0,
                                 -0.025792018153246846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30011801866023069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21193086694972096,
                                 -0.87634401210686008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059909634095677289,
                                 0,
                                 0,
                                 -0.78244626001197615,
                                 0.032263413431138921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18517373007876325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087114397334024402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0072320479972516477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02796201752064198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85087091406813187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35427367589193259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37694264152248769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063157249436234159,
                                 0,
                                 0.18517526770075171,
                                 0,
                                 0.5419307281933855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41671084921250673,
                                 -0.51573073456171326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39309944397779534,
                                 -0.22109672594156535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15809905254202675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088965234918395017,
                                 0,
                                 0.30539601574548714,
                                 0,
                                 -0.53403879641870666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32241108831016058,
                                 -0.10055072676259992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57073853256653462,
                                 -0.096061995250267457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40569851670527879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49407921826764506,
                                 0.0093694435459233359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55851730543172673,
                                 -0.459325810990098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61241964332108922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16245507123771047,
                                 0.4875464765244944,
                                 -0.53001851629545005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69116915133883405,
                                 -0.62227321210789488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43214876503245347,
                                 0.64232385629304578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22119569892683835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43235148755395231,
                                 0.3971256050390507,
                                 0.44928821081490755,
                                 0,
                                 0,
                                 0,
                                 0.20526354077689507,
                                 0,
                                 0,
                                 -0.18485063165113266,
                                 0,
                                 -0.49227103400094996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15220736883775204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51791743436492199,
                                 -0.012711493939586732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0039777871843516,
                                 0,
                                 0,
                                 0.34337041117604866,
                                 -0.19656356327688335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33081638277817754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48277317789530039,
                                 0,
                                 0,
                                 -0.19437135410719281,
                                 0,
                                 -0.33464441820855134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81825731112712474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24082550700716654,
                                 0.21331523533140795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10768666318094915,
                                 0,
                                 0,
                                 0.27778232345209053,
                                 0.023942012309179483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52449084590156958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20557240579306582,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30935828062211296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086637428296490793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38061691725074032,
                                 0,
                                 -1.1346098466130699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89883620699553934,
                                 0,
                                 0,
                                 0,
                                 0.76622259947619342,
                                 0,
                                 -0.25781132961875325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55712061908912347,
                                 0,
                                 0,
                                 0.090307738662052717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18178769929926231,
                                 0,
                                 0,
                                 0,
                                 0.3946707930608585,
                                 0.031323330764040536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11186756572689381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49745822729382022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07097379312314904,
                                 0,
                                 0,
                                 0.47239294106167257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059133445040725222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11289699649433083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12959331046544142,
                                 0,
                                 0.77970258950120241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29420865177841959,
                                 0,
                                 0,
                                 0,
                                 -0.085657595083669769,
                                 0,
                                 -0.87934393777413811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4632086642323236,
                                 0,
                                 -0.28703686475280621,
                                 0,
                                 0.023830443270101948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07197924063376647,
                                 -0.14982562624651605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19155494892099895,
                                 0.34535291182581423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7203395172427145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72170158610489232,
                                 0,
                                 -0.26477000493083658,
                                 0,
                                 -0.019375195733706108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2634530721370118,
                                 -0.18786676423978607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24287126846501883,
                                 -0.35125985410494365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3487074510487288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61846998090632521,
                                 0,
                                 0,
                                 -0.17197160452068863,
                                 0,
                                 -0.46119959627819834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28655421110646861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3277565389532906,
                                 -0.074030393852451359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68903274216187138,
                                 0,
                                 0,
                                 -0.81536416915486543,
                                 -0.39050825951958978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21959970611309099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011246415343185198,
                                 -0.10183320369212154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46662918160534367,
                                 0.49432509487012932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57253893677233136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16065805320385593,
                                 0.46045042149552856,
                                 -0.87658358913820866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42009397747013721,
                                 -0.79571309579385896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7392822439335649,
                                 -0.04154300814625559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15979598787219065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31220887986970325,
                                 -0.016295227959124164,
                                 -0.3338167472975262,
                                 0,
                                 0,
                                 0,
                                 -0.43606880631349421,
                                 0,
                                 0,
                                 0.0031112253634878635,
                                 0,
                                 -0.86752684295676485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50031196630315344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.195946658621727,
                                 0.034183552357379264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09914380959135187,
                                 0,
                                 0,
                                 -0.21291074794013298,
                                 0.48698352297334457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11577778267951672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0099847261711153712,
                                 0,
                                 0,
                                 -0.27234530265432366,
                                 0,
                                 0.10615214153841904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43833675891408708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92854617304942,
                                 -0.62377128980183483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86780897842830396,
                                 0,
                                 0,
                                 -0.13920861090018538,
                                 0.23480569074024146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.008433073319807867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43512425988299053,
                                 0,
                                 0,
                                 0.10233410653613648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37951353549851374,
                                 0,
                                 0,
                                 0,
                                 0.63997574132728685,
                                 -0.17814628888214162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043842597306041564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25129813814631713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25786973831189836,
                                 0,
                                 0,
                                 0.14864822237735792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24737221391441219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52394373048354392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2886578197112679,
                                 0,
                                 -0.043621893960908126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35361137825338018,
                                 0,
                                 0,
                                 0,
                                 0.0011525447526481714,
                                 0,
                                 0.044177209378824356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56282839225390058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54961331936147717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29684433840929569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33195804868224538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28648976356034611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31742764230279141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25878534251980839,
                                 0,
                                 -0.16423002049336297,
                                 0,
                                 -0.14141419294918584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17728149021314379,
                                 -0.36845109573606871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51203700691124165,
                                 -0.6398867026984334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21734499635368848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0011129462804659526,
                                 -0.65681452806210594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81388426742279185,
                                 -1.0262370998703094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11008080469686778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42363438618155314,
                                 -0.060174414645592589,
                                 0.21813597301636639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92364437401496979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30499908606616533,
                                 0,
                                 -0.048675705315384454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53988443011652099,
                                 0,
                                 0,
                                 0,
                                 0.21016395033053323,
                                 0,
                                 -0.68565861330012312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.007000470454019303,
                                 0,
                                 0,
                                 0.42497143005957366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47726509439827014,
                                 0,
                                 0,
                                 0,
                                 0.41180724671497937,
                                 0.27194311677335004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078641705489792643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35526496213615832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34699289220283724,
                                 0,
                                 0,
                                 0.034294940329801016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30667917792493027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39166602719329202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33979790443872993,
                                 0,
                                 0.56928230683644832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13727796777355458,
                                 0,
                                 0,
                                 0,
                                 1.5022174547663656,
                                 0,
                                 0.398930266791795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032810594900219675,
                                 0,
                                 0,
                                 -0.63542459761140979,
                                 0,
                                 0.67222984785471407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1953003939138574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3779220930751615,
                                 0.9009907415832652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13363812085955307,
                                 0,
                                 0,
                                 -0.38379319476961438,
                                 -0.089069953714837224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70947080070369928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26900740395135458,
                                 0,
                                 0,
                                 0.20395537099290487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40149987870823306,
                                 0,
                                 0,
                                 0,
                                 -0.056606382834968147,
                                 -0.3987342695925255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038919410559040066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32349706615133678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37871745296643422,
                                 0,
                                 0,
                                 0.16658832816392244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5341330524747655,
                                 0,
                                 0,
                                 0,
                                 -0.54812871453506351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60508625861355614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47475794551069805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18440396381240845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25390198023273258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097772121168654053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53272834249798484,
                                 0.027397257699897259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29530575563035655,
                                 -0.76375841006559342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56080817107460323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82914971412261984,
                                 -0.29046015456332563,
                                 -0.088868832921835422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73877740441860695,
                                 -0.33692175042920791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12108475370994487,
                                 0.35108512078458903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21593516664203843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28243197999699932,
                                 -0.7808492371940714,
                                 -0.42709859622109114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81794171624705792,
                                 0.25947569068894599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39105120307833435,
                                 -0.50086360975717592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85712940277443728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32676849226519322,
                                 -0.16164733141866233,
                                 0.15287932958337408,
                                 0,
                                 0,
                                 -0.42067550650035301,
                                 0,
                                 0,
                                 0.60933938450988767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00017910254212769039,
                                 0,
                                 0,
                                 0,
                                 -0.09965829711617652,
                                 -0.45713974447324179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036307433481275492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15554610503434416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35146374172389849,
                                 0,
                                 0,
                                 -0.28388856490478287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056540064815066661,
                                 0,
                                 0,
                                 0,
                                 0.17569942967022226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34952980141119672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40299641993266588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013191148492210106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64745936338359011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51495133772895041,
                                 -0.29264651930942903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52301191241287237,
                                 0,
                                 -0.086153248440494698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2975369165773778,
                                 -0.17428482758973846,
                                 0.3773727483140723,
                                 0,
                                 0,
                                 0,
                                 1.0981160349915924,
                                 0,
                                 0,
                                 0,
                                 0.22239922239476489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54715863421704258,
                                 -0.41048449094407174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34117170815082276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46644785496076074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24281807831752292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70021134539290608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16783774189652134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2976612322427501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7941595308691205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0067873943052911816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23780479349348535,
                                 -0.38385840702670898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11357011523159635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24517245332480692,
                                 0,
                                 0,
                                 -0.085433841813269892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97591743163091293,
                                 0,
                                 -0.41419461852215089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98078102683519008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29784016164912708,
                                 -0.77344849884012368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096785857437446235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67506228309236482,
                                 0,
                                 0,
                                 0.58184238111747466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48310234538862246,
                                 0,
                                 0.0060693044981993023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22170603879090336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92114728096310783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77007453735481846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010767410461394527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3903247528703912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89472094878186459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68702424632597636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25012166024440691,
                                 0,
                                 -0.72754799562795192,
                                 0,
                                 0,
                                 0,
                                 0.14133793371119496,
                                 0.113592594981786,
                                 0,
                                 0,
                                 0,
                                 -0.52229879383160149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24084937314913468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011029149602321998,
                                 0,
                                 0,
                                 0.041428531504702312,
                                 -0.18389512979805764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.093667204946967064,
                                 -0.63786850964289532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15219882808159901,
                                 0,
                                 -0.83941647982284606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50854142741977038,
                                 0.67226972322676537,
                                 -0.95494100962745176,
                                 0,
                                 0,
                                 0,
                                 0.092587742126283901,
                                 0,
                                 0,
                                 0,
                                 0.11236256448763422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50036311950893186,
                                 0.10806924131171451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62684844419288643,
                                 0,
                                 0.038421183290527641,
                                 0,
                                 0,
                                 0,
                                 -0.32452193180368533,
                                 -0.078471635042839799,
                                 0,
                                 0,
                                 0,
                                 0.14508693065574169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061228762409556658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59740314789885829,
                                 0,
                                 0,
                                 -0.17541596013485999,
                                 -0.019718895127967297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28506712394055606,
                                 0.50318872675315818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10152187889521661,
                                 0,
                                 0.82261277442410363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50037056857863693,
                                 1.0112651237362318,
                                 -0.11029020235893744,
                                 0,
                                 0,
                                 0,
                                 0.32738865014374002,
                                 0,
                                 0,
                                 0,
                                 0.060148987680214205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28469670341939196,
                                 -0.14395059388083464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68091323253705438,
                                 0.3057189053478383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29229358106859404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64889487089478559,
                                 0,
                                 0,
                                 -0.45513255532951929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67622806184454409,
                                 0,
                                 0.055240794608356458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75481590167444124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39687039349380515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21032146883658687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65668453150178541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63807683299428186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72365701381323833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76463864295130723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19913079639065753,
                                 0,
                                 -0.043783394900622857,
                                 0,
                                 0,
                                 0,
                                 0.27709943285790145,
                                 0.074061455133229731,
                                 0,
                                 0,
                                 0,
                                 0.17621166486900267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50769355710592268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10382220114960193,
                                 0,
                                 0,
                                 -0.066580356473776331,
                                 0.69987695874400124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28691060623463871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11402435436613591,
                                 0,
                                 0.16417558654306233,
                                 0,
                                 0,
                                 0,
                                 0.63341470022441293,
                                 0.19073728322851843,
                                 0,
                                 0,
                                 0,
                                 0.23023683712303095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051869906997921961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054609068334026997,
                                 0,
                                 0,
                                 0.21918865892991179,
                                 -0.098571522651526716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63718778839115831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30017270211277802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32183019709525479,
                                 0.16427021757009247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43016802071896215,
                                 0,
                                 -0.014580682768252785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66003335079305547,
                                 0,
                                 -0.056845166752251111,
                                 -0.39395995895770891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1899765368451769,
                                 -0.36775756905382084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76452669037394694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80865331906400117,
                                 0,
                                 0,
                                 0.55229089797471487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13177974639379203,
                                 0,
                                 -0.20076458973923098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43658699783381255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68683333324750806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34987421268039387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06776804746597076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36359814970546633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088697546866828542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51106225657409876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19498572109469026,
                                 0,
                                 0.47981890496311286,
                                 0,
                                 0,
                                 0,
                                 -0.24691279950934805,
                                 0.56754211047722525,
                                 0,
                                 0,
                                 0,
                                 -0.24331667051411721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42123671901053117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098249779753878802,
                                 0,
                                 0,
                                 0.14431563554550816,
                                 -0.2558119564636942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12696950317100522,
                                 0,
                                 0,
                                 0,
                                 0.78649986935591065,
                                 0.08066497759425291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20325717134194374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9688289685892949,
                                 0,
                                 0,
                                 -0.38231279250290667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21823101872762812,
                                 0,
                                 -0.82154107069750137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55962582919347592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75753715152221557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37283829343415648,
                                 0.29286834867616468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0021681611643391691,
                                 0,
                                 0.43332010308156693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078000392092183624,
                                 0,
                                 -0.083934480470451558,
                                 -0.0213806108560292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33469305893034729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4537365974637646,
                                 0.5045324545566483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029107345884070435,
                                 0,
                                 0.64917042569740868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069112911868074584,
                                 0,
                                 0.016130419107185708,
                                 -0.015633122940350117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50887812945190714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43349532313970979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68063852357214794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67617937065912126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23161638340772189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.126527478915619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30771130069461461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24284627463483241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90480803572354995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029627435114932509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10606156559531173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12463956114687191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95332971828518553,
                                 -0.50070229780404274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93445683270611302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037669498275678961,
                                 0,
                                 0,
                                 -0.38808532046395616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81630104449242458,
                                 0,
                                 -0.42072212591837876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32039388792322399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47750955276613466,
                                 0,
                                 -0.15864819248744655,
                                 0,
                                 0,
                                 0,
                                 -0.012114683667873561,
                                 -0.038476321225523774,
                                 0,
                                 0,
                                 0,
                                 0.3374590691618275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50473444228895048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46511842665035008,
                                 0,
                                 0,
                                 -0.017025397847388206,
                                 -0.39884817114003934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029117451579957966,
                                 0,
                                 0,
                                 0,
                                 0.33090396219678542,
                                 -0.99691744602674937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81078600076276286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19806211976467483,
                                 0,
                                 0,
                                 -1.1149780061475765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38042044877552827,
                                 0,
                                 0.00087499001457816764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25689488315528847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72703056051319681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84573530143195408,
                                 0,
                                 -0.083161730986124741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034561406707841469,
                                 -0.25233070050779483,
                                 0.097196605277698966,
                                 0,
                                 0,
                                 0,
                                 0.94141028199295629,
                                 0,
                                 0,
                                 0,
                                 -0.030932440995256355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1016855592751226,
                                 0.66638367696095124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43169871062619725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6544661964122449,
                                 0,
                                 -0.19161384477227486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3764355421013279,
                                 -0.31888167894327224,
                                 0.22723631784409809,
                                 0,
                                 0,
                                 0,
                                 -0.34891382531021403,
                                 0,
                                 0,
                                 0,
                                 0.5017887591562793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10737941629636757,
                                 0.78779267003689213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37426660026713321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19828374099465043,
                                 0,
                                 0.60320582026280745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42974019266784802,
                                 0.31244839906479482,
                                 -0.3806812567501604,
                                 0,
                                 0,
                                 0,
                                 -0.027352292778011034,
                                 0,
                                 0,
                                 0,
                                 0.31675203349319858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12441417779859038,
                                 0.85803154803212101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4029887553044369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43821334347171315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037812886904471904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40448214127145254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50910191642589731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47047715180379773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67621525537062377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49370055346483571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30928025435828232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55026814174934569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76946960604044923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16336685711427654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44141519941680013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72616119087177355,
                                 -0.092823303301349608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2823775286945493,
                                 0,
                                 -0.17718344993632887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37887184265105645,
                                 0,
                                 -0.12062351651411037,
                                 -0.0011964224688168282,
                                 0,
                                 -0.74361767655339994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25035066289772584,
                                 0,
                                 0.19263360532584861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72321283788990087,
                                 -0.63017366385536955,
                                 -0.38414239222442748,
                                 0,
                                 0,
                                 0,
                                 0.3428987040636774,
                                 0,
                                 0,
                                 0,
                                 0.75359234369747052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33544298490808921,
                                 0.18101942308615707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017187234904147641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017819105066854961,
                                 -0.13371417797750546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42878003368599454,
                                 0,
                                 0.045502439433229167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49493437586436345,
                                 0,
                                 -0.68200433779713043,
                                 -0.2923950317469135,
                                 0,
                                 0,
                                 0.38095988097793865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56005892630672183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32278751699535208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44990023862402018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071251171176609521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47908750026839736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10203408025996091,
                                 0,
                                 0.15086011596501511,
                                 0,
                                 0,
                                 0,
                                 -0.31803113062253141,
                                 -0.53430490179167556,
                                 0,
                                 0,
                                 0,
                                 -0.22217381775736861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45084254163007415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23847631580848525,
                                 0,
                                 0,
                                 0.094027392848751834,
                                 0.18907974649018355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47552212017129569,
                                 -0.17508682778845389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30407006592766295,
                                 0,
                                 -0.28256086388675256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0094847505954032407,
                                 0.46123494722226199,
                                 0.84076118050700455,
                                 0,
                                 0,
                                 0,
                                 -0.36206595421504778,
                                 0,
                                 0,
                                 0,
                                 0.5204422139349496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082907557027633694,
                                 0.51246314659362502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31266900260762731,
                                 0.68534818478330983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52441844596323739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46007819879321876,
                                 0,
                                 0,
                                 0.21989268999924896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49235398356824478,
                                 0,
                                 -0.69484585744453031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27731695612462837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20828842402972422,
                                 0,
                                 -0.17658892235472773,
                                 0,
                                 0,
                                 0,
                                 -0.28864014307279845,
                                 0.26437858714495338,
                                 0,
                                 0,
                                 0,
                                 0.0004939691972477519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17302692401783748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25720604710057243,
                                 0,
                                 0,
                                 0.73626270425610107,
                                 0.34361295844051065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12640003714584658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36136282226302047,
                                 0,
                                 0.080308913565135601,
                                 0,
                                 0,
                                 0,
                                 0.17042431649692527,
                                 -0.48605993772677653,
                                 0,
                                 0,
                                 0,
                                 0.10356333296551708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056564750864611546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022191475878660383,
                                 0,
                                 0,
                                 0.58547605731432339,
                                 -0.28541743249156809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39875551072846116,
                                 0,
                                 0,
                                 0.011852757228064776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49459261180666364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82249967505200217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42012328834354234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89956386732878624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98538672134983973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79846680104021972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4668267863091215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098210108979936414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30877691861158824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11021658464519744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10298856771913563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82973049309748437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42872433712048197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45928153121136561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1616007548310229,
                                 0,
                                 -0.2085473984977286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43540714691917365,
                                 -0.080376594326342435,
                                 -0.76095665235399768,
                                 0,
                                 0,
                                 0,
                                 -0.44756987264558279,
                                 0,
                                 0,
                                 0,
                                 0.96547525903169618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6233697806680718,
                                 -0.4476462608795666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4619805449779768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2502403940222967,
                                 0,
                                 0.16585916020325642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087188914742037993,
                                 -0.4104222453703481,
                                 -0.2497375777972079,
                                 0,
                                 0,
                                 0,
                                 0.24928198434607904,
                                 0,
                                 0,
                                 0,
                                 0.74432557888794548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0738712050722723,
                                 -0.652348561218274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067834702408082231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030806481977008856,
                                 0.76050912064275444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099815990790903766,
                                 0,
                                 -0.59352005632033455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17706413676111354,
                                 0,
                                 -0.068211385480187861,
                                 -0.13357207914996147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42145013489649824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053594187510709074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40027362481502837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74583033003281896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35254974182412741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.9076136101273371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00787890428379312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12289673812173274,
                                 0.13355164060074282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70534871526386789,
                                 0,
                                 -0.066321734993392695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18264955487997442,
                                 0,
                                 0.29767612267304189,
                                 0.58575673906045977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15558909335309673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088655445982089576,
                                 0.099923060132652938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20744663723984186,
                                 0,
                                 -0.021674262213430301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31666834716562359,
                                 0,
                                 -0.64538331474820143,
                                 0.6305912162283952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20355009403789426,
                                 0,
                                 0.35290188951264412,
                                 0,
                                 0,
                                 0,
                                 0.34942345386165979,
                                 -0.15445585636949966,
                                 0,
                                 0,
                                 0,
                                 -0.62363912783243791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095944084936060547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5288857168084482,
                                 0,
                                 0,
                                 -0.014604959025095166,
                                 0.080286342239845709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059698590435090085,
                                 1.1791924394261495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52978015459475747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6181409352388878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88562596620358291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13680469644629439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13585437674634282,
                                 0,
                                 0,
                                 0.40045179233310024,
                                 -0.18111614701426748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1770622112662813,
                                 0,
                                 0,
                                 0.046605056466541665,
                                 0,
                                 0,
                                 -0.71233779538815711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26694927135904684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18556631458935541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40023785432327363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28893681404199201,
                                 0.22330289967221628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59735808568538418,
                                 0,
                                 0,
                                 -0.49835388471610903,
                                 0,
                                 0,
                                 -0.10264735113183375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16095510509757488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37954316455422471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28453825267037675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20143616164410516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52294316271794883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55398792618226311,
                                 0.57188054444475078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22129606553061187,
                                 0.055063538382155941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64940516560768236,
                                 0,
                                 -0.47269771823571183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55409716867191572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10952043544221947,
                                 0,
                                 -1.1118714548721806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28603069299398232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25595192928066096,
                                 0.055642753642840978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20486943182787351,
                                 0,
                                 0.25703938484757516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44674686909024364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19660125348095608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56695688217901075,
                                 0,
                                 0,
                                 0.72572460077036549,
                                 0.47756608886754559,
                                 0,
                                 0,
                                 0,
                                 -0.71216876437665588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3536771463617398,
                                 0,
                                 0,
                                 0,
                                 0.4856925322580985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32657959965029337,
                                 0,
                                 0.5957577086975494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81996419044180402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53088020393230795,
                                 0,
                                 -0.59185104726298832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1770364982882936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51058709594639717,
                                 0.72354418283600219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3250462036525395,
                                 0,
                                 0.16015090809566226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34379618574869486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39196844132359193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17497491744349997,
                                 0,
                                 0,
                                 0.21598901432337236,
                                 0.63115987524686668,
                                 0,
                                 0,
                                 0,
                                 0.38923945439639207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.4064358575163793,
                                 0,
                                 0,
                                 0,
                                 -0.48197567149562065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22740334778935561,
                                 0,
                                 -0.39565510562894002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41104184664407195,
                                 0,
                                 0,
                                 0,
                                 -0.20070627405684599,
                                 0,
                                 -0.46993803186695748,
                                 -0.073207999546820723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29152445110544795,
                                 0,
                                 0,
                                 0,
                                 -0.19387287633604497,
                                 0,
                                 0.33772871483690692,
                                 0.34593539725854233,
                                 0,
                                 0,
                                 0,
                                 0.31067629776372963,
                                 -0.56423616028219947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25303376633663244,
                                 0,
                                 0,
                                 -0.086388612924585786,
                                 0,
                                 0,
                                 0.497900923676868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32744073201735641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20380333877574566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34200899170899746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35014411781479154,
                                 0,
                                 0.21341145835010433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63087607348092289,
                                 0,
                                 0,
                                 0,
                                 -0.40233870065902827,
                                 0,
                                 0.13550097010254677,
                                 0.35052111966976596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16713761969273647,
                                 0,
                                 0,
                                 0,
                                 0.11840844547731737,
                                 0,
                                 -0.029166998642273335,
                                 -0.29654977684344402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.99711462829178454,
                                 0,
                                 -0.16318488978845333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28079569440901586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29386568695843357,
                                 0,
                                 -0.51276470543525732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66321699314850535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57357204192990785,
                                 0.2694573011187088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26062051923362067,
                                 -0.47638144540556371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38967251653752233,
                                 0,
                                 0,
                                 -0.64815414833840235,
                                 0,
                                 0,
                                 -0.03987747048611863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3622663665867269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0012040790447198635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018989746077103433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2796257064510565,
                                 0,
                                 -0.39432970072173906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63431045938296082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22421276584940203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23242900218040904,
                                 0,
                                 0,
                                 -0.36771668492107473,
                                 0.44295622992224648,
                                 0,
                                 0,
                                 0,
                                 -0.39092828378011113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15606850262681629,
                                 0,
                                 0,
                                 0,
                                 0.31130625862307643,
                                 -0.1190537078617232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3101913527525066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58622273074157261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28436327465963213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7333544025663894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74140049197004765,
                                 0,
                                 0,
                                 0.73179537450697252,
                                 0.22378742656054407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15593486578380758,
                                 0,
                                 0,
                                 -0.27614240899621395,
                                 0,
                                 0,
                                 0.19430507038539779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17486362680521877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49000503880590651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07340108131516658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20710637477264465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31742564206673801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12036010916789314,
                                 0,
                                 0.43617369952618612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35004976394038489,
                                 0,
                                 0,
                                 0,
                                 -0.41412910552713844,
                                 0,
                                 0.099409105233410205,
                                 -0.054398592695137415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30773410439731297,
                                 0,
                                 0,
                                 0,
                                 0.26065737890609547,
                                 0,
                                 0.26437965291460375,
                                 0.5058138674751107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67020070132389775,
                                 0,
                                 0.25015767409771289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27110071488301135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75163283679027459,
                                 0,
                                 0.32285591496297672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59148130985443281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39640600271568455,
                                 0.47909230729456653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33712237371022286,
                                 0,
                                 -0.43848347441770363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59086870728283691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30743247691457609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2931840483939121,
                                 0,
                                 0,
                                 0.029058509337911348,
                                 0.64493100477997312,
                                 0,
                                 0,
                                 0,
                                 0.42059689922039417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08869554804365791,
                                 0,
                                 0,
                                 0,
                                 -0.84532568727497781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5203628773867105,
                                 0,
                                 0.2887660472840155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66836452623900811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54885783216353012,
                                 0,
                                 -0.15101398544528816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43873070690542976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52126553877739112,
                                 0.47309881171607254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28691256040944996,
                                 0,
                                 0.1478072596236015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22595400790410775,
                                 0,
                                 0,
                                 0,
                                 0.19020899827490495,
                                 0,
                                 0.22861924588544347,
                                 0.48006517855169351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083430076529833669,
                                 0,
                                 0,
                                 0,
                                 -0.1559192225512803,
                                 0,
                                 -0.3820848755371703,
                                 0.59043200368633497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15587762153553728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46501466422404819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60455797928086485,
                                 0.10495011026380051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.434167632526269,
                                 -0.44097292441941172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086915904358856599,
                                 0,
                                 -0.14565190222107183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38427421365604791,
                                 0,
                                 0,
                                 0,
                                 -0.46565964800262444,
                                 0,
                                 -0.10678531375726399,
                                 0.47341436980722268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33305025731909965,
                                 0,
                                 0,
                                 0,
                                 -0.49244218943047102,
                                 0,
                                 0.11192041149986909,
                                 -0.072479919798937614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072048816596619408,
                                 0,
                                 0.43796318135026208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20940494388293912,
                                 0,
                                 0,
                                 0,
                                 0.19732011982826891,
                                 0,
                                 -0.30088062260001697,
                                 0.077386618207041319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59746456265933379,
                                 0,
                                 0,
                                 0,
                                 0.15709062806596025,
                                 0,
                                 0.49038929839055523,
                                 0.039631916776495454,
                                 0,
                                 0,
                                 0.69348144579817095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32730007053160037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15766679793206442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.257171504532743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56194509747569032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093656927030987172,
                                 0,
                                 0,
                                 0.069793624878322941,
                                 -0.49692927903570955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33358633107748575,
                                 0,
                                 0,
                                 0.10229923718269121,
                                 0,
                                 0,
                                 -0.24998575187464395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12474427242521272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33093346292616926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66247581150255019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43134332861943303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53123841081716028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077846351440593181,
                                 -0.33688457673144234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47508367149561903,
                                 -0.4318250992405071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31952219257836328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1967396846973832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37079637464250115,
                                 0.60852809210575076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53420468718208391,
                                 0.25695919282620377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49530122673668087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059569528244007089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15736873353882797,
                                 0,
                                 0.30523225992273267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52097560921366126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43591108169015735,
                                 0,
                                 -0.57540978784518626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065466733521671816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50058251733417924,
                                 -0.68681137021341965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0276207701540689,
                                 0,
                                 -0.06309015381823814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0097936863626448545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34806135282879352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31527954345905701,
                                 0,
                                 0,
                                 0.24106999058241321,
                                 0.18873078669542831,
                                 0,
                                 0,
                                 0,
                                 0.32941421485952843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62912000207299501,
                                 0,
                                 0,
                                 0,
                                 0.092019830827056337,
                                 -0.027621918340069565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40630857963372757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90199930343674639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21744958937589903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91246968214355162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0354910565156801,
                                 0,
                                 0,
                                 -0.18406743918827206,
                                 -0.16346514802936435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25138714220220126,
                                 0,
                                 0,
                                 0.40302458823053122,
                                 0,
                                 0,
                                 0.31561727913312909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68834247056642195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31601523246319213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20119333588809607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93419492648233426,
                                 0,
                                 -0.081213106595484308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6642991064219812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19926508361493853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31575117212756221,
                                 0,
                                 0,
                                 0.88107954632369045,
                                 -0.16879097871148863,
                                 0,
                                 0,
                                 0,
                                 0.32483630595572299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081330610866054517,
                                 0,
                                 0,
                                 0,
                                 -0.51390809198923282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26387672733959033,
                                 0,
                                 0.58530444560237949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0081540480304305718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6977239924957912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42944979297238084,
                                 0,
                                 0,
                                 -0.95328691692503509,
                                 -0.093299096685291058,
                                 0,
                                 0,
                                 0,
                                 0.81967249197179404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10762630771464982,
                                 0,
                                 0,
                                 0,
                                 0.19686040849229572,
                                 0,
                                 0,
                                 0,
                                 0.69657592218452202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41033166789409647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05247263098368124,
                                 0.030635030040726791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47345535438299607,
                                 -0.34432259916269581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40218916671725224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14491024906481695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42579765669755548,
                                 0.42095362601385128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16518899153457917,
                                 -0.65684997622265706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84597334417517334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081574599110228796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65561757380871177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22771828591098023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18944684985339444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75487829168823994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26754446391010378,
                                 0,
                                 -0.32840100727171168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3956533315937345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69298739495054718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039744570505565464,
                                 0,
                                 0,
                                 0.24144873498410802,
                                 0.078715948418527332,
                                 0,
                                 0,
                                 0,
                                 0.9400444944004791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15139647967604514,
                                 0,
                                 0,
                                 0,
                                 0.57800297620692709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48076340766314024,
                                 0,
                                 0.52109241997321853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10924844423181912,
                                 0,
                                 0,
                                 0,
                                 0.0081023206663170672,
                                 0,
                                 -0.3458016499722405,
                                 0.084308208530559897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38510175039924943,
                                 0,
                                 0,
                                 0,
                                 -0.24476273865899556,
                                 0,
                                 -0.14131496592807818,
                                 -0.36119196335259007,
                                 0,
                                 0,
                                 0,
                                 -0.13204022143993341,
                                 -0.21975134794168955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44401634636943244,
                                 0,
                                 0,
                                 0.26973319995139344,
                                 0,
                                 0,
                                 -0.18077953620723564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38003080013603596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57488029740038193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39594974920832338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30644308692325889,
                                 0,
                                 -0.80244656200961528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34197923746458003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2424477157042563,
                                 0,
                                 -0.31382494757350271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017653725587543849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68363309903047187,
                                 0.94406008816295661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021708711048325863,
                                 0,
                                 -0.077385651771644526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12260730175588336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51145558892495913,
                                 0,
                                 0.87766717968810426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69865384927944962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77830274863666693,
                                 -0.19885430172663027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17776040745149133,
                                 0,
                                 0.10240802959297998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1315007866205771,
                                 0,
                                 0,
                                 0,
                                 0.074895503711761541,
                                 0,
                                 0.64386895052040805,
                                 -0.1907852897690705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078467789071206301,
                                 0,
                                 0,
                                 0,
                                 -0.48906317641475688,
                                 0,
                                 0.48064303210443027,
                                 -0.087681689455781864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25797171520290341,
                                 0,
                                 0.70735327246651136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26073315186667279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71283677149817304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48848682449124931,
                                 0,
                                 0,
                                 -0.37059698197697988,
                                 0.33399572649653952,
                                 0,
                                 0,
                                 0,
                                 0.15972056218933894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28992909083031881,
                                 0,
                                 0,
                                 0,
                                 -0.56386961958698223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14494187790096461,
                                 0,
                                 -0.25960977418967657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19175804120938403,
                                 0,
                                 0,
                                 0,
                                 0.31115749847649377,
                                 0,
                                 0.10266690401668592,
                                 0.59643308060353539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30281173349866947,
                                 0,
                                 0,
                                 0,
                                 0.36718286328120037,
                                 0,
                                 0.40021041978160854,
                                 -0.15825608360156204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65756799648107644,
                                 0,
                                 0.15287226794385739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043977285877160724,
                                 0,
                                 0,
                                 0,
                                 0.481549656873758,
                                 0,
                                 -0.22810096772084196,
                                 0.094892445690422406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26716245666511396,
                                 0,
                                 0,
                                 0,
                                 -0.39376141953762211,
                                 0,
                                 0.070987899542567318,
                                 0.1338378967849784,
                                 0,
                                 0,
                                 -0.51477927845128202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27964987153668425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19687608663019726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026161794665400639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95137765286808806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76104945007307756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47336501190422581,
                                 0,
                                 0.7681396886693187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26557402674802083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39096791606641884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.492726491967521,
                                 0,
                                 0,
                                 -0.22356783819986942,
                                 0.82194573515277858,
                                 0,
                                 0,
                                 0,
                                 -0.13049332929927596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3850839515188843,
                                 0,
                                 0,
                                 0,
                                 0.20337910897545503,
                                 0.064466365567735981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1140169796451178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83866684408441394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20303649406266333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087333267477233245,
                                 0,
                                 0,
                                 0.48024079706650641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0057180391884791779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22274566727641401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56401848849212033,
                                 0,
                                 0,
                                 -0.14450251029375377,
                                 -0.50100136965633257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17630794225180166,
                                 0,
                                 0,
                                 0,
                                 -0.46589558170570844,
                                 0,
                                 0,
                                 0.33497505122591714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37486816667886352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6204089723207783,
                                 0,
                                 -0.19784973005207193,
                                 0,
                                 -0.34872598350131817,
                                 0,
                                 0,
                                 0,
                                 -0.33903387402310126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068830419644497556,
                                 0.48468879954707056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54940467463414833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2095583171911381,
                                 -0.6474840480070011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67793397034103675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26518311742087186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97097048093334881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51475017124986788,
                                 0,
                                 0,
                                 0.24372193013021443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17546541268269,
                                 0,
                                 0,
                                 0.44276890179740513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74312937687096337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23870939631226762,
                                 0,
                                 0,
                                 0.51211067454580783,
                                 0,
                                 0.15087239400099595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39778238860484005,
                                 0,
                                 0,
                                 -0.54976183930185896,
                                 -0.20654079919365595,
                                 0,
                                 0.094500223391192517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12107451188125251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33209172968254458,
                                 0,
                                 0,
                                 -0.14489908528619799,
                                 0,
                                 0.81815679224487381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28636535734248758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13757570087696597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46044266280922408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13010966719935824,
                                 0,
                                 0,
                                 0.027409865237246936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27907657011249892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67518898798227722,
                                 0,
                                 0.61564607170717967,
                                 0,
                                 -0.25857898147333042,
                                 0,
                                 0,
                                 0,
                                 -0.84790911147011028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086168306240251694,
                                 -0.36427738487749461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20802001697400063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24850926782883415,
                                 -0.16962049392009468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047951451890974217,
                                 0,
                                 0,
                                 -0.2646882096041992,
                                 0,
                                 0.24219331048116266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19730388925761938,
                                 0,
                                 0,
                                 -0.044686554657746361,
                                 0.42502697616818963,
                                 0,
                                 -0.56032312097922377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37159112165920932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050058046921543357,
                                 0,
                                 0,
                                 -0.43916033211204503,
                                 0,
                                 0,
                                 0,
                                 -0.49784448760002936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95366983778245085,
                                 0,
                                 -0.1633792913951595,
                                 0,
                                 0.58036672963214753,
                                 0,
                                 0,
                                 0,
                                 0.23737706147661919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74479935144030673,
                                 -0.014029688820390296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22754894589176589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48850187690959379,
                                 0.244347646743896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37009747205765037,
                                 0,
                                 0,
                                 0.0024983745550787931,
                                 0,
                                 0.47058971810912253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30553965686456136,
                                 0,
                                 0,
                                 0.042783235904606642,
                                 0.23648638929073226,
                                 0,
                                 0.17629363872896861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4111521179659024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12846594964763874,
                                 0,
                                 0,
                                 0.52328503286156414,
                                 0,
                                 0,
                                 0,
                                 -0.66939145849693305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44566502464766111,
                                 0,
                                 -0.26041043577632228,
                                 0,
                                 -0.3859706811014133,
                                 0,
                                 0,
                                 0,
                                 0.07065381476447069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17394951788353025,
                                 -0.37128954752733212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4753899593862948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74624462381276602,
                                 0.014207294052550765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47738257993479022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19536148457898167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3676013240450679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57604019663233685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036079024323562622,
                                 0,
                                 0,
                                 -0.51544643285781777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017447850349291527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23949671500644709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27167386899387463,
                                 0,
                                 0,
                                 0.081976513442228408,
                                 0.13023023096607428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20513930777087616,
                                 0,
                                 0,
                                 0,
                                 -0.26057997465122007,
                                 0,
                                 0,
                                 -0.85724330521132863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39237014117711522,
                                 0,
                                 0,
                                 0,
                                 -1.0761212389256958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83071159808855199,
                                 0,
                                 0,
                                 0,
                                 0.028225861298720907,
                                 0,
                                 0.094253870185181679,
                                 0,
                                 0,
                                 0,
                                 1.1134087325020947,
                                 -0.10580407121282559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022364307392048172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15230874790946661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36559174315306137,
                                 0,
                                 -0.020394268878174415,
                                 0,
                                 -0.12014264631348756,
                                 0,
                                 0,
                                 0,
                                 -0.64906814727266282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59894253942807674,
                                 0.52145822573277689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36915303869643473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70475756976675774,
                                 0.19889231622459347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25635651294670891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18747366378056285,
                                 0,
                                 0,
                                 -1.0673140716284404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50637506074159733,
                                 0,
                                 0,
                                 -0.044444788511201261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37854881164634946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15902666090530093,
                                 0,
                                 0,
                                 -0.22398381188868643,
                                 0,
                                 0.20465871159883697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36742667522123051,
                                 0,
                                 0,
                                 -0.57472918798308248,
                                 -0.10265905017863089,
                                 0,
                                 -0.41149976807818311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40326127566946002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15425956540400965,
                                 0,
                                 0,
                                 0.22595126472502122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10348063037259392,
                                 0,
                                 0,
                                 0,
                                 0.31403337903782669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46486990943206935,
                                 0,
                                 0,
                                 0,
                                 0.10761098020981225,
                                 0,
                                 1.1355536335185945,
                                 0,
                                 0,
                                 0,
                                 -0.36893306906576989,
                                 0.52936927101478348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45091169035227013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03807369958000989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44710860369452449,
                                 0,
                                 0,
                                 -0.51755202972595238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0518183463468151,
                                 0,
                                 0,
                                 -1.3173469536011513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33359382871826315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34238458172777159,
                                 0,
                                 0,
                                 -0.13420703541932749,
                                 0,
                                 0.22012886805138154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39830594593847779,
                                 0,
                                 0,
                                 0.27163199301814156,
                                 -0.33776391669174455,
                                 0,
                                 0.11580729026090511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16661618208383219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36953268566272524,
                                 0,
                                 0,
                                 -0.54042745608147436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52051680833546399,
                                 0,
                                 0,
                                 0.21471687097627812,
                                 0,
                                 0.044329794188966543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059909303074127299,
                                 0,
                                 0,
                                 0.026661260115139907,
                                 -0.29762631174742582,
                                 0,
                                 -0.39310790760092412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048440243549724225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65637948707879201,
                                 0,
                                 0,
                                 0.01995251372881679,
                                 0,
                                 0,
                                 0.6599750751964899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23357974207488999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1574533796712034,
                                 0,
                                 0,
                                 -0.64975971164033941,
                                 0.1130251862103933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19912415777462483,
                                 0,
                                 0,
                                 0,
                                 0.019449201563441872,
                                 0,
                                 0,
                                 -0.10045277597951718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27048132973265709,
                                 0,
                                 0,
                                 -0.51734341493574076,
                                 0,
                                 -0.43468722647465208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11268427147630641,
                                 0,
                                 0,
                                 -0.46390362066124835,
                                 -0.10347491113213284,
                                 0,
                                 0.29142253893432013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33698097146321948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14834770065616995,
                                 0,
                                 0,
                                 -0.10555080898172085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97050596098301223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40547626775313389,
                                 0,
                                 0,
                                 0.25280969911136097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63703834361525891,
                                 0,
                                 0,
                                 0.98895341919148272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74902638520783071,
                                 0,
                                 0.60280226156560035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14186818615940047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36115341946146895,
                                 0,
                                 0,
                                 0.42129009754579594,
                                 -0.030072636309845788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39910570310230864,
                                 0,
                                 0,
                                 0,
                                 -0.37139100705243022,
                                 0,
                                 0,
                                 0.10229714905875983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20957508023284793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30008186781222723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35750108340796416,
                                 0,
                                 0,
                                 0.55543513958670365,
                                 -0.28046188002399169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56716069278988535,
                                 0,
                                 0,
                                 0,
                                 0.11555466712275636,
                                 0,
                                 0,
                                 -0.12661335136471849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29242960574703059,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7731881969327522,
                                 0,
                                 0,
                                 0.036413942499325558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0050015750237773,
                                 0,
                                 0,
                                 0.025487305754300187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10776731467182582,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47593994047035532,
                                 0,
                                 0,
                                 0,
                                 -0.54652321775997392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0966165949313051,
                                 0,
                                 0,
                                 0,
                                 0.56786646609496572,
                                 0,
                                 0.24769761372886581,
                                 0,
                                 0,
                                 0,
                                 -0.08960095114849688,
                                 0.37732380682370836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44924796362220371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015708675641790668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094836787067018397,
                                 0,
                                 -0.045356807314843733,
                                 0,
                                 -0.067546906993454003,
                                 0,
                                 0,
                                 0,
                                 0.54899032860530761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08238007207878327,
                                 -0.3211735299889778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68638362031581446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66302191530282761,
                                 -0.24705658607307651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82647033205125275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21871840326179648,
                                 0,
                                 -0.80817306008504786,
                                 0,
                                 -0.030496015319389225,
                                 0,
                                 0,
                                 0,
                                 -0.18317354035849892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29179040729542172,
                                 0.34188149614461671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12556523012637125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094076751540916187,
                                 -0.43810587244794469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080658632735359934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55113727825595837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1120536455223021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070176082285100361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78787845751611352,
                                 0,
                                 0,
                                 0.22695532526068635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82920185319694029,
                                 0,
                                 0,
                                 0,
                                 -0.51607502567853469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77181456882932342,
                                 0,
                                 0,
                                 0,
                                 -0.64746395994133343,
                                 0,
                                 0.43797005831463331,
                                 0,
                                 0,
                                 0,
                                 0.2176148530761785,
                                 -0.0075269095125203855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13131558042936445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12051604232340216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38117234016683982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48273584383866597,
                                 0,
                                 0,
                                 0.15092464550317364,
                                 0.68534611254162114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18769933877680953,
                                 0,
                                 0,
                                 0,
                                 -0.13367066290638549,
                                 0,
                                 0,
                                 0.24813948741092023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22436502677118225,
                                 0,
                                 0,
                                 0,
                                 -0.63614928811468952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13328105452062097,
                                 0,
                                 0,
                                 0,
                                 0.10772044400689981,
                                 0,
                                 0.5005302748862096,
                                 0,
                                 0,
                                 0,
                                 -0.79901193795473024,
                                 -0.86818979208777591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57223918401241036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35848265375697835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31842896990538372,
                                 0,
                                 0.13818191584793707,
                                 0,
                                 0.87774385429618662,
                                 0,
                                 0,
                                 0,
                                 -0.040639487106478328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020821644617659969,
                                 -0.049925761377608284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51178903242610596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54159395865226212,
                                 -0.6215185256307616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28009502647138074,
                                 0,
                                 0,
                                 0.2705884233128209,
                                 0,
                                 -0.64418424063982094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23519557433020338,
                                 0,
                                 0,
                                 0.10367826720308333,
                                 0.21552185146011418,
                                 0,
                                 -0.36138044676030051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027013479980336236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41364412596187539,
                                 0,
                                 0,
                                 0.13569273138508819,
                                 0,
                                 0,
                                 0.24259961824138179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71435961262897185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0061092904877650608,
                                 0,
                                 0,
                                 0.15119147054752918,
                                 0.40951397728731981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41570798277365928,
                                 0,
                                 0,
                                 0,
                                 -0.13182219598500927,
                                 0,
                                 0,
                                 0.2237133634528749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.94386676600986796,
                                 0,
                                 0,
                                 0,
                                 -0.31170543710431498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33701787929948657,
                                 0,
                                 0,
                                 0,
                                 0.54882463861211839,
                                 0,
                                 -0.43295902936036312,
                                 0,
                                 0,
                                 0,
                                 0.014079032567024141,
                                 -0.23087732362574387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.016514948939175461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14563882867309991,
                                 0,
                                 0,
                                 0,
                                 -0.30528874647168769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23994987325432879,
                                 0,
                                 0,
                                 0,
                                 0.31446050251030283,
                                 0,
                                 0.1765551471031746,
                                 0,
                                 0,
                                 0,
                                 0.25319169409306053,
                                 0.35887833701235228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0259542594071307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28883352408272889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26960800545499397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30327355867534161,
                                 0,
                                 0,
                                 -0.13631046521559528,
                                 0.047945809580186835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4451765506886905,
                                 0,
                                 0,
                                 0,
                                 -0.72672691819348612,
                                 0,
                                 0,
                                 -0.068690238573267226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19456128386307553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71831399019445141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27310727860872785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1758126940377896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57479228537482108,
                                 0,
                                 0,
                                 0.10142513481468464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034930900856579017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27081678376211937,
                                 0,
                                 0.64467958183195306,
                                 0,
                                 -0.028294229462627607,
                                 0,
                                 0,
                                 0,
                                 -0.2970852957996799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76663819987033843,
                                 0.55330393863477023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22696684686237642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17418591459999089,
                                 0.58092567966483766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45879729169983979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090618620764668728,
                                 0,
                                 0.5352073284261778,
                                 0,
                                 -0.59057336251165782,
                                 0,
                                 0,
                                 0,
                                 0.4022228514135146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44917198976151879,
                                 0.4258670493557471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54949498733120139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080274222376595539,
                                 -0.31446889411332068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23282936922923425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21702905984533893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23544959676778082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6157204254350841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15167084015229149,
                                 0,
                                 0,
                                 0.66418120519809387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22366301764884619,
                                 0,
                                 0,
                                 0.44778588748117903,
                                 0,
                                 0.0091021445300579207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54739824234643253,
                                 0,
                                 0,
                                 -0.23633094486202855,
                                 0.36444407006960855,
                                 0,
                                 0.19057608626810602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075455047723660768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2861249392296773,
                                 0,
                                 0,
                                 -0.37038221246191272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20176601094825919,
                                 0,
                                 0,
                                 0,
                                 -0.62594870631428123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39978360695273596,
                                 0,
                                 0,
                                 0,
                                 -0.77125839417748665,
                                 0,
                                 -0.49395440583830014,
                                 0,
                                 0,
                                 0,
                                 -0.49825424564286375,
                                 0.55140021013751739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24366893830070863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18154379638045148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16155302644405883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43434248704823969,
                                 0,
                                 0,
                                 0.10962869594984992,
                                 0,
                                 -0.028443471603655734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21115684432953816,
                                 0,
                                 0,
                                 0.085546226170014922,
                                 -0.56354785434034493,
                                 0,
                                 -0.23855581744656887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60457299272386245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.067419139452423144,
                                 0,
                                 0,
                                 0.045440577772288201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5014619824841442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44253949180941204,
                                 0,
                                 0,
                                 0.94287971918362246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1276883828251214,
                                 0,
                                 0,
                                 -0.56300876157927682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76129354809656458,
                                 0.33853090454950185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55107881364778721,
                                 0,
                                 0,
                                 -0.035083249553222971,
                                 -0.095276893467748411,
                                 0,
                                 0,
                                 0.61113044152860341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44472851971095417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0021730647828870214,
                                 0,
                                 0,
                                 -0.011482681201306341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38048732750730258,
                                 -0.096705830162715972,
                                 0,
                                 -0.043512286447688259,
                                 0,
                                 -0.57502991353499222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061783064982206926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28559667712666781,
                                 0,
                                 0,
                                 0,
                                 0.051817855454388384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46681995273469817,
                                 0,
                                 0.29808283657973589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3442131759593105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30893847781476752,
                                 0.068723820980817363,
                                 0,
                                 0.48105451962668261,
                                 0,
                                 -0.30247457525590704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22792148484571836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38500116675647544,
                                 0,
                                 0,
                                 0,
                                 0.014514206160845962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48259300199814198,
                                 0,
                                 -0.32709203625022693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19146739730640674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042323306936106087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57312543794842985,
                                 0,
                                 0,
                                 -0.14042827509106684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2771734415007068,
                                 0,
                                 0.85565214018909996,
                                 0,
                                 -0.24156086112144365,
                                 0,
                                 0,
                                 0,
                                 0.42358213699305286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19827718865485125,
                                 0,
                                 0,
                                 -0.35089056479864178,
                                 0.65250328880925679,
                                 0,
                                 -0.11929587838663117,
                                 0,
                                 -0.077600285400418301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35053448233343754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11363757601683851,
                                 0,
                                 0,
                                 0,
                                 0.18514371304043215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011175891077427724,
                                 0,
                                 0.26644951658201821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43551761943670192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67839775275515279,
                                 0,
                                 0,
                                 0.28100812533543396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011666870346300505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70879346667099441,
                                 0,
                                 0,
                                 0,
                                 0.14531433432716562,
                                 0,
                                 0.077072888442206902,
                                 -0.4189741780411213,
                                 -0.437187667772995,
                                 0,
                                 0,
                                 0.29223408561048847,
                                 0,
                                 0,
                                 0.49374678798075633,
                                 0,
                                 -0.097666494406193821,
                                 0.54962798404571245,
                                 0,
                                 0.28034077168438593,
                                 0,
                                 0.4045952868216886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16838950793787072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063049466396292705,
                                 0,
                                 0,
                                 0,
                                 -0.070025241881591913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022120231336628535,
                                 0,
                                 0.097247949207064227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63158671319223658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18245545388546375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29995102675983015,
                                 0,
                                 0,
                                 0.23497756735774628,
                                 0.36558716153165116,
                                 0,
                                 0,
                                 0,
                                 0.80748326813242999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18931912407680576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16558942682872169,
                                 0,
                                 0,
                                 -0.81269866806671576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47017595761427133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027147702417164604,
                                 0,
                                 0,
                                 0,
                                 -0.27508953644709128,
                                 0,
                                 -0.32582598851156319,
                                 0.74131602693238163,
                                 -0.28424297908106094,
                                 0,
                                 0,
                                 0.40905593732199047,
                                 0,
                                 0,
                                 -0.27244840589792263,
                                 -0.29966797872837059,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21752567565673991,
                                 0,
                                 0,
                                 -0.035961805636347766,
                                 -0.74443907465085213,
                                 0,
                                 0,
                                 0.061051973657791976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29770704672308068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18625757552717234,
                                 0,
                                 0,
                                 -0.42467656166303591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16162010982509267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16675108344443967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25111392087566725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15173925354471807,
                                 0,
                                 0,
                                 0.30149532963546571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47292940364524727,
                                 0,
                                 -0.15583341834851105,
                                 0,
                                 -1.201725747358003,
                                 0,
                                 0,
                                 0,
                                 -0.95735247708795024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039057776746442077,
                                 0,
                                 0.3242403760239167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35195860094316522,
                                 0,
                                 0,
                                 0.49140949982009619,
                                 0.13218843833335403,
                                 0,
                                 0,
                                 0.44006453287253444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35970687959162773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11754752041987319,
                                 0,
                                 0,
                                 -0.41853672498458488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10282523306243664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16854947987933364,
                                 0,
                                 0,
                                 -0.79148134246667845,
                                 0.029368613045700098,
                                 0,
                                 0,
                                 0.3344549875015107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38494709704419439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26507782211127373,
                                 0,
                                 0,
                                 0.058327998511296705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48100904877917233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49834447738494619,
                                 0,
                                 0,
                                 -1.1428649498661461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19171764913387573,
                                 0,
                                 -0.41307500009040327,
                                 0,
                                 -0.90718067790258472,
                                 0,
                                 0,
                                 0,
                                 0.22215196968677367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56459484634470991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052628897997618267,
                                 0,
                                 0,
                                 -0.32832650097677724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45751923830979641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34948089892671935,
                                 0,
                                 0,
                                 0,
                                 0.51019058375393345,
                                 0,
                                 0.17651278588695632,
                                 -0.2639580772318863,
                                 0.12228413190046274,
                                 0,
                                 0,
                                 0.74517590260887889,
                                 0,
                                 0,
                                 -0.47344869639015197,
                                 0.26254586662591295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31588204784693741,
                                 0,
                                 0,
                                 0.1798205281904281,
                                 -0.01706064206923754,
                                 0,
                                 0,
                                 0.017555416849960204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58848529595786492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36340358243370191,
                                 0,
                                 0,
                                 0.56566457548103211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48509901586345799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20290486238219227,
                                 0,
                                 0,
                                 -0.056811265676888892,
                                 -0.74908271383771641,
                                 0,
                                 0,
                                 0,
                                 0.39759689327831838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032754236475743319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082281102030655084,
                                 -0.15372544952282344,
                                 0,
                                 0.47569462012807778,
                                 0,
                                 0.40212266849833844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26265419977791366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11848166559342546,
                                 0,
                                 0,
                                 0,
                                 0.12665729869348674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49705954068938324,
                                 0,
                                 0.22083086899016233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43209793974770971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4551625164841086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27513183418406473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19224341027204955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72935319111139163,
                                 0,
                                 0,
                                 0.19737432875465818,
                                 0.063426952333408615,
                                 0,
                                 0,
                                 0,
                                 -0.4212508509282118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45897114340795309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0028370981371852854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37152810790823698,
                                 0,
                                 0,
                                 -0.38448839997499784,
                                 -0.062650037924845442,
                                 0,
                                 0,
                                 0,
                                 0.082260657143767513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83871070294067585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16224573024370695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61150696073725175,
                                 0,
                                 0,
                                 0.37476468527682671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078393612650346819,
                                 0,
                                 -0.52007186288951868,
                                 0,
                                 -0.17900509053092672,
                                 0,
                                 0,
                                 0,
                                 0.56464111172588782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0403081637915688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011724372885615453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43892915918796371,
                                 0,
                                 0,
                                 0.32376641654739385,
                                 0.43880983975754873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51813564204172402,
                                 0,
                                 0,
                                 0.90974471849975347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45440679651921645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0968105368417325,
                                 0,
                                 0,
                                 -0.12994827232330866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88172548979770071,
                                 0,
                                 0.38335872292274065,
                                 0,
                                 -0.119269356226861,
                                 0,
                                 0,
                                 0,
                                 -0.32644226038164259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15643125269480027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78296368508381509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07326527482639951,
                                 0,
                                 0,
                                 0.25924905392752051,
                                 -0.54446413342559885,
                                 0,
                                 0,
                                 0,
                                 -0.061028945872728918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11926554641238894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1117288447361191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59288897596230139,
                                 0,
                                 0,
                                 -0.1422152303341713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17752069463193376,
                                 0,
                                 0.87602148719533623,
                                 0,
                                 -0.27895300621299474,
                                 0,
                                 0,
                                 0,
                                 -0.047695762326086064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1691431454768386,
                                 0,
                                 0,
                                 -0.43255370592186992,
                                 -0.084252496398575946,
                                 0,
                                 -0.21121671191656666,
                                 0,
                                 0.29277329131348562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23454714638775809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25545559090829822,
                                 0,
                                 0,
                                 0,
                                 -0.69113394318420096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13271042614444972,
                                 0,
                                 -0.22877343663096394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087090275592701383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076052256273720378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46434671374126846,
                                 0,
                                 0,
                                 0.17156345923545996,
                                 -0.59885977571124605,
                                 0,
                                 0,
                                 0.153247650279804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20427048910818371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24366661211909296,
                                 0,
                                 0,
                                 0.51569995088735954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15988144406117577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0533266786015798,
                                 0,
                                 0,
                                 -1.233593274416636,
                                 0.48404046376915838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67971873748584266,
                                 0,
                                 0,
                                 -0.23177887083784332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68039087491035433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33593850424936589,
                                 0,
                                 0,
                                 -0.97813482314657707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09894356238540572,
                                 0,
                                 -0.027652472207973677,
                                 0,
                                 0.362174339850246,
                                 0,
                                 0,
                                 0,
                                 -0.65773676637739109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43752002158122011,
                                 0,
                                 0,
                                 -0.090495813936401229,
                                 -0.28597291762429305,
                                 0,
                                 0.20937796790035093,
                                 0,
                                 0.22544912492210775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7102837478649825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26568518688170145,
                                 0,
                                 0,
                                 0,
                                 0.43256600070115192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083271489939683085,
                                 0,
                                 -0.039074160454999958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21141821031097477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2243968457811167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53462877956600341,
                                 0,
                                 0,
                                 -0.65755610323497338,
                                 -0.042404889042089111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1209173384914996,
                                 0,
                                 0,
                                 0.0020901435787734624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14281002465386333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63049144791260758,
                                 0,
                                 0,
                                 -0.41637319061561573,
                                 -0.75524550666659729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0095493848352217,
                                 0,
                                 0,
                                 0.29643286654002227,
                                 0,
                                 0,
                                 0.60814539022705794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30154512023629154,
                                 0,
                                 0,
                                 -0.25727306040637571,
                                 -0.16054714729205394,
                                 0,
                                 0,
                                 -0.24100159788121578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1848453008494941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56191990719475671,
                                 0,
                                 0,
                                 -0.19814482875809872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21149857013163387,
                                 0,
                                 0,
                                 0.44848002719141178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053963136843812057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3496992700907256,
                                 0,
                                 0,
                                 0,
                                 -0.0059698389121495762,
                                 0,
                                 -0.35402715717973826,
                                 0.88058789801999404,
                                 0.48843715077034716,
                                 0,
                                 0,
                                 0.50316845067548444,
                                 0,
                                 0,
                                 0.23750015893808046,
                                 0,
                                 0.27501436000469781,
                                 0.056862674129086341,
                                 0,
                                 0.58437362881828925,
                                 0,
                                 -0.31386247499463421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39532201867365124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28409324199965169,
                                 0,
                                 0,
                                 0,
                                 -0.47056637495668008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11790601727446177,
                                 0,
                                 0.09366094097501762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0060136679554524718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48511440482650958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30063622433191972,
                                 0,
                                 0,
                                 -0.039887737908821552,
                                 0.18356741559036022,
                                 0,
                                 0,
                                 0.48518089722723873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11749293516451939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61158005062874898,
                                 0,
                                 0,
                                 0.1255332464823454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20265740752702763,
                                 0.31904531098620065,
                                 0,
                                 -0.015590040847256832,
                                 0,
                                 -0.10430108329935479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065672163938689673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087860720600710568,
                                 0,
                                 0,
                                 0,
                                 0.19158092692153803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51123776398126886,
                                 0,
                                 -0.73196658762496336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01198214255557048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22125575845531018,
                                 0,
                                 0,
                                 0.30379125090470738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41478079960504677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26345142582420511,
                                 0,
                                 0,
                                 0,
                                 -0.16481245036800743,
                                 0,
                                 -0.70215017006305758,
                                 -0.50057531687321644,
                                 -0.90179475159991784,
                                 0,
                                 0,
                                 0.42221999226573126,
                                 0,
                                 0,
                                 0.10782584073447166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28529150368852441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43988860581032863,
                                 0,
                                 0,
                                 0.82919237550873959,
                                 -0.028842971961555885,
                                 0,
                                 0,
                                 0,
                                 -0.044089168576818494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18646985006212125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67596309350157813,
                                 0,
                                 0,
                                 -0.39634069265971639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50315973372069023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23591578312177536,
                                 0,
                                 0,
                                 0,
                                 0.11595674565466757,
                                 0,
                                 -1.015073836831605,
                                 -0.33619724288705682,
                                 0.42347593902096636,
                                 0,
                                 0,
                                 -0.62647945990479181,
                                 0,
                                 0,
                                 0.10393732983917461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14579367429934925,
                                 0,
                                 0,
                                 0.35781212528330053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83389220081269322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23489745582958768,
                                 0,
                                 0,
                                 0,
                                 -0.3722268728474401,
                                 0,
                                 0.56925971539141007,
                                 -0.7612301497728825,
                                 0.1612881595042831,
                                 0,
                                 0,
                                 0.22254257665087263,
                                 0,
                                 0,
                                 0.060554974208098675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32922838983858915,
                                 0,
                                 0,
                                 -0.37488387433467563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96534604852744188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22935257706328599,
                                 0,
                                 0,
                                 0,
                                 -0.63212742031562608,
                                 0,
                                 -0.054234706578761199,
                                 -0.43871795671380215,
                                 -0.13321473680426921,
                                 0,
                                 0,
                                 0.24714350164448887,
                                 0,
                                 0,
                                 0.63201230365823169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37518324671060055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58461085790128642,
                                 0,
                                 0,
                                 -0.37272915670718371,
                                 -0.42079453607899264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85156300615108871,
                                 0,
                                 0,
                                 0.88802756682234285,
                                 0,
                                 0,
                                 0,
                                 0.55530007590944597,
                                 0.20134491630770568,
                                 0,
                                 -0.13190217329750123,
                                 0,
                                 -0.022272442817764901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062532178543965269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71764012346280159,
                                 0,
                                 0,
                                 0,
                                 -0.13771350769043944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04109325383547148,
                                 0,
                                 0.27663533498212745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13080294688311433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11124501480815431,
                                 0,
                                 0,
                                 -0.11900323391269105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30894040968707837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7485371794743757,
                                 0,
                                 0,
                                 0,
                                 0.39033335982384998,
                                 0,
                                 0.11607311236605593,
                                 0.01006447627940299,
                                 -0.54788207297299196,
                                 0,
                                 0,
                                 -0.31089588054025041,
                                 0,
                                 0,
                                 0.72464725418473053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64371279313648133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65555685771970795,
                                 0,
                                 0,
                                 0.2399349676817773,
                                 -0.32750270960082006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54878034398808051,
                                 0,
                                 0,
                                 0.053474987932490267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0375728302628497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15869858722102428,
                                 0,
                                 0,
                                 -0.68330692635875434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64672104010822951,
                                 0,
                                 -0.61750515635904413,
                                 0,
                                 0.3975107758652936,
                                 0,
                                 0,
                                 0,
                                 -0.075005615762004693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78776618075608684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77898628127559599,
                                 0,
                                 0,
                                 0.035159958699062355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5304489280259046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48275610937848534,
                                 0,
                                 0,
                                 0,
                                 0.28428734806626299,
                                 0,
                                 0.044107250093206263,
                                 -0.63422588313619011,
                                 0.34842704602860081,
                                 0,
                                 0,
                                 0.26908528208863663,
                                 0,
                                 0,
                                 0.58860548794926815,
                                 0.26901986732404409,
                                 0.1260644579370597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1751252043022338,
                                 0,
                                 -0.37639219225173959,
                                 0,
                                 -0.78186484807888734,
                                 0,
                                 0,
                                 -0.16789258437915217,
                                 0,
                                 0,
                                 -0.077300487784005584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11256249195902848,
                                 -0.08111509862818328,
                                 -0.27325856633589279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55662549364545255,
                                 0.14810477672537645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59239016146019541,
                                 0,
                                 -0.22165740115943919,
                                 0,
                                 -0.16722274370091758,
                                 0,
                                 0,
                                 -0.0076675883830815209,
                                 0,
                                 0,
                                 -0.14054722292858174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38393896725009236,
                                 0.14032009726626504,
                                 -0.23086859462951362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.079487457542061282,
                                 0,
                                 0.43707124395908337,
                                 0,
                                 -0.73285600698050746,
                                 0,
                                 -0.3479385052314829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33846835308499718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068831602669922776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13474780226164129,
                                 0,
                                 0.083998545385636877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37227324498902381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49922244152297318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47713034417387479,
                                 0,
                                 0,
                                 0,
                                 0.61693907123332181,
                                 0,
                                 0.92481459112495301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28519497473849309,
                                 0,
                                 0,
                                 -0.57173724916206847,
                                 0,
                                 0,
                                 0,
                                 0.34222361522618783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20958262253714632,
                                 0,
                                 -0.17192197368933801,
                                 0,
                                 0.09746100314089598,
                                 0,
                                 -0.39917590881805398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27115938834433545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78688936037067847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24830936029522904,
                                 0,
                                 -0.057428984121178868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13925571606001963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20085413035520477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32713708081371295,
                                 0,
                                 0.63129143770026208,
                                 0,
                                 0.50692033029381889,
                                 0,
                                 0.087811646690309497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083219197770256589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03116852958590792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36240960866202498,
                                 0,
                                 0.30089152184587242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38552337969938488,
                                 0,
                                 0,
                                 -0.078324542911079431,
                                 -0.36208307554925617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35886282280536863,
                                 0,
                                 0,
                                 0.34045475831628108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0505434005623004,
                                 -0.028579579717795629,
                                 0,
                                 0.89899692377661444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63811170011370399,
                                 0,
                                 0,
                                 0,
                                 -0.071073785831674952,
                                 0,
                                 0,
                                 0,
                                 -0.30392267394598915,
                                 0,
                                 -0.19228208946677197,
                                 0,
                                 0.26642226427858723,
                                 0,
                                 -0.071406707582510442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74546281957622507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30595452837312226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17292262874425499,
                                 0,
                                 0.33963751442726553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48372135037124991,
                                 0,
                                 0,
                                 0,
                                 0.28415493018484572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33222787050027436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74030420703308886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11740113147111965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.114284418395173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9446147873111338,
                                 0,
                                 0,
                                 -0.014923261768823443,
                                 -0.48093350063475915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87405551732481002,
                                 0,
                                 0,
                                 0.0095364928686567374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40538459933250592,
                                 -0.74591110670255534,
                                 0,
                                 -0.11715752511367175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61994944385134754,
                                 0,
                                 0,
                                 0,
                                 -0.36663922254802117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12470698985665657,
                                 0,
                                 0,
                                 0.17032163412296766,
                                 0.42093187857296033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39082416481184024,
                                 0,
                                 0,
                                 0.56722776420005261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44805776564892191,
                                 -0.40218021715437663,
                                 0,
                                 0.60496795182219887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47192330104202551,
                                 0,
                                 0,
                                 0,
                                 0.71099620773775374,
                                 0,
                                 -0.036294902078118751,
                                 -0.18126170596035551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20668167596635603,
                                 0,
                                 -0.35670975565486829,
                                 0,
                                 0.055576093997191635,
                                 0,
                                 0,
                                 0.68108604155753283,
                                 0,
                                 0,
                                 -0.050790329190898223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13983904398181363,
                                 0.53067252491456596,
                                 -0.1585965522547805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21500489115161522,
                                 0,
                                 0,
                                 0,
                                 -0.20860241355853837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78811437394904105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24412855835716291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1370399534005792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45908056109986461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6996826939879528,
                                 0.19218141987416384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60398623103792548,
                                 0,
                                 -0.17350975655818152,
                                 0,
                                 0.14255764331242182,
                                 0,
                                 0,
                                 0.22282852995044272,
                                 0,
                                 0,
                                 0.032269802870723646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040578666056321738,
                                 -0.034418981866416537,
                                 0.068975043523183788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34797897101342751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092193342386404725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52512548666391268,
                                 0,
                                 0,
                                 0,
                                 0.55755841140237927,
                                 0,
                                 -0.18186718898828746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097226023406431938,
                                 0,
                                 0,
                                 -0.2531664723141071,
                                 0,
                                 0,
                                 0,
                                 -1.1238029425727412,
                                 0,
                                 0,
                                 0,
                                 0.22532291147136363,
                                 -0.15239888451793965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15239763497602396,
                                 0,
                                 -0.0098187012306977101,
                                 0,
                                 -0.10342842912256621,
                                 0,
                                 0,
                                 -0.25787041547375916,
                                 0,
                                 0,
                                 0.35707310093960948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63536360029003758,
                                 0.50214997710390274,
                                 0.20529350915856581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039028992532763193,
                                 0,
                                 0,
                                 -0.42878254981880115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85152431161985664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30428180160092805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.4570253644768829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16983477434889255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5338613358471741,
                                 0,
                                 0,
                                 0,
                                 -0.62084373207770238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13913399762089762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54665373318998234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044004112022817995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.097057710914011636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1731462122916389,
                                 0.52671787212265642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019213088211377224,
                                 0,
                                 0.30887510447071531,
                                 0,
                                 -0.37544123094502202,
                                 0,
                                 0,
                                 0.37137258884978958,
                                 0,
                                 0,
                                 0.37656092531865915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11045094978965275,
                                 0.07187907167679429,
                                 0.39846936903772284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54299878359596288,
                                 0,
                                 0,
                                 -0.37670490277945518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43178970853079923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69064605606056884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34579401868230186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92983625780240176,
                                 0,
                                 0,
                                 -0.090117028741651201,
                                 0,
                                 0.13177607909025577,
                                 0,
                                 0.021435214275430214,
                                 0,
                                 -0.37187530127572588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4190387652103284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.074650238944996422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51579950161247812,
                                 0,
                                 0.6233361911626879,
                                 0,
                                 0,
                                 0.093918011771549792,
                                 0.4318670371470924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39998647663646819,
                                 0,
                                 0.024332019165962306,
                                 0,
                                 0.14315539226944735,
                                 0,
                                 0,
                                 0.28422923226479041,
                                 0,
                                 0,
                                 -0.34551523553135394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57215051296617137,
                                 -0.28440431866406002,
                                 -0.12323357450696587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23494146243971803,
                                 0,
                                 0,
                                 0.82792758649967646,
                                 -0.11521345640796463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54394505559191619,
                                 0,
                                 0,
                                 0.010451408898121711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24344989201409989,
                                 -0.40973093030941787,
                                 0,
                                 -0.60453054781663962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076204301220971868,
                                 0,
                                 0,
                                 0,
                                 0.57823969575034173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081906730832107616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78662635584914609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46763268114358425,
                                 0,
                                 0,
                                 0,
                                 0.23648035280583288,
                                 0,
                                 -0.22208418632590346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37374986693908591,
                                 0,
                                 0,
                                 -0.05664805679385692,
                                 0,
                                 0,
                                 0,
                                 0.4582472923962399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23006915316202348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34697596278927961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40198971882259549,
                                 0,
                                 0,
                                 -0.81451776755671634,
                                 0.68448859130699546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24956737761383738,
                                 0,
                                 0,
                                 -0.56215877002853609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69124441532947967,
                                 -0.18987630060753685,
                                 0,
                                 -0.44440300408502642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35256733224645065,
                                 0,
                                 0,
                                 0,
                                 0.68910880875934766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36995752235898161,
                                 0,
                                 0,
                                 0,
                                 -0.53651197674142659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092601039175025379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20192558796229515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72230447905619433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064912822062800038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64755343184296155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5816859033395968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63751283597601371,
                                 0,
                                 0,
                                 0,
                                 0.064041927762800266,
                                 0,
                                 -0.67343844189249458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28045477315676481,
                                 0,
                                 0,
                                 0.2016551447102379,
                                 0,
                                 0,
                                 0,
                                 0.50638709500274759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085619905879848718,
                                 0,
                                 0,
                                 -0.34679240723617732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27588565584071062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73604578024895539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24694589560099367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1915156835478999,
                                 0,
                                 0,
                                 0,
                                 0.20055647408296731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14033830786715776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19068467608407139,
                                 0,
                                 0,
                                 0,
                                 -0.012831092778513124,
                                 0,
                                 0.92993593464284485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67566075786598079,
                                 0,
                                 0,
                                 1.363323531295906,
                                 0,
                                 0,
                                 0,
                                 -0.33201061029265155,
                                 0,
                                 0,
                                 0,
                                 -0.058666876581588812,
                                 0.32093118894285882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10638979717800397,
                                 0,
                                 -0.21461233182015887,
                                 0,
                                 0.31489406118566526,
                                 0,
                                 0,
                                 -0.10970449893393489,
                                 0,
                                 0,
                                 0.66881823958226039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069580477599111484,
                                 -0.08081356918132522,
                                 -0.51604328051241299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16297916631039361,
                                 -0.30856159567704117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03228538982037997,
                                 0,
                                 -0.5265901370188919,
                                 0,
                                 -0.02907622712356827,
                                 0,
                                 0,
                                 0.19164018413453252,
                                 0,
                                 0,
                                 0.28047395037795436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1673669485103072,
                                 -0.53019231287774393,
                                 0.41777434834225485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085723680314983633,
                                 -0.45498336498236441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1222451562362044,
                                 0,
                                 0.48208040733443097,
                                 0,
                                 -0.25526811101879204,
                                 0,
                                 0,
                                 0.35250601948561644,
                                 0,
                                 0,
                                 0.23661473471551353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20645412028648794,
                                 -0.25512913895122324,
                                 -0.43031752762022824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15217886681023218,
                                 0,
                                 0,
                                 -0.22207705695091828,
                                 -0.50589902097840789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20999786715067986,
                                 0,
                                 0,
                                 -1.0703956545142175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50262274024135256,
                                 -0.59023507811246434,
                                 0,
                                 0.085885708386690851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48031619880220949,
                                 0,
                                 0,
                                 0,
                                 -0.010772437250562299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37575695696565636,
                                 0,
                                 0,
                                 -0.39730562030626382,
                                 -0.1371259691004732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48262236527652913,
                                 0,
                                 0,
                                 0.49818819057457542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09955690186198414,
                                 0.56739349244344417,
                                 0,
                                 -0.33273343903803421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47442619960249266,
                                 0,
                                 0,
                                 0,
                                 0.69589115339172047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099105289121361892,
                                 0,
                                 0,
                                 0,
                                 0.25003766043423858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49047637236070984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22609960789406933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42330974404181065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67585506293733355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13132880245814899,
                                 0,
                                 0,
                                 0.036870665630861832,
                                 -0.72767705954090056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29331671805567938,
                                 0,
                                 0,
                                 -0.15835370772766166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052449221429130055,
                                 -0.11847287207783903,
                                 0,
                                 0.73275065241590842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81318616324383441,
                                 0,
                                 0,
                                 0,
                                 0.45160273513767835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033266708139431403,
                                 0,
                                 0,
                                 0.21278203391478706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2131837089469053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29048444167004656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23975890462816873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0065374857095143457,
                                 0,
                                 0,
                                 0,
                                 -0.85777190373261258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063812568732183356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30195660501746296,
                                 0,
                                 0,
                                 0,
                                 -0.61416910863230179,
                                 0,
                                 0.36035457333316895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0009033850151792,
                                 0,
                                 0,
                                 0.25259099481823633,
                                 0,
                                 0,
                                 0,
                                 -0.08214553376032882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51472826346074552,
                                 0,
                                 -0.055697362676078443,
                                 0,
                                 0.24911560701450913,
                                 0,
                                 -0.50991963903685522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2572194409025077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2651152746314499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35770217318398523,
                                 0,
                                 -0.38141473533448772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53673848323139839,
                                 0,
                                 0,
                                 0,
                                 -0.37407236763306556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00028643214892873359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040319328730128556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51437900789298108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55296489067413579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6066558257224246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4986902318925952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33727742394941862,
                                 0,
                                 0,
                                 0,
                                 -0.87857994222768543,
                                 0,
                                 0.82732413639317781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39584492346668465,
                                 0,
                                 0,
                                 -0.66575156254904022,
                                 0,
                                 0,
                                 0,
                                 -0.034634402759752991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44651667489945729,
                                 0,
                                 0,
                                 0.96237420499131965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34213393934668529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50996331309499232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13150525401170057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019984680733082599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67596512407761167,
                                 0,
                                 0,
                                 0.12748754513401184,
                                 0.54502102431147115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37425331710216703,
                                 0,
                                 0,
                                 -0.24699829165632492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31855093104865712,
                                 0.071237535930445142,
                                 0,
                                 0.83012557751026539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3864703245717433,
                                 0,
                                 0,
                                 0,
                                 0.12837364909954913,
                                 0,
                                 0,
                                 0,
                                 0.46320971875330252,
                                 0,
                                 0.13078264675220028,
                                 0,
                                 -0.17089835476005966,
                                 0,
                                 0.55132247379196375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046939822625101796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39035300996138456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52951690152533859,
                                 0,
                                 0.014246742020755231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40582716383532746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5439011342662301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31740812728600998,
                                 0,
                                 0,
                                 0,
                                 0.63730107931274982,
                                 0,
                                 0.44758012093726579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0004570243712436,
                                 0,
                                 0,
                                 0.13240950588795103,
                                 0,
                                 0,
                                 0,
                                 -0.014181012419302627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51258140760283322,
                                 0,
                                 0.55347904161085248,
                                 0,
                                 0.18371194844619304,
                                 0,
                                 -0.067244621583029102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07288919912664768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23076710107244489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29078241320242315,
                                 0,
                                 -0.49952840742960725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12299140390496616,
                                 0,
                                 0,
                                 0.40343462961090049,
                                 0.0046833342984943533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73476014167143189,
                                 0,
                                 0,
                                 -0.57394543262680142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23610846272826619,
                                 0.93608653032456501,
                                 0,
                                 0.040352012939228736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37857862895044464,
                                 0,
                                 0,
                                 0,
                                 0.5371657584838857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.5787726351841651,
                                 0,
                                 0,
                                 -0.17851026087740438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039021677585524696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46360356265486696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58689024757489017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40892863299257898,
                                 -0.98298556635959811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50239460247224033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40604352321949438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20447730790069035,
                                 0,
                                 0,
                                 0.35917089438489735,
                                 0,
                                 -0.91604668733219197,
                                 0,
                                 0.033947785748426829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043490803068806184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81061518315022929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41289379234936324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91057143289307652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8222083894786677,
                                 0,
                                 0,
                                 0,
                                 -0.28047532463103458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15619622240462272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40481574046147262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31080908571664467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55150521177404266,
                                 0,
                                 -0.21648055092875551,
                                 0,
                                 0,
                                 -0.037453783769891488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6240216493857258,
                                 0.057955876258788314,
                                 -0.43708654062903518,
                                 -0.23991255993679694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43373556212423409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2406477385966718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3860850047956278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41925042181565408,
                                 0,
                                 0,
                                 0.40540912655998362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24344527211210548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33953712935522412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10532697501549571,
                                 -0.51696685048373869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38648956910409749,
                                 0.04615794668369054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46161955465987659,
                                 -0.45621070121893215,
                                 0,
                                 -0.34921692581867303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39663649451623945,
                                 0,
                                 0,
                                 0.24144485990324538,
                                 -0.27340879967390352,
                                 0,
                                 0,
                                 -0.026009716774683857,
                                 0,
                                 0,
                                 0,
                                 -0.1194862847389839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47442795970468093,
                                 -0.14076470138057198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36070726536523329,
                                 -0.023081304772299808,
                                 0,
                                 0.57097063084470523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45973601313316742,
                                 0,
                                 0,
                                 -0.053286010341189509,
                                 -0.028260522259404983,
                                 0,
                                 0,
                                 -0.022738612445828758,
                                 0,
                                 0,
                                 0,
                                 -0.28799508399838442,
                                 0,
                                 0.12656949587540581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37396247700345631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27241044950215026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8331820362467639,
                                 0,
                                 0,
                                 0,
                                 -1.2025296165509973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39607995821710218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5328975901524805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16757762561162565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55723518920349968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28080460056068013,
                                 0,
                                 0,
                                 0.29675071199972564,
                                 0,
                                 0.35431210991922579,
                                 0,
                                 0.88313901427327401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88391263752997185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37912671868126502,
                                 0,
                                 0.11772675095790953,
                                 -0.22871607068747679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78057903585297339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40605606803034305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12612351367900371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22664526303004209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62334870606951465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36457535389411189,
                                 0,
                                 0,
                                 -0.24698425012594444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46247592454837777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14567324261294676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18974335487120997,
                                 -0.30829319128418858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30196832383168803,
                                 0,
                                 0.94670123970848363,
                                 0.0049331981329303037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03375306562164633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091990163582382781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054277970283620317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20201867542995322,
                                 0,
                                 -0.013266387289166681,
                                 0.26887070007989722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46356122744025818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77411992814590747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26938880757338879,
                                 0,
                                 -0.088781769715722977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63167020434394261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14951043536466613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011315346468082091,
                                 0,
                                 0,
                                 -0.89840483109166336,
                                 0,
                                 0.33136230263077548,
                                 0,
                                 0.51513160401331604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59501794727261825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95827558479398744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4118092909482185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6714209633869398,
                                 0,
                                 -0.12859953374866634,
                                 0,
                                 0,
                                 -0.075870272569569408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0078760102286507122,
                                 -0.27423335112783598,
                                 -0.95968336793319142,
                                 0.42914419287205546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32953055661817604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17245377982635929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21542083967081965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77121546967967658,
                                 0,
                                 0,
                                 -0.069790550883957289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045100606834056783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11651843483097044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22584483721070273,
                                 0.50753623821970084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020220511181140266,
                                 0.26888230253047107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56627970986321818,
                                 0.23716111336512982,
                                 0,
                                 -0.1785939266773218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090763634585517963,
                                 0,
                                 0,
                                 -0.32007836913558307,
                                 0.39738702639848528,
                                 0,
                                 0,
                                 0.49982139967258737,
                                 0,
                                 0,
                                 0,
                                 0.0073119149294901264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031377143489336956,
                                 -0.30297635417458452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12433598817415252,
                                 -0.15823278274818983,
                                 0,
                                 0.15629373522841289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01076674405650066,
                                 0,
                                 0,
                                 -0.15089677506236565,
                                 -0.48518405517061769,
                                 0,
                                 0,
                                 0.71679940245308515,
                                 0,
                                 0,
                                 0,
                                 0.26496284694970523,
                                 0,
                                 0,
                                 0,
                                 0.34460274378006761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32482745957388209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26589850596140063,
                                 0,
                                 0,
                                 0.059455485313258838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59059331898730794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25570403897202554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52931377438943972,
                                 -0.08450446462904368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46131639938988506,
                                 0.48278379573301589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2202262155875305,
                                 0.093395437380752441,
                                 0,
                                 -0.14430557456649115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24133785724262261,
                                 0,
                                 0,
                                 -0.0058911150398438805,
                                 -0.59450057870909756,
                                 0,
                                 0,
                                 -0.16420425283168838,
                                 0,
                                 0,
                                 0,
                                 0.19335964500567249,
                                 0,
                                 0,
                                 -0.15011163309676959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51649419082182946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38877088771385998,
                                 0,
                                 -0.21078522359159346,
                                 0,
                                 0,
                                 0.72931578394072871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75771245983638891,
                                 -0.21615261417972079,
                                 -0.013007071255927405,
                                 0.7597206200530644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0032809395374640161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030645309518560749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5241614619180851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22257025608180941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6590621202569934,
                                 0,
                                 0,
                                 0,
                                 1.031752518202206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33596017000841472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36824284306197158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72485412757563072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0071080915625245343,
                                 0,
                                 0.19312596355311398,
                                 0,
                                 0,
                                 -0.053112181751303694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66503677007500206,
                                 0.71589797136649946,
                                 0.38018045736745409,
                                 0.74627884266378341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41537970886976006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71679914378940057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.093553393282952965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018615362803808568,
                                 0,
                                 0,
                                 -0.070001464763093435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37705259439981609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48023031669922867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20696018156714349,
                                 0.2378606324967418,
                                 0,
                                 0,
                                 -0.55073857714362506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49396110884589212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12124283854188572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8348584263602391,
                                 0,
                                 0,
                                 0.048762417650036534,
                                 0,
                                 -0.33566805378896053,
                                 0,
                                 0.9652048222031453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28890730644198775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64568817198463968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2823265831550118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25289397199292024,
                                 0,
                                 -0.55476242266423359,
                                 0,
                                 0,
                                 -0.53184105322696484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43573352672225008,
                                 0.80994835287065792,
                                 0.21882359636642809,
                                 0.44153019247154301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2990185765047087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87113680617892797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32475402613419713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1027608759474115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44244376403909652,
                                 0,
                                 0,
                                 0,
                                 -0.13202305171752357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0064981098044019636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49635624037824166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26221800691834346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21646574912259706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18351627111096358,
                                 0,
                                 0,
                                 0.35365260802347104,
                                 0,
                                 1.0035322231411048,
                                 0,
                                 0.049198707357572674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56446828527711157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72129070406600004,
                                 0,
                                 -0.20244908854356969,
                                 -0.1920234704923908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15664309043005301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13686536642851188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59884212213974375,
                                 0,
                                 -0.61426612859959195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032376717019401292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1881442400329166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79600178930957532,
                                 0,
                                 0,
                                 -0.40264464594829874,
                                 0,
                                 0.47104313288953481,
                                 0,
                                 -0.62080015347400519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0887881004556283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3602634636864106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44259438218107816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29169354932441344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64744369217706532,
                                 0,
                                 0,
                                 0,
                                 -0.29194681422895635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2114595869608176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065192988848846084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1793580502429641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28378097026522164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12829271086739433,
                                 0,
                                 0,
                                 -0.92216708539760561,
                                 0,
                                 -0.40861250131989962,
                                 0,
                                 -0.0032956912669690006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05623056587739278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88400151502465563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53398723728726716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85178886254419317,
                                 0,
                                 0.40300548122062851,
                                 0,
                                 0,
                                 -0.18622265731662305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096493810156342369,
                                 0.15322545633938733,
                                 -0.57610123423956006,
                                 0.37507342116579701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098041763987186045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49353962353439956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34754837131537508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22738610680895591,
                                 0,
                                 -0.4997391017519458,
                                 0,
                                 0,
                                 -0.78909832789528156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31658829681127015,
                                 -0.64353563932615698,
                                 0.34692319698801288,
                                 0.44739132641653662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53860675388027046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039053362882596532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2812428924642862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40564515931579093,
                                 0,
                                 0.15505820066814147,
                                 0,
                                 0,
                                 -0.47233315687126576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19066947210150614,
                                 0.4157598764725548,
                                 0.1984131752762312,
                                 -0.60511175565097552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47986413625388663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50955604592900083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1304882805040381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68092322335349509,
                                 0,
                                 -0.44820972428295652,
                                 0,
                                 0,
                                 -0.034919262162677177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33682194492252387,
                                 -0.39098794359443101,
                                 -0.073539447039929109,
                                 -0.082109601277303768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0019893614867141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76511162652971454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39812774865656786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80212789950004215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70600056635613984,
                                 0,
                                 0,
                                 0.16023994516920817,
                                 0,
                                 -0.45488673259157586,
                                 0,
                                 -0.30418153243741147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58198590456746213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44211018556258641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0298302546299971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14251521974219195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85287129525536964,
                                 0,
                                 0,
                                 0,
                                 -0.15535508052289609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23137475194284435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15738346350074453,
                                 0,
                                 -0.036215971746086706,
                                 0.91110512482445272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37553618081958101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052553439861482143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0041247035991752584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33842123261041801,
                                 -0.12372738563946707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16980945298601971,
                                 0.17787626251480193,
                                 0,
                                 -0.40942870516369712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050611463562042658,
                                 0,
                                 0,
                                 0.40623367054016657,
                                 -0.044887751048162686,
                                 0,
                                 0,
                                 0.33734778885753786,
                                 0,
                                 0,
                                 0,
                                 -0.59887374921091718,
                                 0,
                                 0,
                                 0,
                                 0.25124670725141418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53898783058168354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0070482202092288226,
                                 0,
                                 0,
                                 -0.55079331213629057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13389364549251986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24067910118050151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43926856400005415,
                                 -0.27227458770692287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38935605824713881,
                                 0,
                                 0,
                                 0.45083494875198699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24238301211441865,
                                 0.035740113134001217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27925032216245155,
                                 -0.1288465120038455,
                                 0,
                                 0.47171128268180584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63004887300988233,
                                 0,
                                 0,
                                 0.42222738745558386,
                                 -0.023531674163648625,
                                 0,
                                 0,
                                 0.062000957986002386,
                                 0,
                                 0,
                                 0,
                                 -0.20795194608391568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10045381655632719,
                                 0.39357056357130316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28081686615436446,
                                 -0.38287652783184412,
                                 0,
                                 0.083086901123605575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088549154173384131,
                                 0,
                                 0,
                                 -0.52965462621601656,
                                 -0.091818806942736614,
                                 0,
                                 0,
                                 0.039535578021879944,
                                 0,
                                 0,
                                 0,
                                 -0.55162172745009275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30174449128930825,
                                 0,
                                 0,
                                 -0.39882370302677622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33355789501835764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2829799952333435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041147702507427178,
                                 0,
                                 0.78311329898696702,
                                 0,
                                 0,
                                 -0.31890541103906944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80544346164145053,
                                 -0.09336055161685558,
                                 0.51749684960657683,
                                 -0.034393184097156387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42109150022006675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47436328120178806,
                                 0.18008928667616778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054537708544591272,
                                 0.69734684953143433,
                                 0,
                                 0.18563431549772305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24665448877390536,
                                 0,
                                 0,
                                 0.0039778486960674632,
                                 -0.34385964045957335,
                                 0,
                                 0,
                                 0.0048043299182004544,
                                 0,
                                 0,
                                 0,
                                 -0.19925722807820526,
                                 0,
                                 0,
                                 0,
                                 0.17149629985304796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071001469635180503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077181371664276952,
                                 0,
                                 0,
                                 0.56732305613454492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33377155430458855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68707389550385545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087030232399642818,
                                 -0.21607208657134352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36863577166631467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078450082571394297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13959013475964277,
                                 0,
                                 0,
                                 -0.36892765792251381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32328975829792705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15464351997041198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61511062089568047,
                                 -0.44223101187305847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42336353528177062,
                                 0,
                                 0.2177704014552268,
                                 0.091583882330275909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095412823446467232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45376273943362022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74158447338434175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054293299915249615,
                                 0.61397591503935955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28899386664259047,
                                 -0.14214387771970832,
                                 0,
                                 0.20829192306939898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3106796996989325,
                                 0,
                                 0,
                                 0.43561297986712122,
                                 0.22013455291465378,
                                 0,
                                 0,
                                 0.29830656313233112,
                                 0,
                                 0,
                                 0,
                                 0.22192651973396044,
                                 -0.16142769835787393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36398102913792874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74840820302899647,
                                 1.205553573471956,
                                 0,
                                 0.28645306506629453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22578130552881198,
                                 0,
                                 0,
                                 0,
                                 -0.32863737595121623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41914370890312541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1269197484651676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040789451185142322,
                                 -0.4987397957610582,
                                 -0.30828614709281799,
                                 0,
                                 0,
                                 0.11536114937720265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50748786335686435,
                                 0.27394816706158653,
                                 0,
                                 -0.45416839314272706,
                                 0,
                                 0,
                                 0,
                                 0.67703078690268081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22017952680970984,
                                 0,
                                 0,
                                 -0.14996771910800993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062197911570579689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16815352995699201,
                                 -0.1331055465490425,
                                 0,
                                 0,
                                 0,
                                 -0.61547965762158507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20489872492646172,
                                 0,
                                 0,
                                 0,
                                 0.55673724980444372,
                                 0,
                                 -0.28380322085890253,
                                 0.17807096953127818,
                                 -0.23822812192946585,
                                 0,
                                 0,
                                 -0.043370342041909905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19211460495289559,
                                 0,
                                 0,
                                 0,
                                 -0.1762605956784454,
                                 0,
                                 0.48690613205126654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.296206358997957,
                                 0,
                                 0,
                                 -0.35547835955024704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47390725754360896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033128343611019018,
                                 0,
                                 0,
                                 -0.58743940844787523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35209892024568284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36435186935241687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41533532375746751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16166496552723056,
                                 0,
                                 -0.31534271075276754,
                                 0.34336007016695219,
                                 0.17075294590678419,
                                 0,
                                 0,
                                 -0.29562956990723005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031039549103493939,
                                 0,
                                 0,
                                 0,
                                 -0.0060636779914725603,
                                 0,
                                 -0.013579311837428365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79667131869678609,
                                 0,
                                 0,
                                 -0.064062900561497799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25606321473427696,
                                 0,
                                 0.0012587281319663968,
                                 0.10249240561466519,
                                 0.14909857899302068,
                                 0,
                                 0,
                                 0.58981811723509825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096732621825832699,
                                 0,
                                 0,
                                 0,
                                 0.067856792361105728,
                                 0,
                                 0.0040266286799113841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14157904350330866,
                                 0,
                                 0,
                                 -0.72096253098589458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30110820881369965,
                                 0,
                                 -0.46256440158394319,
                                 0.11713967456516083,
                                 0.39160620690930953,
                                 0,
                                 0,
                                 0.17410262630199111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44312171025101066,
                                 0,
                                 0,
                                 0,
                                 0.33024794072032504,
                                 0,
                                 0.28238410302053346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17888408078553392,
                                 0,
                                 0,
                                 0.28428563698667847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68819088162988007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22597870376591392,
                                 0,
                                 -0.86184170969956608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15284323207163966,
                                 -0.4958626820521338,
                                 0,
                                 -0.33558555078094277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15456754320971897,
                                 -0.78705068167242087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38124975393427035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79531234731668909,
                                 0,
                                 0,
                                 -0.43789353113532692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063063623582679335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15861727149886298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035209249969110568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4137406766621623,
                                 0,
                                 -0.44503809808664724,
                                 -0.12560367473729084,
                                 0.091000035716601479,
                                 0,
                                 0,
                                 0.4095839268402573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011951765329409642,
                                 0,
                                 0,
                                 0,
                                 -0.18762662547703329,
                                 0,
                                 -0.61263158656927796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07367743978361474,
                                 0,
                                 0,
                                 0.15116560361039125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098458255080641516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32095728734852497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046465029481704355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11139932644198654,
                                 -0.25009969697752421,
                                 -0.95714242411184947,
                                 0,
                                 0,
                                 -0.41548113326346525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69785345471996885,
                                 0.37018320787378933,
                                 0,
                                 0.50852269841519893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62828600502052245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5009995320110483,
                                 0,
                                 0,
                                 -0.45141836832668725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30274431773062593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072601697574071963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2314141161392558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11971403844162193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018403385621024455,
                                 0,
                                 0,
                                 0.74983370127031623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087413110347186199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27936652285849317,
                                 -0.0958677932421097,
                                 0,
                                 0,
                                 0,
                                 -0.4656605680235586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33370972489454076,
                                 -0.33494141685194267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46665281704432698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21722506578166573,
                                 0.91414780499236736,
                                 0,
                                 -0.81254819292838931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29713559131759359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094562621608290931,
                                 0,
                                 -0.13611055875814632,
                                 -0.70503124225793479,
                                 0.18145982627378351,
                                 0,
                                 0,
                                 -0.36597288718926152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37293420578877062,
                                 0,
                                 0,
                                 0,
                                 -0.11457316077461301,
                                 0,
                                 -0.095417385467805441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046819505890146385,
                                 0,
                                 0,
                                 -0.38091400147788762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23645296109202291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66668101732697638,
                                 0,
                                 0,
                                 -0.40555172051296573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34888901326035426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20064329435383588,
                                 -0.12203883132431813,
                                 0,
                                 0,
                                 0,
                                 -0.39759806393078584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01397313065118605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20930817820411379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29293966681848571,
                                 0,
                                 0,
                                 0.46807028702082698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15076854703060288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47962905117645588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63127764338937631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18355299618551837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57842304053591276,
                                 0,
                                 -0.35940539795535636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79422100478090918,
                                 0.29721725977939062,
                                 0,
                                 0.43029274908123166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12284104252695115,
                                 0.38481366592494959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4182394426223644,
                                 0,
                                 0.21692403391249188,
                                 -0.47655207284617429,
                                 0.18175779313347404,
                                 0,
                                 0,
                                 0.3494849484086312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1074055483513459,
                                 0,
                                 0,
                                 0,
                                 0.23346012486371742,
                                 0,
                                 0.42224685198508599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32720654945128208,
                                 0,
                                 0,
                                 0.21058517932176951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16582611268339917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4741373541720883,
                                 0,
                                 0.15157179096390228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83495261387734798,
                                 0.32046303868099763,
                                 0,
                                 -0.046290607619572058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34168840705547548,
                                 -0.87526183983708905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36618430511209354,
                                 0,
                                 0.31692659833879461,
                                 0.18414969942689444,
                                 0.15633732092450178,
                                 0,
                                 0,
                                 -0.16208728144393095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24812350924777224,
                                 0,
                                 0,
                                 0,
                                 0.66423652632346863,
                                 0,
                                 -0.33722143760818252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14876548450647781,
                                 0,
                                 0,
                                 -0.20546757245254546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081486515255923667,
                                 -0.21437486395959635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41550673548342004,
                                 0.25702780750249704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80293487005740516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.9446254740147787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064029795043584081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065811283863312864,
                                 0.1449570412034005,
                                 0.26750328035878507,
                                 0,
                                 0,
                                 0.36637626423664615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34522365792169246,
                                 0.216532490315405,
                                 0,
                                 -0.20007124151014616,
                                 0,
                                 0.4358806538156404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16187275005181556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21314378596661643,
                                 0.58336086292627221,
                                 0,
                                 0.7536457738146296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2393956809505449,
                                 0,
                                 0,
                                 -0.43607579051394302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3355643155714167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16911112816292151,
                                 0.20067044789139901,
                                 0,
                                 -0.069174359351958759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32545192666436229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27790897041994805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10954400557406559,
                                 0,
                                 0,
                                 -0.16135766300019333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049940658293500383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63344023335316813,
                                 -0.61156383285439142,
                                 0,
                                 0,
                                 0,
                                 0.28483162740225304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16078073077503829,
                                 1.2170440053476257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40767748780391744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55266319599591973,
                                 0.23101625062715891,
                                 0,
                                 -0.45631635970076345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28949302121494547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23354110212155238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15155313963757977,
                                 0,
                                 0,
                                 0.18135424214372001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65784257584460237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53061087512493421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41868375051775208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25566476379502051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31728525199238866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64169035995904422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52315088153529221,
                                 1.2439787230281145,
                                 0.44050076305332886,
                                 0,
                                 0,
                                 -0.27873310170320481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38929638520078275,
                                 0.55786662694545186,
                                 0,
                                 0.10934251591257904,
                                 0,
                                 0,
                                 0.89691272113278231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023911349445165708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46739782794276724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28862323228125653,
                                 0.10156564378992869,
                                 -0.5461713431012879,
                                 0,
                                 0,
                                 0.38496514395688686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18802859906177716,
                                 -0.95046357330705433,
                                 0,
                                 0.729500392962532,
                                 0,
                                 0,
                                 0.075106010515754884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47035004234236177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27931714966747484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.93424658177878817,
                                 -0.60095021949064398,
                                 -0.018909844510203777,
                                 0,
                                 0,
                                 0.73861898428092609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38814603010907844,
                                 0.12311062670409301,
                                 0,
                                 -0.49190152099460283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0034770518475276376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47568219256109201,
                                 0,
                                 -0.60407666685373296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15708487761051915,
                                 0.57519967198271538,
                                 0,
                                 -0.74440204106234709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87529692437738105,
                                 -0.27057590307006341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038426235297676109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7456059907528011,
                                 0,
                                 -0.69052917857916296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16429578179005971,
                                 -0.22392930935628003,
                                 0,
                                 1.1276570819241178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41567496577828966,
                                 0.51187749875629329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52236346230431663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11491994108394529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15677448855209891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35951297744276012,
                                 -0.5664697225998383,
                                 0.7750254589424217,
                                 0,
                                 0,
                                 0.57711130632405083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17425897683964858,
                                 0.34173922670287316,
                                 0,
                                 0.46441872885865276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63628659913124685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23372182177217515,
                                 0,
                                 0.04431912509676264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0086622606504013488,
                                 0.76722854304775279,
                                 0,
                                 0.68343610825974599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59443347832308213,
                                 -0.19355050303767737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12581564904861459,
                                 0,
                                 0.073147162397521143,
                                 0.10771179538565985,
                                 0.77993377109895889,
                                 0,
                                 0,
                                 -0.20584616373878406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40528044414181474,
                                 0,
                                 0,
                                 0,
                                 -0.25767711983573832,
                                 0,
                                 0.077394834479551672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27623178745052601,
                                 0,
                                 0,
                                 -0.060042122738863418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16151625330777591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25536887804989172,
                                 0,
                                 0,
                                 -0.36065731795613098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10452431396326334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3272081537692863,
                                 -0.12761672341878202,
                                 0,
                                 0,
                                 0,
                                 -0.15425459654788884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78775282817058534,
                                 0,
                                 0,
                                 0.34592568693821335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39671937125476398,
                                 0,
                                 0,
                                 -0.043666597763677123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63690315365342665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23913805640672911,
                                 0.43641458605682987,
                                 0,
                                 0,
                                 0,
                                 -0.059219834205060023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25346611407680386,
                                 0,
                                 0,
                                 0,
                                 -0.052013066578534509,
                                 0,
                                 -0.48642912233097535,
                                 -0.20176233294086754,
                                 -0.17754540322830237,
                                 0,
                                 0,
                                 -0.20011303941536671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61631018337400922,
                                 0,
                                 0,
                                 0,
                                 0.49475765476894229,
                                 0,
                                 0.023631012965909425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11141245841492364,
                                 0,
                                 0,
                                 -0.10397678760810736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078190682228213682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14556940516322722,
                                 0,
                                 -0.14619774521317108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39159936873148171,
                                 0.83279935662392557,
                                 0,
                                 -0.0062394562512475219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67265067351239471,
                                 -0.031462160062466285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0600907614945347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12356108222940737,
                                 0,
                                 0.010611746175266501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15654182086029464,
                                 0.036936958992760199,
                                 0,
                                 -0.36993848950334629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12941035014058,
                                 0.55591894932738761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48650843485429202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39690735596246224,
                                 0,
                                 0,
                                 0.24101336014875485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43885694451932999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3337121053120653,
                                 -0.037411417323107377,
                                 0,
                                 0,
                                 0,
                                 0.36994562874566039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32475850176635229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37008900608452489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081229609442524456,
                                 0,
                                 0,
                                 0.086061017854977384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57000631440071226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57028531671238203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44597851788681853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24417495741938264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85574594167647589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39887687094104396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60347642508697785,
                                 -0.30513894580740464,
                                 -0.23527299483382275,
                                 0,
                                 0,
                                 -0.66845809562333891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28374566729217637,
                                 0.48944372317229173,
                                 0,
                                 -0.47312887758616451,
                                 0,
                                 0,
                                 0.45211889212936363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31331416643232746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44260201705596269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2986724806425976,
                                 -0.017717335373044207,
                                 0.20969711037701713,
                                 0,
                                 0,
                                 -0.105734421998468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79341320663637993,
                                 0.59328583553067182,
                                 0,
                                 0.8026977104514238,
                                 0,
                                 -0.11562160399354826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3533543613287764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1835381756435921,
                                 0.080164507569356114,
                                 0,
                                 1.1797112347483465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046389773911607812,
                                 0,
                                 0,
                                 0,
                                 -0.40303978618243513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095008217915965851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18821437182948875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53215394003595495,
                                 0.69399142683378501,
                                 -0.97793430178499474,
                                 0,
                                 0,
                                 0.64987819407930014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0055251981461532755,
                                 0.6090806628446972,
                                 0,
                                 -0.37476468031976656,
                                 0,
                                 0,
                                 0,
                                 -0.10822165118978729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33850236443464515,
                                 0,
                                 0,
                                 0.18623291255610683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50508056576659444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42018867229183832,
                                 -0.61322520212788523,
                                 0,
                                 0,
                                 0,
                                 -0.031153049359887785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17418658536205642,
                                 0.045815504345511016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054371792393180247,
                                 0,
                                 0.75892900219156267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50009127155108546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29983482478443974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38894222536384904,
                                 0,
                                 0,
                                 0,
                                 -0.22275647152322034,
                                 0,
                                 0.94310182433139711,
                                 0,
                                 0,
                                 0,
                                 0.14780437785942907,
                                 0,
                                 0,
                                 0.010185153651081469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36732097845364281,
                                 0,
                                 -0.40141818221653447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21037648955436722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20969715458800964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17330967189590599,
                                 0.67183039049832871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14659492621369163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30145533324788792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34073302071991829,
                                 0,
                                 0,
                                 0.36604824135166286,
                                 0.21054805147108954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31601411169516086,
                                 0,
                                 0,
                                 0,
                                 -0.28764902896892441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97413828797105206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34928074087844113,
                                 0.40406237782785964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13237323527435477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90507256478443687,
                                 0,
                                 0,
                                 0,
                                 0.18157913629179914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035117322001715107,
                                 0,
                                 0,
                                 0,
                                 0.54818186459845042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013778382293513344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053580565459547702,
                                 0.50014845771117555,
                                 0,
                                 -0.26469322892825164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58482538272495976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4081813812896038,
                                 0,
                                 0,
                                 -0.063731529744950527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37341814411451746,
                                 0,
                                 0.25963213478767067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29462534982330424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05899897934929095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31764860372023479,
                                 0.27952041552419732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34505131059322214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48383738478071925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58867342800833933,
                                 0,
                                 0,
                                 0.71461520922467636,
                                 -0.82066476836525037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38314240107498249,
                                 0,
                                 0,
                                 0,
                                 -0.017296293636036408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095978646586860547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015479296941978832,
                                 -0.16041567287613895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0017584480091780291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15870280696681974,
                                 0,
                                 0,
                                 -0.33961023018597436,
                                 0,
                                 0,
                                 -0.0042961747645951041,
                                 0.0028895394008687002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07514630054247369,
                                 0,
                                 0,
                                 0,
                                 -0.27589565151968165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40302297507109458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41398621969235883,
                                 0.97845226208320946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.449006679467363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23867840149883091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0582712324530419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91793871772238811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19465335887233318,
                                 0,
                                 0,
                                 0,
                                 -0.30188120205793906,
                                 0.091863678734832893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67220904285950778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08314575568425317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23312759344499107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51994440178707069,
                                 0,
                                 -0.4997721249254683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06043718397182174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64418265847317269,
                                 0,
                                 0.95729925383725911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012314342842090015,
                                 0,
                                 -0.65575312474644676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59109412930877481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74964224650003497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57521503035106325,
                                 0,
                                 0,
                                 0,
                                 -0.30835122901139944,
                                 0,
                                 0.28892358464760526,
                                 0,
                                 0,
                                 0,
                                 0.10584075363400808,
                                 0,
                                 0,
                                 -0.19882199998810651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21456312693956345,
                                 0,
                                 -0.079132455109139341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47483921498375781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013309707191451831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23384005171496725,
                                 0.39647221875046335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61443075391235691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28622071295599116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4570864623461261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68870236165999854,
                                 0,
                                 -0.66660555998803006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10979597527660723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50290939307944005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33283741030880548,
                                 0,
                                 0,
                                 0,
                                 0.41417087653377449,
                                 0,
                                 0.47763136001742879,
                                 0,
                                 0,
                                 0,
                                 0.45035453500730149,
                                 0,
                                 0,
                                 0.11212009920220956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38494934332616865,
                                 0,
                                 0.054480369644734829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0033723394318511193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035830545297630884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71796115568938834,
                                 0.015648322055995367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33726917195681105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051932480061661582,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37333894401346535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01905865224818732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20650860918074476,
                                 0,
                                 -0.14241822334663912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88912910951226198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082313250867319165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13591347313327679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26194327186801958,
                                 0,
                                 0,
                                 0,
                                 0.1454455306613861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35624272198848339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11037120507097996,
                                 -0.71483841600789255,
                                 0,
                                 -0.27825854491242985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40527322766069246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79642919074218987,
                                 0,
                                 0,
                                 -0.027000954496268305,
                                 0.26650723227340439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31739195158000283,
                                 0,
                                 0,
                                 0,
                                 0.71844561793726869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53088109893656599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63894132616256161,
                                 -0.20843445017254067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072672987139427686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13048680251423561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67677296935302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42175687769545966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72137353815230065,
                                 0,
                                 0,
                                 0,
                                 -1.0516651700934654,
                                 -0.56019823812336089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18143246076262765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045135933506833911,
                                 0,
                                 0,
                                 -0.19022987651544276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40961035729680068,
                                 0,
                                 0.63607580167945099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36327992416679361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23043426848674795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28785017183871492,
                                 0.19568866727433787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094098160673814657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27262387301075436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16660519076776067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0099392833389666674,
                                 0,
                                 0,
                                 0,
                                 -0.23667928011222281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40102730412847076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31039747617349134,
                                 0.070727798682824777,
                                 0,
                                 0.6707593744988386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45170431430914265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54843251812744676,
                                 0,
                                 0,
                                 -0.044302084991593257,
                                 -0.26621120397561066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46549448962760409,
                                 0,
                                 0,
                                 0,
                                 0.38586360155421079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44630115122074698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22313156392831718,
                                 -0.36111319401040864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85843046876625273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81726611660439197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61193477669605034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21360855200551121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40377279919564801,
                                 0,
                                 -0.64221745826038812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06284455609818268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021955415827597365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81390103952774151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60811701207660307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52454512364999628,
                                 0,
                                 0,
                                 0,
                                 0.24442698065445875,
                                 1.1322728879087423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39307997752223234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44698921443720041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55643886359406292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43457894603824837,
                                 0,
                                 -0.3689505959599122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37440576064384917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15941567381150801,
                                 0,
                                 0,
                                 -0.67942504422705874,
                                 0,
                                 0,
                                 -0.28567347793298425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49270534075519878,
                                 0,
                                 -0.26963746707093689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13907117733127444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1787801465035152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16101628962978146,
                                 -0.15194830299548423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14325756793438171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14306977527646042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16159954280393424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19414950298139702,
                                 0,
                                 0,
                                 0,
                                 0.11084869947919054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30447914520522423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85399168862793839,
                                 0.020847644373598838,
                                 0,
                                 0.29451309780317964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12133499461142097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64393458616883736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0632139443527315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53334197125538529,
                                 0,
                                 0,
                                 0,
                                 -0.68782142342118302,
                                 0.44880269379609855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71006166785341629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4554530990724393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65860238777219293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46127074547934721,
                                 0,
                                 0,
                                 0,
                                 0.090230197996820971,
                                 -0.31680852429840956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3670722752005204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1826159154211468,
                                 0,
                                 0,
                                 0.17125028151309971,
                                 0.019897002160345817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076503751761847649,
                                 0,
                                 0,
                                 0,
                                 -0.98217232043819258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66213812675533645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32372337727619471,
                                 -0.32328812597259055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45204339933792481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95406861462790804,
                                 0.58315937230566739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59592635652693637,
                                 0,
                                 0.67416542225622766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035506381910422755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1104951684023341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1103133269103482,
                                 0,
                                 0,
                                 0,
                                 -0.87870149388890584,
                                 0,
                                 -0.16823202872885354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14730522492246387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22639492574032141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17427389277664648,
                                 0,
                                 0,
                                 0.40650044553546411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28930068770742789,
                                 0,
                                 0.21220601038113443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55172191923875635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39824680160908266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1130304052516363,
                                 0.068483793763323933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0092803567304657331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44171269013364722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25870699159337812,
                                 0,
                                 0,
                                 0.6163445967454918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082814587369469422,
                                 0,
                                 0.18426366796812274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060881237893235338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36099955252630955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15807528238477883,
                                 0.32039447439782548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18024207968538386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46714435871847182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3482906108076218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51993576401355746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45828039970189199,
                                 0,
                                 -0.091913344891647403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1712267138425127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60047720728557896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19311727409219562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49028576214420855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68788563611626075,
                                 0,
                                 0,
                                 0,
                                 0.26381189828092605,
                                 0.61642808236060231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4195104970361227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1975582856702798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078110813646248861,
                                 0,
                                 -0.14507242795892533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35250498752715664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15401125826474427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21075618886758288,
                                 0,
                                 0,
                                 0,
                                 0.86424191011299201,
                                 0,
                                 0.37842658868762946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090756606226591277,
                                 0,
                                 0,
                                 0.38430956040694059,
                                 0.20354869341649312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72359348872362383,
                                 0,
                                 0,
                                 0,
                                 0.37982672192873901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31093210841791674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73129558715441012,
                                 0.27129254063873542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39393919596706461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25495573423455592,
                                 0,
                                 0,
                                 -0.0030401526297945576,
                                 0,
                                 0,
                                 0.038198021122186801,
                                 -0.33184747790982227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71614665353841978,
                                 0,
                                 0,
                                 0,
                                 -1.1483133325443093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22059175383200394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63799437519014524,
                                 -0.41482601727721069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24076419839357965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82608461476980877,
                                 0,
                                 0,
                                 0,
                                 0.029716713763434231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71724392115523572,
                                 0,
                                 0,
                                 0,
                                 -0.086831144101829794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5315460144948343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28913963990506836,
                                 0.0174297850209571,
                                 0,
                                 0.275769070231836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18612671090079361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68526053538492815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34393382211887868,
                                 0,
                                 0,
                                 0,
                                 -0.37860288171110923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1829354812230429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2314177672681679,
                                 0.11541540139838585,
                                 0,
                                 -0.029661303488162413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4093498522101201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033149491322518265,
                                 0,
                                 0,
                                 0.47290192213917159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13656774208043826,
                                 0,
                                 -0.10944050270045649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29417855974420587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26470441813664181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38421377839038007,
                                 -0.36187212227129129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54398913748856592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11632547172452679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43156688649264635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50511391190548005,
                                 0,
                                 0,
                                 0,
                                 -0.034769665317874683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.538011963391269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0081369284481401082,
                                 0.44730768864142101,
                                 0,
                                 -0.12312411059965041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22942151505664377,
                                 0,
                                 0,
                                 0,
                                 -0.13145035201230992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2783795898426789,
                                 0,
                                 -0.50055031610968292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67317753377724809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74416983404400927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5336896451367048,
                                 0,
                                 0,
                                 0,
                                 -0.5258846270519616,
                                 0,
                                 0.46146648806744706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88985030099305407,
                                 0,
                                 0,
                                 -0.5407768785544993,
                                 -0.058418352088337969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098640773797714687,
                                 0,
                                 0,
                                 0,
                                 -0.28591477165252099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44482828798853297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37991900791146588,
                                 -0.44685539685223641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32952453003230919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43620315364755113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40744952369871412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024583550633533999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.188321863649449,
                                 0,
                                 0,
                                 0.23911755770512488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10801743602294415,
                                 0,
                                 -0.44041575642395464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31224391290883358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71206273160278988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068890271054123625,
                                 0.11576160888283471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10148480838027427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26219932021650666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0024564288623771038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41315655406368523,
                                 0,
                                 -0.79676472244093799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21869428856847722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.98769208361770777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012002948093706778,
                                 0,
                                 0,
                                 0,
                                 -0.82118117264553814,
                                 0,
                                 0.53983731129252177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48782146458440984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067009676356425352,
                                 0,
                                 0,
                                 0,
                                 -0.67671929621743432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11792964903865261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14858263242841763,
                                 0.14039883497542432,
                                 0,
                                 -0.47303874456005401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14187751264087636,
                                 0,
                                 0,
                                 0,
                                 -0.33632167282727854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61096133035517697,
                                 0,
                                 0.24065062797906434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1092501534128534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21659972819092349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60864125168151717,
                                 0,
                                 0,
                                 0,
                                 0.456446963419541,
                                 0,
                                 0.27880540447364965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39766183858226545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56542220671010512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35369443722454846,
                                 0,
                                 -0.41584733242319855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17985848337986637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43793259463490647,
                                 0,
                                 0,
                                 0,
                                 -0.049627636713574744,
                                 0,
                                 0,
                                 -0.5553117566890734,
                                 -0.55931012289965787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28987462820176318,
                                 0,
                                 0,
                                 0,
                                 0.35646849250458756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29766349861731195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13203542993515996,
                                 0.52477952423583385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55570265643841144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5995279996317544,
                                 -0.10256047744231217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30074621873923191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1267041862702809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40233361387206101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2413270611690036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9493153962122729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054065224554848974,
                                 0,
                                 0,
                                 0,
                                 -0.16892371334658765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55513377626202021,
                                 0,
                                 0,
                                 -0.14556472122454614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11397411606988853,
                                 0,
                                 0,
                                 0.049880135322199148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76930491266604417,
                                 0,
                                 0,
                                 -0.17852438843233817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27682830762930477,
                                 -0.064488753505897473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65662016931137224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58986659313494316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31453958481551575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20292731188116558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25767863976107047,
                                 0.53918727950175571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12864962808347644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048908178994881445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032651062229879096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7892211145116611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082946107512998107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27351062567883805,
                                 0,
                                 0,
                                 0,
                                 0.15382628832527212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54730559276428181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36962917395766742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0911652569678361,
                                 0.12380786601227822,
                                 -0.25977302473844449,
                                 0,
                                 0,
                                 -0.15769288155498334,
                                 0,
                                 0,
                                 0,
                                 0.49071434150261756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34440034823152554,
                                 0,
                                 0,
                                 -0.36060392351888237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16158429425004983,
                                 0,
                                 0,
                                 -0.28003100591923624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44138944825054049,
                                 0,
                                 0,
                                 0.43166434550468435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12581024042019667,
                                 0,
                                 0,
                                 -0.54763933132145648,
                                 0,
                                 -0.14162296328613719,
                                 -0.48744765229047082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67048468587481236,
                                 -1.0063560968598546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19217387541214548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25021527234829782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36684267666812337,
                                 0.3308202005436458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74658835663506129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27937525608321589,
                                 0,
                                 0,
                                 0,
                                 0.38365916981232567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18720395392866063,
                                 0,
                                 -0.032691481873692113,
                                 0.15397071621399866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36005300979736121,
                                 0,
                                 0.086599237673044741,
                                 0,
                                 0.11085312160588201,
                                 0,
                                 0.090077112741137472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61400069615650388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0057364609708686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71026729146601053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35875934859548303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.002342449960388529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30774888560833807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23358535646499529,
                                 0,
                                 0,
                                 -0.64159715702944975,
                                 0,
                                 0.1641091353141142,
                                 0.3188915491372466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18552059417092293,
                                 0.39368680018402541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73220926224287985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28361584377312293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12165199851462746,
                                 -0.10832958717555863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16936704583242318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29755468479482156,
                                 0,
                                 0,
                                 0,
                                 -0.91202824883102029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90851601037263241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065321088993543386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80694793448892832,
                                 0.13881210237242247,
                                 -0.26589261078320769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33624046624179516,
                                 0,
                                 0,
                                 -0.074286846231014697,
                                 0,
                                 0.30162365051298479,
                                 0.024499459986489891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86297885842615585,
                                 -0.675167781213174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49378639168268551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065486435384338543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.94452987081755135,
                                 0.093442020480933419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24628259520808163,
                                 0,
                                 0,
                                 -0.31022819905776405,
                                 0,
                                 0.42703829679105249,
                                 -0.26679443628254484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061854662372777272,
                                 0.20344388251370701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70221047852938689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75352477965969467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31451311752986533,
                                 0.10372386066430886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37911154901053112,
                                 0.390594283551842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27026578090932368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2514870869653647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73328598977832693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1723741541456541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34132590490099862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072683119024753773,
                                 0,
                                 0,
                                 0,
                                 0.083552791677625665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38924805243480609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26682788701572735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8455342971791624,
                                 -0.25171263378044006,
                                 1.0277616873022786,
                                 0,
                                 -0.87605528784937325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014900141697098274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75335461391138914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47976208245187946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071386059934851753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74254020017289668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039331360965857438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37001837201207399,
                                 0,
                                 0,
                                 0,
                                 -0.22588914352294026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3060854067103248,
                                 0,
                                 0.18644717905185951,
                                 0.056774325175596836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36961822223561497,
                                 0,
                                 0.65471626488548129,
                                 0,
                                 -0.041306553500585583,
                                 0,
                                 0.33445798451181535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88154876346381283,
                                 0,
                                 0,
                                 -0.27341691321383532,
                                 0,
                                 0.13080021918702769,
                                 -0.19880285724415417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092111910311814274,
                                 0.022810950921808293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6532415576932149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34092646755274475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79983809737683198,
                                 -0.67088717128106445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98860909713500988,
                                 0,
                                 0,
                                 -0.13500609407119854,
                                 0,
                                 0.53650375416407881,
                                 -0.55124484787827188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22362939246778232,
                                 -0.20791742928684601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3805712995401147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18208547686607202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43605370390871595,
                                 -0.050543854232343186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078537979189268109,
                                 0,
                                 0,
                                 0,
                                 0.081794344887822126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53144957695832207,
                                 0,
                                 0,
                                 0.44807261066879023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21353062491957614,
                                 0,
                                 0,
                                 0.25619846379204642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39362947663712355,
                                 0,
                                 0,
                                 -0.48760292060543298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2149344837772118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25032406252921058,
                                 0,
                                 0,
                                 0,
                                 -0.14839115925959853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22577063579569925,
                                 0,
                                 0.34473466665665259,
                                 -0.26840726793782704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43096435737334093,
                                 0,
                                 0.19151909809158002,
                                 0,
                                 0.32065332501578331,
                                 0,
                                 -0.54957789828910042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30812559679301216,
                                 -0.67921186355842988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086977839980981339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098621304994668368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5411371922362227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36552577711362694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62284692805359576,
                                 0,
                                 0,
                                 0,
                                 0.4175338532683629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078792588949260736,
                                 0,
                                 0,
                                 -0.039848204603015358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42872069701258753,
                                 0,
                                 0,
                                 -0.33198379462912342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030032653407822234,
                                 0,
                                 0,
                                 -0.36744305394392152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91216895690307709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97442691884741151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40429686014883126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21810287523264424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048813096526366465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49456934894796667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28434086281211413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070607031823502697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3242942178811265,
                                 0,
                                 0,
                                 0.30578749752546341,
                                 0,
                                 -0.045156345687357512,
                                 -0.12705035727212421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55666592274343951,
                                 -0.29703361962376718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21493581240233456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1748219024097266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93049472165131153,
                                 0.18886923343954409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34454502886857702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052480487762439618,
                                 0,
                                 0,
                                 0,
                                 -0.022958295190316242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18475498944544799,
                                 0,
                                 -0.29014142928400105,
                                 0.76761359805269924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38781189681597927,
                                 0,
                                 -0.079432373944266083,
                                 0,
                                 -0.03934600698319024,
                                 0,
                                 -0.11047474613145726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45851292949975492,
                                 0,
                                 0,
                                 0,
                                 -0.1861639839866461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13944864762978257,
                                 0,
                                 0,
                                 0.35007523017599745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66562580060855081,
                                 0,
                                 0,
                                 -0.38037133032470044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11081195932183564,
                                 0,
                                 0,
                                 0.11441558784413583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058414240130887266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027986655080580222,
                                 0,
                                 0,
                                 0,
                                 -0.084862534291647557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30059368940062353,
                                 0,
                                 0.063841479247531668,
                                 -0.33822553089602303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4480696109885548,
                                 0,
                                 -0.29805188435495,
                                 0,
                                 -0.66407068541435921,
                                 0,
                                 0.22177214961616382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21317681967990471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13233133237246045,
                                 0,
                                 0,
                                 0,
                                 -0.75731746581324266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087349159943261756,
                                 0,
                                 -0.17031304862808389,
                                 -0.010047395888910932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080214106866052459,
                                 0,
                                 -0.28492086871787875,
                                 0,
                                 0.3839076976512229,
                                 0,
                                 0.30294823463891091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066301478156360713,
                                 0,
                                 0,
                                 0,
                                 -0.6253037930291846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41041013013952726,
                                 0,
                                 0,
                                 -0.52947383101223355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05885922701581256,
                                 0,
                                 0,
                                 -0.28714469740974358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020167150293448333,
                                 0,
                                 0,
                                 -0.2636229655460437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17586186690391564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42632243132870562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66007108717356622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58930945328278428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0336342229569655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0341160213503576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091766179481739846,
                                 0,
                                 0,
                                 -0.11903221910856125,
                                 0,
                                 -0.30302679995928561,
                                 -1.046591555494871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035646552321376784,
                                 0.058297611511861414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34356248269907047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45247945074450152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42985622035022292,
                                 -0.22851724631100589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33209611072413942,
                                 -0.099186917072166356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5266855794260632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73595415413585497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12750594872953414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2111637876081264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42826878625824594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082256038410948903,
                                 0,
                                 0,
                                 0,
                                 -0.37760085148980471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24109520765588288,
                                 0,
                                 0.23771469112228383,
                                 0.26626408408680086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10299856353746054,
                                 0,
                                 -0.098496570821902982,
                                 0,
                                 -0.41318459957813736,
                                 0,
                                 -0.53914178091520704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29777396965666519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14139311161900989,
                                 0,
                                 0,
                                 0,
                                 -0.88810377121056783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29578047697084248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3248433959065648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.283210033010313,
                                 -0.72146427024420112,
                                 0.044085576059374937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13935343822184437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78517481046685711,
                                 0,
                                 0,
                                 0,
                                 -0.15526366119814139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18369327701465016,
                                 0,
                                 -0.21769434788459707,
                                 0.032798364602335255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10144775294279121,
                                 0,
                                 0.36587127521122892,
                                 0,
                                 -0.32657408186380921,
                                 0,
                                 0.083429505491424569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46495999711852859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15231459208506179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15655935839653679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73954116425766647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92734972271019955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29714926368748829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13801398186249747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25778544143884019,
                                 0,
                                 0,
                                 0,
                                 -0.061380096204602053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031037173792636895,
                                 0,
                                 -0.7838268760435535,
                                 -0.33403607557375031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084048072822600392,
                                 0,
                                 0.22204914681269833,
                                 0,
                                 -0.045788443995733341,
                                 0,
                                 -0.35402941895218309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71275032792392745,
                                 -0.28528509220528558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44078655820457852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18725639810639647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2306581607735565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35782460864604687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073571648283130481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10773033802250781,
                                 0,
                                 0,
                                 0,
                                 -0.16746521816837126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77158262690236135,
                                 0,
                                 0.098887476278372285,
                                 0.11724650211506031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40305179176397687,
                                 0,
                                 0.39745956055618836,
                                 0,
                                 -0.11745198822961692,
                                 0,
                                 0.043031889582588308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16019104684770316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71618127056765868,
                                 0,
                                 0,
                                 0,
                                 0.14028271839431977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69647500090534353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23703316717098133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38056396542504178,
                                 -0.60139471804587474,
                                 -0.66912060980995691,
                                 0,
                                 0,
                                 0.54830079939624765,
                                 0,
                                 0,
                                 0,
                                 -0.33424477789752011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068752304698504713,
                                 0,
                                 0,
                                 0.45933204974392328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23148788689789868,
                                 0,
                                 0,
                                 -0.26100569794828132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18377979572165731,
                                 0,
                                 0,
                                 0.46523996071806406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066104095156299114,
                                 0,
                                 0,
                                 0.38256198895178645,
                                 0,
                                 0.31728833199705531,
                                 -0.013042682346646295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81953691272615936,
                                 -0.78793449205942223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14306260289848666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39040145027945389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42504793653588291,
                                 -0.97937485777241062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52914023623631279,
                                 0,
                                 0,
                                 0.62226300406019419,
                                 0,
                                 0.61363630202058062,
                                 -0.22886815478443129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048288217599301915,
                                 0.20764421300824842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43151821152929271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022661202267346275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1000991356897995,
                                 0.6519916788485598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25067835466400967,
                                 0,
                                 0,
                                 0,
                                 -0.1107156112292645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30324690603581061,
                                 0,
                                 0,
                                 -0.18038193369757563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48103523371076462,
                                 0,
                                 0,
                                 0.66931705083118742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10506266500258872,
                                 0,
                                 0,
                                 0.33164395626384108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1275547034130025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029558480519807171,
                                 0,
                                 0,
                                 0,
                                 -0.075526813065562359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44094539727872284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23166678719744371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3979310478785254,
                                 0.070897421694112464,
                                 -0.0039745944017426926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0085235622467912785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79440749571471514,
                                 0,
                                 0,
                                 0,
                                 0.29816100891525765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085504314025248385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33239211777559396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44832867096154894,
                                 -0.8250222554758293,
                                 -0.25973944631566681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11017892829216044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28291175774104638,
                                 0,
                                 0,
                                 0,
                                 -0.17042328009305241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40308766072238661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3685912470610093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14837334483498665,
                                 -0.087876421315920744,
                                 -0.17303877349093902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17074692901736965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17762912127801911};

const double rot_28_20[4000] = {0.53265435184158183,
                                0.49451971575321618,
                                0.52864808449706147,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32702470239410164,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.031348123257433802,
                                0,
                                0,
                                -0.29040133289201048,
                                0,
                                0,
                                0.68277907723922227,
                                -0.16520119966180771,
                                -0.44302860643233721,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37696987603323051,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34423466576694728,
                                0,
                                0,
                                -0.22280744297506094,
                                0,
                                0,
                                0.18299099276860303,
                                -0.023821597363384461,
                                0.38443006544726821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22174140394594646,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3869025012527153,
                                0,
                                0,
                                0.78695460932972483,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2465765628018694,
                                0,
                                0.10075223980063627,
                                0,
                                0.28021031804147095,
                                0,
                                0,
                                0,
                                -0.85486893095509209,
                                0,
                                -1.0339748240121551,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0805344407551172,
                                0,
                                0,
                                0,
                                0,
                                -0.13425408496928254,
                                0,
                                -0.054857858691506778,
                                0,
                                0,
                                0.21964889353697178,
                                0.42763733086510775,
                                0,
                                0.1361760629496768,
                                0,
                                0,
                                -0.35621365171464098,
                                0.15301660324046548,
                                0,
                                0.76092113006000317,
                                0,
                                0,
                                0,
                                0,
                                0.279199888269828,
                                0,
                                -0.32909848199440767,
                                0,
                                -1.128678430523002,
                                0,
                                0,
                                0,
                                0.16482972929820938,
                                0,
                                -0.023196148444507441,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.089755048352370942,
                                0,
                                0,
                                0,
                                0,
                                -0.31800720762911444,
                                0,
                                0.16752476407963388,
                                0,
                                0,
                                0.6136282722266726,
                                0.065429583397018432,
                                0,
                                -0.62751135119418433,
                                0,
                                0,
                                0.30923738597766842,
                                -0.023924325688750761,
                                0,
                                0.0039436446446711459,
                                0,
                                0,
                                0,
                                0,
                                0.15176400695517606,
                                0,
                                0.048629667185489583,
                                0,
                                -0.67731201883474734,
                                0,
                                0,
                                0,
                                -1.4375608673487215,
                                0,
                                -0.42722425185121765,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65167235245794108,
                                -0.41838285959827748,
                                0.29383145098292396,
                                0.26438029209288738,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58005568087971227,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42120868786653393,
                                0,
                                0,
                                -0.39349786620189431,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68992110738866919,
                                0,
                                -0.308054334005677,
                                0,
                                0,
                                -0.30944074944360567,
                                -0.24665088009044128,
                                0,
                                -0.24874540436801196,
                                0,
                                0,
                                -0.35905572808477471,
                                0.27002785617289593,
                                0,
                                -0.093865987664750461,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.054419655228432874,
                                0,
                                -0.22257357821075868,
                                0,
                                0,
                                0.054081130868710164,
                                0.26740086317989731,
                                0,
                                -0.12192851713592832,
                                0,
                                0,
                                -0.40673435058193808,
                                -0.80855070260804296,
                                0,
                                -0.19752943866586009,
                                0,
                                0,
                                0,
                                0,
                                -0.63272638348232568,
                                0,
                                0.51224433125707325,
                                0,
                                -0.4975333158586272,
                                0,
                                0,
                                0,
                                0.64198817725813695,
                                0,
                                -0.62258014608089129,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57842333769538656,
                                0,
                                0,
                                0,
                                0,
                                -0.25303597955033375,
                                0,
                                -0.015780048568319105,
                                0,
                                0,
                                -0.12617050421748088,
                                0.77832294108207967,
                                0,
                                0.18327704762814703,
                                0,
                                0,
                                0.22904120694558688,
                                0.22973758866869545,
                                0,
                                -0.41855522462077149,
                                0,
                                0,
                                0,
                                0,
                                0.91183461019316414,
                                0,
                                -0.6766163803539309,
                                0,
                                0.057273712207126223,
                                0,
                                0,
                                0,
                                0.3150342564156644,
                                0,
                                -0.78963500699208344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64703347638046127,
                                -0.1871332432318393,
                                0.41947014348914646,
                                -0.4600529656295711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47254651355507149,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58101515386943126,
                                0,
                                0,
                                0.12844609887105432,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21848618954279031,
                                0,
                                -0.87317602099283487,
                                0,
                                0,
                                0.0083811784956406288,
                                0.04411898615437905,
                                0,
                                -0.14399249422090488,
                                0,
                                0,
                                0.38046478475818363,
                                0.035689565203080129,
                                0,
                                0.14508499699312083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11820402812374865,
                                0,
                                0.23882739559820892,
                                0,
                                0,
                                -0.65311722422378049,
                                0.12738241987807586,
                                0,
                                -0.3027493570243085,
                                0,
                                0,
                                0.37531790184130737,
                                -0.30112426633258466,
                                0,
                                0.40373799546214462,
                                0,
                                -0.080890677992231458,
                                -0.68212845051000404,
                                0.30809854168550382,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37684812056018169,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46457601834014384,
                                0,
                                0,
                                -0.27456762562895448,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5255083339365797,
                                0,
                                -0.069034048734684758,
                                0,
                                0,
                                0.1843502430011594,
                                -0.23779410871670567,
                                0,
                                0.60412188899171959,
                                0,
                                0,
                                0.38085872875553112,
                                -0.32344294008336277,
                                0,
                                0.11795031719145549,
                                0,
                                0,
                                0,
                                0,
                                -0.87219211295957888,
                                0,
                                -1.2014533930682592,
                                0,
                                0.1087582439826352,
                                0,
                                0,
                                0,
                                -0.19105472809470075,
                                0,
                                -0.14602012865211864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74020531822771329,
                                0.14179202324665346,
                                0.35669057175593477,
                                0,
                                0,
                                0,
                                0,
                                0.19254793267079748,
                                -0.31118956812990961,
                                0.16602643899579186,
                                0,
                                0,
                                -0.83137742694262562,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26008137151810484,
                                -0.48935972532039251,
                                0,
                                0,
                                0,
                                0,
                                0.82607462937653553,
                                0.076627941118211751,
                                -0.065979450894554315,
                                0,
                                0,
                                -0.016134336790694953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15165739858870594,
                                0.58279552793450373,
                                0.079376549029688548,
                                -0.17165795674230666,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13662065363881154,
                                0.27827279661695647,
                                -0.71047510939344904,
                                0,
                                0.026579729469874497,
                                0,
                                0,
                                0,
                                0.48206482714749843,
                                0.15672364586427812,
                                -0.041555720078167407,
                                0.019748676471317977,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66178613631095606,
                                -0.46551452389306769,
                                -0.29224433104091063,
                                0,
                                0.029375193043702036,
                                0,
                                0,
                                0,
                                0.076610535029904822,
                                -0.68559411969996176,
                                -0.021123551029182341,
                                -0.28793773792418176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.034302206117028222,
                                0.10063132727896165,
                                -0.4476142158150293,
                                0,
                                0.47861821115808406,
                                0,
                                0,
                                0,
                                0.42656954092256455,
                                0.24025736395973729,
                                0.56169764404222666,
                                -0.14061530891325896,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.013605173629343048,
                                0.30400354461624551,
                                0.33671727445481242,
                                0,
                                0.46803433484293405,
                                0,
                                0.59381662490027176,
                                -0.033551027301316566,
                                0,
                                0,
                                0,
                                0,
                                -0.20943419079083236,
                                0.51695949682995035,
                                0.57754934792450574,
                                0,
                                0,
                                -0.03978810923086662,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13377483185244621,
                                0.23979289174979598,
                                0,
                                0,
                                0,
                                0,
                                -0.017546768771479461,
                                0.61431733130465593,
                                -0.69689511873615484,
                                0,
                                0,
                                -0.24748168472686011,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58453715232864789,
                                0.52721910320855336,
                                0,
                                0,
                                0,
                                0,
                                0.15508515254997818,
                                -0.34374956587952249,
                                -0.17506796157395163,
                                0,
                                0,
                                0.45551330936209899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64239145636531125,
                                0.21523537497610656,
                                0,
                                -0.38275981034132728,
                                1.3361961175504218,
                                0,
                                0,
                                0,
                                0.084231872700155766,
                                0,
                                0.097923922461479351,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20706694732252373,
                                0.68837279933908013,
                                0,
                                1.2161541016606208,
                                0.4069368241891268,
                                0,
                                0,
                                0,
                                0.066719637891252015,
                                0,
                                0.73783092552420593,
                                -0.44727522872980241,
                                0.54471332836643671,
                                0,
                                0,
                                0,
                                0,
                                0.46076461063827318,
                                0.36673224889665146,
                                0.34381257486902583,
                                0,
                                0,
                                0.19552136514754426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.92814869917388887,
                                -0.36916947895008323,
                                0,
                                -0.21896650633950765,
                                -0.033295720909581855,
                                0,
                                0,
                                0,
                                1.2084641818145847,
                                0,
                                0.31248710111654093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71826874280227093,
                                0.10107210884238241,
                                0,
                                -0.44082384428816762,
                                -0.86238897622678612,
                                0,
                                0,
                                0,
                                0.075287226779737954,
                                0,
                                1.1217750233454582,
                                0,
                                0,
                                -0.22131320393632969,
                                0.25578584072375149,
                                -0.18328099343719298,
                                0.19853998326090705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29458341792111686,
                                -0.53363008687303881,
                                0.060993242025690564,
                                0,
                                0.66130430713635624,
                                0,
                                0,
                                0,
                                -0.090123134026450585,
                                0.057947549131178916,
                                0.14945639389998933,
                                -0.83647190980449404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15038813419563354,
                                -0.43456035819022021,
                                0.1371627974499095,
                                0,
                                -0.19032735975637519,
                                0,
                                0,
                                0,
                                -0.067866731297120092,
                                -0.19743806293052263,
                                0.74349295267070192,
                                0.35394511164260167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21854468499627455,
                                -0.35250191072010739,
                                -0.25362851206661913,
                                0,
                                -0.20495513369520574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49731136995739478,
                                1.0740040970739548,
                                0,
                                -0.76698704604769019,
                                -0.2680052789423189,
                                0,
                                0,
                                0,
                                -0.2447817351969914,
                                0,
                                -0.45147000023782013,
                                0,
                                0,
                                0.70361579133774033,
                                0.016064559865753267,
                                -0.25944388788009526,
                                0.055517625508562568,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62036634687165981,
                                -0.073853151256770694,
                                -0.096021508427121455,
                                0,
                                -0.1863990022343818,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.9794087377199584,
                                -0.3801298656948392,
                                0,
                                0.022005190386085616,
                                -0.29491182055051957,
                                0,
                                0,
                                0,
                                -1.2622365452466464,
                                0,
                                0.28031914203834263,
                                -0.4444804387176734,
                                0,
                                -0.11762665825542291,
                                0,
                                0,
                                0,
                                0,
                                -0.19768968690015815,
                                0,
                                0,
                                0,
                                -0.57260329836313351,
                                -0.23625725799413788,
                                0.48312166720382155,
                                -0.32918866727756679,
                                0,
                                0,
                                0,
                                0.15510042979081243,
                                0,
                                0,
                                0.21214036173495576,
                                0,
                                0.40741379216039597,
                                0,
                                0.3584862323253562,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.95084512900239915,
                                0.74691579681959863,
                                0,
                                0.14409872541893573,
                                0.49641787694917527,
                                0,
                                -0.058131725464634021,
                                0,
                                0,
                                0,
                                0,
                                -0.29789142917656336,
                                0,
                                0,
                                0,
                                -0.66781245917552079,
                                0.10318672186361742,
                                -0.43397293867609288,
                                0.037871333228538973,
                                0,
                                0,
                                0,
                                0.12273125429260268,
                                0,
                                0,
                                0.39507363672279061,
                                0,
                                1.1617879861226363,
                                0,
                                0.22297878040520658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59068352338133212,
                                -0.55827663535279448,
                                0,
                                -0.8402306815808086,
                                0,
                                0,
                                0,
                                0,
                                -0.086098666201275903,
                                0,
                                0.26692309206392989,
                                0,
                                0.39949972276393853,
                                -0.43226898069263087,
                                0.59932387523138009,
                                0,
                                0,
                                0,
                                0,
                                -0.46442811609712331,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0374258022202472,
                                0,
                                0.53830314068974461,
                                0,
                                -0.47827157414487093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47326295136818974,
                                0.069940269360015461,
                                0,
                                -0.56930579760448963,
                                0,
                                0,
                                0,
                                0,
                                0.042247828214576587,
                                0,
                                0.47607798584768579,
                                0,
                                0.056382456666525117,
                                0.82784786887131967,
                                0.17777700084742368,
                                0,
                                0,
                                0,
                                0,
                                -0.2268240175940793,
                                0,
                                0,
                                0,
                                0,
                                0.39964029567781917,
                                0,
                                -0.75588582300876817,
                                0,
                                0,
                                0,
                                0,
                                -0.14319784939304134,
                                0,
                                0,
                                0,
                                0.2588041927477005,
                                0.036759071791913782,
                                0.22170562424262502,
                                -0.35834854525856241,
                                0,
                                0,
                                0,
                                -0.050206865283329433,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49881344690996815,
                                0,
                                -0.40818299676245801,
                                0,
                                -0.54241360154944718,
                                0.074201035765282697,
                                0.46355526032262662,
                                0,
                                0,
                                0,
                                0,
                                -0.2645184267845162,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65902396496701121,
                                0,
                                0.47963675670102757,
                                0,
                                0.058034622424207122,
                                -0.19260594284547342,
                                0.1149357904047108,
                                0,
                                0,
                                0,
                                0,
                                0.53099971062629447,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.023272779148354898,
                                0,
                                0.50737759499701807,
                                0,
                                -0.53857205052883728,
                                -0.28855400337027481,
                                -0.41513816155241157,
                                0,
                                0,
                                0,
                                0,
                                -0.44312909427929548,
                                0,
                                0,
                                0,
                                0,
                                0.0076623597103506469,
                                0,
                                0.27372527567716409,
                                0,
                                0,
                                0,
                                0,
                                -0.41451886484849126,
                                0,
                                0,
                                0,
                                -0.025433523139734723,
                                0.28272858753625274,
                                0.12323529517254844,
                                -0.20646258371795539,
                                0,
                                0,
                                0,
                                -0.7840878889656101,
                                0,
                                -0.49620716194989745,
                                0,
                                -0.11529853540587355,
                                0,
                                0,
                                0,
                                0,
                                -0.38264050874241345,
                                0,
                                0,
                                0,
                                0.22701568020774204,
                                0.33181793651616615,
                                -0.51043683806873841,
                                -0.31314973987536521,
                                0,
                                0,
                                0,
                                0.27170416621130683,
                                0,
                                0.27083916606511332,
                                0,
                                0.36050231985470416,
                                0,
                                0,
                                0,
                                0,
                                -0.42231386813750332,
                                0,
                                0,
                                0,
                                0.20181398983625265,
                                0.31067784316086822,
                                0.46610619463960778,
                                0.10595594627776739,
                                0,
                                0,
                                0,
                                0.50259721878012886,
                                0,
                                0.11037165197157939,
                                0,
                                0.17756250353669978,
                                0,
                                0,
                                0,
                                0,
                                0.5905276633737403,
                                0,
                                0,
                                0,
                                -0.16562106781963234,
                                0.53675827489181327,
                                0.061376863766378312,
                                -0.52780084376899472,
                                0,
                                0,
                                0,
                                0.098417989766024824,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55419588343940374,
                                0,
                                -0.21910046367961286,
                                0,
                                0.49958042789443302,
                                0.04410417834084554,
                                -0.45691664675462079,
                                0,
                                0,
                                0,
                                0,
                                -0.42960831583013537,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23392377918826862,
                                0,
                                0.43927586529532281,
                                0,
                                -0.50055106192855192,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.86591468979920849,
                                0.82199174159124455,
                                0,
                                -0.12542269853093757,
                                0,
                                0.52729886959476069,
                                0,
                                0.074569175902320428,
                                0,
                                -1.0934172778023532,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.89825669856193691,
                                -0.47898021000507451,
                                0,
                                0.76572124514601803,
                                0.25392528498099587,
                                0,
                                0.40213387104594894,
                                0,
                                0,
                                0,
                                0,
                                -0.079763947801156268,
                                0,
                                0,
                                0,
                                0.19705370874710382,
                                -0.59792559237510046,
                                -0.17986870665331167,
                                -0.57558400974332291,
                                0,
                                0,
                                0,
                                0.08633151210685476,
                                0,
                                0,
                                0.035856391237506488,
                                0,
                                -0.64445322644226577,
                                0,
                                0.23144450321686186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35640097314226504,
                                0.46789135376705138,
                                0,
                                -1.2141857607349511,
                                0.34737787263784092,
                                0,
                                0,
                                -0.05384576354911897,
                                0,
                                -0.11510325089003315,
                                -0.4611744146247832,
                                0.66144563248618826,
                                0,
                                0.19568489172631803,
                                0,
                                0.28123321582819927,
                                0,
                                0,
                                0.30919835867835832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0024807234727496769,
                                0.29020166818589355,
                                0,
                                0.85032513493804485,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.058299874155670589,
                                0,
                                -0.38609746747024298,
                                0.2006336785593798,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.064242397562068093,
                                0.46882083202480646,
                                0,
                                0.039178889814883648,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32877033982128245,
                                0,
                                -0.034410126181729887,
                                -0.81564144283985174,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56870397339921586,
                                0,
                                0,
                                -0.24678241004129753,
                                0,
                                0.23148783761383229,
                                -0.64375594445696815,
                                0.070444882556790753,
                                0,
                                0.10013477300956221,
                                0,
                                -0.23616020438374236,
                                0,
                                0,
                                -0.27731714943121244,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76915502271498315,
                                -0.068359875048644075,
                                0,
                                -0.18100288049502058,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41030846573404162,
                                0,
                                -0.40564780381306464,
                                0.19509550988366417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38533720986367986,
                                0,
                                0,
                                -0.3228471995310685,
                                0,
                                0.21737503583581261,
                                0.40397124608625962,
                                0.386742098302085,
                                0,
                                -0.22068940941588056,
                                0,
                                0.56452710982059673,
                                0,
                                0,
                                -0.1409827040118348,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34971107921995076,
                                0,
                                0,
                                -0.12603310203353549,
                                0,
                                0.25804497218656153,
                                0.2570803389663317,
                                0.48291551893063189,
                                0,
                                -0.071771355602333053,
                                0,
                                -0.57538954477151405,
                                0,
                                0,
                                -0.39963565377404148,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31921833347262674,
                                0,
                                0,
                                0.68779145960025545,
                                0,
                                -0.21780430975649026,
                                0.1548598880074637,
                                0.29693838688866181,
                                0,
                                0.41699129427277171,
                                0,
                                0.032966261167587413,
                                0,
                                0,
                                -0.30080116677139562,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0074469787230549,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.199375140964849,
                                0.27053852276144402,
                                0.094256919777782944,
                                0.26774678632186366,
                                -0.12428404417647165,
                                -0.09675497818804224,
                                0,
                                0,
                                -0.57384466530026801,
                                0,
                                -0.62142672342131289,
                                0.22168180949243227,
                                -0.003230884556866459,
                                0,
                                0.45117811221936882,
                                0,
                                -0.14470121972803529,
                                0,
                                0,
                                -0.038938496486552024,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.07833294682389691,
                                0.37780749818775394,
                                0,
                                -0.43298622658468144,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56047589384134144,
                                0,
                                -0.59109959737621598,
                                -0.010789334890499692,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24465452483699374,
                                0,
                                0,
                                -0.11317304189557832,
                                0,
                                0.54812250418335307,
                                0.070254128963863252,
                                -0.2444662308973283,
                                0,
                                0.69569505619457517,
                                0,
                                0.24821402145120858,
                                0,
                                0,
                                -0.12882761399826453,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59676887656098832,
                                0.16215427814480582,
                                0,
                                -0.20689291912080734,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6372000282117114,
                                0,
                                -0.27547222436798735,
                                0.30472839663197027,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20493454762158256,
                                0.72269248724300028,
                                0,
                                -0.11121323816706466,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0010235936459060679,
                                0,
                                0.50981454243115509,
                                0.40427354639132507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33764492185492812,
                                0,
                                0,
                                -0.030356046914052803,
                                0,
                                -0.29202284032786585,
                                -0.25603383119088013,
                                -0.16371854657050683,
                                0,
                                -0.19076285752831479,
                                0,
                                0.36295568932647948,
                                0,
                                0,
                                -0.73437912038395403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49677819728041889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23642337817493084,
                                -0.038407963859052818,
                                -0.17503983474841261,
                                1.2162545999731325,
                                1.0544076261339637,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42744421438523417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.062463445631261882,
                                0.53781972643863563,
                                0.42778742860190805,
                                -0.67385516223757014,
                                0.90532385702799323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49407796859800557,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.069818367264823489,
                                1.1978836148412584,
                                -0.3019447112570201,
                                0.46630242262807164,
                                -0.71480877089266959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31688920955239608,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18741539108341232,
                                0.54288146324090492,
                                1.6418036595237149,
                                -0.21162543795553765,
                                0.043136796332100935,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90579374577575988,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0921800270792437,
                                0.34303554110351248,
                                0.21108306207930083,
                                0.79400201916086988,
                                -0.15492471915230077,
                                -0.63002786650128595,
                                0,
                                0,
                                0,
                                0,
                                -0.56379034024147667,
                                0,
                                0,
                                0,
                                0.044120887668726072,
                                0,
                                0,
                                0.49125828149749923,
                                0.24806204082597805,
                                0,
                                0,
                                0,
                                0,
                                1.5263327420268671,
                                0,
                                0,
                                -0.013964774004154135,
                                0,
                                0,
                                0,
                                0,
                                -0.28461300937763323,
                                -0.44218759064667235,
                                -0.72131064173787152,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068980792387280318,
                                0,
                                0,
                                0.44522259944373366,
                                0,
                                0,
                                0,
                                0,
                                -0.11765549253712322,
                                -0.14471550491040505,
                                -0.68762958126911422,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0094151355345337973,
                                -0.57192631977332387,
                                0,
                                0,
                                0,
                                -0.29868464776415077,
                                0.13263354300317051,
                                0,
                                0,
                                -0.2416353267050893,
                                0,
                                0,
                                -0.57971275155403956,
                                -0.047267990118932735,
                                0.34814897914551557,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48947902961309514,
                                -0.24405718429743967,
                                0,
                                0,
                                0,
                                0.14957287407185227,
                                -0.20659654855577014,
                                0,
                                0,
                                -0.41986109958443768,
                                0,
                                0,
                                -0.1761321645263057,
                                0.29196852001344992,
                                -0.43749699531515018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59556721793701173,
                                0.2500323211518794,
                                0,
                                0,
                                0,
                                0.26907188755529982,
                                0.27291023084445065,
                                0,
                                0,
                                0.35809506497112942,
                                -0.64632717583995292,
                                0,
                                0,
                                0,
                                0,
                                -0.99235674871644652,
                                0,
                                0,
                                0,
                                -1.1802471402321315,
                                0,
                                0,
                                0.076743987357899945,
                                -0.45516727394584233,
                                0,
                                0,
                                0,
                                0,
                                -0.3134459051112421,
                                0,
                                0,
                                -0.70159568926448868,
                                0,
                                0,
                                0,
                                0,
                                0.13335832913372822,
                                0.42555721195923929,
                                -0.47102104215667606,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.06620850416445366,
                                0,
                                0,
                                -0.28746428652542144,
                                0,
                                0,
                                0,
                                -0.34093716961692005,
                                0,
                                0,
                                0,
                                0,
                                -0.34118010168670831,
                                0.15923640302640063,
                                0.37620900683190661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63784111298110047,
                                0,
                                0,
                                0.44003096516886758,
                                0,
                                0,
                                0,
                                0.46085059285250363,
                                0,
                                0,
                                0,
                                0,
                                0.36564690743353667,
                                0.089046750140361203,
                                -0.27009878953021615,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7262671918282394,
                                0,
                                0,
                                -0.21347682874135082,
                                0,
                                0,
                                0.76527372513759739,
                                0,
                                0,
                                0,
                                0,
                                -0.31723347803090812,
                                0,
                                0,
                                0,
                                0.31652636799450962,
                                0,
                                0,
                                1.3795973310011318,
                                0.50238413694656536,
                                0,
                                0,
                                0,
                                0,
                                -0.50553036326205159,
                                0,
                                0,
                                0,
                                -0.12638024219067748,
                                0.45557207068801137,
                                -0.27817853182115809,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.08347568428998578,
                                0.48776417843071035,
                                0,
                                0,
                                0,
                                -0.3342676687094937,
                                -0.4319579084298269,
                                0,
                                0,
                                -0.39483443947972591,
                                0,
                                0,
                                -0.01513273496312862,
                                0.21296397390076865,
                                0.23872841337990056,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.013141037849136561,
                                0.15051995112333466,
                                0,
                                0,
                                0,
                                -0.25534745086088134,
                                0.80766350794170005,
                                0,
                                0,
                                -0.39632623621743501,
                                -0.0016102934803846891,
                                0,
                                0,
                                0,
                                0,
                                0.54969311493355355,
                                0,
                                0,
                                0,
                                -0.25495765612462407,
                                0,
                                0,
                                1.1183189782305034,
                                -0.47079333455265887,
                                0,
                                0,
                                0,
                                0,
                                0.50808334769245955,
                                0,
                                1.0055215816483452,
                                0,
                                0,
                                0,
                                0,
                                0.17509244440069255,
                                0,
                                0,
                                0,
                                -0.30896114542741104,
                                0,
                                0,
                                -0.51163020658791913,
                                -0.12348812634526535,
                                0,
                                0,
                                0,
                                0,
                                0.8698729470631712,
                                0,
                                0,
                                -0.28425105853200394,
                                0,
                                0,
                                0,
                                0,
                                -0.18005456537362005,
                                -0.67867865115332504,
                                0.15195368945610738,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23769922219081668,
                                0,
                                0,
                                -0.58871566457060887,
                                0,
                                0,
                                0,
                                0,
                                -0.68493745971474951,
                                0.28650268732727546,
                                0.081347310207202442,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47714404771555718,
                                -0.13090526626786764,
                                0,
                                0,
                                0,
                                -0.098394155438531375,
                                0.081854907023549681,
                                0,
                                0,
                                0.42541184153766337,
                                0,
                                0,
                                0.36454291324379262,
                                0.73460539091056754,
                                0.16987494689105481,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10542358603785867,
                                -0.52260152282700001,
                                0,
                                0,
                                0,
                                0.023001418287548765,
                                -0.10934988864243031,
                                0,
                                0,
                                0.04350791794709364,
                                0,
                                -0.31328642973648441,
                                0,
                                0,
                                0,
                                0,
                                0.78656838337751878,
                                -0.35983458246384142,
                                0.14238553049688202,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0072003258789802892,
                                0,
                                0,
                                0.36517855973382762,
                                0,
                                0,
                                -0.66983365758721869,
                                0,
                                0,
                                0,
                                0,
                                0.90965319940321021,
                                0,
                                0,
                                0,
                                -0.42344094785130715,
                                0,
                                0,
                                -0.12765243733013035,
                                1.2575793445994392,
                                0,
                                0,
                                0,
                                0,
                                0.032730235675512587,
                                0,
                                0,
                                0,
                                -0.028912744255185561,
                                0.13018873645062548,
                                -0.21143507985565674,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3996246641584521,
                                -0.0012345357967490991,
                                0,
                                0,
                                0,
                                0.7930120338216744,
                                0.087639115867225698,
                                0,
                                0,
                                -0.37584578809544922,
                                0.35368846182177888,
                                0,
                                0,
                                0,
                                -0.065935893013727612,
                                -0.037748530551948073,
                                -0.39955747390198554,
                                0,
                                0.29258343043149421,
                                0,
                                -0.74014279564405128,
                                0.27002386153320318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.05618270172128189,
                                0,
                                0,
                                0.45980312591964512,
                                0,
                                0.13068269341874009,
                                0,
                                0,
                                0,
                                0.019034596063939174,
                                0,
                                0.87547206624626095,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.066665092132246279,
                                0,
                                0,
                                -0.015659818055509839,
                                0,
                                0,
                                -0.081949604807861176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1521431439413975,
                                -0.11200800403636382,
                                -0.61949978043907394,
                                -0.32817913628220841,
                                0,
                                1.3920803153120163,
                                0,
                                0,
                                0,
                                -0.32708706149749334,
                                0,
                                0.074948202913030781,
                                0,
                                0,
                                0,
                                0.10653752261709033,
                                0,
                                0.18150564314127682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.090310812353264797,
                                0,
                                0,
                                0.9137539253188568,
                                0.090079407835531755,
                                0,
                                0,
                                0,
                                -0.4267783654011007,
                                -0.51828053391696938,
                                -0.022047189941666545,
                                0,
                                -0.36828672169664994,
                                0,
                                -0.094643545103028331,
                                -0.057246581272634461,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62671800326210669,
                                0,
                                0.52725141261537045,
                                0,
                                0,
                                0,
                                -0.39616898912038656,
                                0.15949891112560877,
                                0.11906797197142208,
                                0,
                                -0.29134357313731202,
                                0,
                                0.30851655084911489,
                                0.51269754506474463,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28725717203077411,
                                0,
                                0.56092871988237247,
                                0,
                                0,
                                0,
                                0.26449665483635898,
                                0.46176460778080947,
                                0.30205107671070686,
                                0,
                                0.053632813179260913,
                                0,
                                -0.049455234784375898,
                                -0.24968786652308222,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49322688011146454,
                                0,
                                0,
                                0.54323916634323199,
                                0,
                                -0.20982557676302305,
                                0,
                                0,
                                0,
                                -0.31495851079608195,
                                0,
                                -0.28556637476747926,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58995072585327391,
                                0,
                                0,
                                0.36342201175939171,
                                0.034073121679915441,
                                0,
                                0,
                                0,
                                -0.34359087765821378,
                                -0.058308344055098424,
                                -0.085739154800842085,
                                0,
                                0.79318136231358016,
                                0,
                                0.41817613115086855,
                                0.074405246956421395,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24594547069635728,
                                0,
                                0,
                                -0.15485902005061686,
                                0,
                                -0.03797491676999265,
                                0,
                                0,
                                0,
                                -0.93001443765540281,
                                0,
                                0.13040175162664022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30437657899159931,
                                0,
                                0,
                                0.00012919696411589632,
                                -0.1703357016583141,
                                0,
                                0,
                                0,
                                -0.56488392612526306,
                                0.57658959908728924,
                                -0.34943991947812697,
                                0,
                                -0.14434814220266456,
                                0,
                                -0.076930514494504249,
                                -0.41193415937949529,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.029725977930382362,
                                0,
                                0.44198075868717634,
                                0,
                                0,
                                0,
                                -0.10077150208589142,
                                -0.39178976591982412,
                                0.057813142057879546,
                                0,
                                0.093330451079476462,
                                0,
                                0.042994895814195508,
                                -0.65011303024953937,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45216196984989315,
                                0,
                                0,
                                0,
                                0.5914778635947826,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47314278839349388,
                                0.67516700749208114,
                                0.26790117649063877,
                                -0.039135181720235335,
                                0,
                                0.43150176676111673,
                                0,
                                0,
                                0,
                                0,
                                -0.27149940973951714,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57764771323538244,
                                0.36522638163805909,
                                0.61367278307026485,
                                -0.79359641423181959,
                                0,
                                0.17163647408314892,
                                0,
                                0,
                                0,
                                0,
                                0.93498894787822084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4525964106188014,
                                -0.0078759059993465663,
                                -0.11213214582552056,
                                -0.6561371283948324,
                                0,
                                -0.7825784260824783,
                                0,
                                0,
                                0,
                                0,
                                -0.23110938114203036,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.85385001195591226,
                                -0.58260173245398983,
                                0.1996950731056284,
                                -0.62832630344982654,
                                0,
                                0.40917170114262985,
                                0,
                                0,
                                0,
                                0.23326681551684147,
                                0,
                                0.9296391884848314,
                                0,
                                0,
                                0,
                                -0.083710804237696362,
                                0,
                                -0.25181033280770426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.086744982648554486,
                                0,
                                0,
                                0.058454576744242565,
                                0,
                                0,
                                -0.65911868210147895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47165422299911475,
                                0.47377433485412346,
                                -1.062458004341041,
                                -0.26924904542754918,
                                0,
                                0.041334908813220855,
                                0,
                                0,
                                -0.2205286181751169,
                                0,
                                0,
                                0,
                                -0.37323035734044141,
                                0.044036706428739636,
                                0.77566351737580663,
                                0,
                                0.17977385188967226,
                                0,
                                -0.40368901055187995,
                                0.027097881696802471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11160356162928795,
                                0,
                                0,
                                0.55506001876712685,
                                0,
                                -0.2600132934804904,
                                0,
                                0,
                                0,
                                0.13097413451056633,
                                0,
                                -0.19657860462550614,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73429426654098318,
                                0,
                                0,
                                0.17121921970795642,
                                0.90895439120508836,
                                0,
                                0.091654822594488553,
                                0,
                                0.08223293561614356,
                                0,
                                0.14311114221907084,
                                0,
                                0,
                                0.085891119519052914,
                                0,
                                0,
                                0,
                                0.036559580275724687,
                                0.2931063074189591,
                                0,
                                0,
                                0,
                                0,
                                0.20864577327610445,
                                0,
                                -0.19284510758564899,
                                0,
                                0.049236611235877567,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2275600642623497,
                                0.78291965268821084,
                                0,
                                0,
                                0.52368334508063885,
                                0,
                                0.14627203856829796,
                                0,
                                0,
                                0.13033471939007221,
                                0,
                                0.14614987312827782,
                                0,
                                -0.087112458261831269,
                                0,
                                -0.24465597742935599,
                                0,
                                0,
                                -0.20692906237994163,
                                0,
                                0,
                                0,
                                -0.23108707841131859,
                                -0.65154973968215224,
                                0,
                                0,
                                0,
                                0,
                                0.6111219271828271,
                                0,
                                0.24770650960162457,
                                0,
                                -0.34215699080859435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.014712136388442709,
                                -0.4476519731669511,
                                0,
                                0,
                                0.78798633486048564,
                                0,
                                -0.0062352848812143313,
                                0,
                                0,
                                0.0013235225957329635,
                                0,
                                0.13805785207134885,
                                0,
                                0.88075856566956867,
                                0,
                                -0.18772419724744235,
                                0,
                                0,
                                -0.057242923835959553,
                                0,
                                0,
                                0,
                                0.35825620995626661,
                                -0.18501939344264109,
                                0,
                                0,
                                0,
                                0,
                                -0.064076612624380164,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58723068301068992,
                                0,
                                0.4628987861436884,
                                -0.70645305408929127,
                                0,
                                0.44374940435541083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45121171907685009,
                                0,
                                -0.21174600692477602,
                                0,
                                0.28080473191335659,
                                0,
                                0.33992671153837611,
                                0,
                                -0.061441423010546906,
                                0,
                                -0.20898763939805701,
                                0,
                                0,
                                -0.23982420625149384,
                                0,
                                0,
                                0,
                                -0.37739514793577011,
                                -0.23582051137154353,
                                0,
                                0,
                                0,
                                0,
                                -0.70893835434533969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76167946433243683,
                                0,
                                -0.52796261703652614,
                                -0.28938563803076045,
                                0,
                                0.8406799580603016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.88546751985253169,
                                0,
                                -0.66790754424994025,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65332739807038565,
                                0,
                                0.066849339723621642,
                                -0.15477657366476424,
                                0,
                                -0.57264832295556556,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6845472852503981,
                                0,
                                0.869301989095838,
                                0,
                                0.020306954765925013,
                                0,
                                0.11925954236903774,
                                0,
                                0.026936315051747553,
                                0,
                                0.034647841395619494,
                                0,
                                0,
                                0.92668013199300425,
                                0,
                                0,
                                0,
                                -0.12597274275351036,
                                -0.31795086929036942,
                                0,
                                0,
                                0,
                                0,
                                -0.087981798857926383,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.159417980984478,
                                0,
                                -0.67537733796913468,
                                0.40312080435295333,
                                0,
                                -0.22140211335546484,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10711872962520477,
                                0,
                                -0.30507562414150136,
                                0,
                                0,
                                -0.89176765468467911,
                                0,
                                -0.12987592610813878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2585743024833585,
                                -0.17157033471548239,
                                0,
                                0,
                                0.12912976124514963,
                                0,
                                -0.27369901164851318,
                                0,
                                0,
                                0,
                                -0.27243448486211508,
                                0,
                                0.55933894939315876,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38811118409300216,
                                -0.38792760995099573,
                                0,
                                0,
                                0.10522818464656523,
                                0,
                                0.54838699704250427,
                                0,
                                0,
                                0.26110356821037506,
                                0,
                                -0.84598565281817029,
                                0,
                                -0.017943912676850159,
                                0,
                                -0.00040744669867578964,
                                0,
                                0,
                                -0.03254069589657832,
                                0,
                                0,
                                0,
                                0.12491738850282701,
                                -0.38330287191807155,
                                0,
                                0,
                                0,
                                0,
                                -0.22853163767459012,
                                -0.064893232218867836,
                                0,
                                -0.32502450402579769,
                                0,
                                0.35780691649706359,
                                0,
                                -0.33158564965499576,
                                0,
                                0,
                                0.076716880392841538,
                                0,
                                0,
                                0,
                                -0.71698999259082752,
                                0.34046137261244214,
                                0,
                                0,
                                0,
                                0,
                                0.12766766305916921,
                                0,
                                -0.011766562932223834,
                                0,
                                -0.17324228865754793,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6791209027533901,
                                0.078677941773955248,
                                0,
                                0,
                                -0.0085410824138094539,
                                0,
                                0.70878790075049358,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3910035563375156,
                                0,
                                0.12040933509139334,
                                0.49569034215043156,
                                0,
                                0.7482217364636824,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42693500991779804,
                                0,
                                0.63719023827365096,
                                0,
                                0,
                                0.17844802911246391,
                                0,
                                0.72163955177416683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51894489930665633,
                                0.023023890111065277,
                                0,
                                0,
                                0.27751193485371156,
                                0,
                                -0.31708969740842091,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49397497253657091,
                                0,
                                -0.54914709888673319,
                                -0.78863379163510683,
                                0,
                                -0.23817349373260821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62760639236366911,
                                0,
                                0.74433884828147268,
                                0,
                                0.071855056340096868,
                                0,
                                -0.0086009828763723428,
                                0,
                                -0.27760606241542501,
                                0,
                                -0.85416436594144773,
                                0,
                                0,
                                0.15274237408020774,
                                0,
                                0,
                                0,
                                0.35908134772094685,
                                0.18920979518415859,
                                0,
                                0,
                                0,
                                0,
                                -0.0055668953263637577,
                                -0.6185804258857639,
                                0,
                                0,
                                0.47028226837061582,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17162210663597888,
                                0,
                                0,
                                0.030069172786545861,
                                0,
                                0,
                                -0.57637051967346142,
                                0,
                                0.18338911140052877,
                                0,
                                -0.10553275851315427,
                                0,
                                0,
                                -0.038080136273099779,
                                -0.62874023016655611,
                                0.13609793599747425,
                                0,
                                0,
                                -0.72969126809659823,
                                0,
                                0,
                                0,
                                -0.07784688656108224,
                                0,
                                0.1613730843912001,
                                0.095000305471897056,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1617813341171378,
                                0,
                                0,
                                0,
                                0,
                                0.012014808676572855,
                                0.95895688696617964,
                                0,
                                0.94995398565629263,
                                0,
                                -0.88123734171767476,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29920543347234602,
                                0,
                                -0.18471304213333484,
                                0,
                                0,
                                0.58096929917459428,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29469113061924457,
                                0,
                                0,
                                -0.15056967551271208,
                                0,
                                0,
                                0.70466402907978143,
                                0,
                                -0.149299303259678,
                                0,
                                0.33407973294966231,
                                0,
                                0,
                                0.80899870523236983,
                                -0.073701037304752942,
                                -0.18678892884367723,
                                0,
                                0,
                                -0.07492824340562862,
                                0,
                                0,
                                0,
                                -0.13918233921546658,
                                0,
                                -0.29458522801525966,
                                0.28604800008411624,
                                0,
                                0,
                                0,
                                0,
                                -0.72695487188398822,
                                0,
                                0,
                                0.32797315503275609,
                                0.45895349051389062,
                                0.035816709376005507,
                                0,
                                0,
                                -0.29018282333243495,
                                0,
                                0,
                                0,
                                -0.23153786347506869,
                                0,
                                0.006255791182248633,
                                -0.11913896337255533,
                                0,
                                0,
                                0,
                                0,
                                -0.28768470371862392,
                                0,
                                0,
                                -0.18654068143797653,
                                -0.30595646210346922,
                                -0.50789906216689573,
                                0,
                                0,
                                0.32403827279228919,
                                0,
                                0,
                                0,
                                -0.5921580475306425,
                                0,
                                0.022798525352436851,
                                0.27330851270010004,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1977411951473096,
                                0,
                                0,
                                0,
                                0,
                                0.071788615800790767,
                                0.24030584040178182,
                                0,
                                -0.33848162823274525,
                                0,
                                0.24311298276542709,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3195774086332831,
                                0,
                                0,
                                0,
                                -0.20256929520412315,
                                0,
                                0,
                                0,
                                0,
                                0.24218429625492705,
                                0.94211341913943503,
                                0,
                                -0.93379735372157713,
                                0,
                                -0.59010277114212983,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65845144172538328,
                                0,
                                0,
                                -0.48712775820026272,
                                0,
                                0,
                                0.21782310942240302,
                                -0.35236302910471345,
                                0.24496697166174508,
                                0,
                                0,
                                0.39148508975029855,
                                0,
                                0,
                                0,
                                0.51043889246117558,
                                0,
                                -0.030978754587816133,
                                0.34106157367514067,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.88287858228067462,
                                0,
                                0,
                                0,
                                0,
                                0.8638915130500584,
                                0.4533358133257383,
                                0,
                                0.12956623351103352,
                                0,
                                0.18116392643623985,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0391407622506383,
                                0,
                                0.54247069882502408,
                                0,
                                0,
                                0.37351940465068717,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12914661165264632,
                                0,
                                0,
                                -0.41953273706832284,
                                0,
                                0,
                                -0.40616569752077075,
                                0,
                                -0.45667456317354954,
                                0,
                                0,
                                0.20291100250686625,
                                0,
                                0,
                                0,
                                0,
                                1.2955237661595917,
                                -0.096350547957403415,
                                0,
                                0.14263142143252239,
                                0,
                                0.16363910964487627,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0859959916580901,
                                0,
                                0,
                                0.011485657409119943,
                                0,
                                0,
                                0.06102281507114668,
                                0.18010206438000817,
                                -0.62021554810837942,
                                0,
                                0,
                                -0.17101836095791248,
                                0,
                                0,
                                0,
                                0.43622239135081609,
                                0,
                                0.56394556787920114,
                                0.20363781076756066,
                                0,
                                0,
                                0,
                                -0.052658280679221708,
                                0,
                                0,
                                -0.0083878929039437056,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18324195142916705,
                                0,
                                0,
                                0.73969541454129917,
                                0,
                                0,
                                -0.061565607791797969,
                                0,
                                -0.64237022472152305,
                                0,
                                -0.078927306453174265,
                                0,
                                0,
                                -0.37675976970185299,
                                0.20546394278092003,
                                -0.20157956573675764,
                                0,
                                0,
                                -0.3003285099724276,
                                0,
                                0,
                                0,
                                0.22989244986083301,
                                0,
                                -0.6673039394387823,
                                0.42500647421981796,
                                0,
                                0,
                                0,
                                0,
                                -0.14957540427510851,
                                0,
                                0,
                                0.092674521184852726,
                                -0.3101521034197291,
                                -0.44948024340898296,
                                0,
                                0,
                                0.0049466381050915775,
                                0,
                                0,
                                0,
                                0.25810623214002981,
                                0,
                                -0.34975781482446106,
                                -0.69414551050883211,
                                0,
                                0,
                                0,
                                0.50264547189251574,
                                0,
                                0,
                                0.20217072384678586,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48184090922368999,
                                0,
                                0,
                                0.40128095504514516,
                                0,
                                0,
                                -0.032296147241559506,
                                0,
                                0.55877940208557331,
                                0,
                                0,
                                -0.27617471986175074,
                                0,
                                0,
                                0,
                                0,
                                0.027257606685847841,
                                -0.93268453848217281,
                                0,
                                -0.45876125444881799,
                                0,
                                -0.99698185483921575,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2009720901511079,
                                0,
                                0.18313799375056289,
                                0,
                                0,
                                0.51073394002558903,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.77541980125718946,
                                0,
                                0,
                                0.30371234584145784,
                                0,
                                0,
                                0.037969608115420092,
                                0,
                                0.1032112852950709,
                                -0.58416038263069081,
                                0,
                                0,
                                0,
                                -1.2813116820016799,
                                0,
                                -0.56829550943808771,
                                0,
                                0.19840072411632104,
                                0,
                                0,
                                -0.18597878897255687,
                                0,
                                0,
                                0,
                                0.29893324224485263,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39872703281756094,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36668211688918728,
                                -0.27718770312248325,
                                0,
                                -0.090090080493794605,
                                0.54330176699302901,
                                0,
                                0,
                                -0.44857066667555284,
                                0.34771307682820668,
                                0,
                                0.065687870049476821,
                                0,
                                0,
                                -0.0045871978347627462,
                                0.66630238239088124,
                                0,
                                -0.30252329073576267,
                                0,
                                0.29433320169952698,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61462050393112388,
                                0,
                                0,
                                0,
                                -0.010457242630100338,
                                0,
                                0,
                                0,
                                0.27400520146434226,
                                -0.4220607236971522,
                                0,
                                -0.096450322131779453,
                                0,
                                -0.42426260227339108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62231468137976786,
                                0,
                                0,
                                0,
                                0.41256382790400581,
                                0,
                                -0.11103721064803604,
                                0,
                                0,
                                0,
                                0.53373327855021124,
                                0,
                                -1.7214161015586251,
                                0,
                                0.19831719203673495,
                                0,
                                0,
                                -0.12314456516152195,
                                0,
                                0,
                                0,
                                0.012364641203141125,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71404196275022258,
                                0.030006800214348844,
                                0,
                                -0.61051007340713759,
                                0,
                                -0.0037119809196172887,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32755643456725292,
                                0,
                                0,
                                0,
                                -0.095990213107159827,
                                0,
                                1.246686770283342,
                                0,
                                0,
                                0,
                                -0.46001663518851937,
                                0,
                                -0.17339738883433864,
                                0,
                                0.14317953929999414,
                                0,
                                0,
                                -0.64141131683002572,
                                0,
                                0,
                                0,
                                -0.88926671957464232,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57186652253636083,
                                -0.10111979419890021,
                                0,
                                -0.63480122594006239,
                                0,
                                0.020537467658503658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20903587817022362,
                                0,
                                0,
                                0,
                                0.46438463069756075,
                                0,
                                -0.84705732839870473,
                                0,
                                0,
                                0,
                                0.16431726052268728,
                                0,
                                0.39512421686485627,
                                0,
                                -0.15019292542989332,
                                0,
                                0,
                                -0.80990052286841097,
                                0,
                                0,
                                0,
                                -1.1210528795734591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55574934669105447,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30720670115597137,
                                0.077841763766667377,
                                0,
                                -0.27329701268931705,
                                -0.28328916224182943,
                                0,
                                0,
                                -0.65162981856031565,
                                -0.09988625600841132,
                                0,
                                0.034127336053590085,
                                0,
                                -0.24518429748682519,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29119593954750228,
                                -0.043834419529887952,
                                0,
                                -0.79247703309561135,
                                0.41058975945063925,
                                0,
                                0,
                                0.21468566726312319,
                                0.0027070012694843382,
                                0,
                                -0.10230868285524564,
                                0.011451997222226864,
                                0,
                                0,
                                0,
                                -0.20453829397454193,
                                0,
                                -0.53551564605717372,
                                0,
                                -1.6514464207020088,
                                0,
                                0,
                                -0.38046234412335822,
                                0,
                                0,
                                0,
                                -0.017750438349234954,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37323119603289351,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19168245731352795,
                                -0.58337877449913178,
                                0,
                                0.25235594795452898,
                                0.10055770558770774,
                                0,
                                0,
                                0.15840128373547666,
                                -0.0094304563994983548,
                                0,
                                -0.62020177241922658,
                                0,
                                -0.34437967711248768,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59860666730266054,
                                0.15493802369899867,
                                0,
                                0.42837154553481988,
                                0.40089615498432601,
                                0,
                                0,
                                -0.35002126467324907,
                                0.17824364579286089,
                                0,
                                0.02369205712582844,
                                0,
                                0,
                                0.29010535043393415,
                                0.0064313498897695665,
                                0,
                                0.29768445646468744,
                                0,
                                0.58809081557195197,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12831130077020855,
                                0,
                                0,
                                0,
                                0.68181147724433244,
                                0,
                                0.39892349907485325,
                                0,
                                0,
                                0,
                                -0.41664316330272783,
                                0,
                                0.17828647720489685,
                                0,
                                0.23228198720217852,
                                0,
                                0,
                                -0.87237720843338651,
                                0,
                                0,
                                0,
                                0.9003731396585124,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33420863492188496,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47817703045154075,
                                0.52382901324701425,
                                0,
                                0.11219380515126957,
                                0.22577082870986587,
                                0,
                                0,
                                0.362326568749408,
                                0.43568439283539379,
                                0,
                                0.024354284635898497,
                                0,
                                0.05076868404496844,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22717891168193127,
                                0.28744956992135823,
                                0,
                                0.12417857852640442,
                                0.46172396395368437,
                                0,
                                0,
                                -0.039153338318762013,
                                -0.78890069873614488,
                                0,
                                -0.10333630987005896,
                                0,
                                0,
                                0.062062457815442437,
                                0.60558971064007971,
                                0,
                                0.18672389272883783,
                                0,
                                -0.6221598162443962,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25983276812692235,
                                0,
                                0,
                                0,
                                0.3740957594509754,
                                0,
                                0,
                                -0.31602581948728303,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10505977234027919,
                                -0.44025618067742606,
                                0,
                                0.11823365636153171,
                                0.14489798050047933,
                                0,
                                0,
                                0.21829709594347033,
                                -0.15832274254590484,
                                0,
                                0.76653133391543893,
                                0.055142122526070259,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63378833358869269,
                                0,
                                0.36095277687854516,
                                0,
                                0,
                                0,
                                0,
                                0.92300222718877645,
                                0,
                                -0.55978651931389489,
                                0,
                                0,
                                -0.044154341298697497,
                                0,
                                -0.10876932788240898,
                                0.098079053745417685,
                                0.64595103821807365,
                                -0.72609766728484859,
                                -0.079024278791072378,
                                0,
                                0,
                                -0.0097478849647424162,
                                0,
                                0,
                                0,
                                0,
                                0.16189728975762263,
                                0,
                                0,
                                0,
                                -0.039097007383031505,
                                0,
                                0,
                                0,
                                -0.32494543157702355,
                                0.18072114588208571,
                                -0.50818705514702467,
                                -0.47579041494827146,
                                0.53371661796476266,
                                0,
                                0,
                                0.25886882500777664,
                                0,
                                0,
                                0,
                                0,
                                -0.13966662906153984,
                                0,
                                0,
                                0,
                                0.075805460400747357,
                                0,
                                0,
                                0,
                                0.30351474800977163,
                                0.44670321559509046,
                                0.19414705221891806,
                                0.13298646726399779,
                                -0.059670833544436128,
                                0,
                                0,
                                0.60491815492491363,
                                0,
                                0,
                                0,
                                0,
                                -0.11189268310718561,
                                0,
                                0,
                                0,
                                0.52052857893716376,
                                0,
                                0,
                                0,
                                0.02685025671966524,
                                0.30940498845344538,
                                0.19394779659771572,
                                0.211484724222225,
                                0.21185828348068536,
                                0,
                                0,
                                0.35131044414220142,
                                0,
                                0,
                                0,
                                0,
                                -0.064679004018650108,
                                0,
                                0,
                                0,
                                -0.80543140393588741,
                                0,
                                0,
                                0,
                                -0.26068252690363486,
                                0.25995670772399232,
                                -0.38843195302115024,
                                -0.14433657536842173,
                                -0.77358446198918185,
                                0,
                                0,
                                0.19631826620626391,
                                0,
                                0,
                                0,
                                0,
                                0.16272097868645755,
                                0,
                                0,
                                0,
                                -0.17118061449102451,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38562148057878981,
                                0,
                                0,
                                0,
                                -0.14567258342217282,
                                -0.42224889670219901,
                                -0.18977302739376467,
                                0,
                                0,
                                -0.70279465014013098,
                                0,
                                0,
                                -0.3490663535738201,
                                0,
                                0.26394775349369487,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44979571518900674,
                                0,
                                0.38174716286142063,
                                0,
                                0,
                                0,
                                0,
                                0.6598324031972187,
                                0,
                                1.2418143527962162,
                                0,
                                0,
                                0.21346652725926096,
                                0,
                                -0.087639885107329424,
                                0.6688144297898464,
                                0.039642294602051154,
                                0.051458536900625518,
                                -0.026451581132099271,
                                0,
                                0,
                                -0.59479937904836966,
                                0,
                                0,
                                0,
                                0,
                                -0.42925962474678292,
                                0,
                                0,
                                0,
                                0.045135391917268598,
                                0,
                                0,
                                1.1498458705015495,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0028509583732020533,
                                0,
                                -0.066121081732774714,
                                0,
                                0,
                                0,
                                0,
                                -0.19900251958127865,
                                0,
                                0.32815219913362725,
                                0,
                                0,
                                0.51000513276191628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23568892335495448,
                                0,
                                0,
                                0,
                                0.068676542805621382,
                                0.070491516569125862,
                                -0.28628701275514051,
                                0,
                                0,
                                0.52677190219554348,
                                0,
                                0,
                                -0.75849609053235167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65478386441976555,
                                0,
                                0,
                                0,
                                -0.42920759370988992,
                                0.52846225111127532,
                                -0.15136238835145974,
                                0,
                                0,
                                0.027572348456484153,
                                0,
                                0,
                                0.28999271463404541,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.092250960314960828,
                                0,
                                0,
                                0,
                                0.4255174255834846,
                                -0.2161931981571156,
                                -0.76795349010345859,
                                0,
                                0,
                                0.098380754883740262,
                                0,
                                0,
                                0.40528242747841059,
                                0,
                                0,
                                0.092061222493586031,
                                0.38362208465809916,
                                -0.098980189078653233,
                                0.11222311699648173,
                                0.24070383788006619,
                                0,
                                0,
                                -0.19756265539779899,
                                0,
                                0,
                                0,
                                0,
                                0.84898107918447352,
                                0,
                                0,
                                0,
                                0.065034671259654911,
                                0,
                                0,
                                0.0095913831671806671,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3160759157188171,
                                0,
                                -0.39380783414469733,
                                0,
                                0,
                                0,
                                0,
                                0.66649318639444211,
                                0,
                                -0.29551387506473981,
                                0,
                                0,
                                -1.3406116440072167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57274953593085276,
                                0,
                                0,
                                0,
                                -0.63155799225919163,
                                0.10292809665248159,
                                -0.50078508062723215,
                                0,
                                0,
                                -0.068262844180357482,
                                0,
                                0,
                                -0.083980745112280694,
                                0,
                                0.098816147702964069,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71352130362123156,
                                0,
                                0.72484971612018201,
                                0,
                                0,
                                0,
                                0,
                                0.0038614239049659382,
                                0,
                                -0.49917588392900514,
                                0,
                                0,
                                -0.38380416912487031,
                                0,
                                -0.84001557323800868,
                                -0.019723633573935029,
                                0.29484975163021049,
                                0.38460292972714261,
                                0.058191501689361755,
                                0,
                                0,
                                0.11040263622878534,
                                0,
                                0,
                                0,
                                0,
                                0.077899544583340627,
                                0,
                                0,
                                0,
                                0.19361222431381414,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17450680626119516,
                                0,
                                0,
                                0,
                                0.45816295719698591,
                                0.69291469349845569,
                                -0.13629787912208918,
                                0,
                                0,
                                -0.46205218272962068,
                                0,
                                0,
                                -0.21779342353841946,
                                0,
                                0.095041498091327781,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71607676933641118,
                                0,
                                0.48671590072667015,
                                0,
                                0,
                                0,
                                0,
                                -0.61703896103039002,
                                0,
                                0.50526068597144169,
                                0,
                                0,
                                -0.28251015739400748};

const double rot_28_10[1000] = {0.14714580630145696,
                                0,
                                -0.56300129084783368,
                                0,
                                -0.12523593792256421,
                                0,
                                0.45346421716743601,
                                0,
                                -0.10512847783916096,
                                0.65498994262520149,
                                0,
                                -0.28393776062250825,
                                0,
                                0.28836649068515702,
                                0,
                                0.29572997794192857,
                                0,
                                -0.20119844597327119,
                                0,
                                0,
                                0.10827926321681339,
                                0,
                                -0.30621686927265707,
                                0,
                                0.49548209941622318,
                                0,
                                0.30192369200152186,
                                0,
                                -0.56192861326163746,
                                -0.49201893977182937,
                                0,
                                -0.27593085255723659,
                                0,
                                -0.08225097403186088,
                                0,
                                0.39977044859348454,
                                0,
                                -1.0948879508660014,
                                0,
                                0,
                                -0.43369043590546935,
                                0,
                                -0.35568736582657795,
                                0,
                                -0.089966316089187356,
                                0,
                                -0.66165104350610537,
                                0,
                                -0.46312421737769799,
                                0.15823723161882658,
                                0,
                                0.81904300747212921,
                                0,
                                -0.089851551851091879,
                                0,
                                0.12570337884004606,
                                0,
                                -0.73250935312654109,
                                0,
                                0,
                                -0.67417325939363204,
                                0,
                                -0.14972055624434383,
                                0,
                                0.54333354788749699,
                                0,
                                0.16034754599220785,
                                0,
                                0.4412222591742847,
                                0.086454667889305489,
                                0,
                                -0.31510626093560823,
                                0,
                                -1.6373130111738385,
                                0,
                                0.24958847579807877,
                                0,
                                0.57400223056111421,
                                0,
                                0,
                                -0.074140559834747599,
                                0,
                                0.64347003402514813,
                                0,
                                0.34467972225879484,
                                0,
                                0.090806259067648123,
                                0,
                                -0.45045192326395095,
                                0.50049242741985212,
                                0.56438454298039964,
                                0,
                                -0.16210287973207391,
                                0,
                                0.5627646539928397,
                                0,
                                -0.48111648526380063,
                                0,
                                0.24721686605148457,
                                0.21424153890126846,
                                -0.40595780184790276,
                                0,
                                0,
                                0,
                                0.62846564618483258,
                                0.19974274223436861,
                                0,
                                0.52404922569319801,
                                -0.16143913714553471,
                                0.31566096631838769,
                                0,
                                -0.64739080444761854,
                                0.27343806370968426,
                                0.76045176654370639,
                                0,
                                0,
                                0.77968143977965709,
                                0,
                                0,
                                0,
                                0,
                                0.68698171157713817,
                                -1.0608439970816872,
                                0.67049811446611829,
                                0,
                                0,
                                0.96813316454112974,
                                0,
                                0,
                                0,
                                0,
                                -0.71134781263550861,
                                -0.16585233689571849,
                                0.26960518176998755,
                                0,
                                0,
                                -0.27760279013634703,
                                0,
                                0,
                                0,
                                -0.21216973610327827,
                                0,
                                0,
                                0,
                                -0.16355077503087884,
                                -0.46128279578478104,
                                0,
                                -0.31562921278979261,
                                -0.47069176555709802,
                                0.62791782205323621,
                                0.79655093983018099,
                                0,
                                0,
                                0,
                                0.085093135994999597,
                                -0.24798423635061501,
                                0,
                                0.44867244801758632,
                                -0.28393831902067279,
                                0.12182627945322394,
                                0,
                                -0.0027004667141968808,
                                -0.59837956075170751,
                                -1.0116100764949332,
                                0,
                                0,
                                -0.017220655310368226,
                                0,
                                0,
                                0,
                                -0.12747409506886248,
                                0,
                                0,
                                0,
                                0.48592379224625248,
                                -0.62422138997515852,
                                0,
                                -0.15100365229535406,
                                -0.14581221145018902,
                                -0.56027919424010852,
                                -0.22373265749113569,
                                0,
                                0,
                                0,
                                -0.28959796474596328,
                                -0.54021853251071794,
                                0,
                                0.48196240019985881,
                                0.57170041275923977,
                                0.12292899073621213,
                                0.29896976354586141,
                                0,
                                0,
                                0,
                                0.50105121564849286,
                                -0.065851584557399451,
                                0,
                                -0.41152616594940417,
                                0.56891399602143877,
                                0.40275477460072229,
                                -0.17364458437259006,
                                -0.082501769300300537,
                                0,
                                -0.058285679789605582,
                                -0.077853355567117963,
                                0,
                                0,
                                -0.87778578756381531,
                                0,
                                -0.42787236658817501,
                                -0.015131673914933544,
                                0.41631002601604233,
                                0,
                                -0.1967497733804438,
                                0.59092786834389122,
                                0,
                                0,
                                -0.34962826709322264,
                                0,
                                0.56241519415973495,
                                0,
                                0,
                                -0.052427518945991819,
                                0,
                                0,
                                -0.10467521775001579,
                                -1.133688536935086,
                                0,
                                0.34450645095805982,
                                0,
                                0.41735106285249479,
                                0.25111149599303595,
                                0,
                                0.0043002851642046924,
                                -0.71945643378036794,
                                0,
                                0,
                                -0.25073522416999727,
                                0,
                                0.42691556743224501,
                                -0.68803211165179867,
                                -0.44971478320365538,
                                0,
                                -0.064054763757461941,
                                -0.23662642128816139,
                                0,
                                0,
                                -0.045964126562770047,
                                0,
                                0.51201625966536657,
                                0,
                                0,
                                -0.0428357470020495,
                                0,
                                0,
                                0.71184499040383897,
                                0.59141549902734036,
                                0,
                                -0.21854129455814819,
                                0,
                                0,
                                0,
                                -0.2469471401751214,
                                0,
                                0,
                                -0.2970306985033051,
                                0.3645333732723533,
                                0,
                                1.0974567062656413,
                                0,
                                0.45335884915514185,
                                -0.57576906020623131,
                                0,
                                -0.66709540132717149,
                                0.11025988756063353,
                                0,
                                0,
                                -0.034165649222381772,
                                0,
                                0.067933308019175284,
                                0,
                                0,
                                -0.41495517765110396,
                                0,
                                0,
                                -0.30540735525852392,
                                -0.087749392837303888,
                                0,
                                -0.53488392686123709,
                                0,
                                -0.34134183500882032,
                                0.47230185258826141,
                                0,
                                -0.71327030396745794,
                                -0.24285024866570298,
                                0,
                                0,
                                0.20274131508727539,
                                0,
                                -0.2271164922949592,
                                0.36328193034993062,
                                -0.1423027609240449,
                                0,
                                -0.076203448869282528,
                                -0.49958764158706004,
                                0,
                                -0.71402452029478869,
                                0,
                                0.2873158027090138,
                                0,
                                -0.050970084637263019,
                                0.02217785902033062,
                                0,
                                0.78097442928386507,
                                0.23584450203794061,
                                0,
                                -0.047886229734598357,
                                0,
                                0.57364920788437157,
                                0,
                                0,
                                0,
                                0.50513286960955328,
                                0,
                                0,
                                0.5222365621977556,
                                0,
                                -0.68572525803546136,
                                0,
                                0.045375410642287728,
                                0.88714678889569853,
                                0.28567646746604869,
                                0,
                                0.14197277845856379,
                                0.22172840029363891,
                                0,
                                0.14171590491299532,
                                0,
                                -0.20483256543538428,
                                0,
                                0.082764852096637309,
                                -0.5119002434559824,
                                0,
                                0.47384655079882998,
                                -0.51977852839082994,
                                0,
                                0.30480466631120634,
                                0,
                                -0.37881652963137313,
                                0,
                                0,
                                0,
                                0.027264664807187228,
                                0,
                                0,
                                0.94824164354811658,
                                0,
                                0.82850743800067184,
                                0,
                                -0.32186567333702476,
                                0.19155683155806397,
                                -0.79667709534875442,
                                0,
                                -0.20640902917061663,
                                0.5214789298918171,
                                0,
                                -0.04196624693561643,
                                0,
                                0.11092997117089307,
                                0,
                                0,
                                0,
                                0.33603009936741635,
                                0,
                                0,
                                -0.15602018083008196,
                                0,
                                -0.097712385842118443,
                                0,
                                0.97809906309105343,
                                0.18669446710121504,
                                -0.030178953513440562,
                                0,
                                -0.31141686584836475,
                                -0.32173915341146653,
                                0,
                                0.61083995058226703,
                                0,
                                0.62498993137372638,
                                0,
                                0,
                                0,
                                0.76473415620526697,
                                0,
                                0,
                                -0.81117765325293689,
                                0,
                                0.52517265534072655,
                                0,
                                0.052199058496849318,
                                0.59573031093644524,
                                0,
                                0,
                                0,
                                0,
                                0.62316935895726111,
                                0.75599495194997113,
                                -0.060464975756899839,
                                0,
                                0,
                                0,
                                -0.26209408351505342,
                                0.7248078718518447,
                                -0.10349146464911374,
                                -0.60301506243671699,
                                0,
                                0,
                                0,
                                0.16074694835719291,
                                -0.076046105101282319,
                                0,
                                0.085840779624217878,
                                0.22777648935325506,
                                0.27501665018804555,
                                0.21674222789113903,
                                0,
                                0,
                                0,
                                0.46895191069968434,
                                0.77344811440112771,
                                0,
                                0.56837184793350726,
                                0.55625314893007449,
                                -0.24520693224911877,
                                0.34477868819221513,
                                0,
                                0,
                                0,
                                -0.43340191430284591,
                                0.026455131942344726,
                                0,
                                0.38510243087233487,
                                -0.32772286432895104,
                                -0.60671728951764181,
                                -0.48678857567417444,
                                0,
                                0,
                                0,
                                0.062878030458219242,
                                0.36779234414465106,
                                0.88144962498908219,
                                0,
                                0,
                                0,
                                0,
                                -0.64559540457039111,
                                0.63885374362551972,
                                0.59089252617534582,
                                0,
                                0,
                                0.40317024563238657,
                                0,
                                0,
                                0,
                                0,
                                0.28052190184729037,
                                0.42461605745333164,
                                0.061180074899338965,
                                0,
                                0,
                                0.15157748820183531,
                                0,
                                0,
                                0,
                                0,
                                -0.66279410129890004,
                                -0.27372047081354689,
                                0.26613223330047253,
                                0,
                                0,
                                0,
                                -0.12779676361563458,
                                0.075687217470407048,
                                -0.587682919251169,
                                0.4423078715079144,
                                0,
                                0,
                                0,
                                0.59652211022490864,
                                -0.28476891957575201,
                                0,
                                -0.66049647944720291,
                                0.014933968410860934,
                                -0.37423500138535315,
                                0.19474066521127262,
                                0,
                                0,
                                0,
                                -0.45454926028111742,
                                0.42300187263701255,
                                -0.23874177274523523,
                                0.10849500623647945,
                                -0.25430711008181472,
                                0,
                                0.426525797768742,
                                0,
                                -0.14512300152821248,
                                0,
                                0.81460060863912109,
                                0,
                                -0.089226665338750538,
                                0.23208139673049752,
                                0.072032101600340487,
                                0,
                                -0.80149313904355668,
                                0,
                                -0.44378334969030231,
                                0,
                                0.30602825102749392,
                                0,
                                0.50703511935742718,
                                -0.48848244866428037,
                                -0.65738093483255966,
                                0,
                                -0.11342907620488932,
                                0,
                                -0.24223059769026672,
                                0,
                                0.024673342249070487,
                                0,
                                0,
                                0,
                                0,
                                0.91741076558169243,
                                0,
                                0.7611143698503936,
                                0,
                                0.82263977718335379,
                                0,
                                0.11115232400603403,
                                0.12271595641789645,
                                0.53410398010733995,
                                -0.13659479631161578,
                                0,
                                0.34533572679563534,
                                0,
                                -0.64934406232014108,
                                0,
                                -0.37431419773051006,
                                0,
                                0,
                                0,
                                0,
                                -0.83462695672706955,
                                0,
                                0.6856893233828657,
                                0,
                                0.12669028873266516,
                                0,
                                0.49924189474863145,
                                -0.6458018125990963,
                                0.12780656791809281,
                                -0.64707020450038699,
                                0,
                                -0.1667489132622364,
                                0,
                                0.19547354606101486,
                                0,
                                -0.28616523758965107,
                                0,
                                0,
                                0,
                                0,
                                0.26820605385478768,
                                0,
                                0.74780625945507762,
                                0,
                                -0.81800418703877908,
                                0,
                                -1.1171316657440262,
                                -0.49581969380143676,
                                -0.62781396598898054,
                                0.24623482427950627,
                                0,
                                0.12552438926177911,
                                0,
                                -0.51328585800470095,
                                0,
                                -0.14199338834153857,
                                0,
                                0,
                                0,
                                0,
                                0.87888318217551853,
                                0,
                                0.49322687939668108,
                                0,
                                -0.76951580167766365,
                                0,
                                0.66422637020144315,
                                0.16672240040287592,
                                0,
                                -0.61914678134174017,
                                0.57393113698259057,
                                0.36304205152086505,
                                0,
                                0,
                                0,
                                -0.24122354760110809,
                                -0.26358228937126144,
                                0,
                                0.15910007650838981,
                                0,
                                0,
                                0,
                                0.51882876421902702,
                                -0.57843055803280119,
                                -0.53573770453792524,
                                0,
                                0,
                                -0.63647459115605098,
                                0,
                                -0.60286698283629825,
                                -0.16045372114531711,
                                -0.072303927515921004,
                                0,
                                0,
                                0,
                                0.40244127492307114,
                                0.19626324539577605,
                                0.35625520239150466,
                                0,
                                -0.36719513210260851,
                                -0.12281440893005086,
                                -0.81311105082552604,
                                0,
                                0,
                                0,
                                -0.064368755264478911,
                                -0.24056946826106385,
                                -0.15663493679786133,
                                0,
                                -0.086188164890846866,
                                -0.63224486002196589,
                                0.27872023561781956,
                                0,
                                0,
                                0,
                                -0.26205028598070068,
                                -0.64957540875364606,
                                0,
                                -0.37965297902741429,
                                0,
                                0,
                                0,
                                -1.3191493599402164,
                                -0.55490449693678445,
                                -0.30881366605632465,
                                0,
                                0,
                                0,
                                -0.22915139643286614,
                                0,
                                0,
                                0,
                                -0.77667793335310042,
                                1.2525028648708152,
                                -0.86212101765687088,
                                0,
                                0,
                                0,
                                0.64505909535954997,
                                0,
                                0,
                                0,
                                0.17665356970647253,
                                0.0073257965970369987,
                                -1.0779658390873521,
                                0,
                                0,
                                0.25647817303365122,
                                0,
                                -0.29936091263561238,
                                -0.40898709466527672,
                                0.15830057103908882,
                                0,
                                0,
                                0,
                                -0.49039250499793885,
                                0.64170683913379767,
                                0.59149844472938529,
                                0,
                                -0.1460515091975802,
                                -0.25053995231242793,
                                0.31476815179517781,
                                0,
                                0,
                                0,
                                0.68304737926882253,
                                -0.019888869463939349,
                                0.41253452413991587,
                                0,
                                -0.34332759963693688,
                                0,
                                0,
                                1.2596143534439912,
                                -0.37011425868365899,
                                0,
                                0,
                                0,
                                0,
                                0.24173527411864054,
                                0,
                                -0.10353701784124614,
                                -0.023950789902501365,
                                0,
                                0,
                                -0.92172889371880307,
                                -0.14760537303207594,
                                -0.24269116832373999,
                                -0.26044402967861702,
                                0,
                                0.44001417684283528,
                                0,
                                0,
                                1.0258716848831109,
                                0.29181526087183213,
                                0,
                                0,
                                0,
                                0,
                                0.55266484189611453,
                                0,
                                0.39401420090395789,
                                -0.45298855409480548,
                                0,
                                0,
                                0.25982180982214409,
                                -0.41490679028527794,
                                -0.30734465082860879,
                                0,
                                0.54974729248895571,
                                0,
                                0.23320695294972754,
                                0.68694903194435042,
                                0,
                                0,
                                0.082300101320569835,
                                0.3732846364581478,
                                -0.15930703849679728,
                                -0.3524312475164621,
                                0,
                                -0.67582792799832037,
                                0,
                                0,
                                0.64251737433271039,
                                -0.3725383447160554,
                                0,
                                0,
                                0,
                                -0.63012066501417063,
                                0,
                                0.94288609744171759,
                                0,
                                0,
                                0.070086675995633257,
                                0.18901786431848233,
                                0,
                                0,
                                0,
                                0,
                                0.41017030978149155,
                                0,
                                -0.43641994944517981,
                                -0.49557476129141981,
                                0,
                                0,
                                0.041697369278404811,
                                0.61806296953200346,
                                0.10937593775376893,
                                0,
                                0.27053384871515684,
                                0,
                                0.27912450747540035,
                                -0.0089872488853284249,
                                0,
                                0,
                                -0.17386539743922702,
                                -0.13620738802448046,
                                0.89444873883543996,
                                0,
                                0.30409751372365956,
                                0,
                                -0.71503464921033144,
                                0.27686394196660918,
                                0,
                                0,
                                0.21016022439044291,
                                -0.51591598400550576,
                                0.096228310523732902,
                                1.1360345266212488,
                                0,
                                0,
                                0,
                                0,
                                -0.71303355918251365,
                                -0.029839628654332678,
                                0,
                                -0.64316164828449851,
                                0,
                                0,
                                0.023429904266454131,
                                0.43846788858228108,
                                0.19290420587974882,
                                -0.38332349673788013,
                                0,
                                0,
                                -0.25521366483537261,
                                0,
                                -0.74693640944333872,
                                0,
                                0.19106754899224557,
                                0.0080337468549817759,
                                0.90753531517055241,
                                0.3233377982337084,
                                0,
                                0,
                                -0.13872584316979469,
                                0,
                                0.12655477478965341,
                                0,
                                0.15015051706891033,
                                -0.46112046235634563,
                                0.25038485273348765,
                                -0.38155475023807062,
                                0,
                                0,
                                0.70424876323651042,
                                0,
                                -0.24612967921900017,
                                0,
                                0.28128661496759261,
                                0.70716161260873867,
                                -0.074085156220951409,
                                0.24753489012053626,
                                0,
                                0,
                                0.5901188861721729,
                                0,
                                0.076143692295074172,
                                0.55242551893530722,
                                0,
                                0,
                                0,
                                0,
                                0.28193540902671577,
                                -0.73224537948615209,
                                0,
                                -0.73592048463884085,
                                0,
                                -0.043374178925611739,
                                0,
                                0,
                                0,
                                0,
                                -0.92574586016310578,
                                -0.87587030671468702,
                                0,
                                0.71157985114914957,
                                0,
                                0,
                                -0.22813354312652007,
                                0.2970815990426271,
                                0.21079086330065439,
                                -0.69288690892755378,
                                0,
                                0,
                                -0.0048545790207745292,
                                0,
                                0.57892053553068212,
                                0.13519916746923641,
                                0,
                                0,
                                0,
                                0,
                                0.79145350218482247,
                                -0.43736747345250526,
                                0,
                                0.097114242479370935,
                                0,
                                0,
                                0.89957322118475325,
                                -0.081940624557178668,
                                -0.16295289555727949,
                                -0.24812486224201602,
                                0,
                                0,
                                -0.26719082776812991,
                                0,
                                0.1566627648738744,
                                -0.24470501684136081,
                                -0.14098233683446526,
                                0.42583890653522133,
                                0,
                                -0.46181701324846014,
                                0,
                                0,
                                0.72474261149222219,
                                0.019438479260351194,
                                0,
                                0.17902636250893603,
                                -0.7528875018388953,
                                0.21757134102822639,
                                0,
                                -0.38017841097850275,
                                0,
                                0,
                                -0.45676369471996753,
                                0.024576120043864544,
                                0,
                                -0.081073096805797829,
                                0.031201187646956931,
                                -0.34999771279889863,
                                0,
                                -0.24615144373355693,
                                0,
                                0,
                                0.0033638072754944041,
                                0.89964070130679175,
                                0,
                                0,
                                0,
                                0,
                                0.78755180471708353,
                                0,
                                0.41237124006098136,
                                -0.88658266705427491,
                                0,
                                0,
                                0.26431804194496361,
                                0.21839871855442899,
                                0.1733330651238553,
                                -0.58320190171815989,
                                0,
                                -0.65302272355360125,
                                0,
                                0,
                                0.044532055563686335,
                                -0.39206046555446511,
                                0,
                                0,
                                0,
                                0,
                                -0.29580495889752623,
                                0,
                                0.82723946925718095,
                                0.065309717123923861,
                                0,
                                0,
                                0.66418011802425381,
                                0,
                                0,
                                0,
                                0.3272896527108704,
                                0,
                                -0.42763619196049601,
                                0.58473745526517029,
                                0,
                                0,
                                0.54998898321506451,
                                -0.48241421635596254,
                                0.48719907963974374,
                                0.35616388377075919,
                                0,
                                -0.37212107666469779,
                                0,
                                0,
                                -0.51392193415882337,
                                -0.021702959372810499,
                                0,
                                0.78808292255653656,
                                0.38066203054396652,
                                0.42643682768876434,
                                0,
                                -0.12917474858717756,
                                0,
                                0,
                                0.0022137505592225715,
                                0.18836756967040977,
                                0,
                                0,
                                0,
                                0,
                                -0.90017375549561207,
                                0,
                                -0.50562001799142053,
                                -0.4754808064201303,
                                0,
                                0,
                                0.20919926511075615};

const double rot_28_100[100000] = {-0.33034699794660882,
                                   0,
                                   0,
                                   0,
                                   -0.08343795747131677,
                                   -0.25950240708428846,
                                   0,
                                   0,
                                   0.17747497211481189,
                                   0.41279458506947442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39423618263591576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26892457213871013,
                                   0,
                                   -0.060050635184746792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02545134906727288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24737426020282327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10304417357183634,
                                   0,
                                   0,
                                   0,
                                   -0.48020702017035916,
                                   0,
                                   -0.27385368595403642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072577825291439552,
                                   0,
                                   -0.2189211959722222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43638918257960924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68514166543580468,
                                   0.080958218734134335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47888921977167237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23733893816927765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050563332791122476,
                                   0,
                                   0,
                                   0,
                                   0.30009472988738684,
                                   -0.17518669958349997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2024008789861014,
                                   0,
                                   0,
                                   -0.28696078475858622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2500655819618231,
                                   0.17586027184451009,
                                   0,
                                   0,
                                   0.44040760439717408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35516056987088002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17541634906480985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08986992134710077,
                                   0.54861507250270258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66088030793751962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023249830069941607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67644542334692004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38520022716191527,
                                   0,
                                   -0.25945000704342425,
                                   0,
                                   0,
                                   -0.24734504897744264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016258547601344722,
                                   0,
                                   0,
                                   0,
                                   0.062770314295743534,
                                   -0.30911135692886627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33692766287490999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4137710361488206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1895143715351775,
                                   0,
                                   0,
                                   -0.69859109218298987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28602262137572981,
                                   0,
                                   0,
                                   0,
                                   -0.4090343841858558,
                                   0,
                                   0,
                                   0,
                                   -0.092520853330297192,
                                   0.44633086002559375,
                                   0,
                                   0,
                                   0.0014055044583422341,
                                   -0.046824854303835983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1207692498413904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050764703781137982,
                                   0,
                                   -0.062097743197274818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4647377859897871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052087981796077584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38579073652757168,
                                   0,
                                   0,
                                   0,
                                   0.22098790927422363,
                                   0,
                                   -0.40260553494478657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15248231331017512,
                                   0.444854768151424,
                                   0,
                                   0,
                                   0,
                                   -0.42741669566310586,
                                   -0.11399002679142642,
                                   0,
                                   0,
                                   0.26688444491357893,
                                   -0.3142236082997798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3636443184763134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065804995403950767,
                                   0,
                                   0.018597205761917694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038570230956816429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31288645036401325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17798421935798789,
                                   0,
                                   0,
                                   0,
                                   -0.18121140818822024,
                                   0,
                                   -0.14066981721004082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34038037944620397,
                                   0,
                                   0,
                                   0.20192192593374733,
                                   0,
                                   0,
                                   0,
                                   -0.21221665384377925,
                                   -0.20380590342427554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34170038599032448,
                                   0,
                                   0,
                                   -0.26418586329742971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57449483741095719,
                                   -0.042927450748426403,
                                   0,
                                   0,
                                   0.014384329378432514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39949392193542588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1315362284352323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36133425698662947,
                                   -0.21574949765448903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073312046542591422,
                                   0,
                                   0,
                                   0,
                                   0.51330457737087898,
                                   -0.40067128772200844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017869128806117809,
                                   0,
                                   0,
                                   0.31556192400566813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13635658978922807,
                                   -0.11447675679792023,
                                   0,
                                   0,
                                   0.17449221443570298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4767662186700854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30072452640136516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24633262547175974,
                                   0.17361172048533266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08594681885988753,
                                   0,
                                   0,
                                   0,
                                   -0.39207847587089267,
                                   -0.3808859212463519,
                                   0,
                                   0,
                                   -0.11906707296855566,
                                   -0.14756961538739333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21859121314652818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42390973373661794,
                                   0,
                                   0.079805712790924355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088132579514800899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55181608518256453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24903033650154474,
                                   0,
                                   0,
                                   0,
                                   -0.062655230117580063,
                                   0,
                                   -0.11752412218074385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17884962153946435,
                                   -0.089420569830828286,
                                   0,
                                   0,
                                   0,
                                   0.32189794224185359,
                                   -0.12511752462666709,
                                   0,
                                   0,
                                   -0.095737486638725888,
                                   0.058155781005934402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087400634395992466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044271463795992977,
                                   0,
                                   0.1039994495144215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58737189246965871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036557920411966247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67746478678694877,
                                   0,
                                   0,
                                   0,
                                   0.0081550841499089116,
                                   0,
                                   -0.078653684049799819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16797361410409017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045749172163282989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37105163491209014,
                                   0,
                                   -0.24434416253682306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25675359695003885,
                                   -0.35486178368071186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20766727941163474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72753795052035419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075730977616166706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14252109374619037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10094414855195746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16986379456705147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5972079341799631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1627959972182866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036698501078024158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35785664796707589,
                                   -0.32694069398225301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33017090048760206,
                                   0,
                                   0,
                                   0,
                                   0.26182032902092273,
                                   0.23458612892745928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21977055266218887,
                                   0,
                                   0,
                                   -0.57257246296936082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00071808511450710544,
                                   -0.36539975246597678,
                                   0,
                                   0,
                                   -0.19809277043884921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050302476908412955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44004572673652487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12171271212977283,
                                   0.08674971575985832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56276205853224082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52759940986268083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48454876754660586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04593139765230491,
                                   0,
                                   0.57420644855214498,
                                   0,
                                   0,
                                   0.71457489065738478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68133428776744853,
                                   0,
                                   0,
                                   0,
                                   0.24383121702770957,
                                   0.063657579170950815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35327749075120773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78034610560402684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098179605349636156,
                                   0,
                                   0,
                                   -0.17212090553632853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35306457319553208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33694830044774121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40064071104671606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14793084136750279,
                                   0.45617194165567304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24980962745224081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65846157012230333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2877224888432045,
                                   0,
                                   0,
                                   0,
                                   0.47712727092764179,
                                   -0.36945532405233356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030115219180202879,
                                   0,
                                   0,
                                   -0.24316584181773493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060018388084506158,
                                   0.21643633061511156,
                                   0,
                                   0,
                                   -0.33315290824436455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26270958049827331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09865471454226428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018628263640144853,
                                   -0.50249149867821918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13206537488436323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42169742572317148,
                                   0,
                                   -0.10238932069516327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51271275334713251,
                                   0.43720190858811669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11445317522863326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086999689198935276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49297611323191493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21496077002462485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1741393478721682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29834922217062132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49506344382362633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43255675958360901,
                                   -0.061290319032785645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19283342495754474,
                                   0.26430337899332562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36238176270073597,
                                   0.49590756147753068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072477993068523566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55520019265289111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40607151136343528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045067642830923051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029510155989235523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30228959628561525,
                                   0,
                                   0.29195969092493151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042999560999533296,
                                   0.05843550576961673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28780996513292195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086914331598602013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5751648579656039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48252880708530271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40399093850293394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46823086975802103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44421490244452744,
                                   0,
                                   0,
                                   -0.44873881569929869,
                                   0,
                                   0,
                                   1.1286087973031489,
                                   0,
                                   0,
                                   0,
                                   0.0024648699392351703,
                                   -0.0053842144486530852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64765131628880479,
                                   0,
                                   0.14002861311118553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25895952196060129,
                                   0,
                                   0,
                                   0.62104524281468132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39294334659471108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065775801953872864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44288838561864879,
                                   0.4079412486082013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092380124021225501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13195291153049865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11890814783599882,
                                   0,
                                   0,
                                   0,
                                   -0.296727401478319,
                                   -0.33420296649149434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32643603665035326,
                                   0,
                                   0,
                                   -0.075296938228518309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21253201413563227,
                                   -0.36012328669207871,
                                   0,
                                   0,
                                   0.37612572597307803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34262702142033719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40170116092796443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021984599054591422,
                                   -0.27986129129405435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68742654568006212,
                                   0,
                                   0,
                                   0,
                                   -0.088862016173753611,
                                   -0.25832312212624375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10696070489765473,
                                   0,
                                   0,
                                   0.23719515500188063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027924701614487624,
                                   0.48319242303877025,
                                   0,
                                   0,
                                   -0.055253541157621225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24131806936801337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2653800770237687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10918838421274107,
                                   -0.08499739653580464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041369235385888346,
                                   0,
                                   0,
                                   -0.1864546497798189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40587106518720517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012938193396096448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00011585702979691193,
                                   0.150884395678508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1950285362259021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85896582429685919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41394110399050787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22456090766283038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43578721613750759,
                                   -0.40287044360732788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23781100656457935,
                                   -0.9440097671257841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65528670708851011,
                                   0.48190459819944476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037425146494910522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12203561719746735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54004366596237896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43018269008306148,
                                   0,
                                   0,
                                   0,
                                   0.16679773219401958,
                                   0,
                                   0,
                                   0,
                                   0.28385896051501358,
                                   0.28982533053923426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26672595896335416,
                                   0,
                                   0,
                                   0.28859061054194524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21669554503867261,
                                   -0.27242234618943656,
                                   0,
                                   0,
                                   0.45365694641493898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23318199890014282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24368346248852812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2390530876032485,
                                   -0.3940802392947404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15899055484608748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25792250065407107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85424308680322503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31648418159805208,
                                   0,
                                   0.22910633444680431,
                                   0,
                                   0,
                                   0.26573514824672245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69941877317045242,
                                   0,
                                   0,
                                   0,
                                   0.36460357679231786,
                                   -0.029128920179801281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48810936369137631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75728742895583812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16454632380180306,
                                   0,
                                   0,
                                   -0.095309471801348578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53587183714051456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81204417484202518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17033360593968713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35407836298107864,
                                   -0.19952697427097874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34192682418537362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1716807126678172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036337294532318147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023891445075950812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079767573779126855,
                                   0.82557006135750766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23687217649348052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50405513571934635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27867894918317587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61754413147884435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53374020486746443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44897944690531905,
                                   0,
                                   0,
                                   0.11047268740377356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20823392068677751,
                                   0.036623044025951478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44295856996878208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70690969099900869,
                                   0,
                                   0,
                                   0,
                                   -0.13016777207403873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32394332248339014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21108386643508112,
                                   0,
                                   0.15097242201731104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11904302257282298,
                                   0.064168085321401655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12028646310274994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2624626544633526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10299043698735844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56534184319563741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62916528875166955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12452752038913602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38097961197869573,
                                   0,
                                   -0.31164498869341661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19801736674304088,
                                   -0.30470566288179768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26738174967359718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23453600655407963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45598441726105721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38521498262283604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3568695901441099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018293588278669545,
                                   0,
                                   0,
                                   0,
                                   -0.12049839189176856,
                                   -0.05813313241945741,
                                   0,
                                   0,
                                   0.27748386463492303,
                                   0.27512572829822735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089688555848455143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18863465934943505,
                                   0,
                                   -0.14109392569979384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11357324410969137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41834104217866763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32090700650835913,
                                   0,
                                   0,
                                   0,
                                   0.081214512729484184,
                                   0,
                                   0.16353885599148094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66431153933294496,
                                   0,
                                   0,
                                   0,
                                   0.06159684129564745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54112410512932696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24232365807663797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28510444611681329,
                                   0,
                                   0.016246059557991598,
                                   0,
                                   0,
                                   0.24732225203827704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36108113566354094,
                                   0,
                                   0,
                                   0,
                                   0.18309329587882728,
                                   -1.244278246980121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47048229981357881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21858411822778162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052898250952202436,
                                   0,
                                   0,
                                   0.88919297023006205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36373447087143895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50195744215812921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52226632856374577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50489766658099977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0619809051217904,
                                   0,
                                   0,
                                   0.51988913882139187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63518440488896133,
                                   -0.19534178882276396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046814307026459362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55533852621321744,
                                   0,
                                   0,
                                   0,
                                   0.25033290309112866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33174876930638891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24745954428775474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31910969153229729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45561012673351931,
                                   0,
                                   0.43163461368819556,
                                   0,
                                   0,
                                   0.31573684323328122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29581820020136684,
                                   0,
                                   0,
                                   0,
                                   -0.75584358228113591,
                                   0.062985241539432468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10185702928966421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5512278011480064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10493229682702579,
                                   0,
                                   0,
                                   0.3163620880721475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080925808181904202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62115017126516225,
                                   0,
                                   0,
                                   0.31867561619507334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3690835738615903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29613237062624093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48232996318789773,
                                   -0.059831831423785009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15871829111383734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16518993183099595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054973180110405105,
                                   0,
                                   0,
                                   0,
                                   -0.26623154979374253,
                                   -0.080232606523239075,
                                   0,
                                   0,
                                   -0.28065278223926943,
                                   0.40318463218700473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28545205671488305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10910183890087712,
                                   0,
                                   0.51154557417134328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01240669289696919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43582662632017272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11983427299215368,
                                   0,
                                   0,
                                   0,
                                   -0.0214468833409035,
                                   0,
                                   -0.32250235556281015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11977429041336585,
                                   0,
                                   0,
                                   0,
                                   -0.59921334727188846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084800301543564646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076765665917929077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18180201241152458,
                                   0,
                                   -0.041817424390701727,
                                   0,
                                   0,
                                   0.50206490320183528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21723788259305826,
                                   0,
                                   0,
                                   0,
                                   -0.50494669015615512,
                                   -0.39775044415827404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72381456078971795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20878522519381948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25360802971998214,
                                   0,
                                   0,
                                   0.60986457451269915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82931723668412682,
                                   0,
                                   0,
                                   0,
                                   0.3039842028412475,
                                   0,
                                   0,
                                   0,
                                   -0.016793523551649019,
                                   -0.22888805953564625,
                                   0,
                                   0,
                                   0.09094429813687771,
                                   0.3962527068384476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21939708700468108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19874696629474556,
                                   0,
                                   0.062131906104596887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056474301011971949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24498765822192456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021329050808212093,
                                   0,
                                   0,
                                   0,
                                   0.72000861553110129,
                                   0,
                                   -0.059231981353383548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11204861078702852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010757690124707432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45821798341147157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52809489570963097,
                                   0.17206077354880128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31679167885185489,
                                   -0.19981347366277807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30493377848366715,
                                   -0.22253323745581441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82373563144668949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11437405247608984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51869843101908586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14137241772626247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67818991523200245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38570661567731823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25160800214661999,
                                   0.096896986073354091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41227573675290535,
                                   0.56180282157785399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22060348509810793,
                                   0.17859973163709975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3240462957797553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29603337685228082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078311393922140732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48973012457603038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77120461027288945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08420820860740337,
                                   0,
                                   -0.047724847046818411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032332868905541788,
                                   0.37751197046039742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39957366472889788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12267347115232101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22216667740794976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11654634092458925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12109949304574094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25124452990341872,
                                   0,
                                   0,
                                   0,
                                   -0.10113568594655639,
                                   -0.37288925037456727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43973135370414029,
                                   0,
                                   0,
                                   -0.273927101913432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17936229276162777,
                                   -0.12152542202626508,
                                   0,
                                   0,
                                   0.25471085497998747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30036130261437771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30588279998093054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45476828593431085,
                                   -0.12957381043882935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26080050128764753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64390757030087709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83397440225493236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14145023300674972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011843075447234175,
                                   0.51392947342083828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43699927997388061,
                                   0,
                                   0,
                                   -0.0050811031235016568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36968930952718582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34490112882328133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040185719452342533,
                                   -0.74161575019900017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023392525097962798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034968760765993701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37793109914350981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080705079157441642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43750374303328377,
                                   0.12050853652999899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6849766782286858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41896287691922024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0043472783909852195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41479270604273183,
                                   0,
                                   0.35824754504872769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58264577992622113,
                                   -0.25513166618978939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057065783951971677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36054010895423927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15565757290958521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0035201811701342086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3708519801078673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13094170376143607,
                                   0,
                                   0,
                                   0,
                                   -0.53642774512829972,
                                   0.29967280113570532,
                                   0,
                                   0,
                                   0.24452468038268649,
                                   0.07597173712404659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3146811767709175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1528132625020551,
                                   0,
                                   -0.30758469780040637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53584560126231207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07787288524310497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054482591672355057,
                                   0,
                                   0,
                                   0,
                                   0.15204600103431734,
                                   0,
                                   -0.055933535421494922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018375412482835869,
                                   0,
                                   0,
                                   0,
                                   0.51567354474093929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18578000708822068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40833158052102198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40903980585448257,
                                   0,
                                   -0.26311127929864497,
                                   0,
                                   0,
                                   -0.071863304360270774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17473525621035879,
                                   0,
                                   0,
                                   0,
                                   0.19045940075949669,
                                   -0.17734362676734031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10203009679819276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11352966783653429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0498020569236532,
                                   0,
                                   0,
                                   -0.051611111962401875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054316778965163681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43852482993156572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6000663945354564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24535126524246553,
                                   -0.027849808032084394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78108305637758746,
                                   0.77884720127147389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16776626259246114,
                                   -0.4312519358979956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44558552410662128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38065896824769224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26767994981981269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13012433374696747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62108734296482548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48169061060063106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040429356010984754,
                                   0.097121788158863492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34581110194719211,
                                   -0.33898910341711119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82883463863550122,
                                   -0.14952869165139329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19655680498420466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27816815614633145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19598660643877752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3570404320330548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20854071101759608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10670599688450885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46373752286393155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25601974421526469,
                                   0,
                                   0,
                                   -0.61526666609855329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66259178041129196,
                                   0.32960371893246421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66850086383358054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2215694281576098,
                                   0,
                                   0,
                                   0,
                                   0.093468781393155329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18477413219708613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82383899431036489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46873482022042834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38136815346452746,
                                   0,
                                   0.4525957358283022,
                                   0,
                                   0,
                                   -0.46163723590792111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31359213367483529,
                                   0,
                                   0,
                                   0,
                                   0.088914053416393315,
                                   0.0017602149928619554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098769762922624793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29045411829350609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44988600829543901,
                                   0,
                                   0,
                                   0.3983012554815259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46988568106139716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47398031210587188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60426101097783691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57266177705549848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43996871777334856,
                                   0,
                                   -0.51140322489211221,
                                   0,
                                   0,
                                   -0.25538543988351842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35705914012972095,
                                   0,
                                   0,
                                   0,
                                   -0.34790293109400322,
                                   0.60956361937702885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13886640654961768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042958312926447056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39896727684505046,
                                   0,
                                   0,
                                   0.2384542304914698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57999470831104749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3859958017093032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18249505913531638,
                                   0,
                                   0.32396050300781498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18060048022726422,
                                   0.053357131256638143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72954496610713704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19080665456269122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27363332364603765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055894160118737574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17506136092247809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28795813512193125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8362952092692445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2219068948447302,
                                   0.58432744313625373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084035405016721992,
                                   0.178815264172558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54051288386703811,
                                   -0.14779886278138932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01546658258752151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14901427589376987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32181944766413489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66035682831961073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78339963566632076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12705229902965776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31807205265999799,
                                   -0.14871367568718852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30188871197089756,
                                   -0.036373410924683769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51726396956658305,
                                   -0.61994663011712892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54662980929447902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20461038730520623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51053265205978249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31264377209271699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32807110175458898,
                                   0,
                                   0,
                                   -0.41709955229050472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0076019692499965236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62638778426025954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53314779046970862,
                                   0.1365184692686256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089223093251951477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12301727586810049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11677716468070372,
                                   0,
                                   0,
                                   0.51413923353716073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60764295265087931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30925517632455818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15115108837427887,
                                   -0.23790154355043561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13277740085907849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4001019698000049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25162097616141654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11158512241623415,
                                   0,
                                   0,
                                   0.24774422424757525,
                                   0,
                                   0,
                                   -0.32097798471053407,
                                   0,
                                   0,
                                   0,
                                   -0.31831042864856052,
                                   0.31233822788118926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0099009662433625,
                                   0,
                                   -0.80847545944379329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02138426586208475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73413164923541041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10298811768595467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31450930284471307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61064031014592912,
                                   -0.79061691251515454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18934553779214447,
                                   0,
                                   0,
                                   0,
                                   0.022229682687757865,
                                   0.038062492440286415,
                                   0,
                                   0,
                                   -0.17236377756984356,
                                   0.46641732172588568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048960741497751356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38995985640080044,
                                   0,
                                   -0.56273995154528855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11975311469673555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030811308310747527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042154396566817756,
                                   0,
                                   0,
                                   0,
                                   -0.18170989969026732,
                                   0,
                                   0.14362595850694948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41604666389940198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78082541805808103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24284857086647316,
                                   0,
                                   0,
                                   -0.26883786304123386,
                                   0,
                                   0,
                                   -0.49680083157919303,
                                   0,
                                   0,
                                   0,
                                   -0.500514061412623,
                                   0.75363021611280967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76556338961098347,
                                   0,
                                   -0.37538465412045519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057827236273630504,
                                   0,
                                   0,
                                   -0.18570793286518616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10529080865692789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056008478378093494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069776128904424597,
                                   0.00010391383749984266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94975622471451149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20258298307384875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47798206185996628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05775546358490817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76448065908762297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35772370048340474,
                                   0,
                                   0,
                                   0.34350239252833631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14993959948733143,
                                   0.7492436597118759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59268962077945342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44054600097650654,
                                   0,
                                   0,
                                   0,
                                   -0.39907884032881952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14593476284235701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22876432576270639,
                                   0,
                                   0,
                                   0.9280219159601264,
                                   0,
                                   0,
                                   0.16982799240633298,
                                   0,
                                   0,
                                   0,
                                   -0.45121892234831096,
                                   0.79076708056484735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29665525482231803,
                                   0,
                                   1.0086938508547594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38878936333223835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1174363552299181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07016805537855185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82479331154734647,
                                   0,
                                   0.064869103395047076,
                                   0,
                                   0,
                                   -0.35259474714424971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58929861434453124,
                                   0,
                                   0,
                                   0,
                                   0.29209221638936717,
                                   0.71007902226929498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38761413833039893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21183772713606724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58571579125427975,
                                   0,
                                   0,
                                   0.12283688910184319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039171781983633205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57287463009915873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5245208954276227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77688982844210575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1127602674581708,
                                   0,
                                   0,
                                   -0.041700216379562532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26837351636527929,
                                   -0.13944654218671931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30031493890661842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060555559336806217,
                                   0,
                                   0,
                                   0,
                                   0.14222534894951908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38377496894686369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81003156606518623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48376744573635488,
                                   -0.88655475098647241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27331409217343061,
                                   0.090978451241171071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33621343193965786,
                                   -0.126657904197366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068511689350547231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37986742501277226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16966146327341633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082070951191533154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58473980932450587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69033350726004161,
                                   0,
                                   0,
                                   0.64673133431617091,
                                   0,
                                   0,
                                   0.1994610238080356,
                                   0,
                                   0,
                                   0,
                                   0.54572635482606591,
                                   -0.61201906382545568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66406805310441464,
                                   0,
                                   -0.35829163599808767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18997118126583057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10363486299910393,
                                   0,
                                   0,
                                   -0.51368637282619778,
                                   0,
                                   0,
                                   -0.25298416237655441,
                                   0,
                                   0,
                                   0,
                                   -0.99891416423661039,
                                   -1.0050502272842066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15072210710632783,
                                   0,
                                   0.59707986416429881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085501987890430953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032639038802167508,
                                   0,
                                   0.62521623495773948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42718542526103309,
                                   0.17802455512133167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27791000823679796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25319085348250114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20070581893839068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43907317208928676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11018609625026901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0677606808163302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30990274319765881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18620765318491744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35073253911110053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038044992405434408,
                                   -0.57211089999467379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3960646260268646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060075946623734694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36923311499062034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47331750905210856,
                                   0,
                                   0,
                                   0.66325358976064108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10481272819472495,
                                   0.062122275048076492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23228155118364097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19832946793641329,
                                   0,
                                   0,
                                   0,
                                   0.74938479929258839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20143627784410262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057466341893695962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021215376620382892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76641438706869525,
                                   0,
                                   0,
                                   0.3783005742737513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24092397129488813,
                                   -0.33957547509214719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056262862957952631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85451145982657495,
                                   0,
                                   0,
                                   0,
                                   -0.66480190266040651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19441327450519263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99842567773021429,
                                   0,
                                   0,
                                   -0.38324410316045066,
                                   0,
                                   0,
                                   -0.43273658743193327,
                                   0,
                                   0,
                                   0,
                                   0.012369992587947271,
                                   0.36001727471404976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54242649191284875,
                                   0,
                                   0.45659039345703561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22800819890019755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17470652746357396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5571367462892215,
                                   0.33103871354461156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51879908896618399,
                                   0.38725268350061354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017507608818894734,
                                   -0.69783822405009455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39690895336455861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67815138106971828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011992223836011636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37804498731022407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3085670019830784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22330363965638014,
                                   0,
                                   0,
                                   -0.25936734216660767,
                                   0,
                                   0,
                                   -0.37736343204778733,
                                   0,
                                   0,
                                   0,
                                   0.38896235823068953,
                                   -0.24065199820127028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11638131402728302,
                                   0,
                                   0.57024658650188076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18480184812321476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058959260858936276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077507743148150191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51369065524841806,
                                   0,
                                   0.050425293102948868,
                                   0,
                                   0,
                                   -0.32592032112054742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93885349036421517,
                                   0,
                                   0,
                                   0,
                                   -1.0586451646553336,
                                   0.18841654870134514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33312950678323694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28754661330671755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34134646325522372,
                                   0,
                                   0,
                                   -0.12554647204164074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1497415794861687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47939660317602673,
                                   0,
                                   0,
                                   -0.071825341449223271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16612474983347522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54563504967005116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50757349503314908,
                                   0.42662585500265782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0079744370678092244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00095529568824751984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42300792737014814,
                                   0,
                                   0,
                                   0,
                                   0.049747156983547695,
                                   0.098931477114957353,
                                   0,
                                   0,
                                   -0.34071735863893576,
                                   0.061260671384190925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28964745417929166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56980295944975679,
                                   0,
                                   -0.1946459228245345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14261271284379934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040115079399287601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26096874854488872,
                                   0,
                                   0,
                                   0,
                                   -0.18860654027807394,
                                   0,
                                   -0.24319161957322916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24028297615072053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0035452570363814773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34436819755349135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26612087796499095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55827641679078555,
                                   0,
                                   0,
                                   -0.056030888004470362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52641258596463347,
                                   0.53654682643959561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95927795536141713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23933331880920231,
                                   0,
                                   0,
                                   0,
                                   0.032582904342738563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24580635633269893,
                                   0,
                                   0,
                                   0,
                                   0.0034097536029555307,
                                   -0.24585522177443359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16939470160280554,
                                   0,
                                   0,
                                   0.087976034093358052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34423978819650258,
                                   -0.41116633198819519,
                                   0,
                                   0,
                                   -0.34535597635939058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2124029748144069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50287149034807899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31318278914036735,
                                   0.1994510403912659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32873959690716004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43577211600390597,
                                   0,
                                   0.31335588778000734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24565565679601187,
                                   -0.58344034184610027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050920673153258371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29346373171912904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11467608276275612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15211418136841659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27944317633990062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12673966128092973,
                                   0,
                                   0,
                                   0,
                                   0.26071504490753844,
                                   0.034218983444072176,
                                   0,
                                   0,
                                   0.69617037870930087,
                                   0.1528266195089972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47588006011202816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014600845112647694,
                                   0,
                                   0.22917663449742592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18285951901146169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11887123340532871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13075681125546446,
                                   0,
                                   0,
                                   0,
                                   -0.16847948352855041,
                                   0,
                                   -0.016644980088034812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1850944559689201,
                                   0,
                                   0,
                                   0,
                                   0.18499314676437004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7122635291317515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29459903125558506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18218078254482847,
                                   0,
                                   -0.26185402574076921,
                                   0,
                                   0,
                                   -0.10447122016108569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0065026380883173932,
                                   0,
                                   0,
                                   0,
                                   -0.3173484415422364,
                                   -0.43428212075571665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66294368373325274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58694730194486833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16498746855334348,
                                   0,
                                   0,
                                   -0.35362990048492521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67319049877534098,
                                   0,
                                   0,
                                   0,
                                   0.38559458428059223,
                                   0,
                                   0,
                                   0,
                                   0.02390522984984058,
                                   0.61644436095465516,
                                   0,
                                   0,
                                   -0.010688302256508457,
                                   0.1796188463638948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30227528084030553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26648218304206006,
                                   0,
                                   0.31237050827386237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18532567621179236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26290081492245343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071886086650193998,
                                   0,
                                   0,
                                   0,
                                   -0.1615270022778614,
                                   0,
                                   -0.07064425366634286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19670908891557382,
                                   0,
                                   -0.18700613950043204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7829136949354244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43075919761515424,
                                   -0.22238183248034615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25699189560605468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22588238071426212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40531024762079948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16415998641311572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4277349288752475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055725918164862505,
                                   0,
                                   0.31125925770281881,
                                   0,
                                   0,
                                   -1.1410313258973219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15701578072550451,
                                   0,
                                   0,
                                   0,
                                   0.24727505107402234,
                                   -0.37484917244636073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50747160331989671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19216067665512976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0021517356239974597,
                                   0,
                                   0,
                                   0.020056444594507034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17150917226434051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35197338115086918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35872850098147807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30182585725100342,
                                   0.10045264735444494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50453040661979409,
                                   -0.3802538738628084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10202607673573433,
                                   -0.69517160807597544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058289455303870329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58027087990023496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023336835204631777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72357369217652767,
                                   0,
                                   0,
                                   0,
                                   0.096716597307420452,
                                   0,
                                   0,
                                   0,
                                   0.13236704138909988,
                                   0.30028804963639516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30814782778260619,
                                   0,
                                   0,
                                   -0.30595446031010354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5807946300925928,
                                   0.3507142528438334,
                                   0,
                                   0,
                                   0.27450403214367708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19802042463146657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14267868800977343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23852006160598199,
                                   -0.20555356558979071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33479039608973826,
                                   0,
                                   0,
                                   0,
                                   0.31771800895599955,
                                   0.15369492029934936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5353431373071651,
                                   0,
                                   0,
                                   0.19927738283001109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065773649387302929,
                                   -0.17192877795551445,
                                   0,
                                   0,
                                   -0.12379870715117958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10424648867269667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012075636062494316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59512932667095564,
                                   -0.15046898215181306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35313861037613842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5851603841329035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056622753411316784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75491916097912193,
                                   0,
                                   0,
                                   0.3498176053727251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36885365184171898,
                                   0.16373959392466625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26763240523622955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29865674080958737,
                                   0,
                                   0,
                                   0,
                                   -0.36550428300602844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49534347249931193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4852751634772246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014821022424666336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93726625418106868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39772224448377269,
                                   -0.29684781980371194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055723579435769943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85196145850811067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59760256705892612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18140532304035337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3948363385298141,
                                   0.40217879089255693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12133410410029423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65892084007799911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1934857008171724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091894541542851843,
                                   0,
                                   0.85690364781569384,
                                   0,
                                   0,
                                   0.057835219785728614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31105092883483476,
                                   0,
                                   0,
                                   0,
                                   0.2359815352778328,
                                   -0.033273197991341083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17614473821360266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27674943823133868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48450750052605907,
                                   0,
                                   0,
                                   -0.37886661877469019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6931928085388257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73097804765342644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29461769561403428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92874837161528145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023280924648895251,
                                   0,
                                   0,
                                   0.097542252977164332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5111412404058201,
                                   0.62158025394256833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0025880697320211504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069520056244409198,
                                   0,
                                   0,
                                   0,
                                   0.072171492495367709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19025690067840317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027467158897542449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18314453919463194,
                                   -0.89314039054291183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57526865579170994,
                                   0.18062373064318082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22070257892695572,
                                   -0.08306396599839963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5985642969327547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23910458455945199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45122950381322147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41519603374670544,
                                   0,
                                   -0.13356900479096456,
                                   0,
                                   0,
                                   0,
                                   -0.31543710776198808,
                                   0.1237093960756404,
                                   0,
                                   0,
                                   -0.1397827864773723,
                                   0.15986206963485633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03902849475365508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28426090223702044,
                                   0,
                                   0.30048536598497338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15256211056053978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12455694945659715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27383006172365293,
                                   0,
                                   0,
                                   0,
                                   -0.10992006981928606,
                                   0,
                                   0.70760063782481841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15194430285916105,
                                   -0.22017796296303591,
                                   0,
                                   0.79728109581337647,
                                   -0.12348578432191734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81426378366052188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0549189674284922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062040139747968709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18378052350485941,
                                   0,
                                   0,
                                   0,
                                   0.15782434257866024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033319037588213252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99035465233879971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29939760354908185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22282348912022931,
                                   0,
                                   0,
                                   0,
                                   0.028477592911997446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70815384334873621,
                                   -0.22522949124680436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49826848354918762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1607599557954395,
                                   -0.50165938447748115,
                                   -0.042899041217673933,
                                   0,
                                   0.092899203199369812,
                                   0.49867108010150563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79836435216335888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69520902016556219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27738402446477844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21670668848319052,
                                   0,
                                   0.18790088977726954,
                                   -0.71512312863065119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80053788966652561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73702585551881727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67144608841004239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0071787065703891682,
                                   0,
                                   0,
                                   0.38301311590006759,
                                   0,
                                   0,
                                   0,
                                   0.93417551469002413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11521527926827246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30653653450707474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068964908493127905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037895735575362383,
                                   0.71157471361631641,
                                   0,
                                   0,
                                   -0.14130208811205414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71912708470343956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63603628497331943,
                                   0,
                                   0,
                                   0,
                                   0.23276282785303576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43465986066657686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24529846853792264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016164821198254242,
                                   0,
                                   0,
                                   0,
                                   -0.26027633231994052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046374181418484678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19793212549050071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22152480036967964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81602507448830308,
                                   0,
                                   0,
                                   0,
                                   -0.96810112646145086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13981471655923655,
                                   -0.14775238360958673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64698816049066088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44363096020350312,
                                   0.039970073569477529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49535262601550623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46761445307186861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70999776365288669,
                                   0,
                                   0,
                                   0,
                                   -0.15179248729140671,
                                   0,
                                   0,
                                   0.072456289080697095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059789645928722171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13346754350403778,
                                   0,
                                   0,
                                   0.12689929566364247,
                                   0,
                                   0,
                                   0,
                                   -0.088896326516879953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013310963106235439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5486069415903404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29307965058668467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52400445384470073,
                                   -0.49685252444611988,
                                   0,
                                   0,
                                   -0.34516899820017199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28946284544909162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17996780226430747,
                                   0,
                                   0,
                                   0,
                                   0.024963250270570586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80574174374468532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93312535350109727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18114311250815718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26060559786161264,
                                   0,
                                   -0.46988362209999751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24146202232374905,
                                   -0.34773637397959711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33289429039745227,
                                   0,
                                   0,
                                   0.09476109150270276,
                                   0,
                                   0,
                                   0,
                                   0.042303354513322844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14548204536585718,
                                   0,
                                   0.24657221734863305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38497022928630359,
                                   0,
                                   -0.38406246191107857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25626013823917115,
                                   0.20832793934475252,
                                   0,
                                   0.087340687964219538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070357443961063207,
                                   0,
                                   0,
                                   0,
                                   0.077329076619426035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22493172608068865,
                                   0,
                                   0.50055414278253274,
                                   0,
                                   0,
                                   0,
                                   0.36234794003766641,
                                   0,
                                   0,
                                   -0.40131832908832976,
                                   0,
                                   0.16334375968324219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27617538314418988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38218174029503871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077164484130658323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15459440797721313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043535063522889515,
                                   0.1447744654483083,
                                   0,
                                   0.42319457553313938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18416698471787793,
                                   0,
                                   0,
                                   0,
                                   0.16932910690243119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22597617334047487,
                                   0,
                                   -0.45791550883291965,
                                   0,
                                   0,
                                   0,
                                   0.435217213749093,
                                   0,
                                   0,
                                   -0.10950258482406826,
                                   0,
                                   -0.063784901616530373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07097453061617362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30692372643447152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01686033268924067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4119618346665973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26954854119502752,
                                   0,
                                   0,
                                   -0.29087135307613443,
                                   0,
                                   0,
                                   0,
                                   0.47407069985854711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29729224163951362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0011713857305975309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10626202900884327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032790995488971686,
                                   0.018214933282775125,
                                   0,
                                   0,
                                   -0.15085320124720533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32462776821722583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86878520514436275,
                                   0,
                                   0,
                                   0,
                                   1.1198692102663759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39602497029146316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046431681111043156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28677236692324193,
                                   0.22319800504752677,
                                   0,
                                   0.037702522649577866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09940373009749251,
                                   0,
                                   0,
                                   0,
                                   0.088717762435923594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.422625896536722,
                                   0,
                                   -0.13603397026314329,
                                   0,
                                   0,
                                   0,
                                   -0.23312890937339106,
                                   0,
                                   0,
                                   0.43269550520056899,
                                   0,
                                   0.10670962204352495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42718277405417343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10999615174702773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3641350757125178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26741893393127708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62196371817897389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47659732109220498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97010228767505557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24040036799650735,
                                   0,
                                   0.24673471683546205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61148820400639248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018448080509401082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3724796517805985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0041015996895322,
                                   0,
                                   -0.68512596343348042,
                                   0.47433328612300801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090381406507838005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1210734004728727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2210904609326447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49692319503702809,
                                   0,
                                   0,
                                   0,
                                   -0.10779856223775969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62956008677192909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5734900703148309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83072215726876486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023694490146643068,
                                   0,
                                   0,
                                   0,
                                   -0.030782631166190538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29327501876430961,
                                   0.12240466094431898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16286296444914311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06279350245509617,
                                   -0.63802255192302293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71021544065651598,
                                   0,
                                   0,
                                   0,
                                   0.40408673108840137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90947310298026196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047334873649086229,
                                   0,
                                   0,
                                   -0.25500407711597506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46979607559399311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34386374825160687,
                                   0,
                                   0.12465261476529896,
                                   0,
                                   0,
                                   0.4354670854939231,
                                   0,
                                   0,
                                   0,
                                   0.41129173321830581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21594398900167153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06521983712191215,
                                   0,
                                   0.0864047266060958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21544876960953568,
                                   -0.29405180640227613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20051081588447056,
                                   0,
                                   0,
                                   -0.065380906840143305,
                                   0,
                                   0,
                                   0,
                                   -0.41188086434292581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071416642130604918,
                                   0,
                                   0.023725227652216574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68442710294428433,
                                   0,
                                   -0.34718204645748263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0038907213050671289,
                                   0,
                                   0,
                                   0.76557259866074323,
                                   0,
                                   0,
                                   0,
                                   0.58941840507638776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082583340162169172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098996351434509328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36966393347335935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21052652811817718,
                                   -0.15597597890257137,
                                   0,
                                   0,
                                   0.33585213627941546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42639025964459454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40196708406674375,
                                   0,
                                   0,
                                   0,
                                   0.24496229121747004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23777401374869625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022251767865230566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25337679534280699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43699780962740042,
                                   0,
                                   0.47517606110584343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25362025642808678,
                                   -0.23560368367797374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50431505546793232,
                                   0,
                                   0,
                                   0.17284249576557725,
                                   0,
                                   0,
                                   0,
                                   0.10769601924312859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14474063914375934,
                                   0,
                                   -0.20161675750129321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05190336767204945,
                                   0,
                                   -0.19775927160472104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21351536547257582,
                                   0,
                                   0,
                                   0,
                                   0.028953927913935557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81415149483724814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78046174054595907,
                                   0,
                                   0,
                                   0.3660054732809282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041186564681338578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48244281188569849,
                                   0,
                                   -0.45610421335881046,
                                   0,
                                   0,
                                   -0.02570266904553779,
                                   0,
                                   0,
                                   0,
                                   0.20185328445748985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076881861158093895,
                                   0.27358384748760373,
                                   0,
                                   0.0019733516434648317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11826556426513371,
                                   0,
                                   0,
                                   0,
                                   -0.22075733776818082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39728229735511067,
                                   0,
                                   0.2370106296154256,
                                   0,
                                   0,
                                   0,
                                   0.04109893310431223,
                                   0,
                                   0,
                                   0.60687345316790053,
                                   0,
                                   -0.12582208123104222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17243878502927021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44392378392630732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064770810337779705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16029638334332247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061504074069441139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33004844003701106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17173777341568192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40555508072795493,
                                   0,
                                   1.1213909720348514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56583688802196419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65062290040768656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12472785715292797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1660555811108187,
                                   0,
                                   0,
                                   0,
                                   -0.61445361946941868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24326610156631881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22812295068492228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10605252412078768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36712867432141516,
                                   0,
                                   0,
                                   0,
                                   0.063636694143430914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0083259357416748288,
                                   -0.65101770430389638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22832955574169581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81621271883440838,
                                   -0.023736925042642007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48276715606967668,
                                   0,
                                   0,
                                   0.38957030110451679,
                                   0,
                                   0,
                                   0,
                                   -0.13578190907235088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42954044782289369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6186533708052343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82459603519152447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13543231160103147,
                                   -0.30572493971681758,
                                   0,
                                   0,
                                   -0.15735079183097131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72423453472446464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40728623544233222,
                                   0,
                                   0,
                                   0,
                                   0.11302483805848577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4639225319217789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079957041729420433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078147811701721484,
                                   -0.04311409108952996,
                                   0,
                                   0.38582411604048317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46804907110474231,
                                   0,
                                   0,
                                   0,
                                   0.45693774829471073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29840335398216072,
                                   0,
                                   0.1423088064501612,
                                   0,
                                   0,
                                   0,
                                   0.030848240213703419,
                                   0,
                                   0,
                                   0.21111382336792064,
                                   0,
                                   0.27478682853636682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18638656170283974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37521254860433062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094122064407237915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024568634829557949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012897229225521001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50280600787820384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074582335197350219,
                                   0.55174505372629534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31007636549501727,
                                   0,
                                   -0.27036052728248117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19356719713844692,
                                   0.036878083700790626,
                                   0,
                                   -0.46338500895469953,
                                   0,
                                   0,
                                   -0.11932545555949771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41999504075126215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38748662469899237,
                                   0,
                                   0.10835121518812534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38669560142818038,
                                   0,
                                   0,
                                   0.51356523691482936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089226357282574414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017144903057940669,
                                   0,
                                   0,
                                   0.49008189552860826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62909659838387399,
                                   0,
                                   0,
                                   0,
                                   -0.34415005601891485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56984221138756741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89853748918097731,
                                   0,
                                   0,
                                   -0.77726979985406919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.004082388174523624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07185002191673788,
                                   0,
                                   -0.30123911058791109,
                                   0,
                                   0,
                                   -0.58238978238943961,
                                   0,
                                   0,
                                   0,
                                   0.091940918301347069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63811328061705019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2502847560134169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17763502047743163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46469065716167712,
                                   0,
                                   -0.52218461470715261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18712891685259436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1328313836504329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48216779099499518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98354609151928907,
                                   0,
                                   0,
                                   0.12332940742589468,
                                   0,
                                   0,
                                   0,
                                   -0.012323027718034858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56978507904694264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2047713843694875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11841561785253196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085026825671072684,
                                   -0.099907979106163891,
                                   0,
                                   0,
                                   0.82857175038556696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23755982541666162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70088820152007003,
                                   0,
                                   0,
                                   0,
                                   -0.023950825469427069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095289670188903816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19233250376706523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92918652853454087,
                                   0,
                                   -1.4780781896226705,
                                   -0.05507584156687436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46223634704288452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42726188773271373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25038701149069337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39120167503480535,
                                   0,
                                   0,
                                   0,
                                   0.063766286781940074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32234141613888478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22304108695932698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50559131024712134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28124862787537036,
                                   0,
                                   0,
                                   0,
                                   0.37100729358244672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46870818739221176,
                                   -0.61833334405038276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5981429953260774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07370287362771899,
                                   0.59514147353743374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12173717862405405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33448601474217832,
                                   0,
                                   0.6304730079176144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23300050293195693,
                                   0,
                                   0,
                                   0.49443510845047539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31510106508225827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27295283690577454,
                                   0,
                                   0,
                                   -0.05705881477917743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3745776625778367,
                                   -0.14249569184350058,
                                   0,
                                   -0.059187867285434584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19429633591852066,
                                   0,
                                   0,
                                   0,
                                   -0.22832519300758919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0088991360564667603,
                                   0,
                                   0.32803855484407868,
                                   0,
                                   0,
                                   0,
                                   0.43975475135514658,
                                   0,
                                   0,
                                   0.16892152405279059,
                                   0,
                                   -0.26989916598530839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060142290987971567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43966514998021161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0046290170285754606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38288790967011194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62222276978727309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036802727092815207,
                                   0,
                                   -0.22602166679811814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14471602149363252,
                                   0,
                                   0,
                                   0.048021066977834349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63432767099930665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16651321760898113,
                                   0,
                                   0,
                                   -0.32718739980330847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36203940009630198,
                                   -0.49379084467509471,
                                   0,
                                   0.024324482353835167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40526613758276425,
                                   0,
                                   0,
                                   0,
                                   0.068961961901381999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44197365330706556,
                                   0,
                                   0.090472805250153152,
                                   0,
                                   0,
                                   0,
                                   0.21305671811204638,
                                   0,
                                   0,
                                   0.2346212913313252,
                                   0,
                                   -0.15617547771627802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088439486499290565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28735530261571007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019789116461655567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19070040304283234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28233975418933227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41561074198714015,
                                   0,
                                   0.34403007155118165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39802248510755867,
                                   0.043860714433864537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2924201382501348,
                                   0,
                                   0,
                                   0.52155635276870693,
                                   0,
                                   0,
                                   0,
                                   0.0011299112218292129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27084131371150105,
                                   0,
                                   0.170496691497525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049957292119739906,
                                   0,
                                   0.079986937485732795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19873521022182467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43097418175758018,
                                   0,
                                   0.1941035686206293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2698864378779956,
                                   0.38895258160539387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44681528607274057,
                                   0,
                                   0,
                                   0.44762297801146911,
                                   0,
                                   0,
                                   0,
                                   -0.092570068836023089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26099927494325725,
                                   0,
                                   -0.17701885058065844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020722779515816005,
                                   0,
                                   -0.067092465360443693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050066738771632591,
                                   0,
                                   0,
                                   0,
                                   -0.5070024333863592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2906641473857533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60734672889536623,
                                   0,
                                   0,
                                   -0.64220887650012648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70233096763624858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22528831867695423,
                                   0,
                                   0.085140530892260397,
                                   0,
                                   0,
                                   -0.13454468047216925,
                                   0,
                                   0,
                                   0,
                                   0.12385979208210737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034147594412669492,
                                   -0.10719840076690829,
                                   0,
                                   -0.079661590402125365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20028177040440265,
                                   0,
                                   0,
                                   0,
                                   -0.51688333249125795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14709539154817983,
                                   0,
                                   -0.067084681094659523,
                                   0,
                                   0,
                                   0,
                                   -0.17808711134292377,
                                   0,
                                   0,
                                   -0.09838441037961955,
                                   0,
                                   0.38806865984267241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24986557289641045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11994472657865572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40632594505749114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46223996831032615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27714517435367864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46861083388780922,
                                   0,
                                   0.30492542419651986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5212486813689261,
                                   0,
                                   0,
                                   -0.012373126972579945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47135574541371489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044363835033522245,
                                   0,
                                   0,
                                   -0.3385517001592071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6851360279758949,
                                   0,
                                   0,
                                   0,
                                   0.52328901324028199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050830597370788128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22912497169323567,
                                   0,
                                   0,
                                   -0.2608474917785677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24074263987030878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044981294460207287,
                                   0,
                                   -0.1147027821177498,
                                   0,
                                   0,
                                   1.1083998391309611,
                                   0,
                                   0,
                                   0,
                                   -0.25083152785391305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038327609523965855,
                                   0.18135307536409523,
                                   0,
                                   0.28386219309003252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43814125490481826,
                                   0,
                                   0,
                                   0,
                                   -0.44218745388376374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011155360365487362,
                                   0,
                                   -0.18461851335428545,
                                   0,
                                   0,
                                   0,
                                   0.039185446850675168,
                                   0,
                                   0,
                                   -0.16649076753412681,
                                   0,
                                   -0.4843648526544832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31738773922164826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15846157864349447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20556762831020853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17717586305414332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28374140687371907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039232610347896352,
                                   0,
                                   -0.43923496357668129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22507288059626043,
                                   0,
                                   0,
                                   0.67152024454982329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1731403901688916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40472781878809716,
                                   0,
                                   0,
                                   -0.17217671344709881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36441494364693661,
                                   0.18095022471771943,
                                   0,
                                   0.52633182006187729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37874420805260084,
                                   0,
                                   0,
                                   0,
                                   -0.091985715151143496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2557106224103165,
                                   0,
                                   0.24732388630550137,
                                   0,
                                   0,
                                   0,
                                   -0.1969985988210031,
                                   0,
                                   0,
                                   0.12892023042045775,
                                   0,
                                   -0.10355461569963316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060294000821856417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12956182556486209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43855626573906442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0078957302495984288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3124255079001006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31335729762004583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33119523694464853,
                                   0.1151777992498933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54271191403080188,
                                   0,
                                   -0.0085616912216841812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18866105884481404,
                                   0.10101408919131644,
                                   0,
                                   -0.1421959833241242,
                                   0,
                                   0,
                                   0.56622895760115466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42968071973179428,
                                   0,
                                   0,
                                   -0.90512388240660524,
                                   0,
                                   0,
                                   0,
                                   -0.057733421444970956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23209412852943972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24807713144171126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081126238358161296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17881315557437677,
                                   -0.74813333772180424,
                                   0,
                                   0,
                                   0.39142202117069647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16271212815064703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81080690763513052,
                                   0,
                                   0,
                                   0,
                                   0.072492364420089703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33643179312320698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48341474911742033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52468078829688491,
                                   0,
                                   0,
                                   0.40833711487401469,
                                   0,
                                   0,
                                   0,
                                   -0.29911789300568492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053511459968552597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71391214405326686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37590935784550039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94262476329399947,
                                   -0.69276333150671532,
                                   0,
                                   0,
                                   -0.14119581489396979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15532572846993281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18472604566769676,
                                   0,
                                   0,
                                   0,
                                   0.25439268116638886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19789356772212885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17719935986683633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058067495336315611,
                                   0,
                                   0,
                                   0,
                                   0.3035573320826499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1400743695721629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51351153289993756,
                                   0,
                                   0,
                                   0.41467924092928177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44362818070970655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67417559415151407,
                                   0,
                                   0.16305338524906837,
                                   0,
                                   0,
                                   0.0026435459003718229,
                                   0,
                                   0,
                                   0,
                                   0.12343401544001226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21304324069952385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14825084899294189,
                                   0,
                                   0.37376896653465191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40946608901849324,
                                   -0.27580908800941684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098747642698044522,
                                   0,
                                   0,
                                   -0.024578179358804481,
                                   0,
                                   0,
                                   0,
                                   0.52536368608586481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070616305520714379,
                                   0,
                                   0.42257252854704946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046888523796812916,
                                   0,
                                   -0.27763819493617925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23509936532558057,
                                   0,
                                   0,
                                   -0.27344021179736755,
                                   0,
                                   0,
                                   0,
                                   0.75930405719336225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59558019087278558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30914553726580857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45847340266313996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76704757350031205,
                                   -0.75903596408170038,
                                   0,
                                   0,
                                   -0.2980074059939492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38483479105743401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073441116904657766,
                                   0,
                                   0,
                                   0,
                                   -0.21228627524712623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23128854031474241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43759193914964395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54912353792500412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59424527491497625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1257506123298181,
                                   0,
                                   0,
                                   0,
                                   -0.32990459828479396,
                                   0,
                                   0,
                                   0.46963014724261609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01153939634707583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2692752934990858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22827804289294812,
                                   0,
                                   0.11329986537188763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21158095061817545,
                                   0.51141104437570906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12976813834066611,
                                   0,
                                   0,
                                   -0.41086991688824798,
                                   0,
                                   0,
                                   0,
                                   0.16038761405319535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27627448196187132,
                                   0,
                                   -0.13749761660387649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046009965642540687,
                                   0,
                                   -0.49750094573719739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47848730251032184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2709580087900324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018139281513961145,
                                   0.13711697488052224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3940152474083044,
                                   0,
                                   -0.033095802206033226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42915661919320713,
                                   -0.098005820224520521,
                                   0,
                                   -0.51226165116743638,
                                   0,
                                   0,
                                   -0.25683782686513718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14865528619140023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14844380438799756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5429149398991715,
                                   -0.32509460258544137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14340314456229275,
                                   0,
                                   0.13906075730865072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20950790007049408,
                                   0.57261876875489293,
                                   0,
                                   -0.2445008253721481,
                                   0,
                                   0,
                                   0.28974831493327979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014022333859263526,
                                   0,
                                   0,
                                   -0.18676521756067674,
                                   0,
                                   0,
                                   0,
                                   0.16800219967259356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93140441683781428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87498358520033148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022887910136950906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47326394614460693,
                                   -0.075993567580024957,
                                   0,
                                   0,
                                   -0.12655809142232335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021059279356010152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33681328559611723,
                                   0,
                                   0,
                                   0,
                                   -0.38698053649080022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33580180788879338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015702949130048424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1220602046768743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13079314978921189,
                                   0,
                                   0.42331794002488288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043188424632270697,
                                   -0.33321911594795217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31161325956911851,
                                   0,
                                   0,
                                   -0.38170465360323658,
                                   0,
                                   0,
                                   0,
                                   -0.33447911124851543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2357801310036948,
                                   0,
                                   -0.19659232585120223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43233643118764947,
                                   0,
                                   0.20015747881396423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53293194402619004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061325019773990741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89640222972769656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41773851644438847,
                                   0,
                                   0.23736835182952262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41752983913029396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47430674301608894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.954998660680348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038752318625203321,
                                   0.2038593440734647,
                                   0,
                                   -0.011340812191784929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16693398801944828,
                                   0,
                                   0,
                                   0,
                                   0.20448583479678026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12377109832147773,
                                   0,
                                   0.3690755182288481,
                                   0,
                                   0,
                                   0,
                                   -0.45349552537043314,
                                   0,
                                   0,
                                   -0.28660999344725624,
                                   0,
                                   -0.32472714971177064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2139322871630373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097668263044075221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18040310242454602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50447099182579103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37220440355662021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6480268287036427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86132505016039351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075234187381161902,
                                   0,
                                   -0.095555356017729715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93646482204055725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12935965303756983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015863485020015236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37372147508860953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56735704922115848,
                                   0,
                                   0.28888849581479376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12113763265456454,
                                   0,
                                   0,
                                   -0.072919345898658963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34408996509694117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56266054399895216,
                                   0,
                                   0,
                                   0.0023077776037419076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3856141759862548,
                                   0,
                                   0,
                                   0,
                                   -0.14056880243343939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19669809727952808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58940447067110524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32695069141676636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15873303151081034,
                                   0,
                                   0,
                                   0,
                                   0.46386847496379863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34550985276876756,
                                   0.37286855928357432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45272181714651322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21020456306910323,
                                   -0.093731257936010032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58344854924282619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10043415783869403,
                                   0,
                                   -0.024030916825535181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46495200840818895,
                                   0.18747524085157655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25887623051836994,
                                   0,
                                   0,
                                   0.11515490203522251,
                                   0,
                                   0,
                                   0,
                                   -0.017350495114784873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42859023650728562,
                                   0,
                                   0.34516831116856489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086726831939663906,
                                   0,
                                   0.081639807652535756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46592060680475289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26536792832701672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33341633010042043,
                                   0,
                                   0,
                                   0,
                                   -0.72137983780890524,
                                   0,
                                   0,
                                   0.28449965606262284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0015738155967425713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40738602754027931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26116813174959991,
                                   0,
                                   0.12631011753664401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21735315030194738,
                                   0.1882102785884005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049393506013850966,
                                   0,
                                   0,
                                   -0.20393686491083401,
                                   0,
                                   0,
                                   0,
                                   0.12223327799269008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69302431613951221,
                                   0,
                                   -0.052228576480561825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29040146075204742,
                                   0,
                                   -0.20222168997207729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68597279935008126,
                                   0,
                                   0,
                                   0,
                                   0.30346810199735602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18464662872445151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45633921471442312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22765706574914932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76754726198514456,
                                   0,
                                   0,
                                   0,
                                   -0.013480165978474012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11010268014447956,
                                   -0.065395967099032865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26448282938420065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2099563099450952,
                                   -0.41777660187043031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12964538595677191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18665219034890829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7171594948095753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11337745962703877,
                                   0,
                                   -0.094324689391931157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93420466160982285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48784944630471216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39307210698510792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14819115403403502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2998759958310791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3377213363528343,
                                   0,
                                   0,
                                   0,
                                   0.042675452515230375,
                                   0,
                                   0,
                                   -0.24589366345056457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84366650993737813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40465514814302761,
                                   0.0010222860077082618,
                                   0,
                                   -0.17290755132530464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099487117763188707,
                                   0,
                                   0,
                                   0,
                                   0.30350844211992667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1089293229608474,
                                   0,
                                   -0.26421725354978759,
                                   0,
                                   0,
                                   0,
                                   -0.12030524866937829,
                                   0,
                                   0,
                                   0.01494436338586963,
                                   0,
                                   -0.44746886484464876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086998937845063976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080717353819082266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62526448182058625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051960357143637607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38120070957574137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19123278716154579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30346698615933293,
                                   -0.45680729457066699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41482193224200548,
                                   0,
                                   -0.25871064816960276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22644027513869691,
                                   -0.1373137527152278,
                                   0,
                                   -0.21649940826153766,
                                   0,
                                   0,
                                   -0.40167179445316892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46103363515970652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40425437047834811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48018951752172456,
                                   0,
                                   0,
                                   0,
                                   -0.45412233057866774,
                                   0,
                                   0,
                                   -0.20866877330903616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3790444174214081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15299717694967321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3894642483819572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45066641080119224,
                                   -0.34180178163326719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33336892655090555,
                                   0,
                                   -0.38588552361766204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10041058131466303,
                                   0.16197219279698036,
                                   0,
                                   -0.43256420760612491,
                                   0,
                                   0,
                                   0.14666029802539735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80648118163789251,
                                   0,
                                   0,
                                   0.042027500061222349,
                                   0,
                                   0,
                                   0,
                                   -0.39311413824150021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056540654573947316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25896488832266717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21705456804737977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64326010804348943,
                                   0.26385582503370447,
                                   0,
                                   0,
                                   0.52662490441588861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058227628008223113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13268430811639079,
                                   0,
                                   0,
                                   0,
                                   0.59874628637248062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41809370807083052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48570730942686763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12153517275429986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075417919432211711,
                                   0,
                                   -0.10849308577562021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3294533336939855,
                                   -0.18392859893433663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3001929644834061,
                                   0,
                                   0,
                                   -0.05002168765190957,
                                   0,
                                   0,
                                   0,
                                   0.61607296301628645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10211195462502648,
                                   0,
                                   -0.40346286461249897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25869530090252491,
                                   0,
                                   0.33631099734425818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18971767627462938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67549972712305784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029297633207122194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79430718545124845,
                                   0,
                                   -0.1812195751774569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073163067659810815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55565831314772929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8701158007936004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28844837056489914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4507918284456221,
                                   0,
                                   -0.17285187812165037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11592074483398446,
                                   -0.17563965274531737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16193691532450161,
                                   0,
                                   0,
                                   0.33468507735420278,
                                   0,
                                   0,
                                   0,
                                   0.00052719097028368703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0018652927831968175,
                                   0,
                                   -0.56286072312015756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16652413725175103,
                                   0,
                                   -0.39577225994363602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32009382181741369,
                                   0,
                                   0,
                                   0.33649070140163484,
                                   0,
                                   0,
                                   0,
                                   -0.13874776022225177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085865669133561667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54549297739168956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41546238669607688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063504356333853318,
                                   0.34019308354197264,
                                   0,
                                   0,
                                   -0.17718880042735277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11027355049440565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34786307707491371,
                                   0,
                                   0,
                                   0,
                                   -0.91103880876490806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56441537231664884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37906130994266135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49666757214232393,
                                   0,
                                   -0.025141936362482228,
                                   0.62495208144100156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23712859017597762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3515752059832154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1190238921412812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35129677357568417,
                                   0,
                                   0,
                                   0,
                                   0.35230086164643937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083905008530274869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14669118848116164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0060241939800825609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022932670354950051,
                                   0,
                                   0,
                                   0,
                                   -0.37271271101939429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3512605815795225,
                                   0.26326756828727294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54409104439107658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81558944307192349,
                                   0.4003200501337007,
                                   0,
                                   0.035209900101359777,
                                   0,
                                   0,
                                   0,
                                   -0.0066242714681144016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043614791626441426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088357357562456579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20757881090357275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49737589817871408,
                                   0,
                                   0,
                                   0,
                                   0.46431419026243193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73191946794367668,
                                   0.29506071347153806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1578481486741507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31837230890947776,
                                   0.25109791894577443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1429128642313367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10521805033705789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069443381355297623,
                                   0.20222658791712897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28928497501214451,
                                   0,
                                   -0.45579135514609054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14737631596827191,
                                   0.66446568588712984,
                                   0,
                                   0.35228622797486348,
                                   0,
                                   0,
                                   -0.20979878503347824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44609530748842563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044991173919573912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14225103838609468,
                                   -0.11408329443865209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22278024430321913,
                                   0,
                                   0.32576539067154053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74326282703039359,
                                   0.037562008933343202,
                                   0,
                                   -0.18583553957788931,
                                   0,
                                   0,
                                   0.14691802330734338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23113707163011021,
                                   0,
                                   0,
                                   0,
                                   0.44516246684705707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20218382515834538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018254537453074732,
                                   0,
                                   0,
                                   -0.055763370766341927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20790571783293638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27805272404285181,
                                   0,
                                   -0.63258628724770605,
                                   0,
                                   0,
                                   -0.13600849625910261,
                                   0,
                                   0,
                                   0,
                                   1.1440517668483106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039662922505668829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37515767869833805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49835499603814049,
                                   0.21133247615660053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10503227508668395,
                                   0,
                                   -0.41225711817273558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1990129529474208,
                                   -0.30824597487449856,
                                   0,
                                   0.024152392225504291,
                                   0,
                                   0,
                                   0.49846932335496624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33246750713027146,
                                   0,
                                   0,
                                   0,
                                   -0.39859822562820402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066528765068019413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067213981456447136,
                                   0,
                                   0,
                                   0.42821309759796922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80017580973434344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64511133972103418,
                                   0,
                                   -0.17098416762998064,
                                   0,
                                   0,
                                   0.030438546856376258,
                                   0,
                                   0,
                                   0,
                                   0.21093669700549175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45291475368785772,
                                   -0.019753957684270726,
                                   0,
                                   0.39784692089733831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17755295167496837,
                                   0,
                                   0,
                                   0,
                                   -0.19315463942738242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30344668612973391,
                                   0,
                                   -0.10766777414244,
                                   0,
                                   0,
                                   0,
                                   -0.15187281988100212,
                                   0,
                                   0,
                                   -0.056857508537706922,
                                   0,
                                   0.20906616280897483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62230322472556177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00057044202809854172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014202675910752707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078865031852571016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51132679964198036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45983563312795822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14509878041152949,
                                   0.36571920390955476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077092537782104384,
                                   0,
                                   0.45468124977906699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.154099753533045,
                                   0.26059081797343187,
                                   0,
                                   -0.22283272474526805,
                                   0,
                                   0,
                                   -0.13529550006486157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0360136961563505,
                                   0,
                                   0,
                                   0,
                                   0.70641934619630609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13642836383344595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26816623377303994,
                                   0,
                                   0,
                                   -0.020513353707708373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13224505253506233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3405161948051747,
                                   0,
                                   0.024276381064709029,
                                   0,
                                   0,
                                   -0.85690507008066974,
                                   0,
                                   0,
                                   0,
                                   -0.88545612498404591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68464056990714972,
                                   0,
                                   0,
                                   0.48302420008518421,
                                   0,
                                   0,
                                   0,
                                   -0.51096016221335194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0074066026424535955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17384492772505258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20447894938107969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37927954230889144,
                                   0.23708931087044471,
                                   0,
                                   0,
                                   0.0034481482686612129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31671747987726645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35671061684165101,
                                   0,
                                   0,
                                   0,
                                   0.35314145612068393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19863212319219467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8471196652451275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35678248513373007,
                                   0,
                                   0,
                                   0,
                                   0.73336577945279602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31261258893361438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64035855999575342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51401634374459582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25826824165301165,
                                   0,
                                   0,
                                   0,
                                   0.026686158110260913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41470732584961478,
                                   -0.38471907331933203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35032378961637428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069327021582912471,
                                   -0.029657559759893121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038658417821298939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32317476728300421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15583913553164827,
                                   0,
                                   0,
                                   0,
                                   0.37374435254282257,
                                   0,
                                   0,
                                   0.76762699665550127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37528883983923628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55496073556420944,
                                   0,
                                   0,
                                   0,
                                   -0.21311886955852702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29834578675193341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40509514114869594,
                                   0,
                                   0,
                                   0.1100722090846271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20519619731007072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17954356322192833,
                                   0,
                                   -0.80042787227954737,
                                   0,
                                   0,
                                   -0.038891334047628623,
                                   0,
                                   0,
                                   0,
                                   -0.8400872562536329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19564934316788879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24410000205848825,
                                   0,
                                   0.25569737456531727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63166606779591072,
                                   0,
                                   0,
                                   0.069341091257533793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039311825423193392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14446618068265876,
                                   0,
                                   0,
                                   -0.64072558169059557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26466979323757606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24967800024627659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071422225956352448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55137906909117718,
                                   0,
                                   0.50877258797054259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21666314960812802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71209894214977087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35763243967274289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23899027385949786,
                                   0,
                                   0,
                                   0.39035437055399963,
                                   0,
                                   0,
                                   0,
                                   0.33400986216201289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73367892244636446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55381014087764913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1587748392523578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18046614188754573,
                                   -0.43292159313664669,
                                   0,
                                   0,
                                   0.15701834621402982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48589101447805016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44466086093046631,
                                   0,
                                   0,
                                   0,
                                   -0.17906916243581231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039234493508634213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23859437279584786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29386733363307649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36606643828979585,
                                   0,
                                   -0.32393429683966202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19799043899634455,
                                   0,
                                   0,
                                   0.16810918189106763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34392037539789855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62789013942858185,
                                   0,
                                   0,
                                   -0.30775925905921597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24695257754246305,
                                   -0.65261611417011767,
                                   0,
                                   0.32655894151823289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26718055625669401,
                                   0,
                                   0,
                                   0,
                                   -0.02574744205809576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26648819254328637,
                                   0,
                                   0.10798119967817654,
                                   0,
                                   0,
                                   0,
                                   -0.26127926038399185,
                                   0,
                                   0,
                                   -0.060504742897547259,
                                   0,
                                   -0.1548324942996103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22997964726044917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24812640190386642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15590596893154393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13067828927100525,
                                   0,
                                   0,
                                   0,
                                   -0.67701474854043053,
                                   0,
                                   0,
                                   0,
                                   -0.29476416325434446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80653151278888968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39993537405506341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20485234006924274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30973256699782964,
                                   0,
                                   0,
                                   0,
                                   0.24830965986939918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21562242170418738,
                                   0.44964095394414666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17023315023614682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27252018449940874,
                                   -0.44836419349206835,
                                   0,
                                   -0.47844439482029516,
                                   0,
                                   0,
                                   0,
                                   -0.69824564298587866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47240792287466549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17197399989858109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056992922464331831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43798290936512907,
                                   0,
                                   0,
                                   0,
                                   -0.067596738198055312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5149069257786687,
                                   -0.24964149012031039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79825469068284327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2534712065470125,
                                   0.6331640340462602,
                                   0.16748320098820141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87367268667023734,
                                   0,
                                   0,
                                   0,
                                   0.70122265583492926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25148222666811554,
                                   0,
                                   0.099339846640522783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29365074937840518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13528595747611638,
                                   0,
                                   0,
                                   -0.42447315664223118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53720837582981429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.242217713091881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060106110950725621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077548619234346347,
                                   0,
                                   0,
                                   0,
                                   0.29800935653908717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52438333044247343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20296379976137524,
                                   0,
                                   0.27176931904847379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33772028616712407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22408903403519254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25759277446658557,
                                   0,
                                   -0.54997402808882634,
                                   0,
                                   0,
                                   0,
                                   -0.24781937585430561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080973451361408127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10813787408209585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62387091708157794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34257661243325516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01137412996348907,
                                   -0.14931797579309986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11462021637720259,
                                   0,
                                   0,
                                   0.096311502363293805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0098490355623819248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26231894707038789,
                                   0,
                                   0,
                                   0,
                                   -0.39722235636615277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053907143620074607,
                                   0,
                                   0.24609647578603547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19899628969625255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049034162631194228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045296710732997153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53830636746176319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88575073285959061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08196850787783036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20216269249552474,
                                   0,
                                   0.10245816118683185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26555839194886166,
                                   0,
                                   -0.067186041075209119,
                                   0,
                                   0,
                                   0,
                                   0.36026111793431215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23277800453151279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02645794245976496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2086163832692709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47310845741812807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49460935602660955,
                                   -0.38144400627897701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27737369929616962,
                                   0,
                                   0,
                                   0.00305163135788733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076519584308232469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99081571624855591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07833150534258243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6134900379916356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10205144244329911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98175785869359156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097929779276904105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24000815093133798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056426384333154112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15630444241312832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35536321277467292,
                                   0,
                                   0,
                                   0,
                                   -0.22535394628684469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20067972043635487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13932483679760149,
                                   0,
                                   -0.35576193527635203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74094452481745332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049644274869392539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31796062559887328,
                                   0,
                                   0,
                                   0,
                                   -0.072577478839423587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18055396207329505,
                                   0,
                                   -0.76484837577751885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27429313245667158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56095683167876986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32996053048767116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17717904917777863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19678169893029054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17833011088034428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37877932638327727,
                                   0,
                                   -0.035918121818857812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20581278703937389,
                                   0,
                                   -0.14454277067089141,
                                   0,
                                   0,
                                   0,
                                   0.38376776527627254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22630657158999926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66822503375608111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027712999010257672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16847471190666286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2712758141068965,
                                   -0.3781387027386387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15959746173498873,
                                   0,
                                   0,
                                   0.13454201902791277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049268012125809557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7185049172202489,
                                   0,
                                   0,
                                   0.71480769033022484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24888628821613826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68432218940700296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45235531429568887,
                                   0.19313508396588208,
                                   -0.17604851567728769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15028766054055104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.427151781844191,
                                   0,
                                   0,
                                   0,
                                   0.1981141475401515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24124946194096109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3907438967187834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068579147637249219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4039002191926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72708856381876685,
                                   0,
                                   0,
                                   -0.30433803262112585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061669738747864244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16830008209859584,
                                   0,
                                   0.89679015508319371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6136821952708843,
                                   0,
                                   0,
                                   0,
                                   -0.427257105895543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047765583601620323,
                                   0,
                                   0,
                                   0,
                                   0.22243729184351388,
                                   0,
                                   -0.49294455761705663,
                                   0,
                                   0,
                                   0.072527171136753887,
                                   0,
                                   0,
                                   0.17888034528318342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55610719225881944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36675358844768347,
                                   -0.035135291166657617,
                                   0,
                                   -0.3359216238212171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37932629878157709,
                                   0,
                                   0,
                                   -0.50630715800737447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49983291932240853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97062737282153133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15768081773808074,
                                   0.15877436501074338,
                                   0.46876718839884984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23366372875253527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61741035077618667,
                                   0,
                                   0,
                                   0,
                                   -0.0090024191078494631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62850830573274574,
                                   0,
                                   0.26721338530757821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21147977426521594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12471435816983791,
                                   0,
                                   0,
                                   0,
                                   0.021768456269049309,
                                   0,
                                   0.40092033814112604,
                                   -0.02727072382900711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068889796119519925,
                                   0,
                                   -0.22361319877942537,
                                   0,
                                   0,
                                   0,
                                   -0.0027502333023320252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25316124439266069,
                                   0,
                                   0,
                                   0.34312262796070497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12605322243346334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24263733400034754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62947962438077232,
                                   0,
                                   0,
                                   0,
                                   -0.19598838747978636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024397380134112849,
                                   0,
                                   0.048736052841899677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12901860128194967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41981134261578107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92749265795513858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010725036704937803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085534993699574444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16984927763744662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43391790227022164,
                                   0,
                                   0.68182029792161525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066207381934534446,
                                   0,
                                   -0.21687365097907019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40790025876252256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30164067693257479,
                                   0,
                                   0,
                                   0,
                                   -0.084967216632516607,
                                   0,
                                   -0.015220921482199824,
                                   0.081900299598958184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1065779809605408,
                                   0,
                                   -0.24806039627104684,
                                   0,
                                   0,
                                   0,
                                   0.28448589286652215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37713004829459246,
                                   0,
                                   0,
                                   -0.34674779422046648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37389001828459778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34781319443335884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092030391172421552,
                                   0,
                                   0,
                                   0,
                                   -0.47418805946690257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54834693545316149,
                                   0,
                                   0.068160788588196214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21427121048804867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18800319698006296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60439720743992253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41519893765638427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13706532598144958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32619362074664782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4403359567131469,
                                   0,
                                   -0.16192397777397727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33102496288787131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74222494276647966,
                                   0,
                                   0,
                                   0,
                                   -0.7123705605450692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043905072031270032,
                                   0,
                                   0.082290575785605113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42133238448919141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17845525679357679,
                                   0,
                                   0,
                                   0.68164849351450285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038382709394379218,
                                   0,
                                   -0.12449169615186334,
                                   0,
                                   0,
                                   0,
                                   -0.19563073064734285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12456454703117635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5305088468563619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079214950918502738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23976837269050577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44297403385909606,
                                   0.29830038430770028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32464133204058043,
                                   0,
                                   0,
                                   -0.21810555797299569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3819243585243387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11256519988317466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073875380262638027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35411801723639852,
                                   -0.79047775441624224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30434280555848114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08311538464514015,
                                   0,
                                   0,
                                   0.15492725655441358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32875779583841891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094204669496912065,
                                   0,
                                   0.32228651735879321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34222534150162093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36537339460787366,
                                   0,
                                   0,
                                   0,
                                   -0.14063713883697956,
                                   0,
                                   -0.0033749784875185818,
                                   -0.16182911559021057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17928592499868432,
                                   0,
                                   0.13429853679908499,
                                   0,
                                   0,
                                   0,
                                   0.31603711812470897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22682575991775716,
                                   0,
                                   0,
                                   -0.31092127953061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10508656473174288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53872418016024792,
                                   0,
                                   0.31454824071838894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25519190132734348,
                                   0,
                                   0,
                                   0,
                                   0.1315093717680603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91875051465885027,
                                   0,
                                   0.086542868776453036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82823393954058466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18325059872399926,
                                   0,
                                   0,
                                   -0.10146000603267552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024881046225522285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083387571571426553,
                                   0,
                                   0.64576752662371273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64893084343414442,
                                   0,
                                   0,
                                   0,
                                   0.28669753091427375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075051966520013572,
                                   0,
                                   0,
                                   0,
                                   0.79299900105133714,
                                   0,
                                   -0.30386232266780161,
                                   0,
                                   0,
                                   -0.024589077704288143,
                                   0,
                                   0,
                                   -0.1375049074321894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42649541561403786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23318236331637782,
                                   0.58645323229848034,
                                   0,
                                   -0.32959941108392793,
                                   0,
                                   0,
                                   -0.67157629301644139,
                                   0,
                                   0.23035112667536844,
                                   0,
                                   0,
                                   0,
                                   -0.20234214938976125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28830702961717225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21712696926236535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17472062753550441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0029520406235611016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26798141329170988,
                                   -0.2088428720361567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13645822805922964,
                                   0,
                                   0,
                                   0.20747473351407031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34217571979628009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27205090750177818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.137570854768789,
                                   0,
                                   0.11576449436676813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64252123896757163,
                                   0,
                                   0,
                                   0,
                                   0.080461994262345002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75739121281665756,
                                   0,
                                   0,
                                   0,
                                   0.0042316934853926444,
                                   0,
                                   0.25433322160198346,
                                   0,
                                   0,
                                   0.45565616987094826,
                                   0,
                                   0,
                                   -0.022904203691539421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64457404055363376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067815744716941406,
                                   -0.003458719341862912,
                                   0,
                                   -0.36000520565748267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093013026396285323,
                                   0,
                                   0,
                                   -0.44911614333720234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30615434268193636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28058657602511866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49701660384457874,
                                   0.61531378356011079,
                                   -0.65915693401662256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27938762472888196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14195661568230458,
                                   0,
                                   0,
                                   0,
                                   0.23681312513684999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90395892065121697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46253443292429608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84061486452246403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60997310267246341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066392450581527179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69786525278946909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18670651329475829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071019764222016613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95714667265116526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.008844710784861147,
                                   0,
                                   0,
                                   0,
                                   0.06576520726759133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094928985151150683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03225216143568347,
                                   0,
                                   -0.058854978042780837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15443016992295777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10545579053710949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094203655454606183,
                                   0,
                                   -0.28065316455625067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2656458898992114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28265557890325438,
                                   0,
                                   0,
                                   0,
                                   -0.52369969221671397,
                                   0,
                                   0.24398370886525469,
                                   -0.31321269496301901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28891733315155399,
                                   0,
                                   -0.38851716409920473,
                                   0,
                                   0,
                                   0,
                                   -0.13615679391585439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089598658365385705,
                                   0,
                                   0,
                                   -0.24393293380379705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097284071217265178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0072853483376166903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33965480593388658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23535354914530118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21096001789002042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42592400750093884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11840053713725443,
                                   0,
                                   0,
                                   0.76766479872566507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40739945333775862,
                                   0,
                                   0,
                                   0,
                                   -0.18139346963253358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26306808123742431,
                                   0,
                                   0.47704861534179366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12646963825348054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42357035742152782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23648562924596231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14793137824127875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054289139880982731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83818908755961485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14247441982250336,
                                   0,
                                   -0.61223501578761008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18616902012100323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027247977668427154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41615267088686853,
                                   0.19272017928674881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33532721985863245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5719781176969605,
                                   0,
                                   0,
                                   0.542310665760386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14342371132356063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24906580761983943,
                                   0,
                                   0.22102674689610913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43347960663908663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010666615392825873,
                                   0,
                                   0,
                                   0,
                                   -0.24124580071873131,
                                   0,
                                   -0.24091256558370563,
                                   0.39866991483499004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033203065874053583,
                                   0,
                                   0.28807295840532948,
                                   0,
                                   0,
                                   0,
                                   -0.10029112309829782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38394846115526782,
                                   0,
                                   0,
                                   -0.33705977000825071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14653005019951376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2219806425052811,
                                   0,
                                   0,
                                   -0.64383250301317019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19393486275778618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12031166538838813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11484030806381079,
                                   0,
                                   0,
                                   0,
                                   -0.58655127050513522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15405495714952794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24272033562179116,
                                   0,
                                   -0.30043177130184834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053631249871702036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0195381585094479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23910768687456049,
                                   0,
                                   0.20234926872080838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024703154162497836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32200673377016997,
                                   0,
                                   0,
                                   0,
                                   -0.39160510695474704,
                                   0,
                                   0.22638357103658274,
                                   -0.29728295292990958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039426001439034124,
                                   0,
                                   0.41842451650578583,
                                   0,
                                   0,
                                   0,
                                   -0.15115880706559651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26850764636809649,
                                   0,
                                   0,
                                   -0.099214141370657677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47129591698701478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032563108650050972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3655507339072751,
                                   0,
                                   0.38553700029839455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18636072989410096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025758442448829348,
                                   0,
                                   0,
                                   0,
                                   -0.028753835826799131,
                                   0,
                                   -0.13083313844849284,
                                   -0.015560458533467205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0093206709762065718,
                                   0,
                                   -0.17144879641569913,
                                   0,
                                   0,
                                   0,
                                   -0.67350904003091094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33354362189319015,
                                   0,
                                   0,
                                   0.14979185246800883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21205226075744446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049017777478722185,
                                   0,
                                   0,
                                   0,
                                   0.42174684669064016,
                                   0,
                                   -0.1709479582373874,
                                   0,
                                   0,
                                   0,
                                   -0.20657993446584894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10334697885753381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19234087853531939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044745308019215682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32657040370992829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10045688100023542,
                                   -0.053586043313930617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17246753042073576,
                                   0,
                                   0,
                                   0.5481935260838976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50068043772977167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16458859994554967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2350866004853385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088183035647735386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054036878106572254,
                                   0,
                                   0,
                                   0,
                                   -0.35936481700736217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58240497171546968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39724951842437256,
                                   0,
                                   0.19225312294886654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30324489278732825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38972313263833536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43598091237519448,
                                   0,
                                   0,
                                   0,
                                   -0.13553455525112623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51969071110002407,
                                   0,
                                   0.25591349524712442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10641542556038719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20351925855978847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31709056745073549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70866431130684049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69542222195110959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081477421380870718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48103809382746077,
                                   0,
                                   0.37483992919780507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079805091654361018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018829062377507776,
                                   0,
                                   -0.22168582875468529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86525290526490306,
                                   0,
                                   0,
                                   0,
                                   1.0793349400490511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26162742684864848,
                                   0,
                                   0,
                                   0,
                                   0.12821002003896209,
                                   0,
                                   -0.1711632442763375,
                                   0,
                                   0,
                                   -0.18606541295080256,
                                   0,
                                   0,
                                   -0.60210780163185662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39519990083436024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18764466983609546,
                                   0.39332566051220069,
                                   0,
                                   -0.10018479569802724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29369387884495085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45928200674569375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52742619979283811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4856174759351059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38294144580671746,
                                   0,
                                   0,
                                   -0.20532185400151146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055034716584345569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055859890176115728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72519650109996103,
                                   -0.42564032950854253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15703208685449901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0057248820361143413,
                                   0,
                                   0,
                                   -0.47208333124805457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1980320052662165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83242191872051785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50922173692530004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070279510902686734,
                                   0.10598414978552996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08893946525678699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1189715669058575,
                                   0,
                                   0,
                                   -0.039866770794523387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089113975291017097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26714235556865418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88471201225615892,
                                   0,
                                   -0.45503727571313529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1888006374813356,
                                   0,
                                   0,
                                   0,
                                   0.01995957347165369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66035370247269753,
                                   0,
                                   0,
                                   0,
                                   0.18096164433383857,
                                   0,
                                   -0.13208465649863649,
                                   0,
                                   0,
                                   -0.40117451423487421,
                                   0,
                                   0,
                                   0.39646257481258634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14098325926355826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71673214963705922,
                                   0.31615026428984999,
                                   0,
                                   0.028199693278970588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31309045944358138,
                                   0,
                                   0.18864127727790062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08047723674900982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19336575010879392,
                                   0,
                                   0,
                                   0,
                                   0.046061921112727243,
                                   0,
                                   0.62226462915620528,
                                   0.20067466912467175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25553185200630529,
                                   0,
                                   0.023826925457955499,
                                   0,
                                   0,
                                   0,
                                   -0.13279235317837809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18323917910285331,
                                   0,
                                   0,
                                   -0.31378819096947952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39530907029760232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14529176239458133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27870429394106583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90792010753200103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54235071312397976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39595495095740041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20703534901217008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3978118774349986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23542434769529857,
                                   0,
                                   -0.048923302508718403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32278802809772583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25334645639430031,
                                   0,
                                   0,
                                   0,
                                   -0.33827773408810624,
                                   0,
                                   -0.45832208527130575,
                                   -0.12851327875101518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25452761580822958,
                                   0,
                                   -0.20031468378392089,
                                   0,
                                   0,
                                   0,
                                   -0.20465809993914824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27333775576233577,
                                   0,
                                   0,
                                   -0.032121573475957829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45632230347692837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045034879961294981,
                                   0,
                                   0,
                                   0.31274026216398093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80802669694891405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013355311595546204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093517374205591822,
                                   0,
                                   0,
                                   0,
                                   -0.31584577260566354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0027339721703555364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19069681167376668,
                                   0,
                                   0.29528243428191664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13025091544846948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0086141850137661513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017022943410574531,
                                   0,
                                   0,
                                   -0.17350772469883591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13001398635579789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067792616370980066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73457368656318356,
                                   -0.54555834401710845,
                                   -1.1167524567033233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45813435031578442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17483672937513595,
                                   0,
                                   0,
                                   0,
                                   -0.10502752490841155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5817004591419257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040153076438979335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69669650126481009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39384527497231608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037912822042321728,
                                   0,
                                   0,
                                   0.1344425852127934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12977223894205087,
                                   0,
                                   0.021470921945073183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14897703659497022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0051298279709532102,
                                   0,
                                   0,
                                   0,
                                   0.53124599683643658,
                                   0,
                                   -0.084729164310457836,
                                   -0.65190261245800085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12707533605860269,
                                   0,
                                   0.056683279115443713,
                                   0,
                                   0,
                                   0,
                                   -0.16278510595097567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12272132798510865,
                                   0,
                                   0,
                                   -0.36283995407307962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076106244906672824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21848041871293361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47707720986846697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74860022534179382,
                                   0,
                                   -0.16867968127817404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032885051537227483,
                                   0,
                                   0,
                                   0,
                                   0.097157271787992605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36363542603385035,
                                   0,
                                   0,
                                   0,
                                   0.48910245503118355,
                                   0,
                                   -0.52379984391906775,
                                   0,
                                   0,
                                   -0.14425837587733978,
                                   0,
                                   0,
                                   0.377598010430514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4273113215872345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12618742993318877,
                                   -0.46182512473679127,
                                   0,
                                   -0.10960730060957836,
                                   0,
                                   0,
                                   0,
                                   0.73876048179196463,
                                   0,
                                   0,
                                   0,
                                   -0.61436602172441757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66006687553300414,
                                   0,
                                   0.30114603797189288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65570298301790386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30373949251577559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64259342573581557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021518820502544889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038348633748340633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3319275039649312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056794936061893925,
                                   0,
                                   0.30820786876130646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0081172389707599851,
                                   0,
                                   0.29860223993363599,
                                   0,
                                   0,
                                   0,
                                   -0.39154343322441293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25095793678460998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18094623804246399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081244445080171146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15342987037893543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44109125639157543,
                                   -0.11454252331949903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087312873286595788,
                                   0,
                                   0,
                                   0.52843652580163902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37020474713702645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0011290853610474889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084453771963334284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0567963251148422,
                                   0.31894274808364986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24335840395337416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16430026389179275,
                                   0,
                                   0,
                                   -0.5712377077814913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68948210867622473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22328677260874191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073529066661835771,
                                   0,
                                   -0.67058516872630203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077112129619962749,
                                   0,
                                   0,
                                   0,
                                   -0.14023874128205199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52018036831571179,
                                   0,
                                   0,
                                   0,
                                   -0.084511503909347779,
                                   0,
                                   -0.8040033708825709,
                                   0,
                                   0,
                                   0.97513392652345665,
                                   0,
                                   0,
                                   0.014278163402246975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2332790964144914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065663477228404848,
                                   0.51359219379165488,
                                   0,
                                   0.30125258576010916,
                                   -0.24611860239936437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2952084916021056,
                                   0,
                                   0,
                                   0,
                                   -0.14662822186218979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2075667523138531,
                                   0,
                                   -0.63364065917213142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54086852624736359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9125960469181118,
                                   0,
                                   0,
                                   0.076091469312166565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11949042823448397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38845130288622348,
                                   0,
                                   0.067599506954125116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33578579149857546,
                                   0,
                                   0,
                                   0,
                                   0.099965624257106422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63891855218017479,
                                   0,
                                   0,
                                   0,
                                   -0.31169338356052634,
                                   0,
                                   -0.46864418882207776,
                                   0,
                                   0,
                                   0.28749158568550259,
                                   0,
                                   0,
                                   -0.48659262193349068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66420064314503868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0078140354261308984,
                                   -0.025765858875428864,
                                   0,
                                   0.39122954610140298,
                                   -0.36478742434829542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14218145045327138,
                                   0,
                                   0,
                                   0,
                                   0.60520403055765815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18130706684354289,
                                   0,
                                   -0.45190960984437301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33688143549910643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38564521880534786,
                                   0,
                                   0,
                                   0.73988033195182612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11260684225983639,
                                   0,
                                   0,
                                   0,
                                   -0.82347527358846717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52061972667266654,
                                   0,
                                   -0.0034303174181874591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30483870246409306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34332792754377311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29115014435605224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39742455208021982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052529204936819285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41981774379738901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039980354341256109,
                                   0,
                                   0.50160436106929251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21821112830098896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18784047522690062,
                                   0,
                                   -0.039265846832545859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39882223547582851,
                                   0,
                                   0,
                                   0,
                                   -0.46350949217071202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18610881401467885,
                                   0,
                                   0,
                                   0,
                                   0.26750771348050562,
                                   0,
                                   -0.2134367526969615,
                                   0,
                                   0,
                                   -0.49513089971364221,
                                   0,
                                   0,
                                   0.44810314626068826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19977322162995836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32138481024148191,
                                   0.66551756240527737,
                                   0,
                                   1.0646860660089132,
                                   0,
                                   0,
                                   -0.12251105839570942,
                                   0,
                                   0.058240877535090538,
                                   0,
                                   0,
                                   0,
                                   0.065070656208781386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20586094495846263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12502873060085445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10380827488688481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38151915612039911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14180418588672555,
                                   0.47219883622284853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68370113139470368,
                                   0,
                                   0,
                                   0.008738804628409591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22894790249456731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092299689442778665,
                                   0,
                                   0.44632314843422655,
                                   0,
                                   0,
                                   0,
                                   0.095730727241588251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30558022315571515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27833479472564993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14836976798010743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31382989913222892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22663292662928516,
                                   -0.369999092000598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044561722982052077,
                                   0,
                                   0,
                                   -0.20633192345254839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5088607832001415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39251787176193342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30704833770101075,
                                   0,
                                   0.2433565380430778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23215154370445445,
                                   0,
                                   0,
                                   0,
                                   0.17745874578859477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098695116808560968,
                                   0,
                                   0,
                                   0,
                                   0.51816025545529665,
                                   0,
                                   0.082254273696301158,
                                   0,
                                   0,
                                   0.28352099744940662,
                                   0,
                                   0,
                                   -0.27240626661394118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19553273452701875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37687410700632173,
                                   -0.72862705825728957,
                                   0,
                                   0.90767335532633675,
                                   0,
                                   0.063617971144634203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29874647856943359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070705893903219047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48407823064544331,
                                   0,
                                   0,
                                   0,
                                   -0.42543622413532717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09494906217123486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23625780815557973,
                                   0,
                                   0.39852289413149211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27090650412658562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43512337356098979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48244201303321882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29844658797050999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037338379293574905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46173069373597841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46200366885751187,
                                   0,
                                   0,
                                   -0.50014253972766176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2338608147505605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067101299239140502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05148170029715924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59796884119623239,
                                   0,
                                   0,
                                   0,
                                   0.049595881234329342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06523170707816861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33461459345876227,
                                   0,
                                   0.49110454360806621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020880776624071628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46934837985587663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1086469136428202,
                                   0,
                                   0.40608766448697875,
                                   0,
                                   0,
                                   0,
                                   -0.10131238327036966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3467343982299837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074177569363560014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55557069926915859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41366951053268536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36301287977257363,
                                   0.18411061156590988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17444732190181031,
                                   0,
                                   0,
                                   -0.042089153538236349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098171809720907569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41115872280999521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70021804956929434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43108491702955459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22653848609231458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30950704376478921,
                                   0,
                                   0,
                                   -0.087719360481216049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23219994076779674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0219214622512303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051497730913881559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.4998578969872023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27086530028153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32663488570751154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32073755155728673,
                                   0,
                                   0.10990057713261042,
                                   0,
                                   0,
                                   0,
                                   -0.51953671449237648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44995684225397403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18779485578661156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11955811758609482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021423423143040427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063526117670876917,
                                   -0.35176245029600378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19782483661477632,
                                   0,
                                   0,
                                   -0.42713323808996667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11532500181218197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30735566754914023,
                                   0,
                                   0,
                                   0.80335276813302892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18126213402767907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18374530415655546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52720078546312343,
                                   0.42566958265675942,
                                   0.42105336676033606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58578204232561482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4188376156992869,
                                   0,
                                   0,
                                   0,
                                   0.43860375828589421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098914711915296966,
                                   0,
                                   0,
                                   0.1157810573289841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40410373995350141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2806606052231711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10085054007892978,
                                   -0.38335754741688138,
                                   0.22587049397618306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11738415690339747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2270811413990543,
                                   0,
                                   0,
                                   0,
                                   0.70382539329100535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40514010598711181,
                                   0,
                                   0,
                                   0.39760854924815109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93570939011551002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059720651334907157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3051136692415079,
                                   0.14207543781015394,
                                   0.2819021899865144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2152527392325097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051264474506783342,
                                   0,
                                   0,
                                   0,
                                   -0.78609472749773879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18051434477418274,
                                   0,
                                   0,
                                   0,
                                   -0.49970552490659215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27086403323514141,
                                   0,
                                   -0.45250834255144295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15325613340838767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12703313934809671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.009669208230813145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80108159867398177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23418512374232481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0753828791315567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18366874047696852,
                                   0,
                                   -0.09417263119783964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39771321339463517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95734476748993358,
                                   0,
                                   0,
                                   0,
                                   0.3890137537635539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87964299845399907,
                                   0,
                                   0.45351020533936182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18357423242270335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45504869746084631,
                                   0,
                                   0,
                                   0.029144355414748579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05485466698912897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84747305837416098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55417007844966393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082089642862209322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0311000734088525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53151357601523486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056268862212655091,
                                   0,
                                   -0.60652397008671322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14949183716376518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18637012914344639,
                                   0,
                                   0,
                                   0,
                                   -0.073100149230454034,
                                   0,
                                   0.17161525626771518,
                                   0.0043940799017981175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39626314802603091,
                                   0,
                                   0.42602965097056628,
                                   0,
                                   0,
                                   0,
                                   -0.29516835054912144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27330209445122,
                                   0,
                                   0,
                                   0.18313354328944981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037455706944748396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042203765863666129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083154630223014531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082192732066962357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18771543573086066,
                                   0.20568648926709482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83244343333539128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25677590949196494,
                                   0,
                                   0,
                                   -0.038388127755660764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38524804975232158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2283344844554123,
                                   0,
                                   0.32495228099216339,
                                   0,
                                   0,
                                   0,
                                   0.30453796056534443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50724883283063193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094284190895760983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40663063485569173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1646568665777971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040788524806336178,
                                   0.15205659395193105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42903815617391611,
                                   0,
                                   0,
                                   0.27454069752711507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081507786830334092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084049282575306791,
                                   0,
                                   0.083721453555446856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0075362809899536948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58973913836350522,
                                   0,
                                   0,
                                   0,
                                   -0.01538428069315639,
                                   0,
                                   -0.061463249051720625,
                                   0.15755862207257221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4119272011986439,
                                   0,
                                   -0.16827455783250861,
                                   0,
                                   0,
                                   0,
                                   -0.067945723132727745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42034612494882667,
                                   0,
                                   0,
                                   -0.13708758298041049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35476615859770966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29202465367196129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056747569447197707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080042170942128552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36234680379663203,
                                   0.036352092578132267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056726872805041288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73009880561463913,
                                   0,
                                   0,
                                   0.34939170204280473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44656412513964122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79708580090564696,
                                   0,
                                   0,
                                   -0.33289272578812668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023229779020560393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052872970168291303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59873040774125386,
                                   0.66177136343452125,
                                   -0.14226744917481582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43680492705610063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71545803237590244,
                                   0,
                                   0,
                                   0,
                                   -0.055956354063679603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0057537463312434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096970831700226134,
                                   0,
                                   -0.23572755859190681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16570165532969594,
                                   0,
                                   0,
                                   0,
                                   0.11059468967221406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20313494136000865,
                                   0,
                                   0,
                                   0,
                                   0.48656572673947601,
                                   0,
                                   0.67197915775798589,
                                   0,
                                   0,
                                   0.79566772917441875,
                                   0,
                                   0,
                                   0.30553607251293846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18862438559855726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23333613091253674,
                                   0.51962800744698678,
                                   0,
                                   0.38754122259527596,
                                   0,
                                   0,
                                   0,
                                   -0.095107093393606595,
                                   0,
                                   0,
                                   0,
                                   0.13581178323775162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30872519648522778,
                                   0,
                                   0.34172967125172216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92256741879358994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47999313826729867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1478238352471837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26200484076216951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32525381212704624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57704872376286886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2441451325227646,
                                   0,
                                   0.18511485807530878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22130232111550521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17011454555413036,
                                   0,
                                   0,
                                   0,
                                   -0.36111462327214006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088542463877987657,
                                   0,
                                   -0.61218936902668342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76243401713128423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83626188894508524,
                                   0,
                                   0,
                                   -0.55894550247670705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14387604689831024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30588682620083424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036585320325685039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47673168389536663,
                                   0,
                                   0,
                                   0,
                                   -0.31571796836241639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16084015197452392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64104609472555907,
                                   0,
                                   0.079814537626132678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037553198965127196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33593639253093599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4965670618628823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84325443211626772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028462184422983844,
                                   -0.015768294196049581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08341754592676684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16054017358439862,
                                   0,
                                   0,
                                   0.08708574695552497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031125859335921713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76618791848999379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11456519638356792,
                                   0,
                                   0,
                                   0,
                                   -0.072200006441857353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52281125799125405,
                                   0,
                                   -1.1505595555384107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016530011313832034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097848929309000576,
                                   0,
                                   0,
                                   0.39626583859843739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48593778709156671,
                                   0,
                                   0,
                                   0,
                                   -0.50347001192886653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017971155533209146,
                                   0,
                                   0.46710811447918177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43981992210589965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060737892153690222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30322607978544164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07522840141152505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33816259300354984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53508719011172923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68041636458192412,
                                   0,
                                   -0.36805690802385471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21260110056988379,
                                   0,
                                   0,
                                   0.39291662428607238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43785961926941736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070098017251451941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53388009803686876,
                                   0.15614485286862623,
                                   -0.39045105589769513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80276760087980159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062220458641516152,
                                   0,
                                   0,
                                   0,
                                   0.82366119443297203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25166945436572929,
                                   0,
                                   0,
                                   0,
                                   0.26728022387530592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85923394597245706,
                                   0,
                                   0.29328619769849223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42067919911441065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.616666503046156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3054013857143269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08493019620212891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054551581825892509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12763459065831248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90643691226074163,
                                   0,
                                   0.22137364245867133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0094504905720754206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00067730512162803014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15623296779885198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15362168813789626,
                                   0,
                                   0,
                                   0,
                                   0.0018372059050617284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53158597369536131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3264103170738325,
                                   0,
                                   -0.41871734546042461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35505194207215673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51125830202168954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37827669837818795,
                                   0,
                                   0.16320848671345459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15382547406114688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21083135005966355,
                                   0,
                                   0,
                                   0,
                                   -0.22340790009747932,
                                   0,
                                   -0.114341310880903,
                                   -0.25979720840438991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12760879659589786,
                                   0,
                                   0.36307897802768746,
                                   0,
                                   0,
                                   0,
                                   0.25846978033590767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014637618456290455,
                                   0,
                                   0,
                                   0.25858014813042318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18530656802232645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56155545261481676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83090304376015123,
                                   0,
                                   0,
                                   -0.61034694221280938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34576631120252466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27336373005472636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0091073830506086251,
                                   -0.34254499511502678,
                                   0.17134464654502271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13563281954971765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65426769379667349,
                                   0,
                                   0,
                                   0,
                                   0.61464815438340703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94059684621983364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25488922493383692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83123083966810252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045427557584231948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30825214361577929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52748485343498164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43478168904467818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3520605488228466,
                                   0,
                                   -0.32892784600309521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071226849124697289,
                                   0,
                                   0,
                                   0,
                                   -0.49167715396427741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32218747178517537,
                                   0,
                                   0,
                                   0,
                                   0.66429938072071626,
                                   0,
                                   0.35020119111397535,
                                   0,
                                   0,
                                   0.19790229007688009,
                                   0,
                                   0,
                                   -0.085792299161020463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70799313555182941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31224506112824324,
                                   -0.03125013547305415,
                                   0,
                                   -0.62614514799842136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18836366702822546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1060054549152353,
                                   0,
                                   -0.041531716158552445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29423610754837276,
                                   0,
                                   0,
                                   0,
                                   0.91711714081661977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.005075111598606713,
                                   0,
                                   0,
                                   0,
                                   -0.25499685000665018,
                                   0,
                                   -0.0020864935270940299,
                                   0,
                                   0,
                                   -0.061053683321799251,
                                   0,
                                   0,
                                   0.56573005580694002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028578184771772375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87928563523443659,
                                   -0.086322006469295581,
                                   0,
                                   -0.37103616037245335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12321686662701017,
                                   0,
                                   0.1432953609204336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4461310215813874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21685187695409291,
                                   0,
                                   0,
                                   0,
                                   -0.1778156963881338,
                                   0,
                                   0.048282226150296342,
                                   -0.21586846005426302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61344392687016525,
                                   0,
                                   -0.21557150675485925,
                                   0,
                                   0,
                                   0,
                                   0.26373285276563024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16879138630148688,
                                   0,
                                   0,
                                   0.33109655391627979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057969447333526963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062146364141463295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62615035575614864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33123163252267829,
                                   0,
                                   -0.44043639173154525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56141712176566838,
                                   0,
                                   0,
                                   0,
                                   -0.21943327801621282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022673448588234328,
                                   0,
                                   0,
                                   0,
                                   0.15983857777527891,
                                   0,
                                   -0.053893319197652612,
                                   0,
                                   0,
                                   -0.13542324720175578,
                                   0,
                                   0,
                                   -0.42166296538271275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26679149953420145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69584925082128912,
                                   0.027740747575073853,
                                   0,
                                   -0.39061142515853542,
                                   0.84174260840177262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17091406490393193,
                                   0,
                                   0.62420315590778719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098563291187970248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09214464337321733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071833420086901911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046364778199019435,
                                   0.30978276603952348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0057792595160135879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10118009336704961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17961586828713982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3238511473133906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94966462142603825,
                                   0,
                                   0.11108517967096115,
                                   0,
                                   0,
                                   0,
                                   -0.74079107161766578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1101748735507702,
                                   0.85628432799386389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38631352711125411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30239611965591362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46156478607680085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58440136366733719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75639870538505394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60278560851301033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47198350007631762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22810113925134368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36027263828781453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39019587055016036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17540205457188524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17012695704811526,
                                   0,
                                   0.14174873030048735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36030563746298339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015146608231747127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41803854847972849,
                                   -0.53442799454182666,
                                   -0.36983026371009164,
                                   0,
                                   0,
                                   0,
                                   0.12182857140633035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24814484679150467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38960878387840731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33854351752742751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83837668321565606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27062849701019442,
                                   0,
                                   -0.038730451536206564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079183864738925885,
                                   0,
                                   0.10894124780311414,
                                   0,
                                   0,
                                   -0.34831891219921068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23838967208459752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25072226511241347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051848304580569937,
                                   0.4560189753069096,
                                   0,
                                   -0.044213913507152355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46309298549762667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40272290042698317,
                                   0,
                                   0.27668279232270143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01771711766113061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088273219063852049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054111250884301854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29043953618896012,
                                   0,
                                   0,
                                   0.38312327830146964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015726407988759988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34303643417022733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53469440556183068,
                                   -0.45427153468746523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070559324883557595,
                                   -0.37812772021476393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033778808518046391,
                                   0,
                                   -0.13693572049945615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22337380701563808,
                                   0,
                                   0.023690504255033551,
                                   0,
                                   0,
                                   -0.10222138286446333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12754018473745302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62095865523249316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13209736577859651,
                                   -0.15979261816675949,
                                   0,
                                   0.064553353510238248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036398815982125604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26619785789982536,
                                   0,
                                   -0.05614196804693132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62837609542451267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10777317669600854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23177821583686914,
                                   0,
                                   0.41034209604810767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46773535562875679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57240040240379964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24172424526258743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1967608679563807,
                                   -0.15692934454649915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67715004369710607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03787995794238086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30128681994027057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38818462054588027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30013709345603712,
                                   0,
                                   0.30116331676938335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.868059119808961,
                                   0,
                                   0.15947611304817633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27965088037731184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081022024161146788,
                                   0,
                                   0.25551578333087666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0101626399665897,
                                   0.28316552054645261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64593154235919015,
                                   0,
                                   0.21614366781929098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10610139851611122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29237261705772055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25506868127870591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25745458589024645,
                                   0.24712878246793671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60645275219068118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60950888606655174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38436658283643604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26710153322377256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013267603126654468,
                                   0,
                                   -0.29452592621756285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13800723398385364,
                                   0,
                                   -0.41437894431832278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26717392612497703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0324184682268982,
                                   0,
                                   1.2351976641798037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36816950144858401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092257604561670967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27260258190705361,
                                   0,
                                   0.2013540329525268,
                                   0,
                                   -0.3576823293835395,
                                   0,
                                   0,
                                   0,
                                   -0.082424497816689132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040257768366044659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095994894406228784,
                                   0,
                                   0.24523276866086235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15297128236637184,
                                   0,
                                   0.61992499551794267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20073081067095755,
                                   0,
                                   0,
                                   0,
                                   0.47215207657917951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42287075653017486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37702590303234595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0047549963891961814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62556566417745008,
                                   0.28044329122560546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33670072851582117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089494699203356246,
                                   0,
                                   0,
                                   0.19697304677774058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2501891935592335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017646357912993047,
                                   0,
                                   -0.060279226580843642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2751202388115791,
                                   0,
                                   0,
                                   -0.16282243046845898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71410098698019475,
                                   -0.81954799982557547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28801466757573102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35649944836375891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12292044178261849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1214011038790912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041093881220958139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75804377307967286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73472518611363413,
                                   0.46492186139216829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20512757942895962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4257823046453062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28492369075727386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6250841289985366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17906198653908181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17876327609288456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33604570860228861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14774750490940716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099181089532183853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68826117297122391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20860211870462206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20924305400721183,
                                   0,
                                   -0.51229856268071883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09694576689905493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024593179407626925,
                                   0,
                                   -0.047598355508556317,
                                   0,
                                   -0.31806377267601982,
                                   0,
                                   0,
                                   0,
                                   -0.63330011621704663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057601360869487125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37171057885801373,
                                   0,
                                   -0.23404985895756975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16232814189679193,
                                   0,
                                   -0.0053187988990459484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22075266727794796,
                                   0,
                                   0,
                                   0,
                                   -0.4627321326638949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61545056822662281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39409550356385448,
                                   0,
                                   -0.2785208481215582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24949027007704491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36082976689677004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49316684036110475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22224589025995861,
                                   0.20557346395821091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50570246804630326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62516276102107937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050499479134024049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2156649839579742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16759265776023152,
                                   0,
                                   0.83891339484690997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033786903011246129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21150727140407397,
                                   0,
                                   0.42541324073794257,
                                   0,
                                   0.10266942458535099,
                                   0,
                                   0,
                                   0,
                                   0.17100481682282392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3328377898499133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36820834652319573,
                                   0,
                                   -0.29981697874627039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069289095383470486,
                                   0,
                                   -0.4347049782481055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33659795299369377,
                                   0,
                                   0,
                                   0,
                                   0.30007808226077859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32179571322172768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23269183603529289,
                                   -0.026222897662138089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091869930443755077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54886546077732878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25216907709819397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1781038106000388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089546022100157593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078912086858082042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020367467275227744,
                                   0,
                                   0.18512124924564566,
                                   0,
                                   -0.10851388951231683,
                                   0,
                                   0,
                                   0,
                                   -0.0056009747569673619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11269836518131954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43112470182814244,
                                   0,
                                   0.17530765569867768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23167266400192021,
                                   0,
                                   -0.1238213014435785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8039310950107551,
                                   0,
                                   0,
                                   0,
                                   0.051673872675405477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19140357095786348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12274982634069583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41268921711502043,
                                   0,
                                   0,
                                   -0.25140277972652603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56547495234312428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55453843652224954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034384410153565338,
                                   -0.1686161072108866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18713806744386549,
                                   0.15123581161050861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13847318177069912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30672453863184951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27015016747207293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32059999441004261,
                                   0.59987760212912833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022133974019112712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17036345987682575,
                                   0,
                                   0,
                                   0.030991436956962742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68355623705567625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0046563994295365507,
                                   0,
                                   -1.0692096510031275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60438055765722665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77343022252482596,
                                   0,
                                   -0.91303640347590698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31079222297743753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67165264380078837,
                                   0,
                                   -0.45276833528945759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28557061590519778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55938170502843676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50257764121574433,
                                   0,
                                   -0.17031876455507652,
                                   0,
                                   0.39786798976962079,
                                   0,
                                   0,
                                   0,
                                   -0.085620777893500408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38013084685637277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016655982724573311,
                                   0,
                                   -0.21891816512132184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18540536775052577,
                                   0,
                                   -0.0023684084987720677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075436178478774679,
                                   0,
                                   0,
                                   0,
                                   0.084238138002721702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3539676221990477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42887332089765295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6000633157867008,
                                   0.23311074136961848,
                                   0.30625105021646498,
                                   0,
                                   0,
                                   0,
                                   -0.36967555599824886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19564042884177618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082316418931733845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81758309653824279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34240146042456604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30709761662225182,
                                   0,
                                   0.05162860201886247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10702149369800092,
                                   0,
                                   -0.052749353825050124,
                                   0,
                                   0,
                                   0.13312931879198839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051824276283052195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16848425388616117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41075281758568738,
                                   -0.23167142993353829,
                                   0,
                                   0.57311955187534513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41605716738477266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031103692253289364,
                                   0,
                                   0.15726736934017066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30055573680652237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59108623222361778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057789118188082897,
                                   -0.55609466389886353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032365836286289279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85021095137471958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083499576463606201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55928629391967077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56592629131245586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31857887746322794,
                                   0,
                                   -0.15155309190212904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31893218770189757,
                                   0,
                                   -0.055746919759340804,
                                   0,
                                   0,
                                   0.24987226548803135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084114922311732704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49196576399431935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1058929822337526,
                                   0.3489428986653354,
                                   0,
                                   -0.028341622419233756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19385175219816519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31561495214054414,
                                   0,
                                   -0.17381200485493414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39748243601788957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29132288125162326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096922075155227411,
                                   0,
                                   -0.13009524066429073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028707415219059194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57761223651061111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75889801328499407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35407147577379106,
                                   -0.75284565439450746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12061997393222594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10223880156197715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063943230945211954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47283815345919161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33576776610825698,
                                   0,
                                   0.035973946524622824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24304216099849296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60672683307830921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73740712635141648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00064014787617648616,
                                   0.46599358644823347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53715863432149047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11685831709509312,
                                   0,
                                   0,
                                   0.85912393538123388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063376780125391718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26999511845164897,
                                   0,
                                   0.80921295000036308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32784351183918181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0074790083379858039,
                                   0,
                                   0.021932623784693323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065651193455133053,
                                   0,
                                   0.14882486818776106,
                                   0,
                                   0,
                                   -0.14221160244919159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23182046111399374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0870625876542718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21717467150868752,
                                   0.035439030078636712,
                                   0,
                                   0.49762337036174087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61741578078903447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018254486101395462,
                                   0,
                                   0.46246220479476902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0016729022348300152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13477459989063367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28925587330464686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15163650369716222,
                                   0,
                                   0,
                                   0.13771440155113795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41496634468080823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3741190843367731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41270073865161072,
                                   0.28915966746538257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5373067862489006,
                                   -0.037576712613832372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55912884450541933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41417070414195928,
                                   -0.24275940823895428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96304725921492129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47133384290771235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28141920593497105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40509561901492269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84416458668101046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18884224096434898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55684952226105711,
                                   0.1494043174413309,
                                   0.59516041395519637,
                                   0,
                                   0,
                                   0.2814845879276654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44551776163802648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35559565255698217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72064540820903289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27703330460032394,
                                   0,
                                   0,
                                   0.17130980013379474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0080975783399532767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26370510840699274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40795062788282926,
                                   -0.088373008309285378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062372786982845367,
                                   -0.019940037903756969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63566432434615727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66801768336330636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33154636549432509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39251113540293014,
                                   -0.61697741679911411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48607652486351771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33383440339497378,
                                   0,
                                   0,
                                   -0.00094902325705394086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058438192336783948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20286699407970055,
                                   0,
                                   -0.090211832177676282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33227960371213972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018621453236334184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22407010803526131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12140423770671599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84427336021159616,
                                   -0.28827479830164848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85917816141714165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37823661281713566,
                                   0,
                                   0,
                                   -0.35308021544512891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5047817837567431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41307042248415426,
                                   0,
                                   -0.10367162365902557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34523354266179557,
                                   0,
                                   0,
                                   0.56767903443416834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61017437232891769,
                                   -0.2880893577375791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63537503546248442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10213640910133545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26783948400131025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080360603752002296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57399899124839449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23744466637103867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25311538065862671,
                                   0,
                                   0.44637259641696569,
                                   0,
                                   -0.062608174446020667,
                                   0,
                                   0,
                                   0,
                                   -0.39603048795990348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21664935367655566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39523654607446984,
                                   0,
                                   0.30780347108094713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16203820166805394,
                                   0,
                                   -0.39998866727057464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075077993191185674,
                                   0,
                                   0,
                                   0,
                                   0.1725350524838101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15149126164852622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15120544345151279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20423396239571306,
                                   -0.5204914664236453,
                                   -0.23108341379765834,
                                   0,
                                   0,
                                   0,
                                   -0.67523401630084512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19878871957890246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67693621442582019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021799737836424526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48749087446594924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11854882125791563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15743663657673651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75670426680136238,
                                   -0.0180584435074021,
                                   0.28651404858838697,
                                   0,
                                   0,
                                   0,
                                   0.14123251316542787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20051269379935704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97593961486498437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36758060144897997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26408551067595887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13398688668236408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10755386128927553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4461981048656754,
                                   -0.13312143343152907,
                                   -0.24348063492989919,
                                   0,
                                   0,
                                   0,
                                   -0.73815632413921273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047032310436612143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79968578909604671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3738065457522643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41001904642284737,
                                   0,
                                   0,
                                   0,
                                   -0.42478933241626371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091613069161703559,
                                   0,
                                   0.52670670440470635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22459914605851794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10568638987304044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026014334123576649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44724303148375805,
                                   0.089770196428438725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.290537355526997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22625642393345627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.01833956074592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35550272497758878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27183647399300059,
                                   0,
                                   0.038463388515129961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1963344748511425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59825759531761824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47613270618537157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.280292813595934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23760760510001944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10858194943084691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22143524112761007,
                                   0,
                                   0.4254329895764507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057806089667884891,
                                   0,
                                   -0.2788233062042984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20781139695357775,
                                   0,
                                   0.34724560083572831,
                                   0,
                                   0,
                                   -0.14313054444588788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090766128421723352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16590168405025937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60300987916998894,
                                   -0.40583263388438023,
                                   0,
                                   -0.080480407882794036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25060718567171675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17114594441567288,
                                   0,
                                   0.077078424478894181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25703814472327391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30972341623585387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76494969380373445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12271439161839048,
                                   -0.012278810525304662,
                                   0.78662239081427543,
                                   0,
                                   0,
                                   0,
                                   -0.62996104567126321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26035360690864601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49652649743721466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38081272374924935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048499194612869889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48666259735539114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51555755480632448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17196624484797429,
                                   0,
                                   0,
                                   -0.19379536967932304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0043387993936960523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46076651773442812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11023214110206161,
                                   -0.30280591500057807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31217238715632811,
                                   -0.12888806733641953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089534267745792873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37705916019646485,
                                   0,
                                   0.27662156431740609,
                                   0,
                                   -0.27791794978033396,
                                   0,
                                   0,
                                   0,
                                   0.23028895037453917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54398712177299668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11086753552866296,
                                   0,
                                   -0.53720719566658226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09216302741778036,
                                   0,
                                   0.16309788160131031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0825701573649959,
                                   0,
                                   0,
                                   0,
                                   0.065583409739762025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45436762210760201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11196624833648264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17930489101692093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48998913870218497,
                                   -0.62720124257811583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57147165470707462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7483338595537985,
                                   0,
                                   0,
                                   -0.19938132350525334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50905743155139949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35182332609770245,
                                   0,
                                   0.26578018275077259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47307346397181965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0048650894948658319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06665277986163215,
                                   0,
                                   0.37638227055205975,
                                   0,
                                   0.081429714507664896,
                                   0,
                                   0,
                                   0,
                                   0.19975755113206742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32422702001512926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40148036436072687,
                                   0,
                                   -0.27822214362292147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53546948609154799,
                                   0,
                                   0.22671353946837666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058094209992208275,
                                   0,
                                   0,
                                   0,
                                   -0.34945315163928231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034212079764896812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09028978085546395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33937034945540911,
                                   -0.58665627516476415,
                                   0.21272528166232144,
                                   0,
                                   0,
                                   0,
                                   0.065078985393810296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3047227493465965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31307078141630695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33698532523392533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11439833114998718,
                                   0,
                                   0,
                                   0,
                                   -0.37713761603563151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12163875115897836,
                                   0,
                                   0.60551782049028713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64140544596682625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012060655332928799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27026744538429875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080650312164489174,
                                   -0.47207362364930738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26768314815905903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15460282065187636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19214391269557374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68432003372977257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38702891846034171,
                                   0,
                                   -0.039275252182299547,
                                   0,
                                   0,
                                   0.43760823010662819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055678024478944599,
                                   0,
                                   -0.13378171678144024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010374463646192614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17778397568932969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68001004222627404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49577057504230831,
                                   -0.50354813551239375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15779001638640938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016047528446459625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037355924315308958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095899228168693035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22713292917721509,
                                   0,
                                   0.74035107047774784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10647537252500384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.269434309217017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20121418751724518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36695632111648996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3898443035439404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55477010353639833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50047362576190035,
                                   0,
                                   0.17521917226756292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70446359616840049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38518831421786148,
                                   0,
                                   -0.30483307708065599,
                                   0,
                                   -0.20381947529404917,
                                   0,
                                   0,
                                   0,
                                   0.24825342960857238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38391304365118373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0058113763633232257,
                                   0,
                                   0.031324905740796313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031827569814412676,
                                   0,
                                   -0.023822771174547348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087887668936220673,
                                   0,
                                   0,
                                   0,
                                   0.03945437467855327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25334235238941732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17696836387398654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47322085645286854,
                                   0,
                                   0,
                                   -0.30296908256055871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40975890736405152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17221279179455748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097002090865659571,
                                   -0.30341850596469655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34273437885004437,
                                   0.41505776591005777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25381629969519848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30755381407392285,
                                   0,
                                   -0.32996005184771171,
                                   0,
                                   0.17507517412019352,
                                   0,
                                   0,
                                   0,
                                   -0.31784872478860121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15597291786180106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052535840542186879,
                                   0,
                                   -0.37484032665106648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37004437897428138,
                                   0,
                                   0.0093662762193350013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078360356884298599,
                                   0,
                                   0,
                                   0,
                                   0.53822060718252906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22202798598255818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020127588637341522,
                                   0,
                                   0.12705003478804117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082891063203148305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82551771989624723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23994196275214313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25921023682738886,
                                   0.63138183546623983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31366928729862198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60064085606399997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55355989847715581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15310002537191897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07879441361727893,
                                   0,
                                   0.46448829123237623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73704886862926167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28576821590748741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017566162066474066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46426785421892447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11356619977894433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15226425732948454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20319341393264473,
                                   0,
                                   0.28613464009211625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14859553667549102,
                                   0,
                                   0.11858554586900832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59305241476685133,
                                   0,
                                   0.0074183733251509676,
                                   0,
                                   0,
                                   -0.3186993337183569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.242569832553825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15793760906083229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23455716565818666,
                                   -0.2953030932795348,
                                   0,
                                   -0.075814993566151345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24030228089191832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4611041854646234,
                                   0,
                                   -0.052493974901411493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075167752172110233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047449471014808266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86178213751439059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27185719479482678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18499353625557968,
                                   0.0094193083817928694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042884619645880431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4410828464887312,
                                   0,
                                   0,
                                   0.76416779023712755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25125793789563533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95129435164246556,
                                   0,
                                   -0.28921081753850775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14620373152666993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016688494480465291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37127139963302885,
                                   0,
                                   0.089185119590719689,
                                   0,
                                   0.49224812180435978,
                                   0,
                                   0,
                                   0,
                                   0.13642540353398613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19052512262457816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44532263643897202,
                                   0,
                                   0.32253523926519273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35350275200334219,
                                   0,
                                   0.16800287291866312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29249835664250051,
                                   0,
                                   0,
                                   0,
                                   -0.12497779480938905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80117698878562194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12304883624530544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35698952727393718,
                                   -0.90640621462623294,
                                   0.26302006417157953,
                                   0,
                                   0,
                                   0,
                                   0.70307690049051175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29860561505036021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26268926661989622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75129775689172273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36582041253641695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25618669201552041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19254517252160502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064354573066683879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4002145961447629,
                                   0.51869971616564914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59356723505946318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18234238313694445,
                                   0,
                                   0,
                                   0.51192256130481584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38657104745088378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22369831693883521,
                                   0,
                                   0.059219831551988622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9035760379512674,
                                   0,
                                   0.42589237403081759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14253599289842261,
                                   0,
                                   -0.15556491832798652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62107843895601589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19192620538387417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87179570180663546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35096715064824913,
                                   0.21246249387208924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15224174206310134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1992356298083133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37017755143038639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29142542896082047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64376062921478638,
                                   0,
                                   0.16323399115179038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19084885785055605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1893756198935212,
                                   0,
                                   0.29283739783720697,
                                   0,
                                   0.4335812475974028,
                                   0,
                                   0,
                                   0,
                                   -0.35282649258949139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26661081853429902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0098412987324147331,
                                   0,
                                   -0.10136954634754024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5225064626409377,
                                   0,
                                   0.38011560001542266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1744478355402489,
                                   0,
                                   0,
                                   0,
                                   -0.0096813989490050593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.173235795881546,
                                   0,
                                   -0.31849481537849006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12156235216571222,
                                   0,
                                   0.71641110754863657,
                                   0,
                                   0,
                                   0.046998394212564472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19929238855561984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17711225301178121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23177843592193359,
                                   0.17937224379099889,
                                   0,
                                   0.12190678163139881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052054445429940262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09129028514005634,
                                   0,
                                   -0.36282645253268264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15423861721801957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16418023724522221,
                                   0,
                                   -0.69924479595940647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087482754835036702,
                                   0,
                                   -0.11428930228872616,
                                   0,
                                   0,
                                   0.16388176366984586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29867611226972912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029072033178088322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21665174577538701,
                                   0.051289102134522896,
                                   0,
                                   -0.23121822411671009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12741431508166953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19250132834438563,
                                   0,
                                   0.42962825041147323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074662116436172793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79592196027253492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45825606803580082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0756101486997847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35843691024233371,
                                   0.55761373817563964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10599818263453897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4609600524795795,
                                   0,
                                   0,
                                   -0.083778311333842337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4799999516336973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36450788752730495,
                                   0,
                                   0.51164742337675362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37738642225641239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025792873741832041,
                                   0,
                                   0.25110396361552945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45764873586959331,
                                   0,
                                   0.32194213968454816,
                                   0,
                                   0,
                                   0.041244146001048129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19796784665559736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26619912150988828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25592312264032951,
                                   -0.3110017466953916,
                                   0,
                                   -0.41522234969290139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17214907097004331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14338956433107397,
                                   0,
                                   0.039031388440262528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35368128347287764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27137022823527257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55228386084015457,
                                   0,
                                   -0.57958086717031965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84985245675292265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63156015368734808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54646554710817363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44267036665306808,
                                   0.22513722705090267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0036574268377680789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10853154461517754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16518169937457633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23391322535708328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19637498999999223,
                                   0,
                                   0.014633027081179667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058442190116480719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32385033290162102,
                                   0.35631684951306075,
                                   0.056217183159600892,
                                   0,
                                   0,
                                   0.3534462476208251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79790923882816622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74177926721289933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29018624065884846,
                                   0.37345790359688191,
                                   0.023683751847827339,
                                   0,
                                   0,
                                   0.38635787511184888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27613643537908622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26035218613682026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2580845197819438,
                                   0.5800314856130846,
                                   -0.66882585733469946,
                                   0,
                                   0,
                                   -0.029356347833627838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28457472291571334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097343697064210172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022120510436459521,
                                   -0.5771482943309324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9768834962332843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21527715739661407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75705895529217981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052171683248128195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60006976630876885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33445448344578987,
                                   0,
                                   0.23535164630184227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016069784101665152,
                                   0,
                                   0.19077675617475895,
                                   0,
                                   0,
                                   -0.48583437574783872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44162714754920845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033441862655757215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17398559249431067,
                                   0.35777061613018507,
                                   0,
                                   -0.094210052336462222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031214023478885369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37881528706722778,
                                   0,
                                   0.13220619641700573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18656823595706695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26910878818555845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46209280091965271,
                                   -0.60620425307978376,
                                   -0.43618816511451602,
                                   0,
                                   0,
                                   0.3876766136104981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077548919277061978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66306137817862798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061509807589384208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44688279784565638,
                                   0,
                                   0,
                                   0.19695790764653084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011448848783000523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1980891762837533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044807207126703358,
                                   0.36763820438358452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051682509222695218,
                                   0.37264257023540504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19479803658823625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2344309357982203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25565676623247624,
                                   0,
                                   0,
                                   -0.077916881323872922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43603739156843113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092824841964325222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47596520413587773,
                                   0.047042336014801567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017102899158996324,
                                   -0.6386478016477215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0095216373330169746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36997818715980668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57898274256871152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013184832677587743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19227868570779055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12728543614211529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68463814863265116,
                                   0,
                                   -0.075687209281189577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54379986222453403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3834234230383336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16791528889791552,
                                   -0.086253329264660214,
                                   -0.12383696228817095,
                                   0,
                                   0,
                                   0,
                                   0.10273045441529666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31171041131813293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11816891854309308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61933611022072854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62524364206714289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26699528196683464,
                                   0,
                                   -0.11698835456840291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30200991716976511,
                                   0,
                                   -0.22804333776605507,
                                   0,
                                   0,
                                   -0.26922444766479803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65442983886141526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080106459956157464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16851791191613916,
                                   -0.1077157136791142,
                                   0,
                                   -0.32035932544598933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00059159822215174712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28937378972348737,
                                   0,
                                   0.16408785347744206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10650260728613635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064436810997651139,
                                   0,
                                   0.15086973698498274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64897041049659066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71492322613200643,
                                   0,
                                   -0.69024232531173912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072785385768979971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38257557499203548,
                                   0,
                                   -0.22751958946043929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22324024334202996,
                                   0,
                                   -0.34490396280048546,
                                   0,
                                   0,
                                   -0.34945234935686115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069775143865871345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18139359128756222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18155647209639889,
                                   0.075381639909585504,
                                   0,
                                   0.1188015206528185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14818002648687625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26994897123298589,
                                   0,
                                   -0.51917908371903632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23675099176124537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.4100480218277913,
                                   0,
                                   0.93458618664549209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70847925235248677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045670305786828444,
                                   0,
                                   0.42517535495718672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64768918558030808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037887523199183828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14611176004650073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81933759816112917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23694872521108251,
                                   -0.33553784100211664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25815369374961467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53787498381342602,
                                   0,
                                   0,
                                   0.71585432764715318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028011037489944553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99141637313137587,
                                   0,
                                   -0.15197530757422137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35575260658044061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5200806057431141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46978095018484967,
                                   0.085590456065256254,
                                   0.066892802686282504,
                                   0,
                                   0,
                                   -0.70385710001560331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040085307909951483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67508754670862114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32028118141475037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3145640672164664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43249635542783393,
                                   -0.4112504035746557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22639810688649376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015680937527828176,
                                   0,
                                   0,
                                   0.52003914441919763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18803710849081362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23615475801565389,
                                   0,
                                   -0.61743104752994826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42870868142874274,
                                   0,
                                   -0.3039535148532016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16050307344776826,
                                   0,
                                   -0.17480948331427473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13372886341782744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3047946721044803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20567937039411655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47318438158956622,
                                   -0.65520767401053814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38850761616778928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54990272060581136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13355621137087059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22311223307241737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53748542213020645,
                                   0,
                                   -0.019556174413869837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15624916366247874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13339713801464664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012455459577051346,
                                   0,
                                   0,
                                   -0.35306233582660795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029052260779360302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24042096095428711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35070960247077343,
                                   0.5776856370674146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47998767165433331,
                                   -0.29534876530932813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089032310498382186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073158577060688054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35617591276063809,
                                   0,
                                   0,
                                   -0.66546037515169587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38562055985978994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13299102507634628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055368522985745974,
                                   -0.13761228644322449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46812559070432336,
                                   -0.097406705284621781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0034808588359697828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090588205160630819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35359846589859167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49016390099396689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09022088739977184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74720365125885035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23322179595548509,
                                   0,
                                   -0.075124062041528814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56320354404914674,
                                   0,
                                   0.29589091208277302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24140931484515973,
                                   0,
                                   0.039812449021228921,
                                   0,
                                   0,
                                   0.42940010749793084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0050777155739469256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2785120151548125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27629717613874427,
                                   0.24720094300208728,
                                   0,
                                   -0.1959656478580982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016588834302548677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.240976335207707,
                                   0,
                                   0.10528979573942901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16770800243766931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10707547626470418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083930357654393037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44540945272825505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43722603365772572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32802378289675999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091978720557375021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.251708924357742,
                                   0,
                                   0.64227508325976956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032139972376385148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62723764276621552,
                                   0,
                                   -0.027580791807075969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34913050543295032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28385981593495591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11303583319830762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48948719896819759,
                                   0.24636043531308943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29341366827021731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25048990285221467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15429929903500225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73610683698168278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035800047153616003,
                                   0,
                                   0.51370926681584272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50539864859927031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99297237881380329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020172743586622254,
                                   -0.39881915350078007,
                                   0.37166191768654966,
                                   0,
                                   0,
                                   0,
                                   0.014851873828318506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3326272868585019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078113645518088526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.167623267866292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55917585097205602,
                                   0,
                                   0,
                                   0,
                                   -0.098124281213571724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31771175897586751,
                                   0,
                                   -0.19342080673211143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042107883227426743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012192350130243109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27584794563299614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27036948966365237,
                                   -0.019223632768228784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39457837921242678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69705510985797992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51984456019296554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57810871172514822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51348021105434383,
                                   0,
                                   0.35288807825807633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25964563179627109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060127816966151881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55964510006705115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2908043214942283,
                                   0.191936590637066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68022898991739889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1938641557967267,
                                   0,
                                   0,
                                   -0.23156889204979417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21193593744809272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58164669834525695,
                                   0,
                                   -0.41471553857702481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40715460896731775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22229562218717108,
                                   0,
                                   0.76962051220054228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80118682282731435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36651236758307076,
                                   0,
                                   -0.16475214630689447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22701090464166152,
                                   -0.15280556957362429,
                                   0,
                                   0,
                                   0,
                                   0.15923649884710062,
                                   -0.60172965261634714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2205010009629022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36429079525812874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75844627882797999,
                                   0,
                                   0,
                                   -0.026907393735496943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061989360210703753,
                                   0,
                                   0.81146664084265507,
                                   0,
                                   -0.19570045187817797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29106588041213977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2912266691836094,
                                   0.3907510906837085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3069012972616752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49248805835480591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41022084376049056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32693295117407839,
                                   0,
                                   0,
                                   0.0041464895340809979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15782701404164234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084061096833918506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39533515991184459,
                                   0,
                                   0,
                                   0,
                                   0.54222366303837177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19411929854037233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21263228750878282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16141010403459535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7085729428045896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10714762035859884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033783979558458528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4191023534906706,
                                   0,
                                   -0.075686575291195407,
                                   0,
                                   0.18085967274505632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81784939715805038,
                                   0,
                                   0.5525949221389943,
                                   -0.51792434575210922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21550493857082406,
                                   0,
                                   0,
                                   0.61799274091306122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018033460536471761,
                                   0,
                                   0,
                                   0,
                                   0.10383811506499695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11874010977640417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11469553321959342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23522700801253107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14746891349671271,
                                   0,
                                   -0.51162764250077608,
                                   0,
                                   -0.042994302559835766,
                                   0.00052976328501159325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02429711317348112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43321001722092017,
                                   0,
                                   0,
                                   0.065795326830606599,
                                   0,
                                   0.14563005217142697,
                                   0,
                                   0,
                                   0,
                                   -0.59885501703173172,
                                   0.55814532888808299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57220782240230517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034198016967047204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36636286342391911,
                                   0,
                                   0,
                                   -0.083701137359167316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16269603143585715,
                                   0,
                                   0.57023524956055338,
                                   0,
                                   0.58927386374015889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075762598182407478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62391863327919916,
                                   -0.4050322725368124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29913710074925409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040925664694363068,
                                   0,
                                   0,
                                   0,
                                   0.15438407238627852,
                                   -0.143325100995641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6696011686198452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79917035742466536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30839124722124178,
                                   0,
                                   0,
                                   -0.069803312365538647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61913373548396422,
                                   0,
                                   0.29867340071671122,
                                   0,
                                   -0.16693948033192796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47895792314594543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29787164046937942,
                                   -0.28191329192577175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27900675909040251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3212323156276175,
                                   0,
                                   0,
                                   0.19573440362582337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17161239104516979,
                                   0,
                                   0,
                                   0,
                                   0.16014978137139671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15993553960789403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11754549013414158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054474219262816467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058398228824804374,
                                   0,
                                   0.046682293394008159,
                                   0,
                                   -0.066169585485580024,
                                   -0.32029042311204298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38126921142669112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023686346901755376,
                                   0,
                                   0,
                                   -0.70891050515341802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66996575060129682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4396571570307265,
                                   0,
                                   0,
                                   -0.21284140806090016,
                                   0,
                                   -0.33012210500657779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3944104588496456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39706811360589089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98519903800654496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11422703236610754,
                                   0,
                                   0,
                                   0,
                                   0.66330651672837204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34607298563694622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24860867108390175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28173016298655429,
                                   -0.1772585740739526,
                                   -0.51039500459754139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31743673546431089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35148418879199933,
                                   0.091588025517992097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052888943021368359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56815829277581364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092744340902684907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40910813044092742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17381454970737159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27268668235674176,
                                   0,
                                   -0.2746291251265075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4532304169224719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66874662316228484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32474240681578587,
                                   -0.65387343996199176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42248404765533548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41639999507679537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60038368705287759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45426580161495672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3787679911993399,
                                   0.38076543318930667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0865678086962027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47086064288400509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38787944799705371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085297514688087217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35050727758219569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2167764301015053,
                                   0,
                                   0,
                                   0.11050313651959269,
                                   0,
                                   0.47278178465640708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63815963032156908,
                                   0.20999087890869908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044743794233504837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17078786938514409,
                                   0,
                                   0,
                                   0,
                                   -0.01692047325023141,
                                   -0.30505632334978694,
                                   0,
                                   0,
                                   -0.062565194798714266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12101494019897184,
                                   0,
                                   0,
                                   -0.45628555696098488,
                                   0,
                                   0,
                                   0,
                                   -0.35758237641393997,
                                   -0.53005317220163628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14172287010445503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10798075414843926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37189989912963978,
                                   0,
                                   0,
                                   -0.046532006569508587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73919289130104271,
                                   0,
                                   -0.07632775892804447,
                                   0,
                                   -0.26725442582400205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71635167945681621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46377626750007211,
                                   -0.43428250359612453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25490016012764555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31178151011171867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16926497229560689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22106236839184565,
                                   0,
                                   0,
                                   0.54508631546747643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16554697316865535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065806710719699929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37561878092234402,
                                   0,
                                   0,
                                   0,
                                   0.59609412427456709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34667829368160469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74192044847602079,
                                   0,
                                   0,
                                   0.21983731769604575,
                                   0,
                                   -0.12351922524925288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54072749517008722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83887186807494674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31966210854347532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036205129042883095,
                                   0,
                                   0,
                                   0,
                                   0.85760335662755582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44187019863382315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27365425216951994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0159428223345484,
                                   0,
                                   0,
                                   -0.3984425257093317,
                                   0,
                                   0,
                                   0.87935934231816759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14031228119055345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18501235873790822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60547211899753739,
                                   -0.45018199574338774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12083239488277789,
                                   0,
                                   0,
                                   0.29684552565053601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057125606078832158,
                                   0,
                                   0,
                                   0,
                                   -0.57517819078486465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081874310269061973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46509136676391438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090327108579958112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21088776028077094,
                                   0,
                                   0.31547818977768083,
                                   0,
                                   -0.087826654475785804,
                                   -0.23386694992919116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34928450090670415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030923092497935095,
                                   0,
                                   0,
                                   0.051510233628217744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030546587210579998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10655467901021237,
                                   0,
                                   0,
                                   -0.88187083386001164,
                                   0,
                                   0.10210034058331501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20029091316082384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35722261411946699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67545746419379682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48713763909189017,
                                   0,
                                   0,
                                   0,
                                   0.17926775939976844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52510997076625066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54449028394837751,
                                   0,
                                   0,
                                   0,
                                   0.31801048210497534,
                                   -0.0023989636580787899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28310777135901438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31906941174735681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37297942632108622,
                                   0,
                                   0,
                                   0.0022839684494240231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40768684678588918,
                                   0,
                                   -0.097239605709653176,
                                   0,
                                   0.47702779607734519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68499474125321647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64608138192706743,
                                   -0.47537303841433093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15294071832853112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49818122306234941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068638529331136414,
                                   0,
                                   0,
                                   -0.029579829223593986,
                                   0,
                                   0.17129913021954826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1550304637303321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14702367527197716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22262615065847757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025951946625960922,
                                   0,
                                   0,
                                   0,
                                   -0.60309134927222674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27552178763647822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0059190161105305613,
                                   0,
                                   0,
                                   -0.41600294978679803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23199551353753037,
                                   0,
                                   0,
                                   0,
                                   -0.2527210689024259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22070142501723197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10391810443483941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41715687155849829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39238892658870905,
                                   0,
                                   -0.12532358128495608,
                                   0,
                                   0.49110639971763459,
                                   -0.098948015822623733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1235573863298688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11760369416336224,
                                   0,
                                   0,
                                   -0.16106015992132183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11444041709194348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7052732445710912,
                                   -0.050679752451363878,
                                   0.10996939502735716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16048783359254798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21414568151416644,
                                   0.2151851492830433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38159131218743408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40518720329837576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21707918119599659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64035596665631711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14945577807248139,
                                   0.53753817152375982,
                                   -0.098039288708927627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34564456126241128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037275605093945369,
                                   -0.13807547191796271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051166574506275903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14038839199063818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32679784275534807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13667995448702538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21803156482299346,
                                   -0.19264766314084386,
                                   -0.34877945754135092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11966101720631261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39910488377792463,
                                   -0.72014217343634468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12239755242629032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18264111555675844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18567024392230408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49290799767611959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57326902750860853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3687832093254006,
                                   0,
                                   -0.49306581500169744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21523160100122954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054449356773706402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034539001798999075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34239194004330231,
                                   0,
                                   0,
                                   0.96705244567250137,
                                   0,
                                   0,
                                   -0.025358309116507435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22501645926914482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2477564595369709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02839114694287205,
                                   0.44420506632257067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73111092771629438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12813967425003486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21672840590787362,
                                   0,
                                   0,
                                   0.28590647541928088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10357111913595138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35752486040472231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41092271487457849,
                                   0,
                                   0,
                                   0,
                                   -0.11373144031658061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048146958975122431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07330937654280284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5611200055620913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70841712395851286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058822433577886322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33945181730099677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78205894509198803,
                                   0,
                                   0.029213670226978017,
                                   0,
                                   -0.69196715966355204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34422518757092496,
                                   0,
                                   0.42997170754327124,
                                   0.16434053307573188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82853943330052948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39364278057132485,
                                   0,
                                   0,
                                   -0.24511434661299281,
                                   0,
                                   0,
                                   0.78884406778507143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6005885494093921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76955812547630387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22868368624487478,
                                   -0.46935754570636601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20605552621166265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47343664444228944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13108069557985549,
                                   0,
                                   0,
                                   -0.22048532770597179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45159201826090378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45533674499258581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44857232750548554,
                                   0,
                                   0,
                                   0,
                                   -0.23477414684854866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16595608591106831,
                                   0,
                                   0,
                                   -0.19879516702370265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29660757303726987,
                                   0,
                                   0,
                                   0,
                                   0.47248276910491527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090550222849163572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3251666911457789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041346084879328254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12683100032798156,
                                   0,
                                   0.35001346108987874,
                                   0,
                                   0.10241482090322668,
                                   0.00093461324408797286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093501444095876574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58961912215939605,
                                   0,
                                   0,
                                   0.024543779548242092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11519582153181834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13613575372540301,
                                   0,
                                   0,
                                   0.085273210108869485,
                                   0,
                                   0,
                                   -0.38523896773924049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064405806360369938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19156491609006854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1198828789641908,
                                   -0.1128531618651767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78453287163409868,
                                   -0.10654767355630003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043320203589305904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34774130657591557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2357129255449473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23702850081991431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1590515547729428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04313979625434116,
                                   -0.1145528376057951,
                                   -0.68150319331911924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32742899252537128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070871034826635343,
                                   0.32886629388525163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18775923074442399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39662545857534193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2869178187190749,
                                   0,
                                   -0.28592992379645665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48650942107917405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37173451463750784,
                                   0,
                                   0,
                                   -0.085250179975203608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33320356231156389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56081359332597636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31227727328150728,
                                   0,
                                   0,
                                   0,
                                   -0.11421437525954635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49565590098345153,
                                   0,
                                   0,
                                   0.21388149417960156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40853967168237793,
                                   0,
                                   0,
                                   0,
                                   0.25236263876394249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33885899776774275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23395551293587302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24499880272115904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12890341512365,
                                   0,
                                   0.23093538529648966,
                                   0,
                                   -0.18339766003260422,
                                   0.18371655435575149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25568032829089909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12972077458932901,
                                   0,
                                   0,
                                   0.16991093976589378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.283923257550315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4850446631476043,
                                   0,
                                   0,
                                   0.085652487435443042,
                                   0,
                                   0.39764184144691794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36522924025049813,
                                   -0.0022314238199451358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036006512830050533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29124335589630851,
                                   0,
                                   0,
                                   0,
                                   -0.22525862052965381,
                                   -0.1582110505234198,
                                   0,
                                   0,
                                   0.021750290024315274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47212506780294694,
                                   0,
                                   0,
                                   -0.39297568047742171,
                                   0,
                                   0,
                                   0,
                                   0.32976492699066684,
                                   0.21373399148716204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30574717601332874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29831798485156746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091090639516599098,
                                   0,
                                   0,
                                   -0.74038738195190457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86343719092699267,
                                   0,
                                   0.30376488941591223,
                                   0,
                                   0.45873840351520256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22565043724005041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4437503188769189,
                                   0.46241550222564232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41047031618769803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30876739155478533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68202813481335789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28825388574738298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0000293229333381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39695845024582505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15508842916386367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51009726804193978,
                                   0,
                                   0.054968609294771459,
                                   0,
                                   0.53815042171410721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3400574158767008,
                                   0,
                                   -0.18440159255729352,
                                   -0.36650908515853237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26430085321311564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43577511794022239,
                                   0,
                                   0,
                                   0.58566186278145671,
                                   0,
                                   0.091684459246843944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26416619647137107,
                                   0.15922015077498827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45088093204108998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24274468142776362,
                                   0,
                                   0,
                                   0,
                                   0.020557643657155011,
                                   0.044997765351798787,
                                   0,
                                   0,
                                   0.11720284985800371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12370082201054414,
                                   0,
                                   0,
                                   0.23308785085493761,
                                   0,
                                   0,
                                   0,
                                   -0.18495739525472404,
                                   0.21088457941573599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03224531575423753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041739136146306324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033273343059383717,
                                   0,
                                   0,
                                   0.89289725869549752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35124080585314499,
                                   0,
                                   0.5255665166803225,
                                   0,
                                   0.17609645628557241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3673174195678538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85659930527712624,
                                   0.3216309964134304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33827573137711431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28901013361562866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34507904603647799,
                                   0,
                                   0,
                                   0.099448597271872802,
                                   0,
                                   -0.11041377088698412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19005070962669521,
                                   -0.15157676547437005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5663742076922611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10999301114390062,
                                   0,
                                   0,
                                   0,
                                   -0.15330174594446139,
                                   0.52454382950572165,
                                   0,
                                   0,
                                   -0.19011835546134728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22033323214373798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89294689704474928,
                                   0.065924839227536877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28615618293756478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073854339137948394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48189791295875878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.159015703347466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43903463538673082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84686141098033096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35197544767092342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46360520852673193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039822673094254558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50292472984256531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30440115758954805,
                                   0,
                                   -0.019732204841542547,
                                   0,
                                   -0.12356927356716292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48622998219010116,
                                   0,
                                   -0.24269082304795953,
                                   0.48946739872508771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61338944076939272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60650140279772602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36704822523801339,
                                   0,
                                   -0.041772978050710147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26703783563921335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21938745485675665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25832846696371176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45213964371594562,
                                   0,
                                   0,
                                   0.091047612223019297,
                                   0,
                                   0.76948538877036743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43027583813794601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50321717884505723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56937464123044479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34745893452283688,
                                   0,
                                   0,
                                   0,
                                   -0.47400954117168248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67963521975581376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44605325256068379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39078139651545823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51958895684116713,
                                   0,
                                   -0.39733378148721038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14922192176400614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44521050762566255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31859568125875248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35163576480673309,
                                   0.062984727347730918,
                                   0.11903329253575083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61217034120111158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43137652157515149,
                                   -0.1031847826364946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18755733652891962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10510075148785572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3728321718302306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52138414877110995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022319145117819364,
                                   0.64455155622944149,
                                   -0.10650831128042348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025067788635782164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.005101873606508843,
                                   -0.12801231899633589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50333676439266195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13814507615939686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10675279270007645,
                                   0.60772761809622744,
                                   0,
                                   0,
                                   0,
                                   0.46228954338805439,
                                   -0.73346224211043076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41956441230469466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34487302734917974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42382819555232548,
                                   0,
                                   0,
                                   0.055526701174157062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29389845578348989,
                                   0,
                                   0.040003188653442642,
                                   0,
                                   0.3256356139357357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36748360488061482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14574351145544759,
                                   -0.24896394599063723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19083301303275232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11013126255936073,
                                   0,
                                   0,
                                   -0.34482707678464697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56552907949723308,
                                   0,
                                   0,
                                   0,
                                   -0.089992249228792134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12265587082624997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14162551160792902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14136835381176543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12919074949849968,
                                   0,
                                   -0.083665879377225805,
                                   0,
                                   -0.45091464572033019,
                                   -0.17342504925596611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0053954116780105185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47571917493436,
                                   0,
                                   0,
                                   0.050279711308968238,
                                   0,
                                   0.044778141677359537,
                                   0,
                                   0,
                                   0,
                                   0.14135644793869703,
                                   0.54953728350411657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39653790639934688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66170829283663257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26608010531891435,
                                   0,
                                   0,
                                   0.12376478439494445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43027159759941486,
                                   0,
                                   0.11975667035774552,
                                   0,
                                   -0.1996129241810182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17799557825603149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099760134663088418,
                                   -0.0037274389987892783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90062622084777555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21071445977234607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070590342001377843,
                                   0,
                                   0,
                                   -0.38434251007060327,
                                   0,
                                   -0.11602667433331354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33823958755805589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91951224171805823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25293035703950029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010549753195822284,
                                   0,
                                   0,
                                   0,
                                   -0.23471009490010139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0876932541963549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11259541929733911,
                                   0,
                                   0,
                                   0,
                                   -0.91676362627381769,
                                   0.12179567904873405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016901176418359153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58695918956371507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16056815486943893,
                                   0,
                                   0,
                                   -0.1916657116472153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23145507566450021,
                                   0,
                                   0.55712759079397667,
                                   0,
                                   -0.52972318325077505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07793414968252585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63635091170189928,
                                   -0.47943950670169538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071458297289507214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28929191128071002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56456465225024244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028374976706893873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24180412505152699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19633563224521144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56344094779818654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58920614611218136,
                                   0,
                                   0.66195131199409141,
                                   0,
                                   -0.36088258202700163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3828632940037896,
                                   0,
                                   0.38980740188874741,
                                   0.55241131135304566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15197607052176659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15056960112849632,
                                   0,
                                   0,
                                   -0.28749958881071747,
                                   0,
                                   0,
                                   0.1001611273336559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3393426708956473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39540881448188225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33168831666093807,
                                   0.036218214103907506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0055683794888264776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3535464208349347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19980386762256916,
                                   0,
                                   0,
                                   -0.28135313649847055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5607923895902287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40405152834202923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46172348848176581,
                                   0,
                                   0,
                                   0,
                                   0.2548694311536579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21761185654917495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15155382382124835,
                                   0,
                                   0,
                                   0.41599118622988263,
                                   0,
                                   -0.13336683327047538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072858229278362718,
                                   -0.34869358386375665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.004737522691590404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20309762614171323,
                                   0,
                                   0,
                                   0,
                                   -0.27228595845498843,
                                   -0.46529817874481122,
                                   0,
                                   0,
                                   -0.5245295087525248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070009059433143297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45455765618389216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061893187222693741,
                                   0,
                                   0,
                                   0.32709189405170302,
                                   0,
                                   -0.32294870223209032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075352670079853634,
                                   -0.011143219887345086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14561649290182432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19302435090169806,
                                   0,
                                   0,
                                   0,
                                   -0.39730180933221798,
                                   -0.12048705362990814,
                                   0,
                                   0,
                                   0.54822558465448501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20268125322243311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31089307265540256,
                                   0,
                                   0,
                                   -0.14899805616064107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17480710799035709,
                                   0,
                                   0,
                                   0,
                                   0.24180060218733834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089912707992140434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075948289954806444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57349739082577178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24751164735912937,
                                   0,
                                   -0.011420820576578172,
                                   0,
                                   -0.30009235577892052,
                                   -0.44930421325691733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14624744713927448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27262937768784679,
                                   0,
                                   0,
                                   -0.018195691302066809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027889788843367042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67102176406868663,
                                   0,
                                   0,
                                   -0.48238841265959748,
                                   0,
                                   0,
                                   -0.61007100044895701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032808146855641117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76603917976919467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12424284647652284,
                                   -0.37151938987343924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14514902016167763,
                                   0,
                                   0,
                                   -0.1010266219912628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091846217472552782,
                                   0,
                                   0,
                                   0,
                                   0.16271550333613383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44674916599780878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24821167977448161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15390714673842715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064894747197256325,
                                   0,
                                   -0.087049371493420638,
                                   0,
                                   -0.17648956654987574,
                                   0.55341537689736242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41746253919687509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11328224878129273,
                                   0,
                                   0,
                                   -0.33558627577951433,
                                   0,
                                   -0.68534040576010835,
                                   0,
                                   0,
                                   0,
                                   0.28718792996990311,
                                   0.13534356454067373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41653180306186555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40463229197953204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19594355454841339,
                                   0,
                                   0,
                                   0.46443818955676763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50491758027450162,
                                   0,
                                   -0.001208105903866788,
                                   0,
                                   -0.062630921463800671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68905000221855084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22877496285559057,
                                   -0.68901815315296955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25831713036591814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073794524950416357,
                                   0,
                                   0,
                                   0.010377860431052939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16291702937713459,
                                   0,
                                   0,
                                   0,
                                   -0.049231355070773156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46001268781534432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01583425215984588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058932912624886979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70724148121068309,
                                   0,
                                   -0.15101279069729096,
                                   0,
                                   0.21286802197122795,
                                   0.25713640138544641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038421559681364362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0039989378878558107,
                                   0,
                                   0,
                                   -0.33797335913764531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24366913757182179,
                                   0,
                                   0,
                                   0.084905041965351966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36449145170698743,
                                   0,
                                   0,
                                   0,
                                   0.08095333574358296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2216214369620475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19854186889964892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35102017617412973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1719120836043275,
                                   0,
                                   0.28839061050283288,
                                   0,
                                   0.20610237555527056,
                                   0.21059196428743429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53316428121889414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056979114567788675,
                                   0,
                                   0,
                                   0.30854186359041935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086084055016450445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31080833631021898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60512017776363902,
                                   0,
                                   0.71036752090268962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075491727490930513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1396290383204819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.117823250212974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44349955536943519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75017383568531226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073440943095902156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65276297994898946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36083880243111127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065782057167531799,
                                   0,
                                   0.55703436223979175,
                                   0,
                                   0.1783458799656879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14974748365310395,
                                   0,
                                   0.52434414494271164,
                                   -0.011632254047036168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46232663614518127,
                                   0,
                                   0,
                                   0,
                                   -0.19768851727007969,
                                   0.011832900077661728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79675910940511474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1605714719659351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23944217461490694,
                                   0,
                                   0,
                                   -0.29706731413392201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52835930781438323,
                                   0,
                                   0.019418199867601821,
                                   0,
                                   0.66885329369624069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1365164939345189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029644540444597117,
                                   -0.58430948890518597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71065734415722337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21474840551312285,
                                   0,
                                   0,
                                   0,
                                   -0.54356792832056944,
                                   -0.43347847655633387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25146577604598036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32221188957325825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30441409739269992,
                                   0,
                                   0,
                                   0.47779321962694371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078921646597435335,
                                   0,
                                   -0.74716285751446587,
                                   0,
                                   0.54984369209652562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13388695924564037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21391661828324493,
                                   0.5950996789265075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015450931107384769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1061499109816235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031291251813105464,
                                   0,
                                   0,
                                   0.65318667418880894,
                                   0,
                                   0.1758170181288766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36447731830980246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098511860645645183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50052977190404035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11197315773653639,
                                   0,
                                   0,
                                   0,
                                   0.25000494016447444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35250378453729891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.001728504921155144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37814303408862487,
                                   0.020455004790000078,
                                   -0.19583947087802639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15832257693307111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65995060572803421,
                                   -0.31977982834516983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27964412849911707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41337725204003661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079320756262444558,
                                   0,
                                   -0.027143784315070002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0057923277065685813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4128913401276515,
                                   0,
                                   0,
                                   0.69702437125980765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22154000553425029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33868266504925182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095964203261742972,
                                   0,
                                   0,
                                   0,
                                   -0.41220429530225022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10210686093913449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044228992776123133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2387004844118813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053897945081784332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42064373873534311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59787777917421026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12875841739725519,
                                   0,
                                   0.5558137766052943,
                                   0,
                                   -0.41065341903988145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19020780878959648,
                                   0,
                                   -0.21948816934362242,
                                   -0.42488791204755538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2884358029600777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010946422612937282,
                                   0,
                                   0,
                                   -0.16068069109180716,
                                   0,
                                   -0.10210132518685595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014368105401113468,
                                   -0.07385108926510757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20886249724823108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73821854436527357,
                                   0,
                                   0,
                                   0,
                                   -0.3919012353355264,
                                   -0.025627436499960386,
                                   0,
                                   0,
                                   0.056237229078985436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35886688447741999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0073844454652345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18251601271869403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26484065259093603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3135732462949391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33168141765478326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37208525306885992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12552908979453517,
                                   0,
                                   -0.63372776125638275,
                                   0,
                                   0.29027819097756752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40930046758291111,
                                   0,
                                   0.61985089608548349,
                                   -0.10752928286112684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027240055479052339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44809168318132481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65689080553346146,
                                   0,
                                   0,
                                   -0.015403511316802773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50835992507849703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24692541395305237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11238873885198872,
                                   0,
                                   0,
                                   0,
                                   -0.18626814591737684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13076697923462488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3163815395720902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68628794196463461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16601569750506581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67624973786894693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10553279605690721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036939174936691105,
                                   0,
                                   0.63825749648509578,
                                   0,
                                   0.65290457472518115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55272595018224024,
                                   0,
                                   0.34680540393479919,
                                   0.34045248426896957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16975646332162606,
                                   0,
                                   0,
                                   -0.0050677273563243842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35239213317009499,
                                   0,
                                   0,
                                   0,
                                   -0.40017635395025269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1113906511107557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44656325209353054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42009277945097301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078201210276796079,
                                   0,
                                   0.12006440149823208,
                                   0,
                                   -0.17435027667063183,
                                   0.30828858226497041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19490053138637287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30643071712266634,
                                   0,
                                   0,
                                   -0.14378599597964528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31137342962362796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12121624506106615,
                                   -0.10970982149797284,
                                   -0.021137081092897855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42498863074395971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10080509968713397,
                                   0.29342409040799206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34894609472453592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2186967071559475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65528914241485359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14657126706186044,
                                   -1.5688611370657302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5602534823541393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51364696104371133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061922125203077182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083757411133223922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15854014388881194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016485658004400269,
                                   0,
                                   0,
                                   -0.012938069449283498,
                                   0,
                                   0.54821339276239656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27092064493719525,
                                   0.23345184842216646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10634306874628278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37765835794903713,
                                   0,
                                   0,
                                   0,
                                   -0.37526497173119783,
                                   0.250877832554188,
                                   0,
                                   0,
                                   -0.10585314509441826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42081719193113065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95099495679605106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16162140751690041,
                                   0,
                                   0,
                                   0.38490073070140973,
                                   0,
                                   0,
                                   -0.38044613905861024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013255931621780771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22752068385155352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019280758741641132,
                                   -1.0846865372176726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65349455076512997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17614644505959615,
                                   0,
                                   0,
                                   0.19957266390412079,
                                   0,
                                   0,
                                   -0.41395310935439916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62835501108972314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36520895743714843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16895451412016779,
                                   -0.42995256723818503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1977297019899131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0018809697283522,
                                   0,
                                   0,
                                   0.16484790262334043,
                                   0,
                                   0.47910007920505504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19743287773149104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5735490193545113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47118535459816469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11664764687453977,
                                   0,
                                   0,
                                   0,
                                   -0.61106613194567805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56577846758950123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013923149691438857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41858192737755356,
                                   0,
                                   0,
                                   0.1467549859339044,
                                   0,
                                   -0.2445310607292851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1168206997826242,
                                   0.69435460055806608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0234622838179364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07574467012320045,
                                   0,
                                   0,
                                   0,
                                   0.28308356599822782,
                                   -0.230740028053112,
                                   0,
                                   0,
                                   -0.10271374488277935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31188515533406386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16152030426821801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018985618632415185,
                                   0,
                                   0,
                                   0.49144086589314834,
                                   0,
                                   0.043613362767798702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0027738229669757863,
                                   -0.11073900205976352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60743808677193134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16474991894827229,
                                   0,
                                   0,
                                   0,
                                   0.31193557722258658,
                                   0.42258081704643513,
                                   0,
                                   0,
                                   -0.20827814203748243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049819334233423329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083974214724631402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15490400585927405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13701607397151142,
                                   0,
                                   -0.13123953424702411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8055942890744362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53289182932828194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10223330446869956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10851226086985161,
                                   0,
                                   0,
                                   0.54495817807247249,
                                   0,
                                   -0.95782206267731251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079214931880221773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37476839021802744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.155455034768926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1712224833415301,
                                   0,
                                   0,
                                   0,
                                   -0.15236805989816402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072617465434457684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44687305640701336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2941238008810364,
                                   0,
                                   0,
                                   -0.19698396578491506,
                                   0,
                                   0.037982295967660534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50312644775085458,
                                   -0.2486560428062915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13249241677261922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12455274926947607,
                                   0,
                                   0,
                                   0,
                                   0.25602046325237754,
                                   -0.23986810233931638,
                                   0,
                                   0,
                                   -0.26152006738302686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36611571389145592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57429633663963675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75188159037362234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26329000458761903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60954285061846791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50732522819900827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83249052254914668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10860934463408051,
                                   0,
                                   0.39412495415010168,
                                   0,
                                   -0.57750782766647346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01188656704030118,
                                   0,
                                   0.012637338766915918,
                                   0.21261098435843206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77826292647139206,
                                   0,
                                   0,
                                   0,
                                   -0.21644582267681189,
                                   -0.01610380624202333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029457834895517121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12736502074862022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52692948966273012,
                                   0,
                                   0,
                                   0.028979998342995639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50745073734870905,
                                   0,
                                   0.53217086979553352,
                                   0,
                                   0.40898772314311421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076791869636532423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13450212074194684,
                                   0.1345674492362437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40680285151180406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04888762760216514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58308906505731528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14744082174550016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18745874217442041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1187299799285422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20559159282155162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35662196606054547,
                                   0,
                                   0.1595256177746015,
                                   0,
                                   0.3082346347602023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0063970322925951647,
                                   0,
                                   -0.41819757168993166,
                                   0.87116938639299657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59807772616856625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48515096502258132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41355793909591088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088785917737276079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022163129850832936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61720476277965863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46610801922150652,
                                   0,
                                   -0.25504675332539706,
                                   0,
                                   0.50585952756742458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7378645517134601,
                                   0,
                                   -0.63555029986411782,
                                   -0.21692469100268602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27664958045800703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55510807840118259,
                                   0,
                                   0,
                                   0.11121538259354588,
                                   0,
                                   0.61480439400932529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43190106859772159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26255642073104291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099433178265287581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82060400412836998,
                                   0,
                                   0,
                                   0,
                                   0.27012680452795218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11638961002246256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11188082679236484,
                                   0,
                                   0,
                                   0.15198046638457913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10194889925189507,
                                   0,
                                   0,
                                   0,
                                   0.14044771256432298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51005979318391437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42537425593605172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030855951206390085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25505213968972007,
                                   0,
                                   -0.041352388361533945,
                                   0,
                                   0.50408218361523793,
                                   -0.23520291798360179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32135123440374941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098483561946962728,
                                   0,
                                   0,
                                   0.055341107446001202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84533937763249423,
                                   0.53504311134951144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44008666284633591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64253598713126903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37177823568223822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39311670996653125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23423165873079302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34567199707421481,
                                   0,
                                   0,
                                   0.1403053154757512,
                                   0,
                                   0.31870944162309728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045552821212252709,
                                   -0.41192945763372363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096868050539680201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022196619113884056,
                                   0,
                                   0,
                                   0,
                                   0.39454134640612099,
                                   -0.14412037854394347,
                                   0,
                                   0,
                                   0.4830718054495185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3360894781131728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57140986286539242,
                                   0,
                                   0,
                                   0.22711156061659993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073971952898937404,
                                   0,
                                   0,
                                   0,
                                   0.0076564181458844138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16085380166933189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27925601557405233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14525183692675234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24621690065931126,
                                   0,
                                   0.55513724450104351,
                                   0,
                                   0.062727218606133853,
                                   -0.011277774325722204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14133930875057096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11033221018565396,
                                   0,
                                   0,
                                   -0.29396030662445366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027595460129526309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2639138936281929,
                                   -0.44154248196014317,
                                   0.25958705119289449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22675231427592851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18192143069426586,
                                   -0.28998839859234965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55699933011641289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23195219397594749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36686153038145125,
                                   0.40690347554898898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027022992585770567,
                                   0,
                                   0,
                                   0,
                                   0.29823316689918933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44069196920999359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40065845146562906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43394351391395108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80594348289237805,
                                   0,
                                   0,
                                   -0.075082396556628461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29573351177792945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46566040409863391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1178168677364069,
                                   0,
                                   0,
                                   -0.73919067235371727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1832445232836909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014451653945894788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11535037740737746,
                                   0.0010073178722178333,
                                   0,
                                   0,
                                   0,
                                   -0.70961782197519219,
                                   0,
                                   0,
                                   0,
                                   -0.25563361215874936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30127346925855736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32507432180210261,
                                   0,
                                   0,
                                   0.17910164461316302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69361824900603908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47850686229960032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33544326190407037,
                                   0,
                                   0,
                                   -0.16915797934120591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34293549989470945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30566613556752381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15125056074555188,
                                   0,
                                   0.32949033752177637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077667024203715809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44271422648078085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057620478758144605,
                                   0,
                                   0,
                                   0,
                                   0.075162586228237849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21393807860347247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16168290388929696,
                                   0,
                                   -0.067148870646354664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49743101050299299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17116324096457694,
                                   0,
                                   0.16837010191114657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020886224770531411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32972864877628461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26373444410917762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055126432102500511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37419768154005195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035289336987466405,
                                   0,
                                   0,
                                   0,
                                   0.60983260375697323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.108884773744802,
                                   0,
                                   0,
                                   0.048500765085583188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15690625923314011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12207267306673143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018611161320944404,
                                   0.0030145334781493047,
                                   0,
                                   0,
                                   0,
                                   0.41626793554582309,
                                   0,
                                   0,
                                   0,
                                   0.012858432964640794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41709703342033022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21440111775522613,
                                   0,
                                   0,
                                   -0.10553045059218283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92937159031800642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15786097968965843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30170309905071507,
                                   0,
                                   0.92828977492803288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62842834484867038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58410603674435801,
                                   0,
                                   0.21337452155266901,
                                   0,
                                   0,
                                   0,
                                   -0.1394871768269772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12969421594396122,
                                   0.53114979821272179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12941978883968033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14638419374189932,
                                   -0.029150471364942379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19815906713654061,
                                   0,
                                   -0.060811743677297463,
                                   -0.50614623145607518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084116974384810347,
                                   0,
                                   0,
                                   0,
                                   0.86426655113830764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20547286047101065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42945675772519992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71597861042450472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17317591487213302,
                                   0,
                                   0,
                                   -0.20775855454291331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42896779930988954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12446610782590896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49692962920873868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81484762804802358,
                                   -0.50104906463742138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084961315129395518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40462950968434741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3227835925602278,
                                   0,
                                   0.28927603596040791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011489346554155878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16482227684091003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11714247905530033,
                                   0,
                                   0,
                                   0.026972355544878958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42378417687921066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30334835290101758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37074202852275767,
                                   0,
                                   -0.27484188394906112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080003375496938534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51262170838913013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44459670659168765,
                                   0,
                                   0,
                                   0,
                                   -0.026697105046573161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039328512690234838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0024169393157501325,
                                   0,
                                   0.068335112413087151,
                                   0,
                                   0,
                                   -0.056647799415393052,
                                   0,
                                   0,
                                   0.043770290039043092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60534073617979622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90898356770031308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61527821152754858,
                                   0.23369457585470246,
                                   0,
                                   0,
                                   0,
                                   -0.14282734492432198,
                                   0,
                                   0,
                                   0,
                                   -0.44253829154353141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78645382317048584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26385072018248057,
                                   0,
                                   0,
                                   -0.45896317277945031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29365419341860416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062795335413175168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035101000903685411,
                                   0,
                                   0,
                                   0,
                                   0.040165942151484529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86280847171174369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54634018868018097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17833839203721022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49388950885995409,
                                   0,
                                   0,
                                   -0.51791398758370633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35247183530208959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4916913579889477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30943702154709846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16478260437547632,
                                   0,
                                   0,
                                   -0.19401936935440109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16288512069877084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28064461766061466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20745935984200195,
                                   0,
                                   0.21427967818474347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074385638175261268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052415338538151161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10560854467174147,
                                   0,
                                   0,
                                   0,
                                   -0.063101647903152758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1478180594937791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73922019630889968,
                                   0,
                                   0.23128235118707272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77704173642275642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044703279959520559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10765910895420212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36982043153974209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24478070572155466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43119894178832791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27906655490313242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36830088289311558,
                                   0,
                                   -0.014961339209908501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43870131452945949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0077649485716714955,
                                   0,
                                   -0.087250149877257932,
                                   0,
                                   0,
                                   0,
                                   -0.40413712504089083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24336429796232001,
                                   0.32397656824239618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14288865728429759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29544381856301705,
                                   -0.8884223814114931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82169735530982968,
                                   0,
                                   0.26587388373285248,
                                   0,
                                   0,
                                   0,
                                   0.39917071655007702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25980122450826987,
                                   0,
                                   0.21663298882936288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6182362278437229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40686761593143222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25186749346354842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17371419180653164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084457987676326049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15188554258405679,
                                   0,
                                   0,
                                   0,
                                   0.23380054791338861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22208965507142886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58150879113556131,
                                   0,
                                   -0.66908273052086409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040790246684498335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42752073337684582,
                                   0,
                                   -0.03945570001943334,
                                   0,
                                   0,
                                   0,
                                   -0.88433023865296745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51541455120232216,
                                   0.23498656516297844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54866228204878609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033088398175037684,
                                   0.42772007458460826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13617992115940458,
                                   0,
                                   -0.22298572215522605,
                                   0,
                                   0,
                                   0,
                                   0.38288565032232202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018521320198887734,
                                   0,
                                   -0.15436570446060546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068182849279220331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16659651772117934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69101859105061414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2456219318545613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090833674567741884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47456247055859091,
                                   0,
                                   0,
                                   0,
                                   0.15976966741335152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47606206132629464,
                                   0,
                                   0,
                                   0,
                                   0.2691134941060771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1013925278477549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02048622247653005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27553277587621061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50592116427566625,
                                   0,
                                   -0.42239762070671216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42420328383721317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14039058568226667,
                                   0,
                                   0,
                                   0,
                                   0.10637419560548801,
                                   0,
                                   0.48967733655959539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11879047552628984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35625532536985249,
                                   0,
                                   0,
                                   0.12009179996088928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059670505422898437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24150467757324809,
                                   0.38858938838270068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49628212265664984,
                                   0,
                                   0,
                                   0,
                                   0.13463090569602071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31053474582571733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098767691467716759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49381598988637859,
                                   0.41907813694787832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.008520153892046356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62228347337513656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91536938940409118,
                                   0,
                                   -0.33089086865061762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65738759770454169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22495880969284296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77640392371722666,
                                   -0.0010766872250777271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89093373430962264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83842793936538107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30144535452929833,
                                   0,
                                   -0.36090242894250152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51818058900945563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.178408628086449,
                                   0,
                                   0,
                                   0,
                                   -0.14117024159860511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28599472832701389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7690103631874039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40311271694781975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066948920063225184,
                                   0,
                                   -0.30379831792545609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12568198977505768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49722584140940435,
                                   0,
                                   0,
                                   0,
                                   -0.15789948542905508,
                                   0,
                                   0.33608868974155581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17351014847866603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2826538373496042,
                                   0,
                                   0,
                                   -0.25901922125533838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093136988688823252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25931226467068019,
                                   -0.28666876046751577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069277404370588408,
                                   0,
                                   0,
                                   0,
                                   0.38095977225256428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36022583619278686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30007325945182356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3838362620230158,
                                   0,
                                   0.14607221655317737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15829384796151402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094170216426614564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31830215057592087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60102582913316061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00067843934267205336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3531369948784861,
                                   0,
                                   0,
                                   0,
                                   -0.3590105069383191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26812953120985494,
                                   0,
                                   0,
                                   0,
                                   0.17321395280720006,
                                   0,
                                   -0.15687307437363485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034316047392611806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23168751709740271,
                                   0,
                                   0,
                                   -0.56748782025197231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3588430264596229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087253298307075483,
                                   0.50817312178819063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20351776707584657,
                                   0,
                                   0,
                                   0,
                                   -0.23623345416039809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06890640731234364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66650406624925396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050243533063870673,
                                   0,
                                   0.080929705519536321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13274588316470365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30223056187899133,
                                   0,
                                   0.96596575445242594,
                                   0,
                                   0,
                                   0,
                                   -0.14655608157103447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22646449804171268,
                                   -0.016128478800434477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42182737699544176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29870301149532547,
                                   0.47058904558139958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17652446136160144,
                                   0,
                                   0.096232907163365508,
                                   0,
                                   0.49117138335999855,
                                   0,
                                   0,
                                   0.0064932615728482343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26288852812640839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03889139324829452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78916476024380144,
                                   -0.17512385573175132,
                                   0,
                                   0,
                                   0,
                                   0.28991156096896908,
                                   0,
                                   0,
                                   0,
                                   -0.83666563140024286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041611150073753225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2474038139182283,
                                   0,
                                   0,
                                   0.12385226652107373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95376198338346296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52737386605446135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17831673145982185,
                                   0,
                                   0,
                                   -0.13287409326025534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066382887291893691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25619617009730888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17390300698669456,
                                   0,
                                   0.39714890489014115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046156706646880166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094125420605505258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30829413259217925,
                                   0,
                                   0,
                                   0,
                                   0.104300717440918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087248788131337851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2754068882900606,
                                   0,
                                   -0.46264078599084019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1969039024480036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99636202256914697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17625700715016027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29841609932699092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97638438114329951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.043211535043419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42240042339779699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17975088453848731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060140318445191056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59983749925753049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40602381600926185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51087207717397654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58933914555980538,
                                   0,
                                   0,
                                   0,
                                   -0.59312070987882071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11604956885194841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092859402186631398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39930314629079544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28249666335147849,
                                   0,
                                   -0.014127229311468766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19836803665922209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10341888321686397,
                                   0,
                                   0,
                                   0,
                                   -0.076689235295597694,
                                   0,
                                   0.38160830511416449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6648068584220167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26774544053919774,
                                   0,
                                   0,
                                   -0.24539084921250812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0808380737534624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054184392561157757,
                                   -0.19176551519061674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014234119130550095,
                                   0,
                                   0,
                                   0,
                                   -0.46488983921678895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036824180968253392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28432408604658643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66946813150272799,
                                   0,
                                   0.34834617868596168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35606078430439464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20232671499387012,
                                   0,
                                   0.30895836996910486,
                                   0,
                                   0,
                                   0,
                                   0.046574528840607268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72623420514311787,
                                   0.10105325618821298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37270047156088093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68963964507042774,
                                   -0.1937153083335405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57897502816958657,
                                   0,
                                   0.044356806067666441,
                                   0,
                                   0,
                                   -0.13468389138248088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33371141639011831,
                                   0,
                                   0,
                                   -0.3092929319659749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38307266246855554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10203949642684973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38956813021085457,
                                   0,
                                   0.044386659142213479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35453002864981126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16184545080744622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24250826672907244,
                                   0,
                                   0,
                                   0,
                                   0.47404477954920449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14571517615772037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011918270763071209,
                                   0,
                                   -0.084589796721176266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19648419247697041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036396438485166799,
                                   0,
                                   0.61023465088144124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26649627910737805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38842716960096252,
                                   0,
                                   0.11977501838976171,
                                   0,
                                   0,
                                   0,
                                   0.53778379878455196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6676776278304718,
                                   0.22138810493396538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45733714780009938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32213550393684265,
                                   -0.080854521565202897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50907807684007556,
                                   0,
                                   -0.58837622281902935,
                                   -0.55243678266295759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70809865204065581,
                                   0,
                                   0,
                                   0,
                                   -0.1141020339280857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13896905452148034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033714192067667639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0247975174574563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45724680700539461,
                                   0,
                                   0,
                                   0.54484665802145082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95696881872302975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032474931537948309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19447626509153326,
                                   0,
                                   0,
                                   0,
                                   0.38648622828027868,
                                   0,
                                   -0.3345807065677131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32059149782200819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30426441484163425,
                                   0,
                                   0,
                                   0.031277132452188161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085285674162200356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2306318130193882,
                                   -0.39889970230822402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22779133085662767,
                                   0,
                                   0,
                                   0,
                                   0.14841736697490535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45937660987535128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23058775885904575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18736640534137267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019612352580161987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6439489635674962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53715620319733559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45621422262688877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47891324746083203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34027053367352272,
                                   0,
                                   -0.56782966448182837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58376199440834664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041742195682172703,
                                   0,
                                   0.88182047722171197,
                                   0,
                                   0,
                                   0,
                                   0.015905152031416347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068051987516366388,
                                   -0.021865306596640939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07491901280291352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50217615555614703,
                                   -0.35387857099184172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45896727507469848,
                                   0,
                                   -0.36637962978142047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31812586030621548,
                                   0,
                                   0,
                                   0,
                                   -0.76480471950614115,
                                   0,
                                   -0.35782405784640936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14652924536584255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0024622058862891942,
                                   0,
                                   0,
                                   -0.18644280525007206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12742305561974612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13168155880550969,
                                   0.11887401629427698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13307125662226699,
                                   0,
                                   0,
                                   0,
                                   0.180024928271455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17823912560389624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2942183210893936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.565303991548741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0091761996417336067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44142749856095775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67669658761312412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55652064344304741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21092023071255675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15420327439481174,
                                   -0.75388417540750075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17823279239256232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0581345919062335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49519975533599014,
                                   0,
                                   -0.48158854390077577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90206570221458304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27944786616762679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44648897459903036,
                                   0,
                                   0,
                                   -0.16671411702754554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32692288316339169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0040229369663140405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043274111708871896,
                                   0,
                                   -0.29829278938046894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46077857559100832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050278800702166601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16566578176693492,
                                   0,
                                   0,
                                   0,
                                   0.356603433075103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35205008758012013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0290593233511925,
                                   0,
                                   0.052698905580600322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28478262875839389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31425458291801406,
                                   0,
                                   0.1311680107435452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14216718788299068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35285370491446821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048414563661527549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050247850763960641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046993310616270781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56835721415292295,
                                   0,
                                   0,
                                   0,
                                   -0.57281193025665833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13786787511446386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011647296104072025,
                                   0,
                                   0,
                                   -0.50441476529954898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19177485544008599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28886177253518064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064282469257317815,
                                   0,
                                   -0.44020569625191264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19269252870663714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24351850208657291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24815049126907379,
                                   0,
                                   0,
                                   0,
                                   -0.32075962831934585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3709903647906137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092536761729336128,
                                   0,
                                   -0.034591102637642417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65837208674208147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59536960607352485,
                                   0,
                                   -0.45294743290108852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10674607166989777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49831323168143038,
                                   0,
                                   0.37300873645323146,
                                   0,
                                   0,
                                   0,
                                   0.028270921307353727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19287780807116664,
                                   0.76253230133277505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46736353093351779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072010778120466148,
                                   -0.19997425887888229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71334881516872051,
                                   0,
                                   0.36773130959571448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90679902991836459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15590236208201799,
                                   0,
                                   -0.13509388398504019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087463705539869929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078889697094037342,
                                   0,
                                   -0.026471148114109083,
                                   0,
                                   0,
                                   0,
                                   0.24753431739470483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56911495733755668,
                                   -0.26201696053257584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49434961569824909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47914172401797983,
                                   -0.69016359610210376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14560645816114784,
                                   0,
                                   0.067915888707261562,
                                   0,
                                   -0.016004786505898986,
                                   0,
                                   0,
                                   -0.26899542804144327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41187157609392805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37706326346886887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047306456987638447,
                                   -0.40137401354238511,
                                   0,
                                   0,
                                   0,
                                   0.37909531273782249,
                                   0,
                                   0,
                                   0,
                                   0.15538376958342143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25748463031955882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62139109764344624,
                                   0,
                                   0,
                                   0.44956923616838629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12210219720660305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25824707285274429,
                                   0,
                                   0,
                                   -0.63283344574929457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28313068517177176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40421440232846406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91496083675940221,
                                   -0.1385596306136016,
                                   0,
                                   0,
                                   0,
                                   0.012659503863241342,
                                   0,
                                   0,
                                   0,
                                   -0.25046917138109714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30123301829262233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76823350994494732,
                                   0,
                                   0,
                                   0.067694910252585422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47135703521103428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73166154488683688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098672697110596452,
                                   0,
                                   0,
                                   0,
                                   -0.53075924282761899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27425766253866052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41166623413713355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27931496851124726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31846710904734699,
                                   0,
                                   0,
                                   0.34767058159229802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065945633119263602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94862588212156707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45108928262993381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36011629783985494,
                                   -0.35867114939820111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.207915634678977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28911601751238297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2990684690404552,
                                   0,
                                   -0.26320163572648914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45129004945293993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12673461137977798,
                                   0,
                                   0,
                                   0,
                                   -0.039750934196769269,
                                   0,
                                   0.13801242711139519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10034472622954696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13701214407035217,
                                   0,
                                   0,
                                   -0.15704553921525977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45426080015108106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48485612676245726,
                                   0.13108442767276943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44837828374380101,
                                   0,
                                   0,
                                   0,
                                   0.26623684247899759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42339044788700492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20785647574060689,
                                   0,
                                   0,
                                   0.05856886856307545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84868217695582293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95421857799526799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13012812762614992,
                                   0.98342240869040964,
                                   0,
                                   0,
                                   0,
                                   0.26786979517819803,
                                   0,
                                   0,
                                   0,
                                   0.76059268506354516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13627862371316005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20305347943998439,
                                   0,
                                   0,
                                   0.43162553496752498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28281996896189332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29485518075503303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2929886181250464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38509092883747459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83687967727623402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2680341552453427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82723391464173868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34112006143167722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042743037962215208,
                                   0,
                                   0,
                                   -0.17234558587561982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046208848966051395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40603735919259454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39680141431166349,
                                   0,
                                   0.1400685348342286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24279860793972927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38662299300745273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043891503932119477,
                                   0,
                                   0,
                                   0,
                                   0.089847841611299537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44446741150224689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23575310693357585,
                                   0,
                                   -0.19098841581392256,
                                   0,
                                   0.18587756345357226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043144106936299678,
                                   0,
                                   0,
                                   0,
                                   -0.63414886885902966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0042697855801537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34678140020208614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029684587061742127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15718497242852456,
                                   0,
                                   0,
                                   -0.84491841477704688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7510910089482139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25039754380433449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12249611161947353,
                                   0,
                                   0,
                                   0.44023681010617166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10448519103895319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73428747900756164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0029291298401127666,
                                   -0.51538147014464208,
                                   0,
                                   0,
                                   0,
                                   -0.092980889287478719,
                                   0,
                                   0,
                                   0,
                                   -0.75646677104209614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77379570051567015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21755138545746219,
                                   0,
                                   0,
                                   0.61888981093387641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29556915297251835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38552922954331204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06346983292446115,
                                   0,
                                   0.19029204629882759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42708518757372538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61547716733239033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054925400371974603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046258772738650963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41420798582531715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17626945189662041,
                                   0,
                                   0,
                                   0,
                                   0.20522665710035978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6490853928573036,
                                   0,
                                   0,
                                   0,
                                   -0.043836977155588333,
                                   0,
                                   -0.3057807978523519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53859626019532525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093336106879825104,
                                   0,
                                   0,
                                   0.16250866241169262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19289369101688314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047606241505997453,
                                   0.093248105543435489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23796145067860208,
                                   0,
                                   0,
                                   0,
                                   0.17002875693105721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15605441528755223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10920785432694656,
                                   0,
                                   0,
                                   0,
                                   -0.070504226762682753,
                                   0,
                                   -0.062508731672174869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19130351974925427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26577156979167149,
                                   0,
                                   0,
                                   0.081109758698283407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35034294464866078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53749443198343572,
                                   -0.36300802654768688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3233098863044721,
                                   0,
                                   0,
                                   0,
                                   -0.23826721105808071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40083573072845802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51807016717161281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25580771891509491,
                                   0,
                                   0,
                                   0,
                                   -0.64215203489485095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13503567100455885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17691432643017457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28811903464992517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77633413587380784,
                                   0,
                                   0,
                                   0.36626857399530982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15936837055910044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11045040409952799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05448816074795991,
                                   0,
                                   0,
                                   0,
                                   -0.20006289726146265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68797476860002182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5189928265172985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.244665513781996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071430272615915447,
                                   0,
                                   0.35340151722183805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15648294289185924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037936468406663121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21249366638188899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93840482471148745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068711619939247223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23493446377612234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11352604144497173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042267344268681541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98384363600333824,
                                   0,
                                   0,
                                   0,
                                   0.36890142341001747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43686883754872652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40742641403993091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10301249726909652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48235324471387675,
                                   0,
                                   0,
                                   -0.33946556570773267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41138975338695438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00057615159070337229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14493586725943555,
                                   0,
                                   0,
                                   0,
                                   -0.26344325234179278,
                                   0,
                                   0.17979791642773707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088585998678670466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086811041351979229,
                                   0,
                                   0,
                                   0.63262640549450266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36493842932362969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085458131834078077,
                                   0.2047328397024108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50900049211819232,
                                   0,
                                   0,
                                   0,
                                   -0.10174521724804572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099155817168618363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03341094086805179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53560952032637477,
                                   0,
                                   -0.20946464558524369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020635211663229999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30841643731983209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096252432143655781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19983894946304304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.617685477174861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36095958170977865,
                                   0,
                                   0,
                                   0,
                                   0.10750301153721888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061586427826438694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15804162871924882,
                                   0,
                                   0,
                                   0.31100264800912814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0091704416177839591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084688226666976257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17320671821570072,
                                   0,
                                   0.071559672457909534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43320116319692603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34689695234347773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35569388500883747,
                                   0,
                                   0,
                                   0,
                                   0.055014099265799643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42929634586452436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18144270731187923,
                                   0,
                                   -0.42115023309680277,
                                   0,
                                   0,
                                   0.4574530632005715,
                                   0,
                                   0,
                                   -0.26725411214467976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23245003176125173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051112563874851011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60709025228284175,
                                   0.64078899746749807,
                                   0,
                                   0,
                                   0,
                                   0.65089411712790723,
                                   0,
                                   0,
                                   0,
                                   -0.65581483620252556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54319969745042251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73273099644327067,
                                   0,
                                   0,
                                   0.35986107445887239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0087369054748948505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12236825781559527,
                                   0,
                                   0,
                                   0,
                                   -0.31324534134281007,
                                   0,
                                   0.23985698555842899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049669198558727194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68357569946454189,
                                   0,
                                   0,
                                   -0.18252051434858499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16263717759667468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42036786296515127,
                                   -0.31272771293212248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12750972574858746,
                                   0,
                                   0,
                                   0,
                                   -0.093066906332331695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020897232880097465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30023302837912003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0050256229364710608,
                                   0,
                                   0,
                                   0,
                                   0.070445690523417315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13780797540842113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49074630759650767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94416499091578043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1309565515730183,
                                   0,
                                   0,
                                   0.43901600595824142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18164003818785518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88050882296906186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088325795781066099,
                                   0,
                                   0,
                                   0,
                                   -0.47384590075908589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0075248869036022847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2238060685907427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52987200768025111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05028825263170681,
                                   0,
                                   0.16260943029857605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63858261499559776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12772718878286973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38456040616175524,
                                   0.67826829419120627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58150581595376916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26683656577706705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24660707246680352,
                                   0,
                                   -0.3472469666838397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46199275802416101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20832144537385799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72775535799017588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50755479359264322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33315319789494702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48730501848212915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0146836193115409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70599205907687002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13953087340533901,
                                   0.010290551415815363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27705417096897822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5782782678313787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0821054331603015,
                                   0,
                                   -0.85032515903039785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39390621500746037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30034482636654908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088810722406356582,
                                   0,
                                   0,
                                   0.10610774302877571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41839466086417942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32253928908456442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095008736190731108,
                                   0,
                                   -0.048439187967297015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28502220080536855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33894274741060637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33438726692435938,
                                   0,
                                   0,
                                   0,
                                   -0.09746956479315072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17985192467831634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38960865523090699,
                                   0,
                                   0.31402462840659495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15481788417776007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51260621195331413,
                                   0,
                                   -0.35232566703043877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079480008172275185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37336663576974521,
                                   0,
                                   0.18632180786365393,
                                   0,
                                   0,
                                   0,
                                   0.092868994256589912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45939537849699569,
                                   -0.009867957869315408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64611388603189812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029167380715907701,
                                   -0.11739938938965022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44766336167941301,
                                   0,
                                   -1.158661848260792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079615643681179293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88220191522957925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2909360570102692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055720846742249107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35718199058477462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0073180337547155486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11070803879021786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12432769666986711,
                                   0,
                                   -0.39363614481201104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1315701437640816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12140229145103987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49750899781638819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64927836345127787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15180690791952525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28829217264673623,
                                   0,
                                   0,
                                   0,
                                   0.10026170819491222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031254296496480378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12800881603722986,
                                   0,
                                   0,
                                   -0.38556802560786585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17980060856733462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20888379045543004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048179760935720926,
                                   0,
                                   0.44875586116477878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43839143061043306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1670620193972838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31666574113795631,
                                   0,
                                   0,
                                   0,
                                   -0.1235702480334776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19734182749682089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26613172580226352,
                                   0,
                                   0.32999537212025853,
                                   0,
                                   0.052849304415762938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46494998988578284,
                                   0,
                                   0,
                                   0,
                                   -0.84983511033938719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44593178743244322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69027437495061328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7114440007342302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16037715990092569,
                                   0,
                                   0,
                                   -0.33374260525731159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046164778536993425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14469870558719072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62442532063771217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22006922275613611,
                                   0,
                                   -0.61706373909671175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27678919232600191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33701877517617784,
                                   0,
                                   -0.23048228516866812,
                                   0,
                                   0,
                                   0,
                                   0.35328226310044253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39332917367753023,
                                   1.014182191999681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77664896120994475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028651648387004389,
                                   -0.1840071025336634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38717527871663721,
                                   0,
                                   0.33293004236524415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16646660948730663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12043831421790796,
                                   0,
                                   0.049669842435254206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60969378409181074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5105275467817173,
                                   0,
                                   -0.11079526477645084,
                                   0,
                                   0,
                                   0,
                                   -0.56996039464808701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04216036529996655,
                                   -0.40605161532564316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014354895071557822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59221528379916066,
                                   -0.22146429456466504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78891267876554083,
                                   0,
                                   -0.033906436693844563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2558720729379556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27906373454367339,
                                   0.29239282616613493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061119303215929219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46611656937685675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56661798441694089,
                                   0,
                                   0.43213928824476056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30149444159526873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30332310746926822,
                                   0,
                                   0,
                                   0,
                                   -0.12072862943338573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27850348822975934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0038147256725214254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07021259047305492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52066792127370554,
                                   0,
                                   -0.69740821128565944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23116626083652569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21710626472503172,
                                   0,
                                   0,
                                   0.30922656072318355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34999606187394594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17085121841698395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70057411951039572,
                                   -0.75756524174806794,
                                   0,
                                   0,
                                   0,
                                   0.067347181326569611,
                                   0,
                                   0,
                                   0,
                                   0.3896204072127708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25769476685423182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39168975576186899,
                                   0,
                                   0,
                                   0.56723027060254205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44793665055955861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19460375369903291,
                                   0,
                                   0,
                                   0,
                                   -0.098804119098165485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56158491240102382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27747810420868668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43831767633445368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22722717002630444,
                                   0,
                                   -0.22618231459867311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51486153606689078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034622440028488799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28479436123629931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99955992809332184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29076041840514782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16882346730162137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26293129448981445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78372983321275025,
                                   0,
                                   0,
                                   0.65967801671625859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052356616355825031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28398262039892835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10772657300535568,
                                   0.20695794649875832,
                                   0,
                                   0,
                                   0,
                                   0.0065354293726381171,
                                   0,
                                   0,
                                   0,
                                   -0.30243694784177355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78396890718639356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20999091392677915,
                                   0,
                                   0,
                                   1.0619898327802264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38924984297320908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14521541234316881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21465225507406815,
                                   0,
                                   0,
                                   -0.088038866359560888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0087577031406516539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10728652206914452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48721060812988715,
                                   0,
                                   0.0042260901876962284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024896909407347664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015818431157737088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21044465705245816,
                                   0,
                                   0,
                                   0,
                                   0.5581442178322501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40842256492994172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039978787740195233,
                                   0,
                                   0.38860986125961927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39602459681299584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32733971486941199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13842185402706317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28448454394611578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55128677078130717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57619793537751907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24221250464562152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52778147406280962,
                                   0,
                                   0.044485814281977683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4753030012895077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2651739951330449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10553270994634531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052816491301462834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51533715981111672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24129751145852799,
                                   0,
                                   0,
                                   0,
                                   0.16385062675233905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16174886078816514,
                                   0,
                                   0,
                                   0,
                                   -0.13256112823738886,
                                   0,
                                   -0.17529632320886362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20327575425518271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048051542049222691,
                                   0,
                                   0,
                                   0.096476225867327431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55047216169937963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28825019118777068,
                                   0.034439054000145991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012145101823645935,
                                   0,
                                   0,
                                   0,
                                   -0.57862080626006396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38775642401272659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28615839884532074,
                                   0,
                                   0,
                                   -0.098497616449918252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85841553302769225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48611828658571948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51376022527383425,
                                   0.30299674959089773,
                                   0,
                                   0,
                                   0,
                                   0.50072137091656455,
                                   0,
                                   0,
                                   0,
                                   -0.7288031580098544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40499378878495745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71715229949783987,
                                   0,
                                   0,
                                   -0.42808644391801587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41866015824205016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2279600284397825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21361985734523831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67759297208769542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69753572792247331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19590551949632429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53113258195124124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23410757329507825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26806822261686597,
                                   0,
                                   0.79078179286004746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37600420805804846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12000140755918259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1220913610251193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27617019041152591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025729859718633077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0063750301403896203,
                                   0,
                                   0,
                                   0,
                                   0.018406105973113311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50355606674955966,
                                   0,
                                   0,
                                   0,
                                   -0.5166855496792857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16778365620435784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055938776022539605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25389185258627001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57393273960911551,
                                   0,
                                   -0.20053962610005815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11878899106761008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047609762953078789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18785436287315266,
                                   0,
                                   0,
                                   -0.48859339312835498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40547159186651577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40924050889571972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22229013027133143,
                                   0,
                                   -0.197639388245267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21042170686356845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16925474359836359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31220350534021318,
                                   0,
                                   0,
                                   0,
                                   -0.084888799461891276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017637956631481884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058733422573943733,
                                   0,
                                   -0.34928354794677041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20697613766888298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4193438303810591,
                                   0,
                                   -0.018221850660868809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022434941130432443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77942047800108971,
                                   0,
                                   0.2617625425580582,
                                   0,
                                   0,
                                   0,
                                   1.0226589467892362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66351499044595696,
                                   0.14542121404477387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0065818937155429913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50455954677642689,
                                   -0.072959170765696163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3895017038093993,
                                   0,
                                   0.052438045708093552,
                                   0,
                                   0,
                                   0.14162657839260928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60951730368185686,
                                   0,
                                   0,
                                   0.068172651002443213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085892477229973979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27854997617445809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35076602460959128,
                                   0,
                                   -0.24490377251504225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19957083191960567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094253395948570781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25037274761691453,
                                   0,
                                   0,
                                   0,
                                   0.41158961081949952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1419787877336284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1607417212532968,
                                   0,
                                   -0.13339804419616003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29705335245891101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.004346160612356445,
                                   0,
                                   -0.31547232766708144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24544602920568798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33038187699233307,
                                   0,
                                   0.26259977908754123,
                                   0,
                                   0,
                                   0,
                                   0.2077293566276277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70268835187531842,
                                   -0.16125380413523305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47254669034976504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.105155988359412,
                                   -0.06779016932266102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24076263792877925,
                                   0,
                                   -0.10649279435116679,
                                   0.064083608793225319,
                                   0,
                                   0,
                                   0,
                                   -0.845251554307345,
                                   0,
                                   -0.5062454082208786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037581174973782328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15281274823866017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019864716048020363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62028718296290719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44641227697073199,
                                   0,
                                   -0.35128035748582154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38187527455308695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49503858005643886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26531938509290987,
                                   0.26285804061396267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52184266201440543,
                                   0,
                                   0,
                                   0,
                                   -0.22906263321880399,
                                   0.24131800219937141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16711810217149622,
                                   0.039159711825912574,
                                   0,
                                   0.156659702724469,
                                   -0.17428102892614275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0060834635125489173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30688918657211695,
                                   0,
                                   0,
                                   -0.16732606698827979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38175944428837694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45999641582250428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11133129267255233,
                                   0.092735011457310848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20332256906010049,
                                   0.15194565854399078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15581423163274916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59918719149419408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22742399944247121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12342218702883451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19289339020256918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12242236857399125,
                                   0,
                                   0,
                                   0,
                                   0.59904258012053957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19930330031916432,
                                   0,
                                   0.041972382228744554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63056265551599311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36691566567944761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95966259667333986,
                                   0,
                                   0,
                                   0,
                                   0.13285992581187461,
                                   0,
                                   -0.038782538822711876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040444947954211677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22519757798086018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086845336077685548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18817988216375139,
                                   0,
                                   0,
                                   0.20811609132324649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15141480561060383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78258319043644209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02854408765140859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40314927460218347,
                                   0,
                                   0.4740196231642137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1724575902758199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12974459878083541,
                                   0,
                                   0,
                                   0,
                                   0.4371498919675485,
                                   0,
                                   -0.77554859314274138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40160892364210171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023938327895100919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16949312559184998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20321835614688344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30736200756188226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15360090479364308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32652346573343838,
                                   0,
                                   0,
                                   0.078077178406999542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68545700238732055,
                                   -0.22912223699305675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27393334352314697,
                                   0,
                                   0.36095636399147735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015708711285707926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46345638100261027,
                                   0,
                                   0,
                                   -1.1546897191863204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45157727775751577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3131177073155495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027145540607637547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46041765021026815,
                                   0,
                                   0.28059726870274726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31813795510664666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3191724018864357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10035195448188551,
                                   0,
                                   0,
                                   -0.34002785118890311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36696013363080104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20069310370329815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17958047475520272,
                                   -0.030760061045260481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22053454419924634,
                                   -0.16052151385222188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63699180081550011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11711104296589939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2653875306397101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050110573112233096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40812768305344554,
                                   0,
                                   0.64772760730512169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26304516256921778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30214183252340826,
                                   -0.033089399618810349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10749406295706081,
                                   -0.26591876172042089,
                                   0,
                                   -0.32817065619752478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10949611643585329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019576984217281559,
                                   0,
                                   0,
                                   -0.071896563364452312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079484174693261453,
                                   0,
                                   -0.18965513431713724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0546798727984978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046195599139881978,
                                   0,
                                   -0.3624982557118212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85464444715156618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068991068808176972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033360864137815444,
                                   -0.18216686020266828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15686807531149688,
                                   0,
                                   0,
                                   0,
                                   -0.54709024147997098,
                                   0.21537654706235373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52350749921215567,
                                   -0.06246143794333664,
                                   0,
                                   -0.61451468903144801,
                                   -0.30293347938892318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072846065296715945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04080775801879144,
                                   0,
                                   0,
                                   0.26321287425316192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46115832243865001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05522343009498807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014287591712984719,
                                   -0.21541149532418086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64858616657263801,
                                   0.19951189109391332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06154211052695676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081097147800100189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43656740418442974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00173675774291507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08641313386568529,
                                   0,
                                   -0.40149934258014541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48340558826214636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39672531336026329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23469536121297818,
                                   -0.19629737998017915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0092799128039163202,
                                   0,
                                   0,
                                   0,
                                   0.052503561037243365,
                                   0.064608794613655374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36827554562652698,
                                   0.41779926415734975,
                                   0,
                                   0.64644522594039344,
                                   0.54215054953124198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28615712441472041,
                                   0,
                                   -0.7551933970606326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016607367596379752,
                                   0,
                                   0,
                                   0.79592995747714024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56772447802818771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61579649839306738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52479459816721985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55743939510214979,
                                   -0.49941446346966328,
                                   0,
                                   0,
                                   0,
                                   -0.41633200417068933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23643692428866914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058487492316489774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17864434728979903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53496667021179789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37929138487079522,
                                   0,
                                   0,
                                   0,
                                   0.42616741283837345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2233096281943501,
                                   0,
                                   0.21944889002230814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0019382329421028521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50831828456006301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85691903676560954,
                                   0,
                                   -0.88467501786625657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16683340540055008,
                                   0,
                                   0,
                                   -0.34680570132535543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071783184803112673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50779585426749696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19099550998683928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44728269543825827,
                                   -0.32393124218589098,
                                   0,
                                   0,
                                   0,
                                   0.76451764684801393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02572534210867387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27882587602724196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23039179995468007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19942632601629451,
                                   0,
                                   0.089085962286686707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015214899470143872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14490884438262011,
                                   0.46154121290908295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11965162134996113,
                                   -0.03469002347710809,
                                   0,
                                   0.043168599423298606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33913762513461315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18287222626785971,
                                   0,
                                   0,
                                   0.042285129523858017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083990379213095837,
                                   0,
                                   -0.70019972912802497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13198147885278511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26144622951973745,
                                   0,
                                   0,
                                   0.037180434108683831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30650565998155205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10873524334097574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58739016641198938,
                                   -0.28693700383242082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1468163092547872,
                                   0.28045078033072518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17148994610550819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44854957726314182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22113809122069475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36159275860336865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09352504600843925,
                                   0,
                                   -0.26636757241670328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20413749647574839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41237251985638385,
                                   -0.16443674360040933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1862583040688747,
                                   -0.23017621472160674,
                                   0,
                                   -0.52522987494345141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22301938876836047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33119079869016149,
                                   0,
                                   0,
                                   0.13681043403598747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039233737476995018,
                                   0,
                                   -0.086996337285522959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77400649348795714,
                                   0,
                                   0.079952213228087654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51909148763457857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32821301603091513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.550874193439297,
                                   0.82757437474836371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21796648733302967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27434540062446899,
                                   0.26224875354385113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013954040292668612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24550957517659866,
                                   0,
                                   0,
                                   -0.12123713604089258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21268469208261692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49034619679935093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035662560901013329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84426833067163487,
                                   0,
                                   -1.018693471274464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64665112621397791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5043843301687867,
                                   0,
                                   0.58307180662294233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18696637902103316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30789180050155041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32938762492540602,
                                   0.090649276033232029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35825763782410991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57496835623598419,
                                   -0.75905951200517507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30805159054783549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78482368074608966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098392271876586432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4951828576989753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19526143868748427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2012790208815125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25609885768897572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09059376612783393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66112770828771472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56105933812456177,
                                   0,
                                   0,
                                   0,
                                   0.038150091082669681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0076868186552701417,
                                   0,
                                   0.28258796265675268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040956773966613166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39606490803066224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42259357507811446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18436815139142612,
                                   0,
                                   -0.045205706882968544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44315181990311336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49610579245201775,
                                   -0.2139523908927225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14196981158756222,
                                   0.22931990010845449,
                                   0,
                                   -0.30957649077039467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089251239288828832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0026310718471427505,
                                   0,
                                   0,
                                   -0.33891518940125764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048766999441049452,
                                   0,
                                   -0.057483050050554506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28240974166751232,
                                   0,
                                   0.1806990919363983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56889443896340919,
                                   0,
                                   0,
                                   0.0047449768602373932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34763678479260873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30712037259073927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64451949341880854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5680099176192801,
                                   0.012756475466258993,
                                   0,
                                   0,
                                   0,
                                   0.55778181098800372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74643470136038159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10655517976850856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0060647983285160093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3898594069564485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2827392990309181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22724130545586699,
                                   0,
                                   0,
                                   0.044363156949834837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14782368396591433,
                                   -0.11579711778948441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6123719183475349,
                                   0,
                                   0.52241682777553911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17676291143551301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50273447147918648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086556680849673495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074225277480705287,
                                   0,
                                   0,
                                   0,
                                   -0.13376835559365791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6736542845410427,
                                   0,
                                   0.031842115752819811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49621560309902524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12372827985736629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098389437469921265,
                                   0,
                                   -0.4692168680773165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05901304726653836,
                                   0,
                                   0,
                                   0.29211829040203741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79973494747304252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18069548218359793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23917760955356079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4202983643915944,
                                   0.33368392262069174,
                                   0,
                                   0,
                                   0,
                                   0.15792379961269307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10114558993745627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72927001157255245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36079286053470799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14932144389363927,
                                   0,
                                   -0.047292694375469041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21599206144338187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024417502715228641,
                                   -0.16042497191513358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068500359293564184,
                                   -0.18700071484318387,
                                   0,
                                   0.11582257309281097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046008946251033744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33200781918791522,
                                   0,
                                   0,
                                   -0.10359994063558604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69472969493388714,
                                   0,
                                   -0.3369054996691252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0032105073503270812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27943239771598399,
                                   0,
                                   -0.029712964289529839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014324025784339861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3035764859018385,
                                   0.33985705968496355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079814297824972777,
                                   0.035963268813785233,
                                   0,
                                   -0.079414588781149126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22963459061459912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28388160045364214,
                                   0,
                                   0,
                                   -0.7298193609598016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025131698769415935,
                                   0,
                                   0.18055087933177785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5271488666447196,
                                   0,
                                   0.26874633308085455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45576538596314309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26063471917693554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01254523970957816,
                                   -0.63783812645080618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77126063594905214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37889328579257792,
                                   -0.18743544762517098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023694260643504189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21861838880023512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43499435653691032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34691113522988148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22429580290482881,
                                   0,
                                   0,
                                   -0.25996728204048641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060237265720037236,
                                   -0.17183300191310208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55174852136465469,
                                   0,
                                   0.17435577717666825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39593623551002044,
                                   0,
                                   -0.20681925242628513,
                                   0,
                                   0,
                                   0,
                                   0.015852785025471078,
                                   0,
                                   0.13037595935448706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16452708495683066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65615594356450213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69452632152838678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36988244066172932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22868258787028034,
                                   0,
                                   0,
                                   -0.054109089942371215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052346168247541465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12029333575681131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62247131367142561,
                                   0.15055662940299189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21232432636339213,
                                   0.051509042576126186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24771045005961351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16956698371616499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49271369724602626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12418799218815753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34904419680980531,
                                   0,
                                   0.099123271353955655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15935791666442028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3558305347132516,
                                   -0.41854357951080212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32463867349420694,
                                   0.12805139883040501,
                                   0,
                                   -0.18208140863604438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48428854553935291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29363374324123281,
                                   0,
                                   0,
                                   0.16989951627301869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14404646063660115,
                                   0,
                                   -0.020458688973098701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058849671180676549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29941554954128585,
                                   0,
                                   -0.061403896116190973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47927704484448708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060643776180985258,
                                   -0.3497765662668712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.003816951084615515,
                                   -0.17098566247095678,
                                   0,
                                   0.13644367722155015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045711491049282002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49953397637517966,
                                   0,
                                   0,
                                   -0.48342324905549822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11582718716012125,
                                   0,
                                   -0.027992050708571192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.175496161957405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4044817630163316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52362563401999274,
                                   0,
                                   0,
                                   0,
                                   -0.12459620770917608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076934808306237834,
                                   0,
                                   -0.56051025242206809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020776666280368533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44200136118113853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072488266225559622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069798990452861698,
                                   0,
                                   -0.24395506527491842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54452150652607723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29737587271368071,
                                   -0.13469576883431961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27833101614568889,
                                   0.47317460910544107,
                                   0,
                                   -0.040243736300234222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17330153184562219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33070404185889357,
                                   0,
                                   0,
                                   0.036189734219146133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082481544479493935,
                                   0,
                                   -0.27710474118635919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27635609508761166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24787541910210176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040183067049291463,
                                   0,
                                   0,
                                   0,
                                   -0.50714580105994156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35551925512816124,
                                   0,
                                   -0.15354620575879901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59386193760030292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31738173214990617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70899053855012939,
                                   0,
                                   0.17378113502307854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25575781011658666,
                                   0,
                                   0,
                                   0.11869417470742301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59113874969652802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0392548159513297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098756112378985642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33164273309874626,
                                   0.088556244517643976,
                                   0,
                                   0,
                                   0,
                                   0.1172418425316353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36850379406242784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10278302999266614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28306304230110946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16468651207082655,
                                   0,
                                   0,
                                   -0.30014962229204778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45344656595352612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61311182412660759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067961959734137475,
                                   -0.018039471007016524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39577189450362416,
                                   -0.15726463525703563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012817786972860937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034314174178986814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18300384511021373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30735338365694598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50749182069166732,
                                   0,
                                   0,
                                   0.237202521576374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26918443808551662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42123639225656895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13691843550832475,
                                   -0.015814157791081099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33252916736687421,
                                   -0.17958126992075579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059655910716555856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38694605496005274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16344005328386113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21620235762025686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2817465742036076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41978562985430701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098511274044600278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45404600017622426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82949226547843224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46300329804377272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079109500866997695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33370708334625282,
                                   0,
                                   0,
                                   0,
                                   0.38579293679545823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31350937330932482,
                                   0,
                                   -0.53047634204278316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034275868959324857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37189368575390247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057657250854689937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16536177666364862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049716663346103057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28940357274101908,
                                   0,
                                   0,
                                   0.033414366219605834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33567113842130059,
                                   0.39412974550172003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28975789676532232,
                                   0,
                                   -0.13832463297411157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71475990203671791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1030679392162665,
                                   0,
                                   -0.24668008003488412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10961658892402264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0033457444600456868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84748078406820493,
                                   0.22824992974084027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30102277807011346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71653119779523222,
                                   -0.50251543005218491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41633962930904256,
                                   0,
                                   0.45430022029776707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10595850386308028,
                                   0,
                                   -0.41244635639116023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048747213828314671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30201919243606073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61327643955073796,
                                   -0.17201298585560734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18333775009916248,
                                   0,
                                   0,
                                   0,
                                   0.74907484559937498,
                                   0.26287530557661026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54967577939414847,
                                   0.017911842680473869,
                                   0,
                                   -0.39108508283732968,
                                   -0.17608660157944167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043708552505150801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59994347606204534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088217435835295635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55299146316919168,
                                   0,
                                   0,
                                   -0.40222737122462887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17573981431026042,
                                   -0.22138917475973208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011997692376383309,
                                   0,
                                   0.27681184178979912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078244910830311459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3667298599483419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31708614665536772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0898976348453995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0353661056043624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0088374118344844987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25456644298592457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23786454277617705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37159842402365523,
                                   0,
                                   -0.46945823222868577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080035989016705972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14977484657375967,
                                   0.063212988512190371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62295290235708789,
                                   -0.022116217239403609,
                                   0,
                                   -0.1029084340827139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25076594221417436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23930134475944417,
                                   0,
                                   0,
                                   0.060364067148957534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16664191680244345,
                                   0,
                                   0.037393325379823941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37970905438333002,
                                   0,
                                   0.55512252260999206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73875280741420546,
                                   0,
                                   0,
                                   -0.059697788431016793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30345702003826791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45412463387991348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35772648848740041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09659499875060637,
                                   0.51888703803904357,
                                   0,
                                   0,
                                   0,
                                   0.52104720855458109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24563939739837368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47122857073082336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084323232050120212,
                                   0,
                                   -0.32051551721218352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20689795375266781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56135729824464853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11979521215898407,
                                   -0.046519419199519588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2987434319575262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47792902809392174,
                                   -0.28077710934999422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48562855385505971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37211871302732691,
                                   0,
                                   0.54203550055747074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022222657442487491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052794490237997677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38051526875219538,
                                   -0.55286697727979139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013691237923181401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34268578133472466,
                                   0.80256984976965073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13850754057116565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34593668885824658,
                                   0,
                                   0,
                                   0.0099527731656712665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60467592977358531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10304764757852838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022190828253081996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.196777222760049,
                                   0,
                                   -1.3009273954517879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58874038745670942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6381624314614418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13639541269647137,
                                   0,
                                   0,
                                   -0.13560292458012452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092086376203116035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21636005993383448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29371423322812201,
                                   0.20849486904842207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012605058178116427,
                                   0.020719974298034561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53015075756915997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23479277995556835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18425914299648144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21900971833738272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47418460754370184,
                                   0,
                                   0,
                                   0.58071082977801014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19095821140211586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14675687546493216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013292326391694968,
                                   -0.284005467341095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095341622627628991,
                                   0.029341360323183609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3237061940877895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36558829053579556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052237767024517698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084654165862648484,
                                   0,
                                   -0.2909433298587219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72139459455914701,
                                   0,
                                   0,
                                   -0.63405793495272267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15686863048695776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11362924929415816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2440305548006953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2863955872028715,
                                   -0.089808214797648764,
                                   0,
                                   0,
                                   0,
                                   -0.60305646046170813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7276757824822746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20821200582695376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60108950491674151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1734557900575711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57182728863426735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.036679873708604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16351795440175645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26670868904874101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38265940253835112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042427706883249219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17256484555121293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41528658612228192,
                                   0,
                                   0,
                                   -0.38134783979794268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0064765748102626926,
                                   -0.50082261063757927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37433883863946182,
                                   0,
                                   -0.10052214517692189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32094301792347113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24977120455817564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15843348070100896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096294059305693652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10684535600715979,
                                   0,
                                   0,
                                   0.56942859084321684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50309386479206319,
                                   -0.32511949099350745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036549777243511362,
                                   0,
                                   0.22312925112855789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39704799759969589,
                                   0,
                                   -0.0761412407009599,
                                   0,
                                   0,
                                   0,
                                   -0.1347398562576701,
                                   0,
                                   0.29608871646426543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79046051856177479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42438876260287828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28886934997360458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17057757091817533,
                                   0,
                                   -0.56299071803884693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77235573476002317,
                                   0,
                                   0,
                                   -0.68028869221084898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33636172062365693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41219084768579961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1924143265836433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26441183553077446,
                                   0.64846651858709481,
                                   0,
                                   0,
                                   0,
                                   -0.023287671872612881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20817789002809545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73349611368330614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45325151469186625,
                                   0,
                                   0.0019890542764172403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15072399668907377,
                                   0,
                                   0,
                                   -0.40398896967052095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40021663724694068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14163236226115655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27601390492730848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61284786047276374,
                                   0.43237813015169158,
                                   0,
                                   0,
                                   0,
                                   0.23046726549345267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7741507201662492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58767196403454092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11051842436456305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75145054929420707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26821133228253236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5194428889739362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25940051492761251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9665627706513813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10075589636605845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071730809825387473,
                                   0,
                                   0,
                                   -0.31663243897718929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14561933119284629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20136816234770927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19210699474541432,
                                   -0.28257129250799101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17089146732405039,
                                   0.77429719200975688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067098297220477165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21495538787147919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16276684007898837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38096552125476935,
                                   0,
                                   -0.07974024479797498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1956226249360857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041191135794719162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23240352835616296,
                                   0.074115380923369154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31140871707352069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58876336866657086,
                                   -0.27829942680381403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080463092449606283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49820137002541315,
                                   0,
                                   0.27308971316121505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58698818978699441,
                                   0,
                                   0,
                                   -0.19566137754150109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55405096715744118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023349495503649398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0840122992378369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83473343184731441,
                                   0.064436874424387752,
                                   0,
                                   0,
                                   0,
                                   0.26924961614305493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31873643933066304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22107639401081131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09765059655614125,
                                   0,
                                   0,
                                   0,
                                   -0.24164412335010282,
                                   0,
                                   0.18991962041083885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42867836525099084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56099449837432891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63049428893929416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19002410701497729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58844278753768187,
                                   0,
                                   0.13148578848947168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00285798854863001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10175104257153707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50711035727885723,
                                   -0.69927694363573845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22280435898911388,
                                   0,
                                   0,
                                   0,
                                   -0.11833984342895959,
                                   -0.59303561666684868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49521856607272025,
                                   0.37673440308290124,
                                   0,
                                   -0.29047605867420845,
                                   -0.31414132617342849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28920741107157405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37302589099310457,
                                   0,
                                   0,
                                   0.018231085146078463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17678204437048656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019393852257826527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26409411208615996,
                                   -0.6515955520880633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15203493942170637,
                                   -0.24717245564598159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28519362639573681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034739716018796718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29013240299369897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68148783890411169,
                                   0,
                                   0,
                                   0.075817329650451598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77067418909076257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44971204608879067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79372194230158377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62417220021161612,
                                   0,
                                   -0.63061831110217925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43296330382842074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12757923625167999,
                                   0,
                                   0.4888819470525706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30957669545001604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2037312007992951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47894564247006849,
                                   0.4780420449434627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097148609279450487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13880864655228708,
                                   -0.062352093641870915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0915798766579043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22528227372315429,
                                   0,
                                   0.054207034007073628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19973439307683344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95752091839450382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16456490083298458,
                                   -0.20141892235569619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12993551013184879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070230357404978128,
                                   -0.40032099936800725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46056237883795825,
                                   0,
                                   0.14577428219960886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17426146428376288,
                                   0,
                                   -0.18260945865318182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42901765321313795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5685299126712634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04075373893739348,
                                   -0.12377699324118743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43594308194692638,
                                   0,
                                   0,
                                   0,
                                   -0.29600236187807449,
                                   0.66528836934399704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030141668580073028,
                                   -0.72176862755226334,
                                   0,
                                   0.29476933780411751,
                                   -0.022952649174376123,
                                   0,
                                   0,
                                   0,
                                   0.048898399524153612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20149169502802711,
                                   0,
                                   -0.32838249329903535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10600231183722039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17606718163861151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29109605674450145,
                                   -0.20845652557433891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33452870646991845,
                                   0,
                                   0,
                                   0,
                                   0.22085967985814964,
                                   -0.55243943820250552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17196375574363493,
                                   -0.086349444685777987,
                                   0,
                                   -0.47356465840891515,
                                   0.62240605957707384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89770145288888425,
                                   0,
                                   0,
                                   -0.18412254916255355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12539179977632953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95349332593786829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21754927507677338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65254755062402126,
                                   0,
                                   -0.10466325451552624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13656740779459853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14998704472804553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055735730372657853,
                                   0,
                                   0.21294576373866297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15566117827468129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16273491977512047,
                                   0.27973515395913146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1259091630400366,
                                   0.5966661071577104,
                                   0,
                                   -0.069865709394077699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24767027890277554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15662180806307457,
                                   0,
                                   0,
                                   0.076752930279245388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55296020657057188,
                                   0,
                                   0.16067036221921613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79313898916806091,
                                   0,
                                   0,
                                   -0.3458045896646903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012637562093125207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78687173559645007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0764621006018866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93880500919166909,
                                   0,
                                   0.33655528006253815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12132746461172744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33126154043156109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15823826068920469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75680396562125174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18986501062254135,
                                   0,
                                   0,
                                   -0.30963029979325934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15742455646363551,
                                   0.012134866323056499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14094255801268163,
                                   0,
                                   -0.33103591378273695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078582635897314818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60119350566897456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23076683618354782,
                                   0,
                                   0.032085292902882048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13836358005240249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11021457337406577,
                                   -0.072775693508774358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13196530026622655,
                                   -0.17868217064651565,
                                   0,
                                   0.58500676583778122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15559360995327889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25309771911278556,
                                   0,
                                   0,
                                   0.097339010418296262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20597709263546848,
                                   0,
                                   0.12629801593273526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63987320454879648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25616085411081591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35806000885290074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23046113336207208,
                                   0,
                                   0,
                                   0.43464992872498787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14165206512640302,
                                   -0.18272886782162839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0023987394931194207,
                                   0,
                                   -0.27175115383146542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16551267081684834,
                                   0,
                                   0,
                                   -0.72742677205780559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040697597859476221,
                                   0,
                                   -0.038221576355322986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01571324068384004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72887672340733856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44348142208478453,
                                   -0.44104464920598208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56309405030564996,
                                   0,
                                   0,
                                   0,
                                   0.030313758516863371,
                                   0.19614727363522524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027529730710340747,
                                   0.087430729492681589,
                                   0,
                                   0.12294905193574757,
                                   -0.08594411924367891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60857237326588898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026736921623760596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36564318039022603,
                                   0,
                                   0,
                                   0,
                                   0.1364648395735121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47533229379797254,
                                   0,
                                   -0.50005729370107643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014180713803294609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020199914827716291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62979087998330496,
                                   0,
                                   -0.23789342533811036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.106206399811533,
                                   0,
                                   0,
                                   0.13772497308454365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29338283571496637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42326071527785381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17458283783710082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80801997685081717,
                                   0.17199265183866486,
                                   0,
                                   0,
                                   0,
                                   0.90917361054574664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25323802802028039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49427940366232348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0472243328367525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18326414455481957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03840977184917288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15456807999389624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64676833982346738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81027066409978543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12369948290798474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49091372509734998,
                                   0,
                                   0.39790606967123954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23470921394593122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26122856475224276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26530597011843299,
                                   0.41858608852102808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15914979512647637,
                                   0,
                                   0,
                                   0,
                                   0.27154440629691312,
                                   -0.56898968287259799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4487434080903383,
                                   -0.70845386596078996,
                                   0,
                                   0.19632727266479963,
                                   0.3888616231421681,
                                   0,
                                   0,
                                   0,
                                   -0.36929225536405891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13903060876411688,
                                   0,
                                   -0.16877766164007646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32671391672833477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23064343677837737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47775281631048694,
                                   0.097162264085791025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53517419892389684,
                                   0,
                                   0,
                                   0,
                                   0.59518690395392682,
                                   -0.059317860163697583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20625369324296616,
                                   0.01620726529527991,
                                   0,
                                   0.1690545593679291,
                                   -0.61381850873894095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12228359725692098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31782921823629628,
                                   0,
                                   0,
                                   -0.4245413117659268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18647058170526354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23698393862101447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078697502990450321,
                                   -0.45817437324734439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3065050007628089,
                                   -0.33336518855973446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00066003598869878929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060278140440452987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43362969443913574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14788491100096432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037011112033709,
                                   0,
                                   0.26071438290275256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095571238764847716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31377175643440031,
                                   -0.41040951017945643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50839008780658179,
                                   0.35449075794074286,
                                   0,
                                   0.25615868491135363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083668393612314318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1854976752958036,
                                   0,
                                   0,
                                   -0.12192936615423097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28713213691535322,
                                   0,
                                   -0.21048236424964697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068043973278943667,
                                   0,
                                   0,
                                   0.63039596714433932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.143495620607536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3136724126327729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72012252695619416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21902181505235885,
                                   0,
                                   0.12023017113101109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75689732107910701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13554474624703125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48823620273775992,
                                   0,
                                   -0.29757287925837284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18746397440404428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023328467463325543,
                                   0.013620179270020679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21341640424436209,
                                   0.051326695666777354,
                                   0,
                                   0.14934288095773471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58168008287334783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20069571107756459,
                                   0,
                                   0,
                                   -0.13543610223579211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0074130940048912422,
                                   0,
                                   -0.38899650238091732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11296368765799095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45906410512445706,
                                   0,
                                   0.34714709425705137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17975865631536342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55714317206368269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27481801086803748,
                                   0.73286795364549628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2996179819888472,
                                   0,
                                   0,
                                   0,
                                   -0.21754877656185689,
                                   0.45589786300399049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23875737360564625,
                                   0.34236316371988307,
                                   0,
                                   -0.42207158088392716,
                                   0.58001958791634445,
                                   0,
                                   0,
                                   0,
                                   0.46691389143949702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74812137917296972,
                                   0,
                                   0.31579800858467144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17305325566117874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40909265847186438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53216394367765507,
                                   0.34744286298333704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54313848541778609,
                                   0,
                                   0,
                                   0,
                                   -0.21049423306671838,
                                   -0.41727458719088117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15143969734041723,
                                   0.007235107188314556,
                                   0,
                                   -0.018297770145811437,
                                   -0.43775777371079949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14102294202734245,
                                   0,
                                   0.31744221006053175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21542632006123355,
                                   0,
                                   0,
                                   -0.34128855135269931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25746748990071727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.207861735446526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34126163410578225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17787809727379222,
                                   -1.2025841974314533,
                                   0,
                                   0,
                                   0,
                                   0.13576703531019768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20868614098943405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44023861700468508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18586590151370427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.264076428050534,
                                   0,
                                   0.61235966219172289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40511341287800429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21319017970534584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24114693664041617,
                                   -0.48134537952899692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11506416490968099,
                                   0,
                                   0,
                                   0,
                                   0.46672212082815545,
                                   0.14285537119078046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72344864547289067,
                                   -0.16203132662436931,
                                   0,
                                   -0.045764038406849117,
                                   0.087190308949941633,
                                   0,
                                   0,
                                   0,
                                   0.26681344875200369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19965968551366209,
                                   0,
                                   0.85121388514483898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23639601502384547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23927832003734154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44759602321235226,
                                   0.11272067064819016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24441697014351887,
                                   0,
                                   0,
                                   0,
                                   -0.074736094343271997,
                                   0.30624316776635879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67249959061658537,
                                   -0.037139832478723517,
                                   0,
                                   -0.050609857080910134,
                                   0.51492560050820579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42148656306017551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24389023925165898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16079013771526862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35894468515848393,
                                   0,
                                   0,
                                   -0.083563871827756125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25122808622368709,
                                   0.55691378114090562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0097535530182583062,
                                   0,
                                   0.47676817665482368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022746764453541245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63925103178797127,
                                   0,
                                   -0.67671099171107263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.438186960557361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023495169426011143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38192334464508038,
                                   0.095336682362501118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099915959027680357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46912445766330185,
                                   0.13149926570119425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33860979023952037,
                                   0.32898089813381992,
                                   0,
                                   -0.10503933347130393,
                                   0,
                                   0.21910322577888389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35738515924936426,
                                   0,
                                   0,
                                   0,
                                   -0.05550613971191172,
                                   0,
                                   -0.023960095997785806,
                                   0,
                                   0,
                                   0.063291867135105359,
                                   0,
                                   0,
                                   0,
                                   0.72165667295478064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25500846081051448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19461901490623118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24546112726528385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1157655329994149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20952236562248994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37105394312552054,
                                   0,
                                   0,
                                   0.1481639603860018,
                                   0.12902299374952039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16909800844800962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16723596336564533,
                                   -0.20742470677568067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57556686084453001,
                                   0.078381951081210904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29487038633300167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4003533971527215,
                                   0.14547436540995726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21231114192823597,
                                   -0.17129420233263412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37067407207483066,
                                   0,
                                   0.094235563430679153,
                                   0,
                                   0.16301886641087776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31642147823282807,
                                   0,
                                   0,
                                   0,
                                   0.017280561704934347,
                                   0,
                                   0.052127131638365805,
                                   0,
                                   0,
                                   0.25648253373099866,
                                   0,
                                   0,
                                   0,
                                   0.14542406997150034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28177204833960129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2809814933675488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44673481742496279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52835338395938269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62251433242458787,
                                   0,
                                   0.031816425851398003,
                                   0.43569690119707061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29623823537763011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40780564205364922,
                                   -0.099316168722578937,
                                   0,
                                   0,
                                   -0.04654555933793611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38366657567617446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06909296442987059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45603713368004795,
                                   0,
                                   0,
                                   -0.24262919917884784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15577115387611346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97099588170805229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31410619555866598,
                                   0.17983397431723697,
                                   0,
                                   0.022704731616502771,
                                   0,
                                   0.23069694415055525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21372579605185357,
                                   0,
                                   0,
                                   0,
                                   0.049279941487688619,
                                   0,
                                   -0.057920265947131205,
                                   0,
                                   0,
                                   0.17846424460163327,
                                   0,
                                   0,
                                   0,
                                   0.10257856852592498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75778637250788639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1467111600468223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46411965692414608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09443471267642406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53530117376583763,
                                   0,
                                   -0.20108867486852008,
                                   0.069259375701498205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94659629684545632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31149924699852982,
                                   0.26026833809485,
                                   0,
                                   0,
                                   -0.44674009354060634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54898480463594979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29396073047892191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33347818158718279,
                                   0,
                                   0,
                                   -0.076982774290153641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057870438867035003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27919421100235203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043689098072349219,
                                   0,
                                   0,
                                   0,
                                   -0.23805031235054963,
                                   0,
                                   -0.11926924167241588,
                                   0.32653139115707125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4907683706226682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46262308618178788,
                                   -0.034232023718174374,
                                   0,
                                   0,
                                   0.27026564241438494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.508503383839918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4075996791674395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44589963217213852,
                                   0,
                                   0,
                                   -0.14090106145019241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59288554470499477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07929791387866765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.404474785434358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0754292425156631,
                                   0,
                                   0,
                                   0.1350294131513019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070135571049330978,
                                   0,
                                   0.3355960731962056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23574000742412948,
                                   0,
                                   -0.5251947088268849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24790674550576053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13108682721084752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036826762514126699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68037751897836962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34663449611665742,
                                   0,
                                   0.10061263792587943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080226204290543862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24507354653723407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15195398115278214,
                                   0.040340039981287837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083478766407230912,
                                   0.55431806907330705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74630268557122537,
                                   0,
                                   -0.20151953555552399,
                                   0,
                                   0.061700294640590327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082062315554784576,
                                   0,
                                   0,
                                   0,
                                   -0.029945406305975992,
                                   0,
                                   0.13280507739401751,
                                   0,
                                   0,
                                   -0.064657434834531916,
                                   0,
                                   0,
                                   0,
                                   -0.48207594709371082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10663242712358245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06706335841224112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34757861553936414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0095103724170761683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67024798924574513,
                                   0,
                                   0,
                                   0.52153873839854703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48245947506009257,
                                   0,
                                   0.38868170069591601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70550490578119884,
                                   0,
                                   0.83942618727035367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0013296366410540106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56853793737181912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56427174514217071,
                                   -0.47143970738467822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13167021976064622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34392686721364146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19006484720473357,
                                   0,
                                   0,
                                   0,
                                   0.28237040831051624,
                                   0,
                                   -0.74952154522430325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64334394805239081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51725257213892739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17496358013112878,
                                   0,
                                   0,
                                   0,
                                   0.013970519208984022,
                                   0,
                                   -0.18526569265194029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49519991622327797,
                                   0.25756402206301382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16690336924398119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72370573095822122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049334697517068711,
                                   0,
                                   0,
                                   0,
                                   -0.28928619137590861,
                                   0,
                                   -0.48540729035473607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36766303877081269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19845393798093763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33399454740318596,
                                   0,
                                   0,
                                   0,
                                   -0.47692543702152135,
                                   0,
                                   0.20889551875799908,
                                   0,
                                   0,
                                   -0.13386936542459041,
                                   0,
                                   0.45537267548250782,
                                   0,
                                   0.44980398069652505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13878051296597788,
                                   0,
                                   0,
                                   0,
                                   -0.53709847728423976,
                                   0,
                                   -0.098607178988041777,
                                   0,
                                   0,
                                   0.38883691423411693,
                                   0,
                                   0,
                                   0,
                                   -0.23296285690811525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068424754449366826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078558003882440025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18695774750809355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06050266628427918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28005852777461759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18247865336818894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09409030269826528,
                                   0,
                                   -0.39475179745384326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10321607006969641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47708735235865152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19029654738446997,
                                   -0.175603453028392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31651231892326104,
                                   0.56399601048004866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034259002242055928,
                                   0,
                                   -0.25926946275180107,
                                   0,
                                   -0.3483722613088292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2206153594771377,
                                   0,
                                   0,
                                   0,
                                   -0.29810436099402304,
                                   0,
                                   0.11846952041737087,
                                   0,
                                   0,
                                   0.38325733899841496,
                                   0,
                                   0,
                                   0,
                                   0.22586857183612369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16645823798787768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52565872022982507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061874140576065717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39104145022285308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058468665775083313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16558243023722319,
                                   0,
                                   0,
                                   -0.5152502609245484,
                                   -0.1141807384417976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096000054704927021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22542837129857776,
                                   -0.14502938996470371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041224825149409026,
                                   0.026965367107361131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35633499314158601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01087875086219945,
                                   -0.66106847754052567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030466797531174258,
                                   -0.20522418698377895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17625432257579424,
                                   0,
                                   0.1604662076425063,
                                   -0.16303507582937971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27700651031560308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0067649852704345231,
                                   0.19079880393046084,
                                   0,
                                   0,
                                   -0.49466512704326498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11332947563644916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59338644278204256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035686108259206678,
                                   0,
                                   0,
                                   -1.1348749104544074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17421762445876132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29518795068079984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2883636904835567,
                                   -0.022935580923198216,
                                   0,
                                   -0.17651519197798043,
                                   0,
                                   0.41969490172314244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49289277043381652,
                                   0,
                                   0,
                                   0,
                                   0.44531559844415358,
                                   0,
                                   -0.41601714917711941,
                                   0,
                                   0,
                                   0.24854344753761276,
                                   0,
                                   0,
                                   0,
                                   -0.030128854597184396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.007311221959707629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05289162743563925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21013397915218757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26108263292748518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52525793252979636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050588846554713747,
                                   0,
                                   0,
                                   -0.19686635401305186,
                                   0.22179806218196901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49758686142605207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064729025568776924,
                                   0.061024346345384846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035618741890417457,
                                   -0.25344042509401138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32750573882541634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030613837487847524,
                                   0.099786489235748357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43896993647189397,
                                   -0.041685975001049494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28187763367703489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3049857672129202,
                                   0,
                                   0,
                                   -0.2486904465401531,
                                   -0.20143316573453104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15451775151225133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35243198890424976,
                                   0.18028007587714828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11275472326856736,
                                   -0.18967285775955878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18857490371369123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45354504235259097,
                                   -0.25321085080967581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022405270610156548,
                                   0.43583336657051913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3025118493180152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16002499410616947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4546426873864659,
                                   0.29777597519970617,
                                   0,
                                   0,
                                   0,
                                   0.12294372159544949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58701523767137687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37857655603749318,
                                   0.20849904541403344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26046375411755607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1654497204132615,
                                   0,
                                   0,
                                   0,
                                   -0.039476802069222411,
                                   0,
                                   0.34836661088722348,
                                   0,
                                   0.14084744439735836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38926172796335906,
                                   0,
                                   0,
                                   0,
                                   0.050130836622464661,
                                   0,
                                   0.44339295937983453,
                                   0,
                                   0,
                                   -0.19667122210603588,
                                   0,
                                   0,
                                   0,
                                   0.29261288956472148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39568192350180831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032367040822225274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42438748897839951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2111652206112796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034712875816280846,
                                   0,
                                   0.14347635879605172,
                                   0.078540755276855306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047991877193407514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068203918125590624,
                                   0.30886751562019255,
                                   0,
                                   0,
                                   0.33916147092065702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3624625482605553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48587641055828046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62165793838315853,
                                   0,
                                   0,
                                   -0.16854669821698076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63695146917701551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33370738368916386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77389382212405977,
                                   0,
                                   0,
                                   0,
                                   0.29723323013162178,
                                   0,
                                   0.42479887423132484,
                                   0.20864702695615936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010714852511858913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56458597903267416,
                                   0.066361775892384178,
                                   0,
                                   0,
                                   -0.51986276515216523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4425847509383965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91410248727837107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21842624316910725,
                                   0,
                                   0,
                                   -0.017173401979406699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14897547171532716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013398572285199251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59087285839178383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18435155804457329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30893000140200899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31373382072271372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43957303994977298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58011438345851585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1942637577866633,
                                   0,
                                   0,
                                   -0.022002919887354977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45184970465401236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02000177116918328,
                                   0,
                                   0,
                                   0.82102799555022299,
                                   0,
                                   0,
                                   0.43999263034150882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73630006698288841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52376294144955693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21643270347566546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14329664919794791,
                                   0,
                                   0.38736134098745045,
                                   1.0751708991183304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049291379946161708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10656185578674693,
                                   0.23823450600873158,
                                   0,
                                   0,
                                   0.26688508055801508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50579633728565132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18457109796047594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10233814975967676,
                                   0,
                                   0,
                                   0.029445841979737555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49462573887742406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25181123146195344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36623394275411114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60991603340917022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30010247470692847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19415625194845262,
                                   0,
                                   -0.25135881193497955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0037559759979391011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16640118989060218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18552642836878075,
                                   -0.6003809945470685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084313114576410719,
                                   -0.085868943619238317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1325645105044444,
                                   0,
                                   0,
                                   -0.067853405500121977,
                                   0,
                                   0,
                                   0.33962100520320671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31932123217162928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94862008528303809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49160673129550048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26897998061160289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062208308191243358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56500450827200999,
                                   0,
                                   -0.15792334024760893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17714267612440876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39834539038121702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41014001210079876,
                                   0.18784206519119237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2400844146891333,
                                   -0.35834542798683311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28453712734573672,
                                   -0.8207654588283162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38026692900866088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19746685079002485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52307043195690783,
                                   0,
                                   0,
                                   0,
                                   -0.554703034716448,
                                   0,
                                   -0.21402952419766094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054579949479990023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55339572969372852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50378911929775416,
                                   0,
                                   0,
                                   0,
                                   -0.10195104803154523,
                                   0,
                                   -0.51332830915819005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22013343727710782,
                                   0,
                                   0,
                                   0.26309918669911808,
                                   0,
                                   0,
                                   -0.28274564857568191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93414907517951584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068929177794848251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98802417594386438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068330857893467989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10394882606412081,
                                   0,
                                   0,
                                   0.10123313442394791,
                                   0.68110679450257627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12272392514960723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21316262236981992,
                                   0.023690725740189263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23158648109922414,
                                   -0.3134299207258987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36032997271131045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22377475557500198,
                                   -0.02426183605307659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26131587705866527,
                                   0.22057229730454131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19730402300187899,
                                   0.70320934651829015,
                                   0,
                                   0,
                                   0,
                                   0.25359353866870821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56532931354225835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054849960849609275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2822273970873711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47196121293575261,
                                   0.14982554098889442,
                                   0,
                                   0,
                                   0,
                                   0.63239081803204233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49858719212023916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23368382468069163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22735315251085067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24785690495002463,
                                   -0.096504242281643726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12549664774958424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50693852910927228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93041977306525114,
                                   0,
                                   0,
                                   0,
                                   -0.32481416801627472,
                                   0,
                                   -0.11558102551157656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22014517692590779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15840658012762224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77464110249987217,
                                   0,
                                   0,
                                   0,
                                   -0.072348835734335357,
                                   0,
                                   -0.17415234175668956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53757032133614757,
                                   0,
                                   -0.77534994530950119,
                                   0.33672169145169489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61958881002044042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36750943017883003,
                                   -0.051893442870015322,
                                   0,
                                   0,
                                   -0.0079217530727046931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23393179586238855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40124322091293146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56226225102318383,
                                   0,
                                   0,
                                   0.40372652640686568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011682470458104763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20067799037763648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37194696689092044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48056565778960636,
                                   0,
                                   0,
                                   -0.13443834667095556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.230764493536214,
                                   0,
                                   -0.14967759798738278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41586768080276038,
                                   0,
                                   0.1081445631761062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88137467649814416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61024239942802871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54536122300946288,
                                   0.53523334246299448,
                                   0,
                                   0,
                                   0,
                                   -0.17823068483810878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22821956290868742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52742347413656465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23255222762023453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63500557924873191,
                                   0,
                                   0,
                                   0.20708749160574791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87212413377028342,
                                   0,
                                   -0.71606717317498647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39205229988309759,
                                   0,
                                   -1.0422872722008658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21002228304291443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37126317724830304,
                                   0,
                                   0,
                                   0.24536391619751854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23493782135452473,
                                   0,
                                   0,
                                   -0.050365823653323219,
                                   -0.17492584001757921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3026106489462419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63749223225611695,
                                   -0.018217319513145494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20634606060811389,
                                   -0.41825992343757423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068156307224521068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12959577724626162,
                                   0.15377214719636598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27290399433803392,
                                   -0.12680973897301484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51129017264127896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33362760150943632,
                                   0,
                                   0,
                                   0.16778349454337821,
                                   -0.35086264522496502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13211199400374946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085117311334510393,
                                   0.1158596412654667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14483057157541396,
                                   -0.32197199980794433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02434388092562307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29446126643877524,
                                   -0.015621524599740033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4629530948411314,
                                   0.10670318057683782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19296987392602236,
                                   0,
                                   -0.16471382731485318,
                                   0,
                                   0.43534751308548592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21817037644913134,
                                   0,
                                   0,
                                   0,
                                   0.29403330702712727,
                                   0,
                                   0.63204572942818626,
                                   0,
                                   0,
                                   -0.00067615986125989236,
                                   0,
                                   0,
                                   0,
                                   -0.10999881854163457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18235313607016398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26687079185763585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16721701470463041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26083406554377625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093670025686020009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16659360185449107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35623367191207322,
                                   0,
                                   -0.30241668677353428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66682710225453035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -8.6242735019344263e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35668219700105558,
                                   0.25666513963707566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31378930413924822,
                                   0.094302247971562392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44063177873595516,
                                   0.72519236134170573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37576353551859887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079297606046888069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33285628006937884,
                                   0,
                                   0,
                                   0,
                                   -0.47968951679288652,
                                   0,
                                   0.29804958565564249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48091033733488059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18773157513306393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45985285831118239,
                                   0,
                                   0,
                                   0,
                                   -0.43506039757123133,
                                   0,
                                   0.023251204480911961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45432239231834226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40348043077302176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0033727578711122697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010262614218178201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16513114687344987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31864092025499458,
                                   0,
                                   0,
                                   0.4974862441875112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50436605178245264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17578358677583483,
                                   -0.080113620820899401,
                                   0,
                                   0,
                                   0,
                                   0.26528867731105232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43296200481392638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18458681096983837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81900883247571288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059880395435693325,
                                   0,
                                   0,
                                   -0.20138845603800448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11352493645489314,
                                   0,
                                   -0.39869855277113003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1036353640518466,
                                   0,
                                   0.16636309018605358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41931578649677659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88288563235748385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48937615291558761,
                                   -0.51785998264074606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51313506241678608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22900008210853282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32123088855909798,
                                   0,
                                   0,
                                   0,
                                   0.053272103977982904,
                                   0,
                                   0.26695022893290626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18130059782176119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31622754940396441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66656976201014406,
                                   0,
                                   0,
                                   0,
                                   -0.4784558855981757,
                                   0,
                                   -0.23282869731694003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050638580157572,
                                   0,
                                   0,
                                   -0.7677683234312106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65087107061496896,
                                   0,
                                   0.6482642768760809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10100159659217899,
                                   0,
                                   -0.076085196104476088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48853193936370276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35702913783973977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22611888608500194,
                                   0.026869968844539106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60721814848397349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16192945188950197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17354228977982764,
                                   0,
                                   0,
                                   0,
                                   0.14239269680460526,
                                   0,
                                   0.13432117169180294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33171406332806175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.691156398681115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091234820666251853,
                                   0,
                                   0,
                                   0,
                                   -0.19825246656295567,
                                   0,
                                   0.95104973581848873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3869637346504165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35881179167118799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64751560029351696,
                                   0.55955514469227463,
                                   0,
                                   0,
                                   0,
                                   -0.71483753228349411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6797837078452994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27438583413566675,
                                   0.19115263136650729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30494221848416309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13660463885260782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53195078579423105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2151326744072028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056603501505803566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25454354058447048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17597129626890717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70311995702902286,
                                   0,
                                   0,
                                   0.26790447212801327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075056952976149477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01945388828142984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36246695623686487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40481986834907774,
                                   0,
                                   -0.14112137370813987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45448847249416791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051199025431286543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27134401748765352,
                                   -0.31106282009869879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53682537419644583,
                                   0.12920772364388181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0736144218286268,
                                   0,
                                   0,
                                   -0.46296929180870139,
                                   0,
                                   0,
                                   0.47371052599633123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53085570406641747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2106104767730716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38495295247183153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32632281218642484,
                                   0,
                                   0.60467589643523001,
                                   0,
                                   -0.15214667134837212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16312453711957256,
                                   0,
                                   0,
                                   0,
                                   0.1161159306938417,
                                   0,
                                   0.025456915443567464,
                                   0,
                                   0,
                                   -0.19489605878121979,
                                   0,
                                   0,
                                   0,
                                   0.0044535305334825401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18623713097663863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036047781666088602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23443512514630352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57882937668785228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13189805146082387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12122758433980826,
                                   0,
                                   0,
                                   0.40628780150278632,
                                   -0.29126721552187534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36318851682133058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24552523273755161,
                                   -0.53306499246137318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34961612903790906,
                                   0.050715011152807382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12834399330816629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11655680111954814,
                                   -0.1113740957278702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10253050928714388,
                                   0.25273656324225763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0086005005505348786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30591222834047249,
                                   0,
                                   0,
                                   0.094906859190043824,
                                   0.12831731052887818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35775111438379198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18920555487185908,
                                   -0.14350523854502012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13346933950585946,
                                   -0.34284292016527224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04581933213145039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40766068932373023,
                                   -0.23856555565585438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33832007674333181,
                                   0.47061317504596367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058407830241962749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62756997038814166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35429156939043305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5185771290749851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32909316840078257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057245664811897051,
                                   0,
                                   0,
                                   -0.096403503399478369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2956800426088122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47606075182261243,
                                   0,
                                   0,
                                   0.51522268690298034,
                                   0,
                                   0,
                                   -0.83113659175477417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65001557695049295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28512114941758299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084510242022265827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20323107279307706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22896260515767597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29950984379629936,
                                   0.35701723761547771,
                                   0,
                                   0,
                                   0,
                                   0.053689398390406623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59982902545784156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031718755097219498,
                                   -1.1349916267668823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65538308810348589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28422097844113114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26980874080689604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059636042027147652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93293063499876516,
                                   0.51047318512201623,
                                   0,
                                   0,
                                   0,
                                   0.21992921177932712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49701767809215514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42285051050664701,
                                   0.56645612406005386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60750736411846962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56398707697701589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0037662810867149198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086951886834236214,
                                   0,
                                   0,
                                   0.53678706278019306,
                                   -0.027257128176611169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052264578646127005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20101573858488553,
                                   0.34529022956908412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21752504866957798,
                                   -0.19396423244797417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050737540428335226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12945146520402484,
                                   -0.40195572132937285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28492391671336653,
                                   -0.44063174690169415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6092500477014231,
                                   0.028523708948937937,
                                   0,
                                   0,
                                   0,
                                   0.52756939352846066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2420328331470224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46390705189118564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27546627252728362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11022065468791925,
                                   0,
                                   0.85613265489052959,
                                   -0.28602630641257387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16327471868191548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074639185473198533,
                                   -0.050382471022157545,
                                   0,
                                   0,
                                   -0.050627286271157389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63425976823188157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60316961300344096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.600989828160852,
                                   0,
                                   0,
                                   0.16350973936546515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17530923860558534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16938555773240943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58122897102796511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22191719326735859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94999268344243348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68812269465564269,
                                   0.08993175420001312,
                                   0,
                                   0,
                                   0,
                                   0.78336905790927092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46382594007211692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10934346174254567,
                                   -0.23115051949426177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10133542936430863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79934927249686261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42496508188976639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3815301475887859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11370048727954177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02878112518748295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20615353677956649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58956236045387711,
                                   0,
                                   0,
                                   0.12364699636226827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50468964164182939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012419486292399544,
                                   0,
                                   0.31940177203259185,
                                   0,
                                   -0.1485994378541117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4255523414284354,
                                   0,
                                   0,
                                   0,
                                   0.48684268761091126,
                                   0,
                                   -0.26970375783340067,
                                   0,
                                   0,
                                   0.094821093168350773,
                                   0,
                                   0,
                                   0,
                                   0.037934213564417854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0944689676142553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54528436671367597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21474395135296512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14863149515396884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024583495266102484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073949123818599388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24121874632735549,
                                   0,
                                   -0.64373563121871713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49197711013712936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30482810677667238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30677371512944174,
                                   0.13833552971211552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26974649543240542,
                                   0.019325576669677463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64922387460714104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48862164290160442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010879708894403595,
                                   0,
                                   0.19497485513465726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11255129814562406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21722557975305831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032037996640937705,
                                   0.17174735003123281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20451466368444127,
                                   0.41160552496416708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54283897744448706,
                                   0,
                                   0,
                                   -0.087076075879875203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38115999498760184,
                                   0,
                                   -0.49997586451329051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54763682077022324,
                                   0,
                                   0.87411317592971338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24280111174814573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55263749222706837,
                                   0,
                                   0,
                                   -0.41714329450144688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61096053556457275,
                                   0,
                                   0,
                                   0.22985346959818312,
                                   0.087688272669058695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095488374461975487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019382696894361964,
                                   -0.3370708162074687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39067535924640645,
                                   0.21341992133253851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0778217742808439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0091597103194411139,
                                   -0.24198576331658816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.006303628355304073,
                                   0.078575556520252013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023792636757433538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15236305010645801,
                                   0,
                                   0,
                                   0.15509818943648113,
                                   0.037889653338224388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03042712884009258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42130750060411087,
                                   0.55043588271281341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13516831680978333,
                                   0.49887112972938563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024576603495807418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051447959751647281,
                                   -0.1420766303305582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19116141158741778,
                                   0.37709497725957941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56252865435830313,
                                   0,
                                   -0.18151878114355141,
                                   -0.451730821178362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053410119507090244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23802101460939537,
                                   -0.5040635323984014,
                                   0,
                                   0,
                                   0.46667464534109881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42078646864872005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052579389904270427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49203197424637451,
                                   0,
                                   0,
                                   -0.28694038914539105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37487122403347684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074050919542194935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41804790362067079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19702634957067452,
                                   -0.4351349183177064,
                                   0,
                                   0,
                                   0,
                                   0.39407923835054803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36564110856903709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64414733347948461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26061574555699096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48888443254149283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63478866476166473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021411890048399433,
                                   0.90409994717722342,
                                   0,
                                   0,
                                   0,
                                   -0.16261668328528964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76166053738219153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14190155289475623,
                                   -0.77749642567225485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57714570315068947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33501979907527457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050517973001567074,
                                   0,
                                   -0.029608759698842517,
                                   -0.34913462565783537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031467845446037784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51732391543250034,
                                   0.88600529509461579,
                                   0,
                                   0,
                                   0.18062221467226783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015506700672893947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21870625820010492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080289554830205889,
                                   0,
                                   0,
                                   0.2807149860595205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12805472323913902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031883672707243654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32975855221003247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055742902839796382,
                                   -0.24318227256769653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3448628253864584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52642587367060867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23964805903914799,
                                   0,
                                   0,
                                   0,
                                   -0.48901857001754651,
                                   0,
                                   0.74608598845219321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59367880505023307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20597290254860057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43959397385014609,
                                   0,
                                   0,
                                   0,
                                   0.56455980425302676,
                                   0,
                                   -0.13867151033663466,
                                   0,
                                   0,
                                   0,
                                   0.25754444978752361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038115600196857911,
                                   0,
                                   0,
                                   0.17861987143376012,
                                   -0.039361616331668264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48160003762906378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10595325755590282,
                                   0.14823097957424877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41300227708640475,
                                   -0.22410614439831711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10752883349780742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49222583425351146,
                                   -0.18234807519715068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34478954852343813,
                                   -0.08278121576024508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1124797245371448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21963206129137358,
                                   0,
                                   0,
                                   0.0038184440744685744,
                                   -0.3875783078036194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2490536214832868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090254756719863688,
                                   0.15117476983317329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083802449463798057,
                                   -0.11703082785939556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68469858391577898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19450804975952057,
                                   0.31685050437089557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20516855137516973,
                                   0.16123936079835788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46974569004457128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74282114581305803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5474588862073283,
                                   0.12705405104797241,
                                   0,
                                   0,
                                   0,
                                   -0.56337024696946858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27672551601572892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40937606167939389,
                                   0.56734890350417844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7800877071442367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39484676725434364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46227155010148513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26115453534425725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59219549685177575,
                                   0.58402957531826516,
                                   0,
                                   0,
                                   0,
                                   0.97235668703960931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31728623636205777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44571329475507793,
                                   0.23292489413530043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0035984207047365657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1702288938045052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16543090204158972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070237785306370912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22066252813768461,
                                   0,
                                   0.11328173391383886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0076267972320040595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57804962870152754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063625853937709614,
                                   0.46221501035306428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56960990133453415,
                                   0.17270964518811185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13132903096063731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039597372992580378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34100797456676685,
                                   0,
                                   -0.41147597613227832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21337986874085491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22155893325953202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66183666128420371,
                                   0.38324987882366424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049111619104224576,
                                   -0.1168173778455418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42869892371807194,
                                   -0.13845964727145063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27259185653742679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57399970358791186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35921857552946063,
                                   0,
                                   0,
                                   0,
                                   -0.41882329014252395,
                                   0,
                                   -0.13755246513639585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57128559864897921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2397929961921475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48365718609896685,
                                   0,
                                   0,
                                   0,
                                   -0.56415873332169919,
                                   0,
                                   -0.49872330629202305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32513708607930186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25913889352024561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79044596732310357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1531274845063825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12614455889096463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021220783018950487,
                                   0,
                                   0,
                                   -0.33868765112258842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21865031205027949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37011847255183761,
                                   0,
                                   0.022778673688029865,
                                   0.66179101369214643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33712190269779135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88898269908299177,
                                   -0.54291406522919283,
                                   0,
                                   0,
                                   -0.11935054608743756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40901098133783009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70797063362997015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0032912272209033901,
                                   0,
                                   0,
                                   0.025080316951892317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28771465268165003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62402137341161368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18312956245957834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4719977259320749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6575202454755158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20011132095646814,
                                   -0.15050072258623709,
                                   0,
                                   0,
                                   0,
                                   0.62325779477032262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54923479894800986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66530191093602742,
                                   -0.10444788823317126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027332511872221063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83797148744706917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34781322462622782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15543427389491565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15678124918006894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51065413144723837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49777928560577089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050847139488284683,
                                   0,
                                   0,
                                   -0.501031283856468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26099070680787795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0026467907404825776,
                                   0,
                                   0.13068227069009838,
                                   0,
                                   -0.33758568236829795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045149638360956937,
                                   0,
                                   0,
                                   0,
                                   0.27960837938859506,
                                   0,
                                   0.33078809936753073,
                                   0,
                                   0,
                                   0.66982912720244581,
                                   0,
                                   0,
                                   0,
                                   -0.098827985567194493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06399441551707552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44828905685274834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10899507697812641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062726568832832702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46686364516184808,
                                   -0.43251466091300422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68085501360503264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16511543846437052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15248874968379117,
                                   0,
                                   0,
                                   0,
                                   -0.82004790845391917,
                                   0,
                                   0.20818236326571959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72772860899539127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0043731500719630945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1708773020751117,
                                   0,
                                   0,
                                   0,
                                   -0.2955101992963971,
                                   0,
                                   -0.32910236479886484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8184067983122868,
                                   0,
                                   -0.39295656558236097,
                                   0.17832445608406167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26677063365259723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42701957572949828,
                                   0.3265037345692744,
                                   0,
                                   0,
                                   -0.28853313860727942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32213095049179591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097387233498084466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13903544104605431,
                                   0,
                                   0,
                                   0.10239361231645094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074183126499804602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68309881909127379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14718855665210279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17041894953536868,
                                   0,
                                   0,
                                   -1.0805482269958786,
                                   0,
                                   0,
                                   -0.23259335405691217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062049290139294923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26391201145766574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83244608276252796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25678603729446453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25448305981174063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33244586560189426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4334876547300377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43673200958421632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11160325330104391,
                                   0,
                                   0,
                                   -0.53844833974258144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27883822199607339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21001825230766419,
                                   -0.16692925792410732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28833175337539918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24192114068566184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39760191095479264,
                                   0,
                                   0,
                                   0,
                                   -0.94706861839014278,
                                   0,
                                   -0.26719946718163401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079942921206989231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16862894795790653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18461582208305571,
                                   0,
                                   0,
                                   0,
                                   0.54685910154874706,
                                   0,
                                   0.65148931613457284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27912373489818026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10446361234899712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40890009858878273,
                                   0.11498228725709017,
                                   0,
                                   0,
                                   0,
                                   0.23508902683030039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80296438797126779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1288942165421112,
                                   0.15740393224321367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20303644776856639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50597633628531613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26184220532803404,
                                   -0.55946121114453218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033048211389095361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25990685352659082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13774828826962446,
                                   0,
                                   0,
                                   0,
                                   0.039135560690416515,
                                   0,
                                   0.46347033536827131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019551337495197371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74291404459225718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17644253093311288,
                                   0,
                                   0,
                                   0,
                                   -0.4320182495775694,
                                   0,
                                   0.5218762313188855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051394788850167489,
                                   0,
                                   0,
                                   1.0680075316922242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64215794710174379,
                                   0,
                                   0.29428301136214963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66077237730240879,
                                   0,
                                   0.15125466068936766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0089927650531861913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53422535755003286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17665666971117433,
                                   0,
                                   0.11713176867695713,
                                   -0.15565404914273798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43578769297767039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29947351300724434,
                                   -0.28023071996319415,
                                   0,
                                   0,
                                   -0.56696972305303173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5627142271122676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38023979619539072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28656645245686518,
                                   0,
                                   0,
                                   0.66600388038125269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4867907077375529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19754161965626171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32362407154979467,
                                   -0.099701644110563148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38733886611608925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16774831011742963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44827619307745625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061836280116553476,
                                   0,
                                   0,
                                   0,
                                   -0.36941830378799778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15884331023591625,
                                   0,
                                   0,
                                   0,
                                   -0.098197047093541545,
                                   0,
                                   0,
                                   0,
                                   0.65265736927432161,
                                   0,
                                   0,
                                   0,
                                   -0.099035531428663087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46334950597191682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7409547286452951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50883649618881355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076400180485596297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25519651027987278,
                                   0,
                                   -0.034554724507879456,
                                   0,
                                   -0.52211112575601715,
                                   0,
                                   0,
                                   0,
                                   0.23836845040971805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15207018856842824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19524442246384702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78304713353002398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1384463424695581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28699205848380605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10465717458942414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46456126157564759,
                                   -0.64321608901278138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32146160473005403,
                                   0,
                                   0.39171064051608473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28827607075516237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54544177143997408,
                                   0,
                                   0,
                                   -0.65797101307505468,
                                   0,
                                   0,
                                   0,
                                   -0.15395739652955459,
                                   0,
                                   0.15520301881892717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29291288799129894,
                                   0,
                                   -0.28671106590975282,
                                   0,
                                   0,
                                   0,
                                   0.19929942043242407,
                                   -0.61488745420505009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18893708142506146,
                                   0,
                                   0,
                                   0,
                                   -0.89690320150903058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2683032593146259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017942847445628698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68882142089038301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54427772980927835,
                                   0,
                                   -0.37190338880328255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2259650484544001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19897870100940432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38100667506275199,
                                   0,
                                   0.15536962391981243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14881675781565792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21201084037280965,
                                   0,
                                   0,
                                   0.21689086089025142,
                                   0,
                                   0,
                                   0,
                                   0.71511083469993042,
                                   0,
                                   0.37850837975540219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68510693851658122,
                                   0,
                                   -0.56326975250855538,
                                   0,
                                   0,
                                   0,
                                   0.60638368840052081,
                                   0.42809259540127387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2437818551724508,
                                   0,
                                   0,
                                   0,
                                   -0.52547551237868784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46139529285312575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080369236600716334,
                                   0,
                                   0,
                                   -0.39894381329456485,
                                   -0.19139875530319084,
                                   0,
                                   0,
                                   0,
                                   -0.1592795473585788,
                                   0.51640149110118372,
                                   0,
                                   0,
                                   0,
                                   -0.086974030652197706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21686531331272507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44213191505352017,
                                   0,
                                   -0.0064087403677940968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077620966721611576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29475875654218969,
                                   0,
                                   0,
                                   0.36920474076803611,
                                   0,
                                   -0.11747751868052594,
                                   0,
                                   -0.11212968594528927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13709733657247791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49754276979396861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061041381030282942,
                                   -0.43543187282951334,
                                   0,
                                   -0.36796069757536815,
                                   -0.1186940294743771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21333150420147534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4148414280773644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24296917671233684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1254662487882717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16426293683632848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26736369404625338,
                                   0.58426881740575198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47062887669835629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1483756756034198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29903185847309022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21553710230130529,
                                   0,
                                   0,
                                   0,
                                   0.36166328616056098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043092512780379261,
                                   0,
                                   0,
                                   0,
                                   -0.020982295014181418,
                                   0,
                                   0,
                                   0,
                                   0.25313212900844201,
                                   0,
                                   0,
                                   0,
                                   0.28648445823333857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52284284441606188,
                                   0,
                                   0,
                                   -0.052432544073833479,
                                   0.24871004381665845,
                                   0,
                                   0,
                                   0,
                                   0.34870178562261306,
                                   -0.29794893713682818,
                                   0,
                                   0,
                                   0,
                                   0.12901828179377914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0062182841921665649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25940672236641016,
                                   0,
                                   0.25462913636550272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42714543361126267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10738493951289828,
                                   0,
                                   0,
                                   0.17564835596336675,
                                   0,
                                   0.27758837646087575,
                                   0,
                                   0.030957565372959444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19663312614887923,
                                   0,
                                   0,
                                   -0.10956231175286725,
                                   0.025071435037226669,
                                   0,
                                   0,
                                   0,
                                   0.11491020462103096,
                                   -0.3233632391752741,
                                   0,
                                   0,
                                   0,
                                   -0.32045331744089744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13207643823294091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1405613961630747,
                                   0,
                                   0.061226171092754605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59364628898589078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23293743549837814,
                                   0,
                                   0,
                                   0.34492701272091353,
                                   0,
                                   -0.1182902902592501,
                                   0,
                                   -0.3842539923577229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55455033307930446,
                                   0.2324672949537894,
                                   -0.22741954875770093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036312565804758862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32068086962399711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52114691806119273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16399277455697261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4290345799718755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10326640861266981,
                                   0.19652652720485661,
                                   0.54363636808899818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13606109595419702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067984361097586543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30422697810133253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46330586030237592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56994035009529331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11653886675156713,
                                   -0.66762706272498673,
                                   0.38263951788843464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18326185778035828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43753869010443519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30950019292977621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25206411697427478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099639824661476056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080314664824813808,
                                   0,
                                   0,
                                   0.010187478449481431,
                                   0.0020758810308251288,
                                   0,
                                   0,
                                   0,
                                   -0.53561622347931448,
                                   -0.17757339503773528,
                                   0,
                                   0,
                                   0,
                                   0.11700812607386439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12441501122333107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086588198149787743,
                                   0,
                                   0.065927080601481919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23325568498259458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1660920343205651,
                                   0,
                                   0,
                                   0.01783842600049506,
                                   0,
                                   0.73551590124433486,
                                   0,
                                   -0.10350792079850903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20844219351025722,
                                   0,
                                   0,
                                   0.38282670283299297,
                                   -0.41389665291366751,
                                   0,
                                   0,
                                   0,
                                   -0.10607582437137604,
                                   0.040938639043709271,
                                   0,
                                   0,
                                   0,
                                   -0.28927428734337007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42324050220624598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32272611830040671,
                                   0,
                                   -0.037818566161983987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18076292424175855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32887979621715074,
                                   0,
                                   0,
                                   0.32946737185031527,
                                   0,
                                   0.079636310586042078,
                                   0,
                                   -0.040431447699917016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16636639303185102,
                                   0,
                                   -0.080221897756104721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15933044825976644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4445536325599535,
                                   0,
                                   0,
                                   0.17179937308142815,
                                   0,
                                   0,
                                   0,
                                   0.043519369774404154,
                                   0,
                                   -0.21670964520339436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0046179672465145247,
                                   0,
                                   0.61649570391504016,
                                   0,
                                   0,
                                   0,
                                   0.070707395422693692,
                                   0.14900701383470571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86326492593412341,
                                   0,
                                   0,
                                   0,
                                   -0.0072632355238261836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61995662884752512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061021243070625633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34431606155078198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10336144609137289,
                                   -0.16552186468727639,
                                   0,
                                   0.4791295607453025,
                                   0.044437897609426506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10693667917355906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092466377031704711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46126502634697764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073047858190982903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5921346461427579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13925365771454484,
                                   -0.024420660826321227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14382332739737663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35590975368552169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094463984125292638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067169964811205407,
                                   0,
                                   0,
                                   0,
                                   -0.043214222931524521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23907669161125772,
                                   0,
                                   0,
                                   0,
                                   0.85635229679631175,
                                   0,
                                   0,
                                   0,
                                   -0.19045924790748478,
                                   0,
                                   0,
                                   0,
                                   0.099861732940791176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1078131251771229,
                                   0,
                                   0,
                                   -0.10974665376301149,
                                   0.073394821143397432,
                                   0,
                                   0,
                                   0,
                                   -0.1414407883812468,
                                   -0.12117238802171768,
                                   0,
                                   0,
                                   0,
                                   0.41595480430339044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23240261352763011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48392264005858171,
                                   0,
                                   0.31213019125668789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036367820839605769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33288329948429995,
                                   0,
                                   0,
                                   0.068961710821105721,
                                   0,
                                   -0.3379092882208547,
                                   0,
                                   -0.38281704778349912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.003115799505576014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43538720934787167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22782541696861011,
                                   0,
                                   0.19524906964155586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25540505756367865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80942566458433585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40117280089245161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044274874444484531,
                                   0,
                                   0,
                                   -0.32521929072658162,
                                   0,
                                   0,
                                   0,
                                   -0.69927997566643485,
                                   0,
                                   0,
                                   0,
                                   0.39184696543220982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60401527795447141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60853918271197072,
                                   0,
                                   0,
                                   0.31432669899512722,
                                   0,
                                   0,
                                   0,
                                   -0.21113865003141133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86576031984869195,
                                   0,
                                   0,
                                   0.30089443699574359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25140191384492316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13404480280141484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30810796738226864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12442979919606308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11898451749380522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.346411966860945,
                                   0,
                                   0.11265488525733007,
                                   0,
                                   -0.016178540348168458,
                                   0,
                                   0,
                                   0,
                                   0.89630121585311529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84602137145207634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036319101077584376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25354684958498652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24321992889490598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0033757533881220618,
                                   -0.17240276501876514,
                                   0,
                                   0.0603513313398511,
                                   0.33686700973100159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27730758831135294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52717745514395742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010861014454668857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21159519230064586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42652892871403569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38479774544615009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1513543754949408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076760857790203141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075035558224818943,
                                   -0.068948224424553506,
                                   0,
                                   0.48489308000662568,
                                   -0.55019768405978198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40661192724683382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13627714884176273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015517001183057613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17320387791081931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36870134797648724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26998310164306943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11162740739239943,
                                   0.48815631085409616,
                                   0.40099422816716074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58378595958323942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34502014459393937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14051741499159673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21416548805712821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25097693140202554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17614251880655529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059539898854960499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54972014681352155,
                                   -0.33689659374817238,
                                   0,
                                   -0.19230101256237872,
                                   0.044211941689945675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05877556893356415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23088124087320486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086268784510981411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65149123171855572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011225772081628983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14843524704032757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42731806286926471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25414131962158315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21350319285951605,
                                   -0.42756869514833118,
                                   0,
                                   -0.28448893806302566,
                                   -0.28924853076561691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22513852152234265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19171440934763551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31787839013740982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034795736150855808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063635548528715141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40751138157398581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0051402931514959466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10911072704751043,
                                   0,
                                   0,
                                   -0.15901666026075489,
                                   0,
                                   0,
                                   0,
                                   -1.0184180328162533,
                                   0,
                                   0,
                                   0,
                                   0.1258644773704419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69811750393808036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49406413058279813,
                                   0,
                                   0,
                                   0.69470542333277741,
                                   0,
                                   0,
                                   0,
                                   0.27006546431940631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013893822029467939,
                                   0,
                                   0,
                                   0.23069349025531058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027648976403995204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18064569497251609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10313375026563942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091489217022495378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85131724113424989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33763679532442437,
                                   0,
                                   -0.71098700680220772,
                                   0,
                                   -0.4409206332116638,
                                   0,
                                   0,
                                   0,
                                   -0.051527941780759451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13131216609351198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27950101652128262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14493771711114276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049112973363370713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67495480761093984,
                                   0.75431261520862691,
                                   0,
                                   0.04157549009003321,
                                   0,
                                   -0.68249028226884034,
                                   0,
                                   0.22259761822634963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033675790654612327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.819978503630718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16121617854752723,
                                   0,
                                   0,
                                   0.021734166744362605,
                                   0,
                                   0,
                                   0,
                                   -0.25265246076434716,
                                   0,
                                   0,
                                   0,
                                   -0.73507419331866708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21970487382669074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84580532115498019,
                                   0,
                                   0,
                                   -0.14851761812886147,
                                   0,
                                   0,
                                   0,
                                   0.7204907065947912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099959835070680167,
                                   0,
                                   0,
                                   -0.3525078275471889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.596387529334241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070588966900024391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10880775083383139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14384770942215769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58141695908979685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46342180946076511,
                                   0,
                                   0,
                                   0,
                                   0.32091574279618579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37902514615349531,
                                   0,
                                   0,
                                   0,
                                   -0.14155024535066957,
                                   0,
                                   0,
                                   0,
                                   -0.23666737068955251,
                                   0,
                                   0,
                                   0,
                                   0.29493314853420727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1766428584598177,
                                   0,
                                   0.087992099644463279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054943229644844424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0284239216578843,
                                   0,
                                   0,
                                   0.01902857676660967,
                                   0,
                                   0,
                                   0,
                                   0.27269621363765095,
                                   0,
                                   -0.038965989745548026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54162190953018374,
                                   0,
                                   -0.12053866215142862,
                                   0,
                                   0,
                                   0,
                                   -0.60784529503715123,
                                   0.49920340212107961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30878514595369611,
                                   0,
                                   0,
                                   0,
                                   -0.0044300258757710639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11741443682072616,
                                   0,
                                   0,
                                   0,
                                   -0.91962080373586907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26305260923535945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5546492623630308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75037312328284522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94616728643330483,
                                   -0.28514844921488164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41642871824724975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74201349316374265,
                                   0,
                                   0,
                                   0.60230341994275716,
                                   0,
                                   0,
                                   0,
                                   -0.071033085530081891,
                                   0,
                                   0,
                                   0,
                                   0.34718892097263476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25400822574987747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037862192586953516,
                                   0,
                                   0,
                                   0.40320026223879007,
                                   0,
                                   0,
                                   0,
                                   0.76256165406469589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54968759398171718,
                                   0,
                                   0,
                                   0.12427193340200496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69476452961981683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24347287894519687,
                                   0,
                                   0.50392848505455867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41181956658448893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26290336537183795,
                                   0,
                                   0,
                                   0.38711280270608972,
                                   0,
                                   0,
                                   0,
                                   -0.65046982896014038,
                                   0,
                                   -0.22945690022612611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57546403088476383,
                                   0,
                                   0.5503179111327785,
                                   0,
                                   0,
                                   0,
                                   0.23257217202081643,
                                   -0.36136265621397812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38503530124603635,
                                   0,
                                   0,
                                   0,
                                   -0.38348981295137519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11757329855787818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098117287778231116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3313993881593198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37052515834953054,
                                   -0.15874491622692025,
                                   0,
                                   0.87581777723671694,
                                   0,
                                   0.78783958478974059,
                                   0,
                                   1.1424707579023452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35091090390098273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22013373919412021,
                                   -0.015295967513318631,
                                   -0.040656570643050921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40599483576966111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63160742383038393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21091338963067266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51021716154134977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28476035388321286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88764454583247243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63784045898032149,
                                   0,
                                   0,
                                   -0.50246424814019086,
                                   0,
                                   0,
                                   0,
                                   0.53795929596858161,
                                   0,
                                   0,
                                   0,
                                   -0.05943749823795591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084284270202967471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76686925971909714,
                                   0,
                                   0,
                                   0.4180174400925144,
                                   0,
                                   0,
                                   0,
                                   0.14835294665475307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020073328842450416,
                                   0,
                                   0,
                                   0.093880182776804391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087479498845069864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1350271134687004,
                                   0,
                                   0.13860799236721399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57486936083427764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56667364336551851,
                                   0,
                                   0,
                                   -0.15711382938538904,
                                   0,
                                   0,
                                   0,
                                   -0.11798265995510858,
                                   0,
                                   -0.26142330064865527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47094802441557643,
                                   0,
                                   -0.16795610784899026,
                                   0,
                                   0,
                                   0,
                                   -0.24734473598697937,
                                   -0.26968753255477029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046373255268719618,
                                   0,
                                   0,
                                   0,
                                   0.35797874120254591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2403310733358604,
                                   0,
                                   0,
                                   -0.071522017683141301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24831095937861544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2445122909204169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10922648815860554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1337211514666772,
                                   0,
                                   -0.25585200320531215,
                                   0,
                                   0.1162614309913538,
                                   0,
                                   0,
                                   0,
                                   -0.015754463755956676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42553741800012129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32100906860759965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41759473672445013,
                                   0,
                                   -0.37168856831323643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83035154957345969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20868725991851717,
                                   0,
                                   0,
                                   0.67402722084194422,
                                   0,
                                   0,
                                   0,
                                   -0.4271690698451957,
                                   0,
                                   0.49364038532402982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32601427295237168,
                                   0,
                                   -0.137630626197904,
                                   0,
                                   0,
                                   0,
                                   0.17540517634064812,
                                   -0.42180521103789925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15871042703851013,
                                   0,
                                   0,
                                   0,
                                   0.0063211991262245859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027100536896635316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2184779810074354,
                                   -0.045880091297388285,
                                   -0.38856490679240241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018600197573898958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38114162138705815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56702306438886063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5165076730783339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25547889823975173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36575468625272028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24926857455577867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66026609487818089,
                                   0.17197265515565485,
                                   0,
                                   -0.12878678461255597,
                                   -0.16534918677025892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074717649910693101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17469668018873674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066218725201792727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48035382763344087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13375971523788183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074285594919849332,
                                   0,
                                   0,
                                   0.91833897983093549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63042200301146223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07741574840949153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78407940300595846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61542427071712646,
                                   0.33784500084669467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3927663751567515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26126815804758369,
                                   0,
                                   0,
                                   0.29423857145043386,
                                   0,
                                   0,
                                   0,
                                   -0.10975460103108022,
                                   0,
                                   0,
                                   0,
                                   0.137631468155584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2319935078124781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45657854475216608,
                                   0,
                                   0,
                                   0.1320120680788123,
                                   0,
                                   0,
                                   0,
                                   0.27289784993987204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.223886327784206,
                                   0,
                                   0,
                                   0.28078157532511394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27450766619360673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06812054914855406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47536872276734116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16832627140624801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55112131109781781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074827072830766159,
                                   0,
                                   -0.033508404484990775,
                                   0,
                                   0.88160940459010873,
                                   0,
                                   0,
                                   0,
                                   0.20822619140734655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09981467121598192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14728494496996858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8926164184008919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044141527771652603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0095905835658579349,
                                   0,
                                   -0.19377038280688746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38064149501378253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13696921863893136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17741197374793022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25931172197100749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4869468062407008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43395171380017905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38830961612766757,
                                   0,
                                   0.43626485069252025,
                                   0,
                                   -0.21644031333310459,
                                   0,
                                   0,
                                   0,
                                   0.12425079893495798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60151665827962775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17882456241846068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064315536872839862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20899610950996697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77777168057646995,
                                   0,
                                   -0.40277554820812866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28318468529518798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32378023812397316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32953121836754695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46882412794333927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21134030349750385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019851979344029054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57114842897802887,
                                   0,
                                   0.061820460339613137,
                                   0,
                                   -0.12830436366973302,
                                   0,
                                   0,
                                   0,
                                   -0.67797925052944019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84016968335827003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11383561787919622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5144005352595431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023608356018128523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12429852698939327,
                                   -0.06591382501081107,
                                   0,
                                   0.27609743685384158,
                                   -0.28763331249130314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63993338963830271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014685482199773014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23297484835144472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2183066823271925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20556614163102135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046414749380000647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53946679056938218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.133955992994437,
                                   0,
                                   0,
                                   -0.43138113571359049,
                                   0,
                                   0,
                                   0,
                                   0.22376891645003957,
                                   0,
                                   0,
                                   0,
                                   -0.35260338300020538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18074328733862985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11165762701225679,
                                   0,
                                   0,
                                   0.69796948834620753,
                                   0,
                                   0,
                                   0,
                                   -0.24571967331229283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36027714024653928,
                                   0,
                                   0,
                                   0.83282402725243854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42182153261584598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11405518234717696,
                                   0,
                                   0,
                                   0.67190485030811342,
                                   -0.16736233217241653,
                                   0,
                                   0,
                                   0,
                                   0.035295850721378745,
                                   -0.017549099805986894,
                                   0,
                                   0,
                                   0,
                                   -0.076456831471408027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55861685316261034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23341090558482194,
                                   0,
                                   0.24541139040467105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083893479406320304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15474671101876264,
                                   0,
                                   0,
                                   0.11539700977159373,
                                   0,
                                   -0.092984330752145766,
                                   0,
                                   -0.14289267339492734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14708188124197721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10243658957409714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19729821083226093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54870215980971837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70082735053253942,
                                   0,
                                   0.66149268389243943,
                                   0,
                                   -0.16579528491964773,
                                   0,
                                   0,
                                   0,
                                   0.17355561471328448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15125181241947988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40062310540448326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12428906656108031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66269181221374396,
                                   0,
                                   0,
                                   -0.63726865216519479,
                                   0,
                                   0,
                                   0,
                                   0.49473322013879439,
                                   0,
                                   0,
                                   0,
                                   0.5064236975961206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39509263056392668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077644920363718686,
                                   0,
                                   0,
                                   0.31187808858899291,
                                   0,
                                   0,
                                   0,
                                   0.55306135891978037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19402789266080833,
                                   0,
                                   0,
                                   -0.64852904658453259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051891402462960055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31104744301861109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47506783732729108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21056408442431873,
                                   0,
                                   0.1394330978238677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77675462274841922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10214436719419839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27118148328826608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14572460873835724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017747952369986681,
                                   0.42728176255420358,
                                   0,
                                   -0.029334453156350648,
                                   0.29766514746893785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1545391905964123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01942673088256236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57263149483348097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2860084300307798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41032376858044234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17476324458036346,
                                   -0.1111538775441617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076384628979365446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24341971502631005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24301762487097081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060642039249198539,
                                   0,
                                   0,
                                   0,
                                   0.43708094920670304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78582456425463254,
                                   0,
                                   0,
                                   0,
                                   -0.17086885750596589,
                                   0,
                                   0,
                                   0,
                                   -0.11649842288616313,
                                   0,
                                   0,
                                   0,
                                   0.092162749693644963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18725626803960715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12167680144426078,
                                   0,
                                   0,
                                   -0.25056285378078069,
                                   0,
                                   0,
                                   0,
                                   0.22774813174736519,
                                   0,
                                   0,
                                   0,
                                   0.51354749997059568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018534820551852189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43013009150357345,
                                   0,
                                   0,
                                   -0.45821006528378039,
                                   0,
                                   0,
                                   0,
                                   0.54878091991335864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094217200608414792,
                                   0,
                                   0,
                                   0.72134830320339116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091523712154348749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14045761876859206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32097830810088052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25801080218111083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075600113916822309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1856299217442644,
                                   0,
                                   -0.48220725096974099,
                                   0,
                                   0.15214992504014621,
                                   0,
                                   0,
                                   0,
                                   -0.22599291045841544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2472118737486336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94708764282027824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13189775981427029,
                                   0,
                                   0,
                                   0.19208316952555465,
                                   0.22106728693593655,
                                   0,
                                   0,
                                   0,
                                   -0.40111519372763099,
                                   0.1728307212727361,
                                   0,
                                   0,
                                   0,
                                   -0.017544489239097363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45415870210167103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33180466341165615,
                                   0,
                                   0.4613876194003157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0077981153281538665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026288983654341042,
                                   0,
                                   0,
                                   -0.33276746322315093,
                                   0,
                                   -0.23688021277596272,
                                   0,
                                   -0.094516072120122002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55898884058418885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53390073917671599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30415561111562606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060698283842797109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31239963031543394,
                                   0,
                                   0,
                                   0,
                                   -0.070023651959805436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24783173362083719,
                                   0,
                                   0,
                                   0,
                                   0.039903905418677721,
                                   0,
                                   0,
                                   0,
                                   -0.17580443077111221,
                                   0,
                                   0,
                                   0,
                                   0.33146588177878428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17566129725110144,
                                   0,
                                   0,
                                   -0.11043177882698807,
                                   -0.020687566592408377,
                                   0,
                                   0,
                                   0,
                                   -0.25403527513746349,
                                   -0.17527602285024832,
                                   0,
                                   0,
                                   0,
                                   0.10894126284100754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048238723408440397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066622796668242279,
                                   0,
                                   0.35660871114259185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.003419894385741043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23057794527108313,
                                   0,
                                   0,
                                   0.50752804348441849,
                                   0,
                                   -0.15260868734773203,
                                   0,
                                   0.61758302784077168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19836238483184743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46724638271725383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33293082977220756,
                                   -0.36650783244737417,
                                   0,
                                   0.29639652952908169,
                                   0.46790397661646338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072631902747202451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34908819785051315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12391660787713185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19288614237850379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099568915392511809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027656783904068026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55379605241989638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66960436241891141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59073386639218772,
                                   0.011190706295708175,
                                   0,
                                   -0.36749146019567724,
                                   0,
                                   0.16929649851191778,
                                   0,
                                   -0.20088013941602656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63160812357218044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47367845460071567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.086937584371924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090890515823229767,
                                   -0.47630409335478252,
                                   0,
                                   -0.67797577366946937,
                                   0,
                                   0.22731204648238526,
                                   0,
                                   0.32313540944867075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077846011676580812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14651894483561292,
                                   0,
                                   -0.10402380364764083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36884142264842928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058081282105218561,
                                   0,
                                   0,
                                   -0.5274677030355589,
                                   0,
                                   0,
                                   0,
                                   0.42245104211340223,
                                   0,
                                   0.42096353237486228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33561212176183142,
                                   0,
                                   0.76480736233186886,
                                   0,
                                   0,
                                   0,
                                   0.43963379569843908,
                                   -0.0022359649436170109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47837286908657306,
                                   0,
                                   0,
                                   0,
                                   0.37578982692349583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058230611740145967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2186759828984971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027094211018375058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34197107648605873,
                                   0.21106394981066456,
                                   0,
                                   -0.16830725463654886,
                                   0,
                                   1.1456996536716848,
                                   0,
                                   -0.036018005018470578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0925613014894666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23615638676659165,
                                   0,
                                   -0.12606954772208834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71947914069332652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32576798961701947,
                                   0,
                                   0,
                                   0.033882221121609199,
                                   0,
                                   0,
                                   0,
                                   -0.18223587332170818,
                                   0,
                                   -0.69379638260371024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67275649050500941,
                                   0,
                                   -0.54447232831430392,
                                   0,
                                   0,
                                   0,
                                   -0.3010126328592368,
                                   0.12743386174970253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011786586494224632,
                                   0,
                                   0,
                                   0,
                                   0.16611917868319298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34174760802489401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50205050109488047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6634176358455609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6554527334166742,
                                   0.29701907139615247,
                                   0,
                                   0.48344475152821131,
                                   0,
                                   0.29668483828743214,
                                   0,
                                   -0.59540978358336194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73190895031531666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63048914579485427,
                                   0.075280791918986359,
                                   -0.43703672275835126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52134455969956539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068708633178562822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054914819903507148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13545572415163787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32852735884776063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7666044917112721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27786274010244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22932050940241394,
                                   -0.24798450495578389,
                                   0,
                                   0.92281052811133391,
                                   0,
                                   -0.0044350652600565477,
                                   0,
                                   -0.45456503650748226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.605301482640074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080260228447690984,
                                   0,
                                   1.0109162905161382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.587079077837519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38642358046111952,
                                   0,
                                   0,
                                   -0.16659745747966428,
                                   0,
                                   0,
                                   0,
                                   0.0067813856602527423,
                                   0,
                                   0.035736692706652445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1442247437616177,
                                   0,
                                   0.26998216578699785,
                                   0,
                                   0,
                                   0,
                                   -0.069883414526547505,
                                   -0.28082265483402696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29319330923678327,
                                   0,
                                   0,
                                   0,
                                   -0.081576274579285055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40939845229015154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1439626987177573,
                                   0,
                                   0.43796728997734524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14880052740236219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45657350320254825,
                                   0,
                                   0,
                                   0.61362766037539296,
                                   0,
                                   0,
                                   0,
                                   0.6984254010632035,
                                   0,
                                   0.29806187569485904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029985978094547158,
                                   0,
                                   0.28923532579923023,
                                   0,
                                   0,
                                   0,
                                   -0.86112585416342458,
                                   -0.066211606529805705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24506171570043442,
                                   0,
                                   0,
                                   0,
                                   -0.42372653982589681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73958900058498656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24051783253448727,
                                   0,
                                   0,
                                   -0.35415273842985673,
                                   -0.51917969921879148,
                                   0,
                                   0,
                                   0,
                                   -0.083023691290449786,
                                   -0.04367943367238096,
                                   0,
                                   0,
                                   0,
                                   -0.27402648693589327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17457633482868698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18878939674533135,
                                   0,
                                   0.34106921689917197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16489702150768376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34789279494065672,
                                   0,
                                   0,
                                   -0.34809455173116993,
                                   0,
                                   0.10215932241834456,
                                   0,
                                   -0.031855861834785539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65329218816548473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69427973687024136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73486536016702109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1831071485337033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65310692142207794,
                                   0.012593562669774599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58060189234099258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0496497811459393,
                                   0,
                                   0,
                                   -0.7595594831094501,
                                   0,
                                   0,
                                   0,
                                   -0.38404583123962233,
                                   0,
                                   0,
                                   0,
                                   -0.1055714820377236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33789274635860322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27531757027222209,
                                   0,
                                   0,
                                   -0.067875868316251864,
                                   0,
                                   0,
                                   0,
                                   0.34328955783876314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32614382892078297,
                                   0,
                                   0,
                                   -0.37903150765921545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12940421511700262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4025666865342804,
                                   -0.46401255924879536,
                                   -0.043517075891819967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41085264591946991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18205809876230672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38897438390168482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32187092580141663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40483534883467048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35452614444553954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4436177170797847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029834973513493974,
                                   -0.19398374212699954,
                                   0,
                                   0.31111608443777444,
                                   0.1105287065868595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38399991121712135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2457683365617625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45550563266138466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18501499082067166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20890419905921415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19175506120408775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38271932710500767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17402125941527735,
                                   0,
                                   0,
                                   -0.18562636897771448,
                                   0,
                                   0,
                                   0,
                                   -0.52992663980796473,
                                   0,
                                   0,
                                   0,
                                   -0.94250821974933074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86588927583511055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20122350158766872,
                                   0,
                                   0,
                                   -0.064613443503966028,
                                   0,
                                   0,
                                   0,
                                   0.094306490816589192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12975529270515734,
                                   0,
                                   0,
                                   -0.1723606245149597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33608228666270934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1097880964345168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29562120319356316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12234742851396734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12045114645807743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35602279119127322,
                                   0,
                                   -0.41822292629639757,
                                   0,
                                   -0.26641907356582417,
                                   0,
                                   0,
                                   0,
                                   0.40126297639239933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14463981544897117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11669864753536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16227778556964029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45992723591251639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018231827162220132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29353602346322127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50227794593006914,
                                   0,
                                   0,
                                   0,
                                   0.36457257988950909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21613734057605355,
                                   0,
                                   0,
                                   0,
                                   0.22169475503769087,
                                   0,
                                   0,
                                   0,
                                   0.40742436298663165,
                                   0,
                                   0,
                                   0,
                                   0.16906281214866742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31940143319730113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25425524523926574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049993321227994936,
                                   0,
                                   -0.77739885383533636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2351144312346504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41377516703293959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47764287582084075,
                                   0,
                                   0,
                                   0.10982186449733249,
                                   -0.26742018626597264,
                                   0,
                                   0,
                                   0,
                                   -0.1516460734080689,
                                   -0.25674223808412461,
                                   0,
                                   0,
                                   0,
                                   0.15418047035801549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16228667803946839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20654702549601128,
                                   0,
                                   -0.2762988343653594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2993185361649458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24379512363066408,
                                   0,
                                   0,
                                   -0.23555360786477583,
                                   0,
                                   -0.26094133501620115,
                                   0,
                                   0.39705785852806302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1150403624578889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11683426355139823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71230380709299201,
                                   1.1251656320923908,
                                   0,
                                   0.11227583939139996,
                                   0,
                                   0.3134337044085288,
                                   0,
                                   -0.10928142285578216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51607302620206297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30367362855489538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20786371595610631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050541685851418168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40133597691903716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49596187855535923,
                                   0,
                                   0,
                                   0,
                                   0.026787055559198275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12684953391374193,
                                   0,
                                   0,
                                   0,
                                   -0.0081527378430913677,
                                   0,
                                   0,
                                   0,
                                   0.35999385446953081,
                                   0,
                                   0,
                                   0,
                                   0.55542902027258712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42144906231145851,
                                   0,
                                   0,
                                   -0.081582784743398556,
                                   -0.29387638242009545,
                                   0,
                                   0,
                                   0,
                                   0.4199591079054813,
                                   -0.16439820690536583,
                                   0,
                                   0,
                                   0,
                                   -0.025039024553181181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13159838516548691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18550459670659658,
                                   0,
                                   0.39861294510632878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20292336310984474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47950061383399972,
                                   0,
                                   0,
                                   -0.17953950058288048,
                                   0,
                                   0.036575696783586215,
                                   0,
                                   0.10024429787980452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31036052615687271,
                                   0,
                                   0.045501311977420689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070422239257023705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15733715238447271,
                                   0,
                                   0,
                                   0.3953056596562225,
                                   0,
                                   0,
                                   0,
                                   0.49373273531968809,
                                   0,
                                   -0.82601950793567569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54365015789260995,
                                   0,
                                   0.25077824880694266,
                                   0,
                                   0,
                                   0,
                                   0.52537359949938522,
                                   -0.27553709148937988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56725027341009715,
                                   0,
                                   0,
                                   0,
                                   -0.0042677298854494339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028688428357283136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17208750285940644,
                                   0,
                                   0,
                                   0.040560835627303185,
                                   0.44140516338047059,
                                   0,
                                   0,
                                   0,
                                   0.051243846562780679,
                                   0.23945569908813061,
                                   0,
                                   0,
                                   0,
                                   -0.53553988662033269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28804649110133151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27860326074763647,
                                   0,
                                   0.2059150216256817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2302392753519939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25798554203618557,
                                   0,
                                   0,
                                   -0.076450037406960797,
                                   0,
                                   0.076396518051067147,
                                   0,
                                   0.30478681704751337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23837383046673899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21847089508773263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19056261591842596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16586825578708969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31873514772181499,
                                   0,
                                   0,
                                   0,
                                   0.51046279611608636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1698558937217291,
                                   0,
                                   0,
                                   0,
                                   0.22341211624834292,
                                   0,
                                   0,
                                   0,
                                   0.24314355267364524,
                                   0,
                                   0,
                                   0,
                                   -0.57582536410566587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25593326435033281,
                                   0,
                                   0,
                                   0.14509713642327157,
                                   -0.15686896401389033,
                                   0,
                                   0,
                                   0,
                                   0.29348978454491337,
                                   0.52821466344564261,
                                   0,
                                   0,
                                   0,
                                   0.44541761007280628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095505614776857858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11086390770134166,
                                   0,
                                   0.18421404743535788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39066421479595759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21452143092959816,
                                   0,
                                   0,
                                   0.062196987405065546,
                                   0,
                                   0.24473253483990032,
                                   0,
                                   0.086867059331411228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19015913461077116,
                                   0,
                                   0.72905764723426758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1602374803690314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040537880408311175,
                                   0,
                                   0,
                                   0.3095761842065432,
                                   0,
                                   0,
                                   0,
                                   -0.55441160361603736,
                                   0,
                                   0.33211563346123513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22689931957876247,
                                   0,
                                   -0.6681814646699632,
                                   0,
                                   0,
                                   0,
                                   0.30909120896668302,
                                   0.30913537835632776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10880333357560867,
                                   0,
                                   0,
                                   0,
                                   0.38946068405379419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71514188848929239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29057795703705847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37064039115194097,
                                   0,
                                   0,
                                   -0.38414384013350017,
                                   0,
                                   0,
                                   0,
                                   -0.4697996007221466,
                                   0,
                                   0,
                                   0,
                                   0.24965927331378246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3386503113501706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52125512324909384,
                                   0,
                                   0,
                                   -0.50359598815443685,
                                   0,
                                   0,
                                   0,
                                   -0.50614711638812171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53175877560176732,
                                   0,
                                   0,
                                   -0.17008819693043953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98804733290831703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37803811505521606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050973105506437535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78199519276963914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15865430453241325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17124267590065662,
                                   0,
                                   0,
                                   0,
                                   -0.1942404557944668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038679702612405956,
                                   0,
                                   0,
                                   0,
                                   0.32653462555403368,
                                   0,
                                   0,
                                   0,
                                   0.13597154004281109,
                                   0,
                                   0,
                                   0,
                                   0.15536604107935048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13825355454481841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18734691293373007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1000499302811295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1316081413483443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56683552763614542,
                                   -0.80221410347249589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2694235572612434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14921295257989625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098797334909387496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84601131951628683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78460031005226161,
                                   -1.0748300565086972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13513489572068246,
                                   0,
                                   0.036489060303373747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11909885736507414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27524583415439408,
                                   0,
                                   0,
                                   0.35413179853494897,
                                   0,
                                   0,
                                   0,
                                   0.080493544177547421,
                                   0,
                                   0.37322323219770082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52108975663941481,
                                   0,
                                   -0.21039357250154167,
                                   0,
                                   0,
                                   0,
                                   0.18788287780858731,
                                   -0.79238068407768614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15804894153905563,
                                   0,
                                   0,
                                   0,
                                   0.71412790475424348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20694217830588124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19924718722201346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040901950963039432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26215126292423757,
                                   0.2525155578021091,
                                   0,
                                   -0.0064892319621551661,
                                   -0.22867482621399421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23445336369420208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46843551269962058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099715124619145612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2164821326823454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13520912702048898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65139586562041618,
                                   0.13971772703204788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018760339342626928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15788582176286192,
                                   0,
                                   0,
                                   -0.16751944805912317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43300486087670431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22117985073945681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54017720861360485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36123237332399172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48353604054159893,
                                   0,
                                   0.1861054152019265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083345545519398212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2458610146851963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098138515181056846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59729440809620848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069225375419248739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1877021095923914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06516519067433936,
                                   0.41710284256562785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33538632979185745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36623944121125374,
                                   0,
                                   -0.21703493718667963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48667832564807068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44940833782957412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15700793102009031,
                                   0.22877256638025012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.002365754906350187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084874092556678951,
                                   0,
                                   0,
                                   0.049518366300421196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03510478738366167,
                                   -0.036791123912735813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066396340094698525,
                                   0.32518453758082161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30019037304654311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059928064648720941,
                                   0,
                                   0.38597459744850715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26810563606884913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12538504042063631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41163524708448024,
                                   0.3180610353191608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18249191828186698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42584581540960886,
                                   0,
                                   0,
                                   -0.10823459053429584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19664651919412882,
                                   0.15467236837699072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60332970453742774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17320663623943672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1970973233587113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51417892065341519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085526722862372451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19403486969777362,
                                   0,
                                   0,
                                   0.54414016395854992,
                                   0,
                                   0,
                                   -0.67096381292877127,
                                   0,
                                   0,
                                   -0.52957887838886963,
                                   -0.21018575406443502,
                                   0,
                                   0,
                                   0,
                                   -5.7994651427861754e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41739433658184572,
                                   0,
                                   0,
                                   0,
                                   0.095804641068655355,
                                   0,
                                   -0.3929187575401023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2421513505779932,
                                   0.16937868093805544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45331993858292619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27324534927541227,
                                   0,
                                   0,
                                   0,
                                   -0.48597563097393998,
                                   0,
                                   -0.52613986359225207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26411927217792142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22306308153144841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040412840073394386,
                                   0.61303381050839667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34421392815535262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.009463302322890832,
                                   0,
                                   0,
                                   0,
                                   -0.16434837494469698,
                                   0,
                                   -0.30488891849926558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61705632976953229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057073741987874002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042443965142912612,
                                   0.094612431861858345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015598351260874992,
                                   0,
                                   0,
                                   -1.1325522843439024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33279054598527297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29989752647426415,
                                   0,
                                   0,
                                   0.37500544472184894,
                                   0,
                                   0,
                                   0,
                                   -0.18762606534792509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084101278152290321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56579377070670112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0093321961077547921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42375471367682482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35061154685049062,
                                   -0.00036219451110176479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80389557365538344,
                                   0,
                                   0,
                                   -0.014479319062303446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43446758714932066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035064138361832392,
                                   0,
                                   0,
                                   0.43676192728197355,
                                   0,
                                   0,
                                   0,
                                   -0.071083203753771487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01005240686141623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058568422199736597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74582647732934348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42113461766242943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61309704673802012,
                                   0.085708837758878637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17448685428049471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24001354329577765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19710517211437403,
                                   0.30244835008031029,
                                   0,
                                   -0.3268799754119987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11842002665684535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20704597834021002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37419425809569029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26627338308115822,
                                   0,
                                   -0.15402491445745178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07920726997092295,
                                   -0.055909496671327628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082711136792229106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44434915425693733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27328036135213313,
                                   0.086633363826826348,
                                   0,
                                   -0.026327560254344406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48843968618609968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0091008150898998913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45531459135098468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44844358095011788,
                                   0,
                                   0.2374093999832107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43574050473459341,
                                   0.46990604216691584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25970140836943612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46579743658060119,
                                   0,
                                   0,
                                   0,
                                   -0.20140284455974342,
                                   0,
                                   0.35410524059812293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20770231502500427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3095360588882155,
                                   0,
                                   0,
                                   0,
                                   0.29285560423159956,
                                   -0.48709605617406582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13250194988253866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25689211501772102,
                                   0,
                                   -0.32235505128484004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1588170824978529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29268194967772321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081452260653214523,
                                   0.33130747393654603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10299723474965185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43162584501493023,
                                   0,
                                   0,
                                   0.19017316196215892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074934561296455607,
                                   -0.15341088517340934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67722609746941642,
                                   0,
                                   0,
                                   0,
                                   -0.39505182257208471,
                                   0,
                                   0,
                                   0,
                                   -0.45198015807430969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098923536050940855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41339785700153919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01814257252030263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070471038164225924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29896927211472274,
                                   0,
                                   0,
                                   -0.68159976538998335,
                                   0,
                                   0,
                                   0,
                                   0.030292421947923646,
                                   0,
                                   0,
                                   0,
                                   0.13967219231501626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64557274796791997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48172486928207481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33638003058335819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67262029998677642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21627606328952312,
                                   -0.22424401157186155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56044450946058766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092456926970433756,
                                   0,
                                   0,
                                   -0.19546919792987039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.307154705757897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038150477162691342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15208954661680524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67298513121794301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097322997611534595,
                                   0,
                                   -0.086882848329706275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18285012572351769,
                                   -0.11408737540144893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32276632665956245,
                                   0,
                                   0,
                                   0.36127907670621434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099283031888738951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79415767270180582,
                                   0,
                                   0,
                                   -0.14234669797608415,
                                   0,
                                   0,
                                   0,
                                   -0.19793784916869656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96911529226999038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19100730344043104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2706691515737662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083883655981494401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034404101250603614,
                                   0,
                                   0,
                                   0,
                                   -0.2457952077363354,
                                   0,
                                   0,
                                   0,
                                   0.61007745939918379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12737896503499188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3782542614992882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63789096256983369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14674785400863297,
                                   -0.14736245544363707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21168818912697429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24668691623600542,
                                   0,
                                   -0.069208385735907971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40987185582523628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17589534830048953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18292699370479801,
                                   0.063043538237673794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20383672409428572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.157492580343052,
                                   0,
                                   0,
                                   0.37851430131851033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05221519971463838,
                                   0.63053115587429065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012951414296717137,
                                   0.44676845522330072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81413008659755104,
                                   0,
                                   0,
                                   -0.090613842720746116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74970863403681109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15690669668176158,
                                   0,
                                   0,
                                   0.2726426976152343,
                                   0,
                                   0,
                                   0,
                                   0.010116196162212751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067606596346998754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3851444372259884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21250797364917864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51212438817325845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6084358860335557,
                                   0.033765919980901483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20369306571659987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48974197675323733,
                                   0,
                                   -0.32317874448982353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077697580708170622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13499821149159591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19818410093637928,
                                   0.12852353901192162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26603178859856685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034226672358778694,
                                   0,
                                   0,
                                   -0.20134995428433033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029180186881759818,
                                   0.2224606288510064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53460889774094511,
                                   0,
                                   0,
                                   0,
                                   -0.53756700976132432,
                                   0,
                                   0,
                                   0,
                                   -0.3167736603126915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4798118597645481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11165245464286139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.286677158500794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00086451295382793114,
                                   -0.22108667300072646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059162617711748515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49453302900140661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039371611996271927,
                                   0.65594656207601232,
                                   0,
                                   0.13151142230151075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13992367168571065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37142476914546535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2343235856253828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15634754433186288,
                                   0,
                                   -0.13060797361955082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17259903246625058,
                                   0,
                                   -0.57535497279788461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44200112026517602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24251186739916814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38396208479648064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49409272955741435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35740851268988177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89538107760361396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60537663483903681,
                                   0.056955878829995733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38416863557854136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18759232860982608,
                                   0,
                                   0,
                                   0,
                                   -0.226988241040744,
                                   0,
                                   0.45364445290874567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33202680962175879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28273659474651119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62062212645233383,
                                   0,
                                   0.65545068153611408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44588675290043317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2764963759025969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96519419309079446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47911286295638772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46095482944295441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088840360169813615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03622043311226316,
                                   0.64618172790102335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12599704375093373,
                                   0,
                                   0,
                                   -0.29973448666263569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58958030786871007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060318719828694481,
                                   0,
                                   0,
                                   0.43681897393951857,
                                   0,
                                   0,
                                   0,
                                   -0.36635531559132412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0082587182273488047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55284688744331378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15287128429671304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11072094249795157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27548330919660546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1170965920309266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24184510509908538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05336567630304459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4342411885186046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25452890546240947,
                                   0,
                                   0,
                                   0.13538158909837783,
                                   0,
                                   0,
                                   0.23015136388577107,
                                   0,
                                   0,
                                   -0.41967192646972679,
                                   -0.044606991848544691,
                                   0,
                                   0,
                                   0,
                                   0.57063521980058907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019054656002973645,
                                   0,
                                   0,
                                   0,
                                   -0.069913103491796705,
                                   0,
                                   0.16585339746124597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53064314877502194,
                                   -0.23464249482296715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094616834908545069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12940885641640848,
                                   0,
                                   0,
                                   0,
                                   -0.52438154920905045,
                                   0,
                                   0.024638363565450745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070358846177616799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59760214638900122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30106429461295098,
                                   0,
                                   0,
                                   0,
                                   -0.082712957880618054,
                                   0,
                                   0,
                                   0,
                                   0.51534211273485231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72133538642965644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16837791719506051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29709510469756079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14522863762398419,
                                   -0.439898071650482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4344549245494046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38652088119605599,
                                   0,
                                   0,
                                   0,
                                   -0.54577146666260812,
                                   0,
                                   -0.023643805751767267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076195413525804376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37817666756475493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3675736224557965,
                                   0.041788356755406167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11743966672784605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52494251332085462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15875784401380846,
                                   0.36479508095808927,
                                   0,
                                   -0.057520472991983512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47651886630242379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11245978501892069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039893315473596237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010723277853688554,
                                   0,
                                   -0.4132488841669606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7279379038797501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28655708710215755,
                                   0,
                                   0,
                                   0.64254461956969711,
                                   0,
                                   0,
                                   0,
                                   0.065885048424078801,
                                   0,
                                   0,
                                   0,
                                   -0.12311121302385636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043502945664341819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76458591945428767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13258158746673818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3170418151175507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60568096583574271,
                                   0.027410926970791217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63840216836586572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035436393617131169,
                                   0,
                                   0,
                                   -0.6264051630350197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14132759525198957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0029646530619186241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038133534748412731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37168348893824443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15023573291877754,
                                   0,
                                   -0.12608056957362274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22218465037706223,
                                   -0.069846182024340273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32619493984445957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26521257826425221,
                                   0,
                                   -0.21380627608809086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087837044417399548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31055206304293026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1947322659744426,
                                   -0.10338039349809934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31782641507196702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36112772673813281,
                                   0,
                                   0,
                                   -0.28185027584776823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50948746705542336,
                                   -0.0095657841787474204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4979201051975542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50454062646740594,
                                   0,
                                   0,
                                   -0.16349486198041874,
                                   0,
                                   0,
                                   0,
                                   -0.83773822066505732,
                                   0,
                                   0,
                                   0,
                                   0.01772790184815716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30757892819869853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38814423376969343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32802366160859642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44564123397751837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41815402498903625,
                                   -0.52842844561252911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090786177894194839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33635483190803794,
                                   0,
                                   0,
                                   -0.32440122336885091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054438780080828225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60525972669587746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022486426408810295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19306751077281548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27983425556684349,
                                   0,
                                   0.093593214956180448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.059142423128707,
                                   0,
                                   -0.49844551121687641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10942371025067416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16686576073106471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71041152099890126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16588692860731913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38712321008435496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60793551374286392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057140300629918733,
                                   -0.45775595111985462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13559465019444744,
                                   0,
                                   0,
                                   -0.38594822740108214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5254941094841078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16483181472609129,
                                   0,
                                   0,
                                   0.41045222278835974,
                                   0,
                                   0,
                                   0,
                                   -0.24261075050818337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19153868849229957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66471235603113077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10222642505917244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63469259079833484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81578527357688913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10906465712113587,
                                   0,
                                   0,
                                   1.1926680133161283,
                                   0,
                                   0,
                                   0,
                                   -0.2767985593340978,
                                   0,
                                   0,
                                   0,
                                   -0.221931680527828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70122222606317119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36850623153588513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25473856506303133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20820980058280647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050401310472413169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98908052088717413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059957575152503426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57200196400113368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57833149118158089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25227847664993402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34067944997541344,
                                   0,
                                   0,
                                   -0.22999122536418373,
                                   0,
                                   0,
                                   0.031348456368358243,
                                   0,
                                   0,
                                   -0.93176947124600229,
                                   0.15445302788381246,
                                   0,
                                   0,
                                   0,
                                   -0.32842743781698602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00011052065586777265,
                                   0,
                                   0,
                                   0,
                                   0.25218237675650251,
                                   0,
                                   0.26808564690661657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77404179321188227,
                                   -0.49940240832631411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59048270996370078,
                                   0,
                                   0,
                                   -0.35573862217487684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20010779588008751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28795236986372535,
                                   0,
                                   0,
                                   -0.085352348013511312,
                                   0,
                                   0,
                                   0,
                                   -0.15389563946803839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24730915386345548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24615112540549192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15477864647519954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46077877890948915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020122890017577607,
                                   0,
                                   0.35362189147099499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87566480293829063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24904847048296958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75983557370411003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62265583007541936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12142175597077649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1245038307218518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039038119965895408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25430046763450059,
                                   0,
                                   0,
                                   0.28860404724086142,
                                   0,
                                   0,
                                   0,
                                   0.070337096787495418,
                                   0,
                                   0,
                                   0,
                                   0.19970317120437117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53878189472448068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46114291817006114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87152525790302571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1018608412756485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67321738473982928,
                                   0,
                                   -0.12244147899893121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4740119690581811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61513637898566953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0078255107303904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37159750135363512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054423060521495592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61930224873055517,
                                   -0.55436593001250312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27502645892867728,
                                   0,
                                   0,
                                   -0.46658625263481801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27011289823685597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18191082572793668,
                                   0,
                                   0,
                                   0.1946276762260408,
                                   0,
                                   0,
                                   0,
                                   -0.50154406238890803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12750074524790858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28378475491430272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52053257806473086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19456226898384882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30119149889242092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29225358763095999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74219024180740034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39185515901650092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22674480011520159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77073218034551694,
                                   0,
                                   0,
                                   0.39516827555487338,
                                   0,
                                   0,
                                   0.36529223116261589,
                                   0,
                                   0,
                                   -0.085701823177040962,
                                   -0.34660936952649679,
                                   0,
                                   0,
                                   0,
                                   -0.3795996780555152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18359996268732987,
                                   0,
                                   0,
                                   0,
                                   -0.57134539138737428,
                                   0,
                                   0.34022549097146848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25433821146749519,
                                   0.17461808840737009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02013272860982546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40252393367726458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16935737691531588,
                                   -0.18065218539861891,
                                   0,
                                   -0.50015578780449299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049071158650301185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10139704843508608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26519366132495381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25268457077419088,
                                   0,
                                   -0.53296369276715538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43309829096197106,
                                   0.26042334601630041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54507730004514543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084626340452901516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.002343516183694383,
                                   -0.17193821272687615,
                                   0,
                                   -0.20739862231688183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39744043745801205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23367860910831681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28894731948070013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24496425047631495,
                                   0,
                                   0.10811849962732695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092905947297283145,
                                   0,
                                   0.10851896877366357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67580187067006259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0743588261681736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012803343263739629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86807654818345092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23439136429022658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19405897989165741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031174438430694104,
                                   -0.029000463839540094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47451841766993841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037675101266436389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23549766759003438,
                                   0.25437055416606325,
                                   0,
                                   -0.43113033270294737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34310058576227986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30927033652245994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29223404514612067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16978369525061862,
                                   0,
                                   0.37144272527536959,
                                   0,
                                   0,
                                   0,
                                   -0.17014490334951232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31930856353790033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33319650016703245,
                                   0,
                                   0,
                                   0.5051574659410667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12420581472427555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30172777991734234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46380782191618236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32952642664178977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24174786212854027,
                                   0,
                                   0.11947657528215508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47908626978854024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21272478432735459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9220167372220186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18983848846793294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25975361667441088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27805756074974841,
                                   0,
                                   0,
                                   0.024483249781167921,
                                   0,
                                   0,
                                   -0.50896626183712868,
                                   0,
                                   0,
                                   -0.75852334657979281,
                                   -0.33010646610064998,
                                   0,
                                   0,
                                   0,
                                   0.8068280570928118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27699209382201323,
                                   0,
                                   0,
                                   0,
                                   -0.28322598953526201,
                                   0,
                                   -0.16170144489567204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033609300918949377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56317798331251079,
                                   0,
                                   0,
                                   -0.2455070486814836,
                                   0,
                                   0,
                                   0,
                                   0.66620075840247284,
                                   0,
                                   0,
                                   0,
                                   -0.98522329967214939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42931770857934065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029054465398811138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20099508575774652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31588774766729411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18286493157390957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15478396235362712,
                                   0.080475641139942669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40559099282615496,
                                   0,
                                   0,
                                   -0.46965480959236011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066439823442782167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46143491884072135,
                                   0,
                                   0,
                                   -0.71622390069945463,
                                   0,
                                   0,
                                   0,
                                   0.18313443116942052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40846900704889738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25740724699709244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026901260804788441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14783391076536467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60590716365766806,
                                   0,
                                   0.11727028505249149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75999713058376628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31298813143946508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73983010370573665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30409099111532306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16047464036912201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11365706665887093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45383863684278991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18987576104649859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57102564983160398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2174927104736723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88246912606607297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075380260541287103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22870746967028904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10410884265653747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26752332761282466,
                                   0,
                                   0,
                                   0.20294477654382831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56943152814615505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026369036980588255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060402170053917334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092405155512393866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69170688537758962,
                                   0,
                                   0.092226826383991684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2414656111545477,
                                   -0.32122006865320152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27690736584486314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2842979297327165,
                                   0,
                                   0.14059871687457379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24991358887806314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4208679057200766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071901375991550318,
                                   0.27232402444389781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081064443394825353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10833666395582114,
                                   0,
                                   0,
                                   -0.14987256925209042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54467829916179689,
                                   0.069855088333293888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23870004600846773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11307048980116391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15449482046559476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56394094370042946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68020651689460609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26135917265952935,
                                   0,
                                   0,
                                   0.063598903797720208,
                                   0,
                                   0,
                                   0.053728991833454934,
                                   0,
                                   0,
                                   -0.55009889670582435,
                                   0.090828821120233577,
                                   0,
                                   0,
                                   0,
                                   -0.54778332240995764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55228663452067894,
                                   0,
                                   0,
                                   0,
                                   0.35427161982032912,
                                   0,
                                   0.038250093922151715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39963549774668872,
                                   0,
                                   0,
                                   0,
                                   -0.14235888293901372,
                                   0,
                                   0,
                                   0,
                                   0.13055706578690313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016783525596676632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69045410970585641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5709393186855044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80915684794115905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71771971121064548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3614548240893945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13657923505505329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36872303271588502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66188915080823918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12793029117223365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37736549435118943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33483063004577857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41864690660535675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35027356463996284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37597508367680521,
                                   0,
                                   0,
                                   0.83983641973508816,
                                   0,
                                   0,
                                   -0.30988912841902821,
                                   0,
                                   0,
                                   0.33503582248274522,
                                   0.092401761633061491,
                                   0,
                                   0,
                                   0,
                                   0.17336730359990615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31094269919125006,
                                   0,
                                   0,
                                   0,
                                   -0.70874327820346039,
                                   0,
                                   0.72735143318028139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045021896829894298,
                                   0.39734518490365239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31362595753546313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12215486130227732,
                                   0,
                                   -0.22144969151064514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30139328579163205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011252695278348018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42583107098411344,
                                   -0.13199819506321778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29760723859603233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44699710277304933,
                                   0,
                                   0,
                                   -0.083051817769724062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29657690000379022,
                                   -0.069388145962035339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2245608372528842,
                                   0.17966102132663886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030499478386048828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029814937061993781,
                                   0,
                                   -0.35064333499827788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35227549379572426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33359164905732364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12028725659781415,
                                   0.44078235515758935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11825392656200578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41356113964689778,
                                   0,
                                   0,
                                   0.066870845326113024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15652994626786765,
                                   -0.36659894814507671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05686815465197341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13503424365573072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31515245490884558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63698456893807287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37482031677855887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23407306878903592,
                                   0,
                                   0,
                                   -0.0079674010062227504,
                                   0,
                                   0,
                                   0.21735228868246745,
                                   0,
                                   0,
                                   -0.13094088748150617,
                                   -0.55990036511158903,
                                   0,
                                   0,
                                   0,
                                   -0.44074956592965442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042855657244750704,
                                   0,
                                   0,
                                   0,
                                   -0.24058863849302506,
                                   0,
                                   -0.5795400330238506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020932687755182484,
                                   -0.10422837873565832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10003931915827471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13956152657092555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55383740686006622,
                                   0.042519213585113493,
                                   0,
                                   -0.20969057347451842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13922337940930649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22810669137432041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35223087177841622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57239576387089697,
                                   0,
                                   0.28910167701442219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1321125631086402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65562563908383986,
                                   0,
                                   0,
                                   -0.14688608752888843,
                                   0,
                                   0,
                                   0,
                                   0.14531366604595997,
                                   0,
                                   0,
                                   0,
                                   0.53213038590000605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85156930763140704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62911047093165473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22022887171804467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40352493686410595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48920088109016668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18461381466951035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43849593470973763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20212119860087502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10474469176875183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71858803134975291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18387689619864375,
                                   0,
                                   0,
                                   0.022784342390170159,
                                   0,
                                   0,
                                   -0.89190421057388725,
                                   0,
                                   0,
                                   0.11237904480702569,
                                   -0.59354962963124314,
                                   0,
                                   0,
                                   0,
                                   -0.4423419615998499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73008529484492179,
                                   0,
                                   0,
                                   0,
                                   0.17838385329408576,
                                   0,
                                   0.23645429289104286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2876810599751054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26233207932501434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33232657480647154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29248471303842838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13439190397967854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33036318884555016,
                                   0,
                                   0,
                                   -1.055173490637098,
                                   0,
                                   0,
                                   -0.23634414994585615,
                                   0,
                                   0,
                                   -0.20921883260283702,
                                   -0.35946570407216327,
                                   0,
                                   0,
                                   0,
                                   -0.0095041192460770668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21611628346724432,
                                   0,
                                   0,
                                   0,
                                   0.0087538498206344156,
                                   0,
                                   0.57805017410837423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14140599067653917,
                                   -0.064626828933473934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20783323995098654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044846119114666697,
                                   0,
                                   -0.45971445224817381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080755757287256175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16180545142456709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50535610796620078,
                                   -0.30439931169968837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37341576912684071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028788893200328666,
                                   0,
                                   0,
                                   -0.016680734742138471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28360275078068009,
                                   0.34287224109695347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12055460578549361,
                                   0.86908560576429306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26954076193166532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083121653799155343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0097000775448064288,
                                   0.12838831727626995,
                                   0,
                                   0.28776229181653901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0056507438247700072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17215931421557729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064690975521120575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06444755576118949,
                                   0,
                                   0.11489737577890578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24755259757231995,
                                   -0.146434383214957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39757220010409211,
                                   0,
                                   0,
                                   -0.33330838200520346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12503178852559674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72153062294704851,
                                   0,
                                   0,
                                   -0.40771150962326791,
                                   0,
                                   0,
                                   0,
                                   0.63703584419602932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5411022759652877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44298128032400275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021114914070153076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26617096268749818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026571173776572931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53099207797866799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37016406556525483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015442346513419254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44698628076642066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42819497714696136,
                                   0,
                                   0,
                                   0.32763175386964721,
                                   0,
                                   0,
                                   0.7122113100059565,
                                   0,
                                   0,
                                   0.0034265250579744583,
                                   -0.15450430440434565,
                                   0,
                                   0,
                                   0,
                                   0.34292631486191166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80315617606382927,
                                   0,
                                   0,
                                   0,
                                   0.41432518134103857,
                                   0,
                                   0.25759336666380533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16194428161950142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35878558457016452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47477799731477927,
                                   0,
                                   0,
                                   -0.29267503330315681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55684247553426136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045270493103769786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2582676167723339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21401652091934459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14546191182221815,
                                   0,
                                   -0.29696257526248299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035452688872284158,
                                   -0.36570536262871134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36243748135366571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081338789873307865,
                                   0,
                                   0.16245932716437161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3728033691188084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41592288939757538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33509757726986383,
                                   -0.19419271726384585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13599588827691772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12390440223601121,
                                   0,
                                   0,
                                   -0.20647566352496141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19818595887458165,
                                   -0.35057136058036958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12874267019536573,
                                   0,
                                   0.31880757616902461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45900148660665019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32863302358959046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59075524493586951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35529489401186132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96720653329654105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2583612638555367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027204811147815339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46361975572956554,
                                   0,
                                   0,
                                   -0.16361070113083159,
                                   0,
                                   0,
                                   0,
                                   0.82229683277135324,
                                   0,
                                   0,
                                   0,
                                   0.16826059634230317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06526191255057634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15000091008135727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20705994298279742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0068135195085612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28833021936670822,
                                   0,
                                   0,
                                   -0.52676689831617585,
                                   -0.0087514676581243317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24949023672061843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44092162245571054,
                                   0,
                                   -0.23185190798537961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16652539421402801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032373394060767599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033071513993143925,
                                   -0.18906473691684028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13667455645930743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21634602928530242,
                                   0,
                                   0,
                                   0.41864366086553195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011654281491449224,
                                   -0.32484714077949284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58354870065733344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66944139234442201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49836684929568598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25823492345413629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26096818067561223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76188808256914808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68012751777337466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16541752229035811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.215718795467647,
                                   0,
                                   0,
                                   -0.074918866734640599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15619429980387298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36673639786917028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044212322125186845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2726062237860355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098142012327574052,
                                   0,
                                   0.46165266760235035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4230223821291168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25581206463164879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3060936148977968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068299594392265114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77211903479521737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35930796202390491,
                                   0,
                                   0,
                                   -0.12038054946853238,
                                   0,
                                   0,
                                   0.50863193787850602,
                                   0,
                                   0,
                                   -0.41563741009874877,
                                   0.64883789858765628,
                                   0,
                                   0,
                                   0,
                                   -0.20054844181051876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090019068883387204,
                                   0,
                                   0,
                                   0,
                                   -0.46114973292671496,
                                   0,
                                   0.3656087608280662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48917069264186852,
                                   -0.093142390333384242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56169920968900533,
                                   0,
                                   0,
                                   -0.24610835168732997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49259888939487334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25337528449224539,
                                   0,
                                   0,
                                   0.29202482346937109,
                                   0,
                                   0,
                                   0,
                                   -0.0045253127145538224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3011015190167004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28545274358248723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88977409535437024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62415468049084355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14330117127488862,
                                   0.2707654627704123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43216118570178469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5521394826375956,
                                   0,
                                   0,
                                   0,
                                   -0.26811901184280118,
                                   0,
                                   0.49000677752830357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31822740796796145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035586655507884479,
                                   0,
                                   0,
                                   0.50743288572760437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30921190405349308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90198010358603753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35695547708724057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18957706577537251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0223905700513831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24402056954923748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073554323726468362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37949613401503413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72863148362354346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16765053506978939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54998979271857762,
                                   0,
                                   0,
                                   0.23454712658647572,
                                   0,
                                   0,
                                   -0.30122093216453366,
                                   0,
                                   0,
                                   0.0482120886099104,
                                   0.52550494899521705,
                                   0,
                                   0,
                                   0,
                                   0.55474332716859776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086128349240079394,
                                   0,
                                   0,
                                   0,
                                   0.65405231288277388,
                                   0,
                                   -0.41830010612117791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34410805126068073,
                                   0.066472526715570079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14018975015586785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044033676080071971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13088636396132541,
                                   0.28803950874097206,
                                   0,
                                   0.32008656866097063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077283573162521768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69801366935702536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1833028426173467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30518897558346492,
                                   0,
                                   -0.18190501655675836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17293562341543023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22174581250918024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43867669630061323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27026080189515667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40808705773135312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58248661528807766,
                                   0,
                                   0,
                                   0.23727349866704298,
                                   0,
                                   0,
                                   0.38612909318733524,
                                   0,
                                   0,
                                   0.077447910174950479,
                                   -0.14298451287625055,
                                   0,
                                   0,
                                   0,
                                   -0.084236652552489313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43507086779888721,
                                   0,
                                   0,
                                   0,
                                   0.88212948804485369,
                                   0,
                                   0.47014739167162189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062237757513549735,
                                   -0.09729008876009293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40476073278896724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34254127413405694,
                                   0,
                                   -0.24343267632884702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.118353519468497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23946615159243934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33164144373941606,
                                   0.13252229505644139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043824993677584703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11952049832656124,
                                   0,
                                   0,
                                   -0.64985196919141153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025939876998880229,
                                   0.09027634838351653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22608805125930675,
                                   -0.12033597818379882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10265343907026053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090745587609101647,
                                   0,
                                   0.05055039732646012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14020936465360284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070263826873177601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094258668081867739,
                                   0.48580344441165418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67460094391981451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09441574444713427,
                                   0,
                                   0,
                                   0.11000577395551678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40209003609536392,
                                   0.076235322239907283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78144266671643592,
                                   0,
                                   -0.22732111895364265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63285700310973769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015212317966826389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24774709761468783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5452717171969178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49036533362631141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70566152705106078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063452790558471875,
                                   0,
                                   0,
                                   0,
                                   0.68369071838045992,
                                   0,
                                   0,
                                   0,
                                   -0.20137337904338767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47240119185285889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41046516812968903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31039485638725561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050579824577760613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5322310666649277,
                                   0,
                                   0,
                                   -0.37706570785786409,
                                   0,
                                   0,
                                   0,
                                   -0.44878064096825115,
                                   0,
                                   0,
                                   0,
                                   -0.59558568218385755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042721993888570307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22706865391719694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52384246297997961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20733522448847058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59391641176049448,
                                   -0.0069501797174083297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014373634837030982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47307258858052054,
                                   0,
                                   0,
                                   -0.10121212389452938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10694665998839201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52936302238855104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59872368929457676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031155337335146915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2956891687220774,
                                   0,
                                   0.16482697689518927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30386974686529716,
                                   0.049773130867944874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52109099300181894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16025189709982765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47973131180660261,
                                   0.25894507129240879,
                                   0,
                                   -0.072239129078102302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19022683941562576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08634599250214639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.302749573364261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064420650311468486,
                                   0,
                                   0.40756219208066585,
                                   0,
                                   0,
                                   0,
                                   -0.28302209874593698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025637456776768708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41689137067329862,
                                   0,
                                   0,
                                   -0.19550803493718283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098176207098872009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27344231012408848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19293647145609377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054444906268858104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026825260525309744,
                                   0,
                                   0.76282489256675046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06143646233028225,
                                   0.25822550276057965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22110974566417452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014385998804094829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47059889204424216,
                                   0.20607091115469878,
                                   0,
                                   -0.39794213328597516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40136708026642509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26374263145415738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32162174443795061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34881669745544908,
                                   0,
                                   0.048916781195614045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31628158100859738,
                                   0.4421324477589646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015453721404407497,
                                   0,
                                   0,
                                   0.35807730962902951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095541183478868891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040897758319641458,
                                   0,
                                   0,
                                   -0.79513025905674295,
                                   0,
                                   0,
                                   0,
                                   -1.1674706342363659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39821855846928245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064394973828055757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12329030593288476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20841752290126947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24529601317248806,
                                   -0.22262838851128777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27662379784677815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44954003083518235,
                                   0,
                                   0,
                                   0,
                                   -0.00047212232895274542,
                                   0,
                                   0.24033946764579026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53298747688983106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51944255559487251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0147622032280181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074594222633171586,
                                   0,
                                   0,
                                   0.0010133998351283986,
                                   0,
                                   0,
                                   0,
                                   0.53508055246206465,
                                   0,
                                   0,
                                   0,
                                   0.60790330348768074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95148882724782236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45219337995370901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4876098949888894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34890235035663802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030647300637706119};

const double rot_28_30[9000] = {-0.41033822803742143,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19549179843340814,
                                0.028078905367745609,
                                0,
                                0,
                                0,
                                -0.43741706304484951,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37968109439050057,
                                0,
                                0,
                                0,
                                0,
                                0.67611067877188546,
                                0,
                                0,
                                0,
                                -0.25347016118288312,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.020368951216896913,
                                0,
                                -0.34945845154481481,
                                0,
                                -0.29126591360128451,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.029076987091887899,
                                0,
                                0.77342222748254885,
                                0.7018223513497559,
                                0,
                                0.37545686675645618,
                                0,
                                0,
                                0,
                                0.21733479755782775,
                                0,
                                0,
                                0,
                                0.4914956020265091,
                                0,
                                0,
                                0,
                                0,
                                0.28747531901483403,
                                0,
                                0,
                                -0.096712589521687042,
                                0,
                                0,
                                0,
                                -0.71216741023052565,
                                -0.33266858948312766,
                                0.0057335900251077321,
                                0,
                                0,
                                0,
                                -0.036312398250564634,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31086697857858103,
                                0,
                                -1.1885985797217011,
                                0,
                                0,
                                0,
                                0.57287497968240875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45980664997851495,
                                0,
                                0,
                                0,
                                0,
                                0.31928607653182162,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10479314347235602,
                                0,
                                0,
                                0,
                                0,
                                0.33897437152585636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.092566665548252242,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56701669515464803,
                                0,
                                -0.15726274264088103,
                                0,
                                0,
                                0,
                                0.028760199725843233,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66698427613810463,
                                0,
                                0,
                                0,
                                0,
                                -0.56679173164317775,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0995490531238035,
                                0,
                                0,
                                -0.28629790796606019,
                                0,
                                0,
                                0,
                                -0.26339248676251359,
                                0,
                                0,
                                0,
                                0,
                                0.51365499297745487,
                                0,
                                0,
                                0.62711957623207626,
                                0,
                                0,
                                0,
                                -0.1770990149249364,
                                0.073058219492157933,
                                -0.36900598307303834,
                                0,
                                0,
                                0,
                                -0.13664007845688056,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.004462494239666992,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.8286535171478826,
                                -0.12341115019390148,
                                0,
                                0,
                                0,
                                -0.26454381786216469,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45412217222170254,
                                0,
                                0,
                                0,
                                0,
                                -0.14789436702922829,
                                0,
                                0,
                                0.095472543140882021,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23971200259983497,
                                -0.013296236330918025,
                                0,
                                0,
                                0,
                                -0.80159180971536226,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19748553382379141,
                                0,
                                0,
                                0,
                                0,
                                -0.5016935259127866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33874687542021181,
                                0,
                                0.048786389546038575,
                                0,
                                0,
                                0,
                                1.3416035514973577,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15431355471525549,
                                0,
                                0,
                                0,
                                0,
                                0.24867019444625602,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48057302027185267,
                                0,
                                0,
                                0,
                                0,
                                -0.14454350375297795,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21410537040349684,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35580669485648708,
                                0,
                                0,
                                0,
                                -0.1731420539430007,
                                0,
                                0,
                                0,
                                0,
                                -0.23368122174800665,
                                0,
                                0,
                                0.46916965604965033,
                                0,
                                0,
                                0,
                                0.14078750433004383,
                                -0.62453380738106334,
                                0.2448221936167459,
                                0,
                                0,
                                0,
                                -0.31447550154444182,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18826679268755578,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4402196292510559,
                                -0.51089735831823924,
                                0,
                                0,
                                0,
                                -0.20117242469297658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63377872463822482,
                                0,
                                0,
                                0,
                                0,
                                0.26000070345239962,
                                0,
                                0,
                                0,
                                0.47521249928502374,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31787059754808999,
                                0,
                                -0.67301610580231686,
                                0,
                                0.8196884979331428,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34464941784762526,
                                0,
                                -0.27986834850198433,
                                0.11303784104719788,
                                0,
                                0.87699027073009095,
                                0,
                                0,
                                0,
                                0.51557036199577089,
                                0,
                                0,
                                0,
                                -0.31604158599103643,
                                0,
                                0,
                                0,
                                0,
                                0.25035607921419323,
                                0,
                                0,
                                -0.17366488010862541,
                                0,
                                0,
                                0,
                                -0.12791540546513064,
                                0.46958784393716296,
                                0.2206181090803051,
                                0,
                                0,
                                0,
                                -0.50588518123200699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14511258474610084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12597117604622265,
                                0,
                                -0.0029519857089997659,
                                0,
                                0.2477515256439913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0558081321408508,
                                0,
                                0.28954107368259657,
                                -0.18727513117815178,
                                0,
                                -0.282021783821368,
                                0,
                                0,
                                0,
                                0,
                                0.23498318539766844,
                                0,
                                -0.059914689123543655,
                                0,
                                0,
                                0,
                                0.49683747975918541,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83973866889441884,
                                0,
                                0,
                                0,
                                0,
                                0.91439042293522588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87064056644411192,
                                0,
                                -0.21367984726359049,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73106011707260832,
                                0,
                                -0.35033853193746778,
                                0,
                                0.25448608488164648,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41293366930593534,
                                0,
                                0.42733570695268885,
                                -0.32559630528751282,
                                0,
                                -0.61685291480491844,
                                0,
                                0,
                                0,
                                0.10901064660976989,
                                0,
                                0,
                                0,
                                0.66539133462878919,
                                0,
                                0,
                                0,
                                0,
                                -0.058891697507418135,
                                0,
                                0,
                                0.15241698380055962,
                                0,
                                0,
                                0,
                                0.37916596817646037,
                                0.19141181147112976,
                                -0.35634351306177914,
                                0,
                                0,
                                0,
                                -0.45965842692744091,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36531269864514682,
                                0,
                                0,
                                0,
                                0.15140281284564483,
                                0,
                                0,
                                0,
                                0,
                                -0.31300024937127291,
                                0,
                                0,
                                0.53298590975640636,
                                0,
                                0,
                                0,
                                -0.21389563765055716,
                                0.44709036358161525,
                                0.10189260334012523,
                                0,
                                0,
                                0,
                                0.45338443371687615,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37291053581967132,
                                0,
                                0,
                                0,
                                -0.29992716501652283,
                                0,
                                0,
                                0,
                                0,
                                -0.27846463090899432,
                                0,
                                0,
                                -0.19658790286762218,
                                0,
                                0,
                                0,
                                -0.13167237648704724,
                                -0.12270989206316506,
                                -0.78544737678513243,
                                0,
                                0,
                                0,
                                0.073953767315281027,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.95827538814159974,
                                0,
                                -0.34077687591185224,
                                0,
                                0,
                                0,
                                -0.41884844197984977,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57601395547510381,
                                0,
                                0,
                                0,
                                0,
                                0.4221552396534155,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40081886873952777,
                                -0.77469108598316394,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.058457302357170032,
                                -0.33024330523951095,
                                0,
                                0,
                                0,
                                0.22309810625689555,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20314349391424932,
                                0,
                                0,
                                0,
                                0,
                                -0.44309793534694997,
                                0,
                                0,
                                0,
                                -1.1387182479956008,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46856190483077143,
                                0,
                                -0.080706345785965125,
                                0,
                                -0.50303949206346976,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24775527117608601,
                                0,
                                0.017544306813617475,
                                -0.16062513882222212,
                                0,
                                0.38687926836702285,
                                0,
                                0,
                                0,
                                0.44044174961124383,
                                0,
                                0,
                                0,
                                0.059760119936508274,
                                0,
                                0,
                                0,
                                0,
                                0.59770517024736958,
                                0,
                                0,
                                -0.033709566743083966,
                                0,
                                0,
                                0,
                                0.46734811054341041,
                                -0.14782724380893711,
                                -0.030017832116213734,
                                0,
                                0,
                                0,
                                0.45042620610763229,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.98909754699367525,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35236702739119841,
                                0,
                                0.6564581818589611,
                                0,
                                0.25161744914181061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.05920880006872524,
                                0,
                                0.61291107042484894,
                                -0.53319590422689556,
                                0,
                                0.47687904937102205,
                                0,
                                0,
                                -0.22229489945693842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49021034861983281,
                                0,
                                0.62133843406983702,
                                0,
                                0.74948531581550215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.065043455801330863,
                                0,
                                0.26054868507505025,
                                0.45723889478890384,
                                0,
                                0.12853362862483536,
                                0,
                                -0.43231580393486552,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14298210691019531,
                                0.78340776214467511,
                                0,
                                0,
                                0,
                                -0.076748566847294392,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40947775551995891,
                                0,
                                0,
                                0,
                                0,
                                -0.073273912167755847,
                                0,
                                0,
                                0,
                                0.22801569706843666,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83910306074803498,
                                0,
                                0.0064239715934398256,
                                0,
                                -0.67016400048869684,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4370273910066978,
                                0,
                                -0.23880363908293056,
                                0.77279478491578668,
                                0,
                                -0.31762516352636444,
                                0,
                                0,
                                0,
                                0,
                                0.061405809347151452,
                                0,
                                0.43880890150165897,
                                0,
                                0,
                                0,
                                -0.028478866985226337,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.93312559452819088,
                                0,
                                0,
                                0,
                                0,
                                -0.041859608748927322,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74092639700222296,
                                0.039468213188320833,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54040812480284328,
                                0,
                                0.26859130774174284,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72861157019867595,
                                0,
                                0,
                                0,
                                0,
                                -0.29243818911225211,
                                0.1336604411250531,
                                0,
                                -0.25621501918768275,
                                0,
                                0,
                                0,
                                -0.89855225720296639,
                                0,
                                0,
                                0.51518132354230606,
                                0,
                                0.64505561012670054,
                                0,
                                0,
                                0.73077185825798474,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12742765000802722,
                                0,
                                0,
                                0,
                                0.12778565191291782,
                                0,
                                0.20703928280028749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25921950827888657,
                                0,
                                0.58346577727422555,
                                0,
                                -0.16800377399542321,
                                0,
                                0,
                                0.11571623456812072,
                                0,
                                -0.27681154816900211,
                                0,
                                0,
                                0,
                                0,
                                -0.46421312643848456,
                                0.10630238410904207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49733164129515228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2074899337980437,
                                0,
                                0,
                                0,
                                -0.68618468028626234,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29775248131449633,
                                1.0425305888131642,
                                0,
                                -1.1826276247913563,
                                -0.063003150634649119,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11629288396928503,
                                0,
                                -0.43530160263713508,
                                0,
                                0.14325234154587557,
                                0,
                                0,
                                0.33305638534372567,
                                0,
                                0.19991534664041227,
                                0,
                                0,
                                0,
                                0,
                                -0.73135818348507431,
                                0.22623597900228531,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19876376464279497,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13683800034039184,
                                0,
                                0,
                                0,
                                -1.2113824711107348,
                                0,
                                0,
                                0.40687404439977237,
                                0,
                                -0.34980695391710687,
                                0,
                                0,
                                -0.25291941470278839,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58865138449041732,
                                0,
                                0,
                                0,
                                -0.30657508215258511,
                                0,
                                -0.79136883422266502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29173864134586702,
                                0,
                                0.36831260487435202,
                                0,
                                0.0057070062532181276,
                                0,
                                0,
                                -0.26687729462578169,
                                0,
                                -0.010106209874155489,
                                0,
                                0,
                                0,
                                0,
                                -0.25307967004164245,
                                -0.44678306238033633,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66649213816280517,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0698238543485796,
                                0,
                                0,
                                0,
                                0.4932370469439461,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3502173233022573,
                                -0.7419744552066978,
                                0,
                                -0.92002263920852578,
                                -0.13845488515174365,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83480184838256766,
                                0,
                                0,
                                0,
                                0.27874724768072717,
                                0,
                                0,
                                0.04830809840696032,
                                0,
                                -0.20409304268323591,
                                0,
                                0,
                                0.27398372227716983,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31859967501645581,
                                0,
                                0,
                                0,
                                -0.56547733753694662,
                                0,
                                0.4174797815684671,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79800443970913071,
                                0,
                                0.16502067077078736,
                                0,
                                -0.41585700106047463,
                                0,
                                0,
                                0.23158362474618358,
                                0,
                                -0.11678058687172713,
                                0,
                                0,
                                0,
                                0,
                                -0.20643115059853789,
                                -0.097533767574920299,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20886529299139958,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72911562439984401,
                                0,
                                0,
                                0,
                                0.004937206650514725,
                                0,
                                0,
                                -0.004500748266073662,
                                0,
                                0.4535238917262972,
                                0,
                                0,
                                -0.5644887223543178,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79117753621413511,
                                0,
                                0,
                                0,
                                0.11067097639026459,
                                0,
                                0.14569825227917282,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.06791517375697434,
                                0,
                                0.045768284339362003,
                                0,
                                -0.55572527101205949,
                                0,
                                0,
                                -0.48604435092460091,
                                0,
                                0.42879730205344835,
                                0,
                                0,
                                0,
                                0,
                                -0.051187800178638797,
                                0.50517615585130449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.080825984923795668,
                                0,
                                0,
                                0,
                                0,
                                -0.83637261851141076,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16062701318572134,
                                0,
                                -0.16044717903130457,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14074131896167949,
                                0,
                                0,
                                0,
                                0,
                                -0.41946743652481971,
                                -0.23059804685321908,
                                0,
                                0.065255984105487552,
                                0,
                                0,
                                0,
                                -0.43054586466070055,
                                0,
                                0,
                                -0.2901187176171004,
                                0,
                                -0.93663671509725943,
                                0,
                                0,
                                0.74575438496277435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50473541367901098,
                                0,
                                0,
                                0,
                                -0.66211827341070906,
                                0,
                                0.45519786039781485,
                                0,
                                0,
                                0,
                                0.2045402378887976,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43896097610408547,
                                0,
                                -0.12990673316284229,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.029300734274047613,
                                0,
                                0,
                                0,
                                0,
                                0.27117352187645072,
                                -0.8211012003554885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67989370927236215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14441055279949011,
                                0,
                                0,
                                0,
                                0,
                                0.3304418233640592,
                                0,
                                -0.018504939533071613,
                                0,
                                0.46551413309309014,
                                0,
                                0,
                                -0.59641515013535173,
                                0,
                                -0.4113434925373079,
                                0,
                                0,
                                0,
                                0,
                                -0.23355404777950586,
                                0.30626224826478032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.022445542210985967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13753018190316812,
                                0,
                                0.55067995611986009,
                                0,
                                0.45948698694717893,
                                0,
                                0,
                                0.2894501976401419,
                                0,
                                0.40156992457626667,
                                0,
                                0,
                                0,
                                0,
                                0.15862840715775087,
                                0.39584457529327544,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19953201055241632,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62476710589653961,
                                0,
                                0,
                                0,
                                -0.62325478117561528,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.84997833398980516,
                                -0.68274994042893844,
                                0,
                                -0.3968431065028627,
                                -0.51013559890296056,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20979093829080731,
                                0,
                                0,
                                0,
                                -0.73620737146537096,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3333422951892804,
                                -0.51673241341908371,
                                0,
                                0.024602519642259152,
                                -0.67654935976108943,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21832838309683239,
                                0,
                                0,
                                0,
                                -0.45791646282824744,
                                0,
                                0,
                                -0.47980666371156566,
                                0,
                                -0.34915506247779549,
                                0,
                                0,
                                -0.43542905940769167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54319328636552378,
                                0,
                                0,
                                0,
                                0.45672214908061592,
                                0,
                                0.59080587189489653,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084319908202765026,
                                0,
                                0,
                                0,
                                -0.49977129570220907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11332623105689357,
                                -0.4375698438629616,
                                0,
                                -0.12439109849580791,
                                1.298535795575501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7141781120687013,
                                0,
                                0,
                                0,
                                0.90064470511581862,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15429244519704399,
                                -0.19906575697549966,
                                0,
                                -0.32738284609915097,
                                -0.15435750714010479,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39891638032981958,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13034064259827732,
                                0,
                                -0.74063880762205125,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.070488937492165366,
                                0,
                                0,
                                0,
                                0,
                                -0.50549682025675513,
                                0.12180094185737875,
                                0,
                                0.44842490210919034,
                                0,
                                0,
                                0,
                                -0.15975138322066595,
                                0,
                                0,
                                0.70557226163284281,
                                0,
                                -0.17302114735996027,
                                0,
                                0,
                                -0.05377600088973454,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.071367322765470934,
                                0,
                                0,
                                0,
                                -0.60866568190688897,
                                0,
                                0.63316173501034645,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25424372288616998,
                                0,
                                -0.03884098466429247,
                                0,
                                -0.20401374264714961,
                                0,
                                0,
                                0.27403863288080793,
                                0,
                                -0.59610433701198962,
                                0,
                                0,
                                0,
                                0,
                                0.24622669572382208,
                                0.47190751567260308,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42245480011871833,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69613218615999239,
                                0,
                                0,
                                0,
                                -0.18508734241998398,
                                0,
                                0,
                                0.65258927468012384,
                                0,
                                -0.6847173483976442,
                                0,
                                0,
                                0.040769518288057499,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13691637746059906,
                                0,
                                0,
                                0,
                                1.1542424013182921,
                                0,
                                0.17564086040227561,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32944229202333608,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29252228299916871,
                                0,
                                0,
                                -0.23268062209931209,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52390985079825336,
                                0,
                                -0.33634323423050078,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1082259320589624,
                                0,
                                0,
                                0,
                                0,
                                0.57216181836278268,
                                0.46815534426209249,
                                0.20931278948146648,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44497310914646937,
                                0,
                                0.47282876208727798,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65709739400011657,
                                0,
                                0,
                                0,
                                0,
                                -0.28652349745748473,
                                0.14403940517098263,
                                0.22058737088907229,
                                0,
                                0,
                                0,
                                0.048554833648217485,
                                0,
                                0,
                                0.6726718479627134,
                                0,
                                0,
                                0,
                                -0.63228405837739254,
                                0,
                                0,
                                0,
                                -0.2579099404997186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17376868821890501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42826857474871532,
                                -0.61248076272179741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.066547100924299066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30973012921427445,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13186632584091704,
                                0.05270220315668224,
                                0,
                                0,
                                0.1107840726434525,
                                -0.55556521915441026,
                                0,
                                0,
                                0,
                                0.070993775531154241,
                                0.035339722158760682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.049404588127657773,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35061628248579735,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.059156415950159469,
                                0.11396952855848247,
                                0,
                                0,
                                -0.85503376286387323,
                                -0.34751564910991367,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.089889599449636245,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12057537439620297,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32944779025620569,
                                0,
                                0,
                                0,
                                0.087226967674037301,
                                0,
                                0,
                                -0.2643699045371814,
                                0,
                                0,
                                0,
                                -0.079199677920725783,
                                0,
                                0,
                                0,
                                -0.62939454632286795,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64152480798250289,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80340415903390294,
                                -0.52698745500155364,
                                0,
                                0,
                                -0.93391041041089018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1231980294522759,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6560162181334861,
                                0,
                                0,
                                0,
                                -0.22767740188311361,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1495311342631767,
                                0.38990297054339867,
                                0,
                                0,
                                0.26483541128447924,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51080936665180965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24163339567114331,
                                0,
                                0,
                                0,
                                -0.21131957460347411,
                                0.53608046315047453,
                                0,
                                0,
                                0,
                                -0.16438548323600127,
                                0,
                                0,
                                -0.45733949276056907,
                                0,
                                0,
                                0,
                                -0.045514334254189298,
                                0,
                                0,
                                0,
                                -0.21221192499148411,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65523299868057627,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47034562555509934,
                                0.44882542056091279,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14320969993718721,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40407093246022086,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.050052004624456831,
                                0.059326768332853996,
                                0,
                                0,
                                0.061737941705017237,
                                -0.61944487705558837,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26254036379804918,
                                -0.80507818926699493,
                                0,
                                0,
                                0.014156768211695314,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21354564341348983,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23513006246964069,
                                0,
                                0,
                                0,
                                0.54375192980717468,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59073354866867245,
                                0,
                                -0.3806830531750251,
                                -1.1218627619645787,
                                0,
                                0,
                                0,
                                -0.11863271682860047,
                                -0.33436656106668433,
                                0,
                                -0.53440418077649487,
                                -0.6077345464723316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37736404293347658,
                                0,
                                -0.22198309796352902,
                                0,
                                0,
                                0,
                                -0.92252951876072975,
                                0,
                                0,
                                -0.087745610626348253,
                                0,
                                0,
                                0,
                                -0.26734070425683359,
                                0,
                                0,
                                0,
                                -0.031129826159393303,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13972609212371312,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40085541385995049,
                                0,
                                0.28668780299662233,
                                -0.37160230336696559,
                                0,
                                0,
                                0,
                                0.36048899343199248,
                                -0.8137184123568848,
                                0,
                                -0.01387409797716059,
                                -0.88699210027854702,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35883059668193107,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13494332876813508,
                                0,
                                -0.1126474855271013,
                                0.61535638360677258,
                                0,
                                0,
                                0,
                                -0.44675050607769606,
                                -1.1133541507942866,
                                0,
                                0.58143766538043562,
                                0.56146029236648121,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46959399845480476,
                                0,
                                0,
                                0,
                                0,
                                -0.0074624311605928639,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61458790093231919,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41194189517124463,
                                0,
                                0,
                                0,
                                0.078885612172030481,
                                0,
                                0,
                                -0.23745961792252918,
                                0,
                                0,
                                0,
                                -0.4624782129946724,
                                0,
                                0,
                                0,
                                0.68379901791782294,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29364378190408486,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49520741157033255,
                                0.43700474020128649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14669832949299108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068019702531370185,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4840840743678182,
                                0.53985846550153638,
                                0,
                                0,
                                0.10430646564806667,
                                0.031384775811068577,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0030195592569446095,
                                0,
                                1.0090049688344795,
                                0.35984456021151789,
                                0,
                                0,
                                0,
                                -0.3127516786322686,
                                0.17552517685639152,
                                0,
                                -0.78964167148811593,
                                0.20074065925613932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.78587889395170252,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52123607580618347,
                                0,
                                -0.81441286650278855,
                                0.96597927706894227,
                                0,
                                0,
                                0,
                                0.66689428735340051,
                                0.18461192979950314,
                                0,
                                -0.21632524585655519,
                                -0.096052844634030174,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60592325601161856,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41317462952171696,
                                -0.24250029909244991,
                                0,
                                0,
                                1.0506124622888624,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.09845671779104205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49499183541490266,
                                0,
                                0,
                                0,
                                -0.35465184901872987,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60745957894240643,
                                0,
                                -0.81821238363293447,
                                -0.080510989722395801,
                                0,
                                0,
                                0,
                                -0.32933853576245942,
                                -0.52156314563534334,
                                0,
                                -1.0517606818809802,
                                0.38366105499480729,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1012243963347863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14849445266868883,
                                0,
                                -0.30813324319999913,
                                0.59639660218863277,
                                0,
                                0,
                                0,
                                -1.0721272407709197,
                                0.14421888399237012,
                                0,
                                0.064254119828999257,
                                -0.80584121535425446,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.019664646871849101,
                                0,
                                0,
                                0.1659677726228708,
                                0.27398463208549251,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66553206733896864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28703067472086119,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36278173124294971,
                                -0.45379335519829739,
                                0,
                                0,
                                -0.17011422046097974,
                                0.074764545043601055,
                                0,
                                0,
                                0,
                                -0.095292700665105382,
                                0.0058932844301292,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00027586960685191744,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69524431581685864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3578220403488141,
                                -0.3722356841319614,
                                0,
                                0,
                                0.34495613812636616,
                                -0.34918344933179357,
                                0,
                                0,
                                0.58004351694434098,
                                0,
                                0,
                                0,
                                -0.32515787603623147,
                                0,
                                0,
                                0.45207893621228468,
                                0,
                                0,
                                0,
                                0.55363848878955324,
                                0,
                                0,
                                0,
                                0.15414572183417652,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15221704801583177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25235992213715691,
                                -0.26059323893828162,
                                0,
                                0,
                                -0.67885385657085906,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.89094318439785247,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.072349000800666197,
                                0,
                                0,
                                0,
                                -0.83255171499028824,
                                0,
                                0.084770140214128875,
                                0.17327928208968252,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62314666674181207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21474871276377216,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52438783979244541,
                                0.34766592213585801,
                                0,
                                0,
                                0.30292517261162905,
                                -0.20184567293575875,
                                0,
                                0,
                                0,
                                -0.54888846475778652,
                                -0.35506759808729343,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3462029389916001,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.036975594396289981,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45567465667125495,
                                0.47318832292249263,
                                0,
                                0,
                                -0.047492062005394436,
                                0.13275054373067235,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59463319454394403,
                                0,
                                -0.31202268238198172,
                                -0.42162657098827122,
                                0,
                                0,
                                0,
                                -0.38691270138146333,
                                0.94328654181408855,
                                0,
                                0.60266818783967102,
                                0.15446190032777557,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69485375978772157,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.025044100999283447,
                                0.28861499055895801,
                                0,
                                0,
                                -0.29390423591622927,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25176068938316509,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.86017835569202294,
                                0,
                                0,
                                0,
                                0.64366684441135225,
                                -0.11139662739218023,
                                0.97055967641085306,
                                0,
                                0,
                                0,
                                0,
                                -0.087745999125348362,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.030293881390545598,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77394099001377326,
                                -0.32038575926209634,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38227607553596937,
                                0,
                                -0.27358715336589934,
                                0,
                                0,
                                -0.91988143727754268,
                                0.58161549632051845,
                                0,
                                0,
                                0,
                                0,
                                0.22146107483192282,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41389074773219603,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16290785552070258,
                                0.24221374500704007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0141312643815685,
                                0,
                                0.11858663432404276,
                                0,
                                0,
                                0,
                                0,
                                0.11822710637264496,
                                -0.33559764637318751,
                                0.68207211994347183,
                                0,
                                0,
                                0,
                                0,
                                -0.15259557604688118,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51593737328182621,
                                0.34452490662551061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.031256445332559127,
                                -0.22040986858200273,
                                0.17792423868242471,
                                0,
                                0,
                                0,
                                0,
                                -0.35546589978061804,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77879811098592466,
                                0.43116468566433919,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59984891697008291,
                                0.68464847465661927,
                                0.38274959308363227,
                                0,
                                0,
                                0,
                                0,
                                -0.12683420651577629,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.021834104887683985,
                                0.091525121555582512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.02123558948888235,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23523615396150252,
                                0,
                                0.057715660438933059,
                                -0.68291060658104574,
                                0,
                                0,
                                -0.46008604736658665,
                                0,
                                0,
                                0,
                                0.51161217893165978,
                                0,
                                0,
                                -0.013235292295634749,
                                0,
                                0.030226511424645913,
                                0,
                                0,
                                0,
                                0.69109152368308235,
                                -0.22855173843734541,
                                0,
                                0,
                                0,
                                0,
                                0.23539047646717848,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.037067362802917753,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19013466276134455,
                                0.97730866597896604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35066629972602614,
                                0,
                                -0.64415788503239158,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21736475567620109,
                                0,
                                0,
                                0.69489919998816929,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25324252698284999,
                                0,
                                0,
                                0.7974183084087314,
                                0,
                                0,
                                0,
                                0,
                                -0.38739364328414028,
                                0.74723482427636101,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53361719524515139,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50333558590744631,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12846610824638943,
                                0.074034625172702331,
                                0.30381079411020595,
                                0,
                                0,
                                0,
                                0,
                                0.88817465642593374,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24682261974106312,
                                0.18957507419627606,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.029833698511883416,
                                0,
                                0,
                                0.15193828027175979,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.017333201613570826,
                                0,
                                0,
                                -0.17428668397283198,
                                0,
                                0,
                                0,
                                0,
                                0.82922099714395436,
                                0.87342640614310885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.047726422637232979,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26148086268321935,
                                0,
                                -0.21235182328692254,
                                -0.23238918200640124,
                                0,
                                0,
                                0.31707608830195066,
                                0,
                                0,
                                0,
                                0.12889343617131205,
                                0,
                                0,
                                0.82839481938507475,
                                0,
                                0.16389990183298625,
                                0,
                                0,
                                0,
                                0.89177303389570106,
                                0.32842438070990199,
                                0,
                                0,
                                0,
                                0,
                                0.52832672812577264,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15347067831223185,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29939289250712409,
                                -0.68978918843761572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21200395713612574,
                                0,
                                0.83319296358369055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64222627567261681,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26285263634024597,
                                0,
                                -0.21299640033686484,
                                -0.15901205037309862,
                                0,
                                0,
                                -0.43817762764504631,
                                0,
                                0,
                                0,
                                -0.41629915861138689,
                                0,
                                0,
                                0.13723621176028356,
                                0,
                                -0.25231568131378646,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.019706623889611585,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35716906869432896,
                                0,
                                0.70949185799238934,
                                0.098159673928501667,
                                0,
                                0,
                                -0.076442104020120971,
                                0,
                                0,
                                0,
                                -0.14819371669979339,
                                0,
                                0,
                                0.44726071833558889,
                                0,
                                -0.36218912752492716,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40028050257922537,
                                -0.45555151268838834,
                                0.35748029310318974,
                                0,
                                0,
                                0,
                                0,
                                0.060315874545620513,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20756187790523287,
                                -0.67656207453813966,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66970041140848369,
                                0.39628508588346489,
                                0.36949990379484149,
                                0,
                                0,
                                0,
                                0,
                                -0.20440020372313922,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15100351739006074,
                                -0.43971332162559512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0049091676858330074,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75193587183176336,
                                0,
                                -0.59215151105840269,
                                0.17763198445290304,
                                0,
                                0,
                                -0.047869700891721489,
                                0,
                                0,
                                0,
                                -0.074293142627827657,
                                0,
                                0,
                                0.18507273750034209,
                                0,
                                -0.10153281885656258,
                                0,
                                0,
                                0,
                                -0.47747283256649053,
                                0.045685002320606849,
                                0,
                                0,
                                0,
                                0,
                                0.96652733738198837,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13526885545017786,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44132449942063778,
                                -0.077059368948298623,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.07359869508234787,
                                0,
                                -0.25295726603046786,
                                0,
                                0,
                                0.43783198779717625,
                                0.74271337299517037,
                                0,
                                0,
                                0,
                                0,
                                -0.09083593183976002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.099767650805071745,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87938790409154044,
                                -0.34241761442800545,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4696179201466909,
                                0,
                                -0.27386031649299342,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62352599055836766,
                                0,
                                0,
                                0.53307009362941826,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41431322616715849,
                                0,
                                0,
                                0.90488250272745518,
                                0,
                                0,
                                0,
                                0,
                                0.31097915131423914,
                                -0.79499194107660509,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.02315230073548806,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15285994356729685,
                                0,
                                -0.011374436402356003,
                                -0.61924075263314271,
                                0,
                                0,
                                0.55990879143062189,
                                0,
                                0,
                                0,
                                -0.38212380139977764,
                                0,
                                0,
                                -0.2283047520420558,
                                0,
                                -0.28437617160307777,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1813425444789232,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26605814126272231,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49406102461685475,
                                0,
                                0,
                                0.27597041135548039,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.514100507834589,
                                0,
                                0,
                                -0.44095677426799995,
                                0,
                                0,
                                0,
                                0,
                                0.49982465617360322,
                                -0.38794018699139027,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36693026616886726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.086980808289127229,
                                0,
                                0.084991764081222138,
                                -0.17229697562284019,
                                0,
                                0,
                                -0.3099813336962351,
                                0,
                                0,
                                0,
                                -0.60661246580031969,
                                0,
                                0,
                                0.075565092386479654,
                                0,
                                0.59254491550968624,
                                0,
                                0,
                                0,
                                -0.047386344868711835,
                                -0.29795115967797553,
                                0,
                                0,
                                0,
                                0,
                                0.11963349880702387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3456370588435393,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14988143570401405,
                                0.51476439057079371,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25492161879079439,
                                0,
                                0.64039020602205299,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67024648372400653,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2886019396182693,
                                0,
                                0.21173817029294292,
                                -0.0031206289082113259,
                                0,
                                0,
                                0.27939714455448716,
                                0,
                                0,
                                0,
                                0.082803013525021188,
                                0,
                                0,
                                -0.05124315672561211,
                                0,
                                0.57887029279032876,
                                0,
                                0,
                                0,
                                -0.11220698814888291,
                                0.62433862584937505,
                                0,
                                0,
                                0,
                                0,
                                -0.23470467265836434,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14767316959498838,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0050492952741681557,
                                0.85808624752518026,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.86393537884802596,
                                0,
                                1.1035752187757275,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19386025882895555,
                                0,
                                0,
                                0.87508483798511527,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34085237493250264,
                                0,
                                0,
                                -0.51710074170981701,
                                0,
                                0,
                                0,
                                0,
                                -0.19991683181419401,
                                0.15735788883287871,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1540461199452539,
                                0,
                                0,
                                -0.028493828214855219,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56774382297738268,
                                0,
                                0,
                                -0.11183198237117217,
                                0,
                                0,
                                0,
                                0,
                                0.7468195644860578,
                                -0.13705355963253174,
                                -1.2117498630981496,
                                0,
                                0,
                                -0.47988466831368665,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56609836607289976,
                                0,
                                0,
                                0,
                                0,
                                -0.33690611947071714,
                                0,
                                0,
                                0.6286036336879175,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40713241380501536,
                                0,
                                0,
                                0,
                                0.43447874498761024,
                                0,
                                0,
                                0,
                                -0.81597788360675849,
                                0,
                                0,
                                0.12368573499155902,
                                0,
                                0,
                                0.32831363587310092,
                                0.27454524293373184,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26846958318329867,
                                0,
                                0,
                                0,
                                0,
                                0.84832327941189611,
                                -0.15489124877318994,
                                0,
                                0,
                                -0.60373917674142763,
                                0,
                                -0.49597921138098527,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2669269988462003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19452602843861416,
                                0,
                                0,
                                -0.50937988241352583,
                                -0.14472513701745721,
                                0,
                                0,
                                0,
                                0.35914501632803775,
                                0,
                                0,
                                0.68012812588573146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.83587168867251549,
                                0,
                                0,
                                0,
                                0,
                                0.04271633468236935,
                                0,
                                0,
                                0.830238629434773,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45622103120428859,
                                0,
                                0,
                                0,
                                0,
                                -0.45054313920028394,
                                0,
                                0.37415394133880925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18086073390649898,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56530105809280717,
                                0,
                                0,
                                0.52702510676679115,
                                -0.16428132391600439,
                                0,
                                0,
                                0,
                                0,
                                -0.72884143419048208,
                                0,
                                0,
                                0,
                                -0.459136850252444,
                                0,
                                0,
                                0.47154599978443357,
                                0,
                                0,
                                0.34744660676976541,
                                0.17628515626424901,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72422439611212419,
                                0,
                                0,
                                0,
                                0,
                                -0.17191548457197534,
                                0.33438079917682478,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30204299826841607,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.064599239357203742,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60861817284978104,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.029171184029972916,
                                0,
                                -0.1406193245610701,
                                0.23467868336442405,
                                0,
                                -0.0039236570507603791,
                                0,
                                0.19809129587389232,
                                0.71722792537201663,
                                0,
                                0,
                                0.014616063577966965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4822662187371376,
                                0,
                                0,
                                0,
                                0.12440246773294691,
                                0,
                                0,
                                0.63756821353401116,
                                0,
                                0,
                                -0.17695163047393109,
                                0.019921223557936973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14638802879754501,
                                0,
                                0,
                                0,
                                0,
                                -0.097000735944128016,
                                0.9507269444198676,
                                0.018803577098128466,
                                0,
                                0,
                                0.94008843987228197,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38267960770990711,
                                0,
                                0,
                                0,
                                0,
                                -0.50699861215945752,
                                0,
                                0,
                                -0.57274290765941682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54006599424880986,
                                0,
                                0,
                                0,
                                0,
                                0.37594205300247563,
                                0,
                                0.032440004064762384,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45295244936943591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50567073554166209,
                                0,
                                0,
                                -0.21492308292351681,
                                0.59207640822295937,
                                0,
                                0,
                                0,
                                0,
                                0.42288765395601247,
                                0,
                                0,
                                0,
                                -0.41798313558530309,
                                0,
                                0,
                                -0.7763580275963653,
                                0,
                                0,
                                0.94431095510270191,
                                -0.49264057395128935,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17904337040455989,
                                0,
                                0,
                                0,
                                0,
                                -0.61988318132337894,
                                0.18986588996312276,
                                0,
                                -0.60022513652983112,
                                0,
                                0,
                                0,
                                -0.053667498496749885,
                                0,
                                0,
                                0.29634255894545847,
                                0,
                                0,
                                0.59102182523508384,
                                -0.14005887052753199,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.82994022387036448,
                                0,
                                0,
                                0,
                                0,
                                0.39862122887576629,
                                0.24115045558658224,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28338913195763105,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.044348723698957516,
                                0,
                                -0.099336013300331122,
                                0.11113787749123596,
                                0,
                                -0.32038206948707404,
                                0,
                                0.11256918285303077,
                                -0.34393469471778321,
                                0,
                                0,
                                0.81357049702854811,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68199438630184916,
                                0,
                                0,
                                -0.31827513759156761,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.050684554610466184,
                                0,
                                0,
                                0,
                                0,
                                -0.99896379934948176,
                                0,
                                0,
                                0.75138281665474083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0025462119501010773,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40089166897871131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16072969535405218,
                                0,
                                -0.62834918660167105,
                                -0.19076517692912881,
                                0,
                                0.12801400649671879,
                                0,
                                -0.51930307760642758,
                                -0.25992297485332883,
                                0,
                                0,
                                -0.16915837731433753,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39659851264633694,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35948644621471398,
                                0,
                                -0.39251909506366944,
                                0.056501268947330457,
                                0,
                                0.54790529935226262,
                                0,
                                -0.10111886799126453,
                                0.27828228738411215,
                                0,
                                0,
                                0.4103037988838365,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0254331126267178,
                                0,
                                0,
                                -0.12356163174128748,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23311241402300609,
                                0,
                                0,
                                0,
                                0,
                                -0.54817757658289912,
                                0,
                                0,
                                -0.83128698668728662,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87177478277669185,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19746471285447209,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48071612158984195,
                                0,
                                -0.28246384243791117,
                                0.72031654723499827,
                                0,
                                0.12814278152145606,
                                0,
                                0.24459079015818214,
                                -0.20768774783052765,
                                0,
                                0,
                                -0.10908033475565712,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23259982152326095,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39936393205760368,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2002020927454605,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15203195984126336,
                                0,
                                -0.49601251979086547,
                                -0.50908881690321994,
                                0,
                                -0.22379128328883924,
                                0,
                                0.61153541333092643,
                                0.064099837479325933,
                                0,
                                0,
                                -0.05864019579767657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30933348841514691,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62357816222095042,
                                0,
                                0.056281977125558817,
                                -0.12779862690648661,
                                0,
                                -0.26167231101957278,
                                0,
                                -0.42683012342551951,
                                0.40049615977717679,
                                0,
                                0,
                                0.29139216177460703,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45104544698763344,
                                0,
                                0.37623616106317614,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49956529994400145,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.030467109597359182,
                                0,
                                0,
                                -0.26891512649698801,
                                0.5763638407515862,
                                0,
                                0,
                                0,
                                0,
                                -0.33840322662954592,
                                0,
                                0,
                                0,
                                0.58503349054755704,
                                0,
                                0,
                                0.30073454988274984,
                                0,
                                0,
                                -0.010127622564506222,
                                -0.83540557144752292,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39602628379490512,
                                0,
                                0,
                                0,
                                0,
                                0.49691254231527665,
                                0.0059559583120347565,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23771750305357456,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44616842333300433,
                                0,
                                0.30410971491513716,
                                -0.31405525132366474,
                                0,
                                0.66766505244954089,
                                0,
                                0.22848005393028403,
                                -0.1210449534162476,
                                0,
                                0,
                                0.20169052808400142,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2471206494337177,
                                0,
                                0.30024625923976256,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66123077019798759,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61256546012836088,
                                0,
                                0,
                                0.061908452031331274,
                                0.18024521520466796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16329987246352687,
                                0,
                                0.61746225076176275,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.063889204590662371,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10357006076235888,
                                0,
                                0,
                                -0.58346956987033982,
                                -0.48664997033122848,
                                0,
                                0,
                                0,
                                0.34099550314718968,
                                0,
                                0,
                                -1.0351156757788416,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80371506742035459,
                                0,
                                0,
                                0,
                                0,
                                -0.090746875942811278,
                                0,
                                0,
                                0.0388174186842698,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28804244416906727,
                                0,
                                0,
                                0,
                                0.34592018619008147,
                                0,
                                0,
                                0,
                                -1.1123771545407444,
                                0,
                                0,
                                0.42642281216228234,
                                0,
                                0,
                                -0.13174262982238838,
                                -0.84397110826859767,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37779733602050652,
                                0,
                                0,
                                0,
                                0,
                                -0.48648689285725566,
                                -0.20769680602802532,
                                0,
                                0.31673714957374666,
                                0,
                                0,
                                0,
                                0.013512177314517275,
                                0,
                                0,
                                0.4301582336420755,
                                0,
                                0,
                                0.76732721898615885,
                                -0.016235063843277664,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.07057955996929785,
                                0,
                                0,
                                0,
                                0,
                                -0.36710774934519225,
                                -0.83132113188696943,
                                -1.1361206202610135,
                                0,
                                0,
                                0.19884512812927033,
                                0,
                                0,
                                0.5783333205319604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64232203385957587,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18917583251736705,
                                0,
                                0,
                                -0.022819616749725796,
                                -0.36950471891156195,
                                0,
                                0,
                                0,
                                0.2989200522363481,
                                0,
                                -0.97490606217955689,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.81865389316650827,
                                0,
                                0,
                                0,
                                1.0155427616350856,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16397762541767372,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50240654079741676,
                                -0.010140688558244654,
                                0,
                                0,
                                0,
                                -0.52664607340727354,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79611172880097392,
                                -0.068551244659785071,
                                0,
                                0,
                                0.15268488347010301,
                                -0.2392338422742207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.060043738693168952,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46589019952128197,
                                0,
                                0,
                                0.09700412286693616,
                                0,
                                0,
                                -0.6221151417104207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49907206726520753,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.81687467154036475,
                                0,
                                0,
                                -0.7394784668766079,
                                -0.1302876994867409,
                                0,
                                0,
                                0,
                                0.9527543588160714,
                                0,
                                0,
                                0,
                                0,
                                0.56432179923027026,
                                0.39812773932772227,
                                0,
                                0,
                                0.26329127340760006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44017455641000064,
                                0.074972411982352327,
                                0.31360205525450457,
                                0,
                                0,
                                0,
                                0,
                                0.35809628591985332,
                                0,
                                0,
                                -0.1666109651855992,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27285364770679488,
                                -0.038089670243580766,
                                0,
                                0,
                                0.76881619702940318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12952137176011769,
                                -0.32178461795752322,
                                0.14806479804443698,
                                0,
                                0,
                                0,
                                0,
                                -0.18098106565039868,
                                0,
                                0,
                                -0.3975213987931866,
                                0,
                                0,
                                0,
                                -0.5863865591375037,
                                0,
                                0,
                                0.79529901369123723,
                                0,
                                0,
                                0.41954444622145992,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17116792583786297,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44547688051445644,
                                0,
                                0,
                                -0.61828667607868903,
                                0.63775017494203967,
                                0,
                                0,
                                0,
                                -0.087486574324105199,
                                0,
                                0.54304635845972016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53685096288050749,
                                0,
                                0,
                                0,
                                0.16607687926027495,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41541751029895857,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.94465985519291507,
                                0.51565062548710772,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26788066656610104,
                                0.38729552162755138,
                                0,
                                0,
                                -0.31354017557726482,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28424420449928867,
                                -0.13861085611388502,
                                -0.33794717276690484,
                                0,
                                0,
                                0,
                                0,
                                -0.24431139704782459,
                                0,
                                0,
                                -0.63720530300183542,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.432978449890071,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34653173127685633,
                                -0.098832998864383403,
                                0,
                                0,
                                0.16946861129848992,
                                0.13644463625646183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79708262464184487,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42477467133179092,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26899953676292437,
                                0.80177738792381636,
                                0,
                                0,
                                0.15514044885301523,
                                -0.10456082710515235,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26335759452716673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.01438044609615774,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17301557749192509,
                                0,
                                0,
                                0,
                                -0.33658404786996543,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.88920114420916141,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22334045775397102,
                                -0.6755139312077737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42724600401536256,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32858698856714186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19833715896458778,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.069799326380713012,
                                -0.33864113319780353,
                                0,
                                0,
                                0.697030491960002,
                                0.43879841735440206,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40338201561600584,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2844922895377312,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40766799617654303,
                                0.19783865516765309,
                                0,
                                0,
                                0.66159682208932269,
                                -0.43771178711202946,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29056642103474073,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.86428847152964916,
                                0,
                                0,
                                -0.26016147280239105,
                                0,
                                0,
                                0.078991774971220771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4988588452005745,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31858245810126062,
                                0,
                                0,
                                -0.80016876197754583,
                                -0.083603756691219819,
                                0,
                                0,
                                0,
                                -0.74576051797854304,
                                0,
                                0,
                                0,
                                0,
                                0.205557420118401,
                                -0.26667241459360264,
                                0,
                                0,
                                0.22939036823751435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46615649462788056,
                                0.74882262695051427,
                                -0.0082084112931764819,
                                0,
                                0,
                                0,
                                0,
                                0.13795671365365011,
                                0,
                                0,
                                -0.19202966519276954,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20111313206825981,
                                -0.58779734549708063,
                                0,
                                0,
                                0.01184942797214758,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59221348844399491,
                                0.076680619341088246,
                                -0.29530277334985811,
                                0,
                                0,
                                0,
                                0,
                                -0.2927204805217829,
                                0,
                                0,
                                -0.29055402053741086,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60491348802645073,
                                0.032548455237647114,
                                0,
                                0,
                                -0.29911900909435218,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25027156813534551,
                                0.23575894449896415,
                                0.23577721838776777,
                                0,
                                0,
                                0,
                                0,
                                0.33853313773619415,
                                0,
                                0,
                                -0.50510827421390725,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11446838782472513,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.097335988095127918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47393750796599216,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17059154347877967,
                                0,
                                0,
                                0,
                                -0.50037401704017248,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3496115496938734,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60785992949690171,
                                -0.22196598345849922,
                                0,
                                0.34496373551594545,
                                0,
                                0,
                                0.53554350650805427,
                                0,
                                0,
                                0.5314572343201408,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4046511720399536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14136712574196272,
                                0,
                                0,
                                0.36222313209184565,
                                -1.0357305612085657,
                                0,
                                0,
                                0,
                                -0.034746491059315765,
                                0,
                                0,
                                -0.48421747434174345,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.051922852727114943,
                                0.43458927141968395,
                                0,
                                0,
                                0.018365607892856173,
                                0.72737982081791852,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21107089043093694,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.07418781244818487,
                                -0.031705103803254434,
                                0,
                                0,
                                0.19213765839628283,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0015210384998652904,
                                -0.17831154322507303,
                                -0.69584999509657997,
                                0,
                                0,
                                0,
                                0,
                                0.66369245079212535,
                                0,
                                0,
                                0.0090482143640096893,
                                0,
                                0,
                                0,
                                0.78394830095996582,
                                0,
                                0,
                                0.13705866031128883,
                                0,
                                0,
                                0.47621131341731782,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38605615848154551,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20858985258365545,
                                0,
                                0,
                                0.98456153062136176,
                                0.66527940727040269,
                                0,
                                0,
                                0,
                                0.7224280828181211,
                                -0.13704505377211354,
                                0,
                                0,
                                0.24355780096604418,
                                0,
                                0,
                                -0.883926557787446,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62624656175240723,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53195771068219766,
                                0,
                                0,
                                0.69691314854373976,
                                -0.21106551178034066,
                                0,
                                0,
                                0,
                                -0.58464470560198523,
                                0,
                                0,
                                0,
                                0,
                                0.28496883681991575,
                                -0.5209233604875545,
                                0,
                                0,
                                -0.24928398960347309,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27931870972314327,
                                -0.4665064814991115,
                                0.37209280641851522,
                                0,
                                0,
                                0,
                                0,
                                0.34570964119619707,
                                0,
                                0,
                                -0.17797094027042787,
                                0,
                                0,
                                0,
                                0,
                                0.6094592179446463,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.4876518184989789,
                                0,
                                0,
                                0,
                                0.082740249534508203,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17254821277884275,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49407197142327497,
                                -0.11265250027868039,
                                0,
                                0,
                                -0.86665110388655631,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.040975727364922138,
                                0,
                                0,
                                0,
                                -0.95853364899465854,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1249073782374087,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33233679482256978,
                                0.79295912174561589,
                                0,
                                -0.33474429351641233,
                                0,
                                0,
                                0.57402087900493759,
                                0,
                                0,
                                -0.60993545518766634,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11565784946647806,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.93143265789924579,
                                0,
                                0,
                                -0.29174429798495738,
                                0.43810657564816535,
                                0,
                                0,
                                0,
                                0.30399087571346323,
                                -0.0099598913389884608,
                                0,
                                0.28489445942499952,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37870353892325037,
                                0,
                                0.95760888132105881,
                                0,
                                0,
                                0,
                                0,
                                -0.4656695869591827,
                                0,
                                0,
                                0.088027988980899058,
                                0,
                                0,
                                0,
                                -0.41120913170447371,
                                0,
                                0.72850334161382846,
                                0,
                                0,
                                0,
                                0.57246349518775241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53474828906238425,
                                0,
                                0.20432596783874882,
                                0,
                                -0.49886856748603259,
                                0.2092335954282771,
                                0.96091400448140207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20937844074270606,
                                0,
                                0.58401617648640924,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12068673768706005,
                                0,
                                0.18649009194013283,
                                0,
                                0,
                                0,
                                0,
                                -0.51620165480087488,
                                0,
                                0,
                                0.063296116418823489,
                                0,
                                0,
                                0,
                                0.014713572341578898,
                                0,
                                -1.0513230541404992,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39509171110094865,
                                0,
                                -0.56168134007452064,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15337620231398283,
                                0,
                                0,
                                0,
                                -0.37423748785554034,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63648402974729446,
                                0,
                                0.0072905184679252499,
                                0.044937951048968736,
                                -0.22310910409009638,
                                0,
                                0,
                                0,
                                0.57284457218500273,
                                -0.22651484677663947,
                                0,
                                0,
                                0,
                                0.1218412274203219,
                                0,
                                1.3521787467408617e-05,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18434657068341381,
                                0.30947593618543667,
                                0,
                                0.70107903640519387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.021392353283386623,
                                0,
                                0.61370229352050254,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.04050967367497061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.040292524141186517,
                                -0.20338386186506299,
                                0,
                                0.32784134389361569,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12876149641885093,
                                0,
                                -0.32074231926591518,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85444509018258319,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68294370793217363,
                                0,
                                0,
                                0,
                                -0.21353961188019904,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.09005222055912751,
                                0,
                                0.19834091565208017,
                                -0.19731799382600457,
                                -0.2238676616167731,
                                0,
                                0,
                                0,
                                -0.326596009378681,
                                -0.49479706017438269,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.94920208533639749,
                                -0.13884198216854818,
                                0,
                                -0.023798751287008299,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19240480592500617,
                                0,
                                -0.18939928810696538,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.07924787025061078,
                                0,
                                0,
                                0,
                                0,
                                0.17492703130851556,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28832744204605487,
                                0,
                                0.95560078376630053,
                                0,
                                -0.7514849689967662,
                                0.71831912528335851,
                                -0.66975895796249385,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22590193846623913,
                                0,
                                -0.17741176953197191,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.92560130107410976,
                                0,
                                0.27163766995977245,
                                0,
                                0,
                                0,
                                0,
                                -0.17429972989743631,
                                0,
                                0,
                                0.62205544034765126,
                                0,
                                0,
                                0,
                                0.18324234918309421,
                                0,
                                -0.14210827341068655,
                                0,
                                0,
                                0,
                                0.34346506673868005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1790969074801252,
                                0,
                                -0.0079181863601639705,
                                0,
                                0.20481509634665121,
                                -0.69546034177465799,
                                0.20702181091828087,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12067301138293444,
                                0,
                                0.18047319663237452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67654882887445122,
                                0,
                                0.026522243854295441,
                                0,
                                0,
                                0,
                                0,
                                0.55963674555769072,
                                0,
                                0,
                                0.89134734159550688,
                                0,
                                0,
                                0,
                                -0.15322251865310949,
                                0,
                                0.35785409961963377,
                                0,
                                0,
                                0,
                                0.97955427237349657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.91325138999809163,
                                0,
                                0.84856172753191661,
                                0,
                                0.45698354889097925,
                                -0.89885699939638675,
                                -0.12005134154398375,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8702297993837339,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20072552018975029,
                                0,
                                -0.58294302627971795,
                                0,
                                0.76912794598015854,
                                0.99612541598972504,
                                -0.27993032607595636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79885490304329965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.046467532458905711,
                                0,
                                0.87409366687744094,
                                0,
                                1.2858618224919727,
                                0.42105853423405049,
                                0.28386709890973538,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15638730840134385,
                                -0.47617249043077681,
                                0,
                                -0.3323222680440433,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47012377516719889,
                                0,
                                0.56897464614466875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30596759200459356,
                                0,
                                0,
                                0,
                                -0.24154261701491081,
                                0,
                                0.32279677027140924,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36537305702191486,
                                0,
                                0.45793767991614853,
                                0,
                                0,
                                0,
                                0,
                                0.70036707578293822,
                                0,
                                0,
                                -0.082305111486380617,
                                0,
                                0,
                                0,
                                -0.77462131658168798,
                                0,
                                0.015323327482361107,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18223009404131998,
                                0.53447610422471303,
                                0,
                                -0.0036218567663721113,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7553319147182338,
                                0,
                                -0.30286200613441877,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13734144618560779,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36481989526977698,
                                0,
                                0,
                                0,
                                0.37852493897538431,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18007781356806773,
                                0,
                                -0.34783523528047811,
                                -0.14080424780981424,
                                0.63340132915555292,
                                0,
                                0,
                                0,
                                0.32377155516457329,
                                -0.21061064748951952,
                                0.39874513511670689,
                                0,
                                -0.46306854450415813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12699268193577079,
                                0,
                                -0.061939562857142583,
                                0,
                                0,
                                0,
                                0,
                                -0.26443427186882817,
                                0,
                                0,
                                0.44833236729473375,
                                0,
                                0,
                                0,
                                -0.96417896429850558,
                                0,
                                -0.041335228702551824,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23642134242322116,
                                0,
                                0,
                                0,
                                -0.2955522923536858,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23878820826055888,
                                0,
                                -0.1157769846916489,
                                -0.66864630811606407,
                                -0.11666213876860493,
                                0,
                                0,
                                0,
                                0.32852207086769269,
                                0.46658866436744906,
                                0,
                                0,
                                0,
                                0,
                                -0.26546338468975672,
                                0,
                                0,
                                0,
                                -0.062664204120344819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56288133882513813,
                                0,
                                -0.23729877548213854,
                                0.50257290899425655,
                                -0.26187585838020466,
                                0,
                                0,
                                0,
                                0.44584435867690198,
                                -0.18033466734597409,
                                0,
                                0,
                                0,
                                0,
                                0.022372951561355318,
                                0,
                                0,
                                0,
                                0.50571732566495042,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20174090069403924,
                                0,
                                -0.53227315391649654,
                                -0.1648673699496471,
                                -0.61485015698133694,
                                0,
                                0,
                                0,
                                -0.12044863689441607,
                                -0.0023445306260050924,
                                -0.54013194893444638,
                                0,
                                -0.89529246912644034,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.060027606075611514,
                                0,
                                0.33254412102430847,
                                0,
                                0,
                                0,
                                0,
                                0.18364015860113383,
                                0,
                                0,
                                -0.25301937802062441,
                                0,
                                0,
                                0,
                                0.55960451657599775,
                                0,
                                -0.69398893739993794,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.075785606584006932,
                                0.5754803272156519,
                                0,
                                -0.53850779910786872,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39293837881856974,
                                0,
                                0.26299092476539065,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38668267231015552,
                                0,
                                0,
                                0,
                                1.0116380279624135,
                                0,
                                0.047077201016071393,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.071342928888131638,
                                0,
                                0.40620843423378139,
                                0,
                                0,
                                0,
                                0,
                                0.46626939632664727,
                                0,
                                0,
                                -0.15291394026901156,
                                0,
                                0,
                                0,
                                -0.075498925436877182,
                                0,
                                -0.082009365869465292,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.048404627826533833,
                                0,
                                0,
                                0,
                                0.56772421608778023,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.059796424204774351,
                                0,
                                0.69348981487239336,
                                -0.12886299774146137,
                                -0.19262879908201294,
                                0,
                                0,
                                0,
                                0.36993367122294291,
                                -0.016733895717591596,
                                0,
                                0,
                                0,
                                0,
                                0.49775562242350507,
                                0,
                                0,
                                0,
                                -0.041560178194529035,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.369080540190312,
                                0,
                                -0.075236466388073547,
                                -0.44245453731823386,
                                0.039658093475910552,
                                0,
                                0,
                                0,
                                0.047889293135236946,
                                -0.63953026085077691,
                                -0.60624742332302961,
                                0,
                                0,
                                -0.72536952967347101,
                                0,
                                0,
                                0.18110564404571722,
                                0,
                                0,
                                0,
                                0,
                                0.099157072055777187,
                                0.37222569717905746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14250204997581795,
                                0,
                                0,
                                0,
                                0,
                                0.5013731206206733,
                                0,
                                0,
                                0,
                                0.83507374608816987,
                                0,
                                0,
                                0.29455305948195409,
                                0,
                                0,
                                0,
                                0.039539645424137876,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3012155634649893,
                                -0.85535913989691148,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22009845411629558,
                                0,
                                -0.11035993256593873,
                                0,
                                0,
                                0.52248944744777892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.069167366083910359,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14462298197787424,
                                0,
                                0,
                                0.031464557038157537,
                                0,
                                0,
                                -0.69654108042180285,
                                0,
                                0,
                                0,
                                0,
                                -0.42674772721444609,
                                -0.12600204201031134,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.044099334577602,
                                0,
                                0,
                                0,
                                0,
                                0.1153314106005266,
                                0,
                                0,
                                0,
                                0.73739802460525361,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.030572113759329882,
                                0,
                                0,
                                0,
                                -0.098628230040823217,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50700663368118759,
                                0,
                                0.6765979477596642,
                                0,
                                0,
                                0.16660292110963754,
                                0.22359227830787942,
                                0.16600236761483805,
                                0,
                                0.4113277066951338,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40843720018156737,
                                0,
                                0,
                                0,
                                -0.97647726224464004,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.021556387185023451,
                                -0.042902162806805588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3126182295059019,
                                0,
                                -0.30822248141759001,
                                0.54925171114060745,
                                0,
                                0,
                                -0.3098453072390942,
                                0,
                                0,
                                -0.90798896713485822,
                                0,
                                0,
                                0,
                                0,
                                1.1484676395257953,
                                0.42072408158704888,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.022956729125674168,
                                0,
                                0,
                                0,
                                0,
                                0.074210450799842953,
                                0,
                                0,
                                0,
                                -0.28491685248463067,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.053534302353170943,
                                0,
                                -0.37682769297713131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36042120871979771,
                                0,
                                -0.7564671273468071,
                                0,
                                0,
                                -0.31828754807251147,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2273368482400295,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10938252308812421,
                                0,
                                0,
                                0,
                                0.52736215227966454,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21812704723956072,
                                0,
                                0.19217427300149351,
                                0,
                                0,
                                -0.72133265264210722,
                                0.017189522987825091,
                                0.20519634324409636,
                                0,
                                -0.25038460275291846,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16071260090541084,
                                0,
                                0.69359758633918878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19871815979019591,
                                0,
                                -0.24839931868295906,
                                0,
                                0,
                                -0.38524911767293618,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49344284057460414,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21982514501124364,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43352979005103409,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.084552439303903909,
                                0,
                                0,
                                -0.98376916972773865,
                                0,
                                0,
                                0.41520258204392479,
                                0,
                                0,
                                0,
                                0,
                                -0.066842507926726788,
                                0.015144352283014549,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80721114338344502,
                                0,
                                0,
                                0,
                                0,
                                -0.14376172406727836,
                                0,
                                0,
                                0,
                                -0.53535097408986976,
                                0,
                                0.10888850422983859,
                                0,
                                0,
                                -0.32250571323485372,
                                0,
                                0,
                                -0.6265851119268161,
                                0,
                                0,
                                0,
                                0,
                                -0.56384686472780476,
                                1.0687827643907273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28913619619896069,
                                0,
                                0,
                                0,
                                0,
                                0.73176303787204278,
                                0,
                                0,
                                0,
                                -0.091563460311897563,
                                0,
                                0,
                                -0.53626189455964612,
                                0,
                                0,
                                0,
                                0.72753026905135876,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10858082303637177,
                                0.27204548739979373,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2017112468328188,
                                0,
                                -0.022517636681938041,
                                0,
                                0.73955161898095678,
                                0,
                                0,
                                0,
                                0.33034497116276607,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31492250280498096,
                                -1.1477525109740792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42477001563038641,
                                0,
                                0.85046733810799502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64286695661803595,
                                0,
                                0.53740168858529214,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.05184321143247192,
                                0,
                                -0.12685539629932363,
                                0,
                                0,
                                0.086899795834957064,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52114289454648854,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3174825556253521,
                                0,
                                0,
                                0,
                                -0.54199404828143427,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.094591095094227737,
                                0,
                                0.30073233494947482,
                                0,
                                0,
                                -0.26136628533201245,
                                -0.023194312971902296,
                                -0.54035170643679131,
                                0,
                                -0.3810899999136203,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6572767268188342,
                                0,
                                0.21837486508425386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13793178727679042,
                                0,
                                0.091658149136827557,
                                0,
                                0,
                                -0.28479566431626158,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6416889885480771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26651657787907268,
                                0,
                                0,
                                0,
                                -0.11230164254112243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74587450578702807,
                                0,
                                -0.5392318877947192,
                                0,
                                0,
                                -0.12982657360188379,
                                -0.048443887233167032,
                                -0.20754242294336678,
                                0,
                                0.083557410538059873,
                                0,
                                0,
                                0,
                                0,
                                -0.16301304552545914,
                                0,
                                0,
                                1.0444343565283021,
                                0,
                                0,
                                0.21777298021754868,
                                0,
                                0,
                                0,
                                0,
                                -0.019721737456367183,
                                0.87903953855933137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90351338655137658,
                                0,
                                0,
                                0,
                                0,
                                0.35728272031505404,
                                0,
                                0,
                                0,
                                0.005168965707295442,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32772381894479241,
                                0,
                                -0.16943882540608463,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22602060680903041,
                                0,
                                0.53363465627678119,
                                0,
                                0,
                                -0.72534078031890947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.043784406649425414,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28449994488511582,
                                0,
                                0,
                                0,
                                -0.29147089539750815,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22435049943897936,
                                0,
                                -0.19108271813872729,
                                0,
                                0,
                                -0.508802009317745,
                                0.049258538201282634,
                                0.068632603512811446,
                                0,
                                0.6937163859894675,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16319916443891824,
                                0,
                                0,
                                0,
                                -0.33796996571771182,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.066693096152579248,
                                0,
                                -0.23203381009723095,
                                0,
                                0,
                                0.016059563113375017,
                                0.64605458815070271,
                                0.51942580481716116,
                                0,
                                -0.33675966170049304,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83007780999505421,
                                0,
                                0,
                                0,
                                0.19703177446395134,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26726401916949871,
                                0,
                                -0.16377657736008033,
                                0,
                                0,
                                0.31648717554947325,
                                -0.25641486604445135,
                                0.085622417115434682,
                                0,
                                0.025545485754197149,
                                0,
                                0,
                                0,
                                0,
                                -0.29151940934995646,
                                0,
                                0,
                                0.31447094256526947,
                                0,
                                0,
                                -0.36296970213782259,
                                0,
                                0,
                                0,
                                0,
                                0.036490194199246262,
                                -0.58154944591776137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.050686832782011429,
                                0,
                                0,
                                0,
                                0,
                                1.0192755126370139,
                                0,
                                0,
                                0,
                                -0.15337848594569137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13664257584298345,
                                0,
                                0,
                                0,
                                -0.40962412594056602,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.062269088608083667,
                                0,
                                0.083055633726037484,
                                0,
                                0,
                                -0.086335798184332263,
                                -0.67916471421235436,
                                0.55985627745660893,
                                0,
                                -0.14353945010992736,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.136425867594831,
                                0,
                                -0.10828483679676036,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87052250634847705,
                                0,
                                -0.23831871405415417,
                                0,
                                0,
                                -0.36809884752749517,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13985839871872724,
                                0,
                                0,
                                0,
                                0,
                                0.10496682566285699,
                                0,
                                0,
                                0,
                                -0.40216103179057133,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0581569378079043,
                                0.48842969424267413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15816850267647209,
                                0,
                                0.82569632700224194,
                                1.0505616601678545,
                                0,
                                0,
                                -0.22471259577690475,
                                0,
                                0,
                                0.48245552696630389,
                                0,
                                0,
                                0,
                                0,
                                0.095488176637141861,
                                -0.23841963422702145,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.057904236159988437,
                                0,
                                0,
                                0,
                                0,
                                0.83141186409061141,
                                0,
                                0,
                                0,
                                0.28724286841988539,
                                0,
                                0,
                                -1.5653010290909499,
                                0,
                                0,
                                0,
                                0.032520483727464647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14525931356497149,
                                -0.67960181184792634,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13252471736492766,
                                0,
                                0.12550655003899536,
                                -0.036160282053786075,
                                0.27816913138817057,
                                0,
                                0,
                                0,
                                0.63323442628285864,
                                0,
                                0,
                                0,
                                0,
                                -0.42071413019232129,
                                -0.020592607512339774,
                                -0.55645311502844041,
                                0,
                                0,
                                0,
                                -0.13226342496819216,
                                0,
                                0,
                                0.12558030131332681,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48062038932816431,
                                0.11836543298534627,
                                0,
                                0,
                                0,
                                -0.2284263208142864,
                                0,
                                0,
                                0,
                                0,
                                -0.30064929558802844,
                                -0.080278256083225502,
                                0.18118038074300541,
                                0,
                                0,
                                0,
                                -0.7569538042533982,
                                0,
                                0,
                                0.013232237843315642,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.78036459532278157,
                                0,
                                -0.25026889645742062,
                                0,
                                0,
                                0,
                                0,
                                -0.38166669662266522,
                                0,
                                0,
                                0,
                                0.33145122237149205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.06747145617171707,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26137100128428614,
                                0,
                                0,
                                0,
                                -0.48364244775214338,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48080146931716972,
                                0,
                                0,
                                0,
                                0.41731276860030247,
                                0,
                                0,
                                -1.120552627154088,
                                -0.19928651853188767,
                                0,
                                -0.17259283367782097,
                                -0.092570728248041106,
                                0,
                                -0.36679861816249482,
                                0,
                                0,
                                0,
                                0,
                                -0.52213702701643117,
                                0,
                                -0.41671958722379893,
                                0,
                                0,
                                0,
                                0,
                                -0.093619618031022006,
                                0,
                                0,
                                0,
                                0.5634784148254175,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43457035354815909,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19645295010525388,
                                -0.23919996072051833,
                                -0.012449213145031321,
                                0,
                                0,
                                0,
                                -0.54463159395930272,
                                0,
                                0,
                                0,
                                0,
                                -0.54427854594931691,
                                0.10182799165473155,
                                -0.12845519499962377,
                                0,
                                0,
                                0,
                                0.1944953596656922,
                                0,
                                0,
                                0.53391718948316202,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16692727721242984,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10646475075925642,
                                0,
                                -0.46968101375708821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.032486780794960812,
                                0,
                                0,
                                -0.36324521523920172,
                                0,
                                1.3329584209290559,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13861870302667789,
                                0.34819129960364847,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29820538620823744,
                                0.024569683505355586,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13782213860731246,
                                0,
                                -0.12426143016729269,
                                0,
                                0,
                                0,
                                0,
                                -0.74809627996582551,
                                0,
                                0,
                                0,
                                -0.1476355399277387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.025456020680309575,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61925103903437106,
                                -0.12073427334624016,
                                0.16159642732698953,
                                0,
                                0,
                                0,
                                -0.2110102071596518,
                                0,
                                0,
                                0,
                                0,
                                -0.37933614085310263,
                                -0.58108835002066583,
                                -0.03300107423832549,
                                0,
                                0,
                                0,
                                0.20576652001660492,
                                0,
                                0,
                                -0.62433645772251267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6363210638482899,
                                -0.0056051028560109989,
                                0,
                                0,
                                0,
                                0.23262761840387358,
                                0,
                                0,
                                0,
                                0,
                                -0.28216255931087836,
                                0.2804736294346255,
                                0.53311707947392684,
                                0,
                                0,
                                0,
                                -0.26802554511439397,
                                0,
                                0,
                                -0.16314348817807509,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20503910289966251,
                                0.046861267920194793,
                                0,
                                0,
                                0,
                                -0.18946343433089996,
                                0,
                                0,
                                0,
                                0,
                                -0.16290341699002991,
                                0.74691830213848076,
                                -0.25143306847846392,
                                0,
                                0,
                                0,
                                0.1110850997739076,
                                0,
                                0,
                                -0.5097878325831452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10335972440613542,
                                0,
                                -0.75081793327553015,
                                0,
                                0,
                                0,
                                0,
                                -0.0029408161405279909,
                                0,
                                0,
                                0,
                                -0.47044716114073248,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35894626430098087,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27462264648417517,
                                0,
                                0,
                                0,
                                0.70362445150529462,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14703663326738156,
                                0,
                                0,
                                0,
                                -0.68266494471716388,
                                0,
                                0,
                                -0.60632677502446652,
                                0.0083642002649235159,
                                0,
                                0.067902542293401758,
                                0.5228751981632821,
                                0,
                                0.223241092575929,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69009362275650166,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.78358470393688695,
                                0,
                                -0.017735417813891735,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70234689553319452,
                                0,
                                0,
                                0.64613411022467138,
                                0,
                                0.21383178700557331,
                                0,
                                0.16413528019739687,
                                0.85344210786963814,
                                0,
                                0,
                                0,
                                0.024079942365864943,
                                0,
                                0,
                                0,
                                0,
                                0.054343591957928136,
                                0.092327478934758275,
                                0.36153104694755317,
                                0,
                                0,
                                0,
                                0.2879708897426479,
                                0,
                                0,
                                0.13786520259196566,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41377642023467431,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20233435386155488,
                                0,
                                0.1473852684068806,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3507972133165419,
                                0,
                                0,
                                -1.4514138458478991,
                                0,
                                0.19103700873857724,
                                0,
                                0,
                                0,
                                0,
                                0.2494808539971487,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13361333793641827,
                                0,
                                0,
                                0,
                                -0.095275314736267158,
                                0,
                                0,
                                -0.1653672971759845,
                                -0.83971398877615744,
                                0,
                                -0.15117134499292981,
                                -0.53206585699109943,
                                0,
                                0.25846890200244504,
                                0,
                                0,
                                -0.47118697899486783,
                                0.38955403128460658,
                                0,
                                0,
                                0,
                                -0.33925632086694124,
                                0,
                                0,
                                0,
                                0,
                                0.42821503856133442,
                                -0.0046867321016862643,
                                -0.40225201817689338,
                                0,
                                0,
                                0,
                                -0.40280788644960425,
                                0,
                                0,
                                -0.060701499702733135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.005424319736037797,
                                0,
                                0.18096534409450715,
                                0,
                                0,
                                0,
                                0,
                                -0.22599453575374046,
                                0,
                                0,
                                0,
                                -0.56083178217001894,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66516605570402032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39896167892263262,
                                0,
                                0,
                                0,
                                1.2032174316439752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.098686788536159184,
                                0,
                                0,
                                0,
                                0.82198903912013122,
                                0,
                                0,
                                0.29748638238484759,
                                0.05682052455604767,
                                0,
                                -0.55725539448720118,
                                -0.21025971701165497,
                                0,
                                -0.9407199389434211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41935905184487005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40118474685704902,
                                0,
                                0,
                                0,
                                -0.5242016091741053,
                                0,
                                0,
                                0.59434792542220827,
                                -0.0396165088134455,
                                0,
                                0.52172047550076783,
                                -0.34264954365314049,
                                0,
                                -0.84509698141270517,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46665789044546213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32495886376555405,
                                0,
                                -0.048301811372608749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.5905157223047655,
                                0,
                                0,
                                -0.22437614004240741,
                                0,
                                0.29031551651404591,
                                0,
                                0,
                                0,
                                0,
                                -0.49683125310606163,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.94629608606520754,
                                0,
                                0,
                                0,
                                -0.04115302522698102,
                                0,
                                0,
                                -0.5021356848672619,
                                0.12819757304440818,
                                0,
                                -0.49979814704957615,
                                0.052058820329583866,
                                0,
                                -0.96613635449322022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28478287871355168,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11864008979981024,
                                0,
                                0,
                                0,
                                -0.57754616866220909,
                                0,
                                0,
                                -0.24716477480400181,
                                0.64548643247496551,
                                0,
                                -0.11460296314495169,
                                -1.0045165525484712,
                                0,
                                0.30485943223141521,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75719932009624735,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70933455231346298,
                                0,
                                -0.87510816610013542,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43778760567515773,
                                0,
                                0,
                                -0.038922773171251035,
                                0,
                                -0.93804619682860346,
                                0,
                                0,
                                0,
                                0,
                                -0.29056376242551807,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3826855272102071,
                                0,
                                0,
                                0,
                                -0.48855481918058036,
                                0,
                                0,
                                0.20271097948868194,
                                -0.049785398860192807,
                                0,
                                -0.8317107485712778,
                                0.13258027660050861,
                                0,
                                -0.0029349000863948885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6749062677954687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56495010897540854,
                                0,
                                -0.71521336044394124,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11708350260973435,
                                0,
                                0,
                                -0.1862550048820043,
                                0,
                                -0.51788034207102673,
                                0,
                                0,
                                0,
                                0.29781945138111721,
                                0,
                                -0.38960664441383508,
                                0,
                                0,
                                0,
                                0,
                                0.48459846999349915,
                                0,
                                0,
                                0,
                                -0.12240543798030279,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48441707145160107,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52443452358393261,
                                -0.20045364574470853,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.9332025425115853,
                                0,
                                0,
                                -1.1026492246436252,
                                0,
                                0,
                                -0.16547542780501101,
                                0,
                                0,
                                0,
                                0,
                                -0.41466706589128582,
                                0,
                                0,
                                -0.099878139414516148,
                                0,
                                0,
                                0.76025748896871959,
                                0,
                                0,
                                -0.058026757471589516,
                                0,
                                0.11205232149123859,
                                0.7413753849035859,
                                0.46396591822633226,
                                0,
                                0.035639326356614931,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27824181111572166,
                                0,
                                0,
                                -0.37928060271489006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25313335382579982,
                                0.35000784310402316,
                                -0.25064551156905623,
                                0,
                                0.10630331343825719,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40423878541176134,
                                0,
                                0,
                                0.75887116982906189,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29889967136494056,
                                0.41498464973460619,
                                0.10268205659562678,
                                0,
                                0.23228932402492236,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75860957575877286,
                                0,
                                0,
                                0.31377747482413199,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.045585005128010822,
                                0,
                                0,
                                0,
                                0.22843475370165681,
                                0,
                                0,
                                -0.026409307863234269,
                                0,
                                -0.21535224786851229,
                                -0.78619105751141227,
                                0,
                                -0.35643960098471028,
                                -0.29030721430024331,
                                0,
                                0,
                                0,
                                -0.26313814179834616,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58411230267872472,
                                -0.27456649417691198,
                                0.32882194527528785,
                                0,
                                0.67816993135074344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12353964987796136,
                                0,
                                0,
                                0.011210957135415811,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.049248717357723383,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.92637245174941918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44126963946707037,
                                -0.55839628271319119,
                                0,
                                0.93450220628549618,
                                -0.31460353600992896,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38375739287920119,
                                0,
                                0,
                                0.23174930825324463,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.005314399256298008,
                                0,
                                0,
                                0,
                                -0.27410953417904571,
                                0,
                                0,
                                -0.021479495840575735,
                                0,
                                0.64396656052712464,
                                -0.36003065609941109,
                                0,
                                0.22104251039227396,
                                -0.38022729799869359,
                                0,
                                0,
                                0,
                                0.43200319181542268,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39885556687583967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87856653127614648,
                                0,
                                0,
                                0.094145196182340657,
                                0,
                                0,
                                0.45948961627203055,
                                0,
                                0,
                                0,
                                0,
                                0.76499471634667149,
                                0,
                                0,
                                -0.80194517389102427,
                                0,
                                0,
                                -0.44405948174738308,
                                0,
                                0,
                                0.44697361272656411,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0031981740443305928,
                                0,
                                0,
                                0.55217668203381975,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.049143298556902956,
                                0,
                                0,
                                0,
                                -0.065010478601970428,
                                0,
                                0,
                                -0.40224047063293034,
                                0,
                                0.04345951387321384,
                                -0.041565544722562409,
                                0,
                                -0.63978931477242329,
                                0.39347393082053117,
                                0,
                                0,
                                0,
                                0.51360748853320048,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66766658825852798,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.047495163741300694,
                                0,
                                0,
                                0.0342812229125702,
                                0,
                                0,
                                -0.92088037567756809,
                                0,
                                0,
                                0,
                                0,
                                -0.38078769616046582,
                                0,
                                0,
                                0.26559198918221194,
                                0,
                                0,
                                -1.1278987320906226,
                                0,
                                0,
                                0.54849545402632105,
                                0,
                                0,
                                0,
                                0,
                                -0.039796490579315447,
                                0,
                                0,
                                0,
                                0.015513522431481967,
                                0,
                                0,
                                0.71042792432062696,
                                0,
                                -0.23704226699167802,
                                -0.30088918953598559,
                                0,
                                0.13049894623659597,
                                0.38872043801666534,
                                0,
                                0,
                                0,
                                0.42262375664876933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63747421696975914,
                                0,
                                0,
                                0,
                                0.090098661618566361,
                                0,
                                0,
                                -0.1287191253849482,
                                0,
                                -0.45509899764475781,
                                0.12123701924063369,
                                0,
                                0.17107611996163982,
                                -0.38844858384275571,
                                0,
                                0,
                                0,
                                0.40861643020231203,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1766721665669326,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17581049871679108,
                                0,
                                0,
                                0.334547713836575,
                                0,
                                0,
                                -0.11111438018806419,
                                0,
                                0,
                                0,
                                0,
                                -0.10679967329632191,
                                0,
                                0,
                                -1.263899816382972,
                                0,
                                0,
                                -0.16381478086845158,
                                0,
                                0,
                                -0.67976421416602373,
                                0,
                                0,
                                0,
                                0,
                                0.11012712764040349,
                                0,
                                0,
                                0,
                                0.85055321128668371,
                                0,
                                0,
                                -0.16086923947335152,
                                0,
                                0.31882663920456239,
                                -0.063209670363680304,
                                0,
                                0.26215436454004015,
                                0.23971907876498427,
                                0,
                                0,
                                0,
                                0.081953050300544353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.75267690753723782,
                                0,
                                0,
                                0,
                                -0.24599164254756722,
                                0,
                                0,
                                0.13252696701991407,
                                0,
                                0.30595761039141611,
                                -0.10666392353332198,
                                0,
                                -0.043131328451735187,
                                0.34959696382640726,
                                0,
                                0,
                                0,
                                -0.35543858417289176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6614573094456766,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.065844199639485956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60848531456637289,
                                0.54269279013140403,
                                0,
                                0.52645360278657105,
                                -0.032059985772694824,
                                0,
                                0,
                                -0.35364401362439485,
                                0.12070294697936085,
                                -0.53750669183370348,
                                0,
                                0.65629988269909711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20312803932848603,
                                0,
                                0,
                                -0.31537712355183767,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27598404628866274,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69369720253488354,
                                0,
                                0,
                                1.2293554613094975,
                                0,
                                0,
                                -0.14965266273498637,
                                0,
                                0,
                                0,
                                0,
                                -0.27127641049720297,
                                0,
                                0,
                                0.27493085887305108,
                                0,
                                0,
                                0.34581682785485479,
                                0,
                                0,
                                0.26367727393670348,
                                0,
                                0,
                                0,
                                0,
                                -0.094186258706817585,
                                0,
                                0,
                                0,
                                -0.2759421544605386,
                                0,
                                0,
                                -0.52184770327271657,
                                0,
                                -0.2801376977381449,
                                -0.36048367372829526,
                                0,
                                0.54578238888862984,
                                0.36694418360916647,
                                0,
                                0,
                                0,
                                -0.041325440435966643,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60644496730885977,
                                0.25629831793297692,
                                -0.56065277493947996,
                                0,
                                -0.20694714806881964,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35659636149231433,
                                0,
                                0,
                                -0.28673341744513819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85104124062576281,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6332240477725708,
                                0,
                                0,
                                -0.3308098170868003,
                                0,
                                0,
                                -0.38690448905990299,
                                0,
                                0,
                                0,
                                0,
                                0.44111501785619889,
                                0,
                                0,
                                -0.25093793707171397,
                                0,
                                0,
                                -0.024129870470674671,
                                0,
                                0,
                                0.5813177431773624,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39872816448928328,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64822776388366243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25262491212112459,
                                -1.2533685103320198,
                                0,
                                0.83727061767168942,
                                0.22038318665901613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6803830844330826,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.065640283267135918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.96427675137736257,
                                0.24233457524936819,
                                0,
                                0.57885816556923353,
                                0.47460097708206761,
                                0,
                                -0.50585846408356061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0062914638927865779,
                                0,
                                0,
                                -0.24053445552640854,
                                0,
                                0,
                                0.92434937133168704,
                                0,
                                0,
                                0,
                                0,
                                -1.0400151164617215,
                                0,
                                0,
                                -0.13384469789066489,
                                0,
                                0,
                                -0.79793883760018258,
                                0,
                                0,
                                0.31280364980238917,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5095311027956313,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62664174948355245,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.98833585864654461,
                                -0.015126246161146356,
                                0,
                                -0.27802420709232678,
                                -1.0892471506481867,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35659672353738087,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1002207223164842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54496160809803751,
                                0.08312912195697153,
                                0,
                                -0.70573464618973225,
                                0.33878746330435783,
                                0,
                                -0.78279643779531194,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68235287925757038,
                                0,
                                0,
                                0.095620091334541135,
                                0,
                                0,
                                -0.55284979842106752,
                                0,
                                0,
                                0,
                                0,
                                0.1980705547637846,
                                0,
                                0,
                                0.15648144461804331,
                                0,
                                0,
                                -0.54559479904637453,
                                0,
                                0,
                                -1.121230968313786};

const double rot_28_2[32]
    = {-1.0562769793030591,   0.41362647694756083,  -2.1851987530020143,   -1.9844642829844008,  0.99643402114734392,
       -0.084375597776456923, 0.084375597776456646, 0.99643402114734392,   0.78700197836896191,  0.61695047292577709,
       0.61695047292577709,   -0.78700197836896191, -0.046028650190207077, -0.998940120008035,   0.99894012000803512,
       -0.046028650190209297, 0.056302119035860354, -0.99841377764535699,  0.99841377764535655,  0.05630211903585991,
       -0.55243932916560157,  -0.83355311024016965, 0.83355311024016943,   -0.55243932916560112, -0.82991114767239216,
       -0.55789558787383609,  0.55789558787383642,  -0.82991114767239182,  0.20351072243833807,  0.9790727173466871,
       -0.97907271734668699,  0.20351072243833804};

const double rot_27_50[25000] = {0.13709404102880324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95012446209428914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10755866202165637,
                                 0,
                                 0,
                                 0,
                                 -0.2067889168979628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86920501693174745,
                                 0,
                                 0,
                                 0,
                                 -0.41389120919450273,
                                 0,
                                 -0.095912410288965022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.431884630059504,
                                 0,
                                 0,
                                 0.12160446007275774,
                                 1.1765124377729856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24473842307170215,
                                 0,
                                 0,
                                 0.16808344315447768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069706557686276094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37762742762506757,
                                 0.42258530991217036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41303060450903101,
                                 0,
                                 0,
                                 0,
                                 -0.31913727624368599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77717462814446359,
                                 0,
                                 0,
                                 0,
                                 1.0742771137388902,
                                 0.011332439261046351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36013023409196548,
                                 0,
                                 0,
                                 -0.40165526466138801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85005516129654268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41975930205187811,
                                 0.43959250901703817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48305339364387173,
                                 0,
                                 0,
                                 0,
                                 0.23070222329580944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71654203136476791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39799662332638308,
                                 0,
                                 0,
                                 0,
                                 -1.3294686368312216,
                                 0.62543032241379104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59346346796535066,
                                 -0.11660023839840249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44246546239988893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085273115478783551,
                                 0,
                                 -0.37582684706429736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19355248522403759,
                                 -0.19849322351319643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095274102719708514,
                                 0,
                                 0.43321539091236988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25005324079498148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44195228522365543,
                                 0,
                                 0.50691681748348116,
                                 0,
                                 -0.25110698401024523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51966901369822827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26275596915709165,
                                 0,
                                 0,
                                 0,
                                 0.46361914726590753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25083656319314707,
                                 0,
                                 0.093595847670356863,
                                 -0.27543913762612149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31577977897566345,
                                 0,
                                 0,
                                 -0.44575548418481581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3816803168912416,
                                 0,
                                 -0.031227615630662203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27040240344088318,
                                 0.26592719051678082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08859062977474233,
                                 0,
                                 0.35648356941081766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3159032281266253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24988528427549148,
                                 0,
                                 -0.1780018822037126,
                                 0,
                                 -0.61697587588736258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98098656047773158,
                                 0,
                                 0,
                                 0,
                                 -0.24502585822229914,
                                 -0.72602281044823014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13185214351931235,
                                 0.16241778687723191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86605431790712994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51535132701406894,
                                 0,
                                 0,
                                 0,
                                 0.22801930720445887,
                                 -0.24986233840902985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10030316582133843,
                                 1.3489493470358154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024377009204573814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36497169404532448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06915260806083566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16249969790504376,
                                 0,
                                 0,
                                 0,
                                 -1.1947746853418386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13793037525260868,
                                 0,
                                 0,
                                 0,
                                 -0.37622787856232803,
                                 0,
                                 -0.070658430464490898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62436651207790317,
                                 0,
                                 0,
                                 0.70558915905978792,
                                 0.53654618336710602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39938645763197944,
                                 0,
                                 0,
                                 0.21679000629838979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16411965518106844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85260134894512452,
                                 0.24497476940137364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27302458317130357,
                                 0,
                                 0,
                                 0,
                                 0.14219436868926288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32274640848552927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28438834866624202,
                                 0.6294117219737102,
                                 0,
                                 0,
                                 0,
                                 0.033422043505225874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55337539769251631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19947982425474431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41932157986068075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81366483929466416,
                                 -0.31195859910963358,
                                 0,
                                 0,
                                 0,
                                 -0.19525996781650315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21292117111321818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08179317299570775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38791669008758839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61666309273377129,
                                 0.30207875125680911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41115592070451484,
                                 0,
                                 0,
                                 0.63614930261693781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0331441418833005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090189741316932248,
                                 0.019912257198859151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11528941451622209,
                                 0,
                                 0,
                                 0,
                                 -0.43765920376851236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32142455916144563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044927954576777937,
                                 0,
                                 0.071193428299077099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44008763449127425,
                                 0.018691248252978174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29961167244283626,
                                 0,
                                 0.37142577912608182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40820026895140027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26140860263082288,
                                 0,
                                 -0.25873309955510715,
                                 0,
                                 0.51890026816431079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74216679920468487,
                                 0,
                                 -0.26371304492670455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25965460217030734,
                                 -0.039071569483429922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1877299289149468,
                                 0,
                                 -0.073710241934837412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056349793739283394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039629109962871008,
                                 0,
                                 -0.45204702803102986,
                                 0,
                                 -0.24683752750451543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22204490537842186,
                                 -0.12546342950337419,
                                 0,
                                 0,
                                 0,
                                 -0.89153290616225145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056233451677359395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3218746390624867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18264331557293539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15673765865926914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16076779112730519,
                                 0,
                                 0,
                                 0,
                                 0.28216516290172988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20385878547625749,
                                 0,
                                 -0.036080232797752521,
                                 -0.40058993281492539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28780828292181754,
                                 0,
                                 0,
                                 0.76407051698978079,
                                 0,
                                 0.16367779552613879,
                                 0.15528199716549776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17604571873596847,
                                 0,
                                 0,
                                 0.66922986142093555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22674382460193043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22489388940129559,
                                 -0.22617637302937407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17031383907317704,
                                 0,
                                 0,
                                 0,
                                 0.99996704401549674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49241881643528584,
                                 0,
                                 0,
                                 -0.53991690474553555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51483869825960171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22600570570562759,
                                 0,
                                 0,
                                 0,
                                 0.22813322779862416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67356900020166954,
                                 0,
                                 0,
                                 0,
                                 -0.45734648823511526,
                                 0,
                                 0.11016212516629595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40916686972047867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32618745712169495,
                                 0,
                                 -0.22959013344767293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.380848100851431,
                                 0.14745462255216379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20857633035440196,
                                 0,
                                 -0.61796282354973886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073322135415487405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49039217009529756,
                                 0,
                                 -0.042896850581203211,
                                 0,
                                 -0.031923018492848385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2462819585022632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16350811563358431,
                                 0,
                                 0,
                                 0,
                                 -0.63376478118847179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10406780341791277,
                                 0,
                                 -0.47007699557011962,
                                 -0.48039929932363734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21091331746894873,
                                 0,
                                 0,
                                 -0.062306431566212711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26786312920567579,
                                 0,
                                 0.056932160295040765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098075160591873684,
                                 -0.26004529568735341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037770045581361093,
                                 0,
                                 -0.2684431179076856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6812054315796372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18049266679249887,
                                 0,
                                 0.51211757868726049,
                                 0,
                                 -0.12407513500637506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35109631308264344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17057874022344383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.99377713336254681,
                                 0,
                                 0,
                                 0,
                                 -0.1741895224460914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047693686994593032,
                                 0,
                                 0,
                                 0,
                                 -0.68740172027984414,
                                 0,
                                 -0.72851561644789575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29446271384857359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42788354773400872,
                                 0.12750095320197691,
                                 0,
                                 0,
                                 0,
                                 0.049279621783795989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5284779501841349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1925806104279123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69415737411942791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35551599680436619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07775176745909862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43266835526025993,
                                 0.45865954248214369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53572882969902436,
                                 0,
                                 0,
                                 -0.31457107195352085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61420413032916665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14053399040459008,
                                 -0.75659280523615724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49282912002021512,
                                 0,
                                 0,
                                 0,
                                 0.027999708889360979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03335460801375266,
                                 0,
                                 0,
                                 0,
                                 0.31201773324859972,
                                 -0.6744829831353456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64631498089246153,
                                 0,
                                 0,
                                 0.19095958336069455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047802904874098787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16470338750917879,
                                 0.40148751125396215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13633942121605414,
                                 0,
                                 0,
                                 0,
                                 -0.53752534437888655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.509685983976646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13493990787501714,
                                 0,
                                 -0.044515634714823338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48576682651319175,
                                 -0.22848866484971458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55972153721179263,
                                 0,
                                 -0.2444456535208627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35590356536172019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43700444504594305,
                                 0,
                                 0.0093355754255750878,
                                 0,
                                 -0.029391108919492315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69389238869708025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51191709862485202,
                                 0,
                                 0,
                                 0,
                                 -0.014166791345119622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092347846259127647,
                                 0,
                                 -0.26868632781575713,
                                 -0.14781216506174022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069487367549695783,
                                 0,
                                 0,
                                 -0.38581879323552332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14070662807095494,
                                 0.68488984721521828,
                                 0,
                                 0,
                                 0,
                                 -0.31893846614227822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4569042218549933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21727809738835327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39170723411702424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17821946310284517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23074878601260243,
                                 0,
                                 0,
                                 0,
                                 0.21595392492605414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71857881423183212,
                                 0,
                                 -0.2570893848654961,
                                 -0.35630874411752883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39553539564919249,
                                 0,
                                 0,
                                 0.050020881787093602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28469889498436485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72504549435827081,
                                 0,
                                 0,
                                 0,
                                 0.46091063326510023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088480217909671866,
                                 0,
                                 -0.30124683714021733,
                                 -0.13756955415969932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15588443518275261,
                                 0,
                                 0,
                                 -0.19751762765977096,
                                 0.59283842340032533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79825284259532769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24603744922018805,
                                 0,
                                 0,
                                 0,
                                 -0.52395311603900196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1038209882778145,
                                 0,
                                 0,
                                 0,
                                 0.58012642851870533,
                                 0,
                                 -0.17507260541881112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0066033932011333174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.154121188481225,
                                 0,
                                 0,
                                 0,
                                 0.066054114143450304,
                                 -0.50197678268028367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1171216838562104,
                                 0.51919657969814714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34827888374586047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3807642807924807,
                                 0,
                                 0,
                                 0,
                                 -0.14588457980504574,
                                 -0.053563657654186629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14533208752763005,
                                 0.5533899513097531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67057762182633573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12970859459747103,
                                 -0.64753483297978343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26765188628870357,
                                 0,
                                 0,
                                 0.7936574810908672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076613552553869535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45645543398179311,
                                 -0.055359329651293795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73201521043726192,
                                 0,
                                 0,
                                 0,
                                 -0.4415780705836605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.186322954064123,
                                 0,
                                 0,
                                 -0.67934153536590425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27260544996652308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70975131052832863,
                                 0,
                                 0,
                                 0,
                                 0.43974509358549724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47748276384612681,
                                 0,
                                 0,
                                 0,
                                 -0.091029759866043336,
                                 0,
                                 -0.81091623551262226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8065941667333999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038169775064592001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10551816672759781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30733520773461059,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16597496193541703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37283403278669303,
                                 0,
                                 0,
                                 0,
                                 -0.41379402630251932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27811055609334778,
                                 0,
                                 0,
                                 0,
                                 0.44072626429306605,
                                 0,
                                 -0.5946112017067906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64680105558539369,
                                 0,
                                 0,
                                 -0.32053924121445276,
                                 0.70621440545950387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55246220531921542,
                                 0,
                                 0,
                                 -0.015565000784375504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29324636170690493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83607582178702611,
                                 0.1176852500313888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26590190855412227,
                                 0,
                                 0,
                                 0,
                                 0.11944221413378603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46446457514454226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13452970009613491,
                                 0,
                                 -0.72122639928778021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0036790909377770811,
                                 0.052394911785664522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28796923890091763,
                                 0,
                                 0.091038982182440845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075158766300631619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4233325167380157,
                                 0,
                                 0.098470284203443531,
                                 0,
                                 0.4161795798577847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069901150415600147,
                                 -0.073831217347389969,
                                 0,
                                 0,
                                 0,
                                 -0.24854650047381605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39651939580950368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87499561723330543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071010254098753417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25464073756285915,
                                 0,
                                 0.25575177090936535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32187115745335915,
                                 0.70960288078473988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13566767163620835,
                                 0,
                                 0.015139104487197692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19978129676856782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13825719948135762,
                                 0,
                                 0.40622412230298299,
                                 0,
                                 0.14117814679385932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6188106898335799,
                                 0,
                                 0,
                                 0,
                                 -0.34792060462859908,
                                 -1.0970396537652061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16938987245099324,
                                 -0.068155397994906941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78988457908977117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12215037939751636,
                                 0,
                                 -0.3737043128074764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36616162649599482,
                                 0.49005331605354985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63127965622712701,
                                 0,
                                 -0.14015297186631723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16195690265504159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099850674607482953,
                                 0,
                                 -0.033988176716678919,
                                 0,
                                 -0.12524188806446326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04582657218912245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06859495904220167,
                                 0,
                                 0,
                                 0,
                                 0.13152955521566009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58883074907090682,
                                 0,
                                 -0.17322561838349329,
                                 -0.16304157695413346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75663266502851745,
                                 0,
                                 0,
                                 0.0095037603382643887,
                                 0,
                                 0.60500030500342028,
                                 -0.076011378532281404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51406956574535145,
                                 0,
                                 0,
                                 0.40964710347851963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3651853029129537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16347405688329147,
                                 -0.48606669848782524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67185378005019192,
                                 0,
                                 0,
                                 0,
                                 -0.34517751328467716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18163979133905783,
                                 0,
                                 0,
                                 0.64329645986176776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38597586321458538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67677271422891083,
                                 0,
                                 0,
                                 0,
                                 -0.21097279433967658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17373939372258246,
                                 0,
                                 0,
                                 0,
                                 -0.77630794952109405,
                                 0,
                                 -0.11572284380870694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21633682266544513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2198186976393971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18076990547187813,
                                 0,
                                 0,
                                 0,
                                 0.16494507521643029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072515304985169213,
                                 0,
                                 -0.71408793997583542,
                                 0.58186356225341418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12204673533186333,
                                 0,
                                 0,
                                 0.15216582220140168,
                                 0.25730746811301497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086942811639401069,
                                 -0.10364910887204296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25075211115162338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40845478038604183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3834834785805617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39974077230432281,
                                 0,
                                 0,
                                 0,
                                 -0.3440121285162277,
                                 0,
                                 0,
                                 0.48815356046233765,
                                 0,
                                 0,
                                 -0.14929246858195427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51203883705422903,
                                 -1.3233667329445102,
                                 0,
                                 0.13080602708739222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10931466884303187,
                                 0.068414943171888898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29708496342567448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56769257525204886,
                                 -0.40359633321197941,
                                 0,
                                 -0.19250865490344832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1602918329462679,
                                 1.0099500816765081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088284278144925746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31761659128905395,
                                 0,
                                 0,
                                 0,
                                 -0.2232682737170231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6789948959185691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018145771425766684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43599904632734676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16022973992814624,
                                 0,
                                 0,
                                 -0.036327158325222153,
                                 0,
                                 0,
                                 0,
                                 -0.41330284392616495,
                                 0,
                                 0,
                                 0,
                                 -0.61964062416914012,
                                 0.17005072338107335,
                                 0,
                                 0.62624397156107203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26416566907455097,
                                 1.0357591106765534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2766548981422976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17325372631905545,
                                 0,
                                 0,
                                 0.20253263184653197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2181339679207408,
                                 0,
                                 0,
                                 0.31433940357657369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0906489332704128,
                                 0.34485384626688476,
                                 0,
                                 0,
                                 -0.57987651482061864,
                                 0,
                                 0.017015478315298732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40307195950413482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23701612543669165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41438863666478309,
                                 0,
                                 0,
                                 0,
                                 0.46931614512466713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23866570664890002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22237471156882113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18885764955033019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62617327496059494,
                                 0,
                                 0,
                                 0.046214256906769668,
                                 0,
                                 0,
                                 0,
                                 0.26779963077437718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00035803150930631411,
                                 0,
                                 0,
                                 0.60073134811739248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19634029708174833,
                                 0,
                                 0,
                                 -0.95378937938381592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024763156055428337,
                                 -0.64957394585262707,
                                 0,
                                 0,
                                 -0.87498165414494211,
                                 0,
                                 -0.20639936743448864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42298713203195021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23590909486260056,
                                 -0.12016750391777463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36839951086095346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53398082439026151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14356495046600523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22458996628937938,
                                 0,
                                 0,
                                 0,
                                 0.16222995393666684,
                                 0,
                                 0,
                                 0.43917582798735516,
                                 0,
                                 0,
                                 0.19972311302578841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076697145750635937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18479898834252423,
                                 -0.29185924568316751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037734406144147165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020049922977338638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36900287462151105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2171349470232346,
                                 0,
                                 0,
                                 0,
                                 -0.53457998618734748,
                                 0,
                                 0,
                                 -0.062475605912442674,
                                 0,
                                 0,
                                 0.63243142550650766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46523950733433028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53743311192165244,
                                 0,
                                 -0.26294036228942536,
                                 0,
                                 0,
                                 0.64321473300515597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10176585050510062,
                                 0.038713509537413704,
                                 0,
                                 0.084331361414332409,
                                 -0.09539091698661098,
                                 0,
                                 -1.0366781261879734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38880282527097282,
                                 0.51340416285274271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1018129174697241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021526423901076425,
                                 0.076622576972494194,
                                 0,
                                 -0.028769716031121214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15693353385777362,
                                 0.3898905120396397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1549098285071138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46084167344526683,
                                 0,
                                 -0.29056548985260061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26219575826801328,
                                 0,
                                 0,
                                 0,
                                 0.26348343191217349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89558900727204893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037886601026965366,
                                 0.53607824428558493,
                                 0,
                                 0,
                                 -0.55503981172437089,
                                 0,
                                 0,
                                 0.268877694236621,
                                 0,
                                 0.30376411548025695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053413985530807201,
                                 0,
                                 0,
                                 1.1476809200523963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10212403899216491,
                                 0,
                                 0,
                                 0.43769065442642791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32686010180784009,
                                 0.38057521333564676,
                                 0,
                                 0,
                                 -0.53089731785769534,
                                 0,
                                 -0.25804835831374306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.005597852344171525,
                                 0,
                                 -0.79370103752135268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40078998883199629,
                                 0,
                                 0,
                                 0,
                                 -0.94157592276108282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8629981043336109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099001478719729391,
                                 -0.73134562592488017,
                                 0,
                                 0,
                                 0.17078015387777787,
                                 0,
                                 0,
                                 0.28888884194517944,
                                 0,
                                 -0.60720384415104345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44391661148073125,
                                 0,
                                 0,
                                 0,
                                 -0.43122423282257488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47572908992032831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10466129063624713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077484566198270377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28701179839364188,
                                 0,
                                 0,
                                 -0.21582283946608702,
                                 0,
                                 0,
                                 0,
                                 0.494724591942513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.984500048304915,
                                 0,
                                 0,
                                 0.31105533867568241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59023502501815961,
                                 0,
                                 0,
                                 -0.13481991518358338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36198836674042112,
                                 0.019680768653545788,
                                 0,
                                 0,
                                 -0.35312924278002367,
                                 0,
                                 0.89693903767879735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29054545793967829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23810999433396168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16171214315793278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.007420788240542979,
                                 -0.67349604332485513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49213994376297404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19547462978722971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41413190278704182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12821982316321584,
                                 0,
                                 0,
                                 0,
                                 0.19424304402264067,
                                 0,
                                 0,
                                 -0.079714937780210007,
                                 0,
                                 0,
                                 0.088061068190888089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79681820716472673,
                                 0.017991345269620374,
                                 0,
                                 0.26582169440140191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96546007422910551,
                                 0.10148750364170206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02924431228535667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50086492656659609,
                                 0,
                                 0.36399471672071182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64602321298585852,
                                 0,
                                 0,
                                 0,
                                 0.22695136435232233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42310656425242976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0031162365765645,
                                 0.13000845465399846,
                                 0,
                                 0,
                                 -0.48105210162062917,
                                 0,
                                 0,
                                 -0.5308128732934454,
                                 0,
                                 -0.17282462870571341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69646997818050416,
                                 0,
                                 0,
                                 0.10906979098102484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0103472818532653,
                                 0,
                                 0,
                                 0.078203275617898346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57584047935143845,
                                 -0.88857617838425884,
                                 0,
                                 0,
                                 0.13489326913377744,
                                 0,
                                 0.49079321386910085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51139825972962683,
                                 0,
                                 0,
                                 -0.72109563879859184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2897101471417361,
                                 0,
                                 0,
                                 0.074039047397442298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53423289150179765,
                                 0.53442168529996237,
                                 0,
                                 0,
                                 -1.0009748047363363,
                                 0,
                                 0.18905752987716856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016732167584370621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41043954543004585,
                                 -0.049938986810838207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41481894186632495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025194953204542257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11247422169723183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51272944720378244,
                                 0,
                                 0,
                                 0,
                                 -0.29116494932200021,
                                 0,
                                 0,
                                 0.50352737214880583,
                                 0,
                                 0,
                                 -0.20541955291615208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25473032592737782,
                                 0,
                                 -0.10819590873309218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2467037071252825,
                                 0,
                                 0,
                                 0,
                                 0.19860502696298996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37681525940405902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3238886808754482,
                                 0.71308305634104108,
                                 0,
                                 0,
                                 0.85654891617527351,
                                 0,
                                 0,
                                 -0.010479149823900025,
                                 0,
                                 -0.51395287865214134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15557024964170585,
                                 0,
                                 0,
                                 0.071522541876432061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0738834739963539,
                                 0,
                                 0,
                                 -0.62678162516221381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51911972715080135,
                                 0.48979589316637406,
                                 0,
                                 0,
                                 0.090580329272008514,
                                 0,
                                 -0.71055913808871596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27518938179917929,
                                 0,
                                 0,
                                 0,
                                 -0.4946369280392246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071907843518059483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47323510679739622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08857631279190456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25501076279660656,
                                 0,
                                 0,
                                 0.51061957428243621,
                                 0,
                                 0,
                                 0,
                                 0.34186884521648164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43015733348835422,
                                 0,
                                 0,
                                 0.34350503404921917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63699609830114401,
                                 0,
                                 0,
                                 -0.52548708683563072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19807224156049119,
                                 0.64949764247103536,
                                 0,
                                 0,
                                 0.35376209009270299,
                                 0,
                                 0.48158215099538149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29242926179960388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29925028840636453,
                                 -0.1048619686005651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29471174978917852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47414776181214763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24130499043796111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49007156204578739,
                                 0,
                                 0,
                                 0,
                                 0.19053230716752223,
                                 0,
                                 0,
                                 -0.21954755207180382,
                                 0,
                                 0,
                                 0.34549286786624228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50304319580986401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26142351854202772,
                                 0,
                                 0.22218334502310277,
                                 0,
                                 0,
                                 -0.37408688738386697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68092265682908604,
                                 -0.16013489438944498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21615834879652693,
                                 0,
                                 0.35742743484465522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65603056267176751,
                                 0,
                                 0,
                                 0,
                                 0.090548635471024499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4996433255806555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88774552197661116,
                                 0.14535749016461591,
                                 0,
                                 0,
                                 -0.15539553410955367,
                                 0,
                                 0,
                                 0.44970447208065339,
                                 0,
                                 -0.8734191838040215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39729719901820626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39239488364379804,
                                 0,
                                 -0.48001757554867802,
                                 0,
                                 0,
                                 -0.15249993389973598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21643700720686579,
                                 -0.62262597936380604,
                                 0,
                                 0,
                                 0,
                                 -0.21764069870977759,
                                 0,
                                 0,
                                 0,
                                 -0.45299669055190334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4394943448873167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41843897385056888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47669698434857288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37727587500092719,
                                 0,
                                 0,
                                 -0.097856738644933799,
                                 0,
                                 0,
                                 0,
                                 -0.0051988985500074913,
                                 0,
                                 0,
                                 -0.13882470946077266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0094110308348170791,
                                 -0.63181818670622902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36822876126443915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12509514507831232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37241921289921109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089381610338615858,
                                 0,
                                 0,
                                 0,
                                 0.012133182334123138,
                                 0,
                                 0,
                                 -0.13929627178738058,
                                 0,
                                 0,
                                 -0.51377805295078971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14147371064623707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43371638803750812,
                                 0,
                                 0.21148642694501324,
                                 0,
                                 0,
                                 0.64636797301681537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48495708200418403,
                                 -0.30687757694858497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71268470179499399,
                                 0,
                                 0.068940800204940617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77789956689285478,
                                 0,
                                 0,
                                 0,
                                 -0.28171575513165326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0883539084408482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67255465644987911,
                                 -0.10825306215212877,
                                 0,
                                 0,
                                 0.23170775798777415,
                                 0,
                                 0,
                                 0.8175749522377771,
                                 0,
                                 0.3064335464432556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33124584259065615,
                                 0,
                                 0.54417605022741311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58923153304443388,
                                 0,
                                 0,
                                 0,
                                 0.44948216743301145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41768631328394562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4526282823604913,
                                 -0.45651679052869898,
                                 0,
                                 0,
                                 0.79610056689674535,
                                 0,
                                 0,
                                 -0.23273847034883016,
                                 0,
                                 0.44765853881769652,
                                 0,
                                 0,
                                 0,
                                 0.78083888110019484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011080352340515489,
                                 0.13311731894376624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22667516940283111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023822791348089185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29218350138175803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090613583303366052,
                                 0,
                                 0,
                                 0,
                                 -0.20830105223544718,
                                 0,
                                 0,
                                 -0.35129206106333055,
                                 0,
                                 0,
                                 -0.24519589852350124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084858824641354205,
                                 0,
                                 0,
                                 0,
                                 0.1837192937325561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11913888692670165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2298683712348539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70934093307069568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53542454501878023,
                                 0,
                                 0,
                                 0.27275583316264385,
                                 0,
                                 0,
                                 0,
                                 0.16665206646237335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32471206404007308,
                                 0,
                                 1.1312703937730111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24597787237236923,
                                 0,
                                 0,
                                 0,
                                 -0.50809034129111652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46117490970875907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28214969988761424,
                                 0.3888565436911775,
                                 0,
                                 0,
                                 -0.60679479274305859,
                                 0,
                                 0,
                                 0.42605238604648943,
                                 0,
                                 0.073451697105889127,
                                 0,
                                 0,
                                 0,
                                 0.036872888760001395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7701536397313391,
                                 0.074749508816629825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29043078765720598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40547308562541923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18732531501037772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28180849600675795,
                                 0,
                                 0,
                                 0,
                                 0.047759726876340225,
                                 0,
                                 0,
                                 -0.072732368798412689,
                                 0,
                                 0,
                                 -0.17052863566352885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62475918585151691,
                                 0,
                                 0,
                                 0,
                                 0.22048197532565358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04551331413421586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35402938745771567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13236402581362611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072691762703855939,
                                 0,
                                 0,
                                 -0.2078919864403963,
                                 0,
                                 0,
                                 0,
                                 0.60632663110139295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3065855826349924,
                                 0,
                                 0.42523962720496744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24428718763285456,
                                 0,
                                 0,
                                 0,
                                 -0.40183512939254096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13380582749480296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094543125101806014,
                                 -0.027514895492169698,
                                 0,
                                 0,
                                 -0.22788586072663181,
                                 0,
                                 0,
                                 -0.50383737180943267,
                                 0,
                                 0.31708544814911388,
                                 0,
                                 0,
                                 0,
                                 -0.081886365585153692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22632451526492769,
                                 0.006784392449475915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16590872200111967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32146727934053398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44116276027325779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3570731152097627,
                                 0,
                                 0,
                                 0,
                                 -0.60409755331461801,
                                 0,
                                 0,
                                 -0.32974614142597686,
                                 0,
                                 0,
                                 -0.12396261877778714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44852076201922847,
                                 0,
                                 0.32598264618210376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14167436684380313,
                                 0,
                                 0,
                                 0,
                                 1.0298658679426138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0595993429438679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69454261775987958,
                                 -0.73783625067362613,
                                 0,
                                 0,
                                 -0.39427379167750093,
                                 0,
                                 0,
                                 0.23266305648014884,
                                 0,
                                 -0.37995783222253426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09858027580217843,
                                 0,
                                 0,
                                 0,
                                 -0.10817819715254823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20271874975178267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60170367828017501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11163865403616403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022947265134338354,
                                 0,
                                 0,
                                 -0.74969458348208839,
                                 0,
                                 0,
                                 0,
                                 0.020136145913209395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49224083612943725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25566658207260573,
                                 0,
                                 -0.69993996242318535,
                                 0,
                                 0,
                                 -0.070026461682084651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43872376465202673,
                                 -0.070960270960410368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33217288880878559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48515393743892676,
                                 0,
                                 -0.34122953339194068,
                                 0,
                                 0,
                                 0.019552908109876664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22689459214064067,
                                 0.6971267906993891,
                                 0.19442556971769775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15525779859253716,
                                 0,
                                 0,
                                 0.31028387352363468,
                                 0,
                                 -0.57635506995031538,
                                 0,
                                 0.63181611206545929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16735576067020938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6119150402690835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37898108707771416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094175239242829945,
                                 -0.21225606572343403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52326118378051323,
                                 0,
                                 0,
                                 1.0256123745252956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040844454739345171,
                                 0,
                                 0,
                                 -0.036186222172474261,
                                 0.45642264142006606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033411400068083491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47997709917776082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21843558299990817,
                                 0,
                                 0.11281181511115984,
                                 -0.6207134742645567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85223463527627674,
                                 0,
                                 0,
                                 0.091391248305537021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22910685946883169,
                                 0,
                                 0,
                                 0.52970660378314494,
                                 0.4734532549820607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020066752945253855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78768246410249965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1718644179614256,
                                 0,
                                 0,
                                 0,
                                 -0.4675553178273365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26735092397005561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5375539729356279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084952730766037099,
                                 0,
                                 -0.60975798170888307,
                                 0,
                                 -0.20476687154556941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64107194638492038,
                                 0.13806579169053296,
                                 0,
                                 0,
                                 -0.42006470332955198,
                                 -0.054133160879030306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2857772447919516,
                                 0,
                                 0.38482092921937516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088731512504870505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2434775138891154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17733333851561042,
                                 0.24944411678116599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23460629083841997,
                                 0.13066349714516395,
                                 0,
                                 0,
                                 0.44025610862895542,
                                 0.14348036086915003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53794177748128702,
                                 0,
                                 -0.3427545957138714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34970844309475208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38126166070640161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14211087908649278,
                                 -0.1369703025432247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12796764599534338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23614279191838536,
                                 0,
                                 0,
                                 0.69007661165107326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30477502066414974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15129892901638653,
                                 -0.06548560325820646,
                                 0.57504474741724798,
                                 0,
                                 0,
                                 -0.0301849059461618,
                                 0,
                                 0.27246587205195122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42722384635738908,
                                 0,
                                 0,
                                 -0.41446441191889261,
                                 0,
                                 -0.080925043621725923,
                                 0,
                                 0.12716492703375937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16797840985902962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35464928668681883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82477462047212602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10640135333007182,
                                 0.34388135543834397,
                                 0,
                                 0,
                                 -0.47035259999215356,
                                 0.62279639091175909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18598333049234378,
                                 0,
                                 -0.39486387184418759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039311444726129151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099177269616004426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24333682609932489,
                                 -0.014691650672761659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41352498435844437,
                                 0.43279268213221167,
                                 0,
                                 0,
                                 -0.38075300590329947,
                                 -0.38503424234073075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28254223015415503,
                                 0,
                                 0.15340333120195593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4453059123049028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07981873810134843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17289411277478256,
                                 -0.10266405292329814,
                                 0,
                                 0,
                                 0.1547181082813186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.93116140029693018,
                                 0,
                                 0,
                                 0.71756557591340597,
                                 0,
                                 -0.26995079285582785,
                                 0,
                                 -0.23367468566400235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44726472448377808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33357359048557295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022827470180714838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18089662543143287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056597437678658449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6305072048733823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41413274699811203,
                                 0,
                                 0.58193851211975589,
                                 0,
                                 0.23743513121298629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081699276042680818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053308160183363179,
                                 0,
                                 0,
                                 -0.07094036272965254,
                                 0,
                                 0.60214756265280767,
                                 0,
                                 0.81428542761667033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14480447300824936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36700005988698992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066932492353585768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16006088710525615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11219863969174261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092122265301872619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22671314429395387,
                                 0,
                                 0,
                                 0.16034348351727945,
                                 0,
                                 -0.058138765309692753,
                                 0,
                                 0.2985548962045339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0180155397175428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44603413611885528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17061501648017391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77205026217624739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012572316475897578,
                                 0,
                                 0,
                                 -0.13824197739664465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.158187615666006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03148559634409516,
                                 0.13834285324512838,
                                 0.40169547998597505,
                                 0,
                                 0,
                                 -0.4220862672547856,
                                 0,
                                 0,
                                 -0.5873921949283738,
                                 -0.068123264141626561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43160351119629631,
                                 0,
                                 0,
                                 -0.23960838766325671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58767804428167691,
                                 0,
                                 0,
                                 -0.52959209983514877,
                                 0.27557943030892024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46120611770270459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85824684821829977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44335897283152492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69632604539961496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2353549602959237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67041295259142397,
                                 0,
                                 0,
                                 0.41049887131301233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05489834032414706,
                                 0,
                                 0.025314547940742976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15775150358624257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4554551196508399,
                                 0,
                                 0,
                                 0.20540835154498166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72259060047460599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23207586659773916,
                                 -0.28669539023271889,
                                 -0.070355802832544001,
                                 0,
                                 0,
                                 -0.24968367325767477,
                                 0,
                                 0,
                                 -0.56797333307715681,
                                 -0.94922485741453777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45219851041287035,
                                 0,
                                 0,
                                 -0.10426945133484897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039470886576338932,
                                 0,
                                 0,
                                 0.42112867173254709,
                                 -0.6663019580868248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.582386245135735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048243884126312822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23994014813458794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23103244659096617,
                                 0.23297537265939586,
                                 0,
                                 0,
                                 0.05589158864940931,
                                 -0.016555720526705286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30625516333838704,
                                 0,
                                 0.1945716683024058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27669459059506152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74456874388814576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35397741973282526,
                                 0.032490600098470462,
                                 0,
                                 0,
                                 -1.030791184797297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078950132397244854,
                                 0,
                                 0,
                                 -0.28380803086090245,
                                 0,
                                 -0.57678248491939055,
                                 0,
                                 0.23326751907963766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23766260088339342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062608907740567876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23510888458256049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26068886870000857,
                                 -0.077323328179583831,
                                 0,
                                 0,
                                 0.036486539586906425,
                                 0.5251297967824049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44417737716048805,
                                 0,
                                 0.50753386900775266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26698673795085714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12413081635201786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086286180566299414,
                                 -0.31614868697723159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2545638127244198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33047145881425166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11063565044945967,
                                 0,
                                 0,
                                 0.78674471798233858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77443484635920012,
                                 0,
                                 -0.73756859259389285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95473498072777618,
                                 -0.099454342011986704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22497454006861742,
                                 0,
                                 0,
                                 -0.038483926082469602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71345987896639562,
                                 0,
                                 0,
                                 -0.16755439684351142,
                                 -0.073057873630131068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34618116738578336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74323669304590378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085679989768639497,
                                 0,
                                 0,
                                 0,
                                 -0.58347748301709768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74153472214903493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04811299254882774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21696580824826575,
                                 0,
                                 0.16968654295430891,
                                 0,
                                 -0.17747602034859608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38174477847583499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0387060549735947,
                                 0,
                                 0,
                                 -0.64094233655362309,
                                 0,
                                 0.60637119790338034,
                                 0,
                                 -0.43001440995902618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099781260872235877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0059056853324091149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86922833725365256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4082946501724436,
                                 -0.47289352256143624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54582063040925921,
                                 0,
                                 0,
                                 -0.065141440056158045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68108015969146096,
                                 0,
                                 0,
                                 0.13047400975525525,
                                 -0.32536548595557369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0238991644692628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14704449499707495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30758300414570949,
                                 0,
                                 -0.023210120950122703,
                                 -0.42261724483946272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098429354998677221,
                                 0,
                                 0,
                                 -0.13120655250550112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58870854468218192,
                                 0,
                                 0,
                                 -1.0733983406781975,
                                 0.058540671433716801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025501728847163466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54681376750642852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1612216243405159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66290410737205685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099202958045657208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97190503356242386,
                                 0,
                                 0,
                                 0.0029868139932135718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52395100995719068,
                                 0,
                                 -0.92851045967575352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053918131395647738,
                                 0.21480273762868346,
                                 0,
                                 0,
                                 0.24025869959467899,
                                 0.35668388280771557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33994907318591566,
                                 0,
                                 0.37749210807246131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54981950696364512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069624421176119472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42822038725479689,
                                 0.13197564051294908,
                                 0,
                                 0,
                                 -0.43606682465537594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54165576590866127,
                                 0,
                                 0,
                                 0.65972616882133461,
                                 0,
                                 0.67031853818237175,
                                 0,
                                 -0.35286193559548829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13182058622467477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52102839851894045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034285293466740613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57649303675444641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89080363786036576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0584923623627307,
                                 0,
                                 0,
                                 -0.50867662418369286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65427982512878613,
                                 0,
                                 -0.026840216638884879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26267643980854549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10582449936530031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37785501880584382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75981811343934069,
                                 0,
                                 -0.041739955019313324,
                                 0,
                                 -0.44492927383045106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16243520785035295,
                                 0.35575981820250435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26787601723649507,
                                 0,
                                 0,
                                 0.27489483292988021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35341623849140952,
                                 0,
                                 0,
                                 -0.18332068754651673,
                                 0.21889435238854027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04403657009011358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27283373240201481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2207923268155527,
                                 0,
                                 0,
                                 0,
                                 0.34542055975317298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037205105358226909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27180754004197799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21427995227304752,
                                 0,
                                 0.29616844462836889,
                                 0,
                                 -0.81962761829485087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36823990716870664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38604803834165352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46894369316607976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60238146121646952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30745369841886261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38854018581571287,
                                 0,
                                 -0.41387350429300046,
                                 0,
                                 0.021115340431899256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08533352667900472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60571138205645836,
                                 0,
                                 0,
                                 0.45316010060572576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059984353796312881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028121589560074781,
                                 0.09940780682544062,
                                 -0.30764985390841215,
                                 0,
                                 0,
                                 -0.55817429439497657,
                                 0,
                                 0,
                                 0.77518577612228357,
                                 -0.65860049376074725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40884798757932639,
                                 0,
                                 0,
                                 -0.27748059854344848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98208243954937124,
                                 0,
                                 0,
                                 -0.063582543048755047,
                                 -0.049447071953585497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.016095025727401485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14249261482840853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75184610792221473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1841273854047889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30338037037950943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75600555645294565,
                                 0,
                                 0,
                                 -0.25855150098158408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051186863044614173,
                                 0,
                                 0.9380654996475668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15986397601764066,
                                 -0.66821782981804112,
                                 0,
                                 0,
                                 -0.2460187606844747,
                                 0.16068438337264729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076122369112995358,
                                 0,
                                 0.047985129153501643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37521021328915022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17878525839307502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30064672386744229,
                                 0.41273626733044838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49161595888897658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12648153677766832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36520532445609682,
                                 0,
                                 0,
                                 1.1618880736983301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48084237746849656,
                                 0,
                                 0.18162478686344494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10637214544190307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27624868309945405,
                                 0,
                                 0,
                                 0.032285706779917968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56714362243154282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60373349308830837,
                                 0.22629288703986974,
                                 0.23656860512456254,
                                 0,
                                 0,
                                 0.34352593803208176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23909696408675252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47945257244221984,
                                 0,
                                 0,
                                 0.18648690234755622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14458023251934485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49180000555711095,
                                 -0.42745544049674411,
                                 0.20653230896193786,
                                 0,
                                 0,
                                 0.43593126802181981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041812927573692031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10916525621463638,
                                 0,
                                 0,
                                 0.24412342272262388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11075848411061169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47185009679353201,
                                 0.79895977338177848,
                                 -0.042715643820682242,
                                 0,
                                 0,
                                 0.22730393539417026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44927141413062555,
                                 -0.082303718501175238,
                                 0,
                                 0,
                                 0.12510371908362702,
                                 -0.10315552003664946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29689126883378475,
                                 0,
                                 0.32253393765613103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24551043318339577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21712894363931518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5714989249153748,
                                 -0.37267325356995495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0043988930416710981,
                                 0.31403087069298485,
                                 0,
                                 0,
                                 0.35377992154269711,
                                 0.025237960514508995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11806743393555964,
                                 0,
                                 0.10345198271315517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13706420537226191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35412328897324796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35515448396179211,
                                 0.69325409130063087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53400806559367975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22726134078294752,
                                 0,
                                 0,
                                 -0.4021452236953032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03912534385608845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30407790064097751,
                                 0.11060464757867723,
                                 0.5549062825575557,
                                 0,
                                 0,
                                 -0.29549679397170647,
                                 0,
                                 0,
                                 0.15754326234996974,
                                 -0.10807916748490276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47450268204014578,
                                 0,
                                 0,
                                 -0.37420444522645385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16548223777339008,
                                 0,
                                 0,
                                 0.7665508377571324,
                                 1.1315118958738655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44026825329327973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10641273039679081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.166749535641039,
                                 0.2996272010585358,
                                 0,
                                 0,
                                 0.20677177284067269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4312328218911578,
                                 0,
                                 0.22879513165417698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69168253306960703,
                                 0,
                                 -0.38824642798572701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32721173449298474,
                                 0,
                                 0,
                                 0,
                                 -0.70927641749940828,
                                 0,
                                 0,
                                 0,
                                 -0.47897223444845438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32003634735301639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81217793552893658,
                                 0,
                                 0.054421463250325292,
                                 0.34392832309032839,
                                 0,
                                 0,
                                 0,
                                 -0.0068215837155735544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52146853512933156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59892526648030842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27967726598317777,
                                 0,
                                 0,
                                 0,
                                 0.23045496490615108,
                                 0,
                                 0.23704141996257139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65482626007881273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3825729986389268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15786490935640352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37642277971559457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26590887986884371,
                                 0,
                                 0,
                                 0,
                                 -0.39998690033145351,
                                 0,
                                 0,
                                 -0.80142279515653347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056163419950577581,
                                 0,
                                 0.38191503771903429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17905748079740136,
                                 0,
                                 -0.12906190669887835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91678638151316461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34125077175837493,
                                 0,
                                 0,
                                 -0.086537490993036786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26198603690346034,
                                 0,
                                 0,
                                 0,
                                 -0.13748882504814469,
                                 -0.13429656423575709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25329846418939012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96513085953150846,
                                 0,
                                 -0.2078413239745085,
                                 0,
                                 0,
                                 0,
                                 -0.0017498999364338186,
                                 0,
                                 0,
                                 0,
                                 0.31100680443632378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69827370451824733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1355963373123138,
                                 0,
                                 -0.050128503833110738,
                                 0.67600118536429255,
                                 0,
                                 0,
                                 0,
                                 0.84621704930451558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73413411351852531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70623011423412374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19679390519654807,
                                 0,
                                 0,
                                 0,
                                 0.26419984304077843,
                                 0,
                                 -0.58174667383343948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21491674532652519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10467531854870117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61296583586173869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23071937980475055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25872133930594482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1838337049769547,
                                 0,
                                 0,
                                 -0.18902185812309588,
                                 0.16763831608904595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17566456161405919,
                                 0,
                                 0,
                                 -0.020438924978972435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051714219609305834,
                                 0.32320738695938367,
                                 0,
                                 0,
                                 -0.54523662120019711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022128399295006141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68277924582951566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62130549438040472,
                                 0,
                                 0,
                                 0,
                                 0.27989665114480805,
                                 0,
                                 0.16426911854387893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12038672846114187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21928029514131098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13570146039069331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65129379180818414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058972045891027704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78111189729695119,
                                 0,
                                 0,
                                 0,
                                 -0.56137032935201647,
                                 0,
                                 0,
                                 0,
                                 0.60926895569642603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14644075082183461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63282765168659449,
                                 0,
                                 0.32759633007455724,
                                 -0.7458434830553633,
                                 0,
                                 0,
                                 0,
                                 0.10363543750513199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.620393590078681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24237277710900756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16747245395566265,
                                 0,
                                 0,
                                 0.12566369535350155,
                                 0.48841145528884372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39361454480869151,
                                 0,
                                 0,
                                 -0.031334206242922789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68459031794489311,
                                 -0.18816724530709661,
                                 0,
                                 0,
                                 0.082315039941776108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21809751756780807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057345550941379039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32282252096682967,
                                 0,
                                 0,
                                 -0.22042094365938814,
                                 0.097962610892158603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27427902210344995,
                                 0,
                                 0,
                                 0.64823890972042797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16379076180825383,
                                 -0.058727394768272725,
                                 0,
                                 0,
                                 0.28007722729076656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4380114728834863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20392955696542281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13965007417454653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11850406598640109,
                                 0,
                                 0,
                                 -0.59269100736813707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3819194926472489,
                                 0,
                                 0,
                                 0,
                                 -0.23151181726787567,
                                 0.061341692355031521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14481302935559043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1410588521587299,
                                 0,
                                 0,
                                 -0.23308381624115507,
                                 0,
                                 0,
                                 0,
                                 -0.29108240073816061,
                                 0,
                                 -0.6380007996348831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063263954273608425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27072039904862877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57744765709149792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087457558942920746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18844486351217055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40140505499845258,
                                 0,
                                 0,
                                 0,
                                 -0.68083200084049555,
                                 0,
                                 0,
                                 0,
                                 -0.12469334440516094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019020697769901992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54915375878167116,
                                 0,
                                 0.41133363445397364,
                                 -0.47579671180842131,
                                 0,
                                 0,
                                 0,
                                 -0.31328220485667824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074172566217305044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77986053504336406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11581857265290664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1698352869576916,
                                 0,
                                 0,
                                 0.20237843868147254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12465248622349465,
                                 0,
                                 0,
                                 0,
                                 -0.39546951332257424,
                                 -0.45832549350730245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1255232925530438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22958034127840704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37678371115918063,
                                 0,
                                 0,
                                 0.31119874683005,
                                 0.062808046714077706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43329054946312551,
                                 0,
                                 0,
                                 -0.0038894179890123226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40441877844200513,
                                 -0.10577073298243532,
                                 0,
                                 0,
                                 -0.52316238278107441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07323578449934616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34012400858739622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045159050852712615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48898239177202468,
                                 0,
                                 0,
                                 0,
                                 -0.26941687874684161,
                                 0,
                                 0,
                                 0,
                                 -0.6648532387806293,
                                 0,
                                 0.078960640420875861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24939955800309505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39079312152414564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41653537132359775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23907424548500172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18322750834115287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22254570596606862,
                                 0,
                                 0,
                                 0.57009369825585354,
                                 0.52988043840924215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29740968464194262,
                                 0,
                                 0,
                                 -0.046800133642573655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18719091173296018,
                                 -0.16407984044083324,
                                 0,
                                 0,
                                 0.025282750690212477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41453220580096917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14004189846359422,
                                 0,
                                 0,
                                 -0.55833080703023774,
                                 0,
                                 0,
                                 0.24114871865274923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35360039145804945,
                                 0,
                                 -0.30367978873736612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13849129028027471,
                                 0,
                                 -0.62743885519049114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91601222955546568,
                                 0,
                                 0,
                                 0.35728191686328004,
                                 0,
                                 0,
                                 -0.28906244790132707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80405194195262197,
                                 0,
                                 0.78577932110088167,
                                 0,
                                 1.0468658546288696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43545854094109038,
                                 0,
                                 0,
                                 0.028715513619017828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31493172322815371,
                                 0,
                                 -0.46604278167211283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44349642072105999,
                                 0,
                                 0.54450375440626875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099072578468465289,
                                 0,
                                 0,
                                 0,
                                 -0.79166396283231966,
                                 0,
                                 0,
                                 0,
                                 -0.13526909106793517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26434949949873304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48032459472061839,
                                 0,
                                 -0.48391272724829881,
                                 -0.18784333726090821,
                                 0,
                                 0,
                                 0,
                                 0.62767156226518628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26383587693379545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56566747374589421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015584921504415428,
                                 0,
                                 0,
                                 1.660331196144373,
                                 0,
                                 0,
                                 -0.061317053495130031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21863348487816694,
                                 0,
                                 0.20171629016855616,
                                 0,
                                 -0.81633991807376605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.532558633566109,
                                 0,
                                 0,
                                 0,
                                 -0.79679323419720904,
                                 0,
                                 0,
                                 0,
                                 0.29219000243171833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17333412042163496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10303181494506365,
                                 0,
                                 -1.2227899488568763,
                                 0.13321700403335576,
                                 0,
                                 0,
                                 0,
                                 -0.23506513188915279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20963180422599328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039861035426831559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0213006200629562,
                                 0,
                                 0,
                                 0,
                                 0.28701722139826369,
                                 0,
                                 0,
                                 0,
                                 -0.51649171628233648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079247070436187367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45749193926000753,
                                 0,
                                 -0.53076952083075235,
                                 -0.32591066090569976,
                                 0,
                                 0,
                                 0,
                                 -0.3993848657883205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35694893524855648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11946584533208496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13155803097761251,
                                 0,
                                 0,
                                 -0.093103610224273603,
                                 0,
                                 0,
                                 -1.0925712647498906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00050307427592391485,
                                 0,
                                 0.44978130857738757,
                                 0,
                                 -0.57786639156849584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53859215169026942,
                                 0,
                                 0,
                                 -0.1322258740969561,
                                 -0.12266397313042156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52498948143984114,
                                 0,
                                 0,
                                 -0.22168703723935121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21695390913788953,
                                 -0.51671192860858828,
                                 0,
                                 0,
                                 0.17076791153988763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063423957569916978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073380992690300254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015167188296651434,
                                 0,
                                 0,
                                 -0.51122940341564294,
                                 0.14719510163844399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24006637024190558,
                                 0,
                                 0,
                                 -0.077425213633687456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23166998385145118,
                                 -0.36675207371212609,
                                 0,
                                 0,
                                 -0.45869323336259288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42261158373591001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27557835850894685,
                                 0,
                                 0,
                                 0,
                                 0.11671421030846511,
                                 0,
                                 0,
                                 0,
                                 0.6787883040198659,
                                 0,
                                 0,
                                 0,
                                 0.32822463827431964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47954131229223107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28019226524147939,
                                 0,
                                 -0.47859944479336342,
                                 -0.62039855550754364,
                                 0,
                                 0,
                                 0,
                                 0.71102626995572316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34746015975250621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70149816616513694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33257246452258599,
                                 0,
                                 0,
                                 0,
                                 0.19199716741273506,
                                 0,
                                 0.17675807733041746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14590736279719727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61739608310196403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038181169612642354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11026458529074715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63655813812636364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3690981156853842,
                                 0,
                                 0,
                                 -0.24459114220090911,
                                 0.23569783845022405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30262438662422675,
                                 0,
                                 0,
                                 -0.15108445306695478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3519631655686461,
                                 -0.44377905993939021,
                                 0,
                                 0,
                                 0.12062309994234274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44839510885994083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31233671240987221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58601256890399567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040558737174457404,
                                 0,
                                 0,
                                 -0.66087331228476887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38661737226915971,
                                 0,
                                 0,
                                 0,
                                 -0.42718576926055457,
                                 0.64008042931035369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22474314841249721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0141718024790485,
                                 0.48881158234264849,
                                 0,
                                 0,
                                 -0.49880135839216855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19038812521527201,
                                 0,
                                 -0.64576595414006399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17529000448275195,
                                 0,
                                 -0.1681444331900934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029225398565850953,
                                 0,
                                 0,
                                 0,
                                 0.19050889605724458,
                                 0,
                                 0,
                                 0,
                                 -0.84367098909779192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64292137406697358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4865254043171095,
                                 0,
                                 0.18632349147586375,
                                 0.14446842649229827,
                                 0,
                                 0,
                                 0,
                                 0.19510509526684872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78130906419723278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.408224741408453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099698675814475834,
                                 0,
                                 0,
                                 -0.084775332471631867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74190367179676209,
                                 0,
                                 -0.27452274174052838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49286731852441812,
                                 0,
                                 -0.3378924820375252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26270180413244881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51207543496203511,
                                 0,
                                 0,
                                 -0.75226981072095001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28671019608118464,
                                 0,
                                 0,
                                 0,
                                 -0.081563552034564057,
                                 -0.70347782578165485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88128863914584776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28504927392783741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37474616354444618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4786357891582752,
                                 0,
                                 0,
                                 0.10481514468717323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072209714655917606,
                                 0,
                                 0,
                                 0,
                                 0.52577287762284264,
                                 -0.66143856335578755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49581776681927636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45268284087631877,
                                 0,
                                 0,
                                 0.46598649169918882,
                                 0,
                                 0,
                                 0,
                                 -0.23202165248335366,
                                 0,
                                 -0.13353828649832106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49908230836141465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23907502248552934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26931429969655624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54940238868645974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17486244525517813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60396804685372818,
                                 0,
                                 0,
                                 -0.039230763438866334,
                                 0,
                                 0,
                                 0.46603987181509421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28936312030004757,
                                 0,
                                 0.79061470534989364,
                                 0,
                                 0.027072162629005421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33261694536004599,
                                 0,
                                 0,
                                 0.3285925075747157,
                                 -0.57126414993054619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045140564191912383,
                                 0,
                                 0,
                                 -0.17145409658252653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25688972810969374,
                                 -0.32094700025598177,
                                 0,
                                 0,
                                 -0.11150056131070341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25969273015490446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41802395410939697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81064411229609834,
                                 0,
                                 0,
                                 -0.72407665949807987,
                                 0,
                                 0,
                                 0.26851292759091017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023127000463273234,
                                 0,
                                 0.049716381144118964,
                                 0,
                                 -1.0094396326539601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76482751271528127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12023030932055329,
                                 0,
                                 0,
                                 -0.99160290201325629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31885986838903879,
                                 0,
                                 0,
                                 0,
                                 -0.077906288551901112,
                                 -0.24996550224478559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32400031140247443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2210420904059994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63237104479391371,
                                 0,
                                 0,
                                 0.51441952083240805,
                                 0,
                                 0,
                                 0.31839970982960714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.6156219217082091,
                                 0,
                                 0.35753467207877088,
                                 0,
                                 0.29927101101441694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47179754888819592,
                                 0,
                                 0,
                                 0,
                                 0.022082659474825794,
                                 0,
                                 0,
                                 0,
                                 -0.42432496134731895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0189948091926981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0073822380624244174,
                                 0,
                                 -0.21601100895458311,
                                 -0.7999453209591163,
                                 0,
                                 0,
                                 0,
                                 -0.13624792144198947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54184065501441092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31340833892697872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20584191475598995,
                                 0,
                                 0,
                                 0,
                                 -0.42578288377182311,
                                 0,
                                 0.3406495772282675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41706812491439399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36090655641613101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0010780212721464913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045653833482073525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59498832730189799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3244567906393479,
                                 0,
                                 0,
                                 -0.17721582328806373,
                                 0.14292583444351675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18953190103577314,
                                 0,
                                 0,
                                 -0.68470324106753777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11237861979631222,
                                 0.34223733309630744,
                                 0,
                                 0,
                                 0.27679675261539982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36299819527644567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.003768369645512748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25322621988827387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0098597732743738245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29511463053559422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82433570662666855,
                                 0,
                                 0,
                                 0.2405910226565284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42572059029427634,
                                 0,
                                 0,
                                 0,
                                 -0.97722315231322177,
                                 -1.0460299487975377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13669424381575343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10833686818400515,
                                 0.42985941236376735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64111331853595055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68252682364143658,
                                 0,
                                 0,
                                 0.34772441955610756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012700212004333272,
                                 0,
                                 0,
                                 0,
                                 -0.57637838884884041,
                                 0.35886350126688038,
                                 0,
                                 0,
                                 0.33456498341292618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37625741843885946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5111079501331387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35430997612781556,
                                 0,
                                 0,
                                 0,
                                 0.00050368643397798868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28545845651715285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33334573074532425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15242546336021343,
                                 0,
                                 0,
                                 0.74666841632810377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27512553137130025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15942702618488946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027690632845774457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035148209571196715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013586669834566982,
                                 0,
                                 0,
                                 0.072571825414154412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86528337785043452,
                                 0,
                                 0,
                                 0.17168957846385657,
                                 0,
                                 0,
                                 0.026330639689180646,
                                 0,
                                 0,
                                 -0.088538542240586909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12004509191358552,
                                 0,
                                 0,
                                 0,
                                 0.38016807662368923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050469491439063874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21526253977543774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57931973713200002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23527218055121712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8590091964421237,
                                 0,
                                 -0.23097034709141662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48628189362116464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19737616574226763,
                                 0,
                                 0,
                                 0,
                                 0.66737755469917037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23106865616222982,
                                 0,
                                 0.32485799966779361,
                                 0,
                                 0,
                                 0,
                                 -0.82217292631518357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0044854875632427196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38990764330917999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22115966936596679,
                                 0,
                                 0,
                                 -0.030018949735705777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12118962875590981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044172463835231206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062077240304032333,
                                 0,
                                 0,
                                 -0.2460505722763186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12710941037446921,
                                 0,
                                 0,
                                 -0.34429516728853049,
                                 0,
                                 0,
                                 -0.029064276628015868,
                                 0,
                                 0,
                                 0.21804416437264937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6396907157397369,
                                 0,
                                 0,
                                 0,
                                 0.46783343927931975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22653795611747637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27042520893670385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27776381810056106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27191823169518375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19912569090442286,
                                 0,
                                 0,
                                 0.59975487813165396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15332927895016779,
                                 0,
                                 0,
                                 0,
                                 0.72796614758252165,
                                 0.80132789545400973,
                                 0,
                                 0,
                                 0.1750153467886803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12296201608069027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22380158638238556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53206012708276484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051453183050656964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74365894961322487,
                                 0,
                                 0.28761537831623474,
                                 0,
                                 0,
                                 0.14367266515959881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24056499584254279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47916340364700333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9876837319609354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63443604700855794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30713475521123285,
                                 0,
                                 0,
                                 -0.44272349609793427,
                                 0.4047610744882858,
                                 0,
                                 0,
                                 0,
                                 -0.3007338349162923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20775476316923319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26333589433741356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79590571179223224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39395936245975866,
                                 0,
                                 -0.5678790806230829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3303406254754242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79849766532652566,
                                 0,
                                 0,
                                 0,
                                 0.17532918875957965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82493804350186706,
                                 0,
                                 -0.31060092222132313,
                                 0,
                                 0,
                                 0,
                                 0.0095812962714984518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078563448569295147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21415027803847475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29144990783867519,
                                 0,
                                 0,
                                 -0.0798355806871201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57802835781968465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65266312725281161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59189946603593768,
                                 0,
                                 0,
                                 0.14278815490344166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15431643746449786,
                                 0,
                                 0,
                                 -0.014235250346788696,
                                 0,
                                 0,
                                 -0.088254652068595854,
                                 0,
                                 0,
                                 -0.10321979944075763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18586970889753285,
                                 0,
                                 0,
                                 0,
                                 -0.097065150675307785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50005695203494593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54109241507654238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093551022798192218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55720605124917999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70157175833796837,
                                 0,
                                 0,
                                 -0.44258095967740013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19042140024644255,
                                 0,
                                 0,
                                 0,
                                 -0.71375449199307384,
                                 -0.22821146543868032,
                                 0,
                                 0,
                                 0.52338659579380997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040894084076859016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61778958234793002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11875386861364094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79318204898509992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23047592859657798,
                                 0,
                                 0.43590053536780154,
                                 0,
                                 0,
                                 -0.2369077257685975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23980420123893428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14058308057734889,
                                 0,
                                 0,
                                 0.070832344639131448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19296419372556078,
                                 0,
                                 0,
                                 -0.68178291855558082,
                                 0,
                                 0,
                                 -0.38314690908344273,
                                 0,
                                 0,
                                 0.28644341726062084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41143729858939115,
                                 0,
                                 0,
                                 0,
                                 0.10669685941379442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25163971221235742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017811452501874443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56533928482032281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54931052441858563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45954414377787778,
                                 0,
                                 0,
                                 -0.60750733727029937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22603337604219653,
                                 0,
                                 0,
                                 0,
                                 -0.42523226225919863,
                                 0.49928013523808784,
                                 0,
                                 0,
                                 -0.47684727861492471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.682434386808631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10002540501645471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1535643354520679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40755971485890641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23791679979055069,
                                 0,
                                 0.059750737354143157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45420026684958392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49553708811205427,
                                 0,
                                 0,
                                 0,
                                 -0.41560737241304557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72862036775165451,
                                 0,
                                 0,
                                 0,
                                 -0.07543538496362448,
                                 0,
                                 0,
                                 0.0052872426109932258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057765314821565071,
                                 0,
                                 0,
                                 0.41487312488363465,
                                 0,
                                 0,
                                 0.11495715447755873,
                                 0,
                                 0,
                                 0.3795981677356649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46932164118952607,
                                 0,
                                 0,
                                 0,
                                 0.44494218562386156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05366657506735048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49030463732657276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085588038638346214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76903282653885496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90124074374215757,
                                 0,
                                 0.57477208218136422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065801622674560897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35734961838522528,
                                 0,
                                 0,
                                 0,
                                 -0.23913900850152214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23785178293534825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084105616798040406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31745220605919783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096949362629548841,
                                 0,
                                 -0.67371822328971931,
                                 0,
                                 0,
                                 0.28403883022057691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59006513344815259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56504576592942157,
                                 0,
                                 0,
                                 0.11975864184652113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09446902811837582,
                                 0,
                                 0,
                                 -0.29929030421982095,
                                 0,
                                 0,
                                 0.11001225876987343,
                                 0,
                                 0,
                                 -0.32640025135272055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31759128648199358,
                                 0,
                                 0,
                                 0,
                                 0.23824156419246495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5394579331690954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02457876430360138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62583027297309679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032282278820722883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086365231715807733,
                                 0,
                                 0.48332017467276228,
                                 0,
                                 0,
                                 0.57487666485263778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18908675156512672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97945852171907744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17277647397485746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1356341737931705,
                                 0,
                                 0,
                                 0.8155094475535839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61391468338562349,
                                 0,
                                 0,
                                 0,
                                 -0.17771335630114424,
                                 -0.41077014768152165,
                                 0,
                                 0,
                                 0.1077092620242274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2817035358147788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18355546645002563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12777061103531093,
                                 0,
                                 0,
                                 0,
                                 0.23721358254742819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34051757250457593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2768280936419798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12854268021677806,
                                 0,
                                 0,
                                 -0.5587146676800665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57680795617367342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27097169183035819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55142261872164433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10727379755080717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.553994446158524,
                                 0,
                                 0.073610763151629371,
                                 0,
                                 0,
                                 0.60973569874222977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017872178777359429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0057946582758574144,
                                 0,
                                 0,
                                 0.29869162111364628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25271474678450623,
                                 0,
                                 0,
                                 -0.21932826079783596,
                                 0,
                                 0,
                                 0.5447420557919127,
                                 0,
                                 0,
                                 0.46727808572587576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070940830835437757,
                                 0,
                                 0,
                                 0,
                                 -0.43178286165439922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26133200994477468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15467362708975055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22536738491837205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88050465215016427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048313029343809905,
                                 0,
                                 0,
                                 0.012372362207744347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58726456730501664,
                                 0,
                                 0,
                                 0,
                                 0.035376042092333915,
                                 0.4719229547602567,
                                 0,
                                 0,
                                 -0.52086491282754865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18755406467302232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81513877531554391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57051328702305482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46340052817518518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30204135825861678,
                                 0,
                                 0,
                                 0.035927009819111816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67563314793985463,
                                 0,
                                 0,
                                 0,
                                 -0.40860741357519637,
                                 -0.50497633789057905,
                                 0,
                                 0,
                                 0.37051435596806909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42947896482979303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27347654381881348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51339491523567937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4596207215655656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.98037660577390495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10179240899153906,
                                 0,
                                 0,
                                 0.40984277700744809,
                                 -0.67181676643348109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52158002941965831,
                                 0,
                                 0,
                                 -0.094778135754445603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077838507885473252,
                                 0,
                                 0,
                                 0.22460604063693029,
                                 0,
                                 0,
                                 -0.3018099945888193,
                                 0,
                                 0,
                                 0.61613797980233243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078478226714547933,
                                 0,
                                 0,
                                 0,
                                 -0.034051215161387684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061922616591856973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42496665791171589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37778592901002811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52259215632575906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35237690122796622,
                                 0,
                                 0,
                                 0.02101011833390462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52075077963741823,
                                 0,
                                 0,
                                 0,
                                 0.19624219357945538,
                                 -0.56054210814875638,
                                 0,
                                 0,
                                 0.24122647920790638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76964891431978422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26701827783553667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66745841297105879,
                                 0,
                                 0,
                                 0,
                                 0.22848396089493508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034218816952540684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26045156273082298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15446048044833668,
                                 0,
                                 0,
                                 0.29121431377468593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19529955860661213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53524075745950828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19743410014254004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14386234327668249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61827884409621858,
                                 0,
                                 0.015429544198702211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3924382186778459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0369000209921315,
                                 0,
                                 0,
                                 0,
                                 -1.1476094122214291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24277191747312155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32759278417580118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0346319440237584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88640011208481562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29912727934650468,
                                 0,
                                 0,
                                 0.37801763401987426,
                                 0.42032344331167715,
                                 0,
                                 0,
                                 0.019659862026373556,
                                 0,
                                 0,
                                 0,
                                 0.12146083230407025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48218324167138948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10273654855585833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76088232832872316,
                                 0,
                                 0,
                                 0.1518880755845487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14064100044088976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34642962201647343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10935774788040654,
                                 0,
                                 0,
                                 0.048156453997324766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21470523237173028,
                                 0,
                                 0,
                                 -0.13641930494195503,
                                 0,
                                 0,
                                 0.61504595073850954,
                                 0,
                                 0,
                                 0.056852868861395317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0097436374109059788,
                                 0,
                                 0,
                                 0,
                                 0.36971636652969903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51542922469140662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37019871598205922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0023130226049496647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5048654185256416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26473427141118266,
                                 0,
                                 -0.18535084928843004,
                                 0,
                                 0,
                                 0.37455845414467392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70737002462681897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23659990411334442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00018811626002661341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54639346662432287,
                                 0,
                                 0.56847474779548934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10440836798416396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96717074834852912,
                                 0,
                                 0,
                                 0,
                                 0.63534772660610273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47175169934133576,
                                 0.54935068872051773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40034460127353622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57677147916420546,
                                 0,
                                 0,
                                 0.11002836418270581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099601538005455265,
                                 0,
                                 0,
                                 0,
                                 -0.86854599431070167,
                                 0.50225574632998382,
                                 0,
                                 0,
                                 -0.059555246417669447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033709183617259164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36694568568656366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37335449986922936,
                                 0,
                                 0,
                                 0,
                                 -0.44205235006458793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16736867897804142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73193811025495348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030410028417329069,
                                 0,
                                 0,
                                 -0.033065755151847176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19714875965750975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24609900011322086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12979830941115875,
                                 0,
                                 0,
                                 -0.89100957176519935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21399997347676736,
                                 0,
                                 0,
                                 -0.08997529580564663,
                                 0,
                                 0,
                                 0.22899559283646564,
                                 0,
                                 0,
                                 -0.0086341964727237874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2003580909064076,
                                 0,
                                 0,
                                 0,
                                 -0.19177991374223066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032600711024847392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06973924462038561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0328543622005899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21184987288211021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33508816568191357,
                                 0,
                                 -0.082553825846653356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55487927929778602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47108342088255772,
                                 0,
                                 0,
                                 0,
                                 -0.19911687936573935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1745859855411125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68572541767747852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52347753384395634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97420664125807166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37808133403398536,
                                 0,
                                 0,
                                 -0.12098285339520287,
                                 -0.48568549095632485,
                                 0,
                                 -0.37877419482736346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31617366349108145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59463054559287698,
                                 0,
                                 0,
                                 -0.71086723605206192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24054313453031761,
                                 0,
                                 0,
                                 0,
                                 -0.096637065837537339,
                                 0.49880009306159734,
                                 0,
                                 0,
                                 0.663538636281369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029969116861923065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94419800711507773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26618157927574593,
                                 0,
                                 0,
                                 0,
                                 0.072810755958273091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73122160572800554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015339696471841302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47187273913340516,
                                 0,
                                 0,
                                 0.1186601477942279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38210649443479178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078588370632740018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.9129470456574692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32507049879765487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36807649298148765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2206289742148373,
                                 0,
                                 0,
                                 -0.47610557644285595,
                                 0.59997424533400934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37137953306319277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13613231022944056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47978512069348717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31362451410137421,
                                 0,
                                 0,
                                 -0.85749654355206928,
                                 -0.57946910638450899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12655896817581069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16485769560730862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10764337912396157,
                                 0,
                                 -0.44608026020315328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62507010907127991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37649553604700942,
                                 0,
                                 0,
                                 0,
                                 0.54023303558802183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8705167704519805,
                                 -0.12298873168557825,
                                 0,
                                 -0.53951997975577592,
                                 0,
                                 0,
                                 0.40172226470147654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10809835816365315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11691211457203797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36898492106565273,
                                 0,
                                 0,
                                 0,
                                 -0.14937605178222085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59041884368180908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050509142107087901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071771516739834756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53812492122544497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094602249629413798,
                                 0,
                                 0,
                                 0,
                                 0.26822251891386101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51921111512099716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019319122869426778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33349407948086346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29654639351854295,
                                 0.390787493000821,
                                 -0.72928994748088283,
                                 0,
                                 0.26381520974665867,
                                 0,
                                 0,
                                 0.094477463361746908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42203923067003329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05853395385636527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23286775009066196,
                                 0,
                                 0,
                                 0,
                                 0.23026255094490239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31752188766734474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0870685753045843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12665212542607457,
                                 0,
                                 0,
                                 0,
                                 0.057841330551645607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53936495992396671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39233519014296153,
                                 0,
                                 0,
                                 0,
                                 0.35422454226455113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25294885909892512,
                                 0,
                                 -0.70985597451936044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55555344603126344,
                                 0,
                                 0,
                                 0.27113183998270535,
                                 0,
                                 0.19991782549129899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051735325349884037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20842165906863824,
                                 0,
                                 0.11941638733455504,
                                 0,
                                 0,
                                 -0.45262138239075778,
                                 0,
                                 0,
                                 0.37582482856021804,
                                 0,
                                 0,
                                 0,
                                 0.11620538278126268,
                                 0,
                                 0,
                                 0,
                                 0.84665251011142584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056358068045792978,
                                 0,
                                 -0.62547912000496952,
                                 0,
                                 0,
                                 -0.11527365410272547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36415706184956764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30420443473341097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14683200878601951,
                                 0,
                                 0,
                                 0,
                                 0.47213743365450983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35026778956303084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082480502060155128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38655342407497523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066592858084354722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22786732686497285,
                                 0,
                                 0,
                                 0,
                                 -0.29879336364424364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1428675638916605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26623908121522538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52233075664126749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49693919254103097,
                                 -0.29506854451485748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31671175649944133,
                                 0,
                                 0,
                                 0.48469028623802901,
                                 0,
                                 0.3652017418426689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69028790340233659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53213006781842687,
                                 0,
                                 -0.20449176972255001,
                                 0,
                                 0,
                                 -0.47273334479737883,
                                 0,
                                 0,
                                 -0.054191539471971847,
                                 0,
                                 0,
                                 0,
                                 -1.394724187977032,
                                 0,
                                 0,
                                 0,
                                 0.18765365837554054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089304192416948106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15010909857263277,
                                 0,
                                 0,
                                 0,
                                 0.23275332792127057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39774262651313952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.98310300536160899,
                                 0,
                                 0,
                                 0,
                                 -0.10623600460643882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023049199970429368,
                                 0,
                                 0.27524305010599714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1656908798546723,
                                 0,
                                 0,
                                 -0.32240335554729649,
                                 0,
                                 -0.27733862927900399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011960284371730329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55702598907466472,
                                 0,
                                 0.63805335321833812,
                                 0,
                                 0,
                                 -0.47793137944615732,
                                 0,
                                 0,
                                 0.077616899277451523,
                                 0,
                                 0,
                                 0,
                                 0.040222255547060659,
                                 0,
                                 0,
                                 0,
                                 0.29993877444918915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29382066057534928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76141844599929143,
                                 0.53246331690303506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13142183672421312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17669728920198366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043595349343846811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022059545088543991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60697715580039058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39666015939592897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33966208244084617,
                                 0,
                                 0,
                                 0,
                                 -0.016947264197057041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43299077290555277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055037062260811821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17076913196604476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33737683620667253,
                                 -0.15684378552629635,
                                 0,
                                 0,
                                 0,
                                 0.034375580822999977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30005814521444285,
                                 0,
                                 0,
                                 0,
                                 -0.33080613552797267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061840864467205992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16169058851515195,
                                 0,
                                 0,
                                 0,
                                 0.70478809706405088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80243346014465433,
                                 0,
                                 0.51343824489747591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13003801547772337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69661609321858309,
                                 -0.43876015840462074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11649957095327729,
                                 0,
                                 0,
                                 -0.23182306366257849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1348510880649763,
                                 0,
                                 0,
                                 0,
                                 -0.3724369069437472,
                                 0,
                                 -0.42791789020933346,
                                 0,
                                 0,
                                 -0.33374001514501428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10315538026364546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012524213713401677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42372635028822248,
                                 0,
                                 0,
                                 0,
                                 -0.59641468035046619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14402170879201165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27986870773915923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50841220345492855,
                                 -0.61586501641773062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048667305948095846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27809247559425943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4518814974182026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54449293997240467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10657627700349048,
                                 -0.28672410281772798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30968795493160628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66463120257949515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26891812785988256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0324625572141512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3985487827622215,
                                 0,
                                 0,
                                 0,
                                 -0.86946460972569906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67107925290446468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14488486976814918,
                                 0,
                                 0,
                                 0,
                                 -0.014972306199794005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43095759479872009,
                                 0,
                                 -0.49948304687466216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16122899141202299,
                                 0,
                                 0,
                                 -0.074113806306309579,
                                 0,
                                 -0.45353695122783549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0089913289435675156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50734270640590595,
                                 0,
                                 -0.366082548723274,
                                 0,
                                 0,
                                 0.029743227547916008,
                                 0,
                                 0,
                                 0.9498300353171335,
                                 0,
                                 0,
                                 0,
                                 -0.69910288360927475,
                                 0,
                                 0,
                                 0,
                                 -0.14381753808656081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80077765560394698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82705155438229117,
                                 -0.013873405626564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3528090263716408,
                                 0,
                                 0,
                                 -0.47122952710059485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76536549159912293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53310642304410893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0091533641633259055,
                                 0.74241897021921244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1386103483138248,
                                 0,
                                 0,
                                 0.68687358854444813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32201860661837678,
                                 0,
                                 0,
                                 0,
                                 -0.072906944873164486,
                                 0,
                                 0.029682742870659234,
                                 0,
                                 0,
                                 0.072010169558147527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50475302992226234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67121191402444946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3159444862565805,
                                 0,
                                 0,
                                 0,
                                 -0.25965417965514581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34069896021671864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19813367602636567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33373139188092643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12986169582745355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.074416927444638348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19174137402320302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16268991816309591,
                                 0,
                                 0,
                                 0,
                                 -0.31542003833801341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33338360870133921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29264104570831556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37951974491534779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3419893846884059,
                                 0.59757853717565046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069091404324277891,
                                 0,
                                 0,
                                 -0.20889473861672347,
                                 0,
                                 -0.41061080357434532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63613506073862469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31931497332361547,
                                 0,
                                 -0.32182789696847625,
                                 0,
                                 0,
                                 0.40926347145177833,
                                 0,
                                 0,
                                 -0.51271631011627261,
                                 0,
                                 0,
                                 0,
                                 -0.2739900378597615,
                                 0,
                                 0,
                                 0,
                                 0.56549935146988373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67941265514786664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29410059048520654,
                                 0.47220179037455801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10055694114438918,
                                 0,
                                 0,
                                 -1.3512063485427679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059725218573927652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0083846135002820787,
                                 0,
                                 0,
                                 -0.49521922221983805,
                                 0,
                                 -0.77577555027128919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54148269004465366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24896648699544474,
                                 0,
                                 -0.55116325240382591,
                                 0,
                                 0,
                                 -0.62665652959234464,
                                 0,
                                 0,
                                 -0.45351591489648624,
                                 0,
                                 0,
                                 0,
                                 -0.13803162816337675,
                                 0,
                                 0,
                                 0,
                                 -0.25942691080027153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43111882966549547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10295064213725669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31809146512602626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49506327813109141,
                                 0,
                                 0,
                                 0,
                                 -0.041363572267580057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33099987498754418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57817972557056585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037249881803110382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050416703200182655,
                                 0.088175026975751414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64556514374906204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72732951220699182,
                                 0.2458909189750593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053382275953927388,
                                 0,
                                 0,
                                 -0.36093812261082719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21314352349848015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11965717679985999,
                                 0,
                                 0,
                                 0.7754549003713278,
                                 0,
                                 0.22795973528603269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66201029910320952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019094400896434216,
                                 0,
                                 -0.36905703419852876,
                                 0,
                                 0,
                                 0.50222830406736285,
                                 0,
                                 0,
                                 -0.00041516703790793474,
                                 0,
                                 0,
                                 0,
                                 -0.28248367475124875,
                                 0,
                                 0,
                                 0,
                                 0.48099931290560782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19091144425846771,
                                 0,
                                 0.11069461845530026,
                                 0,
                                 0,
                                 -0.76593831727334483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12184407499759432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026738878209008273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54305684972869095,
                                 0,
                                 0,
                                 0,
                                 0.048103554165070402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22771116759658469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55413054123730365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0024775872456593295,
                                 0.47003699736673343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070558627341931607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4000970501754974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55402369668133089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11873400426062933,
                                 0,
                                 0,
                                 0.062068436140029659,
                                 0,
                                 -0.88898341621603649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3783972342261181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0092970844409025373,
                                 0,
                                 0.71308360509872593,
                                 0,
                                 0,
                                 -0.076167044915175994,
                                 0,
                                 0,
                                 -0.25651136676177011,
                                 0,
                                 0,
                                 0,
                                 -0.6543491882600162,
                                 0,
                                 0,
                                 0,
                                 -0.33248609386020311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3168258546576217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17420697170805374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0034815447589667259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17088564631411915,
                                 0,
                                 0,
                                 0,
                                 0.63219342054913696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22175656679113834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37516189048961746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22923661059549491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37510063094508567,
                                 -0.23920375542538619,
                                 0.37150054798188109,
                                 0,
                                 -0.20932237626417191,
                                 0,
                                 0,
                                 -0.32369819902669095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19679136340438966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46803986615548271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4580381604440531,
                                 0,
                                 0,
                                 0,
                                 0.28249719508654281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40742997301993172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15529433648749549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71683250299966128,
                                 0,
                                 0,
                                 0,
                                 0.23466399939985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025491865833514538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026336996938947976,
                                 0,
                                 0,
                                 0,
                                 -0.77310305259042833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.9459858533591291,
                                 0,
                                 -0.70527193043061276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10252329753721978,
                                 0,
                                 0,
                                 0.84550810542645594,
                                 0,
                                 -0.75085097268184442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39428927988827367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082390422458372026,
                                 0,
                                 -0.35043621306521183,
                                 0,
                                 0,
                                 -0.22674393146184008,
                                 0,
                                 0,
                                 0.078553299886736649,
                                 0,
                                 0,
                                 0,
                                 0.48990732716526575,
                                 0,
                                 0,
                                 0,
                                 -0.096096854785807373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35828595126727647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38776185060138824,
                                 0.15472387434736029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29253110617993866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53264471163047133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57275440647703901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76265111234846561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24602538434795537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30216194894273435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16484251342996914,
                                 0,
                                 0,
                                 0,
                                 0.29130544403612851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24589045065480247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040553190627853952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24347586101344781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04908844696698049,
                                 -0.17522610030195773,
                                 0,
                                 0,
                                 0,
                                 -0.55591022210900132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0596623558981246,
                                 0,
                                 0,
                                 0,
                                 -0.26342219945743761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5024341432905457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31548762714555612,
                                 0,
                                 0,
                                 0,
                                 0.24488082037740166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71483490577627051,
                                 0,
                                 0.14168697170986347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2715194486968478,
                                 0,
                                 0,
                                 -0.6329159658183684,
                                 0,
                                 0.0022211011041205625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29544943355358272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88979246788851074,
                                 0,
                                 0.43875130636415238,
                                 0,
                                 0,
                                 0.64522193800763772,
                                 0,
                                 0,
                                 0.43317252260452943,
                                 0,
                                 0,
                                 0,
                                 0.050656321416080369,
                                 0,
                                 0,
                                 0,
                                 0.40824456509885587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36242130674615902,
                                 0,
                                 -0.089619502582230254,
                                 0,
                                 0,
                                 0.091625997840232135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5988303549647761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46894181112856564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063154282554829883,
                                 0,
                                 0,
                                 0,
                                 0.44328638082330374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27060732180205999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11447290654529033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3314807309165006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25970876242748775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024232012290616382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55881737399205234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085364613335406681,
                                 0,
                                 0,
                                 0,
                                 -0.2203638106159021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25581615126321977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1944184876089638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5122075810708735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087507752805843678,
                                 -0.43656078626625267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32162227000044868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0059234643436892748,
                                 -0.10053919823721991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89101077252681515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076941335946409534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29427152715085142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3928155313423571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020373942201019016,
                                 0,
                                 0,
                                 0,
                                 0.013269197203528607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13473553979903863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24627365832641618,
                                 0,
                                 0,
                                 0,
                                 -0.55580338972256782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13057809661543093,
                                 0,
                                 0.72773117503180762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18205934121277451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27272253476446373,
                                 0.94445379735141743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0110003803561638,
                                 0,
                                 0,
                                 0.11878907517873699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26176259006992703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23998564363684477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15996703482191543,
                                 0,
                                 0,
                                 0,
                                 -0.76503561335053061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65709261962621501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71476613451904591,
                                 0,
                                 0,
                                 0,
                                 -0.44782607848650802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015058559386121606,
                                 0,
                                 0.24869482532462922,
                                 0,
                                 0,
                                 0,
                                 -0.082809745595793391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40403283455293548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01015274492328206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67142526247117429,
                                 0,
                                 0,
                                 0,
                                 -0.31273070401911807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31297462328087883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2758203650334381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2559824982856222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20370997162587653,
                                 -0.011392082069108737,
                                 0,
                                 0.17638091701067626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45404959828050484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083706889861610956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19423426060843046,
                                 0,
                                 0,
                                 0,
                                 0.32619498119046797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1696732542432024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49951720768321672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040667292039251637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48941234587603566,
                                 0.30349143372213289,
                                 -0.081164399053391012,
                                 -0.3146077131380286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20992618529999627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36982121604890561,
                                 0,
                                 0,
                                 0.34301009843738112,
                                 0,
                                 0.58691020213007072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026965079504006222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39004010221084745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29431178482005582,
                                 0,
                                 -0.10954567778880298,
                                 0,
                                 -0.81256244647484877,
                                 -0.12594299264363695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18994389356102367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24565246339097266,
                                 0,
                                 0,
                                 0.048915530094791472,
                                 0,
                                 -0.079427762523206075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20974389998098067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2153369753134699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049958231861887803,
                                 0,
                                 -0.35481964111439646,
                                 0,
                                 0,
                                 0,
                                 -0.51898336806813872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11184612478173181,
                                 0,
                                 0,
                                 -0.033591962456952812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36154407114556464,
                                 -0.51772889210350825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16434906955662965,
                                 -0.44668615437166559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30285612067042811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19727108772941393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34706319562507321,
                                 0,
                                 -0.51051848121965848,
                                 -0.26486618477195756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57199642995595679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4273969171668498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1759065249622289,
                                 0,
                                 -0.19922553668573245,
                                 0,
                                 0.19446540590443315,
                                 0.093205355816919175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18291380200559362,
                                 0,
                                 0,
                                 -0.14879861391487564,
                                 0,
                                 0,
                                 -0.03075449179119967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039915699505300384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96823115215356759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13216777736568397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39494319556761892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23377065764169211,
                                 0,
                                 0.16518413372551924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16824474496700431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36520606525391341,
                                 0,
                                 -0.94361688108201369,
                                 0,
                                 0,
                                 0,
                                 0.67627155638821024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22076093473023545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13644218845275047,
                                 0,
                                 -0.34908753390225894,
                                 0,
                                 0.41955253851001212,
                                 -0.18085953007635705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34874304224747088,
                                 0,
                                 0,
                                 -0.70679612027554117,
                                 0,
                                 0,
                                 0.23020423899504197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59911482159774665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90970980566115811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19717873328621766,
                                 0,
                                 0,
                                 0.15308564917702594,
                                 0.27031864765390556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031272621899104652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2150615732478347,
                                 0,
                                 0,
                                 -0.26439882965857836,
                                 0,
                                 0.45216301163134609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60485918059347044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31171707444359881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27475742490221966,
                                 0,
                                 -0.20830559276985236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19709141326949603,
                                 0,
                                 0.80575167266604719,
                                 0,
                                 0.46241183271704567,
                                 -0.42499730109519362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024501180126503385,
                                 0,
                                 0,
                                 0.5720239014400671,
                                 0,
                                 0,
                                 0.39353712549423436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025042656055346349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31862843746664826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05112840901737805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39791111244035043,
                                 0,
                                 -0.13762144847784213,
                                 0,
                                 0.42335313240601846,
                                 -0.77161663055685781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57313522837914244,
                                 0,
                                 0,
                                 -0.29997973746009687,
                                 0,
                                 0,
                                 0.17305572764148741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36090827250740609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033465875912957313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2126202587052681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30104040069519311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69377922206980347,
                                 0,
                                 1.2095151309900285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31453442212443405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57758869602097462,
                                 0,
                                 0.0030315582997458568,
                                 0,
                                 0,
                                 0,
                                 -0.17737988105009728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3351151676391862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12867988224371335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56733002420741707,
                                 1.1409611339118315,
                                 0,
                                 -0.84679342400790436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52173659261455718,
                                 0,
                                 0,
                                 0,
                                 0.27247743562786841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0957790851968372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19436270671199191,
                                 0,
                                 0.26366153408748716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1994606975031703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24071352497479631,
                                 0,
                                 -0.61376399733303189,
                                 0,
                                 0,
                                 0,
                                 -0.56453844362495231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35309980009647152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09551422444071142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60163593906679647,
                                 0,
                                 0,
                                 -0.04607301472325806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24349532873268853,
                                 0.031887251304335049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23234232425325108,
                                 -0.47096998910475457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53915308482831803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35305863654431968,
                                 0.46750161201871254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30541907898331361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36107343511045481,
                                 0,
                                 0,
                                 -0.15682481224048733,
                                 0,
                                 0.066851136857669413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07804449136060343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14507862728769333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53045014695940484,
                                 0,
                                 0.30912424233921404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39774783011170523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21355582444558571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32441341909239152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30784830737634894,
                                 0,
                                 0,
                                 0.063360683871846984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38768963619217628,
                                 -0.53741944346516712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51596752417451275,
                                 0.018383735087487592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3004786464190396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33191458352149128,
                                 0.21234260467322322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27956029974202312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31875624637293931,
                                 0,
                                 0,
                                 0.28858584612804528,
                                 0,
                                 -0.069702645138636735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17656537688699303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0059561520303898011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5161656609808527,
                                 0,
                                 -0.52839925693542866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50417449802944569,
                                 0,
                                 -0.23867358859347437,
                                 0,
                                 -0.14632367587208955,
                                 0.10549082898390499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7933649564513231,
                                 0,
                                 0,
                                 0.053159697826016913,
                                 0,
                                 0,
                                 0.13577106009829915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40520608813076098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0588478560510053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6767105801459713,
                                 0,
                                 0,
                                 -0.089008604372098676,
                                 0.1800380776322347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013009871523697578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63251523652847019,
                                 0,
                                 0,
                                 -0.39500193414804469,
                                 0,
                                 0.41815000816931286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0014557373739342711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43828954466454062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065891237384483825,
                                 0,
                                 0.17916897371528237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71894134669137433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55431644863532492,
                                 0,
                                 0.25041380631434873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8483301420947339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12145828699175636,
                                 0,
                                 -0.27408954079772802,
                                 0,
                                 0,
                                 0,
                                 -0.0062606615033996144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24677700385826934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14273232797473426,
                                 0,
                                 -0.23244195285873909,
                                 0,
                                 0.54223093637174891,
                                 0.094410727004034217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56162176674129616,
                                 0,
                                 0,
                                 0.12030068551080457,
                                 0,
                                 0,
                                 -0.43060796463216655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86424081059382241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20859521261337227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10298324948915125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48571612473433318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16622717231473466,
                                 0,
                                 0,
                                 -0.26116997379096307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2942570740675885,
                                 0.53617420333665133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42007332409132042,
                                 -0.19918905534041781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27933982674206231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50640180075585661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12108403530192273,
                                 0,
                                 0,
                                 0.55226097900802895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035581940476553164,
                                 -0.11706818535852904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33108304381628406,
                                 0.31796518552864689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44521321636849787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20032809553949915,
                                 0,
                                 0.92894191146670346,
                                 0,
                                 -0.54701377664062423,
                                 0.0085188859685486618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040960283571135604,
                                 0,
                                 0,
                                 -0.59346106159474343,
                                 0,
                                 0,
                                 0.060880644779180051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59102208375487608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20327610569391452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060301246599205355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013041713075478086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52623268398573386,
                                 0,
                                 -0.18189564522751817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041165720184043075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43561471326515722,
                                 0,
                                 -0.025968901391676513,
                                 0,
                                 0,
                                 0,
                                 0.43673838609264731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3790457938653193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66137848583150183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24514941233086746,
                                 0,
                                 0.042466197392951335,
                                 0.016091707910589712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10096418274721067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7001601080686829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47824224019008477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69478920452905668,
                                 0,
                                 -0.14387368123703834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86706969266976563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61926858393828765,
                                 0,
                                 -0.13164880403905399,
                                 0,
                                 0,
                                 0,
                                 -0.10339546985341071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060184007790756944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27326051700369353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35762660527612755,
                                 0,
                                 0.61322481058723199,
                                 -0.50885384764258512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2409650198116973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32309573456219548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048632296541113736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062975391596975072,
                                 0,
                                 0.59026034458302956,
                                 0.42528981742045824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68085654776993487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028716858399719825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88325296550107779,
                                 0,
                                 0.26144779267316154,
                                 0,
                                 -0.74774891547882516,
                                 -1.0670340776242748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10822785708748307,
                                 0,
                                 0,
                                 -0.0012868614033284334,
                                 0,
                                 0,
                                 -0.66686177850009443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17583136098836505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33456219368187817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023670416060061754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017645714776859604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58763488307700396,
                                 0,
                                 0.25738915618309333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063185873942255194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76504090316208473,
                                 0,
                                 -0.20632928332214079,
                                 0,
                                 0,
                                 0,
                                 0.57564758676491778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085796297515455547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070165951734231902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060560259182943679,
                                 0,
                                 0,
                                 0.60980358043893579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43263764601244181,
                                 0.14153098126819266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48775850157790362,
                                 -0.00075472494154877473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41765238013400174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34455005511729964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16973572613274718,
                                 0,
                                 0,
                                 0.4609666930471894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54139810123642917,
                                 0.33460651075657594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30086242320475587,
                                 -0.34540127515886032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15840167629443158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13131147741589783,
                                 0.11761637510005257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16585713061777241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10807051239777354,
                                 0,
                                 0,
                                 0.20054231570674924,
                                 0,
                                 -0.37158595099289315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61488890535219254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55653124522314279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1353579537280839,
                                 0,
                                 0.21285054132862188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65031942472139947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62829333438153112,
                                 0,
                                 -0.01149880020581559,
                                 -0.18234637842368406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035513737909241221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38430259183496041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2389533186548887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48090252218651031,
                                 -0.01493198040210595,
                                 0,
                                 1.0771573815847597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13706411327319587,
                                 0,
                                 0,
                                 0,
                                 0.17748579727076091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16462485906298069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015406216760439628,
                                 -0.20745704888592387,
                                 0,
                                 -0.28947040331906859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2851906656982639,
                                 0,
                                 0,
                                 0,
                                 1.5905055753089214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38386459820695218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58070104979596704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39487193137595167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2611908435406634,
                                 -0.23496301071733927,
                                 0,
                                 -0.58110661972980371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0153361932581821,
                                 0,
                                 0,
                                 0,
                                 -0.52285915561893215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24758327300292038,
                                 0,
                                 0.081334778694057974,
                                 0,
                                 -0.01363211552612284,
                                 0.24785263235096225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20976729759237664,
                                 0,
                                 0,
                                 0.057747753115847289,
                                 0,
                                 0,
                                 -0.036065811613959775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065157572743319264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33471670584586927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.98144567635379443,
                                 0,
                                 0,
                                 -0.20310541538203286,
                                 0.3545476243887512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35268944607871811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15894547609088969,
                                 0,
                                 0,
                                 0.095241528820051977,
                                 0,
                                 0.11008552717196848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40426544252841679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28573033392293645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46439776627238294,
                                 0,
                                 -0.44884655882362767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15398328427242611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54114111015516042,
                                 0,
                                 -0.11394444830249228,
                                 0.67567232614222883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37381186835826463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27240356922370818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0839340131048607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50153566606667177,
                                 0,
                                 0.80391453203300978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09924173428910231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12988567027143055,
                                 0,
                                 0.22369490697039518,
                                 0,
                                 0,
                                 0,
                                 0.61096637005853527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33536461732668488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016979140470252781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67526549053033258,
                                 0,
                                 0,
                                 -0.18756768952036193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30257580636517206,
                                 0.094551928720984807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19565226454029949,
                                 0.56412767852036294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22701223716090688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.069133170325032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42007323083607551,
                                 0.22063581392460094,
                                 0,
                                 -0.67248340511065363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075096149857179592,
                                 0,
                                 0,
                                 0,
                                 0.54887374509274722,
                                 -0.028870745048277725,
                                 -0.59933948336529252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60572230147581996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10882270887396828,
                                 0,
                                 0,
                                 -0.46820252948946067,
                                 0,
                                 -0.014999877298081561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084305949175933259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062461219880015843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072266604479250152,
                                 0,
                                 -0.15983369848172396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46710531638292402,
                                 0,
                                 0.78752218118344364,
                                 0,
                                 0.55954957657095528,
                                 0.035251293585824149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71364368807094958,
                                 0,
                                 0,
                                 -0.22076069931511605,
                                 0,
                                 0,
                                 -0.90133994837348086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043859399079604913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18146990225073306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18486124161045961,
                                 0,
                                 0,
                                 -0.08747078310964633,
                                 -0.13146057888057294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47798783010727303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2753094232513299,
                                 0,
                                 0,
                                 0.52691601231976448,
                                 0,
                                 0.33193275664086735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059421809356951599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30964480910124392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20985132741553394,
                                 0,
                                 0.37353856055580525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07900065167240955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53550667643116245,
                                 -1.39514082450208,
                                 0,
                                 -0.5626087642862917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.06436389420995,
                                 0,
                                 0,
                                 0,
                                 0.043713719112216914,
                                 -0.21765919081034285,
                                 0.062372480221219398,
                                 0,
                                 0,
                                 -0.056232933076864944,
                                 0,
                                 0.7174229975437908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35904544579762482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54951125379893762,
                                 0,
                                 0,
                                 -0.81427559609829947,
                                 -0.26686838579734584,
                                 0,
                                 0,
                                 -0.10401377403555123,
                                 0,
                                 0.17014682971883355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088817840689341426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46698940093268898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20069675839787737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57252336503211088,
                                 -0.097126569040495978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33485021550143035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010910554356791946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0211995530106883,
                                 0,
                                 0,
                                 0.45286312099854475,
                                 0,
                                 -0.054781749502222782,
                                 0,
                                 -0.28345709935682856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65528262894675815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085217861513704349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030401204531598371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59191542119056517,
                                 0,
                                 0.25202445940526474,
                                 0,
                                 0,
                                 0,
                                 0.091412887869191134,
                                 0,
                                 -0.51172399669900803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22260093900815986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013751875426815434,
                                 0.16758103170558369,
                                 0,
                                 0,
                                 0.47947057227901857,
                                 0.12202752467075444,
                                 -0.66350060302651725,
                                 0,
                                 0,
                                 0.35361824235686645,
                                 0,
                                 -0.13135384912069906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62943290005844221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0799422436751141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050147025518269883,
                                 0,
                                 0,
                                 0.34052614559152972,
                                 0,
                                 0,
                                 -0.50156436278635685,
                                 0,
                                 0,
                                 0.43496596073718602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1046056305017595,
                                 0,
                                 0,
                                 0,
                                 0.22520122498127834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29311249321817551,
                                 0.67127572287474246,
                                 0,
                                 0,
                                 0.41240653126509164,
                                 0,
                                 -0.24014143651061304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46481173288831934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14027461141734693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40791095214971462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19200807457521932,
                                 0,
                                 0,
                                 0,
                                 0.57604131260997304,
                                 0,
                                 -0.74548080734282318,
                                 0,
                                 0.10752804415662429,
                                 -0.52428339139214675,
                                 0,
                                 0.09241906253762408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24602902831026349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3374069631911748,
                                 0,
                                 0,
                                 0.73096689871621978,
                                 0,
                                 0,
                                 -0.39108142889899222,
                                 0,
                                 0,
                                 -0.87126393998776241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39173786018355794,
                                 0,
                                 0,
                                 0,
                                 1.0349264380477541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41193624805584117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34470789482858205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11600210750438308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46325247412507103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048616163217662822,
                                 0,
                                 0.23784025524718874,
                                 0,
                                 0,
                                 0,
                                 -0.15825978189627868,
                                 0,
                                 -0.15162811375525809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12136505072206413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6472879075791188,
                                 0.30073078302140577,
                                 0,
                                 0,
                                 -0.37526228133274953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86893149714538942,
                                 0,
                                 0,
                                 -0.38818137586607188,
                                 0,
                                 0,
                                 -0.47887831075936038,
                                 0,
                                 0,
                                 -0.10262419020193261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27055582056139538,
                                 0,
                                 0,
                                 0,
                                 0.16955096419072316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48593367994786774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38187872970715592,
                                 -0.45401119132084933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0231044829869327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08993288835233873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17389502612113725,
                                 0,
                                 0,
                                 -0.1131458684221637,
                                 0,
                                 0.033144499841223592,
                                 0,
                                 -0.68567499513780605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17592813211557057,
                                 0,
                                 0,
                                 0,
                                 0.23873594448676924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58873272616356198,
                                 0.12242409662692152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068646474294967216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042235140044086752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04251657986854443,
                                 0,
                                 0,
                                 -0.19408883533845875,
                                 0,
                                 0.93468119215105738,
                                 0,
                                 -0.35734593014783961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96749237646152586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.586004798889179,
                                 0,
                                 0,
                                 -0.94766358798859684,
                                 0,
                                 0,
                                 -0.18157043251264748,
                                 0,
                                 0,
                                 -0.088080285147957793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48673929222486684,
                                 0,
                                 0,
                                 0,
                                 0.43264743961439978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023049825162068466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35986118176598414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17871868603591429,
                                 0,
                                 -0.1219292846617705,
                                 0,
                                 0,
                                 0,
                                 0.038975036149162277,
                                 0,
                                 0.19184066333591601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8752433831534524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087302851800405798,
                                 -0.028321400016529219,
                                 0,
                                 0,
                                 0.10180743236219245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23802062508330696,
                                 0,
                                 0,
                                 -0.3698593844578234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16110229292282763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27885044860744213,
                                 0,
                                 0,
                                 0.68594846894918482,
                                 0,
                                 0,
                                 0,
                                 0.048221205571650105,
                                 0,
                                 0,
                                 0,
                                 0.37675745914030639,
                                 0,
                                 -0.29671859825682517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5935716836657321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23762566175512267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28499284714018536,
                                 0,
                                 0.46770573405001392,
                                 0,
                                 0,
                                 0,
                                 -0.33112198378985469,
                                 0,
                                 -0.29008869069631132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020179337403528598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26352550183351831,
                                 -0.16237171705858267,
                                 0,
                                 0,
                                 0.035020533224046385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69838482442314365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18421077474073189,
                                 0,
                                 0,
                                 0,
                                 0.93259982517890361,
                                 0,
                                 -0.59051938289325034,
                                 0,
                                 -0.029474401600670157,
                                 0.69491062042933482,
                                 0,
                                 0.44931323685343105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36503707779308536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30544021130117782,
                                 0,
                                 0,
                                 -0.16706076960118033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46935026820296771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53984648286769588,
                                 0,
                                 0,
                                 0.2564746050909828,
                                 0,
                                 0,
                                 0,
                                 -0.11439472577753944,
                                 0,
                                 0,
                                 0,
                                 -0.44524625812556595,
                                 0,
                                 -0.29993911138199536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28347075116430703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55751670953318011,
                                 0.019094224866773563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24622288100765455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30581243868592956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84250199557025329,
                                 0,
                                 0,
                                 0.12016420527920382,
                                 0,
                                 0.23039704379897319,
                                 0,
                                 1.0329942770425509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096106650666616111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11767936239542948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2269533130968604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33089082261104558,
                                 0,
                                 -0.53797966776176476,
                                 0,
                                 0,
                                 0,
                                 -0.35348291210565203,
                                 0,
                                 -0.4116375314818756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048140353604764638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10155365365022415,
                                 0.45701625228608633,
                                 0,
                                 0,
                                 0.14086441134503691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062056089166922741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.004317832686711931,
                                 0,
                                 0,
                                 0,
                                 -0.23937182913049537,
                                 0,
                                 0.041311367118348138,
                                 0,
                                 1.1212527832389072,
                                 -0.42541231950945613,
                                 0,
                                 0.43171355917220605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018113106443417598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092135148964206381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21661842702026199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38015331988050438,
                                 0,
                                 0.39473858650943927,
                                 0,
                                 0,
                                 0,
                                 0.56346086523445249,
                                 0,
                                 0.087849074750297504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040388149918699601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019111599334201815,
                                 0.56190766709274498,
                                 0,
                                 0,
                                 0.036196468048065839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58705068168217189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25756626808396177,
                                 0,
                                 0,
                                 0,
                                 -0.13172461255598464,
                                 0,
                                 0.059582082073857595,
                                 0,
                                 -0.41665493808360904,
                                 -0.51280773649775913,
                                 0,
                                 0.5752229666155666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1131232759962571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4736408607167808,
                                 0,
                                 0,
                                 0.13654069676214331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01424909929208701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052187381247684225,
                                 0,
                                 0,
                                 -0.3309820461873173,
                                 0,
                                 0,
                                 0,
                                 0.73082498568009424,
                                 0,
                                 0,
                                 0,
                                 0.039271132262229114,
                                 0,
                                 -0.32999684418678682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29075219602716396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68369766248446184,
                                 0,
                                 0,
                                 0,
                                 -0.41814876844018367,
                                 0,
                                 -1.0593963011901546,
                                 0,
                                 -0.1747736366834674,
                                 0.73542993965618919,
                                 0,
                                 0.27964929454289494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090317952956532568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020344510438826947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17377759540935683,
                                 0,
                                 0,
                                 0,
                                 0.07901476862416966,
                                 0,
                                 -0.30325112567350998,
                                 0,
                                 -0.058776999747032599,
                                 -0.55068971364351138,
                                 0,
                                 -0.43015541057878937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1549302874969931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61447040591192692,
                                 0,
                                 0,
                                 0.62027030381821746,
                                 0,
                                 0,
                                 -0.99850007955399311,
                                 0,
                                 0,
                                 -0.30921221589161929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039906898929688253,
                                 0,
                                 0,
                                 0,
                                 -0.6720341455652189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65080794940056896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041890565559411459,
                                 0,
                                 0,
                                 0,
                                 -0.34299448129836985,
                                 0,
                                 0.47152364960104232,
                                 0,
                                 -0.23758781635689241,
                                 0.56878524824087806,
                                 0,
                                 1.1934561778955077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071516561460949646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42950269689647502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22867809325618774,
                                 0.31683423309148012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72154832319296236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25665129027364375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26227500111241464,
                                 0,
                                 0,
                                 1.0869857804744596,
                                 0,
                                 -0.32526828526492274,
                                 0,
                                 0.26852977210531848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30817505506040943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57817616083618717,
                                 0,
                                 0,
                                 -0.21894047459178556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23329664711486714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42322330028378208,
                                 0,
                                 0,
                                 0.1064600282192448,
                                 0,
                                 0,
                                 0,
                                 0.50226380419219907,
                                 0,
                                 0,
                                 0,
                                 0.34383915211039207,
                                 0,
                                 0.049031408648546514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18133652605216,
                                 0,
                                 0,
                                 0.64900534115324071,
                                 0,
                                 0,
                                 -0.32081183612968561,
                                 0,
                                 0,
                                 1.2457183733783772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2006271879651037,
                                 0,
                                 0,
                                 0,
                                 -0.38988464959195096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24652639982460076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17310592989540829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26631517492319157,
                                 0,
                                 0,
                                 -0.18752723586502185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68509317377869894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12064791367817121,
                                 0,
                                 0,
                                 0.11045854911499933,
                                 0,
                                 0,
                                 0,
                                 0.21218362426366619,
                                 0,
                                 0,
                                 0,
                                 -0.57245894375746353,
                                 0,
                                 -0.15833181554956718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13441930311623687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65279996684394959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14349645320501511,
                                 0,
                                 0.29227890046953631,
                                 0,
                                 0,
                                 0,
                                 -0.14125309479337575,
                                 0,
                                 -0.17301443284781759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29856440528920869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36421376690478779,
                                 -0.3580113529119292,
                                 0,
                                 0,
                                 -0.22341561004397403,
                                 0,
                                 0,
                                 0.69420416884792213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49866147737928374,
                                 0.070466732038093755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032304139823670197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97879161444930252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04256544478871143,
                                 0,
                                 0,
                                 -0.5810473619842883,
                                 0,
                                 -0.81348789181368863,
                                 0,
                                 0.016108978134520828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19558393852549408,
                                 0,
                                 0.39239162283393247,
                                 0.12332336010677578,
                                 0,
                                 0,
                                 0.31647101349151852,
                                 0,
                                 0.61751232629018749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069549395724463489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58694775681948208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26769351433864247,
                                 0,
                                 0,
                                 -0.34010336164280552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46110908058395111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64406834974891514,
                                 0,
                                 0,
                                 -0.070588637717044697,
                                 0,
                                 0,
                                 0,
                                 0.1591578250028936,
                                 0,
                                 0,
                                 0,
                                 -0.38803117203622706,
                                 0,
                                 -0.065894635053350831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054328912276182334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18355051408229711,
                                 -0.86568173813323146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64331530451381491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49140695403412193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40212482273662647,
                                 0,
                                 0,
                                 0.66255803430929539,
                                 0,
                                 0.034491722527531965,
                                 0,
                                 -0.59611415586382044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14125588728172159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15251636758482037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1148099337889854,
                                 0,
                                 0,
                                 0,
                                 0.29940258976458795,
                                 0,
                                 0.29133820734091737,
                                 0,
                                 0.19268377936071751,
                                 -0.16978801479950006,
                                 0,
                                 -0.38102467772219784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51609686479088723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0525221754282117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18866660420789727,
                                 -0.52338173296150015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68260431069142391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35964831905080119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48246872711129285,
                                 0,
                                 0,
                                 0.21396132374933591,
                                 0,
                                 -0.17639333310261693,
                                 0,
                                 0.24667883843310867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83229838914965937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17557468964879458,
                                 0,
                                 0,
                                 0.76742499146758636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13095313395563796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13876483847604476,
                                 0,
                                 0,
                                 0.52232899770891628,
                                 0,
                                 0,
                                 0,
                                 0.19973025436384484,
                                 0,
                                 0,
                                 0,
                                 -0.17517043641870172,
                                 0,
                                 -0.020580791642988004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14815174417390101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077275559401008886,
                                 -0.90570464522263672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52858888200097531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0106770124626787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30882453863735659,
                                 0,
                                 0,
                                 -0.55043972032087651,
                                 0,
                                 -0.68715509998475699,
                                 0,
                                 0.38072252299544684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35868336565427383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34353902223302757,
                                 0,
                                 0,
                                 -0.17011338389743466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0017465162995332051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018195575334407757,
                                 0,
                                 0,
                                 0.22978510327688398,
                                 0,
                                 0,
                                 0,
                                 0.29659601342230785,
                                 0,
                                 0,
                                 0,
                                 -0.17629488846626887,
                                 0,
                                 0.82514118245055257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1989570178611747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23677684047239381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43553699778410199,
                                 0,
                                 0.097415132657034886,
                                 0,
                                 0,
                                 0,
                                 -0.37443611246289749,
                                 0,
                                 0.33404792693541963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23330346538061492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25671049404006485,
                                 0.42520375771099472,
                                 0,
                                 0,
                                 -0.39019380859220743,
                                 0,
                                 0,
                                 0,
                                 0.65974613302563556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13008132328173072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1986282909703089,
                                 0,
                                 0.12833840020953283,
                                 0,
                                 0,
                                 0,
                                 -0.10302293046615138,
                                 0,
                                 -0.31303253717172208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069607060861475667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53573399474676342,
                                 0.081566175555834453,
                                 0,
                                 0,
                                 -0.29116619957503587,
                                 0.18655533797362131,
                                 0.13725210704170196,
                                 0,
                                 0,
                                 -0.76859617570635907,
                                 0,
                                 -0.010539573207150293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49610978409522077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33073083194242198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63917840599567244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67313214591305415,
                                 -0.27191095694659956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056161637865023442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46491391710024099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61323843963022762,
                                 0,
                                 0,
                                 -0.28245689829234627,
                                 0,
                                 0.42860968446176906,
                                 0,
                                 0.57256011658597294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15573172458351342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33341875620097761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030713480766655005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1742673852788714,
                                 0,
                                 0.29945316398545291,
                                 0,
                                 0,
                                 0,
                                 -0.4921684921502833,
                                 0,
                                 0.42132989413488148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12998504036561101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086720908064811225,
                                 0.11867363306547354,
                                 0,
                                 0,
                                 0.55641579233804084,
                                 -0.42105687914372469,
                                 0,
                                 0,
                                 -0.29731842150010651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46640928793357872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094554362343633194,
                                 -0.094919991019291439,
                                 0,
                                 0.33062096323236628,
                                 -0.58674432917361707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80534678254208936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47303838682708826,
                                 0,
                                 0.26377147537741896,
                                 0,
                                 0,
                                 0,
                                 0.18466577465024184,
                                 -0.58726920267206217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29415124120760816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60651419504394277,
                                 0,
                                 0,
                                 0,
                                 -0.11378043826252082,
                                 0,
                                 0,
                                 0,
                                 -0.39202426664781359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042519850420024263,
                                 -0.54617109164332167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43891778730759012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13941097625886867,
                                 0,
                                 0,
                                 0,
                                 0.13636717004611693,
                                 0,
                                 0,
                                 0,
                                 0.68498828573237303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35482905191904507,
                                 0,
                                 0,
                                 -0.39132467031773654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.006459155615436446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72085630623840757,
                                 -0.6548256928007804,
                                 0,
                                 -0.62816240276322399,
                                 0.043665113163609548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06945727206780393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22916810147159142,
                                 0,
                                 0.31554828048100325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03194562392229644,
                                 0,
                                 0,
                                 -1.228958168326219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38394616399778758,
                                 0,
                                 0,
                                 -0.46186443977872543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16564655465723199,
                                 0,
                                 0,
                                 -0.090270935512215461,
                                 0,
                                 0,
                                 0,
                                 -0.71632514822623117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10194244069270254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49688636760724164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40920515993423978,
                                 0,
                                 0,
                                 -0.082170375252656358,
                                 0.096747097627731107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48004975411648532,
                                 0,
                                 -0.32575703359887914,
                                 0,
                                 0,
                                 0,
                                 0.24591234634190973,
                                 0,
                                 0,
                                 0,
                                 0.10396051360596653,
                                 0,
                                 0.40025940532979687,
                                 -0.03859313289590792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061951518538798656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11844013833601368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8700600985157575,
                                 0,
                                 0,
                                 0.083692588788626482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45467238465709575,
                                 0,
                                 0,
                                 0.21660470383787483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0349731579659029,
                                 0,
                                 0,
                                 -0.18354395179326466,
                                 0,
                                 0,
                                 0,
                                 0.078223522414656854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25438452308160286,
                                 0,
                                 0.3855792770738139,
                                 0,
                                 0,
                                 -0.49528289199983272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26775043285102873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80470631800512393,
                                 -0.25718704269184878,
                                 0,
                                 0.39742239889144132,
                                 -0.40623858897881104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015715277211720578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31728053420429464,
                                 0,
                                 -0.63411655942802458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18172392712059354,
                                 0,
                                 0,
                                 0.66672729267462383,
                                 0,
                                 0,
                                 0,
                                 -0.076752582317501955,
                                 0,
                                 0,
                                 -0.64586917763124485,
                                 -0.29920357748611509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054753663566830722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019615586361801274,
                                 0,
                                 0,
                                 0.080670083211684868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14416240070360559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025150675530086042,
                                 0,
                                 0,
                                 -0.2288433581216418,
                                 -0.38247613946090514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33148973798071818,
                                 0,
                                 0.16643051877136689,
                                 0,
                                 0,
                                 0,
                                 0.19720545469614648,
                                 0,
                                 0,
                                 0,
                                 0.41889360756937866,
                                 0,
                                 -0.63686028355079072,
                                 0.14963266814642187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66658025351634997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.9121201626656924,
                                 0.31435002435871134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39187790725155586,
                                 0,
                                 -0.45867409088921191,
                                 0,
                                 0,
                                 -0.55822820564986786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28256749297820688,
                                 0,
                                 0,
                                 0.38144288047068919,
                                 0,
                                 0,
                                 0,
                                 -0.30190557731338596,
                                 0,
                                 0,
                                 0.19483041604350246,
                                 0.37967191290785729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51439071910187784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39731818662844687,
                                 0,
                                 0,
                                 -0.2809639789127002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060732331694599552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48420272893698957,
                                 0,
                                 0,
                                 0.46383956931270953,
                                 -0.24769206552579992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024620892590319438,
                                 0,
                                 -0.20099368394556619,
                                 0,
                                 0,
                                 0,
                                 0.25955455318510073,
                                 0,
                                 0,
                                 0,
                                 0.3026326528948437,
                                 0,
                                 0.092816415545711531,
                                 -0.52610471465505249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30968213094811542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010484390869445855,
                                 0,
                                 0,
                                 0.35675764108529728,
                                 0.19113873762502748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30264363802950611,
                                 0,
                                 0.68956764644398716,
                                 0,
                                 0,
                                 0,
                                 0.0090982459511891392,
                                 0,
                                 0,
                                 0,
                                 -0.34272400189289298,
                                 0,
                                 -0.10671463540764513,
                                 -0.21011849085886411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071661851405612681,
                                 0,
                                 0,
                                 0.51947401310532404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48925861046146607,
                                 0,
                                 0,
                                 -0.94704920907024004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27321284398281298,
                                 0,
                                 0,
                                 -0.56373434548139822,
                                 0,
                                 0,
                                 0,
                                 0.073439528915502081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41763058475288201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44298581241934731,
                                 0,
                                 0,
                                 -0.0094494285627013952,
                                 0,
                                 0,
                                 0,
                                 0.67908145010657961,
                                 0,
                                 0,
                                 -0.017626257709392558,
                                 -0.26418778808119503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34588816711132314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24095747677971327,
                                 0,
                                 0,
                                 0.3077623438963305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50859718370847673,
                                 -0.19155843590676744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49513061729644264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096558768477662815,
                                 0,
                                 0,
                                 0,
                                 -0.60051540658289837,
                                 0,
                                 0,
                                 0,
                                 -0.29922832897146112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19499142668144695,
                                 0,
                                 0,
                                 -0.2554848176597555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97884613627591921,
                                 0,
                                 0,
                                 -0.036892944054344901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56743341632042721,
                                 0,
                                 0,
                                 -0.066645059402096349,
                                 0,
                                 0,
                                 0,
                                 -0.15221063312043742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.93114187376752233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12873668658965839,
                                 0,
                                 0,
                                 -0.27103335266655137,
                                 0,
                                 0,
                                 0,
                                 -0.49983285920587495,
                                 0,
                                 0,
                                 -0.19352612348154602,
                                 0.077738326219846499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0023283013777351397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3196741808869441,
                                 0,
                                 0,
                                 0.71724632406170197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57995691334035093,
                                 0,
                                 0,
                                 -0.15703329610512501,
                                 0,
                                 0,
                                 0,
                                 -0.40516194454601423,
                                 0,
                                 0,
                                 -0.062051425652144915,
                                 -0.53894826924169503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090201642710073443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32426606015158821,
                                 0,
                                 0,
                                 -0.25929498802888928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22075221802742978,
                                 0,
                                 0,
                                 -0.50901157387426221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048982440907170174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24772153012746054,
                                 0.84041812489824308,
                                 0,
                                 -0.55571616023507397,
                                 -0.0012452658181365678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069223478528560228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34742079824605004,
                                 0,
                                 0.0012322729660274347,
                                 0,
                                 0,
                                 0.69085158069002617,
                                 0,
                                 0,
                                 -0.086122119404862613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58628608397307613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13802565487421614,
                                 0.48463184458862968,
                                 0,
                                 0.65632337987639666,
                                 -0.65709408844912498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14297400294728946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096689544994925714,
                                 0,
                                 0.67103453609871755,
                                 0,
                                 0,
                                 0,
                                 0.60264913687967003,
                                 0.32716139331043387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6285579123955366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28338812056482698,
                                 0,
                                 0,
                                 0,
                                 -0.026637185391825732,
                                 0,
                                 0,
                                 0,
                                 -0.23168086841054622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48498667386625371,
                                 0,
                                 0,
                                 0.41802627463311703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16566344373314579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72053260349277504,
                                 -0.092662319516389591,
                                 0,
                                 -0.5442069420951523,
                                 -0.071321506052875239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081686649717248094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38204016750459852,
                                 0,
                                 0.75349423521770265,
                                 0,
                                 0,
                                 -0.95255171311898379,
                                 0,
                                 0,
                                 -0.26495505309087686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40765566264792386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30901980581789412,
                                 0.31543146293480434,
                                 0,
                                 -0.062666528523156462,
                                 -0.21636516074991871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17916295619324102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72153071611197295,
                                 0,
                                 0.0047028245332024071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2135856971720142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0039012888792756099,
                                 0,
                                 0,
                                 0.13065271618080038,
                                 0.7912868672479435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013290001644108864,
                                 0,
                                 0.033149270280364601,
                                 0,
                                 0,
                                 0,
                                 0.2336362238186408,
                                 0,
                                 0,
                                 0,
                                 0.47701530974069861,
                                 0,
                                 -0.15341754191239165,
                                 0.064953522973199229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4999001409340319,
                                 0.046755259512043415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25654945018758668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26728519299191189,
                                 0,
                                 0,
                                 0,
                                 0.72379794007513609,
                                 0,
                                 0,
                                 0,
                                 -0.29456975737643604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34627457661002092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3329396541416666,
                                 0,
                                 0,
                                 -0.3334607723088609,
                                 0.054552845177638726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30325444973149679,
                                 0,
                                 -0.027684111349995572,
                                 0,
                                 0,
                                 0,
                                 0.60378298832564159,
                                 0,
                                 0,
                                 0,
                                 -0.44144202779139119,
                                 0,
                                 0.048387814187093425,
                                 0.024020656751375324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26457291701578156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38363592356735648,
                                 -0.63864327682864552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92486973336323519,
                                 0,
                                 -0.032256773707648956,
                                 0,
                                 0,
                                 0.8352327699386346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4229951500242613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18289914763688028,
                                 -0.88684277093028774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056988693216482339,
                                 0,
                                 0.14345390493546217,
                                 0,
                                 0,
                                 -0.58884339661398966,
                                 0,
                                 -0.30386409072020276,
                                 0.45923496852281692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12152870224801932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67203520284940099,
                                 0,
                                 0,
                                 0,
                                 -0.28852427204027314,
                                 0,
                                 0,
                                 0,
                                 0.38356624351125873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53378629113629794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55957578733009883,
                                 0,
                                 0,
                                 -0.28047375788974555,
                                 0.1059168106264525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24397278661591515,
                                 0,
                                 0.21076376092199028,
                                 0,
                                 0,
                                 0,
                                 0.042480100822089556,
                                 0,
                                 0,
                                 0,
                                 0.15239762761357467,
                                 0,
                                 0.25765228143176649,
                                 0.34162092510349534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41640630325145217,
                                 0,
                                 0,
                                 0.25032667189544899,
                                 0,
                                 0,
                                 0,
                                 0.049520711180893608,
                                 0,
                                 0,
                                 0.057570903922616032,
                                 0.022702377100650567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77552164238214949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38107398151164967,
                                 0,
                                 0,
                                 -0.10492398687430056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037453013379510042,
                                 0,
                                 0,
                                 -0.66220821365010341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047098614323611315,
                                 0,
                                 0,
                                 -0.14096540381232983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17862990718238475,
                                 0,
                                 0,
                                 -0.8054331441175141,
                                 0,
                                 0,
                                 0,
                                 1.1596354034620151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2123583575376724,
                                 0,
                                 0.77651636705810145,
                                 0,
                                 0,
                                 -0.4382955262350462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92129507201782479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025713427737478756,
                                 0.45396182437413729,
                                 0,
                                 0.34978953751032166,
                                 0.33519836484354859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20450697795020734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49912483646474137,
                                 0,
                                 0.070997276238369461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098332947228879169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40306134637883201,
                                 0,
                                 0,
                                 -0.0006455023214009814,
                                 0.24050377371032564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45683426165438112,
                                 0,
                                 -0.41096170683230943,
                                 0,
                                 0,
                                 0,
                                 -0.53707525821377899,
                                 0,
                                 0,
                                 0,
                                 -0.16586231123226597,
                                 0,
                                 -0.27390431910971103,
                                 0.038195789020797982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1644296488469976,
                                 0,
                                 0,
                                 0.35179987664925555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10125960141205684,
                                 0,
                                 0,
                                 -0.58612282920681469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64730212778043184,
                                 0,
                                 0,
                                 -0.13008134333967955,
                                 0,
                                 0,
                                 0,
                                 -0.027465468822074068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40684624521255686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13326357733164987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021371537617573551,
                                 0,
                                 0,
                                 -0.59060377773707196,
                                 0.077378187419665845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1086408014416784,
                                 0,
                                 0.25535543464914956,
                                 0,
                                 0,
                                 0,
                                 -0.28316289843637144,
                                 0,
                                 0,
                                 0,
                                 0.23354264295200006,
                                 0,
                                 0.1784698508837364,
                                 -0.61919283557376337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39350783342384704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1022354574293728,
                                 0,
                                 0,
                                 0.20666542916490852,
                                 -0.2056888097874699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44193263604368044,
                                 0,
                                 0.26438356213524378,
                                 0,
                                 0,
                                 0,
                                 -0.20883098745727807,
                                 0,
                                 0,
                                 0,
                                 0.27745614821534154,
                                 0,
                                 0.46374605412773723,
                                 0.38577867909310037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2263800582558394,
                                 0,
                                 0,
                                 -0.35225324187020479,
                                 0,
                                 0,
                                 0,
                                 0.15331510983884922,
                                 0,
                                 0,
                                 -0.70105391667522277,
                                 0.47127436278057727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0053979579297258329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0281802327685369,
                                 0,
                                 0,
                                 -0.29455868234106347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26826694493735592,
                                 0,
                                 0,
                                 0.58248312970754756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30239860417100262,
                                 0,
                                 0,
                                 -0.33062423625099696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38320443649289948,
                                 0,
                                 0,
                                 0.14846516052911299,
                                 0,
                                 0,
                                 0,
                                 0.095393972849323688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0224584613140233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.125464409832754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32401301563320528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33664565978227434,
                                 0,
                                 0,
                                 0.35358511143315308,
                                 0,
                                 0,
                                 0,
                                 0.04316868569720575,
                                 0,
                                 0,
                                 0.092139494517942899,
                                 0.42119812817108121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056221767958808663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65600412890005366,
                                 0,
                                 0,
                                 0.37467836786579045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41245230233649216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93997677657189471,
                                 -0.14172877965263891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.211495328063845,
                                 0,
                                 0.36756514439354759,
                                 0,
                                 0,
                                 0.32762249962721851,
                                 -0.20351708324229448,
                                 0,
                                 0,
                                 -0.61056099604447045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14012213183328537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032436887296449238,
                                 -0.17528730202084061,
                                 0,
                                 0.57296126432429517,
                                 0.20595585590980953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8565689356017977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19554352358181326,
                                 0,
                                 0.39275319216951726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.459124586414142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12658973320102107,
                                 -0.31279982331081169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37691032109462302,
                                 0,
                                 -0.92164024889439045,
                                 0,
                                 0,
                                 0.16398559515134833,
                                 0.084753006064502867,
                                 0,
                                 0,
                                 0.30714583744595569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37706380877533408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026613626336836699,
                                 0.093838537027604668,
                                 0,
                                 0.00031991081201350469,
                                 -1.3467646686036101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61779982699968861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051849147028539919,
                                 0,
                                 -0.041390340791127633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066065333267324167,
                                 0,
                                 0,
                                 -0.1154876512413248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030684723236260251,
                                 0,
                                 0,
                                 -0.66901647655835927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31866996723320135,
                                 0,
                                 0,
                                 1.2894649260175184,
                                 0,
                                 0,
                                 0,
                                 0.89974721919257061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36875279240622327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74969967561971829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51016626047588753,
                                 0.34480428481070186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3197057476147664,
                                 0,
                                 0.29292803509873383,
                                 0,
                                 0,
                                 0.10743665175672734,
                                 0.97820757467046482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21762124280199427,
                                 -0.85444273277938909,
                                 0,
                                 0,
                                 -0.26365496933383631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080854296837302359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047740441867823502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82563061958129202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076709294295001895,
                                 0,
                                 0,
                                 -0.13188371078389985,
                                 0,
                                 0,
                                 0.39397958272980182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65494985429390007,
                                 0.0078984724622512773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24065679229444617,
                                 0.50343353645463051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66256898955870625,
                                 0,
                                 0,
                                 -0.027470313701648895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027398351601264873,
                                 -0.082926370232408467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11673176573599345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22392376271042178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39696641666014287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1621049267020534,
                                 0,
                                 0,
                                 0.077969713456048265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60023044381771817,
                                 0.5517022457370705,
                                 0,
                                 -0.27205296863100764,
                                 0,
                                 0,
                                 -0.051842893773322719,
                                 0.62051470157028144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17784379287184093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41188032310154243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24240079956711014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082370143992477066,
                                 0,
                                 0,
                                 -0.43423540321859455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31487854680341743,
                                 -0.17135630305681573,
                                 0,
                                 0.16847892682537549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0044033698754452344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50273070877072024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54770753452978926,
                                 0.48065354278087602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28254754692132955,
                                 0,
                                 0,
                                 0.36932094031189389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61652649603726306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27747923855605505,
                                 0,
                                 0.013955545832171283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59108245690453154,
                                 0,
                                 -0.19490958777493134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1511191437505151,
                                 0.17869554423726905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29962147596215766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0107237443249871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057165417602011687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26949079089403705,
                                 0,
                                 0,
                                 0,
                                 -0.35048977791494546,
                                 0.37491479507410808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53794274760343641,
                                 -0.55568475299810438,
                                 0,
                                 0,
                                 0.24983934349759532,
                                 0,
                                 0,
                                 -0.2447235112559315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7886429778094286,
                                 0,
                                 0,
                                 0.18755814637167059,
                                 0,
                                 0,
                                 -0.17069270988768065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67393277909557625,
                                 -0.17963634230408276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45456138406817709,
                                 -0.25926054850432034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25517095088760722,
                                 0,
                                 0,
                                 -0.1962650056026474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62977099671596981,
                                 0.4018348755853397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31667379973370019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011567107094412015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25652181914852129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22746654226420987,
                                 0,
                                 0,
                                 0.31323283618738174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11417164384658203,
                                 0.23119811632476936,
                                 0,
                                 -0.24362700299562537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59378305911793239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20364311418351541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14020799150295918,
                                 0.63725123327464872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42363190804063888,
                                 0,
                                 0,
                                 -0.027198383199797369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29265820426554623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59623789028117935,
                                 0,
                                 0,
                                 0.45772340243468479,
                                 0,
                                 0,
                                 0.86437185981972353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46428228155490919,
                                 -0.11472771335190926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17406224236701717,
                                 -0.36491087581015841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.093849419257094474,
                                 0,
                                 0,
                                 -0.44930311737506684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24728455872483485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44980522090347042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7202267122931818,
                                 0,
                                 0,
                                 0,
                                 0.03027789181125716,
                                 0.16638597335435404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22406312548165494,
                                 0.34264587853681749,
                                 0,
                                 0,
                                 0.14692708403534527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26141640918858344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79578628332496293,
                                 0,
                                 0.039749216639751846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78945193845412243,
                                 0,
                                 -0.34233873907281787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1425489252065161,
                                 1.0637057045608689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29628524876564233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50904730954893429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12394410820165688,
                                 0,
                                 0,
                                 -0.35261569061526765,
                                 0,
                                 0,
                                 0.52988203729426331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090452944072937622,
                                 0.015347122086145956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33176731866984288,
                                 0.10933803252231319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.94667093660275903,
                                 0,
                                 0,
                                 0.094845608981137225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46085480659524464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26978471401053444,
                                 0,
                                 -0.62780958257030539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50546750453169242,
                                 0,
                                 -0.18442131732955808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10854089901126557,
                                 0.011709708776260395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98986644229810306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27766430345708437,
                                 0.19663351577324778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51928795455044341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47264059359719385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20599799826643478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052793057581388046,
                                 0,
                                 0,
                                 0.062534106153790001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0031623785433132975,
                                 0.205872741852932,
                                 0,
                                 -0.54741419553765291,
                                 -0.20764114610695067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32863708487046472,
                                 -0.38767085290039272,
                                 0,
                                 0,
                                 -1.0941422355001349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75111789319848499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27189213056138284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31728967752475773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50329779261716034,
                                 -0.78317507760854044,
                                 0,
                                 0,
                                 -0.17921019709560032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6464406395815655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71031713193891832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0066862813621406392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75555423180032233,
                                 0,
                                 0,
                                 0.37836209676219978,
                                 0,
                                 0,
                                 0.19426045416453563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3764012853226063,
                                 0.27050749246604738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47504744686491368,
                                 -1.1736604593619555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54338464138406795,
                                 0,
                                 0,
                                 0.42521344933921296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25574545096083362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78821825653669808,
                                 0,
                                 0,
                                 0.67476991144118637,
                                 0,
                                 0,
                                 0.44564923450666361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096509909650034725,
                                 0.41737852248215368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32316020090900122,
                                 0.5106387170089921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31653205587192407,
                                 0,
                                 0,
                                 0.072345879265706486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067686316115689774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17785302234452272,
                                 0.18656810546982139,
                                 0,
                                 0,
                                 -0.89650788864440323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95218248202682765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0303869243837536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18924662110769208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018240227756018135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19149679098511083,
                                 0.24117004623996963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73684792008012068,
                                 0,
                                 0,
                                 -0.57102901940562167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7329163488735041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14511049010834803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37767878819006628,
                                 -0.53994131912786891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025674246806203088,
                                 0,
                                 0,
                                 -0.083303716094301719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14926671483892937,
                                 0.10448299412835538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01007816050144399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31334668205183974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45825499169260653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090155136100575683,
                                 0,
                                 0,
                                 0.39186647722612805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38263012127142931,
                                 0.40716399283906196,
                                 0,
                                 0.42969965160356416,
                                 0,
                                 1.0432319264336969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074456507091408747,
                                 0,
                                 0,
                                 0.78192904876214564,
                                 0,
                                 0,
                                 -0.62877172050509145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23254206066282568,
                                 -0.233591739467921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21620944695798289,
                                 0.071750527433505157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.016275460619346462,
                                 0,
                                 0,
                                 -0.080791459103704596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26833066207935596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51488764635699524,
                                 0,
                                 0,
                                 -0.3494259066905982,
                                 0,
                                 0,
                                 0.4678279564146009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2008586004158559,
                                 -0.47084019045738112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55814532241187265,
                                 -0.36578175175386018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020728161735492481,
                                 0,
                                 0,
                                 -0.94737320771837019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31469111373682246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39246747843916613,
                                 0,
                                 1.3330612444746017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029900985298992634,
                                 0,
                                 0.48017806401997687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3340913973011635,
                                 0.05711872096623008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1126120792928016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051505580305773811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82135052933024522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50118136930373625,
                                 0.048011692505925477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21968472322664978,
                                 0,
                                 0,
                                 0.14484894888355118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2217879226388502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076684458534875877,
                                 0,
                                 0.17378391455536696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01513416670398016,
                                 0,
                                 -0.20956486397820293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84769208591694067,
                                 -0.23557241733590767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17533620623677221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37416018602739376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34554729801298373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29728450683238428,
                                 0,
                                 0,
                                 0,
                                 0.62810037722217216,
                                 0.3432095542768972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085117333282839061,
                                 -0.36283127215195299,
                                 0,
                                 0,
                                 -0.032074406232135533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26789700668150318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098918472619518236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4998631040540259,
                                 0.10429906797241929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38579461935588372,
                                 0,
                                 0,
                                 -0.71334943953669727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24954444263443801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1123788058838504,
                                 1.1704386001097764,
                                 0,
                                 0,
                                 -0.31573664753016772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072096093196979627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42849739852250668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16713908924775295,
                                 0,
                                 0,
                                 -0.39163185887275304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55366792098702011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094624427915324785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24637187703365734,
                                 0,
                                 0,
                                 0,
                                 -0.21946105750985984,
                                 -0.27835180497273659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13722245934511035,
                                 0.010488650266234467,
                                 0,
                                 0,
                                 0.69225432529557995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13931141443080619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77272937024305177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26382514499397036,
                                 0,
                                 0,
                                 0,
                                 0.39917995706910303,
                                 0.32133915955056469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07661996966568807,
                                 0.15573196868023448,
                                 0,
                                 0,
                                 0.1454351526800054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2287781914793407,
                                 0,
                                 0,
                                 -0.17508458073541161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085288404771091481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39215095441736109,
                                 0,
                                 -0.16323700968829225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54048896461117435,
                                 0,
                                 0.62447912782507842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24080867447272755,
                                 1.1866869729514262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034747860686475805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5152579981009342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26327634851048615,
                                 0,
                                 -0.59656136073938892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96936099984283242,
                                 0,
                                 1.1575173477072804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66106363421936587,
                                 -0.11141666280660636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058011534621948163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44144842363269637,
                                 0.38557593241592625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11143832479758316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26069997044793242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043875478738921489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067282499974391022,
                                 0,
                                 0,
                                 0.58613947091181084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18878693144490855,
                                 -0.43000599076864876,
                                 0,
                                 -0.074258907944927011,
                                 0,
                                 -0.15095390544922585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054804052336023285,
                                 0,
                                 0,
                                 0.16694884081077127,
                                 0,
                                 0,
                                 0.082795763911386253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1712615795932545,
                                 -1.1327810720501381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2153294086820548,
                                 -0.053739609115492415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24622663473713524,
                                 0,
                                 0,
                                 0.50069690180573012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4041648352128322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2876503349393515,
                                 0.99553820274904248,
                                 0,
                                 0,
                                 -0.34464117834590163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18910219638983444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05643840002632905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20362376935246027,
                                 -0.23421409599182613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42907436586872805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14472013057723021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28773155127267608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6372021810439561,
                                 0,
                                 0,
                                 -0.20027114744713265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12886248178519411,
                                 -0.11334283092005289,
                                 0,
                                 -0.37450721754849475,
                                 0,
                                 0.35632620373837209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083099331108145144,
                                 0,
                                 0,
                                 0.26223661080621741,
                                 0,
                                 0,
                                 0.2815846206083174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20469535936363703,
                                 0.26112304699332728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74413116368592491,
                                 -0.14991973611950327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49933485283801043,
                                 0,
                                 0,
                                 0.80604451000593891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24058112030358114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82725423304283074,
                                 0,
                                 -0.53612966966844822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080398487773121127,
                                 0,
                                 -0.73732105602704245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16068232043951627,
                                 0.69941655331976316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41656097795583519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3656110503964447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26106117864180145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22495218273084788,
                                 0,
                                 0,
                                 0,
                                 -0.28464541852369807,
                                 -0.07056919360786576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49118942097274548,
                                 -0.45978410530117264,
                                 0,
                                 0,
                                 -0.45705649561363748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53015944315619024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01689958561077351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2317438876159354,
                                 0,
                                 0,
                                 0,
                                 0.28267573274067237,
                                 -0.23936646891149871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39839236357556812,
                                 -0.43388990157925356,
                                 0,
                                 0,
                                 0.42516037094695314,
                                 0,
                                 0,
                                 0,
                                 -0.095854670765836508,
                                 -0.13979728600934557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25603516962704592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12124638762098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21693728709101384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61406345970438958,
                                 0,
                                 0,
                                 0.11689785300701733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53156022442636763,
                                 0.03191586222960599,
                                 0,
                                 0.41187156341928194,
                                 0,
                                 0,
                                 -0.16041556937785389,
                                 -0.41596394468086578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28390214992026286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59140702935248379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038479575207825661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33193281587764195,
                                 0,
                                 0,
                                 0.37643903365792808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21322238440730043,
                                 -0.26083902265703202,
                                 0,
                                 -0.063331964685251554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24092154585126013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022392992924407877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2926748975111616,
                                 0,
                                 0,
                                 0,
                                 -0.33659129953387729,
                                 0.68625571461419976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47800021960656047,
                                 0.13467515406428052,
                                 0,
                                 0,
                                 0.15790677993882876,
                                 0,
                                 0,
                                 0,
                                 -0.47886479912127738,
                                 -0.030621766138461792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49195902798141494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071640243128623687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57633869603043486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080462336799702591,
                                 0,
                                 0,
                                 0.10361569544992114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029288878020776329,
                                 -0.37126218516854953,
                                 0,
                                 -0.18580812929581644};

const double rot_27_20[4000] = {0.61189581585409902,
                                0,
                                0,
                                0,
                                0,
                                0.34077706911615702,
                                0.30412889705485863,
                                0,
                                0,
                                0,
                                0,
                                0.45699412648550264,
                                -0.28755959548810733,
                                -0.24562690312414695,
                                0,
                                0,
                                0.25509187483006324,
                                0,
                                0,
                                -0.0046390665911016093,
                                0,
                                -0.029516466288688842,
                                -0.22576789638636913,
                                -0.51571777104414418,
                                0,
                                0,
                                0,
                                0.66217252090455181,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46291520628616911,
                                0.17155139217244686,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53964553163492424,
                                0.76906125561682892,
                                0.12712169414596752,
                                0,
                                0,
                                0,
                                0.31455068568994571,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.015883435517028383,
                                0.044420071827331459,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43973265526857519,
                                -0.28463719062187476,
                                -0.36311989084764884,
                                0,
                                0,
                                0,
                                0.16211713733065752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70259577356890468,
                                -0.27173152048108007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.058664599599679179,
                                0,
                                0,
                                0,
                                -0.22150289017640018,
                                -1.2811807347681181,
                                -0.24114081506027263,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65080639550591557,
                                -0.23480321991950925,
                                0,
                                0.050530365512450326,
                                0,
                                0,
                                0,
                                0,
                                -0.084554093848096604,
                                -0.4683751069037867,
                                0,
                                0,
                                0,
                                0,
                                0.15463507625221012,
                                0.068213342490717477,
                                -0.37032084879737959,
                                0,
                                0,
                                -0.020695390930924734,
                                0,
                                0,
                                -0.77768319349622961,
                                -0.26622987979458346,
                                0,
                                0,
                                0,
                                0,
                                0.00093303112853112408,
                                0.46487794063305454,
                                0,
                                0,
                                0,
                                0,
                                0.54895581313170427,
                                0.1691996742440367,
                                0.37318820016184134,
                                0,
                                0,
                                -0.35646014726374747,
                                0,
                                0,
                                -0.34160649438723889,
                                0,
                                0.6586693562629371,
                                0.43355559692033907,
                                -0.25812986579659492,
                                0,
                                0,
                                0,
                                0.24869771447900663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22441441795983888,
                                -0.44647599230833623,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71778966853222004,
                                0,
                                0,
                                0,
                                0.60366544452641291,
                                0.45936351119721713,
                                0.74944579707553038,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34031668171203322,
                                -1.0211356729698426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35438103355877487,
                                0,
                                0,
                                0,
                                0.13995468006110845,
                                1.0046399676247237,
                                -0.099705577830304343,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1793554775280892,
                                0.88675287566901195,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27873763444212157,
                                0,
                                0,
                                0,
                                -1.5803406785607499,
                                -0.14927858382103315,
                                0.57875355345822577,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16372639094234392,
                                0.11202667046866693,
                                0,
                                0.34066379536774827,
                                0,
                                0,
                                0,
                                0,
                                0.030598347642722967,
                                -0.46996238647250332,
                                0,
                                0,
                                0,
                                0,
                                0.1976452817716991,
                                0.20830361041098833,
                                0.7121589381431942,
                                0,
                                0,
                                0.26897965483378272,
                                0,
                                0,
                                0.013145932436912255,
                                0.45345834812634145,
                                0,
                                0,
                                0,
                                0,
                                -0.19936871628103112,
                                -0.20830613535633302,
                                0,
                                0,
                                0,
                                0,
                                0.096821978032683498,
                                0.032854399828118594,
                                -0.088707597148449308,
                                0,
                                0,
                                -0.79010783210367252,
                                0,
                                0,
                                0.26199783261364662,
                                -0.13556100592427633,
                                0,
                                0,
                                0,
                                0,
                                0.49867322904157518,
                                -0.12366667944475106,
                                0,
                                0,
                                0,
                                0,
                                0.1844455255007954,
                                0.72356688174454264,
                                -0.30630241674528491,
                                0,
                                0,
                                0.0014094944124662806,
                                0,
                                0,
                                0.25741490883759954,
                                0,
                                -0.11911850505246382,
                                -0.26658669826798981,
                                0.52770679793025721,
                                0,
                                0,
                                0,
                                0.31866212744416716,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24922778632137088,
                                -0.687464768942329,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25789945941969572,
                                0.13234949365542117,
                                -0.49082961216652127,
                                0,
                                0,
                                0,
                                -0.5224053481926505,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42348563938511269,
                                -0.4720278991701094,
                                0,
                                0,
                                0,
                                0,
                                -0.41773557792310601,
                                0,
                                0,
                                0,
                                0,
                                0.42963212939188478,
                                -0.42346188271779173,
                                0,
                                0,
                                0,
                                0,
                                0.29096330541394411,
                                -0.56159785921994809,
                                0.047442346344126148,
                                0,
                                0,
                                -0.17257502754153381,
                                0,
                                0,
                                0.17178049156150499,
                                0,
                                0,
                                0,
                                0,
                                -0.16871652836011247,
                                0,
                                0,
                                0,
                                -0.49513869090127832,
                                0.51434343023481788,
                                -1.0631613436338687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23050737207746386,
                                -0.6300712831507137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.93304176803030481,
                                0,
                                0,
                                0,
                                0.11031052671409694,
                                -0.50548249707875548,
                                -0.27993702987723401,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39213432143745863,
                                0.54127398306576413,
                                0,
                                0.19389623373393217,
                                0,
                                0,
                                0,
                                0,
                                0.63464779520019965,
                                0.11467069841953015,
                                0,
                                0,
                                0,
                                0,
                                -0.54660216516922677,
                                -0.024837384089384684,
                                0.22836182467273947,
                                0,
                                0,
                                -0.28466020398201225,
                                0,
                                0,
                                -0.33749915585118906,
                                0.061012889321668248,
                                0,
                                -0.082612451759110916,
                                0,
                                0,
                                0,
                                0.26244754500084616,
                                0,
                                0,
                                0,
                                0,
                                0.42451769558739338,
                                0,
                                0,
                                0,
                                0.69426752580184448,
                                -0.5082826231774541,
                                0,
                                0,
                                0,
                                0,
                                -0.33749321247506281,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0032644037424103128,
                                0,
                                0.74085852448245015,
                                0.32030349979659167,
                                0,
                                -0.20178263582156547,
                                0,
                                -0.43040383971618007,
                                0,
                                0,
                                0,
                                0.018441206873856503,
                                -0.091204245782294482,
                                -0.50224801875730596,
                                0,
                                0.63689818101594375,
                                0,
                                0,
                                0,
                                0.4083319905853483,
                                0,
                                0,
                                0,
                                0,
                                -0.38098545656497362,
                                0,
                                0,
                                0,
                                0.089340981797742663,
                                -0.14913380232174811,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65314950655827608,
                                -0.33850274407726422,
                                0.4693266520507533,
                                0,
                                0,
                                -0.10532405314292144,
                                0,
                                0,
                                0,
                                0,
                                1.020897719705143,
                                0,
                                0,
                                0,
                                0.45086481060673167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.78880199108890503,
                                0.5960883253859719,
                                -0.27174726721556786,
                                0,
                                0,
                                -0.40167961003000319,
                                0,
                                0,
                                0,
                                0,
                                0.085137271607624743,
                                0,
                                0,
                                0,
                                -0.86143706830740119,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10249283122310382,
                                -0.78796709989908309,
                                0.90964422408044565,
                                0,
                                0,
                                -0.29796582580470043,
                                0,
                                0,
                                0,
                                0,
                                -0.20414116413755234,
                                0,
                                0,
                                0,
                                -0.80347732678546258,
                                0,
                                0,
                                -0.24512246646315328,
                                0,
                                -0.037774852642170911,
                                0,
                                0,
                                0,
                                0.27529244102151007,
                                0,
                                0,
                                0,
                                0,
                                0.3109760305480968,
                                0,
                                0,
                                0,
                                0.31939449518889362,
                                0.81485162681734991,
                                0,
                                0,
                                0,
                                0,
                                0.042305758041981084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25552427360433966,
                                0,
                                -0.24342697454514264,
                                0.38095817715119507,
                                0,
                                -0.39103047540968855,
                                0,
                                0.11971608241054492,
                                0,
                                0,
                                0,
                                0.66076881475461136,
                                -0.3530999067145677,
                                0,
                                0,
                                0,
                                -0.21147945197249568,
                                0.12429944581260777,
                                -1.0692341210474126,
                                0,
                                0,
                                -1.2319952456523957,
                                0,
                                0,
                                0,
                                0,
                                0.21112421749512869,
                                0,
                                0,
                                0,
                                0.28877347817037324,
                                0,
                                0,
                                0,
                                -0.14836195239225938,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23202703988611484,
                                0,
                                0.32819390388057529,
                                0.062429596375047539,
                                0,
                                0.15779526580351413,
                                0,
                                0.74648772408956221,
                                0,
                                0,
                                0,
                                -0.1076896523998435,
                                -0.46776400185959194,
                                0,
                                -0.10482121403758396,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.84652150868887421,
                                0,
                                -0.28113507934612042,
                                0.29012820921046789,
                                0,
                                0.14882606847381688,
                                0,
                                -0.23975852435723063,
                                0,
                                0,
                                0,
                                0.15542062384374025,
                                -0.073577298271060521,
                                0.56226607086524616,
                                0,
                                -0.10981135646812014,
                                0,
                                0,
                                0,
                                0.77150105690936022,
                                0,
                                0,
                                0,
                                0,
                                -0.16813853380567867,
                                0,
                                0,
                                0,
                                -0.21372366178528795,
                                0.051342775294035928,
                                0,
                                0,
                                0,
                                0,
                                0.78085978053816529,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20761209997062385,
                                0,
                                0.35935642026710068,
                                -0.29073115661344723,
                                0,
                                0.0039966293564396571,
                                0,
                                -0.15442048576893297,
                                0,
                                0,
                                0,
                                0.23717348908240965,
                                -0.23104253607474273,
                                0,
                                0,
                                0,
                                0.34995160558430521,
                                -0.60601208120423733,
                                -0.7362329668376304,
                                0,
                                0,
                                0.20375820164851913,
                                0,
                                0,
                                0,
                                0,
                                -0.50887394218864801,
                                0,
                                0,
                                0,
                                0.30705507860553927,
                                0,
                                0,
                                0,
                                0.34517226558854852,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28100320402590895,
                                0,
                                -0.019476660297407383,
                                0.64970887506974295,
                                0,
                                0.57486948990513997,
                                0,
                                -0.081944487528935614,
                                0,
                                0,
                                0,
                                -0.19383797792931401,
                                -0.068039346021325497,
                                0.60198783329387895,
                                0,
                                0.56531393513040684,
                                0,
                                0,
                                0,
                                -0.30092125003581832,
                                0,
                                0,
                                0,
                                0,
                                -0.16549207547957256,
                                0,
                                0,
                                0,
                                0.38986614340830356,
                                0.21930336925773949,
                                0,
                                0,
                                0,
                                -0.073531255571362725,
                                0,
                                -0.5044507617982148,
                                0,
                                0,
                                0,
                                -0.05322465564636443,
                                0,
                                0,
                                0,
                                0,
                                -0.72268286464177212,
                                0,
                                0,
                                0,
                                0.45861152912727376,
                                0.068517602930430799,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26930935688965035,
                                -0.45568580459103314,
                                -0.53192422568189679,
                                0,
                                0,
                                1.0003287709151791,
                                0,
                                0,
                                0,
                                0,
                                0.70384098181505306,
                                0,
                                0,
                                0,
                                -0.70176470051515394,
                                0,
                                0,
                                0,
                                0.31976119004539227,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20480091887659027,
                                0,
                                0.12624754058028445,
                                0.39163082717198006,
                                0,
                                -0.46449255076338392,
                                0,
                                0.34643917195913476,
                                0,
                                0,
                                0,
                                -0.15238803258698791,
                                0.57227674827476749,
                                0,
                                -0.14204467637652515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.015889501447391263,
                                0,
                                0.24427231688438975,
                                -0.064682071974200173,
                                0,
                                0.46161256203629975,
                                0,
                                0.18738152743064881,
                                0,
                                0,
                                0,
                                0.640503962282719,
                                0.50722261234499122,
                                0.14126070584285022,
                                0,
                                0.26061643715719596,
                                0,
                                0.59041449287696524,
                                0,
                                0.20325701898701659,
                                -0.22134236507063376,
                                -0.51934102436801599,
                                -0.11240906837390779,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43689639009979453,
                                0,
                                0,
                                0.26504171314526126,
                                0,
                                0.068926742349643758,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12500469049329094,
                                0,
                                -0.10169469422878764,
                                0,
                                -0.52605887498166182,
                                0,
                                0,
                                0,
                                0.78885744659951629,
                                -0.43218681614005033,
                                0,
                                -0.28150061714777697,
                                0,
                                0.51147422122906061,
                                0,
                                -0.055879858208903205,
                                0.17568575589771074,
                                0.54199973729285322,
                                -0.19763349495031274,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3248927862967792,
                                0,
                                0,
                                -0.26004472323573963,
                                0,
                                0.33697071164121112,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19056932253327957,
                                0,
                                -0.20896391091431674,
                                0,
                                -0.7421216397454935,
                                0,
                                0,
                                0,
                                -0.43370539595366253,
                                -0.13902572136429622,
                                0,
                                -0.14318975111471047,
                                0,
                                -0.10610319573717233,
                                0,
                                -0.63914972753356147,
                                -0.25932348670656169,
                                -0.12823712016858319,
                                0.52711700888649171,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42290957759165987,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3186334651649441,
                                0,
                                0,
                                0,
                                0,
                                -0.34457555952183416,
                                0,
                                -0.19873445037183674,
                                0,
                                -0.09666095354006321,
                                0,
                                0.72089995532878626,
                                -0.73600676653589658,
                                0,
                                0,
                                -0.65277848944681705,
                                0,
                                -0.098738272622501899,
                                0,
                                -0.027045443515926373,
                                0,
                                0.29962275613279049,
                                -0.6121059107218294,
                                -0.12854626332171912,
                                0.052867301959313093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28219320660929964,
                                0,
                                -0.1483058097945831,
                                0,
                                0.019184827086190501,
                                0,
                                -0.55443014674582436,
                                0,
                                -0.033193312774034395,
                                -0.099147986893832585,
                                -0.083047651925315977,
                                -0.64491080207541418,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48631838041387521,
                                0,
                                0.5482097923408904,
                                0,
                                -0.1953234830085937,
                                0,
                                0.065247895705755982,
                                0,
                                -0.01481666858640697,
                                -0.6684150890731968,
                                0.43692983765587279,
                                -0.13835365277134654,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0031291268827044602,
                                0,
                                -0.10057511582904952,
                                0,
                                0.30243902453612026,
                                0,
                                0.24002555956892208,
                                0,
                                -0.67002449952084342,
                                -0.10172791123550512,
                                -0.087788784429638125,
                                -0.43600783489459261,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42861627666670155,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2355150468115583,
                                0,
                                0,
                                0,
                                0,
                                -1.1899375642813304,
                                0,
                                0.67029744015247694,
                                0,
                                0.07078791528721412,
                                0,
                                0.70990244478934916,
                                0.16999598774067018,
                                0,
                                0,
                                0,
                                0.82687266176676455,
                                0,
                                0.36223649183273993,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.054929925801628601,
                                0,
                                0.29213404134866466,
                                0,
                                -0.041514779993320566,
                                0,
                                0,
                                0,
                                -0.30819353235635183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30027383176104938,
                                0,
                                0,
                                0,
                                0,
                                0.13347861301139746,
                                0,
                                1.0229538366430548,
                                0,
                                -1.0612710552740197,
                                0,
                                -0.11193298527815361,
                                -0.36532283022277917,
                                0,
                                0,
                                0,
                                -0.26439935651513602,
                                0,
                                0.81948583331597158,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34392757303318772,
                                0,
                                -0.11972590450686527,
                                0,
                                0.31728778408226965,
                                0,
                                0,
                                0,
                                0.15888342782835335,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49231786772075126,
                                0,
                                0,
                                0,
                                0,
                                -0.67619176789134372,
                                0,
                                -0.3940791376265253,
                                0,
                                -0.67570629013939332,
                                0,
                                -0.54597144035010414,
                                -0.094231371258544874,
                                0,
                                0,
                                0,
                                0.016171219551564892,
                                0,
                                0.27559209875451829,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.90668177565707686,
                                0,
                                0.071399634313702026,
                                0,
                                0.18715614440953998,
                                0,
                                0,
                                0,
                                0.24817395972029521,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37925368675384841,
                                0,
                                0,
                                0,
                                0,
                                -0.11148863540040305,
                                0,
                                0.57214381871865572,
                                0,
                                0.84139470680987793,
                                0,
                                -0.88177525631738218,
                                -0.57684041658642971,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.82338550511646746,
                                0,
                                0,
                                0,
                                0,
                                -0.22753973396547308,
                                0,
                                -0.065444540852858113,
                                0,
                                0.22582847004368531,
                                0,
                                0.16282472207478943,
                                1.5658483815502606,
                                0,
                                0,
                                0.12315891316859992,
                                0,
                                -0.83222307091120484,
                                0,
                                0.092483288746284253,
                                0,
                                -0.083807492750694532,
                                0.10612319902446626,
                                -0.44501777288532446,
                                -0.20616353312098346,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15764971889553031,
                                0,
                                0,
                                0.32900259173084839,
                                0,
                                -0.054557600463165587,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068424017085695579,
                                0,
                                -0.91717924910907467,
                                0,
                                0.18733684794645389,
                                0,
                                0,
                                0,
                                -0.088238580888091986,
                                -0.16205092191311465,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8473517782875204,
                                0,
                                0,
                                0.22652692453995704,
                                -0.4955547507788467,
                                0,
                                0,
                                0,
                                0,
                                -0.58377170577626947,
                                0,
                                0,
                                -0.95016109296437412,
                                0,
                                -0.53247226414789051,
                                -0.10907079829239705,
                                0,
                                -0.11499340697469496,
                                -0.40214343857081564,
                                -0.51037616210891912,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29053437718952058,
                                0.17839307422007439,
                                0,
                                0,
                                0,
                                -0.39104460095013505,
                                0,
                                0,
                                0,
                                0.38525626097413607,
                                -0.42551206249597168,
                                0,
                                -0.052565422437124816,
                                -0.48704361721722145,
                                -0.11512300827476445,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28529479454464679,
                                -0.54413738643790543,
                                0,
                                0,
                                0,
                                -0.19952585595517941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.020442175652080355,
                                0,
                                0,
                                0,
                                0,
                                0.5869430269076108,
                                -0.45475426796115409,
                                0,
                                0,
                                0,
                                0,
                                0.24852743123525031,
                                -0.62057291767932221,
                                0,
                                0,
                                0.037442304374026708,
                                0,
                                0,
                                0.090189272070999221,
                                -0.45678636718356069,
                                0,
                                -0.55505914392777178,
                                0.099834262779535679,
                                0.50433133504896455,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29155561806712155,
                                0.22599235401577936,
                                0,
                                0,
                                0,
                                -0.27336286994326681,
                                0,
                                0,
                                0,
                                0.29163362448498908,
                                0.015609993905029915,
                                0,
                                -0.41396522201841945,
                                -0.3650445680231354,
                                -0.26370520087099192,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.062469834007071776,
                                0.34759322455234021,
                                0,
                                0,
                                0,
                                0.64483909046683996,
                                0,
                                0,
                                0,
                                0.26094080023824962,
                                0.22007734031072274,
                                0,
                                -0.30492836673688539,
                                0.3808946848849063,
                                -0.37751695163503685,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52436613541693411,
                                -0.4744871494083131,
                                0,
                                0,
                                0,
                                -0.052885210984316811,
                                0,
                                0,
                                -0.12653407767150338,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.025123656035771033,
                                0,
                                0,
                                -0.10786891868825477,
                                0.78092913213698778,
                                0,
                                0,
                                0,
                                0,
                                0.66019695799607891,
                                0,
                                0,
                                -0.90066089160695706,
                                0,
                                0,
                                0,
                                0.045744920027730368,
                                0,
                                0,
                                0,
                                0,
                                0.68706452106311122,
                                0.56389163119685126,
                                0,
                                0,
                                0,
                                0,
                                -0.4427343514540022,
                                0.05202644029800324,
                                0,
                                0,
                                -0.095684471084135053,
                                0,
                                0,
                                0,
                                0,
                                0.44521157859386573,
                                0,
                                0,
                                0,
                                0,
                                0.27921996769209034,
                                0.16177937916893853,
                                0,
                                0,
                                0,
                                0,
                                0.68478124645648153,
                                0.41902224005076122,
                                0,
                                0,
                                0.23053264247835159,
                                0,
                                -0.052832757913199996,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58879607845501336,
                                0,
                                0,
                                0.87673312427601169,
                                -0.19332546178998805,
                                0,
                                0,
                                0,
                                0,
                                0.60274426174972606,
                                0,
                                0,
                                0.33267534875076399,
                                0.59184271531073307,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48374461240484601,
                                0,
                                0,
                                0.10583265199533254,
                                0.69849886082329316,
                                0,
                                0,
                                0,
                                0,
                                -0.7007389398206989,
                                0,
                                0,
                                0.31406158400109885,
                                0,
                                -0.62129687563859792,
                                -0.26017727488609227,
                                0,
                                -0.19805185109237383,
                                0.05504571314995936,
                                0.14246584197724194,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.013462906732301008,
                                -0.47565496851887129,
                                0,
                                0,
                                0,
                                0.50726521330818952,
                                0,
                                0,
                                0,
                                -0.14370473324816047,
                                0.49655294162043917,
                                0,
                                -0.60604331394175637,
                                0.0014961944219915547,
                                0.025813562676078237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55172283269767408,
                                -0.061783367878748198,
                                0,
                                0,
                                0,
                                -0.23793230162062995,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49908398977303026,
                                0,
                                0,
                                0,
                                0,
                                -0.1091731075165089,
                                0.56018643393784529,
                                0,
                                0,
                                0,
                                0,
                                0.51258252581143926,
                                -0.30774383819314183,
                                0,
                                0,
                                -0.26026995075563242,
                                0,
                                0,
                                0,
                                0,
                                0.097262574610983421,
                                0,
                                0,
                                0,
                                0,
                                0.11245725061907587,
                                -0.25197884305341123,
                                0,
                                0,
                                0,
                                0,
                                0.092595188907330095,
                                0.26982331699048967,
                                0,
                                0,
                                -0.91270013126775218,
                                0,
                                -0.65780625044577146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20545057955392565,
                                0,
                                0,
                                -1.2273529117394073,
                                0.14175853778195147,
                                0,
                                0,
                                0,
                                0,
                                0.78953549667394773,
                                0,
                                0,
                                0.58013511863145639,
                                0,
                                0.010754826884388967,
                                -0.48523655525785347,
                                0,
                                -0.071142051434588197,
                                0.55653546424910472,
                                -0.48876418927528947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4071244519059668,
                                0.21211773463289876,
                                0,
                                0,
                                0,
                                0.0014897273014100841,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73534436338663822,
                                0,
                                0,
                                0,
                                0,
                                -0.28444865280268983,
                                0.26786197639539305,
                                0,
                                0,
                                0,
                                0,
                                -0.0445010077604992,
                                -0.51874075737128689,
                                0,
                                0,
                                -0.18850803618400416,
                                0,
                                0.91055912588223442,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55784223385921394,
                                0,
                                0,
                                -0.28179903001794804,
                                -0.6013420641430649,
                                0,
                                0,
                                0,
                                0,
                                0.71621254435874715,
                                0,
                                0,
                                -0.20490572432477955,
                                -0.92623368026085751,
                                0,
                                0.84487261052117291,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18015855581568591,
                                0,
                                0,
                                0,
                                -0.41035180613966016,
                                0.36037920252220906,
                                0,
                                0,
                                0,
                                0,
                                -0.16698099873170744,
                                0,
                                0,
                                -0.24429199569213064,
                                0,
                                0.17517792920563791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.055628223152122971,
                                -0.20862844233510475,
                                0,
                                0,
                                0,
                                0,
                                0.25032020009649736,
                                0.89462482931192777,
                                0,
                                0,
                                0.13960511556922198,
                                0,
                                -0.17764079792306456,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15835060981935872,
                                0,
                                0,
                                0,
                                -1.3181884624607569,
                                0.1556309037325293,
                                0,
                                0,
                                0,
                                0,
                                -0.034335957632147723,
                                0,
                                0,
                                -0.76237691879770542,
                                0,
                                -0.32315283239485482,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27858399838386166,
                                -0.4172938473974821,
                                0,
                                0,
                                0,
                                0,
                                -0.078778166391787197,
                                -0.23749627758833511,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72561335402962879,
                                -0.22567536950545883,
                                -0.16925092293762981,
                                -0.24297677918832775,
                                0,
                                0.42491071936317332,
                                0,
                                0,
                                0,
                                0,
                                0.0070049465887845608,
                                -0.38347575242098964,
                                0,
                                0,
                                0,
                                -0.084973269392141129,
                                0,
                                0,
                                0,
                                0,
                                -0.16599861992800893,
                                -0.22203511351658678,
                                -0.11549055746770644,
                                0.81405056910207019,
                                0,
                                -0.26964236692337346,
                                0,
                                0,
                                0,
                                0,
                                0.28388837526706046,
                                -0.30064075780453831,
                                0,
                                0,
                                0,
                                -0.05868549840435984,
                                0,
                                0,
                                0,
                                0,
                                0.18407260202771003,
                                0.1250730049019024,
                                -0.67477134273644834,
                                -0.16875382752288767,
                                0,
                                -0.25891900331244055,
                                0,
                                0,
                                0,
                                0,
                                -0.1392574184285037,
                                -0.17562354816559125,
                                0,
                                0,
                                0,
                                -0.59110446776490522,
                                0,
                                0,
                                0,
                                0,
                                -0.055804598059678627,
                                0.74390588912680944,
                                0.038088388768328874,
                                0.33072381993846678,
                                0,
                                0.26692204349632714,
                                0,
                                0,
                                0,
                                0,
                                -0.41845078528495022,
                                -0.28565330536921235,
                                0,
                                0,
                                0,
                                0.068663357374863163,
                                0.69568340098473391,
                                0,
                                0.97030566221621528,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44159835414603765,
                                0,
                                0,
                                0,
                                -0.35475696242632848,
                                -0.480231798629221,
                                0,
                                0,
                                0,
                                0,
                                -0.49807892648287388,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38895639810519678,
                                -0.26980158932400944,
                                0.015662785853039173,
                                -0.19165936390979277,
                                0,
                                -0.13259615829963867,
                                0,
                                0,
                                0,
                                0,
                                -0.21502734640247753,
                                -0.70649058068555259,
                                0,
                                0,
                                0,
                                0.41951632464322952,
                                0,
                                0.04266760553214876,
                                0,
                                0.16554072486575208,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58693062918699779,
                                -0.54910826337791474,
                                0,
                                0,
                                0,
                                0,
                                0.50968361288624575,
                                -0.25493314852436066,
                                0,
                                0,
                                0,
                                0.017748625020652664,
                                0,
                                -0.62473394106884794,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.075042179595547723,
                                0.36324669817540617,
                                0,
                                0,
                                0,
                                0,
                                0.68672105696855923,
                                0.015072712053910003,
                                0,
                                0,
                                -0.25721836048351931,
                                0,
                                -0.24778493494343762,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.94683666573399872,
                                0,
                                0,
                                0,
                                0.86086978901782307,
                                0.35105586858113774,
                                0,
                                0,
                                0,
                                0,
                                -1.0143067350853334,
                                0,
                                -0.45199382535009125,
                                0,
                                0.1362361176532223,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53485777895200193,
                                0,
                                0,
                                0,
                                -0.012431233487917831,
                                -0.96831242492850034,
                                0,
                                0,
                                0,
                                0,
                                -0.020173152356083079,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16688381922985321,
                                -0.28070326920566219,
                                -0.43278457371239432,
                                0.18735613613368179,
                                0,
                                -0.06636876227392316,
                                0,
                                0,
                                0,
                                0,
                                -0.60802857633691942,
                                0.38269413507072297,
                                0,
                                0,
                                0,
                                0.38780445237329064,
                                0,
                                0,
                                0,
                                0,
                                0.40291424631991568,
                                -0.39894645716625632,
                                0.11950799025106136,
                                0.2592163448076511,
                                0,
                                0.6212908714057328,
                                0,
                                0,
                                0,
                                0,
                                -0.23400474752297121,
                                0.02693338049238524,
                                0,
                                0,
                                0,
                                -0.3943863404550515,
                                0,
                                0.05161557609090188,
                                0,
                                -0.60603433262921547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58966476838773063,
                                -0.08994143419309468,
                                0,
                                0,
                                0,
                                0,
                                -0.44665442373660819,
                                0.273430146606987,
                                0,
                                0,
                                0,
                                -0.59523369240837365,
                                0,
                                0.28268551253393881,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47060920662408035,
                                0.58376579870961942,
                                0,
                                0,
                                0,
                                0,
                                0.01644470587528353,
                                -0.057094579178466012,
                                0,
                                0,
                                0.81471181527756342,
                                0,
                                0.040471271250109853,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0165048356281872,
                                0,
                                0,
                                0,
                                0.18583435880823868,
                                0.30575314393158814,
                                0,
                                0,
                                0,
                                0,
                                1.2494350623999322,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25972228248411755,
                                -0.14137294260747243,
                                0.54719191884136775,
                                -0.037404670896259019,
                                0,
                                -0.44773713968798301,
                                0,
                                0,
                                0,
                                0,
                                -0.50415364881360514,
                                -0.061732421899330647,
                                0,
                                0,
                                0,
                                -0.39152213455688878,
                                -0.047990276008926247,
                                0,
                                0,
                                -0.53250757158565221,
                                -0.16096977902759863,
                                0,
                                0,
                                0,
                                -0.1508815843811796,
                                0,
                                0,
                                -1.1560789131537799,
                                0,
                                0.406897887431587,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44456795399244309,
                                0,
                                0,
                                0,
                                -0.15371890179421238,
                                0.43798408095414931,
                                0,
                                0,
                                0,
                                -0.34987798702593753,
                                0,
                                0,
                                0,
                                -0.17520905287853764,
                                -0.51114021279202215,
                                0,
                                -0.035547208690949288,
                                0,
                                0.41383455528773244,
                                0,
                                0,
                                0.14490880938225317,
                                0,
                                0,
                                0,
                                0,
                                -0.1695464108478999,
                                0,
                                0.79377613784817336,
                                0,
                                0,
                                0.25878938997066075,
                                0,
                                0,
                                0,
                                0.46495234531768775,
                                0,
                                0.19241170114378531,
                                0,
                                -0.83937249003377068,
                                0,
                                0,
                                1.0499920292020553,
                                -0.81459229040805059,
                                0,
                                0,
                                0,
                                -0.17069416307444907,
                                0,
                                0,
                                -0.80983435144522631,
                                0,
                                0.56570618412250628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13183447961550768,
                                0,
                                0,
                                -1.0189392716650381,
                                -1.3352336982741173,
                                0,
                                0,
                                0,
                                0.17464931972451747,
                                0,
                                0,
                                0.5008085049239821,
                                0,
                                0.45381847626730876,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.064317692635019102,
                                0,
                                0,
                                0,
                                -0.10927484153177489,
                                -0.029033558139878436,
                                0,
                                0,
                                0,
                                -0.60224351659178244,
                                0,
                                0,
                                0,
                                -0.42433278546333159,
                                0.12438287854067287,
                                0,
                                0.27612030647351915,
                                0,
                                -0.59043221940122004,
                                0,
                                -0.36554815611852426,
                                0,
                                0,
                                0,
                                -0.21018761682881926,
                                -0.42948447855756511,
                                0,
                                0,
                                0,
                                -0.20865270105665285,
                                0,
                                0,
                                0,
                                -0.1177400963667449,
                                0.39097535776031261,
                                0,
                                -0.62662393252480797,
                                0,
                                0.1866034051912189,
                                0,
                                0,
                                -0.21653437420482721,
                                0,
                                0,
                                0,
                                0,
                                -0.14480660852627025,
                                0,
                                0.091182737452835783,
                                0,
                                0,
                                -0.1232012235457727,
                                0,
                                0,
                                0,
                                -0.42542556998066339,
                                0,
                                0.8530323336362472,
                                0,
                                -0.71103893741175028,
                                0,
                                0,
                                -0.61838000048667796,
                                0.94346037594798438,
                                0,
                                0,
                                0,
                                0.80722522290992538,
                                0,
                                0,
                                -0.20717806330915789,
                                0,
                                0.66726738318581214,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22128491512670617,
                                0,
                                0,
                                0,
                                0,
                                -0.042713064649108845,
                                0,
                                -0.10294054596590309,
                                0,
                                0,
                                -0.82456336129479013,
                                0,
                                0,
                                0,
                                0.47632440425891009,
                                0,
                                0.17838763847173372,
                                0,
                                0,
                                -0.55261528844478502,
                                0,
                                0,
                                0,
                                0.3718116260079018,
                                0.31778565704570255,
                                0,
                                0,
                                0,
                                0.1556433223837502,
                                0,
                                0,
                                0,
                                0.0058559411055876393,
                                0.57432640354144149,
                                0,
                                0.3085143833175068,
                                0,
                                0.078061870019659557,
                                -1.2144029691329135,
                                0,
                                0,
                                -0.54098636788896526,
                                0.10362205380884305,
                                0,
                                0,
                                0,
                                -0.3301626806094457,
                                0,
                                0,
                                -0.120466692421262,
                                0,
                                -1.1462780340333716,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27027039049076457,
                                0,
                                0,
                                0,
                                0,
                                0.24365885622606076,
                                0,
                                0.54038393461103085,
                                0,
                                0,
                                -0.40194989649875806,
                                0,
                                0,
                                0,
                                -0.5734434740895813,
                                0,
                                -0.29183615908517518,
                                0,
                                0.53739496824768973,
                                0,
                                0,
                                0.094046356586819702,
                                -0.091762614259234987,
                                0,
                                0,
                                0,
                                1.0235308655964301,
                                0,
                                0,
                                -0.60906781118083542,
                                0,
                                -0.76747586931375344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37504876159914219,
                                0,
                                0,
                                0,
                                0.46892308007356004,
                                0.29690832630419961,
                                0,
                                0,
                                0,
                                -0.56713287539073054,
                                0,
                                0,
                                0,
                                0.3050013618922936,
                                0.18681283109849953,
                                0,
                                -0.29641186084600235,
                                0,
                                0.11777292961532629,
                                0,
                                0.32344550088725033,
                                0,
                                0,
                                0,
                                -0.66251953561125632,
                                0.49141359232181925,
                                0,
                                0,
                                0,
                                0.060057169817586895,
                                0,
                                0,
                                0,
                                -0.064427204505282235,
                                0.43317462091377645,
                                0,
                                0.00076647882524696204,
                                0,
                                0.13987489463859681,
                                0,
                                0,
                                -0.78994018391434595,
                                0,
                                0,
                                0,
                                0,
                                -0.38905981498033115,
                                0,
                                0.21582811563039367,
                                0,
                                0,
                                -0.27553568261605305,
                                0,
                                0,
                                0,
                                0.021176458786974856,
                                0,
                                -0.31886805407068125,
                                0,
                                0,
                                0.31426255356505328,
                                0,
                                0,
                                0,
                                0.33401255331752117,
                                -0.015472115690221021,
                                0,
                                0,
                                0,
                                0.15115139083821297,
                                0,
                                0,
                                0,
                                -0.81224828443888697,
                                0.049387146982670022,
                                0,
                                -0.056944637973640855,
                                0,
                                0.31805577291077824,
                                0,
                                0,
                                0.43138811985246794,
                                0,
                                0,
                                0,
                                0,
                                -0.85890830532372542,
                                0,
                                -0.11140836183797562,
                                0,
                                0,
                                0.021474209545844641,
                                0,
                                0,
                                0,
                                -0.21601296839523182,
                                0,
                                -0.1290203310262362,
                                0,
                                0,
                                -0.12318254356048916,
                                0,
                                0,
                                0,
                                0.10780265706674119,
                                0.43817929763434382,
                                0,
                                0,
                                0,
                                0.31469674689956562,
                                0,
                                0,
                                0,
                                -0.13572944272050735,
                                -0.12479446245043807,
                                0,
                                -0.58613311137205593,
                                0,
                                -0.55192512624505696,
                                -0.10616440956139611,
                                0,
                                0,
                                0,
                                -0.55210167085322825,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.01715574251009036,
                                -0.089221815097080409,
                                0,
                                0.42445834039412589,
                                0,
                                0,
                                1.4149693806190078,
                                0,
                                0,
                                0,
                                0,
                                -0.41449716921155777,
                                0,
                                0.26609605136872222,
                                0,
                                -0.70427170674011408,
                                -0.10127338710077788,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4022817518209113,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29883012643303075,
                                0,
                                0,
                                0,
                                -0.39588918721213506,
                                0,
                                0,
                                0,
                                0,
                                0.36390093899824294,
                                -0.39428485756403414,
                                0.22049444125160608,
                                0,
                                0,
                                0,
                                0,
                                0.093328008828331338,
                                0.43284192572984431,
                                0,
                                0.51733306972544135,
                                0,
                                0.20754217784497192,
                                0,
                                -0.59459036192359838,
                                0,
                                -0.45688595520358022,
                                0,
                                0.071514739427371327,
                                -0.59579099394748758,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17292300689168116,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21848087492619564,
                                0,
                                0.71678299848532367,
                                0,
                                0,
                                0,
                                -1.0355416860816813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.056937979732186637,
                                -0.18246752902015206,
                                0,
                                -0.45592455960949441,
                                0,
                                0,
                                -0.41553542590210663,
                                0,
                                0,
                                0,
                                0,
                                0.546504752167976,
                                0,
                                -0.44430749376889161,
                                0,
                                -0.037378093559260091,
                                -0.44574971789576584,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48561374371226979,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26079257250562121,
                                0,
                                0,
                                -0.2818802081082557,
                                0,
                                0.057169244233130793,
                                0,
                                0.51939287518305643,
                                0.0089551828018190338,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.014316891928905645,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80450052722556942,
                                0,
                                0,
                                0,
                                -0.24613240816351684,
                                0,
                                0,
                                0,
                                0,
                                -0.013566521973175261,
                                -0.50241233254192874,
                                0.0036957849762798423,
                                0,
                                0,
                                0,
                                0,
                                0.13525016608689705,
                                0.2362524117517063,
                                0,
                                -0.78272071518828146,
                                0,
                                -0.0065915814855513344,
                                0,
                                0,
                                -0.33158779583961395,
                                0,
                                0,
                                0,
                                0,
                                0.21271918368100826,
                                0.67614835008880114,
                                -0.043630714039626303,
                                0,
                                0,
                                0,
                                0,
                                0.035540639613425837,
                                0.50540428410233695,
                                0,
                                -0.17228425144077258,
                                0,
                                -0.31518464629683435,
                                0,
                                0,
                                0.40590594305250516,
                                0,
                                0,
                                0,
                                0,
                                0.2932752507991101,
                                -0.10952847008080119,
                                0.14704214542476512,
                                0,
                                0,
                                0,
                                0,
                                -0.78732162869640132,
                                0.28221612194462131,
                                0,
                                -0.11208736867448187,
                                0,
                                -0.059390652960147589,
                                -0.63688883683853348,
                                0,
                                0,
                                0,
                                -0.35164708907642994,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38549396169463929,
                                0.43117662813768087,
                                0,
                                -0.53644805118422689,
                                0,
                                0,
                                0.40518719872849768,
                                0,
                                0,
                                0,
                                -0.12038140903055353,
                                0,
                                0,
                                0,
                                -0.15429176724756752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80495670948417286,
                                -0.074652382997433597,
                                0,
                                0.74589354224148507,
                                0,
                                0,
                                -0.28718155708574289,
                                0,
                                0,
                                0,
                                0,
                                0.055963648851154901,
                                0,
                                -0.58178591121882572,
                                0,
                                -0.43774726113059137,
                                0.35573291974416738,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48023400571245944,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33105882929604236,
                                0,
                                -0.32143367319486316,
                                0,
                                0,
                                0,
                                -0.12655308269564217,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63957440791777664,
                                0.47931826206708716,
                                0,
                                0.58475386622143888,
                                0,
                                0,
                                -0.65791908095255014,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.029485642649007104,
                                0,
                                0,
                                0,
                                0,
                                -0.67584493994323214,
                                -0.18212081504359445,
                                0.27214112380059441,
                                0,
                                0,
                                0,
                                0,
                                -0.039399273260307344,
                                0.30712913546367593,
                                0,
                                0.21109259204398184,
                                0,
                                -0.54285793767352986,
                                0,
                                0,
                                -0.11185505433084886,
                                0,
                                0,
                                0,
                                0,
                                0.44805476439545577,
                                -0.10694425641668255,
                                0.41099320444044057,
                                0,
                                0,
                                0,
                                0,
                                0.079339745082141866,
                                -0.47808822300764153,
                                0,
                                -0.027472726128155739,
                                0,
                                -0.60890474791811255,
                                1.0412121223725794,
                                0,
                                0,
                                0,
                                0.29322642517963909,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.098834924391757728,
                                1.2727229735952907,
                                0,
                                0.25111617138244002,
                                0,
                                0,
                                -0.2433878060955027,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67515599865940357,
                                0,
                                0,
                                0,
                                0,
                                -0.26609727176384945,
                                0.10218231802806296,
                                0.15977735909534777,
                                0,
                                0,
                                0,
                                0,
                                -0.55135021981864774,
                                -0.30914548972635825,
                                0,
                                -0.038101888452942045,
                                0,
                                0.19072712502705499,
                                0,
                                0.30561180010775046,
                                0,
                                0.4257884420526068,
                                0,
                                -0.18999542055960428,
                                -0.55628938162014363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5844798064262392,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.195276343145599,
                                0,
                                0,
                                0,
                                0.19688552338216034,
                                0,
                                0,
                                0,
                                0,
                                -0.088346021167058836,
                                0.26057998915724512,
                                0.8119966138923671,
                                0,
                                0,
                                0,
                                0,
                                0.20006156174315343,
                                0.057320561320574448,
                                0,
                                -0.17522199768373833,
                                0,
                                0.39009949473836514,
                                0.19838963540889867,
                                0,
                                0,
                                -0.45207489452205507,
                                0,
                                -0.4632010176516122,
                                0,
                                0,
                                0,
                                0,
                                0.50570176726720717,
                                0,
                                -0.37392603845156092,
                                0,
                                0.014794639099934398,
                                0.38149166830176545,
                                0,
                                0,
                                0,
                                -0.020122762551582761,
                                0,
                                0.24856387913689487,
                                0,
                                0,
                                0.90300400945308879,
                                0,
                                0,
                                0,
                                0.21839250422093692,
                                -0.58342783860740366,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29573526320872418,
                                0.3411973029289832,
                                0,
                                0,
                                0,
                                0,
                                -0.2431275192804786,
                                0,
                                0,
                                0,
                                -0.72647157272559204,
                                -0.39546209249599745,
                                0,
                                0,
                                0,
                                -0.042540327816858986,
                                0,
                                0.38957531673297596,
                                0,
                                0,
                                0,
                                0,
                                -0.32118404364234515,
                                0,
                                -0.025519254824569827,
                                0,
                                0,
                                -0.47689739672373299,
                                0,
                                0.17228946136688222,
                                0,
                                0,
                                0,
                                0,
                                0.16444001978474729,
                                0,
                                0.014332441140691876,
                                0,
                                -0.41941831793216466,
                                -0.55565178936304482,
                                0,
                                0,
                                0,
                                -0.47992437604061799,
                                0,
                                0.71685074557879713,
                                0,
                                0,
                                -0.14126127968861851,
                                0,
                                0,
                                0,
                                -0.69611946756936538,
                                0.56479144803338099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1266625906334722,
                                -0.57774617171980824,
                                0,
                                0,
                                -0.62451010262560303,
                                0,
                                0,
                                -0.52843639063880954,
                                0,
                                0.032833622881549583,
                                0,
                                0,
                                0,
                                0,
                                -0.1747669485854359,
                                0,
                                0.28009219047267514,
                                0,
                                0.40232129854182425,
                                0.22415034252723998,
                                0,
                                0,
                                0,
                                -0.092537242116641563,
                                0,
                                0,
                                0.55506911368785949,
                                0,
                                0,
                                0,
                                -0.18141420918736723,
                                0.53717290924592009,
                                0,
                                0,
                                0,
                                0.13589119410848202,
                                0,
                                0.084058371778115815,
                                0,
                                0,
                                0,
                                0,
                                -0.58728204706491183,
                                0,
                                0,
                                0,
                                -0.0084110257004364891,
                                0,
                                0,
                                0,
                                -0.34963263741250056,
                                0.5471146552505245,
                                0,
                                0,
                                0,
                                -0.11456378757942726,
                                0,
                                0.40686028128433027,
                                0,
                                0,
                                0,
                                0,
                                0.6322117347862477,
                                0,
                                0,
                                -0.60966417839777576,
                                0,
                                0,
                                -0.95992348144496942,
                                0,
                                0,
                                0,
                                -0.29027384914199972,
                                -1.2829618882828515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4150436623953932,
                                -0.21457113027417477,
                                0,
                                0,
                                0,
                                0.31646262029805911,
                                0,
                                0,
                                -0.023766994765840377,
                                0,
                                0,
                                0,
                                -0.96869889503505835,
                                -0.40388074575674243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30488682570946707,
                                0.48885168007608448,
                                0,
                                0,
                                0.236985841320072,
                                0,
                                0,
                                0.22540397417776833,
                                0,
                                -0.23401829954235467,
                                0,
                                0,
                                0,
                                0,
                                0.33236367289014146,
                                0,
                                0.69702640144271055,
                                0,
                                0.2004701233489172,
                                0.071182045494463886,
                                0,
                                0,
                                0,
                                -0.44350831513791511,
                                0,
                                0,
                                -0.45010105975549403,
                                0,
                                0,
                                0,
                                0.012799439754824213,
                                0.35933481422234903,
                                0,
                                0,
                                0,
                                -0.72776738167140365,
                                0,
                                -0.21948807878593585,
                                0,
                                0,
                                0,
                                0,
                                -0.30050511323893098,
                                0,
                                -0.49370831528081993,
                                0,
                                0,
                                0.41599644044726991,
                                0,
                                -0.30428058624680659,
                                0,
                                0,
                                0,
                                0,
                                -0.097450970297580847,
                                0,
                                -0.31220350748844106,
                                0,
                                -0.24658443629548552,
                                0.18464442508840648,
                                0,
                                0,
                                0,
                                -0.53735204117194413,
                                0,
                                0,
                                0.53862029906593933,
                                0,
                                0,
                                0,
                                -0.40637947772265803,
                                -0.24215948435685861,
                                0,
                                0,
                                0,
                                -0.40775170234150004,
                                0,
                                -0.50930533633885877,
                                0,
                                0,
                                0,
                                0,
                                0.24586439610152466,
                                0,
                                -0.21404141489108908,
                                0,
                                0,
                                0.062008421904529293,
                                0,
                                0.49644731362243733,
                                0,
                                0,
                                0,
                                0,
                                0.41292383178234898,
                                0,
                                0.21208314062671935,
                                0,
                                -0.48908529459242467,
                                0.47512272168742337,
                                0,
                                0,
                                0,
                                0.1531336595241628,
                                -0.44771331860942909,
                                0,
                                0,
                                0.12038722084709148,
                                0,
                                -0.43081989566948919,
                                0,
                                0,
                                0,
                                0,
                                0.36864286865629969,
                                0,
                                0.17525543388315912,
                                0,
                                -0.11062633860039517,
                                -0.4348246643855872,
                                0,
                                0,
                                0,
                                0.48117690263029589,
                                0,
                                1.0406587265943341,
                                0,
                                0,
                                -0.2967614651482674,
                                0,
                                0,
                                0,
                                0.53206207935755179,
                                -0.37398099021031006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.97631995947285488,
                                0.072412990384321946,
                                0,
                                0,
                                0,
                                0.32555632754073377,
                                0,
                                0,
                                -0.099506032290129054,
                                0,
                                0,
                                0,
                                0.18646442267114555,
                                0.58785701480834629,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59512572060892155,
                                0.8445532507287018,
                                0,
                                0,
                                0,
                                0,
                                -0.37418411575862026,
                                0,
                                0,
                                0,
                                -0.38958548742263166,
                                0.26068722332494809,
                                0,
                                0,
                                0,
                                0.52028091437339885,
                                0,
                                -0.60668198579426191,
                                0,
                                0,
                                0,
                                0,
                                0.038682106331618608,
                                0,
                                0.15429296614436536,
                                0,
                                0,
                                -0.21622679394404332,
                                0,
                                -0.41864800795165935,
                                0,
                                0,
                                0,
                                0,
                                -0.51021148362637125,
                                0,
                                0.35001671916518728,
                                0,
                                -0.55639212720804765,
                                0.20370881964263465,
                                0,
                                0,
                                0,
                                0.14239577057794797,
                                -0.016123870312237415,
                                0.54458808451653529,
                                0,
                                0.29981511831012825,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30908657367535619,
                                0,
                                -0.67756428355397635,
                                -0.060494813909289104,
                                0,
                                0,
                                0.13182531666483782,
                                0,
                                -0.19393124772289877,
                                0,
                                0.056401681362299783,
                                0.34552588473734569,
                                0,
                                0.11139179915475095,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.013575121172244436,
                                0,
                                0.41744453563831735,
                                0.11565049934889249,
                                0,
                                0,
                                -0.45352590739434051,
                                0,
                                -0.68667136933937267,
                                0,
                                0,
                                0,
                                -0.10189256906689848,
                                0,
                                0,
                                1.3082406616415607,
                                0.063428112362829914,
                                0,
                                0,
                                0,
                                0,
                                0.22064275177518969,
                                0,
                                0,
                                0.58889914455653858,
                                0,
                                0,
                                0,
                                0,
                                0.8604800122476608,
                                -0.60105021165585248,
                                -0.18498745270411726,
                                0,
                                0.17391451519513107,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39697468313255557,
                                0,
                                0.27405936733016401,
                                0.18983946818455152,
                                0,
                                0,
                                0.49332387941869926,
                                0,
                                -0.2493333456640483,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61347723911818564,
                                0,
                                0,
                                0.22688322950199585,
                                -0.15614237429024183,
                                -0.35954044823240289,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61860142910197002,
                                0,
                                -0.1893467037038733,
                                0,
                                0,
                                0,
                                0,
                                0.84378804364095072,
                                0,
                                0,
                                -0.075431437040186122,
                                0.83256802625251214,
                                0,
                                0,
                                0,
                                0,
                                0.70926423582683262,
                                0,
                                0,
                                0.36152253780483351,
                                0,
                                0,
                                0,
                                0,
                                -1.094642250568117,
                                0,
                                0,
                                0.52785971328751136,
                                0,
                                0,
                                0.80986559411695791,
                                -0.74124730787045545,
                                0,
                                0,
                                0,
                                0,
                                -0.36367670901170562,
                                0,
                                0,
                                -0.82747242229430051,
                                0,
                                0,
                                0,
                                0,
                                -0.41496384004532899,
                                0,
                                0,
                                0,
                                0,
                                0.18355076372772408,
                                0,
                                0,
                                -0.11621435857611888,
                                0.62243407033986253,
                                0.023279974535956191,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17130743208975968,
                                0,
                                -0.7317724882586657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10446266896266129,
                                0,
                                0,
                                -0.2400148608490956,
                                -0.67255819757375823,
                                0.24794622472846864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22649012139970442,
                                0,
                                -0.60528570344290378,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7571661866855115,
                                0,
                                0,
                                -0.2253294787548803,
                                0.36555148612340232,
                                0.31999318518910869,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36504363518924032,
                                0,
                                0.081520602165965295,
                                0,
                                0,
                                -0.35954365030595875,
                                0.061678545477663604,
                                0,
                                0.21821947837023067,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53071939211986552,
                                0,
                                -0.21182507412786716,
                                0.67546665402941752,
                                0,
                                0,
                                -0.14295765367016636,
                                0,
                                0.12680438936534144,
                                0,
                                0,
                                0,
                                0.68261718075300937,
                                0,
                                0,
                                -0.76935238182307308,
                                -1.20244819688705,
                                0,
                                0,
                                0,
                                0,
                                -0.36382527029493594,
                                0,
                                0,
                                0.64383018110858592,
                                0,
                                0,
                                0,
                                0,
                                0.28151641246120662,
                                0.5308790719412072,
                                0.02335686467037186,
                                0,
                                -0.18184827176548507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25548288299410876,
                                0,
                                -0.0029594286972493208,
                                0.3333344700493186,
                                0,
                                0,
                                0.63106124257509433,
                                0,
                                -0.33154585109580459,
                                0,
                                0.12144001934729887,
                                -0.39685798510671355,
                                0,
                                0.73335659121991037,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33486425309376194,
                                0,
                                -0.046212374339911703,
                                -0.36047856187470351,
                                0,
                                0,
                                0.072847578450813869,
                                0,
                                -0.20105461116995979,
                                0,
                                0,
                                0,
                                0.32205193273310612,
                                0,
                                0,
                                0.31968730469025775,
                                0.51345173080389339,
                                0,
                                0,
                                0,
                                0,
                                -1.4801154450005423,
                                0,
                                0,
                                0.67614512439209873,
                                0,
                                0,
                                0,
                                0,
                                -0.35603537534206497,
                                0,
                                0,
                                0,
                                0,
                                -0.0080642183010742191,
                                0,
                                0,
                                0.82678337791631029,
                                0.014086515194948523,
                                0.55131835085536895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.020486499781352425,
                                0,
                                -0.10860093835218793,
                                0,
                                0,
                                -0.057319647537139681,
                                -0.58473496161356997,
                                0,
                                -0.32946281510836783,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12383160425772159,
                                0,
                                -0.48904290261588518,
                                0.10163063194138586,
                                0,
                                0,
                                -0.27063527060243403,
                                0,
                                -0.45627214935715177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.07534373985547585,
                                0,
                                0,
                                0.37824193528537298,
                                0.045105864254323016,
                                -0.63432153988020412,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63483203153802314,
                                0,
                                -0.20939507167875349,
                                0,
                                0,
                                -0.45404853090916286,
                                0.2146026601547012,
                                0,
                                -0.37471366696333336,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52181356452515681,
                                0,
                                -0.073218850767366367,
                                -0.48916834245586815,
                                0,
                                0,
                                0.19063705096370642,
                                0,
                                -0.2325870781736285,
                                0,
                                0,
                                0,
                                0.35140124741466927,
                                0,
                                0,
                                -0.23462533974161948,
                                0.58080929583338514,
                                0,
                                0,
                                0,
                                0,
                                -0.35953569945221459,
                                0,
                                0,
                                -0.74836099996925953,
                                0,
                                0,
                                0,
                                0,
                                0.71824352378623812,
                                0.10371094440163595,
                                0,
                                0.10404157643485962,
                                -0.54233603534325825,
                                0.045507104458033854,
                                0,
                                0,
                                0,
                                0,
                                -0.53093219722185836,
                                0,
                                0,
                                0.23548833824542637,
                                0.55344379322179194,
                                -0.19640858139125089,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34715924964281308,
                                0,
                                0,
                                0,
                                0.39281785479826636,
                                0,
                                0,
                                0.5387902825904487,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15798779923854733,
                                0,
                                0.62897159916706025,
                                0.11964197615479438,
                                0,
                                0.74249292862362748,
                                0,
                                -0.14658433623839581,
                                0.40609706436788096,
                                0.22668056887029628,
                                0,
                                0,
                                0,
                                0,
                                -0.43294026385190582,
                                0,
                                0,
                                -0.038840184666044691,
                                -0.089012760766921328,
                                0.11852963230132146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23365079282533358,
                                0,
                                -0.36197159044556254,
                                -0.5779230353380701,
                                0.35387428264217924,
                                0,
                                0,
                                0,
                                0,
                                0.27353867134580134,
                                0,
                                0,
                                -0.48451179196394412,
                                -0.027445549386594076,
                                0.21173920888122574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.073786538188991294,
                                0,
                                -0.21197288682330989,
                                -0.2859770911307305,
                                0.013884121624648495,
                                0,
                                0,
                                0,
                                0,
                                -0.30116595306268934,
                                0,
                                0,
                                0.14725981792725401,
                                -0.7406328148863347,
                                -0.45466913772809819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23567513225209771,
                                0,
                                0,
                                0,
                                -0.15104556225090363,
                                0,
                                0,
                                -0.61278135726568195,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29339815099767275,
                                0,
                                0.6781481759682978,
                                -0.013192981918846363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15098276091917151,
                                1.1465142130939923,
                                0,
                                0,
                                -1.0605479885527354,
                                -0.54759748613955117,
                                0,
                                0,
                                0,
                                0,
                                -0.12323151891297265,
                                0,
                                0,
                                -0.41383058913420656,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.91479023351474664,
                                0.3016133568312922,
                                0,
                                0,
                                0.023454412061694498,
                                -1.0521371479215174,
                                0,
                                0,
                                0,
                                0,
                                0.19743802788373022,
                                0,
                                0,
                                1.0801385580955483,
                                0,
                                0.39152868593815343,
                                0,
                                0,
                                0,
                                -0.4397869043156673,
                                0,
                                0,
                                0.078686918219038893,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76698407336927121,
                                0,
                                -0.22065855945739038,
                                0.10072917709007417,
                                0,
                                -0.065528334617860479,
                                0,
                                0.2476607796759428,
                                -0.22345487881850201,
                                -0.4405593126139622,
                                0,
                                0,
                                0,
                                0,
                                -0.38337357406295058,
                                0,
                                0,
                                -0.18457273029863314,
                                -0.2721399703331277,
                                0.65972951371090638,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.84935770431568547,
                                0.53305623820788739,
                                0,
                                0,
                                0.21398200340492479,
                                1.0959666073979275,
                                0,
                                0,
                                0,
                                0,
                                -1.05307786218899,
                                0,
                                0,
                                0.29033661237179775,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35262709643039031,
                                0.64237352339351161,
                                0,
                                0,
                                1.0313573162097298,
                                0.055622447748817971,
                                0,
                                0,
                                0,
                                0,
                                0.47925535980634176,
                                0,
                                0,
                                0.36141799325234503,
                                0.09442770959666523,
                                0,
                                -0.74312611508832538,
                                -0.01113364233595418,
                                -0.5519266190400649,
                                0,
                                0,
                                0,
                                0,
                                0.086919729695574252,
                                0,
                                0,
                                0.30091355518365159,
                                0.15208016158755519,
                                0.11343567025095981,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33900557281803934,
                                0,
                                -0.19744136312503188,
                                0.025180907403643343,
                                0.56186443800609975,
                                0,
                                0,
                                0,
                                0,
                                -0.096954128016081303,
                                0,
                                0,
                                0.52678775692458479,
                                -0.064658440516968479,
                                0.48854912467118572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49977576108716887,
                                0,
                                0.37306443024759978,
                                -0.27292626970824196,
                                -0.081964010150097522,
                                0,
                                0,
                                0,
                                0,
                                0.44857435754144109,
                                0,
                                0,
                                0.53336493207619484,
                                -0.18739588727033957,
                                0.095004990810143061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54325062940435065,
                                0,
                                0,
                                0,
                                0.14731256052451058,
                                0,
                                0,
                                0.32468830025469719,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39938685544778618,
                                0,
                                -0.047931808238614232,
                                -0.64494027033184353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2592422655392337,
                                -0.69833055196993599,
                                0,
                                0,
                                -0.18910503244131821,
                                0.4876901277542498,
                                0,
                                0,
                                0,
                                0,
                                0.69594730419175344,
                                0,
                                0,
                                -0.46149829404635617,
                                0,
                                -0.3532627434455663,
                                0,
                                0,
                                0,
                                -0.70345791883900977,
                                0,
                                0,
                                0.47013372710432066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22796559567444308,
                                0,
                                0.24815686421410793,
                                0.21395449770270597,
                                0,
                                0,
                                0.50072663525922645,
                                0,
                                0,
                                0,
                                -0.33602502258439054,
                                0,
                                0,
                                -0.039549902549052537,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29868819589182488,
                                0,
                                0.17871846998194721,
                                -0.7166874467086003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66592118816714296,
                                0.38159736480589623,
                                0,
                                0,
                                -0.24152662366009087,
                                0.78391456441884588,
                                0,
                                0,
                                0,
                                0,
                                0.63057365372827123,
                                0,
                                0,
                                1.1488652948794249};

const double rot_27_10[1000] = {-0.072900982243024451,
                                0,
                                -0.13585120138483497,
                                0,
                                -0.44452457380077498,
                                0,
                                0,
                                0,
                                -0.8563053831999945,
                                0,
                                0,
                                0.66662785255329982,
                                0,
                                0.56188595306472666,
                                0,
                                -0.057888957524997786,
                                0.10441138681956059,
                                0.28261982348402093,
                                0,
                                -0.3817913674006736,
                                -0.35051544935564366,
                                0,
                                -0.77469466741462034,
                                0,
                                0.4735918484404037,
                                0,
                                0,
                                0,
                                0.7052407813865017,
                                0,
                                0,
                                0.29523251837931641,
                                0,
                                -0.34219104571640746,
                                0,
                                -0.75236559869564712,
                                0.068576428846368984,
                                0.30039407020732373,
                                0,
                                0.36708272938565056,
                                0.0085503430771112776,
                                0,
                                0.085689893508628046,
                                0,
                                -0.19360713466594209,
                                0,
                                0,
                                0,
                                0.3891959579372235,
                                0,
                                0,
                                0.35037462325855051,
                                0,
                                -0.64640750989567408,
                                0,
                                0.4467252203014847,
                                -0.28366812758791937,
                                0.36513219487753235,
                                0,
                                -0.21457494198568836,
                                0,
                                -0.47974105195537947,
                                0,
                                0.20577065385725657,
                                0,
                                0.1075959441478769,
                                0.10866203878238583,
                                0.83364647392197744,
                                0,
                                0.095687991555634996,
                                0,
                                0.32678212948256014,
                                0,
                                0.066424094980737203,
                                0,
                                0.46727556067775583,
                                0.4294522842187648,
                                -0.024599510300547855,
                                0,
                                0.69672119927727627,
                                0.53695232709541285,
                                0,
                                -1.0396604964037124,
                                0,
                                0.96781473266851714,
                                0,
                                0,
                                0,
                                -0.57630950267042058,
                                0,
                                0,
                                -0.093512847179463718,
                                0,
                                -0.32030153410133538,
                                0,
                                -0.033288364916528694,
                                0.84124385644520205,
                                -0.0315648353786585,
                                0,
                                -0.42292622830303062,
                                0.15062376811742184,
                                0.05019925811575307,
                                0,
                                0.33661942084658347,
                                0,
                                0.041514992130928512,
                                0,
                                0.70200063851140782,
                                0,
                                0.60576520982109261,
                                -0.23710173410206389,
                                0.48640195991025992,
                                0,
                                0.79255925624116152,
                                0,
                                0.031626734687047839,
                                0,
                                -0.18579385894186126,
                                0,
                                -0.20862914000742103,
                                0,
                                0,
                                0.94725413069905495,
                                0,
                                -1.1426663399433703,
                                0,
                                -0.0033266486167209119,
                                0,
                                -0.29767192432206263,
                                0,
                                0.36935761746599977,
                                0.24826073712535859,
                                0,
                                -0.11538234698819257,
                                0,
                                0.78575435763545687,
                                0,
                                0.21626647660655224,
                                0,
                                -0.35277098998980932,
                                0,
                                0,
                                0.36517135429615016,
                                0,
                                0.22279963569992786,
                                0,
                                -0.23001361845648799,
                                0,
                                0.74400818192815366,
                                0,
                                -0.091557935300414284,
                                -0.79463246012984334,
                                0,
                                0.41120800823904152,
                                0,
                                0.40643025139092953,
                                0,
                                -0.15996229424553865,
                                0,
                                0.017631985866796776,
                                0,
                                0,
                                0.069955026895560601,
                                0,
                                -0.78163258291110715,
                                0,
                                0.12615809057997068,
                                0,
                                0.68699038240297283,
                                0,
                                0.80366605378496447,
                                0.044743207545168473,
                                0,
                                0.17461365114261612,
                                0,
                                -0.11115649911227433,
                                0,
                                -0.48602453948126878,
                                0,
                                0.27028387287080352,
                                0,
                                0,
                                0.79434264441665148,
                                0,
                                0.061378119717447166,
                                0,
                                1.0159741872351109,
                                0,
                                0.0090417734426738727,
                                0,
                                -0.3611207790490199,
                                0.25654838328982454,
                                0,
                                -0.21364023884462607,
                                0,
                                0.44980554464980022,
                                0,
                                -0.40508859283739301,
                                0,
                                0.62586800706869017,
                                -0.28188838438528768,
                                0,
                                0.51269861006048023,
                                0,
                                0,
                                0,
                                -1.2592253762667029,
                                0.61579896294975367,
                                0,
                                0,
                                0,
                                0.36296160143376555,
                                0,
                                -0.65640728258564696,
                                0.35555310856743527,
                                0.26157639053317805,
                                0,
                                0,
                                -0.21217088063373524,
                                0.44444533023526667,
                                -0.61024219938825519,
                                0,
                                -1.2040816456773822,
                                0,
                                0,
                                0,
                                -0.0254295490908448,
                                0.76907466192262364,
                                0,
                                0,
                                0,
                                -0.38038594701076744,
                                0,
                                -0.34711594219931508,
                                -0.23085939866688207,
                                -0.38498265368873574,
                                0,
                                0,
                                0.55526777424118701,
                                0.47432799546620275,
                                0,
                                -0.1505253554667832,
                                0,
                                0.50654911360922905,
                                0.53824267046944863,
                                -0.32515213530388787,
                                0,
                                0,
                                -0.23287917303986896,
                                0.52066142570850427,
                                0,
                                0.33528720807593893,
                                0,
                                0.31792612990257518,
                                -0.66249084061997821,
                                0.20484794190892347,
                                0,
                                0,
                                -0.15763924748064551,
                                0.52990427293036879,
                                -0.5742359227941245,
                                0,
                                -0.45126934272707236,
                                0,
                                0,
                                0,
                                -0.026315153879391113,
                                -1.0693075987460954,
                                0,
                                0,
                                -0.33541315098487989,
                                0,
                                0.89594133490715477,
                                0,
                                0,
                                0,
                                1.318675352586969,
                                0.57960670501751355,
                                0,
                                0,
                                0,
                                -0.32892630883580976,
                                0,
                                -0.29982152229469516,
                                -0.30220499627671848,
                                -0.38248465711058005,
                                0,
                                0,
                                -0.74841128935072743,
                                -0.064596496788221186,
                                0,
                                0.69303498902959348,
                                0,
                                -0.032833340301832797,
                                -0.018941463542687675,
                                -0.69956060849108259,
                                0,
                                0,
                                0.086365020064419512,
                                -0.1463616584392701,
                                -0.51352319307021832,
                                0,
                                0,
                                0.069101788793505023,
                                0.60575708883570212,
                                0.29795826101017037,
                                0.06748051569135198,
                                0,
                                0,
                                -0.52081136411144535,
                                0,
                                -0.27837115589127243,
                                0.4640568525280907,
                                0,
                                0,
                                0,
                                0,
                                -0.94575195937387191,
                                0.076144814519177151,
                                0,
                                0,
                                -0.62730406044298181,
                                -0.48856959852145909,
                                0,
                                0,
                                0,
                                0,
                                0.5554456437373495,
                                1.10610040924918,
                                0,
                                -0.21307357339051397,
                                0,
                                0,
                                -0.25701113560891653,
                                0.26734083718975965,
                                -0.57012292874469817,
                                -0.69791551979365019,
                                0,
                                0,
                                0.070339026272884173,
                                -0.4784335367645185,
                                0,
                                0,
                                0.011291838492904237,
                                -0.74668700076319816,
                                0.079738499814765246,
                                -0.24772447614408322,
                                0,
                                0,
                                -0.38171550104774765,
                                0.15880332829781535,
                                0,
                                0,
                                -0.8912101025599537,
                                -0.045802611780311128,
                                -0.049085616889731794,
                                0.26988966278442067,
                                0,
                                0,
                                -0.32121386786280254,
                                -0.39458416065780111,
                                0,
                                0,
                                -0.36578336088107882,
                                0.011473522832480015,
                                0.53228842197014581,
                                -0.1103444908717737,
                                0,
                                0,
                                0.64410197989535378,
                                0,
                                -0.65890193198436042,
                                -0.41063593141879678,
                                0,
                                0,
                                0,
                                0,
                                -0.18081228303321656,
                                -0.17934156058756567,
                                0,
                                0,
                                -0.22554462960635818,
                                -1.0082536828344302,
                                0,
                                0,
                                0,
                                0,
                                0.29823689029856348,
                                -0.35030819931188795,
                                0,
                                0.53016957332543446,
                                0,
                                0,
                                -0.031461076580795312,
                                0.04261722674163132,
                                0.54229339892141459,
                                -0.60164487399851474,
                                0,
                                0,
                                -0.245062259931488,
                                0.67029425617860849,
                                0,
                                0,
                                0,
                                -0.063169154070705794,
                                0,
                                0,
                                0.51910011044745752,
                                0,
                                0.80724507132223822,
                                0,
                                0.24629628455266839,
                                0.055373966147435984,
                                0.59816190597925178,
                                0,
                                -0.54145917054024273,
                                -0.37842813476939891,
                                0,
                                0.37694603297653745,
                                0,
                                0,
                                -0.2053037835711598,
                                0.48800372524368546,
                                -0.16570893676276513,
                                0,
                                0.28353029719026318,
                                -0.78055092256239789,
                                0,
                                -0.050932276002541299,
                                0,
                                0,
                                0.010744988119228256,
                                0.16552572791709991,
                                -0.6566087341284349,
                                0,
                                -0.30113958078345182,
                                0.087237330319637513,
                                0,
                                0.66562403049946894,
                                0,
                                -0.97846505912275528,
                                0,
                                0,
                                0,
                                -0.20747767728604433,
                                0,
                                0,
                                0.66994909567156735,
                                0,
                                -0.17393406820122059,
                                0,
                                0.67075007214410176,
                                -0.022842129147026175,
                                -0.38099311410229381,
                                0,
                                -0.33189631933534436,
                                -0.19741066407547575,
                                0,
                                -0.50526298873188602,
                                0,
                                0,
                                0.49131848478980744,
                                0.68095179073072643,
                                0.19368330377787046,
                                0,
                                0.33005001756230429,
                                0.36777734380622379,
                                0,
                                0.11491037521528422,
                                0,
                                0.0061439175066907714,
                                0,
                                0,
                                0,
                                -1.0408980157643539,
                                0,
                                0,
                                -0.28261403778476285,
                                0,
                                0.48076493640785639,
                                0,
                                -0.45362267262535017,
                                0.5168851103055212,
                                0.030641110012548461,
                                0,
                                -0.56272489656795099,
                                0.2563023749261128,
                                0,
                                -0.37916640066295548,
                                0,
                                0.35533960711092155,
                                0,
                                0,
                                0,
                                -0.63024348735487101,
                                0,
                                0,
                                0.41885196974595484,
                                0,
                                -1.0012851086289423,
                                0.6282378246432142,
                                0,
                                0,
                                0,
                                0,
                                -0.10390475641515107,
                                0,
                                0,
                                0.015063744522999439,
                                -0.90317477741700214,
                                0,
                                -0.34031685723048954,
                                0.5142841319749597,
                                0.042266022060979735,
                                0.36574940390680888,
                                0,
                                0.51698402142855193,
                                0.46568739170396445,
                                0,
                                0,
                                0,
                                0.7561843050048529,
                                0.25111853779353421,
                                -0.4629763019023716,
                                0.25525532872278112,
                                0,
                                -0.13062408179455859,
                                0.26183923909819778,
                                0,
                                0,
                                0,
                                0.38467761465953831,
                                0.34310075197763279,
                                0.5641035007060704,
                                -0.60281235240659792,
                                0,
                                0.11147450856308828,
                                0.20070612594046239,
                                0,
                                0,
                                0,
                                -0.35279825788756147,
                                0.54977518568250994,
                                -0.10510611174620721,
                                -0.12631858848167007,
                                0,
                                -0.73654561423780807,
                                0.061461468123577015,
                                0,
                                0,
                                -0.60129985018614707,
                                0,
                                0,
                                0,
                                0,
                                -0.80409348851074403,
                                0,
                                0,
                                -0.27495926988814667,
                                0.30319572519495541,
                                0,
                                0.070643875703144343,
                                -0.33174060375916503,
                                0.55682445976534778,
                                0.4547967142326384,
                                0,
                                -0.40091923772395455,
                                0.45533267969278324,
                                0,
                                0,
                                0,
                                -0.18691093704242701,
                                -0.3773971417391086,
                                -0.38020125463722987,
                                -0.46356544458539711,
                                0,
                                -0.0016210346703572839,
                                0.68057854493532954,
                                0,
                                0,
                                -0.77098460043932482,
                                0,
                                0,
                                0,
                                0,
                                0.16464627619133659,
                                0,
                                0,
                                -0.41966928999729314,
                                0.69702536311141294,
                                0.099952998770290499,
                                0,
                                0,
                                0,
                                0,
                                0.44559334080445101,
                                0,
                                0,
                                0.90742688120411297,
                                0.47719293989173772,
                                0.92315554040980308,
                                0.12717549251758756,
                                0,
                                -0.1200874838405017,
                                0,
                                0.015753981394698316,
                                0,
                                0.33341815036080097,
                                0,
                                0.075982811336837458,
                                -0.26263959314292407,
                                0.80247906930420221,
                                0,
                                -0.42639040286088498,
                                0,
                                0.13178432293233147,
                                0,
                                0.28206975751347879,
                                0,
                                -0.091151280386322919,
                                0,
                                0,
                                -0.62241907393818119,
                                0,
                                0.99949831875231032,
                                0,
                                -0.69057887398199269,
                                0,
                                -0.2833494193181581,
                                0,
                                0.039298666628549611,
                                -0.0022791409402070084,
                                0,
                                -0.23564452993344492,
                                0,
                                -0.86402583736084604,
                                0,
                                -0.0516861846049297,
                                0,
                                -0.44012494421937842,
                                0,
                                0,
                                1.0163278244980252,
                                0,
                                0.21557174403733548,
                                0,
                                0.24348793868099908,
                                0,
                                -0.17035445767349847,
                                0,
                                0.11805015382026279,
                                -0.13846600856885918,
                                0,
                                -0.73708655120146427,
                                0,
                                0.12748407897780265,
                                0,
                                -0.59698117207739665,
                                0,
                                0.22573442689193979,
                                0,
                                0,
                                0.62369594900906322,
                                0,
                                0.083714031517108656,
                                0,
                                -0.20503164635628585,
                                0,
                                0.40065372605080846,
                                0,
                                -0.10400502016891278,
                                0.14837285181017318,
                                0,
                                0.07043928847054845,
                                0,
                                -0.46674168315104436,
                                0,
                                0.083093774786710331,
                                0,
                                0.85875164341395571,
                                0,
                                0,
                                0.66551772870924064,
                                0,
                                -0.077980615322564437,
                                0,
                                0.25296577160977357,
                                0,
                                0.42673034665936976,
                                0,
                                0.22914411205243507,
                                0.54649904324240972,
                                0,
                                0.44719525798372384,
                                0,
                                -0.04176203406064069,
                                0,
                                -0.66581261027713212,
                                0,
                                -0.061625265847471938,
                                -0.46906354946234841,
                                0,
                                -0.11598734832198271,
                                -0.20125294537240279,
                                -0.67927585054463102,
                                0,
                                0.50309140977505362,
                                0,
                                0,
                                0.10727034003566249,
                                0,
                                -1.0818047223557365,
                                0,
                                0,
                                0,
                                0.67425435019386926,
                                0,
                                0.46940081392336908,
                                -0.076542093008459544,
                                0,
                                0.31964116362777595,
                                0,
                                0.72638350572233312,
                                0.35967129981643925,
                                -0.085609293813498064,
                                0,
                                0.47585359610417155,
                                0,
                                0,
                                0.084068359714291288,
                                0.45429785315471216,
                                0,
                                -0.35823493155671304,
                                0.37596126343109443,
                                -0.4732591427968903,
                                0,
                                -0.031028623469125466,
                                0,
                                0,
                                -0.54680648415653899,
                                0.41222028717288001,
                                0,
                                -0.41614119151473056,
                                0.16135755214531511,
                                -0.075050011971853015,
                                0,
                                0.083968096526701744,
                                0,
                                0,
                                0.78624521518555968,
                                0,
                                0.65871139085203501,
                                0,
                                0,
                                0,
                                0.26701547714081009,
                                0,
                                0.021187620157530646,
                                0.30518721776870966,
                                0,
                                -0.51595909248221961,
                                0,
                                0.05080042487382197,
                                0.75371843871493382,
                                -0.10819132791448383,
                                0,
                                -0.35011849255120614,
                                0,
                                0,
                                0.16978140238688913,
                                0,
                                -0.25705063588454485,
                                0,
                                0,
                                0,
                                -0.30732316353228806,
                                0,
                                1.1576086765681244,
                                -0.048529256993824321,
                                0,
                                0,
                                -0.67340055146713673,
                                0,
                                0,
                                0,
                                0.3358102562316681,
                                0,
                                -0.47642585816672078,
                                -0.48837772977853849,
                                0,
                                -0.18783775825833893,
                                0,
                                -0.39348125370043463,
                                0.30766733978987049,
                                0.53846381838142099,
                                0,
                                0.62439251512989857,
                                0,
                                0,
                                -0.18820465172067338,
                                -0.035895903920886041,
                                0,
                                0.19900243528195594,
                                0.90846173977741318,
                                0,
                                -0.048140982660429717,
                                -0.3132739940666569,
                                0,
                                0,
                                0.18261607986199019,
                                0,
                                0.20137715851513041,
                                0,
                                0,
                                0.15806248546920032,
                                0,
                                0,
                                0.54279719601553811,
                                0.96105986772840535,
                                0,
                                -0.37326795832525583,
                                0,
                                -0.36397661587942398,
                                -0.19126457686046022,
                                0,
                                0.20404739238159922,
                                -0.8045536226280402,
                                0,
                                0,
                                -0.051653131535389529,
                                -0.5429216570949994,
                                0,
                                -0.33737432943919665,
                                0.3056750930473715,
                                0,
                                0.048842016666757325,
                                0.38218773644942544,
                                0,
                                0,
                                -0.59120585678656945,
                                0,
                                0.16432575311465367,
                                0,
                                0,
                                0.71544957064170156,
                                0,
                                0,
                                0.54461186285560315,
                                -0.56476484275815708,
                                0,
                                0.66854562345268176,
                                0,
                                -0.67146588886662051,
                                0.20777739428109551,
                                0,
                                0.22093598604978815,
                                0.0067073045065614012,
                                0,
                                0,
                                -0.10075299504752763,
                                0.039127932844962424,
                                0,
                                0.36544417393291528,
                                0.014316319666652089,
                                0,
                                0.91972920174883921,
                                0.054457752488532588,
                                0,
                                0,
                                -0.12588547273339817,
                                0,
                                0.3780153952986724,
                                0,
                                0,
                                0.706589617316561,
                                0,
                                0,
                                -0.13795759420351131,
                                0.86222830673816264,
                                0,
                                0,
                                0.93845301970970108,
                                0,
                                0,
                                0.079923334674888574,
                                0,
                                0,
                                -0.47612165235938986,
                                -0.11529363314452754,
                                0,
                                0.34078489382624139,
                                0,
                                0.36011349809096788,
                                -0.036075807772304652,
                                0,
                                -0.24279013649103001,
                                -0.32476879826338129,
                                0,
                                0,
                                -0.76711188103387384,
                                -0.24494569421812007,
                                0.54832109948186258,
                                0,
                                0.15883081714378469,
                                0,
                                0,
                                0.20823728534232633,
                                -0.53677293282143745,
                                -0.53162994823088505,
                                0,
                                0.66635532698860944,
                                0.16823246139134462,
                                0,
                                -0.42936480320112319,
                                0,
                                0,
                                -0.15748746564808136,
                                -0.52513625748128279,
                                0.20674596040181639,
                                0,
                                0,
                                0,
                                0.093103879997235739,
                                0,
                                0.73932790568039408,
                                -0.16264142457590244,
                                0,
                                0,
                                0,
                                0.62474397584597152,
                                0.6790520047526758,
                                -0.075878501126772108,
                                0,
                                0.62053731940669632,
                                0,
                                0,
                                0.12040980837321621,
                                0.16561287946817649,
                                -0.32578845181108468,
                                0,
                                0,
                                0,
                                0.52488805518384885,
                                0,
                                0.60047486432507569,
                                -0.42146364302559614,
                                0,
                                0,
                                0,
                                -1.2795295413552839,
                                0,
                                0,
                                -0.40239780440486594,
                                0,
                                1.2617426636499596,
                                -0.37617000121533889,
                                0,
                                0,
                                0,
                                0.36537319195991047,
                                -0.0077605952174311377,
                                -0.65185893118746741,
                                0,
                                -0.35101628561073539,
                                0,
                                0,
                                -0.088416623062434835,
                                -0.15983410389622918,
                                -0.6468715747557402,
                                0,
                                0.061811423895568054,
                                -0.18353753390986025,
                                0,
                                -0.17292737053719642,
                                0,
                                0,
                                0.94998347163454355,
                                -0.059717134380829172,
                                0.16295617056098985,
                                0,
                                -0.17601045695398607,
                                -0.45461870984527819,
                                0,
                                0.50223078786169983,
                                0,
                                0,
                                -0.083966145510816881,
                                -0.61608930108882409,
                                0.35141150083231465,
                                0,
                                0,
                                0,
                                1.3813842689634142,
                                0,
                                0.25980167026584156,
                                -0.0062029417910567652,
                                0,
                                0,
                                0,
                                -0.07228856720002641};

const double rot_27_100[100000] = {-0.072248539945302989,
                                   0.11903226219760937,
                                   -0.22434757025786983,
                                   0,
                                   0,
                                   0,
                                   -0.071915824600467526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032692498494741172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012989495195360974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.300078723893559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6367923642918103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094682241206218681,
                                   0,
                                   0,
                                   -0.44768565217934259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22634386119777128,
                                   0.1703679856181794,
                                   0,
                                   0.34706554742824541,
                                   0,
                                   0.13498151918635545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19685440622492403,
                                   -0.56287258969512044,
                                   -0.43436468713266341,
                                   0,
                                   0,
                                   0,
                                   -0.085864887145203031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16180544206337039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10902436385812574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15584400921083999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093585831000646644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060220554095812881,
                                   0,
                                   0,
                                   0.14411782030915152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096839183286729663,
                                   0.54498165826395395,
                                   0,
                                   -0.1814095596406507,
                                   0,
                                   -0.11651450305175093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5123176707126802,
                                   -0.018049170425153777,
                                   -0.14501790918157359,
                                   0,
                                   0,
                                   0,
                                   -0.2301058761302448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20844516154269885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41599269103882347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14091658043565569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37620136431821255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27694810949304344,
                                   0,
                                   0,
                                   -0.23180061320805936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1605614303727014,
                                   0.10506936011514165,
                                   0,
                                   0.31653975434394405,
                                   0,
                                   0.13376446056684232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82103323619630508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27188822825253101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52633521947145612,
                                   0,
                                   0,
                                   0,
                                   0.21105025249192216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60992643756108678,
                                   0,
                                   0,
                                   -0.15957807447685676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4384707504421903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6081884757541548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083565931540289531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081413730300942844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019086948863314503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60090511170761007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22594575599275776,
                                   0,
                                   0,
                                   0,
                                   -0.074252239665453273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44546193096922337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18869051346502436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27614640440363908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030633174190829206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00032664656103688003,
                                   -0.16986632823890552,
                                   0,
                                   0,
                                   0,
                                   0.35823036034511885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33699335049723711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50498527155995088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039574723315056612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53683407899245117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.273600605786601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26127488036274349,
                                   0,
                                   0,
                                   0,
                                   0.12046098189998349,
                                   0,
                                   -0.2509807831266585,
                                   0,
                                   0,
                                   -0.21732057477465372,
                                   -0.45138164569227923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63583029339311448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55348528894255844,
                                   0,
                                   0,
                                   -0.12227360839717363,
                                   0,
                                   -0.58926611207861157,
                                   0,
                                   -0.044837793803839204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085675512186908082,
                                   -0.29182654383003559,
                                   -0.23386575150999553,
                                   0,
                                   0,
                                   0,
                                   0.034222171277881241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21335648711662547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3891457904988237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30421000027576628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081168399773402122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36096105880230711,
                                   0,
                                   0,
                                   0.14814161366854181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18141665734831952,
                                   -0.22652282021518488,
                                   0,
                                   0.52988401863184331,
                                   0,
                                   0.19571578737809317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62866809523298861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64245495233500738,
                                   0,
                                   0,
                                   0.23751265686166231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1619282880222892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16786560812864751,
                                   0,
                                   0,
                                   0.26619963335196506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039369913831286352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093829261538442149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50179017418825889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18672537528793348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15695590661841921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24640563128083137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074998272813412467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7889008953204365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19971871896796312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39081206908762112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38385961802284868,
                                   0,
                                   -0.043104715639818228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0845896568656201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13369414768000487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.772405774879803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19122942345671978,
                                   0,
                                   0,
                                   0.43647264473602071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32334508535550616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24648590328762177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24687319090412274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56352472569180612,
                                   0,
                                   0,
                                   0.44311462613458313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68043338952831789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27936128039059549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21474957442921649,
                                   0,
                                   0,
                                   0,
                                   0.52085561686365855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42437958251009533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36267619392254746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18562690811713933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43206926627768194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075846142287792212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34038489710256536,
                                   0,
                                   -0.75409797294174297,
                                   0.023099235543201771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26303697503699563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044174905125477296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59718827713977052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39529263683832028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010206650367699611,
                                   0,
                                   0,
                                   0,
                                   0.41279515667755301,
                                   0,
                                   -0.3917282421435232,
                                   0,
                                   0,
                                   0.27942312102881889,
                                   0.19080170662862872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3877147520801178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40396659705923516,
                                   0,
                                   0,
                                   -0.27903545646842465,
                                   0,
                                   -0.46277964808380606,
                                   0,
                                   0.35503471276764192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77255296661547423,
                                   0.084269754943318259,
                                   -0.14752689174257849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36931664795049945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34669094316186461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019736262725581211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018009466418485165,
                                   0,
                                   -0.10895181774014404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015940421833501944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32383403971814978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078352439647958072,
                                   0.65367477619973591,
                                   0.45373294219740484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072079483968193928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05666050209377764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011137334621500045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26281468709193134,
                                   0,
                                   -0.34531532102971152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38704678832686379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11852108484986973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22566387301740348,
                                   -0.25259681321983235,
                                   0.23830740561638605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22504136240203182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30219371955266716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080963307183138711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6391822689597787,
                                   0,
                                   0.23131688386659266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24731950946779729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3958940733046819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52942930519989306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82237966286968556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099163626207222688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077165497569025715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080460628010293703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14537692202151298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19545323144013044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0023648601436358115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33451164926098359,
                                   0,
                                   0,
                                   0,
                                   -0.31348289231145871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16209810105459557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91827308822553944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19991711923765706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3439005694221689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37272789213396246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37653768706499546,
                                   0,
                                   -0.27538515900843341,
                                   0.09170625587471623,
                                   0,
                                   0,
                                   0,
                                   -0.35797858617129552,
                                   -0.020288482098964208,
                                   -0.39302729527057184,
                                   0,
                                   0,
                                   0,
                                   -0.14150158980481536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16678461206880368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068011232774486036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093418743800489257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28807218054487072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025872293243557179,
                                   0,
                                   0,
                                   -0.24063607030470999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25314288491466774,
                                   -0.49952829340765748,
                                   0,
                                   -0.28730119530778531,
                                   0,
                                   0.34360496253111239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03540518718535033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70147384892033571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085768194435149533,
                                   0,
                                   0,
                                   0,
                                   0.42886750823964076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39623955331955096,
                                   0,
                                   0,
                                   -0.21841778851452159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1193250210215043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78430754880955966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15325215065614262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13136271583343376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51395384988077697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0068395639654674767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35179904830980913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77846310441289612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46901602182021551,
                                   0,
                                   0,
                                   0,
                                   -0.31510447270446229,
                                   0,
                                   -0.50703211045819885,
                                   0,
                                   0,
                                   -0.065873676229201664,
                                   -0.04289057929782901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50903454459822672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38386981629442507,
                                   0,
                                   0,
                                   0.021509519503226285,
                                   0,
                                   0.54268528667688631,
                                   0,
                                   0.045998363112983207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19484471522464444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20520189507119679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58003704377904319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53678460258452709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53906060740384409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0689978189934633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17051001856540229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39838663796691898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12625108039000627,
                                   0,
                                   0,
                                   0,
                                   0.20010428038843564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44489615782288439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23785521145322025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10245771358011838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0056677456967224038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65833450525924708,
                                   0.20617086013658581,
                                   0,
                                   0,
                                   0,
                                   0.050817211973532138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1127068287074612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17580773428634125,
                                   0.22488332568194869,
                                   -0.42476993850141292,
                                   0,
                                   0,
                                   0,
                                   -0.09323067093324168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081671062155807619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22855911819458646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40364544718088319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088393406911728159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52408289783671169,
                                   0,
                                   0,
                                   -0.062108976300266669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30031081733130488,
                                   -0.022857087048457389,
                                   0,
                                   0.20292844815702221,
                                   0,
                                   -0.29889095030021784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16541706578717019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035784572045556649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39568955135728406,
                                   0,
                                   0,
                                   0,
                                   -0.48253666749301505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45376808608976149,
                                   0,
                                   0,
                                   -0.58360262746632297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48758378216093262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35761549334177334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30202272073375119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27596175015027968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52936611384319721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58156946530368914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73034730044932528,
                                   0,
                                   0,
                                   0,
                                   0.25052055883845303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70619143905637238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12301801138899847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32796215838553333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22949272483580396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26776629819679132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67861895197206268,
                                   0,
                                   -0.10641408630292004,
                                   -0.071231796980686962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10246562966815628,
                                   0.30326486281356496,
                                   -0.43603730083422809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20590444514357797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1135478380999618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57124173271540823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085362488810885429,
                                   0,
                                   0.16128932739635579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019892213632832119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54046194958261951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53757298707615708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58080364846328802,
                                   0,
                                   0,
                                   0.34858396562790817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78395426329285045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13866399394602757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88337031257113552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10805693370998939,
                                   0,
                                   0,
                                   -0.02020631268420825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13936212105356288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65125285224040685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64636614116662439,
                                   0,
                                   0,
                                   0,
                                   0.85306716166156493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096766039578150415,
                                   0,
                                   0,
                                   -0.042839562718305531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24717378658114961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017567418498209496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11390604226855094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019203020660045159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055505808380463852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04486734535896663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34847765800958502,
                                   0,
                                   0,
                                   0,
                                   -0.56675355333754718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25829138439664023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084118754001100901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083389143319392595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098400028549863489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0192042111605824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53424746228699083,
                                   0,
                                   -0.047010795291603416,
                                   -0.32270133247059285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12885823492754031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76447222923961122,
                                   0,
                                   0,
                                   -0.54747970688643954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33739557835732004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40495974651546485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037349603634670617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26810104899771392,
                                   0,
                                   0,
                                   0.60163868940590293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12348323466445169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049701719083032676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011381156863430376,
                                   0,
                                   0,
                                   0,
                                   0.15405526183548351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024110814597127578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017984004899933737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49717832554593905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75671490827382748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091249333300449265,
                                   0.0071236975049030959,
                                   0,
                                   0,
                                   0,
                                   -0.0073447199001259048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35955451190690146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16895782466079701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14135802343416159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067308234609056619,
                                   0,
                                   0.72655256173384575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18033904602622597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99513556042303131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11084985929248663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075710785533965624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29201798052820327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50582861359284115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79684135497939146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076726484099342393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6591298994488205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17289286400099604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080531868969198631,
                                   0,
                                   0,
                                   0,
                                   -0.03948051314259856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53485420840543929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38573456898419156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10288267724458094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.066332873422662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10862989112959297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2749752043616181,
                                   0,
                                   0.41729441632951159,
                                   -0.48880210832130661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39945931188234368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13213843686439569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34870529969818603,
                                   0,
                                   0,
                                   0,
                                   -0.26574337664490033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14514905402179373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15662096654141552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085556865284587169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16650644064459363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30674519766008135,
                                   0.20486826801232277,
                                   0,
                                   0,
                                   0,
                                   0.32646407239505432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55450121936510077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51072668922670927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67166471468379807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079714118045081994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14588733279058805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74917890057511938,
                                   0,
                                   0,
                                   0,
                                   -0.18341638335893459,
                                   0,
                                   -0.29536069857773867,
                                   0,
                                   0,
                                   0.37609463669063847,
                                   0.79013482025718274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019588916144340274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8506527717016279,
                                   0,
                                   0,
                                   -0.04083052400437813,
                                   0,
                                   -0.19231361018566759,
                                   0,
                                   -0.42661784301657552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38085009720287538,
                                   -0.12968536474059822,
                                   -0.089391552276618047,
                                   0,
                                   0,
                                   0,
                                   -0.28371007372094237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54109437421079287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14969274647214151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42742318191458739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065700460933943328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11839334700622148,
                                   0,
                                   0,
                                   0.091116029765102982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093930432039434963,
                                   -0.44405520321518843,
                                   0,
                                   -0.019847388973115429,
                                   0,
                                   -0.13687038766470666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06307188830904642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28418740813881405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0660937950720786,
                                   0,
                                   -0.3609026978443361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070392472876641271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21308707408807287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25141661942954868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043047333196684689,
                                   0,
                                   0,
                                   -0.32879896647631657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30780465936154777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34300209979240581,
                                   0,
                                   0,
                                   0.70089869316026576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2931021471253461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19304366012236054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0083381458605973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50102428749352612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53130818127077439,
                                   0,
                                   -0.86868422017213798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30523218272176866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36185379766867665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30382674958562128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17983530968322534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35674055941976557,
                                   0,
                                   0,
                                   0,
                                   -0.30019112431731187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071453445992275683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089528808348052907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42304922790742344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24362484741046464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20852046647710076,
                                   0.50219075331627283,
                                   0,
                                   0,
                                   0,
                                   -0.32294366623553988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080971368879849903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28592367134617724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12009369673736023,
                                   0,
                                   0,
                                   -0.059459104057554779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25211850226707955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43318076846768383,
                                   0,
                                   0,
                                   0.29646510716176172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36580810751669923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65373796315306232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25254929784675478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61892766419465062,
                                   0,
                                   0,
                                   -0.12127426019178131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70100486047229493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3710421507656666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2270768697491449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62822976194398972,
                                   0,
                                   0,
                                   0.41996751655997605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69957133835738916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27469664612314493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52886981093969099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16612274407041258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095961596585093539,
                                   0,
                                   0,
                                   0,
                                   -0.44825009586756981,
                                   0,
                                   0.11933114346329568,
                                   0,
                                   0,
                                   -0.58777444956248104,
                                   0.039541475436513283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28866633510849582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25749857348593624,
                                   0,
                                   0,
                                   0.25041890683663776,
                                   0,
                                   0.17536512717429995,
                                   0,
                                   -0.20476404234620987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22834786725092121,
                                   0.041647843634467052,
                                   -0.06518668190960028,
                                   0,
                                   0,
                                   0,
                                   0.28754093762234312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01410892065369557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70845353178015247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09580154130786174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32795934814767391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3306989945691084,
                                   0,
                                   0,
                                   0.26237913273896085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0077523770190670929,
                                   -0.22119451230652704,
                                   0,
                                   -0.078647956480784237,
                                   0,
                                   0.083520235025961592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7010077694451784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32745612415293146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41452085073867578,
                                   0,
                                   0,
                                   0,
                                   0.22954572347010285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11542972283616899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061525142842620437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73258253266065154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25813582699283077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63313913016153289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0072181271963346321,
                                   0,
                                   0.45831325285685731,
                                   0.38563303268619237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51141511434694598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19040899706011222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81007402862752609,
                                   0,
                                   1.0725261271918261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066888641679859945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69983849797882858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1815505583193362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17619359963583364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66636848140742977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12659465429598887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21856140200645946,
                                   0,
                                   0,
                                   0,
                                   -0.43026437537657841,
                                   0,
                                   0.71101569287382516,
                                   0,
                                   0,
                                   0.13692749203939306,
                                   0.19489678230902707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14137286523410642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47433310325087558,
                                   0,
                                   0,
                                   -0.21019006520630618,
                                   0,
                                   -0.022187866342727701,
                                   0,
                                   -0.78796814285164918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032006108658970911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14432006785479723,
                                   0,
                                   0,
                                   0.49235687069221218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18301695978566851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75222792898349389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25135079958532835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65852662431223818,
                                   0,
                                   0,
                                   0.53197793170438579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051009612273338958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3202496000235977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054542852180866117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68260775628503834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32457894575826379,
                                   0,
                                   0,
                                   0,
                                   0.62346210407139457,
                                   0,
                                   -0.42602534720755281,
                                   0,
                                   0,
                                   0.020683320046359754,
                                   0.74801357285447689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13608246291746973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1093427670616256,
                                   0,
                                   0,
                                   -0.54699903963963914,
                                   0,
                                   0.24529028113943363,
                                   0,
                                   -0.54521843824061222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17087494520677535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020610986692676577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58858181654640473,
                                   0,
                                   0,
                                   0,
                                   0.15212502584975807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17050697978349452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31609219449533582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44426316956886086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045940966388808901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19126398129606545,
                                   -0.25892480866524253,
                                   0,
                                   0,
                                   0,
                                   -0.20203356411923432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35762772844276092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0070504769025962477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14152399530773394,
                                   0,
                                   0,
                                   0.54120279827150553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57771265593384613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33376555925169721,
                                   0,
                                   0,
                                   -0.19450368192577239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30757266254354609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33081232485372747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073264766021765099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90841533331338986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62146681344080357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45349524224668225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3235314158803555,
                                   0,
                                   0,
                                   0,
                                   -0.62617103507875893,
                                   0,
                                   -0.21567859038144041,
                                   0,
                                   0,
                                   0.035557051664826519,
                                   0.43091396875556509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13558975522350764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30129372938653776,
                                   0,
                                   0,
                                   -0.30868297568870134,
                                   0,
                                   0.056895868929900326,
                                   0,
                                   -0.022821891800387337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30575572283784813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058050145890240185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095030045970018143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.532351999231511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14670363411857157,
                                   0,
                                   0,
                                   0,
                                   -0.020077777000698099,
                                   0,
                                   0.055399997153179364,
                                   0,
                                   0,
                                   -0.34002148798142617,
                                   0.61052908740115086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36084093783135507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12154231974102526,
                                   0,
                                   0,
                                   0.89223712595415117,
                                   0,
                                   -0.46257897760783812,
                                   0,
                                   -0.044690034722381117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29601533317577078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60344943390585937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.163690472991632,
                                   0,
                                   0,
                                   0,
                                   0.022534538901599663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68868794137742961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13892969680283274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41247561096145891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36217905619376023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071867970333151759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15302833050492348,
                                   0,
                                   0.41222777243120245,
                                   -0.56948787916519505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10135104571786646,
                                   -0.21059060564150006,
                                   0.44449244147525047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55615406416359447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1338332756108119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29199561431448168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30457832062143636,
                                   0,
                                   -0.026378317832467559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059748284855237643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48815190023816268,
                                   0,
                                   0.21539531117076247,
                                   -0.32895258824509588,
                                   0.084793152838098323,
                                   0,
                                   0,
                                   0,
                                   -0.15365061852256401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012070642562680145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052732597417020216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37067899284583428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30747177330009934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10259090500039114,
                                   0,
                                   0,
                                   -0.32895160950367008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3922783697477738,
                                   0.03272417636512872,
                                   0,
                                   -0.41753951256509197,
                                   0,
                                   0.36290761646525305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2286521345296495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14583534936133299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0054231770192509493,
                                   0,
                                   0,
                                   0,
                                   0.20390490572720008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22164912696425482,
                                   0,
                                   0,
                                   0.646271669487261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39038456919649384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055010874976779041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97627067487005792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4727695198999039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18141589610044168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2057024482142964,
                                   0,
                                   0,
                                   -0.4431957060839809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59246958593811483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45983401253624773,
                                   0,
                                   0,
                                   -0.29354318209442964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14829591446162263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24026138724822627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086288577816684947,
                                   0.29595768337097544,
                                   -0.28663180798819765,
                                   0,
                                   0,
                                   0,
                                   -0.50093935757496444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37626140158928689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17324878474704858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047983398115476271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2467269360655541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33795119181869993,
                                   0,
                                   0,
                                   0.28642369368197057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2367364715975675,
                                   0.020347361058988961,
                                   0,
                                   -0.21277703311419566,
                                   0,
                                   -0.19778561169883155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66194767895856155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53598805025803353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027829233942755313,
                                   0,
                                   0,
                                   0,
                                   -0.059418279114477168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40874280698645943,
                                   0,
                                   0,
                                   0.070757712305162854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33488610998980844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74405684860729682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56887544595956097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.241095740348118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34703763228408879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054133249584642662,
                                   0,
                                   0,
                                   -0.42245267013786159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17576849381644311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5786905361101804,
                                   0,
                                   0,
                                   -0.16622850312558041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51119529203991743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20841874364919882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47879592180949176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41474997885750203,
                                   0,
                                   0,
                                   -0.12451048359166211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76208239825200164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20505775843636648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52265336149900332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3788541499514293,
                                   0,
                                   0,
                                   -0.39192407959268138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4437212646689605,
                                   0.13595040374625433,
                                   0.1188885566079517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48069700131978133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47063599813257995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079954245101604732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14549843951258704,
                                   0,
                                   0.44851942247666016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23483256563160163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18452128566408346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094802330678189911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087922413463448895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36665257314796201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40351157297004103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17122314152891938,
                                   0,
                                   0,
                                   0,
                                   -0.20381794025711791,
                                   0,
                                   -0.27931362395063702,
                                   0,
                                   0,
                                   0.39461005735082938,
                                   0.12165224555145721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92784732180465324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057316268068926937,
                                   0,
                                   0,
                                   0.48635980015499003,
                                   0,
                                   0.6905760930047864,
                                   0,
                                   0.28921122053122555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30594653234852509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031917766440760172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41982132622412166,
                                   0,
                                   0,
                                   0,
                                   -0.32061133241376993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0018469527707784816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30378836855516833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043616505795388685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18994839872235553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42017448641540445,
                                   -0.0409247820609615,
                                   0,
                                   0,
                                   0,
                                   0.42447862363197159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37102464406561703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23724944509565704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74510917616615391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42768676115856713,
                                   0,
                                   0,
                                   0,
                                   0.47679152011994841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21445453279152291,
                                   0,
                                   0,
                                   0.23842528352964187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62083500139765568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57060110228678118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65734880927208883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41810614390301937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56336396141441192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36751346314211908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60949181359876292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35086344506325212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06533555120119279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22068243974639634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4653168156002343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71022950369761984,
                                   0,
                                   0,
                                   0.19116015978961848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049856257249975298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092864438685806877,
                                   0,
                                   0,
                                   0.44517727105846788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18218793363837621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0052354862625865386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34583631905803075,
                                   -0.39814557004259371,
                                   -0.20112939858062764,
                                   0,
                                   0,
                                   0,
                                   0.36631752806463214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52208724099933501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078348984333421079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0048578975669139376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17792690951058027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2612510145367829,
                                   0,
                                   0,
                                   0.12850006295152788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1266259438199373,
                                   -0.2650152759084336,
                                   0,
                                   0.019020504803827349,
                                   0,
                                   -0.25582646420333355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25578161808576927,
                                   -0.26970265353910861,
                                   0.34448786640087675,
                                   0,
                                   0,
                                   0,
                                   -0.4546520900373443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30340145555168735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18509350457889709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12194093074088953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00998726061039883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32534811862371649,
                                   0,
                                   0,
                                   0.34445904517153353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054185426979450793,
                                   -0.033306072503339335,
                                   0,
                                   0.31451711330452381,
                                   0,
                                   0.26020115910881458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30108816623605311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48043011600689145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22440482721702615,
                                   0,
                                   0,
                                   0,
                                   -0.23443277785794797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09114463752369982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14887493085930434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20726134630190052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40512367576061886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18651577450905107,
                                   0.16962014512593815,
                                   0,
                                   0,
                                   0,
                                   0.40194448749375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33248235871018927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27708677826014944,
                                   0.28839073873538318,
                                   -0.29829280648872991,
                                   0,
                                   0,
                                   0,
                                   0.24904144850264476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046990306260849705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059659670787324079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14262584388800598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048805873592026906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25559019969636226,
                                   0,
                                   0,
                                   0.40994522503185371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094525970476070087,
                                   0.20637368252758376,
                                   0,
                                   -0.02826273266593541,
                                   0,
                                   0.61225523444690821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55406202585354236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91656880803947105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21903001275108425,
                                   0,
                                   0,
                                   0,
                                   0.56699716785334087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43093422634116446,
                                   0,
                                   0,
                                   0.1525584568244272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92771698385219969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081182582867828854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57752228441903719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22169514934866888,
                                   -0.11969666808362685,
                                   -0.061244629053262653,
                                   -0.026092113506531095,
                                   0,
                                   0,
                                   0,
                                   0.25294694992530903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21853239752695652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074351591504039638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48455993802271174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21306272557398698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13243415286228685,
                                   0,
                                   0,
                                   -0.26599790237791859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69261525711890348,
                                   0.0061000334145128732,
                                   0,
                                   0.12516129504477413,
                                   0,
                                   -0.0082507703741700952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21376978452445575,
                                   -0.20504149273799446,
                                   -0.18307314097993121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055556653873471161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4691058677456208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24284647080252181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29722591663790177,
                                   0,
                                   0.37479014448570414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60602274147843616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023429982794713707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29982906795455999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03573751875062138,
                                   0,
                                   0,
                                   0.35722853255822651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31196065318370009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013107661562758589,
                                   0,
                                   0,
                                   0.013161208524864743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60631664908127625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56207542109570341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16158046636651763,
                                   -0.22742040930076801,
                                   0.50699173894185967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025141099327841095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25849114650410016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66536654774059567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15274548460695003,
                                   0,
                                   0.16827802281452142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046604256541498919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31803783369332306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12193726938468859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2357837491449333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20511838743225852,
                                   0,
                                   0,
                                   0,
                                   -0.15331563370964202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43729600904016874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088447312692558219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3934995042063546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15675253396904992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10811877783654199,
                                   -0.67851399125413281,
                                   0,
                                   0,
                                   0,
                                   -0.0091764570940186217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11549472887074026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55943545269065176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01525945491900573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20757544159149807,
                                   0,
                                   0,
                                   0,
                                   -0.25347342425417924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46854529392173261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12502511682323186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070470080369983923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012936295983609583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35198140404289835,
                                   -0.15113474943997846,
                                   0,
                                   0,
                                   0,
                                   -0.40650743777764825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1648711983049107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90272031406565656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2922213793884435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30108503045905211,
                                   0,
                                   0,
                                   0,
                                   0.51984156896328071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13465846408998128,
                                   0,
                                   0,
                                   -0.29991236071842281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079723693150423269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50999538071736739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16809214229183775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33093146691897313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1012659349894747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13906013100937947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11737932597768387,
                                   0,
                                   0,
                                   0,
                                   -0.23138369259875866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084840110995031234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77527757517047802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63725475543331778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35892144901988521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53354152236614061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07151948638819923,
                                   0,
                                   0.38351926924497159,
                                   0.62199557838005282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0023963432391803704,
                                   0.39952410201483701,
                                   0.048301089203862183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20826025987248351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46136842374354398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15189150680550084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.253740874411715,
                                   0,
                                   0.29061755224613572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59936018994961993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22508206459741606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34656651302341895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18852621109632456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069721777688449685,
                                   0,
                                   0,
                                   0,
                                   -0.637047271884434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073326445518823544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48169967997712093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25371548807669225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28041518317215947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051865233073398992,
                                   -0.18424481439916601,
                                   0,
                                   0,
                                   0,
                                   -0.10450808322668387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075402256203676674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014155699597227265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45568731996997708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084263825641596041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061132360122902261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41958949064431977,
                                   0,
                                   0,
                                   0,
                                   -0.21915093552897635,
                                   0,
                                   -0.19205843660421273,
                                   0,
                                   0,
                                   0.5548251488182856,
                                   -0.23324782993036394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46326784349368588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1247485156814999,
                                   0,
                                   0,
                                   0.37352686694074,
                                   0,
                                   -0.8508628793070353,
                                   0,
                                   -0.47460585329943045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31667037200691744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32545235894709407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41513091268106439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51596927997244302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.241018938476703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54511699322773044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41437084546199776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55657441014671183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019013659263288171,
                                   0,
                                   0,
                                   0,
                                   -0.80816248606032215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12882027261675769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45265358301358255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41862437781554157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026990796285812385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.173155577961568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0069917758142788444,
                                   0,
                                   -0.22895318835695505,
                                   0.41748834323576767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9899927941669403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17984899211849636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28337519711986292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4135521944713107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33711553696558155,
                                   0,
                                   0,
                                   0,
                                   -0.01538690450774069,
                                   0,
                                   0.32407301843306247,
                                   0,
                                   0,
                                   0.26674839018953689,
                                   0.33761259719894149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2969148216550751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52505128572946347,
                                   0,
                                   0,
                                   0.40554511564591544,
                                   0,
                                   0.19486238274230858,
                                   0,
                                   -0.23142389731403898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20502388726961734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32296122813494893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14478316976166852,
                                   0,
                                   0,
                                   0,
                                   -0.30903323538370764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35121682287959355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63647281750135209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11558458559763818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1834312759516678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1857646505687805,
                                   0.14058702475620452,
                                   0,
                                   0,
                                   0,
                                   -0.31519802519452278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090093276210913675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52497304817987334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47972312549583662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010907955728056862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14569595139162855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41145506893682016,
                                   0,
                                   0,
                                   0,
                                   0.54023145142218898,
                                   0,
                                   0.98941052740061175,
                                   0,
                                   0,
                                   0.49799144492452335,
                                   0.14162769664783903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42025736480038267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049857221678707125,
                                   0,
                                   0,
                                   -0.057350248624073286,
                                   0,
                                   -0.1528292256061104,
                                   0,
                                   0.44863349738438646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52394015888583623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0095491798052932536,
                                   0,
                                   0,
                                   -0.56355317898721724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23270149084150871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52716143599884535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95032579081802049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088136148062988612,
                                   0,
                                   0,
                                   -0.77560950599705536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17099251300533436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39232244508685843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084886916126793957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67325924012312255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044296794461458497,
                                   0,
                                   0,
                                   0,
                                   -0.70058969349007683,
                                   0,
                                   0.20455691031327305,
                                   0,
                                   0,
                                   -0.031752631837158526,
                                   0.47767200220857653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029362822770549149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16673561472672457,
                                   0,
                                   0,
                                   -0.50861026103305351,
                                   0,
                                   -0.20839969625863869,
                                   0,
                                   0.57689883816271403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45397485940414595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32578304279496295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97136666810001915,
                                   0,
                                   0,
                                   0,
                                   0.50755385044297119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35412098305779038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20825872344701302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45721569869362688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035565084564330607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23589893228056005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32042233691015254,
                                   0,
                                   0.30771993609216897,
                                   0.30008480414657157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068041153073454957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.001375165935901583,
                                   0,
                                   0,
                                   -0.3446226303737796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57209496847316699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2162488346132048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28691468515964752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0967069579790016,
                                   0,
                                   0,
                                   0.46966141391349958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71139346083292443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90866469241013825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25318542076418271,
                                   0,
                                   0,
                                   0,
                                   0.14078009379286732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089562210534605585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047759079081469341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37863190445615136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49111852065775685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46325096764177565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37983067187623754,
                                   0,
                                   -0.52053828742964803,
                                   0.0485821321813905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41316626340373341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23227216927033439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23980479768211854,
                                   0,
                                   0,
                                   0,
                                   -0.23012833543809635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6040826924590823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49322319087744548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43547334417836281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054210816651782526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20452864381246119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47994108194279672,
                                   0,
                                   0.60243696577779626,
                                   0.43081716176842011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30417920485953454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0582592792164172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17185274816474896,
                                   0,
                                   -0.018900218945552043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29474554243241069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067592470447065081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2379649440380609,
                                   -0.30597498007375318,
                                   -0.14438099994275291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42178383509226758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18229762191762128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22405817156184987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47409573156703877,
                                   0,
                                   -0.57814867253117797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031522976279042624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086911937123861277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72953069197120235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36287850568912194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081788022663474236,
                                   0,
                                   0,
                                   0,
                                   -0.14412268512260989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61162356889903002,
                                   0,
                                   0,
                                   1.0636358498306941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43579032448650756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09575659401724855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24056004306894435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2888399686026018,
                                   0.33930280064218227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52865717146061642,
                                   0,
                                   0,
                                   0,
                                   -0.39129935485938339,
                                   0,
                                   -0.14423983257477055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20995195957620744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056100365218884618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54090601574786157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15623152722914546,
                                   0,
                                   0,
                                   0,
                                   0.13297460931834568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22266108578182556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23776457717993094,
                                   0,
                                   0,
                                   0,
                                   0.75784601179049438,
                                   1.0332245487232423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57262730478362123,
                                   0,
                                   0,
                                   -0.61301431235376225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033604560759243993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42389960451579123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10858900757732361,
                                   0,
                                   0,
                                   0.40265689738156757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26766472946864667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4349860126915357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0052854848010829777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21179445542952374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18937995327721213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14355266592627305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37552873295536399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22800315644593075,
                                   -0.30193294976627194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031783774994483427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69078716883382563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46901487554145993,
                                   0.26889190538998975,
                                   0,
                                   0.60916097318423013,
                                   0.71698925017065829,
                                   0,
                                   0,
                                   0.54362273073650802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.273385472468479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12578409599286289,
                                   0,
                                   0,
                                   0,
                                   0.24324484469236302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27006602665854768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.241459462634662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40848573536179689,
                                   0,
                                   0,
                                   0,
                                   -0.25669320032745718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46049270379639196,
                                   0,
                                   0.61588423281477633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079036725374271657,
                                   0,
                                   0,
                                   0.12390050632045088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13870140422594401,
                                   -0.14842527038194836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084170873634365678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31658618703768804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45750132789449921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94239223788656723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74735168987076561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40283750801362056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081335115814167441,
                                   0,
                                   0,
                                   0,
                                   1.1579174712531515,
                                   -0.90942591291043395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74649495520232922,
                                   0,
                                   0,
                                   0.62760066192220243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034478811355513034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76774087989411299,
                                   0,
                                   0,
                                   0,
                                   -0.039085201769503614,
                                   -0.59988262471940601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27683977381694247,
                                   0,
                                   0,
                                   -0.13030039016196865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56002719570324955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50900546835845062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045341231610786958,
                                   0,
                                   0,
                                   0,
                                   0.96630416002538133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03020386522101523,
                                   0,
                                   0,
                                   0.56784658820290634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42682944365067932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55618572249410303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057385368059027192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60482798834081031,
                                   0,
                                   0,
                                   0,
                                   0.89683711052084658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43250135749763541,
                                   0,
                                   0.19453789454990372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24361749460759663,
                                   0,
                                   0,
                                   -0.013688512936339228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1059864127549331,
                                   0.08752987058132447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02159719946799555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26014190019605377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19789570140231039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34126732969167861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47008028264850904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3128215105975849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62261617448377682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13126642295467089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11051078324950911,
                                   -0.39260246169906016,
                                   0,
                                   -0.8280408392080022,
                                   -0.40007210467614307,
                                   0,
                                   0,
                                   0.75913631044319885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34665718187289107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04223325512885702,
                                   0,
                                   0,
                                   0,
                                   0.44540287038929199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47010725553062382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22163488798984171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31499123476962926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21399113604776684,
                                   0,
                                   0,
                                   0.19486438330086908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62333960353818163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40923039917808329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097358932568620229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042500904278980137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04731444426315487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33217967330508974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0033329225001568798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22655291896146987,
                                   -0.29289928782896169,
                                   0,
                                   0,
                                   0,
                                   -0.86121240290865297,
                                   0,
                                   0,
                                   0,
                                   -0.040197381948723368,
                                   -0.26647194500450616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6625756693169581,
                                   0,
                                   0,
                                   0.54535835646185338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3285564741875875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11491449833394249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25726548067694688,
                                   0,
                                   0,
                                   0,
                                   0.14303955343302385,
                                   0,
                                   -0.24373924732461796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55677095918720676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67554802398624147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070501257902480505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15441304108815684,
                                   0,
                                   0,
                                   0,
                                   0.08868893850453613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19416853465245854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058283899238767596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.353520326944881,
                                   0,
                                   0,
                                   0.21075247034902153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075360509732618791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30411107626883749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39390088051421823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4921725868452167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29791132375709195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2524538708078754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14887021270406256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37941121578407083,
                                   -0.11426252718146188,
                                   0,
                                   0,
                                   0,
                                   -0.18658420627511546,
                                   0,
                                   0,
                                   0,
                                   -0.0032447430381253306,
                                   0.7109452842200259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36056554879906882,
                                   0,
                                   0,
                                   0.73782438865041755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35713388419340386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45647771604727799,
                                   0,
                                   0,
                                   0,
                                   -0.061682945766325582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048104085239785974,
                                   0,
                                   -0.47525725572138555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14107247803261175,
                                   0,
                                   0,
                                   0.76865742422260419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34521408441189649,
                                   0.11801609640082686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48469863324004148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70756995338467266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50936425980599698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11848980286282876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050930294873492404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35789445952148213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56618905184547075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2793031156733029,
                                   0,
                                   0,
                                   0,
                                   -0.10037927138419497,
                                   0,
                                   0.076032101807093966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42584630040555577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36163978350885978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27756584994846828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10651745696328316,
                                   0,
                                   0,
                                   0,
                                   -0.31079423068096634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29740985257912805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034877906788818913,
                                   0,
                                   0,
                                   0,
                                   -0.12910177207377249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73110404082376856,
                                   0,
                                   -0.26958336231503688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35836180803816065,
                                   0,
                                   0,
                                   0.10065313659925913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21159071373863433,
                                   -0.25977615129183679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084894778284124769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24354652567235985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36763643816077513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012812286158793849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67960898136103165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1779317783936303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40991075241492969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22900894942982619,
                                   0,
                                   0,
                                   0,
                                   -0.58339446063576106,
                                   0,
                                   -0.079617752444254467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036319396124694349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087207677150079072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073101824541313087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40139234647604916,
                                   0,
                                   0,
                                   0,
                                   -0.50092843635971607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080788145959200627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1913364629390194,
                                   0,
                                   0,
                                   0,
                                   -0.0081399063862437337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10653566561352001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79448155022996858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28205990873743308,
                                   -0.031398854335838181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3256673221275295,
                                   0,
                                   0,
                                   0,
                                   0.17278518015900718,
                                   0,
                                   -0.65898998146120158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18390595588701936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82381194574131289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70261019206516628,
                                   0,
                                   0,
                                   0,
                                   -0.14269645606426398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2052846442853424,
                                   0,
                                   0,
                                   0.45022199838578103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25067771570771857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2364552597457403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86489150177706953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033766645944565243,
                                   0,
                                   0,
                                   0,
                                   0.029652487094107755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58735474598308923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30427691370312049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60875897932751077,
                                   0,
                                   0,
                                   0.22220767944186956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091557183500159955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36340616426243311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038833485326551523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090706238102498005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30267439916496996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27673176345444261,
                                   -0.11927561671844199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40836546183092215,
                                   0,
                                   0,
                                   0,
                                   -0.38126941611958609,
                                   0,
                                   0.30251399152802161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30436870253271997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15913227237465891,
                                   0,
                                   0,
                                   0.21677638471111996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41750823138805571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2536206492592693,
                                   0.024698722748359825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97667370217131722,
                                   0,
                                   0,
                                   0,
                                   0.55770720521831796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064134000703782668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1764948999942679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093096848001646776,
                                   0.49937836895226018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35705517764132211,
                                   0,
                                   0,
                                   0,
                                   0.39740068748335117,
                                   0,
                                   -0.17713060373729611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5543559175561481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83585368496356816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.434021559537626,
                                   0,
                                   0,
                                   0,
                                   0.35386990228398968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35925359436593679,
                                   0,
                                   0,
                                   -0.65539957585051323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0055558403208824866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43675103675686522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20334188166031958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20826501104730624,
                                   0,
                                   0,
                                   0,
                                   0.15222433487654227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086019451056743301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50756083423654508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048332834828244069,
                                   0,
                                   0,
                                   -0.16057519892082514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14576319577982941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78680920429219192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02408517451170189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32069301028899433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43164442615733256,
                                   -0.45297467643051648,
                                   0,
                                   -0.52976318844059689,
                                   0.46912462088136936,
                                   0,
                                   0,
                                   -0.13412181980038729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28889666731761032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10310989543122923,
                                   0,
                                   0,
                                   0,
                                   0.62555252304589282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60172878664703533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61208167810585301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24254636510986544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39069695960351486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6412518316244219,
                                   -0.35085151067683962,
                                   0,
                                   -0.12542512682505141,
                                   -0.039266964017672559,
                                   0,
                                   0,
                                   0.51831262082266161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62673003815859918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29401351680215232,
                                   0,
                                   0,
                                   0,
                                   -0.16541586950426282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57845908068611518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12469117267175704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043607835297970125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56044460478818514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055327603527457574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10817498057524944,
                                   -0.42150654517775332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12314644897357867,
                                   0,
                                   0,
                                   0,
                                   0.335079107261683,
                                   0,
                                   -0.3744825056119041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24520309867021928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21275736127409622,
                                   0,
                                   0,
                                   -0.23066190402681319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17472399090709964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18645540484828685,
                                   -3.9192377802865774e-05,
                                   0,
                                   0,
                                   0,
                                   -0.88044813138210931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36075765667080945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060844121462885564,
                                   -0.4087343515281962,
                                   0,
                                   -0.090578978572776692,
                                   -0.19960165776221003,
                                   0,
                                   0,
                                   -0.14933816204919811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30438915511573855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60587963605203055,
                                   0,
                                   0,
                                   0,
                                   -0.45035794683645719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30899743755665782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36076845641474931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020846013264851249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066644293596356582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27915758680878999,
                                   0.1802217459945461,
                                   0,
                                   -0.41183917660494163,
                                   0.20868307093093963,
                                   0,
                                   0,
                                   -0.62013144053040026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86434670043547734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5694806179460955,
                                   0,
                                   0,
                                   0,
                                   -0.19058979869018283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38703218561999431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.003015006190265089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21618585825764927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76338507749735141,
                                   0,
                                   0,
                                   0,
                                   -0.35517569476280975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0741911425878283,
                                   0,
                                   0,
                                   -0.093899316590558585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49024325403380042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53060287106894177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38775053924325142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1726559526282932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028705012513556113,
                                   0,
                                   0,
                                   -0.56987584569178118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32784748525180701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26560115603118856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20715167902194861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40436040922317862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16778399616831519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19105101180398823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028664103622375914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40626450726949098,
                                   0.17215086189450751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23571562155658804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066947539011789958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38580993474493019,
                                   0.13915503543396762,
                                   0,
                                   -0.61175652400626213,
                                   0.87602542538675632,
                                   0,
                                   0,
                                   0.32226219668303646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24220098074226876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34377074865456098,
                                   0,
                                   0,
                                   0,
                                   -0.5893250642034753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27012368030297695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31002457329578559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75341855018516202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.436697851740462,
                                   0,
                                   0,
                                   0,
                                   0.25125539819820347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44213439678290462,
                                   0,
                                   0,
                                   -0.029870337474335443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54922594414000681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75625696026028133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40205115903640659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39799046612340883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041628830935166228,
                                   0,
                                   0,
                                   0,
                                   0.06573461550698563,
                                   0,
                                   0.057547950864848735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11212527690326446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44187426628051163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15280443308508559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3166976003652846,
                                   0,
                                   0,
                                   0,
                                   0.449295119133304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54671766858140081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66863920615478545,
                                   0,
                                   0,
                                   0,
                                   0.12868781262577683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20647633750448274,
                                   0,
                                   0.57280080006225265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54630434859863541,
                                   0,
                                   0,
                                   0.28756163366713894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13372641956606215,
                                   0.0025902644723111573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13934078075638112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39705742042875258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38370475792460795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60801643609201506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11400469237494001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78343451513666118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15490753287719494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06461763166826226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03076406515789069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19174920654308972,
                                   0.11517856406506054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093088179084190439,
                                   0,
                                   0,
                                   0,
                                   0.51082810451563776,
                                   0,
                                   0.1013012837373634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11840964561444302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37451624683345802,
                                   0,
                                   0,
                                   0.4334866921572858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49729678345870859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19493797395577192,
                                   -0.11608763389260206,
                                   0,
                                   0,
                                   0.64908779052923005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29527972020790244,
                                   0,
                                   0,
                                   0.11186303606334894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26160909256961395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42430681076657667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23180423609255982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13867913953281377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0096928294841934892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30202674850579619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24784282674277344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057369569240181779,
                                   0.03885166139881386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38083060192093737,
                                   0,
                                   0,
                                   0,
                                   0.40735537191084681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44147759904460837,
                                   0,
                                   0.39916501796574411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41853098935035427,
                                   0,
                                   0,
                                   -0.70344872326464847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35312070930416328,
                                   -0.63864512422080333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42521933852287547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58164451286195673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11926770757460062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36198304956224164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11705428505593538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38224050108473173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4418301726033797,
                                   0,
                                   0,
                                   0,
                                   -0.28758380896676955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5141655262674063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094832120645204465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30631736769454598,
                                   0,
                                   0,
                                   -0.23397030634165422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49255690750313186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23986994551121787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45593056999891568,
                                   0,
                                   0,
                                   0,
                                   0.11982577079566333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20731687072360117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94723577452610086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27721522215422523,
                                   0.38744028073495274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58523885857134417,
                                   0,
                                   0,
                                   0,
                                   0.46243852371235195,
                                   0,
                                   0.45287795010477505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83117182219224717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47484483371771918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70656065601084428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18953149656160428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19069475900740704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44376159086618577,
                                   0,
                                   0,
                                   0,
                                   0.077996118103756562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018511336699512271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051631496184646991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82375748061538911,
                                   0.53795696556904615,
                                   0,
                                   0.048148538210386782,
                                   -0.18956675254160946,
                                   0,
                                   0,
                                   0.64342842607962913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27423301129159627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13124815649020682,
                                   0,
                                   0,
                                   0,
                                   -0.20891459179758093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37753950305765049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27983885821929899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51335738732721581,
                                   0,
                                   0,
                                   0,
                                   -0.63856817300354174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38376952934109065,
                                   0,
                                   0.18271615229254717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3163865923723102,
                                   0,
                                   0,
                                   -0.40768847097119315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10087942267833731,
                                   0.84155345535083614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21724211705141755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46056552863619227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18503146274303026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10544476273095232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14611474543759137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073772007579602117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27950232177341483,
                                   0,
                                   0,
                                   0,
                                   -0.3888619315595454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20704706911869397,
                                   0,
                                   0.23298385392957921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49766043185048509,
                                   0,
                                   0,
                                   0.83716600588520762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4447893252844165,
                                   -0.46419169961805157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50993089472759179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024815151270224361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17796426287360717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47584534081798963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15907754371530783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085858097226677851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46854037435420059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2592708547568075,
                                   0,
                                   0,
                                   0,
                                   0.64645860714162018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08595364886628809,
                                   0,
                                   0,
                                   -0.83592840592296569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2230014883254516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099486004712465187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13514260168251852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16898438430382301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03323139848551912,
                                   0,
                                   0,
                                   0,
                                   -0.43427070798864364,
                                   0,
                                   0.089514994748799939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49035330666952304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40037197401047686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45971478616030259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01339996713269111,
                                   0,
                                   0,
                                   0,
                                   0.091893944053845933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39119067766524718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53319275543539013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051295264275566681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53614439849259887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2698573879784365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56908819485731821,
                                   0,
                                   0,
                                   0,
                                   0.1701149082432801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65456139581894623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57011470017444732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33841423270189197,
                                   0.55886517265438196,
                                   0,
                                   -0.072038337551575737,
                                   -0.18006527491137372,
                                   0,
                                   0,
                                   0.30357548642816579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46990761182824953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54331071496296646,
                                   0,
                                   0,
                                   0,
                                   -0.11618908647243449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43414394071733486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031930449451758131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73714244528075978,
                                   0,
                                   0,
                                   0,
                                   0.27180122129465906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14180879198757668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22868725612399313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51094875538396956,
                                   -0.76453448641686139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04138336333023912,
                                   0,
                                   0,
                                   0,
                                   0.34634937585210962,
                                   0,
                                   0.6331590667289424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068429043804832376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33014071846018939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13783667841231573,
                                   0,
                                   0,
                                   -0.41524122287563603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15119253056386611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42199981505914685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29878806532649377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43844070843446259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027760456370183248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096503383363949632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017814011343567821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38355631560537928,
                                   -0.24416994643431084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46370698621799583,
                                   0,
                                   0,
                                   0,
                                   0.48094202828410776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14862948462786374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099015147730869585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083380376176519513,
                                   0,
                                   0,
                                   -0.63881064200488213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3181405687843144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074371555081541155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3721807622139926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95463330565625926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31160278036882516,
                                   -0.88560321797460795,
                                   0,
                                   0.42958744719147279,
                                   0.29763895415901986,
                                   0,
                                   0,
                                   0.069369997235858849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43525292762586215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16194537334372344,
                                   0,
                                   0,
                                   0,
                                   -0.10946482453989877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29967600776170766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087400176275897717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28238475555361642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37678403791927623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17572081335583187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15545379453325234,
                                   -0.27040977942474437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41871029582621655,
                                   0,
                                   0,
                                   0,
                                   0.22394716045330693,
                                   0,
                                   -0.037784513441135648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086209017253769851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023941444305756746,
                                   0,
                                   0,
                                   -0.42643334176667469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050443897168316487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44547755819090268,
                                   0.17995490366641953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15938851990926439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25016703182789235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042271046361850528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31174709975162307,
                                   -0.056783088433908425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16780535274769057,
                                   0,
                                   0,
                                   0,
                                   0.0055667338628985624,
                                   0,
                                   -0.065603638853534735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30237827590049682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18252862983933379,
                                   0,
                                   0,
                                   -0.078749231263725364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53078286482067527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17127726285315512,
                                   0.57905419833895688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19978628829698361,
                                   0,
                                   0,
                                   0,
                                   -0.39356039765990292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36941430030802042,
                                   0,
                                   -0.10832536443351554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24687772977572839,
                                   0,
                                   0,
                                   -0.05507085226943409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40408943771755784,
                                   -0.33162503956412903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46355491257037262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089156831841305476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80510013297428917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27083783238456793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48651727417712093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4443185396649969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058603863591729463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27173524135165056,
                                   0,
                                   0,
                                   -0.097935789197453438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046862517276949206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093236967448714916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7100034339413529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045060221482192755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52484298550834663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15939231042652324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14251644816465256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24853886340316364,
                                   -0.11472151891084366,
                                   0,
                                   0,
                                   0.2156705082213054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097827570840535449,
                                   0,
                                   0,
                                   0,
                                   0.50179410006641345,
                                   0,
                                   -0.29174594690863298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3416677373984357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012891749258873847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03569914092715553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52422963508911891,
                                   0,
                                   0,
                                   0,
                                   -0.39879592385075163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23445812854628129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52137340040583746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58790147358093769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39440068463947608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070940103684142691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1624785654025625,
                                   0,
                                   0,
                                   0,
                                   0.4422193484466016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19792336376934777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097549643959618446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33584696315173496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044263463099282495,
                                   -0.24030176129643657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43307737744488345,
                                   0,
                                   0,
                                   0,
                                   -0.091236767121010642,
                                   0,
                                   0.12230142145349088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35370886073906549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089283426402178345,
                                   0,
                                   0,
                                   0.24439471928396261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18361608595815848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43004596906089443,
                                   0.39561416275887012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62487244674865172,
                                   0,
                                   0,
                                   0,
                                   0.10592930520681476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2625581562456184,
                                   0,
                                   0.51257153713845993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74376945216082979,
                                   0,
                                   0,
                                   -0.0052406109932135458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33767847840568965,
                                   1.092531229861804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1921332720661601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1998459877968039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34800180408403508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020246670783885881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13575201890568064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.252974703399241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55912549079711404,
                                   0,
                                   0,
                                   0,
                                   1.1662853478312667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016605379345042401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082011556688172615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42474533084894295,
                                   -0.25539927284240715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34868113502104381,
                                   0,
                                   0,
                                   0,
                                   0.45579481680117279,
                                   0,
                                   -0.023811434886100675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16343851609910312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73840285754193169,
                                   0,
                                   0,
                                   0,
                                   -0.16943587352564901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15863510021570651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64944842983521389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25179272002601383,
                                   0.47806962598704666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71355980928092888,
                                   0,
                                   0,
                                   0,
                                   -0.29282646085473202,
                                   0,
                                   -0.10692189058479359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94566664105733644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22657754097348909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40054058958205696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54252839888991145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17578397570900284,
                                   0.27695177368164614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27770968248961475,
                                   0,
                                   0,
                                   0,
                                   0.23230256733707935,
                                   0,
                                   -0.23515918292827759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20162466662541315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12794273746376061,
                                   0,
                                   0,
                                   -0.14337877175851682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027756207259120758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25425503836114421,
                                   -0.23855429880599588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59567607114287546,
                                   0,
                                   0,
                                   0,
                                   -0.34587000376549043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14906673137540644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10067810017658989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15049556621731572,
                                   0,
                                   0,
                                   -0.66647556582748313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11447892366121795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11507810063677799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35113745746118441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30394851462933981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64086780930418452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36894721400514241,
                                   0.0048442557597920821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12522367033591192,
                                   0,
                                   0,
                                   0,
                                   0.073959976025527174,
                                   0,
                                   0.053995540000036535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33174458256212902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14043488457561279,
                                   0,
                                   0,
                                   -0.019991509436549787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17498709500169699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21345786336738379,
                                   0.083864961174583239,
                                   0,
                                   0,
                                   0,
                                   -0.80274208041620976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46564211368881203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27932327563237414,
                                   1.1546974030626727,
                                   0,
                                   0.065016256137475137,
                                   0.35350388540218114,
                                   0,
                                   0,
                                   0.1871387200556606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55069699046944087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20500124471140999,
                                   0,
                                   0,
                                   0,
                                   0.39493208002542157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1830068733418542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064221271460545376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24818482786912902,
                                   0,
                                   0,
                                   0,
                                   -0.53384470825879926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18377217119213884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3953453173060939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49566024912735773,
                                   0,
                                   0,
                                   -0.06815981954837233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3094757414477719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34240898023944377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27551417351401153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68289740138225385,
                                   0,
                                   0,
                                   0,
                                   -0.11789560456035414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95202463018493466,
                                   0,
                                   0,
                                   0.26080045027476145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10775789768322111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57330197985764086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3395248023268635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097633567066795712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23807277463742038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2018495276611896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90859371514251142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051633631231845889,
                                   0,
                                   0,
                                   0,
                                   -0.25463157241502987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073206161189091318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75491531408889656,
                                   0,
                                   0,
                                   0.16888593644511285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1134079894702209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037977988006206123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075137263909074464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15029275269556186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36139351144187215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22364794026421392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34733559337494119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12623787467298406,
                                   0.19100356194596826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33287517249804233,
                                   0,
                                   0,
                                   0,
                                   0.030100405603267356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80248960507935174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53985767945403973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69127150215563393,
                                   0.22733677848322198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12738686680897365,
                                   0,
                                   0,
                                   0,
                                   -0.5347792890679941,
                                   0,
                                   -0.1141350642613476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37911129280106781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27559590333204331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09821878154679492,
                                   0,
                                   0,
                                   0,
                                   0.11347753781046852,
                                   0,
                                   0.15229399943756247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11200977389618258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082997156182692003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42606636086325939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50293794437318329,
                                   0,
                                   0,
                                   0,
                                   -0.33905381517154431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55628951855233622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17370526599911623,
                                   0,
                                   0,
                                   0,
                                   -0.27104749926229899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093116149037171858,
                                   0,
                                   0.93081301136063344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00062376632977768562,
                                   0,
                                   0,
                                   0.34097733406314668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1076773878939392,
                                   0.10072429129605834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27974552023504823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2824869902756374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25662609073274145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67492399626155564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082718789840718371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098777840088525734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031318896907015545,
                                   0,
                                   0,
                                   0,
                                   0.36082183463124634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27072793585761568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15928179408208548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50742786420125963,
                                   0,
                                   0,
                                   -0.092473524547637603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69737506338418331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13340185916967659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29416092488112544,
                                   0,
                                   0,
                                   0,
                                   0.28411207666537913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47572283172461383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15652101192228518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3959399844341191,
                                   -0.17437087336834678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42581650583483854,
                                   0,
                                   0,
                                   0,
                                   -1.3105407373723073,
                                   0,
                                   0.39794898631189685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027661101052576964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19309490036578097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31563107062201012,
                                   0,
                                   0,
                                   0,
                                   0.063859589247851498,
                                   0,
                                   0.75732613125082238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05063835022984324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15018137420335004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3096490036361656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3861719366378778,
                                   0,
                                   0,
                                   0,
                                   0.12077917805538571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027439075670133227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24894054247239236,
                                   0,
                                   0,
                                   0,
                                   0.12650455126015736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4713883858759283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85913394937816068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35275102303537925,
                                   0.59207933193340923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32308080413113871,
                                   0,
                                   0,
                                   0,
                                   0.10822721587937567,
                                   0,
                                   0.38621348833204494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2733373069430225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21123336553969052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.004194299780631211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052688336451322912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35994240629720553,
                                   0.10442554063818876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44544379971261205,
                                   0,
                                   0,
                                   0,
                                   0.029373178424548563,
                                   0,
                                   -0.5957225653088104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13047179833376049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11394600079473224,
                                   0,
                                   0,
                                   0.42535582578429815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0069854291079696901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21446663531790305,
                                   -0.03124663411669662,
                                   0,
                                   0,
                                   0.32447832438537416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060603537223601664,
                                   0,
                                   0,
                                   -0.049660842463209856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064357059747392753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030922130858769957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16634783478849538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04005932687628639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16602785102622136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45943399249170036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4459936903464754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18302485620513076,
                                   -0.61898881838856701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41044117324279306,
                                   0,
                                   0,
                                   0,
                                   0.11549015589943218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41037676385078814,
                                   0,
                                   0.087527558776363437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24347108375253537,
                                   0,
                                   0,
                                   -0.3825208976966486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30868938227274029,
                                   0.052692742860704495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48167590206305966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62405074100275082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27767349379229589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46367291070550448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49755714671491585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051259775933656021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35754840858951925,
                                   0,
                                   0,
                                   0,
                                   -0.35655318220896787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48153029784958457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66271844629008192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021972480493125959,
                                   0,
                                   0,
                                   -0.068054526022202411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17700849339152736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19368939523795337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064518172289633274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15446834816195315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28835802605016403,
                                   -0.2089094327719406,
                                   0,
                                   0.30586096102939847,
                                   0.085509312663775899,
                                   0,
                                   0,
                                   0.1361889767259595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13613681171554787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56621692647615229,
                                   0,
                                   0,
                                   0,
                                   0.64289406364653157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24770842518152003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99434780984272375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53680686050845483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12525530795370665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036538821789476351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037176530871717448,
                                   0.06961185595660413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26966421272936414,
                                   0,
                                   0,
                                   0,
                                   0.13083682143131412,
                                   0,
                                   0.052552608269534909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14202143584870491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64930091680769031,
                                   0,
                                   0,
                                   -0.2814293184667862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031446431799139821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20115124726487169,
                                   0.1832286586497307,
                                   0,
                                   0,
                                   -0.16312731438461262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076330917583437852,
                                   0,
                                   0,
                                   -0.015516099371031766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28386296986706883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17857329102745728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26366914212241666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32157076029412823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14202469706802223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52341363960753495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59853844576518256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12921850291860318,
                                   0.11334901591546301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37722023432528057,
                                   0,
                                   0,
                                   0,
                                   -0.00084892060796229463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77787769669855522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034256153429647676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60962128083408862,
                                   -0.7180350965448693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083111719477636986,
                                   0,
                                   0,
                                   0,
                                   -0.17865168026796333,
                                   0,
                                   -0.24396876176643459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36554756801499122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38211958312952859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27130975958117093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11898349378372823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46024641456180054,
                                   0.19288012270094909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16367849726983477,
                                   0,
                                   0,
                                   0,
                                   0.16101757351461005,
                                   0,
                                   0.060717654207246029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46918593521173152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35818935936867641,
                                   0,
                                   0,
                                   0.0051992385695610807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17251049665873192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20469618518749555,
                                   0.20164976862231554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020475947796673832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26349352645478757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69104709899048422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04947916135589242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.670929696227345,
                                   0,
                                   0,
                                   0,
                                   -0.0033104934504038994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2806641355495525,
                                   0,
                                   0,
                                   0,
                                   0.26403965211581293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42459204964038333,
                                   0,
                                   -0.21933629291891052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33558374746958064,
                                   0,
                                   0,
                                   0.29642562966541197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05439795354449764,
                                   0.17145432637375599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83966492982034546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099843631294758373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6601285991763185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018896987942096211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51091080213432316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018156959464674507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4556311747967936,
                                   0,
                                   0,
                                   0,
                                   0.0063985218460292925,
                                   -0.33996648466441187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66035502274596858,
                                   0,
                                   0,
                                   0.36122355619143942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92057459422449084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7464276049062607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28203035023161271,
                                   0,
                                   0,
                                   0,
                                   -0.39104098119722336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26542475166895391,
                                   0,
                                   0,
                                   0.45950107846746124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49063081121241808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42545843222104868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52290937076557342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45655894355023152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1624967941057536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052780402535711438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24039399768898456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0015177538577146599,
                                   0,
                                   0,
                                   0,
                                   -0.83938749953531733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0024443372475938807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3249875139332607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041575838618141597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29027018752784939,
                                   -0.52558702480521602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048102731731433521,
                                   0,
                                   0,
                                   0,
                                   0.08854990635315492,
                                   0,
                                   -0.16886778703748284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20927147904784843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15349852754391816,
                                   0,
                                   0,
                                   0.39663628549919272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32227415205213555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38505082053452749,
                                   0.12914079010934135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041593625083922087,
                                   0,
                                   0,
                                   0,
                                   0.46281509825839506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45326766475380759,
                                   0,
                                   -0.18627767800174486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71016728898873971,
                                   0,
                                   0,
                                   0.30925985631676045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15644582557710437,
                                   -0.04082837288994845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67927314285837115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19042968529120502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028507009606378728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29690452819642954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042077583496723331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049348145039773639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19070069825042707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63419501523910415,
                                   0,
                                   0,
                                   0,
                                   0.1197280298656071,
                                   0,
                                   0.46313006077309427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27999354590471781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13015125537383213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32663009596961734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04378993212089187,
                                   0,
                                   0,
                                   0,
                                   -0.35782088248219657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025087353251928846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1084688106614258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14775189317808679,
                                   0,
                                   0,
                                   0.29610601425409294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3962629762822511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20599798253690071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15224390404347649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2015461939666458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46080526056062387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31609884417815759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19221995791300822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019320111324956271,
                                   0.5156401723328774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071546915916567796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1880413950669213,
                                   0,
                                   0,
                                   0.34246459848013017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28024957066601025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19171538242244496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13890413476558797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40728579710131979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42188408003027711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088873900865980349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1979383186424121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55587907543345494,
                                   -0.087766227734878563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2892568787807091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10713153465049463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031292555600236381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39573568284607236,
                                   0.28879454498662521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11563289480119057,
                                   0,
                                   0,
                                   0,
                                   -0.44090221623366549,
                                   0,
                                   -0.52089352459974092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053847694211267075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30763500111098513,
                                   0,
                                   0,
                                   -0.068732295604278515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081030782978790961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026375507719423603,
                                   0.27430749549897943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30193962338937197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014356656549403782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18137861870089531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03139423769040077,
                                   -0.41403592381400661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10934412736189671,
                                   0,
                                   0,
                                   0,
                                   -0.34252690039800765,
                                   0,
                                   -0.13379650648084873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3930778472789247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17355114722238063,
                                   0,
                                   0,
                                   -0.14476906298939307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23926837742414436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25031273942048982,
                                   -0.48025033206086176,
                                   0.51565345375481098,
                                   0,
                                   0,
                                   0.25211638715308249,
                                   0,
                                   -0.2132423638382428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59142786009937431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30146786838101969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3739143600905287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057922318802641121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16100146352350472,
                                   -0.026654793144536254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12082158294235815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15264678099486623,
                                   -0.19101277973760042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75768618860909032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50094141145737525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13183234237046348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36476083029917356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45749605261687126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72812519332793835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077587136897828507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34207931622809212,
                                   0,
                                   0,
                                   -0.58332248569611678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68569360290984127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99998188397881205,
                                   0.65533665551659348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16497435490667423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015543939664107227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41095619115184223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60568555362641263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043097231174800729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53582293691785265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13899236773546453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15016760288926273,
                                   0,
                                   0,
                                   -0.26285103883771316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68927951764364215,
                                   0,
                                   0,
                                   0,
                                   -0.10543438462206425,
                                   0,
                                   0,
                                   -0.33708350166733103,
                                   0,
                                   -0.37773211033917031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28745839713362864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067385983482730297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38513320774042697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08808410615114666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18486717955085205,
                                   0.61109097370407761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28584804657481966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59191425244943552,
                                   0,
                                   0,
                                   0,
                                   0.78035511567891824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81160156084927504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4834405904344804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41911831035391117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21597059322457321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2883115304086063,
                                   0,
                                   0,
                                   0.39656323001813804,
                                   0,
                                   -0.40983870292422964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14964528245220979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083189631103547879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11671828340358893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39666900038838632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53866323737993838,
                                   -0.31811424049257714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0028056148099718098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093985623513297298,
                                   0,
                                   0,
                                   0,
                                   -0.11649617010605276,
                                   0,
                                   0,
                                   0,
                                   -0.38945772261774741,
                                   0.40631838548102123,
                                   0,
                                   0,
                                   -0.016568830765890358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077297046339496411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11189351645790646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20151095725869014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30404808905093322,
                                   0.38529192614156876,
                                   -0.34950598318746445,
                                   0,
                                   -0.23397507829737618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19194072041513843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38316066327789561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40993614769938991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045115756118636267,
                                   0.25613645972037391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16048681475406201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39796794651843487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15738424680788446,
                                   0,
                                   0,
                                   0,
                                   -0.00078298770193345468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41989568208549877,
                                   0,
                                   0,
                                   0,
                                   -0.38304418747157903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41493686219278025,
                                   0,
                                   0.11371302540391701,
                                   0.21741120909319064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33740999983946623,
                                   0,
                                   0,
                                   0,
                                   0.40794804987762118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19769473263517634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69516923869836889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55321516862748144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85952615618363137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52847317348871603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31766727780340087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61049665746890736,
                                   0.11192417495518896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3758337705885309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042242211927417297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53431932940215543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34506647483106495,
                                   0,
                                   0,
                                   -0.57180808523112836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020820924723970936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0028392474020141681,
                                   0,
                                   0,
                                   0,
                                   0.077541767955924504,
                                   0,
                                   0,
                                   0,
                                   -0.28730400922580418,
                                   0.42733882656836863,
                                   0,
                                   0,
                                   0.3078889580403697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46604609201770869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23427023394478524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35870084099262728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30200096255453535,
                                   -0.030700981303767527,
                                   0.13208161148364103,
                                   0,
                                   0.27814360626318385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062823232540909282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20584079356606894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22486279571962767,
                                   0.028751043831926643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18403756157230727,
                                   0,
                                   0,
                                   0.18384752566094051,
                                   0.031214451210218902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38607973678407914,
                                   0,
                                   0,
                                   0,
                                   -0.68840372279467865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079255529633840471,
                                   0,
                                   0.71274994874329212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19080059645453507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044970604548382469,
                                   0,
                                   0.75333471455641654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033475676492367101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35293462218127042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24950425960001152,
                                   0.33196267695768605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55759182386851069,
                                   0,
                                   0,
                                   0.27691335049053678,
                                   0.41176780022111115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060952145033258132,
                                   0,
                                   0,
                                   0,
                                   -0.6390534601528054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28520218517156315,
                                   0,
                                   -0.38448594339316344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45177837018744454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72654733919160719,
                                   0,
                                   0.24474326704096991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.574106595480113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38524971615648745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031197253844820139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3129045662737952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30862294893869141,
                                   0,
                                   0,
                                   0,
                                   0.42248083348913157,
                                   0,
                                   0,
                                   0,
                                   -0.11168405385786676,
                                   0,
                                   0,
                                   0,
                                   0.29337463106609163,
                                   0,
                                   0,
                                   0.11078860818118395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71872328940855157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17838670647304933,
                                   0,
                                   0,
                                   0,
                                   -0.2015085685879883,
                                   0,
                                   0,
                                   0,
                                   -0.047204625419378435,
                                   0.17084159956261469,
                                   0,
                                   0,
                                   -0.49675803965278886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17266675152288646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10129399233715473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30078319091809075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24195765339635961,
                                   -0.13765928352813014,
                                   0.63919936592339899,
                                   0,
                                   0.056623443858370377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16450225052810016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050073690447076012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10179269613386091,
                                   0,
                                   0,
                                   0,
                                   0.45742510902544742,
                                   0,
                                   0,
                                   0,
                                   0.0012975577069719232,
                                   -0.2322529282860275,
                                   0,
                                   0,
                                   0.22881308382369417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20983173854424333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15324675066388505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25367350740808076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32320658302662486,
                                   -0.42841719877887063,
                                   0.018656635922895969,
                                   0,
                                   -0.29317400504404928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39770886233944813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09880592852712422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12191144797951076,
                                   0.66989294016883372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48598806206042422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56241685940142272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34602407235899552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34924293238304105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22829804630733391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5447882728979031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47373008523211635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50196124710971091,
                                   0,
                                   0,
                                   -0.10716650228367473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13642981027279497,
                                   0,
                                   0,
                                   0,
                                   0.41917864742255506,
                                   0,
                                   0,
                                   0.23427341588816955,
                                   0,
                                   0.55064013427428482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.102947794812462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16165914322420599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56878874939146717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13054772943392656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2840404677112629,
                                   0.048342353239775683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076742570491833501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24792468130917428,
                                   0,
                                   0,
                                   0,
                                   -0.35993143180955595,
                                   0,
                                   0,
                                   0,
                                   0.28208358060445105,
                                   -0.015613123080187623,
                                   0,
                                   0,
                                   0.23116613888707602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14291355549380796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2952073827550053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47525635472809785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28233951325030415,
                                   -0.044929669741859427,
                                   -0.27883040194872488,
                                   0,
                                   0.27254831049267797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12181412245611545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3060846289531659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70973858509549981,
                                   -0.4017342487291542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30068567185108142,
                                   0,
                                   0,
                                   -0.032852614494152117,
                                   -0.1625047503165894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12457926658730406,
                                   0,
                                   0,
                                   0,
                                   -0.40554368428393461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014638194782413964,
                                   0,
                                   -0.04779669262056363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57297396043277304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20871105764971537,
                                   0,
                                   -0.073389166371766082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19437264146690242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4598048540819743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26042460094037662,
                                   0,
                                   0,
                                   0,
                                   -0.2509670346369145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83714672124949474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18623492858708096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84315607755472322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19007987376104135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047043333604690485,
                                   -0.58996337563612078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29508839363313599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046832287029153125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62465443854009239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56064647008112534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48933556933656824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12032268122609363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089644610502140912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13975781624158165,
                                   0,
                                   0,
                                   -0.32884659638180652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20045188338864542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15392354803852812,
                                   -0.24025874884590595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18407587341212509,
                                   0,
                                   0,
                                   -1.4301619136827712,
                                   0.44596798691922251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069349698859906869,
                                   0,
                                   0,
                                   0,
                                   -0.20520230154844796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092248350234775761,
                                   0,
                                   0.20490733970199596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26188398256391449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18454141737978699,
                                   0,
                                   -0.34227727379773465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6204264453841658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034152808024931668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21749900164388086,
                                   -0.090876697309122373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087104690884110353,
                                   0,
                                   0,
                                   -0.19572071760581775,
                                   0.39162491645399666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3777191436224146,
                                   0,
                                   0,
                                   0,
                                   0.37377724634219656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40536431816181501,
                                   0,
                                   -0.085441625337291396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4506729681517338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020607271237928111,
                                   0,
                                   0.94306412955365138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20769270428489242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46108943007287256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019314356897862955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052711670942555355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1096997378032333,
                                   0.20428306051958786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079544710872014507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.935370415582925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95637231109178367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015947899436235161,
                                   0,
                                   0,
                                   -0.16256886935208759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86490397869430857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15782166833723429,
                                   0,
                                   0,
                                   0,
                                   -0.53159552137113564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80725008305687829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48839158196060112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44324276858446676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56975385318957017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18913689506652737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62554873990821602,
                                   0.66037223877738582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092465619676524918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37653795733791878,
                                   0,
                                   0,
                                   0,
                                   0.22120318270973874,
                                   0,
                                   0,
                                   0,
                                   0.71252828666626822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4417998328761561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22322988531963608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14599125768063895,
                                   0.20164529919964858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0070600114288990913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53744583037727156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14035410536892184,
                                   0,
                                   0,
                                   0,
                                   0.2070447337368751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29561804570892336,
                                   0,
                                   0,
                                   0,
                                   0.3476471046492291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40514283153454489,
                                   0,
                                   0.36315035396814815,
                                   0.18017228262843496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22918497589032419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31944613511906922,
                                   0.068527326295011431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014383323219460814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14118142241625214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69487592906501805,
                                   0,
                                   0,
                                   0,
                                   -0.4319981851808864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10773337082598705,
                                   0,
                                   0,
                                   0,
                                   -0.074656374844402018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25692363823608405,
                                   0,
                                   0.21732804337496048,
                                   0.14386475768075715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33842717494922087,
                                   -1.0158995346476005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26327853731579204,
                                   0,
                                   0,
                                   0.052658445554497169,
                                   -0.33212083461278336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11437809957559479,
                                   0,
                                   0,
                                   0,
                                   -0.17603401961462475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49780571107476052,
                                   0,
                                   -0.37661563907344181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42806414420112454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059163915538624531,
                                   0,
                                   0.16517893769132216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41375793926457283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42758702765001966,
                                   0,
                                   0,
                                   -0.0088826230599250884,
                                   0,
                                   0,
                                   -0.10015985346947445,
                                   0,
                                   -0.10921872925151094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3801298228524464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35814922134278032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26685740658651652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14559530196685144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45389065032216341,
                                   -0.54748606257325549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32714254752968996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58857630548526174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31797930954356157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091897671328413505,
                                   0,
                                   0.1532720445957719,
                                   -0.23847763939308231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6809243755240878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18164124092066553,
                                   0,
                                   0,
                                   0,
                                   0.42163258191067343,
                                   0,
                                   0,
                                   0,
                                   -0.18909351097229263,
                                   -0.18421659520032602,
                                   0,
                                   0,
                                   -0.25922945962516453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08921479498646212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39237357029614128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31320585105068377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022568945316539787,
                                   0.35397743864329223,
                                   0.15747609476389904,
                                   0,
                                   -0.061403340286577818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4241202998802267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2409765459451616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074358486697437998,
                                   0.26142707063046722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38470351470350328,
                                   0,
                                   0,
                                   0.12189656968170338,
                                   0.28013574368339117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33289083295937272,
                                   0,
                                   0,
                                   0,
                                   0.17571283141101307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27742081966427895,
                                   0,
                                   0.26231968702105279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13552529340399594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86475815092910358,
                                   0,
                                   -0.1139521715528804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50397833860547425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067767604607804302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39698991463068223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028243013285749831,
                                   -0.043813700285133234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39885269345975061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23864139238297125,
                                   0,
                                   0,
                                   0,
                                   1.143201078652466,
                                   0,
                                   0,
                                   0,
                                   -0.21394061534365802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81319777326970599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32703185189185374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99352266482384954,
                                   -1.1399166527675721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27828608465023519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32958837957613851,
                                   0,
                                   0,
                                   0,
                                   -0.083625923561867113,
                                   0,
                                   0,
                                   0,
                                   -0.5578581342045914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7244266026857431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20132285945361991,
                                   -0.04840542352072455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31013239600144649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90834106077194643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64741457032653127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1184516834759505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72815311179198705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41930541289736006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71745948668058179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3957876520151134,
                                   0,
                                   0,
                                   0.4486189431868145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17646891967467751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45631213263963782,
                                   0,
                                   0,
                                   0,
                                   -0.54759753926402754,
                                   0,
                                   0,
                                   0,
                                   -0.19073274478880015,
                                   -0.19066652591500008,
                                   0,
                                   0,
                                   0.0095513162474907265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45931695587370724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23698056945798773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17564879275342432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21465938702520138,
                                   -0.1225972132223635,
                                   0.13954147239921297,
                                   0,
                                   -0.094017482149638565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067353241178140691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16477739096411759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099613569699284352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15000518305978244,
                                   0.43636416296511477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34102329554968941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34128140453589034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024889399265109177,
                                   0,
                                   0,
                                   0,
                                   -0.043844629993764123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14214112437932641,
                                   0,
                                   0,
                                   0,
                                   0.54272588688190804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16393807831399182,
                                   0,
                                   -0.048574701659162112,
                                   0.44481400316085806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51498765456233087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39821708785075738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21360239825571067,
                                   0,
                                   -0.20787570885424456,
                                   0.69811305035744153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0032772916309023459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19077625252582395,
                                   0,
                                   0,
                                   -0.20248483391812991,
                                   0,
                                   -0.085101255210857346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076041109515713218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10836669014395955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021614865945328673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77181880148926918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31005817062803215,
                                   0.11734520415734588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43790303621195981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34711026410685997,
                                   -0.41761532592851253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44242543393967027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36087099111995369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34895761409082171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60863858701505891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46995757292672313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4257797391560656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50952911590289052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074918995058020285,
                                   0,
                                   0,
                                   0.50512402505155918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13131511197078291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2964211979109791,
                                   0,
                                   0,
                                   0,
                                   0.091799483724120695,
                                   0,
                                   0,
                                   0,
                                   0.34621167401692121,
                                   -0.038961046244284404,
                                   0,
                                   0,
                                   -0.012903757347996956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46780329501249229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010356239717766273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22279959643374922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29777365356912627,
                                   0.55130075808305012,
                                   0.12804462879155201,
                                   0,
                                   0.23868843600390049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20392116330615984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077591161257176355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21457492500040995,
                                   -0.34975391169584907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29897185269418514,
                                   0,
                                   0,
                                   0.43265616973125143,
                                   0.054727022335126052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55906442756939367,
                                   0,
                                   0,
                                   0,
                                   -0.078839191502096118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056549403309471905,
                                   0,
                                   0.77428294110263685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75438259316520384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5318513716010248,
                                   0,
                                   -0.3160817760962093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29774332268019366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081927320488144273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61651741335824772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75784096925249311,
                                   -0.80415096235358641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79967065280142702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046867243830784167,
                                   0,
                                   0,
                                   0,
                                   0.40285652507799741,
                                   0,
                                   0,
                                   0,
                                   0.50967657911594733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098059660682029787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06262872176749118,
                                   -0.20172421377043931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82616227983048351,
                                   0,
                                   0,
                                   0.17650162725763466,
                                   0.37375712570941083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92843809025041257,
                                   0,
                                   0,
                                   0,
                                   -0.11866481080798291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30605953183041562,
                                   0,
                                   -0.39801258887643653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26935343044502941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030350786386294584,
                                   0,
                                   -0.17488810623236178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1755304037195603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30351019445445548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28926267335207467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80074527907804161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5635128857538424,
                                   -0.89087500521069418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38047315331058351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21247404922758528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20670483689642127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46815931675192779,
                                   0,
                                   0,
                                   -0.14808580147353623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1615180164527803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25136739161469851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25266715803405471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16379431314226456,
                                   0.24709527646335483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13924553833171446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78437588249560219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2630203099383856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74234716328386585,
                                   0,
                                   0,
                                   -0.6833268926946704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47672584817490937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.4603821235265613,
                                   0,
                                   0,
                                   0,
                                   0.35935936620534309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19616388434604912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0399840596729091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11389428449241122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0046170409465605758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2473606253872748,
                                   0,
                                   0,
                                   0,
                                   0.0026616432332776455,
                                   0,
                                   0,
                                   0,
                                   -0.087069915659977445,
                                   -0.39781202440358493,
                                   0,
                                   0,
                                   0.10359280130407586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0039627055020382829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64753364242020572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2368900225529621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35726924528494775,
                                   0.054440215381783424,
                                   -0.052466297551412543,
                                   0,
                                   0.19312073668677707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26956175786512021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20854079702623354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11597365740241142,
                                   0,
                                   0,
                                   0,
                                   0.13137961664020462,
                                   0,
                                   0,
                                   0,
                                   -0.085772807546035834,
                                   0.33426338191337779,
                                   0,
                                   0,
                                   0.013144637043569191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15821626227482696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20701190529312796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27627785836872593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31202147580228501,
                                   -0.38352115805009307,
                                   0.016940463471153033,
                                   0,
                                   0.26378277937284095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5339697339729137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32615039812830998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30496961730804845,
                                   0,
                                   0,
                                   0,
                                   0.20713050162461205,
                                   0,
                                   0,
                                   0,
                                   0.310386365888419,
                                   0.41009215930235365,
                                   0,
                                   0,
                                   -0.28241359019662771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044773158140536951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27743270675483594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088101092134043005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32060172014489197,
                                   -0.10645387206552738,
                                   -0.24246585694925088,
                                   0,
                                   -0.16260329629557163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016582613900664293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48317702248883143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16627309841270266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052652558752924752,
                                   0.32310049531002311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54719328524358724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29963255065308103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099471922458759479,
                                   0,
                                   0,
                                   0,
                                   -0.31229698694634445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013971353895825728,
                                   0,
                                   0,
                                   0,
                                   -0.19768327385947221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3675992306073918,
                                   0,
                                   -0.16781070331009856,
                                   0.40743012224111763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22600568767732432,
                                   0,
                                   0,
                                   0,
                                   0.049671315899945945,
                                   0,
                                   0,
                                   0,
                                   0.1322117135545044,
                                   -0.1127590292700435,
                                   0,
                                   0,
                                   -0.51378544042530971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19355905660154674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13321020102799982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19367270263404857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2412889519744314,
                                   -0.17793239704689046,
                                   -0.36755598048236027,
                                   0,
                                   0.44788049538677638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23517944613144445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28050131543292706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40827290285868761,
                                   -0.26702051030424367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3478637644469651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05291249903487058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068589126642583778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40963173022620847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2549355282952811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077513322042595367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68935865466072821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59332357049077489,
                                   0,
                                   0,
                                   -0.75160379854474646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26661666507513571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54627986157205155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34122815004932971,
                                   0.1618880498275852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39277573103522251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16524652928149253,
                                   0,
                                   0,
                                   0,
                                   1.1050200176021145,
                                   0,
                                   0,
                                   0,
                                   -0.37169190515703038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57084362616315076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2686088395425173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24596717817181388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58742871553909826,
                                   0,
                                   0,
                                   0,
                                   0.49875955078721218,
                                   0,
                                   0,
                                   0,
                                   -0.26312189563602439,
                                   0,
                                   0,
                                   0,
                                   -0.20084291921958522,
                                   0,
                                   0,
                                   0.36518797425524546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17487877668846033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072851470060091933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78083439062209514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39597766392043787,
                                   -0.044778561848564713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0257083945180152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43221730419459498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96797391022861767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1848216480447806,
                                   0,
                                   0,
                                   -0.59519997890599208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19009496403942558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57843422511816645,
                                   0,
                                   0,
                                   0,
                                   0.10042283563013144,
                                   0,
                                   0,
                                   0,
                                   0.41707921706900608,
                                   0.2000350002965923,
                                   0,
                                   0,
                                   0.35362679010528925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24046695213206584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19132973441761081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083167952194223516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012485190619841199,
                                   0.091412328405627241,
                                   0.34077560341180502,
                                   0,
                                   0.15089501769940847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087734828133203546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24464868130636935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43902442764800531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6599679336676465,
                                   0.77544360176839289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71901935784779414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11477856763615921,
                                   0,
                                   0,
                                   0,
                                   0.25179339923247229,
                                   0,
                                   0,
                                   0,
                                   -0.68518651702466116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034086338943884936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25935593858220574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52693587540692965,
                                   0.46038942652618642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21500104986887492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20240268380227314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23175472028614089,
                                   0,
                                   0,
                                   0,
                                   0.34563650911164318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06618609341307502,
                                   0,
                                   0,
                                   0,
                                   -0.2007996929421188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22500270824866578,
                                   0,
                                   -0.26055213237910746,
                                   -0.13975966356510056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68364631739628734,
                                   0.1068278493327505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37437206088930286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84703732469267123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27999479151230755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47508537509739074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17559966998588303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51520700530038299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52532016388074498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38919695112919894,
                                   0,
                                   0,
                                   0.33912218175860598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62301230837811306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016413289868798937,
                                   -0.79367548133830201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12860227668124463,
                                   0,
                                   0,
                                   0.55660842906356711,
                                   0.37381263173541496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69980370416391546,
                                   0,
                                   0,
                                   0,
                                   0.034636069138943508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75549116235832203,
                                   0,
                                   0.14396622499702627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22006556860611351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0037888627628455684,
                                   0,
                                   -0.2109697606849894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55883393125110625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27563085124159958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2997506923676787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41378047839521143,
                                   0.17719851077364018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82331429030446712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79570945431745221,
                                   0,
                                   0,
                                   0,
                                   0.13422238164904129,
                                   0,
                                   0,
                                   0,
                                   -0.381767554275248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23329107918527045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012218410457522245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44704508817288846,
                                   -0.17457817677739018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36757094848446936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057087598371328846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52179021572521489,
                                   0,
                                   0,
                                   0,
                                   -0.23239624934106051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33607560300023026,
                                   0,
                                   0,
                                   0,
                                   -0.2883573074651351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022331066210841168,
                                   0,
                                   0.1411588944636489,
                                   0.2972577334279255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32258078144826108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55962384256623598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5419929753125412,
                                   0,
                                   -0.45284728158135867,
                                   0.25586769942765109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13589506590551245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014207034318883318,
                                   0,
                                   0,
                                   0.28194350826069503,
                                   0,
                                   0.10818020026468703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02942443344586846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71745693881992578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44798335141245155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18198255861764159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063443711842306294,
                                   0.35727336705924934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16588160864242432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36733557933379019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11325593022772508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4892927010163684,
                                   0,
                                   -0.27531854814182338,
                                   -0.56508138942826935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46659729909930137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25576353669756247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53767028946067474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063553151907187688,
                                   0,
                                   0.55498123257875032,
                                   0.26624022599014785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51241452317433067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50779332108101816,
                                   -0.024156600023790917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13219299771477966,
                                   0,
                                   0,
                                   -0.18167534198833474,
                                   0.26447607197065182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17935526769759175,
                                   0,
                                   0,
                                   0,
                                   -0.15575543895577162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.548719581790448,
                                   0,
                                   0.057297827271970664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86203896647849576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30387373769480863,
                                   0,
                                   -0.55421972525026231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22734144436913994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17444576026678485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033101819024967699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25920638653210687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25906809218288418,
                                   0.85108655413469658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10890756395141908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49386057669577066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028797058138398939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39887438259110131,
                                   0,
                                   0,
                                   -0.15829226774214267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35376317030129789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81772098769330304,
                                   -0.026964652422406071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62913891122687837,
                                   0,
                                   0,
                                   -0.16041719320441045,
                                   0.44787839301463334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29210049419289547,
                                   0,
                                   0,
                                   0,
                                   -0.19833887701995701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45142672440549775,
                                   0,
                                   0.10436440221924072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14030804918744702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041482881526380785,
                                   0,
                                   0.17589444896316841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64686512894034409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18268316140037288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10815470821700016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00035886838438106694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1998139909983068,
                                   0,
                                   0,
                                   0,
                                   -0.15646928140277916,
                                   0,
                                   0,
                                   0,
                                   -0.31817632219180403,
                                   0,
                                   0,
                                   0,
                                   0.6986408632805593,
                                   0,
                                   0,
                                   0.41971497846789885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39799280431107192,
                                   0,
                                   0,
                                   0.33803933322595148,
                                   -0.73342712756377826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17660578332552146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35609355246810526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011760528487251259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19998074529496321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47799570057392071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47138341453108429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093389863583394961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8855868075818254,
                                   0,
                                   0,
                                   0.11793357065565807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41027913298010449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62174974259247229,
                                   0,
                                   0,
                                   0,
                                   0.34189272907978219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23288155692417878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89400303156313132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80060186018737611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071251788246600084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34801386928006905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36711025460482472,
                                   0.10603684016335697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020999736003009167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24938209258990404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20724741625264198,
                                   0,
                                   0,
                                   0,
                                   0.23792330978301657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4960645765354173,
                                   0,
                                   0,
                                   0,
                                   -0.23430376591053556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046026831896617042,
                                   0,
                                   0.50703047995817707,
                                   0.10249141773084677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48994214944400116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087186597523787018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20190381174821595,
                                   0,
                                   0,
                                   0,
                                   0.096695069634951419,
                                   0,
                                   0,
                                   0,
                                   -0.4810710398052358,
                                   0,
                                   0,
                                   0,
                                   -0.02501518253420458,
                                   0,
                                   0,
                                   -0.6656261799716281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16470211158365786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.003764665314682128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7007008467267497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4853196024987077,
                                   -0.31965836044908003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70171266488431228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35058114128614604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.641221925982426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.006389359956018607,
                                   0,
                                   0,
                                   -0.030674905669844529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27891383000549397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18762947887692791,
                                   0.014486251002621041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25308996634420799,
                                   0,
                                   0,
                                   0.4843471995139319,
                                   0.26320796296950572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05871466256596921,
                                   0,
                                   0,
                                   0,
                                   -0.34441568320745941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39601186587970399,
                                   0,
                                   -0.090613392054401082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28737229992048202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52526872136402436,
                                   0,
                                   -0.27892553846699736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079655687961143584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90044988279675986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14910518487537955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00035013715866456319,
                                   -0.32046217950830591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20109190608982025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10320424385500544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17209174130637553,
                                   0,
                                   0,
                                   0,
                                   0.22999734329073332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47958306007157914,
                                   0,
                                   0,
                                   0,
                                   -0.15772139830515358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51055662820288206,
                                   0,
                                   0.33157442835517109,
                                   0.34056199674795473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81751448189507092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21932472101986061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054500137580306959,
                                   0,
                                   0,
                                   0,
                                   0.15432785510378705,
                                   0,
                                   0,
                                   0,
                                   -0.42427828877431606,
                                   0,
                                   0,
                                   0,
                                   0.019977136010340114,
                                   0,
                                   0,
                                   -0.21978485599659831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16751970502094218,
                                   0,
                                   -0.017621036141416919,
                                   0,
                                   0,
                                   0.087831909266738173,
                                   0,
                                   0.26106702419217231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30610351029394933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40113883595391697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0353767156973879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33441554209844243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10711802714792557,
                                   0.057335239941738954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73577202356762395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5274825198829981,
                                   0,
                                   0,
                                   -0.53345945032448472,
                                   0,
                                   -0.1518327915716407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38349938475897727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23632092962888385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13359200459567641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02994823028006334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.328214397196123,
                                   -0.23433400513229194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17271309421354614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3514098561886162,
                                   0.30746270218003846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65844902562862062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044723186456992969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061648822867196265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63161809409001135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10938043378031766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62542926248379282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41866670808447426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39921213331306027,
                                   0,
                                   0,
                                   0.0063978430906809118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61936057786502952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081180986963076643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77172428335591714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085077158089628888,
                                   0,
                                   0,
                                   0,
                                   0.60281997692273404,
                                   0,
                                   0,
                                   0,
                                   0.035146375991603133,
                                   0,
                                   0,
                                   0,
                                   0.12325755963390156,
                                   0,
                                   0,
                                   -0.055811556061554579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087627660510277941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28975312450671253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35386045071014877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63931689934683555,
                                   0,
                                   -0.58687327261735145,
                                   0.0098727000493332023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1938610382529003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75193078078250664,
                                   -0.007315302441745275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19496297198763601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33757104787085235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29948343404457589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010131085532155165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2239538418687293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045197195353249141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0025423346160642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41258438837354861,
                                   0,
                                   0,
                                   -0.46964231124705719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077013260285711732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014563530910469552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17927154959375452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68367552242804186,
                                   0,
                                   0,
                                   0,
                                   0.2100363473848556,
                                   0,
                                   0,
                                   0,
                                   0.055473680193657463,
                                   0,
                                   0,
                                   0,
                                   -0.4966015964802073,
                                   0,
                                   0,
                                   0.31114705826338951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33108784513594841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47356674012370548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4280287499710923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41972367601644012,
                                   0.039046004211392038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35567092105637255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0083629312029683545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64434885049185964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39534824925974044,
                                   0,
                                   0,
                                   -0.76548734027948151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065826697426021652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071555816738329378,
                                   0,
                                   0,
                                   0,
                                   -0.2055112765341035,
                                   0,
                                   0,
                                   0,
                                   0.43504858509339767,
                                   0.078846793880043897,
                                   0,
                                   0,
                                   -0.07225914203770345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34992184921936076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089476928764668923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29464119502330471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22849726760033903,
                                   -0.020835251321847242,
                                   0.0029931708932753598,
                                   0,
                                   -0.52743447660111376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33477259357573413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30292023482905195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25120515800919585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42543630705382879,
                                   0.33447809685875673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52963753792924595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17538266806225641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050359701836295394,
                                   0,
                                   0,
                                   0,
                                   -0.33538968806842351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20569492351325597,
                                   0,
                                   0,
                                   0,
                                   -0.31600619483602838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012324226179103746,
                                   0,
                                   0.017569798242780252,
                                   -0.27403663000517509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0237198125599751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13600509285166451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10709187346386846,
                                   0.73154968120496733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19862958464054017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34865018744076803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13121212694326181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37073554193840225,
                                   0,
                                   0,
                                   0.49971630464926164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55317221049448495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085340855757603085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23615207235972446,
                                   0.23266068331260115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20600420288526602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19634100644782626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21007634931065822,
                                   0,
                                   0,
                                   0,
                                   -0.24070480589273982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061496863998351095,
                                   0,
                                   0,
                                   0,
                                   0.19080235418346875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34267850430374991,
                                   0,
                                   0.56361195481526538,
                                   -0.47379884908491676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64099728434672931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016935146244101071,
                                   -0.2680434767063159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11447020838177052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37444810188286359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13020641664661259,
                                   0,
                                   0,
                                   0,
                                   -0.46653374442526585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25454303903912079,
                                   0,
                                   0,
                                   0,
                                   0.23174296217735602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064654185822521942,
                                   0,
                                   -0.068101881781896051,
                                   0.041846533361631855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38590957503976447,
                                   0,
                                   0,
                                   -0.43341427750832967,
                                   0,
                                   0.46753687479288503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37771805653433432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.001857261306558583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28852931873658105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22747886160372977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37906295730874351,
                                   -0.15155457953433166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017533926349391396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19110971027308771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38968215322691296,
                                   0.45422678744302325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091148894101235944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71298098123539866,
                                   0,
                                   0,
                                   0,
                                   -0.84356381459842433,
                                   0,
                                   0,
                                   0,
                                   -0.52181560037041352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2458745244395166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17513978218782061,
                                   -0.17987314186404069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33621813490078856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46396681069879286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.581060059719547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18769376104465055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055476237453510463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66007528743780286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013089330877020227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60160612911302014,
                                   0,
                                   0,
                                   0.55718368693928111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06507663841130204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35798229807630599,
                                   0.089610369803981391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3073189405171271,
                                   0,
                                   0,
                                   -0.25247133965258967,
                                   -0.70778452017887905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26587510342102044,
                                   0,
                                   0,
                                   0,
                                   -0.18033217868970655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33214811289676749,
                                   0,
                                   -0.24521281806367307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42026305700157773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80046194642110557,
                                   0,
                                   0.051198613629933012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3655976844494212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27651178441916296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0017014040687718668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39773013065082458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036986369911160902,
                                   0,
                                   0,
                                   0,
                                   0.32801220199502235,
                                   0,
                                   0,
                                   0,
                                   0.63348509022955857,
                                   0,
                                   0,
                                   0,
                                   0.35023417144361296,
                                   0,
                                   0,
                                   -0.29480832512206484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34923998801485823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69688908628535717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26145274130545382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25033277539939147,
                                   -0.19646334665089954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41935905728952494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71685104305554326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13140106783042513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89515742243319629,
                                   0,
                                   0,
                                   -0.054872607154171908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35120831456424023,
                                   -0.47829304815999207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8264344809368066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52767968101693796,
                                   0,
                                   0,
                                   0,
                                   0.42682820681210898,
                                   0.18933678759888373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49745890986294383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0008404288555557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068584631879084881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051781757803284686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034033676850670887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37919655919159684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11435909021841914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059210485883166214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38260582309720853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061328179587153038,
                                   0,
                                   0,
                                   -0.21751049938735414,
                                   -0.029236728045540034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054862254834139368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10641883075147793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66658827781457808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15185237722335096,
                                   0,
                                   0,
                                   0,
                                   -0.21915053318224864,
                                   0,
                                   -0.28798854946974434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15418663212361486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16877565390267826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36499745539350198,
                                   0,
                                   0,
                                   0.74027850829790065,
                                   0.29500099079070097,
                                   0,
                                   0,
                                   0,
                                   -0.16074099628890365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63037381434100825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097087994860462726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21483015826333629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054496132234784202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68714644228791855,
                                   -0.22096118585251176,
                                   0.43432147585533826,
                                   0,
                                   0,
                                   0,
                                   -0.24713207883569147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67236155463979741,
                                   0,
                                   0,
                                   0.062974568641415485,
                                   -0.26215834672400085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28802123215466741,
                                   0.35309842463122026,
                                   0,
                                   0,
                                   0,
                                   -0.20160867697881779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32492227549002944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17365005952601861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12155957062995315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011325642864870348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20003308598658975,
                                   -0.55364194848714088,
                                   0.33273929104116456,
                                   0,
                                   0,
                                   0,
                                   -0.2128227986645497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65881814705709163,
                                   0,
                                   0,
                                   0.75815402244364338,
                                   -0.79882564637688347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31322216746738785,
                                   0,
                                   0,
                                   0,
                                   -0.58148501381183992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00023971699361611653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54634412430395884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21578212768465499,
                                   0,
                                   0,
                                   -0.24619936613279034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13118040146359691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26034475877314245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040403982127685346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20690296908748854,
                                   0,
                                   0,
                                   0,
                                   0.056161599186067897,
                                   0,
                                   0,
                                   0.15973697637162612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082738261146537803,
                                   0,
                                   0,
                                   0,
                                   -0.19356262148598391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49203900082687102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65949177885246435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46321074645186933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090178226927717708,
                                   0.21100945154501069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10693367157063256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32231200090513806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32883252234021193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0052715051165202059,
                                   0,
                                   0,
                                   0.37179180572469889,
                                   -0.090033850463184587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084481724791099264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56049829895515435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36709012311385625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31913173656538124,
                                   0,
                                   0,
                                   0,
                                   0.065969790420323152,
                                   0,
                                   0.17310966706694483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12225775997225974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10200211940220527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15509682615082115,
                                   0,
                                   0,
                                   0.33254633745161466,
                                   0.31118901353597989,
                                   0,
                                   0,
                                   0,
                                   -0.48585201521796895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49108523858973485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84770065062132816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52540145080901968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51242952023364263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18277878204149306,
                                   0.329563034788591,
                                   -0.11845445940555997,
                                   0,
                                   0,
                                   0,
                                   -0.7363045185817082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17715142441369616,
                                   0,
                                   0,
                                   0.23021045436791213,
                                   0.10742990184847195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049481346570288007,
                                   0,
                                   0,
                                   0,
                                   0.086157662089714079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34878158527685976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14427169267511045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077841789527372598,
                                   0,
                                   0,
                                   0.40640251769911667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0069189435848325022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64115656024658108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24673255500925487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022842699435488209,
                                   0,
                                   0,
                                   0,
                                   0.14080660823135041,
                                   0,
                                   0,
                                   0.42905516826181045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047600051747824695,
                                   0,
                                   0,
                                   0,
                                   0.055345094593121424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10330416035363692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15730210751814122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3520772568376942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67887877504435867,
                                   -0.42365348184718793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44151828312396552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.439428803695815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14202857930601459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11763301956170073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43178725920984606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40599960311968658,
                                   0,
                                   -0.6201572596667122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065463353438871719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00078254086562676295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092477115747567257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15551096499700212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73797769230290033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1697442512227843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24536712923382958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016492070828727029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16458042776811813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58224743977719184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25683857081537337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041097563856913821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18602414939676565,
                                   0,
                                   0,
                                   0.28723251229798868,
                                   0.34094707011929881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32277451494353965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023983636571079381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11257346596834553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30964725544994121,
                                   0,
                                   0,
                                   0,
                                   0.31364330415096342,
                                   0,
                                   -0.058710963378625566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16672174337023404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045829852949711924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59494882882681044,
                                   -0.34375860672460173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16858715017402642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96085724805642447,
                                   0,
                                   0,
                                   0,
                                   0.059918882769369866,
                                   -0.014981708547235219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2453897208587438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64691876154251304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071433954243316736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24289694265633616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0023801714367877001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51007714597402121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80046495270082818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83360132717817026,
                                   0,
                                   0,
                                   0.46337291478879883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060797763581746454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047273414566015193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16232738795279025,
                                   0,
                                   0.69523927642728378,
                                   0,
                                   0.0666352238434373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49721424563886019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0039335882078477512,
                                   -0.16018560077664359,
                                   0,
                                   0,
                                   0.42352736949674524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20219224514979989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37565681389988115,
                                   0,
                                   0,
                                   -0.38050204109676228,
                                   -0.0890151932520276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029507848351691277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047725150948527181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24836910975086574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22894028406732017,
                                   0,
                                   0,
                                   0,
                                   0.33378519422091874,
                                   0,
                                   -0.47844829464315602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10524361623360357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045675706719344414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12321617826243782,
                                   0,
                                   -0.027187296891977096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17726444128011287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34577850759664325,
                                   0,
                                   0,
                                   -0.10663556068080016,
                                   0.12687227715972274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37560700530664182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0013722991134933193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19100746866550786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062226646453470598,
                                   0,
                                   0,
                                   0,
                                   -0.040450910110493808,
                                   0,
                                   0.11202774600587165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72506258542168478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30786227291655005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068467048960939303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87237741186218465,
                                   0,
                                   0,
                                   0.83549884837806143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29840659522495216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077993163498933649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41015625851957715,
                                   0,
                                   -0.39837187447725897,
                                   0,
                                   0.30055682399496914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70135091891587209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19864360619698734,
                                   -0.3035442006821828,
                                   0,
                                   -0.3732247015547594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40737150534981581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061160931328943721,
                                   0,
                                   0,
                                   0,
                                   0.085628159606879306,
                                   -0.86284299549595267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38829529031595317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.391702635573972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11501173479234994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14718865854881441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18433115027791369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10127430119439543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42011884981900383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50099075875297772,
                                   0,
                                   0,
                                   0,
                                   -0.05578312954929418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43442176266518207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38243061213819923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15428849978128448,
                                   0,
                                   0,
                                   -0.0071243576407532911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24737985325286307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21176082296909365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1931346133362597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30032909584936773,
                                   0,
                                   0,
                                   0,
                                   0.37388808690073405,
                                   0,
                                   0,
                                   -0.1171967548152964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59578360746739234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10549034167084184,
                                   0.71052346342188921,
                                   0,
                                   0.021765933396304324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25367628259406261,
                                   0,
                                   0,
                                   1.3387410217586877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059626751151977214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24837646317509748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46570581834046781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52473050385419351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28593834697329706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58528013373272825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076919381819360366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27847050934931117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71176409404774332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.271060061320262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44812769293266735,
                                   0,
                                   0,
                                   0,
                                   -0.53497893913666206,
                                   0.38479955853909487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2935626127215637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.195484683213939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07196863443862947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36598072084007899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0343957425005628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061086768598587617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42068352695485994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56194833132540611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61867242800322375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35949559855858781,
                                   0,
                                   0,
                                   0,
                                   -0.1423811233778251,
                                   -0.024802601200699201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060235893793966822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68249203814302095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39602670410985663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50487680230797138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13822080630971742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41424012246058062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33743499977626323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13179540770880754,
                                   0,
                                   0,
                                   0,
                                   -0.383914606643599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41628285099012008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13134822157696033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38249694323368783,
                                   0,
                                   0,
                                   0.13561088916883582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11837958213214099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28920276489341495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27274782920304941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48844459180818689,
                                   0,
                                   0,
                                   0,
                                   0.022024688045548024,
                                   0,
                                   0,
                                   0.26247857808870545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35268984241743018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55493068587236194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1523026949016173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55924725221758875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13791110557017941,
                                   0,
                                   -0.30934990742290602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068583460512205402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19874854956164531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17443763732665546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20581108900794876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15763164448319827,
                                   0,
                                   0,
                                   0.15030329135390058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070103559332688747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17854875911478671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39050983512007142,
                                   0,
                                   -0.22548916588202292,
                                   0,
                                   1.030865933951026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067677904179372861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55078708026352818,
                                   0.50106448945028936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29041085598366145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.009258628672604019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16728585767244469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49975130495021708,
                                   0,
                                   0,
                                   0,
                                   -0.41531140975659003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0688768886461366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1111256366428939,
                                   -0.31047304717299812,
                                   0,
                                   0,
                                   0,
                                   -0.03901766913744667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31556047981767288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81693268446733447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31048151858159723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032190770480607145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58196309178935313,
                                   -0.030526327820601547,
                                   -0.82562964256114479,
                                   0,
                                   0,
                                   0,
                                   -0.3026902714427156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37769061113810332,
                                   0,
                                   0,
                                   -0.20517101687363656,
                                   -0.46125528341001576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22778601807953319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23894300897645693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27014211647381459,
                                   0,
                                   0,
                                   0,
                                   0.06132863867792071,
                                   -0.20347327569759036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73417783516236523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1939800533307508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4921118775337221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45235186340902184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34625415204967858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64961953239521497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10450082232479842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16519142516461935,
                                   0,
                                   0,
                                   0,
                                   -0.01038072881859109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046691061142887236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12745646735236082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14011751388864632,
                                   0,
                                   0,
                                   0.13332302446503635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32673225506022363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18159197048688414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46424441765619578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45170030462521965,
                                   0,
                                   0,
                                   0,
                                   0.54612819027036696,
                                   0,
                                   0,
                                   -0.24337055231961571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47850168131227661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40023188973110441,
                                   0.96813669610024145,
                                   0,
                                   -0.37578613859269933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13947232347997224,
                                   0,
                                   0,
                                   -0.51163048144951817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73873595154480975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031914257391226164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93317032152582824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60661171023707483,
                                   0.098103819800722109,
                                   0,
                                   0.72094582265795648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024288673003637962,
                                   0,
                                   0,
                                   -0.5633295659864811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.106369657261071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37940239224318628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27230432468480603,
                                   0,
                                   0,
                                   0,
                                   0.21415901874689333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31961472098981003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23341716619399475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21489315211249418,
                                   0,
                                   0,
                                   -0.28891208798659623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3707323364723939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051033557030859662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32869281814199963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14048352568337374,
                                   0,
                                   0,
                                   0,
                                   0.2594955467198346,
                                   0,
                                   0,
                                   0.50846872763895967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7941725064175833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8012265828086268,
                                   -0.04179908061092176,
                                   0,
                                   -0.48497202169156783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10241139134839927,
                                   0,
                                   0,
                                   -0.37989233938480971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42998786726453669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3986070090246725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058309524844904995,
                                   -0.72644909192359042,
                                   0,
                                   0,
                                   0,
                                   0.11697623177483021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14886543560126009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51255858672799881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043085496213332741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17585354341276202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54614474503873167,
                                   0.0038203692288179374,
                                   0.62233790123303756,
                                   0,
                                   0,
                                   0,
                                   -1.0071156823574892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074602167794792534,
                                   0,
                                   0,
                                   0.10417137317275332,
                                   0.23079582904868079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13999519947636435,
                                   0,
                                   0,
                                   0,
                                   0.3565063639544247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087211353887812454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4253716888446275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6315848800435282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0045942145968562928,
                                   0.32596675685739507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3994781202802028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29495622356418677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34879423171074081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22115002611521306,
                                   0,
                                   0,
                                   -0.094293473330934616,
                                   -0.02376600932876767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40477102692815148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39931642877721907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40073648618494051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34854266386299598,
                                   0,
                                   0,
                                   0,
                                   0.17416371332878522,
                                   0,
                                   0.025845403623379171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12304265314160291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14679679411510693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24479645041366477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12034992310344494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18340516601027357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30415222775344369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46330694380583337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1213354114379237,
                                   0,
                                   0.28558985914601959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27726442686463049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52929477025161276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12957079188236215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41787029473091297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24282755010371029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047788302566573196,
                                   -0.036306301181121478,
                                   0,
                                   0.67817266139181731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.301012512779749,
                                   0,
                                   0,
                                   0.4268122708928962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0036382330256549689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1271481906761196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27719007317097455,
                                   0,
                                   0,
                                   0,
                                   -0.45824299586294975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046358612526111523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34897253073148848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32333464890186053,
                                   0,
                                   0,
                                   0.11989421959062471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42659244561133991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14533868809292005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2272892371222196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4549683120520715,
                                   0,
                                   0,
                                   0,
                                   0.091641632180096078,
                                   0,
                                   0,
                                   0.012998188520686002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52965439452495744,
                                   0,
                                   0,
                                   1.2778127076002102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41670685406528152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099093231081574362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11908778922917164,
                                   0,
                                   -0.36180258532568743,
                                   0,
                                   -0.24246735425232602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0260082556673675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088527283358195347,
                                   -0.27630120403508568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027659502662907662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49515164836951397,
                                   -0.86785620872885305,
                                   0,
                                   0.081982400982234541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56435747533681568,
                                   0,
                                   0,
                                   0.40437527357025782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88899540285357448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016928776733685147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38446153937653066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11720368412481139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32448273262158434,
                                   0,
                                   0,
                                   0,
                                   0.52672477386722805,
                                   0.36337119746707847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038152054849588793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15332588745920406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62596987455984809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83949199893173798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11997870014113073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43724882284831551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14886891700922356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32943824181951165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21004405014991587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17802308236920217,
                                   0,
                                   0,
                                   -0.12834962835117694,
                                   0.55166350295077737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34901616595060364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087789052902201709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10650660795877354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25830879538805968,
                                   0,
                                   0,
                                   0,
                                   -0.35811622884338851,
                                   0,
                                   0.16116401417870452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13031282042619585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30388201478754123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15401428588749491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10927825386337271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49767836223887629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0812338563774022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37023833083110336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038429512544601738,
                                   0,
                                   -0.011568479674231644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35703240004158532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46049837377863506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50551420604615305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0036046289924387444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10985211304211387,
                                   0,
                                   0,
                                   -0.33528608553842021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36513027105761331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78596515286690127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19610042602517494,
                                   0,
                                   -0.57387295733023036,
                                   0,
                                   0.071627528348388619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015148576034481553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43393269846494514,
                                   -1.0573024495367467,
                                   0,
                                   0,
                                   0,
                                   0.021485680011624819,
                                   -0.42912508734359989,
                                   0,
                                   0,
                                   0,
                                   0.29306022137654342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31487052968119522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27685696247396141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19760676298564753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88631715055326121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2043084716745629,
                                   -0.47233943412590113,
                                   -0.37565176297595898,
                                   0,
                                   0,
                                   0,
                                   -0.049910225251832668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038081592750633879,
                                   0,
                                   0,
                                   0.74011817511438649,
                                   1.0068444212495311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52991688555444427,
                                   0,
                                   0,
                                   0.05232813616992478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2902707494831781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13207275436093885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40635728458650056,
                                   0,
                                   0.61981981899390337,
                                   0,
                                   0.66842885004242736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65255055042632903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52177740949452434,
                                   0.12501313654952506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29413211437338427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36379261411932434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32126433367073759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23322753828573836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59561426914096383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51843902138864617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15068857790458751,
                                   0,
                                   0,
                                   0.13982980526509142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33481300243692325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71473714204744321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98420049346811789,
                                   0,
                                   -0.30726565463104299,
                                   0,
                                   0.20157694070030011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38492011146453109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68035329905883735,
                                   -0.39686773907626638,
                                   0,
                                   -0.29666819574933462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23223838757444501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16310217412057676,
                                   0,
                                   0,
                                   0,
                                   0.070142846420646804,
                                   0.17268156495502193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076514987692851047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29453829922407493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61240998740714392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41096057942705738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73240372118667374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0086612337721489185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54443086851633038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2997473927395421,
                                   0,
                                   0,
                                   0,
                                   -0.53639949921923058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088737749359909815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38078862039284261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13971757213844327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19877663218717978,
                                   0.36347340413200924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52764254114107434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2363074938442771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31007730798279604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54722783003549891,
                                   0,
                                   0,
                                   -0.40636483194605594,
                                   -0.093745049137545972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091287954301122465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29059649288939654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021360912155157449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12210331856861234,
                                   0,
                                   0,
                                   0,
                                   -0.073885069392811087,
                                   0,
                                   -0.25024679049507997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22023019935075372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25868242016226317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28807343940123253,
                                   0,
                                   0,
                                   0.35700998549393881,
                                   -0.34670691313522845,
                                   0,
                                   0,
                                   0,
                                   0.24324280368847431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07677512035340367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13341186982102321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18887562456152035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48406657517804025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5483611011730376,
                                   -0.14507224224766738,
                                   0.66892355622696364,
                                   0,
                                   0,
                                   0,
                                   0.044306823376700964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80748844687173116,
                                   0,
                                   0,
                                   -0.61882328027292577,
                                   -0.25575208890881607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040074073455007755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014962300538532133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32432020120763655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16398175202260126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53093653549745756,
                                   0,
                                   -0.4614213153245123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0096024544188652583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24994431204573345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021667901134982126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55521121308492183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15452354311131405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38515223708550866,
                                   0.14889535094278594,
                                   0,
                                   1.1448629922335078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.048692329999773,
                                   0,
                                   0,
                                   -0.20700855515310815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46827734042938418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22363553431447275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26972110796937854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2484683605950842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52904102404365838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12996796926130572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2910803106230081,
                                   0,
                                   -0.2135897454297366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48714917634015836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079971931646842104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4193535360551261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13719466059799096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16827893479162809,
                                   0,
                                   0,
                                   0,
                                   0.079436403636209282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15511979797065525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090053450862050632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58338493140801351,
                                   0,
                                   0,
                                   -0.052594924530326992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14274050769260796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47219078972259237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1734825174792877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024688155154366301,
                                   0,
                                   0,
                                   0,
                                   0.054694898966476529,
                                   0,
                                   0,
                                   -0.55951752661003984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63321189171373449,
                                   -0.089776432425819105,
                                   0,
                                   0,
                                   0,
                                   0.20710482247186068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73494651337302463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080813529622094898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25941303720070413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28736233648291121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32087531632974803,
                                   0.77103101403751784,
                                   -0.32602627403972501,
                                   0,
                                   0,
                                   0,
                                   0.15792265141420134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28082909995188243,
                                   0,
                                   0,
                                   0.042984959838899647,
                                   -0.2616988686718541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21293038785669449,
                                   0.18977237820501058,
                                   0,
                                   0,
                                   0,
                                   -0.23038794326356113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46659908921321663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48670229508750706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1713914939726646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38867699830144786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1378055886873947,
                                   -0.0080737184062041195,
                                   0.0078324912117365558,
                                   0,
                                   0,
                                   0,
                                   -0.27807511215155162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10858307010918272,
                                   0,
                                   0,
                                   -0.25579327792951134,
                                   -0.14803239724399239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50605914450841083,
                                   -0.012074531840909786,
                                   0,
                                   0,
                                   0,
                                   0.32120396160451592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15192088597883049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29920376866011766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36665589205888782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26254844360275248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40884932887332714,
                                   -0.71411882758306289,
                                   -0.47381960061550088,
                                   0,
                                   0,
                                   0,
                                   -0.45260665944025114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46514159102056418,
                                   0,
                                   0,
                                   -0.51709465394170218,
                                   -0.40267195642030335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78489933379901244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.4313346975669545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49729272165500399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1559568317977893,
                                   0,
                                   0,
                                   0,
                                   0.56941958677351501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22542878605311406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16276676394909614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24207535428586674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30537344887677198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076802254254384167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51774321055408346,
                                   0,
                                   0.10703814389473627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068517783034007143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44952340212854314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22278028228836505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52900165189778259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27415458783580948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46892509949965411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08507331547499454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77285423816579146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29598011126709467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11315098013451301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47365185934544041,
                                   0.63592044654812874,
                                   0,
                                   0,
                                   0,
                                   0.084110629248727115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44371098833898698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72529895005163481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16782915220844136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078499265663993192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18580506164877422,
                                   -0.47072416027913894,
                                   0.36273275584119435,
                                   0,
                                   0,
                                   0,
                                   0.1100229954697549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022190110645280349,
                                   0,
                                   0,
                                   -0.41190964847866801,
                                   0.33828935264613386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37367616218489697,
                                   0,
                                   0,
                                   0.086367573581876522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94829317309305405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6378846353097174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48083381456539098,
                                   0,
                                   -0.31528170356546331,
                                   0,
                                   0.37616285639172192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46006208066329313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4685226892857241,
                                   0.29550944404351942,
                                   0,
                                   0,
                                   -0.53963643569148068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32653907246679614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16572292010970008,
                                   0,
                                   0,
                                   -0.12233215772193623,
                                   0.39955275653507594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070425635665068612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058816360409480524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27088865190271272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3749706485237666,
                                   0,
                                   0,
                                   0,
                                   0.25513043638704108,
                                   0,
                                   -0.038208123165370672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018772127234349643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086859781689364965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32131278379767725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73884860810146424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11300025077415737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.4532608188839569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24591928691732867,
                                   0,
                                   0,
                                   0,
                                   0.082795181568181275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06626107481486776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13038416476308412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25483423001032401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29295910630829214,
                                   0,
                                   0,
                                   0,
                                   0.69738155436837457,
                                   0.3275176745792312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37033322507038191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085334170606266635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077059917531210484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41989640260848266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0022758272357084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25329369157446857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23355534284401278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42297171788856036,
                                   0,
                                   0,
                                   0,
                                   -0.52181613822043027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045626742023822359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25768925933734549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26098908390965936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2859960841809906,
                                   -0.48185658020494959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31340463273523267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27725395205293124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21037503481267686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40133418537529858,
                                   0,
                                   0,
                                   0.067497259991673608,
                                   -0.42346910961310197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19438889454071884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15198722757363856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12522866806059454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47822731886792991,
                                   0,
                                   0,
                                   0,
                                   -0.15828716091839254,
                                   0,
                                   -0.17790955220232046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31231977941478195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21462677754329762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16833245597319968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51230712173983273,
                                   0,
                                   0,
                                   0,
                                   -0.093594415047032045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12292615220128632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24590925739718753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052819126050873015,
                                   0,
                                   0,
                                   0.10406993529638746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31591223101197607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059954368947692079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18064011166902505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21734342535668735,
                                   0,
                                   0,
                                   0,
                                   -0.67540405618570643,
                                   0,
                                   0,
                                   -0.012006979140052654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089426378111601229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27733049011875821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048796277482904493,
                                   0,
                                   0,
                                   -0.022531196631251291,
                                   0.37107358639258597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45331379811073402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27957419472556655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10325808175002901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0048003663850880868,
                                   0,
                                   0,
                                   0,
                                   -0.26950895321857643,
                                   0,
                                   -0.30192487902304355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35939161725621077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25547162646392119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34920507486846081,
                                   0.099088542710588048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16902524268236105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51194020029990106,
                                   0,
                                   0,
                                   0,
                                   0.62202574862871751,
                                   0.18022218861917116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.332441243919257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35121888193547807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073303357225331794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46470619218218423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45903994884105215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56345023754812518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22906876587782751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21161030514897411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33090891596195227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097103218607014027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11409745245719223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076320528535082199,
                                   0,
                                   0.088617989753222659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68830361930587602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43570243066677244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28029383425439824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25967675912041122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62055995949887877,
                                   0,
                                   0,
                                   0,
                                   -0.21815934723023916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58508752004962639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11368199222374632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24856064664220923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13281174771526733,
                                   -0.21411815616814267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29460633770817157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35227163994191157,
                                   0,
                                   0,
                                   0,
                                   0.35611754579400851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60023894458379246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33827390818089598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21900617894849411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32699345032554034,
                                   0.012088964527722224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34544810273393156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68233950567857549,
                                   -0.52574715003805661,
                                   0,
                                   0,
                                   0,
                                   -0.41220140499338553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06051790730378652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094192336195723828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32283542327926729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18851570260283834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61449864223962436,
                                   -0.6813803780102986,
                                   -0.065035554907864113,
                                   0,
                                   0,
                                   0,
                                   0.47723416403529012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56707541918347948,
                                   0,
                                   0,
                                   0.071568878764044969,
                                   -0.32189974721104664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1048364821823895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40193300573201207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23580044713061421,
                                   0,
                                   0,
                                   0.0014204304665062714,
                                   -0.036080999473882353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3217913922665116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059519533965892844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17710089074556057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19154948278039036,
                                   0,
                                   0,
                                   0,
                                   -0.61387974377342425,
                                   0,
                                   -0.036721571595703446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10533492802245449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44733228620441201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077503703132977803,
                                   -0.41388311351924956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15863811330939481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080345180892588491,
                                   0,
                                   0,
                                   0,
                                   0.30826912819196772,
                                   -0.53069562878623966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9706976196304451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24165794631911169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29127559351962229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10675180572627184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38598898630334766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3049794311421401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077063654314531341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65702367228899727,
                                   0.1358481259773156,
                                   0,
                                   0,
                                   0,
                                   0.90330183686012633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37928410362919163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046224540563001959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50978375951926225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71164014281963095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17858304960995547,
                                   -0.041116876683680997,
                                   -0.1569777459032079,
                                   0,
                                   0,
                                   0,
                                   -0.093020157442769036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060930845936757877,
                                   0,
                                   0,
                                   0.35761285985012042,
                                   0.16343096430697154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23287275397117596,
                                   0.054996549140706077,
                                   0,
                                   0,
                                   0,
                                   0.58942692485363835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58063726373264613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32063355758916456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064664112313080391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8328981077309352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089246612112819687,
                                   0.35186887525940608,
                                   0.05789481639714452,
                                   0,
                                   0,
                                   0,
                                   0.29072554253117205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71871028127264069,
                                   0,
                                   0,
                                   0.24650352879792883,
                                   -0.6204634094141831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23232207411647329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5853697207909756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23973143930854593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052516179572999665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7195794065068295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15920147449286853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43971173979239753,
                                   0,
                                   0,
                                   0,
                                   -0.31295995343134753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16446783092727152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14362801542659268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25533418401865265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53394831474325222,
                                   0.50935940635172594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22646771519816064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87855967467271789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58729800383018971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61600030504533532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57092644984606078,
                                   0,
                                   0,
                                   0,
                                   0.67695541995796948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51582873969839826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048340783912009064,
                                   0,
                                   0,
                                   0,
                                   0.47336358112334886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4858593641501503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41264270907348566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056799563003549318,
                                   0,
                                   0,
                                   -0.066720857366385444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3966289233233643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28132363963540241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053952315550194904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30888881691349923,
                                   0,
                                   0,
                                   0,
                                   -0.055894345090485152,
                                   0,
                                   0,
                                   0.14722117379288091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38159093119840864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096505593137461432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58928638759051821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26365902910387856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39929517569530226,
                                   0,
                                   0.31693632808613958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26183145643910444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040751088017424039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28084168253042829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13902091460070934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059259842714229738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074570982691761378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094208155541903288,
                                   0,
                                   0,
                                   -0.1817479179926649,
                                   0.2159341426879178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12512325069364486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53767334165057867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080460289694908774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33731965082630894,
                                   0,
                                   0,
                                   0,
                                   0.17205436517334111,
                                   0,
                                   -0.084658494985861685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22718653789296303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59508947265055157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18673665760433356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16415489446098538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88575824697485683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11281548577707695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10850509630371952,
                                   0,
                                   0,
                                   0,
                                   -1.1237806153657359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81538622468930544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38089478019782486,
                                   0,
                                   0,
                                   0,
                                   0.089952313334343073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25545225878259259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22001699450637363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49927903959535691,
                                   0,
                                   0,
                                   0.17846460009495635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41484938917427783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15362713172659348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41180508915915215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19076175566298725,
                                   0,
                                   0,
                                   0,
                                   0.0026642206205187459,
                                   0,
                                   0,
                                   0.22439552632674967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80986168256469682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20418458083026278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37037886576827866,
                                   0,
                                   0,
                                   0,
                                   0.077564638222218027,
                                   0.067153893024761158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17729730927002152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12914607588564433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53654134866158509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5237381073226639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05616613163433315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0033993881606675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82880704022558938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15119203539922313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030842542928609096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83073150267337859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052138943938140489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082713876450471513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5258467662837899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12089441506528439,
                                   0,
                                   0,
                                   0,
                                   -0.027510175957201233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26337568892280216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19343015861371898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10620267753757529,
                                   0,
                                   0,
                                   -0.76828632998931323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17822978993540223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081557528441396229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46406319005420205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13220710282699713,
                                   0,
                                   0,
                                   0,
                                   -0.021363771945534942,
                                   0,
                                   0,
                                   0.067790822863575087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051662063972560783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85079111837377841,
                                   -0.094624900074666521,
                                   0,
                                   -0.49372797047595396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0344147711914471,
                                   0,
                                   0,
                                   0.14371973398993618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4241402187895022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62830207092756418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028351833950615687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11093495726703972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064825316866523292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3116180354192137,
                                   0,
                                   0,
                                   0,
                                   -0.25131244184729706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60329603934450793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60402597118627421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38882347588687249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16985411914472698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12983813500562247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0022125282248142766,
                                   0,
                                   -0.24438300408477087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04737471429397172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076488419439554048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55253205032634767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25523736241444045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1061221612739852,
                                   0,
                                   0,
                                   -0.25931798857774135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69315834881103822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45668308677692537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25086765388306459,
                                   0,
                                   0.27558962220816691,
                                   0,
                                   0.48910109293643722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18866231995353636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15872377242617766,
                                   -0.78863947473957097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24741338377164313,
                                   0,
                                   0,
                                   -0.27802197725134259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90282929927194255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46656749364792072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55665794988335549,
                                   0,
                                   -0.10892770644963952,
                                   0,
                                   -0.16198275672354506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48274646305195945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.348665316543812,
                                   0.48599300780824312,
                                   0,
                                   0,
                                   -0.067688756815513576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12106242215367624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25588297073406452,
                                   0,
                                   0,
                                   -0.57640636337497009,
                                   -0.11178043900226893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28685736725781197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15066068594460663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010377028466156154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0032810150298481812,
                                   0,
                                   0,
                                   0,
                                   0.05411427991232097,
                                   0,
                                   0.64817787503442659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16217768957745077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090673410871518825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088636575517901245,
                                   0.28277974450384813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33804502913388851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44091478861083711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24489231396269068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2425307257371585,
                                   -0.25176066967155059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18006882457074097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073694393799131827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017236125059499396,
                                   0,
                                   0,
                                   0.11868845234787812,
                                   0,
                                   0,
                                   0,
                                   -0.19113080817244454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21402673368226585,
                                   0,
                                   0,
                                   0.29876679139914042,
                                   0,
                                   0.45314323144962332,
                                   0,
                                   -0.14893246567328558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44731029460726407,
                                   0.42872425052125734,
                                   -0.026868223293010668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15213595436006366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.206326630107178,
                                   -0.08374847522465885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037738959216725765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22897265509962689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25517056246722208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58312663521177721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24794154175256092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081997291420291357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37028651053601325,
                                   0,
                                   0.41832938042156487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23438438774855053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76886204196059427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1872965376157058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53213172837249934,
                                   0.50298706189631903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10288549145621752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80426583802983287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29248760488793513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12477475353496328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36523623947537776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0357721141714638,
                                   0,
                                   0,
                                   -0.41144997812733203,
                                   -0.10360244512344197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073592075728835277,
                                   -0.96871394935543886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20457148025368513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53722670453741794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33488207479077092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035669691126830078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32537235381419588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5039509520237978,
                                   0,
                                   0,
                                   -0.38112782396468864,
                                   -0.24410741482009424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8216369143848552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066619071945064084,
                                   0,
                                   0.03743958835877545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026468016037286227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044242760019865289,
                                   0,
                                   0,
                                   0,
                                   -0.022616784049989125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23630795646794464,
                                   0.33934842930099041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82123597817548177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31247533190732885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073112417573383853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59916506364838473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71915024031001484,
                                   0.98866769269538024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26600530204794204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79060991907099454,
                                   0,
                                   0,
                                   -0.043492456171871807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90762536505666391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60636510074621852,
                                   0.48007591719092058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78298365514521351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11961729664528689,
                                   0,
                                   0,
                                   -0.90949721514824455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30235603546565504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31963699618528141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0560299169913532,
                                   0.41208219332670865,
                                   0.21113071167601086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066230635030042576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14383669818346406,
                                   -0.25225394120440459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30788956334546341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27562167297841556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42977136189283377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08085729291615984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47915839639354363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27283286470191731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12184998823029634,
                                   0.20922538359226284,
                                   0.012320927622623809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19768982868708929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098526868148048244,
                                   0.30005014732195795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45001792811116947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092892561892738118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37664296085304561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26428146027419347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55237583673384172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18576594896921822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40013771070848708,
                                   -0.21884973488955686,
                                   -0.41489934535716255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076233193649648909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56534628775705464,
                                   -0.090293795650371808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023156286299641407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098738290822525873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35606332601383639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22074641933290279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25684181816005996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026480089343809948,
                                   0,
                                   0,
                                   0,
                                   -0.14470717154547411,
                                   0,
                                   0,
                                   -0.51439007229676847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3014142952119015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60410521418632857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27180775611561037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65310493779215151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0389711447085261,
                                   0,
                                   0,
                                   0,
                                   -0.30882648273343838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049745213020300091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1807895699879144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11639969709494946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.327119489693739,
                                   0.13982627899217262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37513063631854882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70058070321337862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017283051100292157,
                                   0,
                                   0,
                                   0.24759552429016757,
                                   0,
                                   0,
                                   0,
                                   -0.057429431190145326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09204081391447759,
                                   0,
                                   0,
                                   0.092849354676262666,
                                   0,
                                   -0.12581769839464876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05461040867468888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14458577715555021,
                                   -0.26092529654505098,
                                   0,
                                   0,
                                   0.035354133590421222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20381028942820892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54066140570935406,
                                   0,
                                   0,
                                   -0.44074005502944996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19377773940010393,
                                   -0.50565136841391112,
                                   0.2030921410891296,
                                   0,
                                   0.63386786585933408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56991841686731837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14962805110781646,
                                   0.45018005655814314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26813817669573509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70491840985716026,
                                   0,
                                   -0.074539918246634473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30563189929579238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18226849431399039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.546811752199865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12894027950077719,
                                   0,
                                   0,
                                   0,
                                   0.43694342020822713,
                                   0,
                                   0,
                                   -0.68272038861999151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74209256127849266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023124707646730344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58362572170385429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51732671580589529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88955563581404362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72286819362015009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13141041515020252,
                                   0,
                                   0.34780969994410499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4377578880325646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23481429389196251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.304058495879445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25262300596610227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30589803501213098,
                                   -0.30903043101148553,
                                   0.29180048780800366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63776055683651767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036442249643180852,
                                   0.063541597413107012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40690346270397537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080269833082913938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19792950010098859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18888900868915007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054660391157620253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61908379196232011,
                                   0,
                                   0,
                                   0,
                                   -0.56731810760243306,
                                   0,
                                   0,
                                   -0.15210117497030895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5652690600477891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53763614053862951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43687617288632258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12689999902023807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51895263488083698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28184400935319726,
                                   0,
                                   0,
                                   0,
                                   0.73172384742042917,
                                   0,
                                   0,
                                   0,
                                   -0.29170432134915814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23251756481748478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32229159055620032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31775339957795845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20269583955472398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0079775187962800032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35367793204675857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33614759647767428,
                                   0,
                                   0.66477855216526893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14704224305332209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17432490047857949,
                                   0,
                                   0,
                                   0,
                                   0.62513770557756665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66021272280820564,
                                   -0.1107482252090404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77182130211513211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4986879920823884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065211716399729169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58591606818871722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17597063819706832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34107239763889735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098528450692504224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59296656281444626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32441584157982223,
                                   0.13229924300353205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3292906129635918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087478207987748857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43630565121955861,
                                   0,
                                   0,
                                   -0.0049303591700329188,
                                   0,
                                   0,
                                   0,
                                   -0.089147763517231651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075725593787409368,
                                   0,
                                   0,
                                   -0.038567171331075976,
                                   0,
                                   -0.21678845794197255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0099747718676677921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32987123807028584,
                                   0,
                                   0.13825958458867588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74722972769440366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16944668607565075,
                                   0,
                                   0,
                                   0,
                                   -0.084771406010859307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47205666229435783,
                                   -0.48870782022236448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47290802776526591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0038831861997253719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33430615557792154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99173310755524591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12799370642242633,
                                   0,
                                   0,
                                   0,
                                   0.3753516925140053,
                                   0,
                                   0,
                                   0,
                                   0.7362504599519395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37789131645464014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066773497640649021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07555632501922549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067099212718252865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37840767516907869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41592612461413547,
                                   -0.83856875624769067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24882689861425616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13489443640975735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0393396850925927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023136626737781812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090407411427626774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46070144303392324,
                                   0,
                                   0,
                                   -0.045902096087839198,
                                   0.13040117416696861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81848228169881232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1292649561622522,
                                   -0.28255340026903686,
                                   0,
                                   0,
                                   -0.85857397195243068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21365534641631048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22573234001357903,
                                   0,
                                   0,
                                   0.10646464741281282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18369621108599254,
                                   0.2010938871497579,
                                   -0.68081569324419122,
                                   0,
                                   0.16160322290249973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38892625836896189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32069156289286366,
                                   -0.11009834120134261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55954561143110992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21087937222392175,
                                   -0.1698988881482586,
                                   0,
                                   0,
                                   -0.63737912159405574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58657302519396926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77889285203577474,
                                   0,
                                   0,
                                   0.31101508353689672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43962577499395739,
                                   -0.28870061228609734,
                                   0.616020297212028,
                                   0,
                                   0.50684773439516517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52165176459352858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040743927725050574,
                                   0.21150162985607618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18910874247036616,
                                   0,
                                   0,
                                   0,
                                   -0.31192651961036455,
                                   0,
                                   0,
                                   0,
                                   0.25832477948889282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018288054410616861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099552682435347956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78542906833569537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15607431960971113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38562265758710634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19711218435439282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2257143654717384,
                                   0,
                                   -0.3517057051796898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074643953871221108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42176388349550414,
                                   0,
                                   0,
                                   0,
                                   -0.092772439430557505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19332215790548815,
                                   -0.78255662204253473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22468964584272474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74964679980048887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4024704750011886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2395151260667267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12967171854943671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55290699722170189,
                                   -0.41467676864200786,
                                   0,
                                   0,
                                   -0.18516306960389106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48357532322322194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75663464341089381,
                                   0,
                                   0,
                                   -0.46080594789656631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29419689980147856,
                                   0.057798488480688304,
                                   -0.58134359483720854,
                                   0,
                                   -0.24551058674037995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42982084490032446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091556201317933489,
                                   0.053233252009537768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47954374943670652,
                                   0.32917500832567925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027858099969467816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46767142070909551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18099967953870411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83553526096941089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029289452098289124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15538193575237114,
                                   0,
                                   0,
                                   0.38290228595521114,
                                   -0.9780112244316832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43104442098562407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3708231841382913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1234063342206615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098722577994355382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0061408456173735124,
                                   0.29859034266650852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27547286137476223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43427393960151606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055234970269670967,
                                   0,
                                   0,
                                   0.06385957553225742,
                                   0,
                                   0,
                                   0,
                                   0.40572501630799718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18032573613406724,
                                   0,
                                   0,
                                   0.24955421405977798,
                                   0,
                                   0.17749967540306499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67665478587938976,
                                   0,
                                   0,
                                   0,
                                   -0.11699982499764172,
                                   0,
                                   0,
                                   0,
                                   0.30394429540467816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47332348698599291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094382573910404416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35564317189566541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20948487832358995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.180991804884088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61633480134820862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067581485834452726,
                                   0.32105197799103952,
                                   -0.30296447217634837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17645206664302171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30384363913816675,
                                   0.20202095381239921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18718098781479392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37863884891067023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23308543467571657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14267811455426899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057823805351960009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27644220757515853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19122489307330232,
                                   0.33762736539357935,
                                   0.23931214430456488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4375638608734978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21265832124301215,
                                   0.4137801288352142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071198408384054362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4370942486138793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2198048881281032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074404686867448847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24058195092298409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32132501850831913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76395860846833097,
                                   0.018407243574529372,
                                   0,
                                   0,
                                   -0.053648644568697543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83088121102058854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00044612460603112199,
                                   0,
                                   0,
                                   -0.12375997810160679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032249768615575242,
                                   -0.33384589226417533,
                                   -0.41472141167618332,
                                   0,
                                   0.27381059640637567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56475547121032454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10457850615605732,
                                   0.11853796609777122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068620203170580776,
                                   0,
                                   0,
                                   0,
                                   0.022667933206782041,
                                   0,
                                   0,
                                   -0.010255173676555084,
                                   0,
                                   0,
                                   -0.1542770434052412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3606244250873708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32130615990685257,
                                   0,
                                   -0.34904787558129313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31721046729809438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64679223455347135,
                                   0,
                                   0,
                                   -0.31110470706550702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27059384349235277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43538871572368287,
                                   0,
                                   0.4035180513262292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2238477174980606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67554396591473509,
                                   0,
                                   0,
                                   0,
                                   -0.17192734488665573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21675580450434956,
                                   0.12141926783427627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31301510853567044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30406047853494267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27389652639201112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0078472830650260922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5247900118078237,
                                   0.082100777016729909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43964038825804075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91634968411649376,
                                   0,
                                   0,
                                   0.24230431718647003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022595729268777301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57183721275660238,
                                   0,
                                   0,
                                   0,
                                   0.0049959442783603335,
                                   0,
                                   0,
                                   0,
                                   0.43843158115429698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45012768648996043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4934722433890063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029976022292960227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15775424836234747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094022536474073673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41725440477181963,
                                   0,
                                   0,
                                   0,
                                   -0.27537255742540906,
                                   0,
                                   0,
                                   0.3617923456288471,
                                   0,
                                   0,
                                   0.038239223278376963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47423082427940133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26369568731057974,
                                   0,
                                   -0.047885269247345263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075773221754669065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54435019795549677,
                                   0,
                                   0,
                                   -0.13758912893054875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2212562277437066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40952597940102692,
                                   0,
                                   0.095393474828249586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04506287083579124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79254842158637295,
                                   0,
                                   0,
                                   0,
                                   0.35191785345229964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10035242374773945,
                                   -0.72070542156741368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010277823235419127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46005762762724711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14880515966531632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25028080179049311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48885815391747367,
                                   0,
                                   0,
                                   0,
                                   0.10327779685317107,
                                   0,
                                   0,
                                   -0.21176408716627584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53899914649992753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070978267418061097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9519066145244518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97115666766757625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28084612061632047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18466032825799372,
                                   0,
                                   0,
                                   0,
                                   0.68930700709565473,
                                   0,
                                   0,
                                   0.51796562466351226,
                                   0,
                                   0,
                                   0.021359723320132706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25121063851199066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032311562920453063,
                                   0,
                                   -0.033215384402712343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38774523512401554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053960715260431433,
                                   0,
                                   0,
                                   0.059157223644504667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78079878939942005,
                                   -0.24679485070447485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37077646013869847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8541648021818985,
                                   0,
                                   0,
                                   -0.51297032737235715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81756344005173209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016902620922479593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35992693936936476,
                                   -0.36394659306690191,
                                   0,
                                   0,
                                   -0.66445939020910105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13879399769988904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16158366522634232,
                                   0,
                                   0,
                                   -0.78416485610333342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22785955842900546,
                                   0.07956520900925676,
                                   0.59586921471140741,
                                   0,
                                   -0.51641910902964616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15923660452825478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18490999164795902,
                                   -0.15556040838231022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1767598724957721,
                                   0,
                                   0,
                                   0,
                                   0.3217719440975092,
                                   0,
                                   0,
                                   0.057462544949156751,
                                   0,
                                   0,
                                   -0.23342672918164786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07402790632641422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13633072512017452,
                                   0,
                                   -0.57497030986347519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54529639207735936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22079439133972067,
                                   0,
                                   0,
                                   -0.32660895316491773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32954236021996547,
                                   -0.80489334058072093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99035060246119966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093683920114249461,
                                   0,
                                   0,
                                   0.42476635355201187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30197035073770689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3943454087393844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40750163551072377,
                                   0.28898576575896401,
                                   0,
                                   0,
                                   0.18459403009557815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096826059877354861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21847292398435386,
                                   0,
                                   0,
                                   -0.22381116832664263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35329028169837551,
                                   0.19559905809843142,
                                   -0.37897572348358954,
                                   0,
                                   -0.19851309657292493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46686656227908252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42724239226258859,
                                   0.51706081689805128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17867554589757306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14010465045875872,
                                   0.36159031101273392,
                                   -0.24351841900330629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41754616071915185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13809876150104489,
                                   -0.023252080987505766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47149519412240715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35624640593743517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074470812638587291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41101143773014992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20185320302705653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26777639173834944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51967315670766623,
                                   0,
                                   0.27996832531952787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57661866942438822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45808039920817939,
                                   0,
                                   0,
                                   0,
                                   0.14636017947332974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36225474685723291,
                                   0.1865174530859004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72624461194664991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41779839960737714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22018936609382569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34582575990426556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20497502815759044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30577443337692928,
                                   0,
                                   0.27233650239561263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3512558076565277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5661860226179658,
                                   0,
                                   0,
                                   0,
                                   0.14401704092337086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098963405499736173,
                                   -0.71512951642746603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33137438026235316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3337479599540753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33579826576244964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10549458018470678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27221294419848796,
                                   -0.39095075817327668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66210446570857484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17625275627765047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16416170851727954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59024912225507198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080093841179042335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33165129078346389,
                                   0,
                                   0,
                                   0.26304576571153299,
                                   0.73364515301087452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014950876857673649,
                                   0,
                                   0,
                                   0,
                                   -0.11642361625665086,
                                   0,
                                   0,
                                   0,
                                   -0.015275612433226116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55345389695147806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45026509157903782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15762738074253579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2281465946642604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63248837140424397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12916539946742159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40225958606706569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10095914128593737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37379649427697431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10659880810932502,
                                   0.156461056185213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25947051520594139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047607966503526979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33179544882963358,
                                   0,
                                   0,
                                   -0.20055376127978156,
                                   0,
                                   0,
                                   0,
                                   0.074440630704457833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6053612396186463,
                                   0,
                                   0,
                                   -0.17510515780119726,
                                   0,
                                   0.11478953644585918,
                                   -0.0063280635568874737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37151936733164714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34623582065285557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16399299761501593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24859859458050415,
                                   -0.44122438284727994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29079175967757259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047245359879231535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45706603291475983,
                                   0,
                                   0,
                                   -0.063567362622463069,
                                   0,
                                   0,
                                   0,
                                   0.16770699587175633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22497202121996054,
                                   0,
                                   0,
                                   -0.26315525676479462,
                                   0,
                                   0.1046387871300857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49484815214405242,
                                   0,
                                   0,
                                   0,
                                   0.81660183650034546,
                                   0,
                                   0,
                                   -0.14540407449146669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026779537131802866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65327994103706011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51837941034634827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68451102144776288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29083314073599464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32795740042534349,
                                   0,
                                   0,
                                   0,
                                   0.0096963475226022871,
                                   0,
                                   0,
                                   -0.059303365983672585,
                                   0,
                                   0,
                                   0.83159479583625806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034508828707014313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20659544679743772,
                                   0,
                                   -0.35295701038226612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1244904928293399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1134361834458765,
                                   0,
                                   0,
                                   -0.021593774061569856,
                                   0,
                                   0,
                                   0,
                                   -0.23764659720904593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58714519622382344,
                                   0,
                                   0.36834679232927758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046584680821398827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22707629741295793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63982144121073126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077496423175360818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41900123146082768,
                                   0.81957737354997984,
                                   0,
                                   0,
                                   -0.55125841125613306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32785985602454554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22824723770167982,
                                   0,
                                   0,
                                   0.12721942996392596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28796883228967907,
                                   -0.11802483724139706,
                                   0.043869362819530251,
                                   0,
                                   -0.55307706536749079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053741605482345411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4824297527921802,
                                   0.52165213825523871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35155019290026313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41733422775472301,
                                   0.065810750536496265,
                                   0,
                                   0,
                                   0.41774249784119832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042064779565110344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52757718154099431,
                                   0,
                                   0,
                                   0.27930558514497567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66427179855893659,
                                   -0.51779010317567686,
                                   0.17049328059257804,
                                   0,
                                   -0.1299203513010645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12069692223626655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067558920956697605,
                                   -0.50810037895864246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16528890068015692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41390806349075987,
                                   0.29528883900252723,
                                   0,
                                   0,
                                   -0.35620160298188064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31180529688137193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19103055198553348,
                                   0,
                                   0,
                                   0.39744349380252875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36576152902232539,
                                   -0.47708014979967989,
                                   -0.0021306052348691326,
                                   0,
                                   -0.21118120042852809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8968321837903187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14150903925866148,
                                   -0.30234206976703976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74621949667910958,
                                   0,
                                   0,
                                   0,
                                   0.56397137621991678,
                                   0,
                                   0,
                                   -0.27120200831975849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01769199674109756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26220623670017956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78177797942574767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081873047527866269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23974222887436553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042009274991340516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075959887078955179,
                                   0.62205074057639165,
                                   0,
                                   0,
                                   0.092085199572389392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067582271953552014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22147422416723678,
                                   0,
                                   0,
                                   -0.62701674565670884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21414359374537908,
                                   0.18434387382298412,
                                   -0.10780121132324931,
                                   0,
                                   0.31255238825226678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093257050804355562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40651027873693391,
                                   -0.30753374104528869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67158127205657547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12053111619805652,
                                   0,
                                   -0.27481575107743095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35680551972933605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061997081536752013,
                                   0,
                                   0,
                                   0,
                                   0.58940894515479747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31822030851505601,
                                   0.12600358161121505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13441376152000542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32180475238689144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0012327865865020896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4329510113536702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70283963058146248,
                                   -0.39996191822446275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20011463423691084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14981677650454295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52507641501804803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40370321714549423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058710614000778108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35187945975088547,
                                   0,
                                   0,
                                   0.65144237475525091,
                                   -0.45360861686810566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10152953939471983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16954068667201241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5516230349381378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25154263371106855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29987270844701597,
                                   -0.20487237810213821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02248249404291441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11005741066788745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16250768850952382,
                                   0,
                                   0,
                                   -0.23020066861829755,
                                   0,
                                   0,
                                   0,
                                   0.3521941385861882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054563629790688087,
                                   0,
                                   0,
                                   -0.36464443052508405,
                                   0,
                                   -0.33088827700924395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0049063289453245007,
                                   0,
                                   0,
                                   0,
                                   0.19426124438174266,
                                   0,
                                   0,
                                   0,
                                   0.13387510680349662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048376908137973046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39533670410699628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34539788743380939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72488808714401654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37539589537402795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29306540932960107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094498404236454558,
                                   0.1677493131423336,
                                   -0.0091208351550290112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16072672293806844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076767773154839264,
                                   0.33615995224794198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17778602424675233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42694293583495624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5270878647122107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27808850606624358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40396390505936841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29284349737049548,
                                   0,
                                   0,
                                   0,
                                   -0.23170589402035302,
                                   0,
                                   0,
                                   0.67554480369905712,
                                   0,
                                   0,
                                   0.13989475220327688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26446653262060743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37117458092344724,
                                   0,
                                   0.054633558174190772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19420672714794704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32712334996009718,
                                   0,
                                   0,
                                   0.1708796658112435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81685265189822387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77515867225812729,
                                   0.4890562697687163,
                                   0,
                                   0,
                                   -0.061089747503898201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053030447115501984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20515826727958844,
                                   0,
                                   0,
                                   0.18726839261731701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39510120593133757,
                                   0.012931671039401516,
                                   0.59704839173767443,
                                   0,
                                   -0.32400106065825018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23236120949439468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56063746056216279,
                                   -0.082311940881893503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073536246830394947,
                                   0,
                                   0,
                                   0,
                                   -0.27263442273999061,
                                   0,
                                   0,
                                   0.078441295530702781,
                                   0,
                                   0,
                                   -0.24730185907595048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24596333564012968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1633064968978854,
                                   0,
                                   -0.5661875893782099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060697519713147165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015772925048126232,
                                   0,
                                   0,
                                   0.66429158564164159,
                                   0,
                                   0.21460744517253907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15313848265465141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015931583852045447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20003371050284435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20609030373729489,
                                   0.29720933717296694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35109644965683506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10793188747933727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34989900588149336,
                                   0,
                                   0,
                                   0.32961654613937635,
                                   0,
                                   0,
                                   0,
                                   0.17498344157028209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17851460342255276,
                                   0,
                                   0,
                                   0.27596057192933082,
                                   0,
                                   -0.50476038739901141,
                                   0,
                                   -0.24313147332917098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19789999005962502,
                                   0.084435635123233613,
                                   -0.61990270611753051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29094494032109014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.334061692135038,
                                   -0.26226878853903146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.419325610360404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19684291508774823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095664739154326411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10836997416575198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099025021312125844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58076871787725159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032686720368278244,
                                   0,
                                   0.097495698643259548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71816730329746203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36433393292028138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060252578286095426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28704251217638577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25389790048934224,
                                   0.010900338841969559,
                                   0,
                                   0,
                                   -0.38615658708544609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19409461453992116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40938163457864796,
                                   0,
                                   0,
                                   0.036894035132680456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37469466359879355,
                                   0.75902749209100628,
                                   0.40854332837426149,
                                   0,
                                   0.30629054274269069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61512232521690557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18260210532363436,
                                   -0.1834024268478863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17190083215107421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088393625902579154,
                                   -0.54925254245207256,
                                   0,
                                   0,
                                   0.4940077526669297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69239410999765161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046122044565404495,
                                   0,
                                   0,
                                   -0.27734332794876293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00016032919318996475,
                                   0.4092706480152406,
                                   0.31196188900656308,
                                   0,
                                   -0.42837950707473949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15479885097474591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72007104485022611,
                                   0.16200808361494229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20802050878598932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67591651303003908,
                                   0,
                                   0.36468752720525066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37671794929219882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35537109814160439,
                                   0,
                                   0,
                                   0,
                                   0.55339034217880778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90937537387626499,
                                   0.21871645792966399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1568555061219091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099447804083361069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53201585447854138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31752026036785108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093328115463368902,
                                   0.1952318634650228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0010149324675215211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90246403682685594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17959738905765696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011350889127668101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79047946518678103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42015844069202513,
                                   0,
                                   0,
                                   0.38023537383203382,
                                   -0.033441997460211349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071216067151573748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053864043780791848,
                                   0,
                                   0.74383329585027369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37694392734869686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3690375919507089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40057895091196088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0041662062390321886,
                                   0,
                                   0,
                                   0,
                                   -0.33717539098859051,
                                   0,
                                   0,
                                   -0.044793138529049439,
                                   0,
                                   0,
                                   -0.066130276269279836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18843227582315863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6207753164372154,
                                   0,
                                   -0.26292523425493713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49751944860891123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14510455733798855,
                                   0,
                                   0,
                                   -0.34833379186712377,
                                   0,
                                   0.070861684871340411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21558116875918726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13250966046541304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31901244320436578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12091059556153341,
                                   0.45097320354165515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13538071242111696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14964580025358382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015434915561205353,
                                   0,
                                   0,
                                   0.23486497735763467,
                                   0,
                                   0,
                                   0,
                                   0.2983931307471907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025932326995438463,
                                   0,
                                   0,
                                   -0.41227805134335965,
                                   0,
                                   0.50534512475071658,
                                   0,
                                   0.083429329908836669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64569988869890116,
                                   -0.084902664695870295,
                                   0.04927490152679731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10341365275457223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54843512567239228,
                                   -0.16322174231448877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25429480409946159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28771396020008666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042942730542437933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.161123594815961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23045141188954255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65737129683502615,
                                   0,
                                   0,
                                   0,
                                   -0.49746433528510459,
                                   0,
                                   0,
                                   -0.39329602116625673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056275498882780592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95788482775797035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44485043482691033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57598478781888851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28520422834108156,
                                   0,
                                   0,
                                   0,
                                   -0.49225121229276309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022374670806751318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13082671287903511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36445462399324874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1077651782025813,
                                   -0.052239886429920425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39455529648975068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27002866065651981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05758552613042793,
                                   0,
                                   0,
                                   -0.44667817368391438,
                                   0,
                                   0,
                                   0,
                                   0.11563087421784257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1562603145680998,
                                   0,
                                   0,
                                   0.33657308691427551,
                                   0,
                                   0.10201424379400156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28863879001268344,
                                   0,
                                   0,
                                   0,
                                   -0.40173045242693567,
                                   0,
                                   0,
                                   0,
                                   -0.057895447225455254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25980316259864045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51990961380544309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069989127638161855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53269970374999531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35422770571619899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33653492285852388,
                                   0.1931842680039717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59398838571288937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12860313620804065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39954725941177105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17672455973827178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80668662832759408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47722108775855099,
                                   0,
                                   0,
                                   0.46785467689775229,
                                   0.24036536854001847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25231955277278051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27182527214795971,
                                   0,
                                   0.065843484367379385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15908610487975225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46106237541618866,
                                   0,
                                   0,
                                   0,
                                   0.12216859493034338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72994618380260479,
                                   0.12405675904462464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21215769269157542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22092349980443191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0228826768960839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0012526283776364555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044513623251732845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13748277154940475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25860216066890374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15634444071553782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12520729682708079,
                                   0.4247005464545377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28631160891896373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22332950038220689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35783134772588127,
                                   0,
                                   0,
                                   -0.41020786368825923,
                                   0,
                                   0,
                                   0,
                                   -0.44123167280562398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24249889171332625,
                                   0,
                                   0,
                                   0.011114474446825187,
                                   0,
                                   0.099860606789066816,
                                   0,
                                   0,
                                   0,
                                   0.25062403038799685,
                                   0.15317371168573848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94703988086609658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32616172546018651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42452366845178735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42218280566224886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33984350233584648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021396919139924045,
                                   0,
                                   0,
                                   0.074730797519077991,
                                   -0.15956717190689493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76083301580257645,
                                   0.32130022386153728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20154698690025452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93286231607534698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16867092524698618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35343837384312837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04054968003918194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24274130213623357,
                                   0,
                                   0,
                                   -0.72609516899527971,
                                   -0.65342068536702091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25042291347908224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049565138756998486,
                                   0.26252937664693743,
                                   0.31954899410127313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052136134306002259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17663788039992864,
                                   -0.63728852086950794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02521252889310327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28573712390201955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21298148571112419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43509896682647414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082395705519845402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17367462099411707,
                                   0.99835163249979619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35923830112768113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15670757019954068,
                                   0,
                                   0,
                                   0.94209794767275945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74990218314838375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56561047076075477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34185325917447945,
                                   0,
                                   0.53606826066570246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18501967035009215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43537162192992174,
                                   0,
                                   0,
                                   0,
                                   -0.60525609641870526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053309754967726969,
                                   -0.28408291797928331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2851805895579409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56877665097216423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025424194643162298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095487994617342545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17102940679435052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45954834159448177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04221332530772428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086713739129720191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13281054287717986,
                                   -0.2061985966338864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27784276368854804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15267054015013845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23731723442534602,
                                   0,
                                   0,
                                   0.14485687621777393,
                                   0,
                                   0,
                                   0,
                                   0.24629443169825443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47494535723408293,
                                   0,
                                   0,
                                   0.44485421292878896,
                                   0,
                                   0.16783722798552811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73059736009367193,
                                   0,
                                   0,
                                   0,
                                   0.066116106395224666,
                                   0,
                                   0,
                                   0.010988349679284262,
                                   0,
                                   0,
                                   -0.36341483881938674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23165675357220472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18566358143953582,
                                   0,
                                   0.1268875073604363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35804235042698057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30143276376661737,
                                   0,
                                   0,
                                   0.079829673383562394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31429590553050507,
                                   0,
                                   0,
                                   0,
                                   -0.37463005294183832,
                                   0,
                                   0,
                                   0.95384348197415458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1376171796231103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36866813029150247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17505370434915307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33081147567770663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13509161595814206,
                                   0,
                                   0,
                                   0,
                                   -0.31543740145790888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012801180612312424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37435615653270649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090033478252474528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49503826387357847,
                                   -0.17411884230582564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08373658524867475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098083025293028078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19839147921193281,
                                   0,
                                   0,
                                   0.46220196790089818,
                                   0,
                                   0,
                                   0,
                                   -0.13578486872771967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38003209107193603,
                                   0,
                                   0,
                                   -0.19405446196507517,
                                   0,
                                   0.081028227845458128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15276036843425725,
                                   0,
                                   0,
                                   0,
                                   0.31433267826726424,
                                   0,
                                   0,
                                   -0.35951762223549094,
                                   0,
                                   0,
                                   0.10521342990555263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59637680274737725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42502072105803201,
                                   0,
                                   -0.10400231247884911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11542601401049363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040465573861644254,
                                   0,
                                   0,
                                   0.41886923749027277,
                                   0,
                                   0.39590731784210104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012246483739621138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26435678297701815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14336552225689467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46767063267896403,
                                   0.040363005807639525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16337401870140217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31801725126876768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33298467806808962,
                                   0,
                                   0,
                                   -0.2388252585911107,
                                   0,
                                   0,
                                   0,
                                   0.47232507414143154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040706860648009761,
                                   0,
                                   0,
                                   0.10193034309752146,
                                   0,
                                   0.038001100747950434,
                                   -0.34024674523571125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19130724048998055,
                                   0,
                                   0.18691152282500872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042451560992532028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35094947820351707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35566598069138872,
                                   0,
                                   0,
                                   0.58520320741498544,
                                   0,
                                   0.41492058286181888,
                                   0,
                                   0,
                                   0,
                                   -0.058492200465588784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37015118040719708,
                                   0,
                                   0.14069461300581668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96146687581095669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25271254000206717,
                                   0,
                                   0,
                                   0,
                                   0.20181331991726856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55938919044859059,
                                   0.51677541677455363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23305710110697095,
                                   0.67018247218593829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35579167399435041,
                                   0,
                                   0.65843461893279964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17965871768441638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14161015155770007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19851921037069167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10064198078283061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44344850590734225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25443364542815589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.407984086487299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10996661537232456,
                                   0,
                                   0,
                                   0.27983945918211223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29038335727845627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27571763601562066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34865868242319403,
                                   0,
                                   0.27868749028483308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32861276137268486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52414131704431244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029384273459263786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14143530069831906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43560744700496778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19068544205756502,
                                   0,
                                   0.83235559010500881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77080135985656861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23056501928009779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99646509924143001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4480920510137783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34019152446752482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54195982750016147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7707696233108382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30760531865734886,
                                   0.29169894302099608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62191120162190072,
                                   0,
                                   0,
                                   0,
                                   0.30925188218255828,
                                   0.12685852936566142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02166727608115341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73651675046203102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014365209234367848,
                                   0,
                                   0,
                                   0,
                                   -0.5326648809350869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30200460601556123,
                                   -0.98177201388973601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67040696370723429,
                                   0.27492331156925198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46914977874004149,
                                   0,
                                   0.14260855080535456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091200113000222155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32918468908136334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16640860653160544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34717589920425929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61059653558609961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0011334622546396236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30189471615519409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86798579188065994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071749585538383745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1461922435807903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08184543628038321,
                                   0,
                                   0,
                                   -0.15872170690122042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13695005416235639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27980975202113273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070178379891494641,
                                   -0.16074854152851131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060114070288664515,
                                   -0.054710584425402754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2360388592869008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57128103936290664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047152578943690682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49966076519068292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1870763389795333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021644140980948738,
                                   0,
                                   0,
                                   0,
                                   -0.37130952031538345,
                                   0,
                                   0,
                                   -0.37177707588366071,
                                   0,
                                   -0.1306544156268615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0064638300857497166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00019446751905866783,
                                   0.23509489896112429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26915379954366297,
                                   -0.235738599734236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27844804389405425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37672615704270962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067219060397186059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06285527230022811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15609330464449744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63952728920603408,
                                   0,
                                   0,
                                   0,
                                   0.16882656738203772,
                                   0,
                                   0,
                                   0.34085131610871255,
                                   0,
                                   0.04433395426790232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093706964117144437,
                                   0,
                                   0,
                                   0,
                                   0.074847645388298717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28409206996589631,
                                   0,
                                   0,
                                   0.43627776751032077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33170318694204598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48929621355457992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42060637147207047,
                                   0,
                                   -0.12372732900113574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25616805236960827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14032753678788032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31045351699042278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55222943355308929,
                                   0,
                                   0,
                                   0,
                                   -0.12643709529565667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21570407995744145,
                                   0.024257509661809125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62443641405935268,
                                   0.14770117352002121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016811065105854135,
                                   0,
                                   -0.0069668749787397885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23401052542832643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24961612504459146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64887399116460298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47481108913852688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25598247920951689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41677667128345153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0024150908932097787,
                                   0,
                                   0,
                                   0,
                                   0.24308012550867816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30307855055772992,
                                   0.010878991551127079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18930825469849077,
                                   -0.69744959796010342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37928574073368909,
                                   0,
                                   -0.39907675724665148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12104780980535325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45294052637879034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29324779255810091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024139518718355873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45194112788292529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9595516045116379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28392735349020559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38783067621692124,
                                   0,
                                   0,
                                   0.23721807134402978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077336257500641895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13567354192986003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12358840971603491,
                                   0,
                                   0.62038189685982992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43092373432739761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23068763002544868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22192828577724716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1654163336935639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24801507497126851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53572195835905922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46028430496306894,
                                   0,
                                   0.13207036972786182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62834999682575066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27319309466972208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5717854919801113,
                                   0.54753852889467614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27873654874229742,
                                   0,
                                   0,
                                   0,
                                   -0.32753688538352155,
                                   0.591503461538334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037958356387822176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58985223154252886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22656484091867413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2674580660487485,
                                   -0.27094487736769945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67070056172917503,
                                   0,
                                   0,
                                   0,
                                   0.95703660177803074,
                                   0.85330280255886248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59069813225646417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20542631029763617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23819538606013249,
                                   0,
                                   0,
                                   0,
                                   0.025520404233360522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17847694264755243,
                                   0.4148511083135199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027196402123961523,
                                   0.15258957039703713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057142404801019148,
                                   0,
                                   -0.11553950461044676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91286873757572651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.489109562142369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82830041961920053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40707926705554492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24733468775665676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27752129697927397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32409282566222569,
                                   0,
                                   0,
                                   0,
                                   0.0045309696108877563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38264840949307311,
                                   0.19055728566578209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20583877622368807,
                                   -0.43603757571065632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79897785691827072,
                                   0,
                                   0.47783221643146695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28253879859190295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024570263818705571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060343221860177862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16691500627044056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76814190840046359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10879531311555876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63760672045198252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24592979738367771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31422320815637289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21550037606625044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4954514873371636,
                                   0,
                                   0,
                                   0.0096404219960772586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1926570492005811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32421862302614146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46041219230077518,
                                   0,
                                   -0.015991232381331155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36375322657776654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37808213282783232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0550882523218491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20568193591257641,
                                   0,
                                   -0.084513570342950983,
                                   0,
                                   0,
                                   -0.40529785475570607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039352469625780484,
                                   -0.12238627637065244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5045023504333902,
                                   0,
                                   0,
                                   -0.15717530534307861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26937580349539214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15314542721924296,
                                   0,
                                   0,
                                   -0.60552153677127474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27531016674667008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41375628138384357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21062116352267735,
                                   0,
                                   0.34352425402849646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13696133851930067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073280826782422259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32223935105467805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41507508169376811,
                                   0,
                                   0.043881150309660943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61582949932566633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040532851062425886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057034431635757943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53778640416575152,
                                   0,
                                   0.14943911088113851,
                                   0,
                                   0,
                                   0.040772587951164362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18109189816899982,
                                   0.15375179423945934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025048426470700977,
                                   0,
                                   0,
                                   0.26716161546857115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17257724464198457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60132123231401391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22337495597775875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32741895329276438,
                                   0,
                                   -0.6642189990912708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10170275076384008,
                                   0,
                                   0,
                                   0,
                                   -0.55416809238958409,
                                   0,
                                   0,
                                   0,
                                   0.40652315525645016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26302763687716252,
                                   -0.25265235969695266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55206267282816635,
                                   0.33415590398290557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34380170219640299,
                                   0,
                                   -0.36589513223915482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03313626956529319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90449042858640261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18761393151532657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37084773581108127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21594231562662503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029433770873349953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07226095973957776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59035867191099101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053122730700427209,
                                   0,
                                   -0.93192498783057565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38389824418869156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2310470407968172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50670631553026801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42260242700864337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6071477921244226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30155153351866121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24557474319672551,
                                   0,
                                   0,
                                   0,
                                   -0.092269298006846245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22148888274036932,
                                   0.41293462792196034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58738676019119906,
                                   0.041962784582581902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76859205003939113,
                                   0,
                                   0.14106450505044299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15865707928717276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41930480951282534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086770503934714194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062800067460780359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65531063777672272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66145532218131442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11986226604918737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072977907885855925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3306238999372203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74955523163725535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11585277991560262,
                                   0,
                                   0,
                                   -0.23415064338332559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24187078621592017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42709739640739408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1386108954473762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12504961634426151,
                                   0,
                                   0,
                                   0.14199271303586761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22714615824192758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29839617956510223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17065564046590084,
                                   0,
                                   -0.055027604927487241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27076584473520715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075793194839877912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83255143348080229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65306730982240568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47517287181183765,
                                   0,
                                   0,
                                   0.076584324337132442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92087410362536226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55279653184515543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60331169671433027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12991548133325109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51904110266578862,
                                   0.39050430592675289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59899608671248938,
                                   0,
                                   0,
                                   0,
                                   0.57748512506288252,
                                   -0.055933398067723739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62783670823975246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35532614198168572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051400977353179472,
                                   0.23271676058938998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14496033294728713,
                                   0.2665785974303434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22691345019099468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19214159060847699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35246481707491656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.109561552499175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27706124226518575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071037691749980231,
                                   0,
                                   0,
                                   0,
                                   -0.49356409965041392,
                                   0,
                                   0,
                                   0.34647197058116352,
                                   0,
                                   -0.29432045635288145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30724217296199341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20538764644942298,
                                   -0.11849161512035887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012108604132331405,
                                   -0.3299750421043447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54416133171451631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018269135694959963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20971338636419568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18530784177641418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34496635433248396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25537727407610433,
                                   0,
                                   0,
                                   0,
                                   0.27124885629152562,
                                   0,
                                   0,
                                   0.016373832822033876,
                                   0,
                                   -0.32101283207484188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31443420249132342,
                                   0,
                                   0,
                                   -0.82738245964252177,
                                   0,
                                   0,
                                   0,
                                   -0.62113867704632431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34770059853395285,
                                   -0.027708969969562555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033976138929359287,
                                   0.04841895493076373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34070921805748478,
                                   0,
                                   -0.25256673653413031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16901107997415057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18470446938925075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34291589115258442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86407542595694953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26011877979441661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38103147506538859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70872311440481039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082284345871740022,
                                   -0.61879887009321077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080502895869924818,
                                   0,
                                   0,
                                   0,
                                   0.49326983993622819,
                                   0.30916290226915322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57174750245921568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57838128288403934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24498096883252515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39602113727120741,
                                   0.1006810523937483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74094345465467959,
                                   0,
                                   0,
                                   0,
                                   -0.34147664715446302,
                                   0.11638297829600772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31359205171224025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93326634377849693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041516637941699311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032941637945084812,
                                   0,
                                   0.23452106217899404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24506393069347093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0115220925515476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013996303397210044,
                                   0,
                                   0,
                                   -0.477662565371061,
                                   0,
                                   0.51155585376911572,
                                   0,
                                   0,
                                   0,
                                   0.017050954578878882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047577973911990208,
                                   0,
                                   -0.30073489846456369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13877629250782447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0029250634035835905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0043398326042766019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71019137670435417,
                                   0,
                                   -0.14476482097023086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71053250214642494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28939675297422679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26402060790919207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59617564929259459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7943347248052548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37818222771470666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062416737428770352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035999583852639794,
                                   0,
                                   0.0074440876410453577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6073969918691744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37328247075957027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35505806332307799,
                                   0,
                                   0,
                                   0.42046154863751456,
                                   0,
                                   -0.047117333474696738,
                                   0,
                                   0,
                                   0,
                                   0.28375046817569621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55775195751738771,
                                   0,
                                   -0.7436984952253749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16515570642006455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0590334275398632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70708969705804825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3025094751224236,
                                   0,
                                   -0.6614967695087115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20594098194671384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11341089726754514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42414175814765331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63280000079811982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092283424675472764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45496509825478548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076187154197335571,
                                   0,
                                   0,
                                   0,
                                   -0.042016727679900043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69047844536488434,
                                   0.19937349487000436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07036475335865669,
                                   0.10864235396477023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43686244271143904,
                                   0,
                                   -0.72152148480624634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82769101552804236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10380070335390204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31576274710059443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32130845593443624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18503351916394259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037346410435014854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11210996963837322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095051008244428803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59767457227537057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20997282660518146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52387447527399067,
                                   0,
                                   0,
                                   -0.50000364654205864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029314512469358081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22756477153112703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3001454654874498,
                                   0,
                                   0.5298556167857621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20025831278184286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0098179419936567994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3190989400722305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39883759571078481,
                                   0,
                                   0.26237666920497049,
                                   0,
                                   0,
                                   0.30381552157345054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057625435477867346,
                                   -0.22727795083943297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25184236818711325,
                                   0,
                                   0,
                                   -0.22028267276202032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05745798692539289,
                                   -0.081368851120152227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10636202534966002,
                                   -0.58714141914964968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061640385102787021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28725746461129226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31611307127722593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15229547788645711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52314963360248845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043932965061551241,
                                   0,
                                   0,
                                   0,
                                   -0.37637462161416352,
                                   0,
                                   0,
                                   0.032944032637442514,
                                   0,
                                   -0.0071168543984688921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078629063107351946,
                                   0,
                                   0.053608478550319555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40400233847543321,
                                   0,
                                   0.85398929948297775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20408221663660328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47061847460779527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52772248010793499,
                                   0,
                                   0,
                                   0.34083339773923804,
                                   0,
                                   -0.58164806129102475,
                                   0,
                                   0,
                                   0,
                                   -0.7383648591682892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37095294317769223,
                                   0,
                                   -0.59372590928081737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19802657664791659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30900823675006328,
                                   0,
                                   0,
                                   0,
                                   0.46656139093546178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53575200986939697,
                                   0.29202651251371781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46282329522879928,
                                   0.11029164172056387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32235752701184672,
                                   0,
                                   -0.68589804175190938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022357219682124944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63209010568591806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38433201652845378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41255237616392088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15366627204982827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040471740119930662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26649767111711875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72624590962516367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47383183195352357,
                                   0,
                                   0.29653804157361707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86561131933165614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15262482566522195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2733769524783962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3502369628460178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41802728089047247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033295777080938532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70362787325787257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10050860407204321,
                                   0,
                                   0,
                                   0.0046065732224203071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44560347958302521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2006196213808335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03758495328019916,
                                   0,
                                   0.35915269522008125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14551957645229327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26198875108909381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18909411001072712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15700290049146245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023256951187130337,
                                   0,
                                   0,
                                   0.32584968011630494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0879447091177352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4263921593526942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84249579847507161,
                                   0,
                                   0,
                                   0.23847710703332833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12239833937572908,
                                   0,
                                   0,
                                   0.36203232990740292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40957582200440823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18787468409820066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66850989509820713,
                                   0,
                                   -0.11770914576885784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28697364877484549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21430784722568585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070625815604517597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46234128163786964,
                                   0.26679125109585416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2817004283621089,
                                   0.058044114111333894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2520694311437145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21817326910031548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21129040409091623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3153579456047152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1204899211553811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43716525895469466,
                                   0,
                                   0,
                                   0,
                                   -0.061740328474516576,
                                   0,
                                   0,
                                   0.39311529922301131,
                                   0,
                                   0.11423453344647479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0085764161402443334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094397194744401669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91481130029673419,
                                   0,
                                   0,
                                   0.14538982830837288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45329245029384935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39669232148874911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37410942755777088,
                                   0,
                                   0,
                                   0,
                                   0.31233204804341236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52926599087782122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63692940429737699,
                                   0,
                                   0.7337045774226898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055215152630886041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1554478075052415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095283568205072944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23397567781792647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35819973280317835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22489762149833989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48358279505793667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098590826634185225,
                                   0,
                                   0.4493458309639124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83218750282823217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039130852873176372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77939957867775,
                                   0,
                                   0,
                                   0.17646761500141001,
                                   0,
                                   -0.28513884100985071,
                                   0,
                                   0,
                                   0,
                                   0.32750279906790059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3335780069921469,
                                   0,
                                   -0.19468421450679202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46598980759690872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.005492819205749816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48286375658596659,
                                   0,
                                   0,
                                   0.12850975350683266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5160167608109254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11526379951120411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068020056593891209,
                                   0,
                                   0.21093566804694236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29191706109440541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56645759858325428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12461243175047942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1335159722973106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01649203294924978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3164183477625887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45799968298731597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0071256753023912489,
                                   0,
                                   0,
                                   0.41647936328228763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48524060338545538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51288686775057946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1222849766313969,
                                   -0.16923069337339938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.459328714775462,
                                   0.17941902842652413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21927499603239553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040672847811792014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46887451496237759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1443314206084724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30996207295763484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27253882445316857,
                                   0,
                                   0,
                                   0,
                                   -0.30493490931336004,
                                   0,
                                   0,
                                   0.25740140402813644,
                                   0,
                                   -0.21371114173689967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21807222523519249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066375259874862036,
                                   0,
                                   -0.59140544603569134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36251822751836682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4811892376431709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013839392395194917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30095382997762221,
                                   0,
                                   0.089883975704030311,
                                   0,
                                   0,
                                   0.23141830606928709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20236483273377076,
                                   0.083429634196613645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27710656171250725,
                                   0,
                                   0,
                                   -0.075980271143975306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20572543362255352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38226645796271774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44161443219583452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30298704650609176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45562715639922224,
                                   0,
                                   0,
                                   0.05000072983995027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40300005329486493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39015346008293011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27573228103371683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58161518549188229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39672210101026711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055900755215565798,
                                   0,
                                   -0.6371203806666571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13877963062600063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31528672699393057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37563785587912962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044177147125919795,
                                   0,
                                   -0.49584427476927739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027129174569474293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56712943043066955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54295562368799877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031250202592651932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20237324368181153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2887680140376589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0089192548845600794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43375343333054989,
                                   -0.032785431543431484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059568131381363132,
                                   0,
                                   0,
                                   0,
                                   0.1723373728816279,
                                   -0.85877537037179952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0177079717895574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29270641342657316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11925640254650637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38442375299009579,
                                   0,
                                   -0.10339777393151031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0022805318326235974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010696297752218586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31670416362248088,
                                   0,
                                   0,
                                   -0.70901432199091752,
                                   0,
                                   -0.41716234109025296,
                                   0,
                                   0,
                                   0,
                                   -0.037140005623937183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44536503829290663,
                                   0,
                                   -0.38809713334296231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91464304279318009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.277620408317172,
                                   0,
                                   0.053504515848309314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33401530504423882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09663999808705373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14672513097020337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25329203385323623,
                                   0,
                                   0.38875472199707345,
                                   0,
                                   0,
                                   0.44088394458962565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13451155569121814,
                                   0.25933615931476039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49748359400564635,
                                   0,
                                   0,
                                   0.18741966024017648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062620700693245004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11804275153433243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62781296516445662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17420546227240036,
                                   0,
                                   0.079034169010771371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7425641349200347,
                                   0,
                                   0,
                                   0.10943207417851633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1012279380458179,
                                   0,
                                   -0.20954065174828002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026975638929898849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073749324363786312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14646851284883702,
                                   0,
                                   0,
                                   0.38616077192876508,
                                   0,
                                   -0.047356498516006658,
                                   0,
                                   0,
                                   0,
                                   -0.34562075457180275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75623147666579471,
                                   0,
                                   -0.62055182879948145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32974119271655467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59555154746831718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28080579278322293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21255995197251901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64807228439055697,
                                   0,
                                   0.30525161680282875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090047168245221743,
                                   0,
                                   0,
                                   -0.19701315223251381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55437380590402752,
                                   0,
                                   0.37194600781227766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014296628608402612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66778743306017097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30386669586949844,
                                   0,
                                   0,
                                   -0.66742982467950474,
                                   0,
                                   0.20499970483815205,
                                   0,
                                   0,
                                   0,
                                   -0.015346967438871553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92175642103630517,
                                   0,
                                   -0.20814578670299599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44638908516314291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85940848204549147,
                                   0,
                                   0,
                                   0,
                                   -0.59923510763980237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12899951091888467,
                                   0.02976484735036336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1122552730226954,
                                   0.34944982369260208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49929903637509582,
                                   0,
                                   0.58957184500653737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40244562883720636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12338799680957367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13246137768391769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31524583139950874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42931481562727619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14312697341358979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1142616128751833,
                                   0.32473395589185117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48057709518174924,
                                   -0.26332188073932306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031053684123459244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24701871174310358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099870571617670642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18452196385848091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14012396262802801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26229371254210837,
                                   0,
                                   0,
                                   0,
                                   0.0003839749982876145,
                                   0,
                                   0,
                                   0.1979111956679285,
                                   0,
                                   -0.39307423087331655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43941468640501274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1549857351395996,
                                   0,
                                   0.24792741182651173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040800105531726111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043248216609408578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37197818690297196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15183586889141448,
                                   0,
                                   0.39900803310265937,
                                   0,
                                   0,
                                   -0.20439635737192224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67879769710304183,
                                   0.21896313087175939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11446239364234223,
                                   0,
                                   0,
                                   0.16357375609817182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.122866894915636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20805979086724974,
                                   0,
                                   -0.60929462380001265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35661122979377802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45240828286990564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2622263838213269,
                                   0,
                                   0,
                                   0.23910647183919692,
                                   0,
                                   -0.033804104704180382,
                                   0,
                                   0,
                                   0,
                                   -0.18104977652046703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091989014147833434,
                                   0,
                                   0.18885784457050295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23951467529722126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18840356395912727,
                                   0,
                                   0.17901502148019419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   2.5712145102264189e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18267313726730272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60818615493200945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17201802951624742,
                                   0,
                                   -0.27868134183205051,
                                   0,
                                   0,
                                   -0.0080662302915850709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41351334757215857,
                                   -0.0032392952478970055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1628808644614729,
                                   0,
                                   0,
                                   0.47365106342531793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45689219766521821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49098512244329723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42396641350239728,
                                   0,
                                   -0.15823744872869411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23105313298658384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0044877932664594417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14950554297207524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0292446422043611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0114066467954153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10456171824200095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58095450717194574,
                                   0.076194386631598512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2949007686185276,
                                   -0.35434214896552907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25866261277989872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2182565739619019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31694880099178907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073534228663085219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28352101863145035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13973534425081174,
                                   0,
                                   0,
                                   0,
                                   -0.23666341107177291,
                                   0,
                                   0,
                                   -0.15187367878778799,
                                   0,
                                   0.21146662193364377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0072040637718112054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030372299725233254,
                                   0,
                                   -0.21766496858882572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075278880668750575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26292049782394927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.111492880030747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20339329862475566,
                                   0,
                                   0.22840682644205887,
                                   0,
                                   0,
                                   -0.24330262420766471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10708583396868029,
                                   -0.60774950346851464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1981461354620439,
                                   0,
                                   0,
                                   0.5400475159388094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28881789912287054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54763906989939759,
                                   0,
                                   0,
                                   0.33669316873687305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19837241665241165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1884308871470633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32889494177001982,
                                   0,
                                   0.33177431621747888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066386798926053786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45353965819427838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010200844192438368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25480948322059449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086842752037410931,
                                   0,
                                   0.35277862283205319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047830341216539118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14397154622330405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91897738512266058,
                                   0,
                                   0,
                                   0.35546124957725478,
                                   0,
                                   0.3303901397757979,
                                   0,
                                   0,
                                   0,
                                   1.013808532774521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22978261093911484,
                                   0,
                                   -0.44102937183504393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032371762937446369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28495818991876803,
                                   0,
                                   0,
                                   0,
                                   0.7723084446052223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0027355740215958962,
                                   -0.52746047178938194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13978579513773762,
                                   0.057405776992490706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50646571153694264,
                                   0,
                                   0.52364401297681218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24176824567554311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083132478698128121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58545207415202427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095055689170030266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31526725932451793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1534196869720276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9916757640108782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46577198097653749,
                                   0,
                                   -0.55305753466485186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25823672825092958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069989402860764841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088910379972689926,
                                   0,
                                   0,
                                   0.4347545197107483,
                                   0,
                                   -0.3900912881869717,
                                   0,
                                   0,
                                   0,
                                   0.47880697144192952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51258338171939388,
                                   0,
                                   0.15505444157251538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65436408360169285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57130801595700742,
                                   0,
                                   0.30838073557075552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39253505224593788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085928086186775568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097435956916902974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019680177729364482,
                                   0,
                                   0.062213222153298872,
                                   0,
                                   0,
                                   -0.50188543614949899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13069850102320604,
                                   0.090704842529980956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28356778921607173,
                                   0,
                                   0,
                                   -0.2137296440839028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18356410411067636,
                                   0,
                                   -0.23245909156976099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054937558733819836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30482804625086363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42684530499253959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29043342838227149,
                                   0,
                                   0.19967273549621925,
                                   0,
                                   0,
                                   -0.35663112836666944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19105155386048653,
                                   0.57596583536099299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079012370862063613,
                                   0,
                                   0,
                                   0.090801812021223616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10807436908632377,
                                   -0.068585231286309875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27288072654838935,
                                   -0.092002994960883738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19035814442024745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38292772667233682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30305931639226696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25333775348882592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077150304361321781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056011380252982391,
                                   0,
                                   0,
                                   0,
                                   -0.17222437050574935,
                                   0,
                                   0,
                                   0.17088261255698353,
                                   0,
                                   0.63436649929845446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30235793442989189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12865971946273433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36882842659314019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74375455658606704,
                                   0,
                                   0.2105298661949308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.578602857255053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94526676230711093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10167574316526566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12777693543117963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78834830743064899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17192012907131343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24425493256969258,
                                   0,
                                   0,
                                   0,
                                   0.22040345914291942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44217852139593017,
                                   -0.016193500114110068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84500494749979627,
                                   -0.64723852274995297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2789117089481965,
                                   0,
                                   0.18925289231810302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23579591095243535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12415971817499202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43587097839601963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14094332040839069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47140465021347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3125251322933616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61751079956695409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0022347384246758153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077385421829550077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075580315226531816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47998676329393164,
                                   0,
                                   0,
                                   -0.28702221629900926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37031387721173858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39632451041880312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44489350509118986,
                                   0.024106412244120145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045079742019064756,
                                   -0.30888612892247502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32215300296124638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20579732377920212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22138981794214851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35587074567673022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25616984395883263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24301523634619235,
                                   0,
                                   0,
                                   0,
                                   0.22956099580975037,
                                   0,
                                   0,
                                   0.3194823717698777,
                                   0,
                                   0.11182698535093492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30050189010178352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53212734062138545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63374382136833007,
                                   -1.0945666591464005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37578517092927166,
                                   0,
                                   0,
                                   0,
                                   0.25161465668291721,
                                   0.44403594684302694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017920656324515269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057541668651622614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99141593791498139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15143535787806031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86983846838756751,
                                   0,
                                   -0.28960077028619358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061054715278586566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0042735313286327015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10255117722768425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28453440700448274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10535856243925981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4605334406559275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1524520974034615,
                                   -0.49430563720317611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34712798473810286,
                                   -0.11108845511571852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18984667767524191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023149398233110199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25974055503000826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23220019755607285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37352433479892977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00035548871971157435,
                                   0,
                                   0,
                                   0,
                                   -0.27693703026263689,
                                   0,
                                   0,
                                   0.27384911421279878,
                                   0,
                                   0.032028729282207929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38650772100745434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84929726029037234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1964600072220522,
                                   0,
                                   0,
                                   0.7210389716868173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068583411477682724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31571950008115818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46754942831520724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18026792868125643,
                                   0.33799146543690467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11311262393877249,
                                   0.19310168913003289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27159265731097948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25192923158525338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12593447514136583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45409105452760717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21785463339164166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31920333463831668,
                                   0,
                                   0,
                                   0,
                                   -0.11412770318268199,
                                   0,
                                   0,
                                   4.5580921208585035e-05,
                                   0,
                                   0.3412673195712857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40626776862670738,
                                   0,
                                   0,
                                   0,
                                   0.14193767902333107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39943232989597377,
                                   0,
                                   0,
                                   -0.16521269988732523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018406836567622112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53065061776172762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22727069082303153,
                                   0,
                                   0.32202488726529577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59621402736408025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010686437852234332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012083949473708078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1514611695286994,
                                   0,
                                   -0.040425355548385528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18588213879218579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46092102257662443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3103494597173066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15333734053326525,
                                   0,
                                   0.59661512362932545,
                                   0,
                                   0,
                                   -0.11035686310779654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18178747704950013,
                                   -0.16808218053761473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42255122202238238,
                                   0,
                                   0,
                                   -0.024894469124067842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056494047917452266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72591383215479877,
                                   0,
                                   0.9594665576692859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7552898974766149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052486871966928701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058687148833692034,
                                   0,
                                   0,
                                   -0.12530426490212684,
                                   0,
                                   -0.72871284225216826,
                                   0,
                                   0,
                                   0,
                                   0.27585909655216956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5465812785010068,
                                   0,
                                   0.80149281557579155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035822308125858154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69515744810322311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42963639059384839,
                                   0,
                                   0,
                                   -1.0400155669175566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75696096447742245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45073457008577278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21480503618104069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026441447725676609,
                                   0,
                                   0.26978895637338024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079767822578479142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44419949443616957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2479357407622621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39040343439111863,
                                   0,
                                   -0.23182937232993339,
                                   0,
                                   0,
                                   0.039265722633606018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41645536775543224,
                                   0.2235632678669382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1142388543718368,
                                   0,
                                   0,
                                   0.46604604985396492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18415370155871616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1592297225848876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.358408054932572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13779890648354787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14808322647536112,
                                   0,
                                   0,
                                   0.64151962245606808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59141125488706481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10022523041893805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71289777845626889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38188884470508455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25765545702104137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47693297675347351,
                                   0,
                                   0.1897978129308821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12674012435269028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31987808786124478,
                                   0.51878355678267007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27096558644836155,
                                   -0.18108054606989246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29332102605860388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032371699153544195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35499146303178875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25724353946813017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044918123725733783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023301475601779746,
                                   0,
                                   0,
                                   0,
                                   -0.22338731243753698,
                                   0,
                                   0,
                                   -0.36730529336150325,
                                   0,
                                   -0.029608922314521044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23409065227351036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0045195383070364414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97283438514674736,
                                   0,
                                   0,
                                   0.18444342567275934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034262413655126445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.395978915484519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14857682505905079,
                                   0.14012678495302752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22284520450887149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42508244125257738,
                                   0,
                                   0,
                                   0.39909505785009153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46816494255861735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31206274192807271,
                                   0.24699923537241844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11691555754133372,
                                   0,
                                   0.14971959856540173,
                                   0,
                                   0,
                                   0,
                                   -0.055270936228310405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19371778296504424,
                                   0,
                                   -0.36945324422873327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33321292614969639,
                                   0,
                                   0.36057984661433662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40686992561764851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17526182363681947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24976146286892847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41303918720834121,
                                   0,
                                   -0.94637989314842808,
                                   0,
                                   0.17950314373656512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44190395074890237,
                                   0.52784420506557428,
                                   0,
                                   0,
                                   -0.096979532051459205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32659660682925357,
                                   0,
                                   0,
                                   0.65639779571829293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60789495751965894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36144340855754375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0658504830024286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21263470154348804,
                                   0,
                                   0,
                                   0,
                                   -0.65611510134915041,
                                   0,
                                   0,
                                   0,
                                   -0.78944012632658378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041632587613878391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029987522726352384,
                                   0,
                                   0,
                                   0,
                                   0.018934268330327145,
                                   0,
                                   0,
                                   0.039197846936504847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41169179228733443,
                                   0,
                                   0,
                                   0,
                                   -0.021591368121051349,
                                   0,
                                   -0.83034534063698806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5750461069128564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34393700986394904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51303789068074668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22761780728051714,
                                   0,
                                   -0.35264433621662744,
                                   0,
                                   0.052308044241408114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074628987008190872,
                                   0.21305171016234442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18084911257087188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.5705310675214399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33557657713429939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11926598993452575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18080321494613666,
                                   0,
                                   0,
                                   0.41221101902846469,
                                   0,
                                   0,
                                   0,
                                   0.74375944916968229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14225947523100244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35361191340046533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56987698797273467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15360067684709169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46993954292288154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5469966335957317,
                                   0,
                                   -0.08097638041348719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37980151642824944,
                                   0.2446076319691195,
                                   0.10579381520305518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027777037877962239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39448755843917072,
                                   0,
                                   0,
                                   0,
                                   -0.3848143757985798,
                                   -0.078797243017856344,
                                   0,
                                   -0.031637207460662585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19619889800542389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17606113426822068,
                                   0,
                                   0,
                                   0,
                                   0.57045053875056584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028533142728786334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11803733444619076,
                                   0,
                                   0,
                                   0.25177224439716994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39947036222466709,
                                   0.26701576428463475,
                                   -0.082164383885959272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12974207840399604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0076927756167843205,
                                   0,
                                   0,
                                   0,
                                   -0.064704970411190998,
                                   -0.2742556438301994,
                                   0,
                                   -0.55591269686250389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17256993309815113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1678262457016293,
                                   0,
                                   0,
                                   0,
                                   -0.26816624344111473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40123944493137936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18438574561020926,
                                   0,
                                   0,
                                   -0.17941756243794646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13269768062852827,
                                   0.11141089507714408,
                                   0.39399086419768631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17173056812883336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47804980208465053,
                                   0,
                                   0,
                                   0,
                                   0.22234716326222032,
                                   -0.093589930889682815,
                                   0,
                                   -0.18466405135258773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41765065214987429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17392508465677589,
                                   0,
                                   0,
                                   0,
                                   0.18060576656462374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051699931921374086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22940071746024937,
                                   0,
                                   0,
                                   -0.4145249935053148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0031298449302941678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28457497847462376,
                                   0,
                                   0.25660923749614112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010708122363954145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16529494212677548,
                                   0,
                                   0,
                                   -0.27929473334848476,
                                   0,
                                   0,
                                   0.38795174400780219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31845102662933322,
                                   0,
                                   0,
                                   0,
                                   0.078375352086850758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69975427631445397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94889763167740393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086837450502075642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081671253637351171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4642677123437654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42650794618596988,
                                   0,
                                   0,
                                   -0.14437320321668018,
                                   0,
                                   0,
                                   0,
                                   -0.093122321354252996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15443236367720539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097610552891228969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58326825110327163,
                                   0,
                                   0,
                                   0,
                                   -0.60321461120991715,
                                   0,
                                   0,
                                   0,
                                   -0.47410694973717793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38241560558558468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28134335316726666,
                                   0,
                                   0,
                                   0,
                                   -0.068832938032577243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046296179869833018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39909998832767596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21047991513222652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23515466171413454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55823137577593773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14891844748989566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098166751788530252,
                                   0,
                                   0,
                                   -0.14310645607807915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23911953665577271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33791647841658878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68828423525907156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28596740104804896,
                                   0,
                                   0,
                                   0,
                                   0.014372273738683817,
                                   0,
                                   0,
                                   0,
                                   0.29574666348008233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58932089873622628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54596678331342585,
                                   0,
                                   0,
                                   0,
                                   0.99543714142505313,
                                   0,
                                   0,
                                   -0.60049731234881343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1221543243488068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54560267479593405,
                                   0.41197340636661944,
                                   0.077963557575698811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22686476154894594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019663353488727574,
                                   0,
                                   0,
                                   0,
                                   -0.39959700283927507,
                                   -0.027842064312708144,
                                   0,
                                   -0.080375297671710838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22873412340290261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15080095624683984,
                                   0,
                                   0,
                                   0,
                                   -0.1422705992247931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17176229867554835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41250285851631896,
                                   0,
                                   0,
                                   -0.11308346316789306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4268344578990394,
                                   0,
                                   -0.10817668080951329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16098178073664399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62911439628588894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63053333230403119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62259185819237095,
                                   0,
                                   0.19925100096751849,
                                   0,
                                   0.887973080156374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047880027669117753,
                                   0.41426266513236676,
                                   0,
                                   0,
                                   -0.29538733145058627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26319149723156116,
                                   0,
                                   0,
                                   0.67715234296584148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073306396944192248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18566600926934415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64615424438454361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65290372555830722,
                                   0,
                                   0,
                                   0,
                                   -0.66978943047970851,
                                   0,
                                   0,
                                   0,
                                   0.51614959204901478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082061209977201524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45358342746799785,
                                   0,
                                   0,
                                   0,
                                   0.59002701418935155,
                                   0,
                                   0,
                                   -0.59371282392517943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26331799472458156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21195705910496029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36176505224865485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12340714041574452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19172146118525046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95035285031605332,
                                   0,
                                   0,
                                   -0.51842307613425798,
                                   0,
                                   0,
                                   0,
                                   -0.40861662130724496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1482410695311103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6141707473011262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51169360452685875,
                                   0,
                                   0,
                                   0,
                                   -0.025625677449661252,
                                   0,
                                   0,
                                   0,
                                   -0.46834299747203312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37985377716002439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018652820170152032,
                                   0,
                                   0,
                                   0,
                                   0.71297853721453319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28767750540237474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092122242510129737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67514861289577111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06792012329625613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45573865181903378,
                                   0,
                                   0,
                                   0,
                                   0.093293713850998994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21094326194796448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0054870621018843768,
                                   0,
                                   0,
                                   0.080260346514423903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033689178923794388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.009679066910621259,
                                   -0.015550073109166562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18851732067586224,
                                   0,
                                   0.53465275020595415,
                                   0,
                                   0,
                                   0,
                                   0.76556416795120485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17518648258930974,
                                   0,
                                   0.026187779679896286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15642280768628197,
                                   -0.17139125914264081,
                                   0.47073561881845372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23506822086858753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48026380501734223,
                                   0,
                                   0,
                                   0,
                                   0.28942304187262941,
                                   -0.38843748861429939,
                                   0,
                                   0.1983004660145776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13137845561644618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17034548540009556,
                                   0,
                                   0,
                                   0,
                                   0.014674523145385181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24226835257202836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02302654441831287,
                                   0,
                                   0,
                                   -0.24282642411296063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0094372742694026623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12561584993304886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54001667868815184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1430265039079333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24421190912011664,
                                   -0.38052981718978218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4878734122324011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24252185500686171,
                                   0,
                                   0,
                                   0,
                                   -0.48358947444076428,
                                   0,
                                   0,
                                   0,
                                   -0.46910581327870121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18578392632861881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73856105003792671,
                                   0,
                                   0,
                                   0,
                                   -0.6286241815440845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81881885216538108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11999731767664598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23488877703619229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27497776574965854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43086733381145886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0041773367131131556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06445984448007791,
                                   0,
                                   0,
                                   -0.32735767572104474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1852498892134985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83744159120385853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016606487428616031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32900999383357904,
                                   0,
                                   0,
                                   0,
                                   -0.70028762001707956,
                                   0,
                                   0,
                                   0,
                                   -0.74674833778872873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18432102938324746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090982321753831738,
                                   0,
                                   0,
                                   0,
                                   0.48231021525562112,
                                   0,
                                   0,
                                   -0.19964310509202091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26086335408067052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087992672854289605,
                                   -0.16566063428937808,
                                   -0.34189724064015214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26289038389235247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034988874634308401,
                                   0,
                                   0,
                                   0,
                                   0.11946970981385246,
                                   -0.14258933629348611,
                                   0,
                                   -0.14727027271754423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30203607123904219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77540668531085555,
                                   0,
                                   0,
                                   0,
                                   0.054333853791256062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090438878026821476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12557876709359794,
                                   0,
                                   0,
                                   -0.04368730573850186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35970629859315895,
                                   0.2750108920803504,
                                   -0.096278064841712446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26365096135524546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17452953316483233,
                                   0,
                                   0,
                                   0,
                                   0.030427711377741373,
                                   0.081043883293150987,
                                   0,
                                   0.57228135326361329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068901327971749568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30054340548651742,
                                   0,
                                   0,
                                   0,
                                   -0.35182957499635198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26930063382882163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23324005200445042,
                                   0,
                                   0,
                                   0.070406649245802672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25674743285412549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51441637951260832,
                                   0,
                                   0,
                                   0,
                                   0.32703561130701342,
                                   0,
                                   0,
                                   0,
                                   -0.36851133149306692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28866520187088701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15103081519343012,
                                   0,
                                   0,
                                   0,
                                   0.47111924752583406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20150909511857457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041407119064870712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0042531478812355972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53352929047329967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96124277070317043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13374313884731726,
                                   0.31041485186254703,
                                   0.16247494705077345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34281612865481548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088285462750748459,
                                   0,
                                   0,
                                   0,
                                   -0.076572752405474773,
                                   -0.16054367834456004,
                                   0,
                                   0.052903574001229456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41445112840149084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02545841168325174,
                                   0,
                                   0,
                                   0,
                                   -0.0008567241093498483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71429790567618545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0048410029146128408,
                                   0,
                                   0,
                                   -0.13015406266926771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13362823539022467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16441177438820548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57980639684945368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20833472452382082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61449528041865986,
                                   0,
                                   0,
                                   -0.25959477830099298,
                                   0,
                                   0,
                                   0,
                                   0.69016647052299696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27014749921405601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30797346749002219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35223636984560625,
                                   0,
                                   -0.15202044851119664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35016731926916556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12741505322372029,
                                   0,
                                   0,
                                   0.014934360094965864,
                                   0,
                                   0,
                                   0.12792274662084741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69690078213397832,
                                   0,
                                   0,
                                   0,
                                   -0.29561143163671588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17168528234747471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23390282848401026,
                                   0,
                                   -0.21986943308015244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0077215309650242314,
                                   0.54477704652016556,
                                   0.2827459003335091,
                                   0,
                                   0,
                                   0.46486204520270957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54555623727329827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080197715149879459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32995594084592839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13110622933461183,
                                   0,
                                   -0.46442651902045262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24886536997176495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28874582150332656,
                                   0,
                                   0,
                                   0.25903235881690512,
                                   0,
                                   0,
                                   -0.44575533289546043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28721802752470937,
                                   0,
                                   0,
                                   0,
                                   0.19527583642366103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35569325690646741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048287406518686363,
                                   0,
                                   -0.065644924706003693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13014349744855663,
                                   0.10496589059683661,
                                   0.39317064725670137,
                                   0,
                                   0,
                                   -0.37655947146875013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082895389208072517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81372726582441401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30524095903172621,
                                   0.1970554705625357,
                                   -0.073056175306906307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12050285079470094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43331397443928649,
                                   0,
                                   0,
                                   0,
                                   -0.057373544328246762,
                                   -0.51541836895003867,
                                   0,
                                   0.191248769365022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070022448926963632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0073493757812563704,
                                   0,
                                   0,
                                   0,
                                   0.27364337224438662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17193724245553943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41399479055254895,
                                   0,
                                   0,
                                   0.27214351357967226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16729203789731312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12657191748924573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35047512441615025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96524516212859801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5338955788759453,
                                   0,
                                   0,
                                   0.089380917424916551,
                                   0,
                                   0,
                                   0,
                                   0.01674932758551264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94841005227600461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12958235334042253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099174397868637312,
                                   0,
                                   0,
                                   0,
                                   0.74573839561099442,
                                   0,
                                   0,
                                   0,
                                   0.14034128011877353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65524515551205487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60246686524245152,
                                   0,
                                   0,
                                   0,
                                   0.10799506143285102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20337157841904172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37931536538886607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16145124407802769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59920228121986474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.103603615987496,
                                   0,
                                   0,
                                   0,
                                   0.52657050034321562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16474336610094464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055807761741659911,
                                   0,
                                   0,
                                   -0.34082849663287712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12708195614603154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35688130996452222,
                                   0.30298534380490255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41522521112696142,
                                   0,
                                   0.19857119798640635,
                                   0,
                                   0,
                                   0,
                                   -0.27268523162062508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14232662410574037,
                                   0,
                                   0.18583258451465517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46285890320968581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15098663434324749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69458450413530293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49676517927412422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38862537015834109,
                                   0,
                                   0,
                                   0.51203598103298842,
                                   0,
                                   0,
                                   0,
                                   -0.65405698255676781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55908286799649809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2787203410918373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57734401291855386,
                                   0,
                                   0,
                                   0.32822224611844442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75567694679547803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20947236704849928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21538827597791738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56387371079369142,
                                   0,
                                   0,
                                   0,
                                   0.44272439523926022,
                                   0,
                                   0,
                                   0,
                                   -0.20417621906394906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41930195570895828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027874070762186023,
                                   0,
                                   0,
                                   0,
                                   0.22483612226410385,
                                   0,
                                   0,
                                   -0.14521388056037771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49908534078511269,
                                   0,
                                   0,
                                   0.037176066212024905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46253533210339903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22084952684240228,
                                   0,
                                   0,
                                   0.02148148864487219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18233910213763246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56826479711594591,
                                   0.089547855290493916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4934350887947887,
                                   0,
                                   -0.31781683447716375,
                                   0,
                                   0,
                                   0,
                                   -0.04215957948712093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0086196432768288478,
                                   0,
                                   -0.15784276060566352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3056160697083411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36404103599027193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33829447476346802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70457856025229648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35670105101800986,
                                   0,
                                   0.1896396662913914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65801926605318894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29893010275610959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54920118036124799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44649287483945554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022909080429946244,
                                   0,
                                   0,
                                   0.11915547504665508,
                                   0,
                                   0,
                                   0,
                                   -0.016442356184900989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0685254751423379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65685351075908871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37282310058565216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34892890436807167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10591434011297537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1108662267783478,
                                   0.15621299045550782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23712977077334418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31111615735763914,
                                   0,
                                   0,
                                   -0.31845011214008839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25526126844703745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1409787527739217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23425293518841736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091060874712459577,
                                   0,
                                   0,
                                   0,
                                   -0.30909203199363999,
                                   0,
                                   0,
                                   0,
                                   -0.11897085874984133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48061153810878143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5916026304281633,
                                   0,
                                   0,
                                   0,
                                   0.17206682185773151,
                                   0,
                                   0,
                                   0.0035189382179381429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085646242417371843,
                                   0,
                                   0,
                                   0.205360339113308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27244908906714244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098073605979460216,
                                   0,
                                   0,
                                   -0.41114659659557035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59985578005300655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22418397978257601,
                                   -0.28012319056106777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28778965774410831,
                                   0,
                                   -0.14946181209705311,
                                   0,
                                   0,
                                   0,
                                   0.059995396310718367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32784167664581149,
                                   0,
                                   0.011954934350526442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23880789102983513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39045089512052045,
                                   0,
                                   0,
                                   0,
                                   0.28476566546107207,
                                   0,
                                   0,
                                   0,
                                   -0.65778641360683709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22447032274577305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033901943819274291,
                                   0,
                                   0,
                                   0,
                                   -0.16348161801315528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058579842776465954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3193875626834623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41380642687642594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58171087335009519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30772866813404426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27721350054837468,
                                   -0.12129522727409925,
                                   0.24331442940854564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41863055051470927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23792524728342035,
                                   0,
                                   0,
                                   0,
                                   -0.024844474205113792,
                                   0.084389763208673058,
                                   0,
                                   0.28195040815828015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58548781537136574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24880241743036521,
                                   0,
                                   0,
                                   0,
                                   0.25662660473153448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24183873601103989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0045861072249723436,
                                   0,
                                   0,
                                   -0.032871139996762277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0570512035005635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31878730197239336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41570173187112475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67697677474643336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075522716175780533,
                                   0.2845092476575421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0716912931956848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17830822755354453,
                                   0,
                                   0,
                                   0.25012526182465988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020011607374440448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084467996589090433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56594892844259537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29852486654293625,
                                   0,
                                   0,
                                   0,
                                   0.20431814345412344,
                                   0,
                                   0,
                                   0,
                                   -0.15575114671544951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3006695984911204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60010975634762098,
                                   0,
                                   0,
                                   0,
                                   0.075406990047030609,
                                   0,
                                   0,
                                   0.16626980121065077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20049485838400644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19023345167889619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12639560870726713,
                                   0,
                                   0,
                                   0,
                                   -0.20541641967362387,
                                   0,
                                   0,
                                   0,
                                   -0.37308298199671897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60804082866460296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66979752171407914,
                                   0,
                                   0,
                                   0,
                                   0.36705792220786704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2978275351489027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9299061876321848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62411953508136531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1384445725545673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054005132439412407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10076446038546008,
                                   -0.24518325344775549,
                                   -0.36539346200541339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15956808398024819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0761288278272019,
                                   0,
                                   0,
                                   0,
                                   -0.39021044462378623,
                                   -0.40472237059358357,
                                   0,
                                   0.3055049278793881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18271692037273382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18841282281888605,
                                   0,
                                   0,
                                   0,
                                   -0.041365757372255223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10658092551377442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068162449446101503,
                                   0,
                                   0,
                                   -0.51861593558174879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37640056887510698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11148503950931687,
                                   0,
                                   0.31538316125751059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052022995132032727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1653469956005203,
                                   0,
                                   0,
                                   0.035023434077521814,
                                   0,
                                   0,
                                   -0.19058064128824101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38087498654856566,
                                   0,
                                   0,
                                   0,
                                   -0.70887204581839725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17682811949784874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14691042916306138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034016072978163753,
                                   0,
                                   0,
                                   0.49004134645040381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32755319250160964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048217955950102823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81451059260855319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.075163913113846,
                                   0,
                                   0,
                                   0,
                                   0.20129926103990739,
                                   0,
                                   0,
                                   0,
                                   0.083875884031413425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19471359281171352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0978720678210655,
                                   0,
                                   0,
                                   0,
                                   0.2442916937436265,
                                   0,
                                   0,
                                   0.45752161161646582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10763848772406792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36693833729101244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1689223243027589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32802714127849614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55716555065784013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12951570601906864,
                                   0.4029112408925748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10774818263541174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43115262079363709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81122135270879925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30403738403819358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062304984266503695,
                                   0,
                                   -0.21931033188979529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048914409698954248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70353487740474674,
                                   0,
                                   0,
                                   0,
                                   -0.040574995483761922,
                                   0,
                                   0,
                                   0,
                                   0.25062973226922974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20594138166204642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14878720149508212,
                                   0,
                                   0,
                                   0,
                                   0.3179133215120391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80187743918946819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092837216685421581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083089628010418262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27326335738261598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017171884130587747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28897403424010526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39584046093102343,
                                   0,
                                   0,
                                   0.020301343088284282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014497618095233547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024615661968617995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42152869036690027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3384730589770325,
                                   0,
                                   0,
                                   0,
                                   0.70284400423100546,
                                   0,
                                   0,
                                   0,
                                   -0.32383475849684384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87334430480537273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55328152126942054,
                                   0,
                                   0,
                                   0,
                                   0.21254696843858742,
                                   0,
                                   0,
                                   0.50007939152404157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27113635328575303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0043213709809039741,
                                   -0.46741727878752404,
                                   -0.088843238184902876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42190580253629323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25189862167060822,
                                   0,
                                   0,
                                   0,
                                   -0.090669081632546666,
                                   -0.19346209820489818,
                                   0,
                                   -0.21567413230310811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15518014786179724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024147694907660465,
                                   0,
                                   0,
                                   0,
                                   0.15242615706049445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097136305611786503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58246364358408242,
                                   0,
                                   0,
                                   0.20830504681215059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54389142315090233,
                                   0,
                                   0.1098562218736423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22235229729727948,
                                   0.4929395439034191,
                                   -0.28660827396274569,
                                   0,
                                   0,
                                   0.33653550721735032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3001694631705949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33790773199111768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57734341636689945,
                                   0,
                                   -0.19996063839636441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27120162632709477,
                                   0.15137655098311328,
                                   0.19334740188872102,
                                   0,
                                   0,
                                   0.1349921466007839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6888093957750332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01267514066739207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38947646276489561,
                                   0,
                                   -0.35930291301986117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62678898937242489,
                                   0.077161365355285366,
                                   0.37969301680736733,
                                   0,
                                   0,
                                   0.051382951046705677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33975805144645288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24114033248784894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78004343370110463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087915590558446083,
                                   0,
                                   -0.21905257434737094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32383656685791989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16557995976780554,
                                   0,
                                   0,
                                   0.078236791427291882,
                                   0,
                                   0,
                                   -0.079639111811334609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12202412641577856,
                                   0,
                                   0,
                                   0,
                                   -0.41206029662285437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079907796202376868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30950803124570608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41764289506403185,
                                   0,
                                   0,
                                   0,
                                   0.5008326667497065,
                                   0,
                                   0,
                                   0,
                                   -0.66110680812932954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23283294965451623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029159932379583836,
                                   0,
                                   0,
                                   0,
                                   -0.088942404983683901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49808795828725594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3998856038710315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5195004242887411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10564379710265773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11429268100494895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0017292014487166689,
                                   0,
                                   -0.39092253290387519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044868331110127668,
                                   -0.5895544893306619,
                                   -0.12770811633016363,
                                   0,
                                   0,
                                   0.58730452113577736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050787770364265843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36575067868990463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057679938480299495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39892468309320261,
                                   0,
                                   0.15002737388560855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15439686119814447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10893634438661813,
                                   0,
                                   0,
                                   0.86244568789077536,
                                   0,
                                   0,
                                   0.13944983241946413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052854931285893969,
                                   0,
                                   0,
                                   0,
                                   0.10906449446077486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037025168308800205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51803256962394506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30208283620589421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41238400216115462,
                                   0,
                                   0,
                                   0.41094064975742894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033127522463760467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084296778136804709,
                                   0.010520250430343417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020832887797342683,
                                   0,
                                   -0.18059716629303219,
                                   0,
                                   0,
                                   0,
                                   -0.012738571526898983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50979705107975115,
                                   0,
                                   -0.0060604140081934252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36073134061328327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063315455970782919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18048718696556604,
                                   0,
                                   0,
                                   0.0088982576298280644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37732389799526711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42739965793507761,
                                   0.33586569035884795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51316720497930812,
                                   0,
                                   0.12611863455613542,
                                   0,
                                   0,
                                   0,
                                   -0.04438407893384394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033417926652038077,
                                   0,
                                   0.33619414211474841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10360645217496431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53205959113019163,
                                   0,
                                   -0.30000057450617101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14271056613955427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21157820997599547,
                                   0,
                                   0,
                                   0.22807012313022698,
                                   0,
                                   0,
                                   0.66018992702246015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042214835197676798,
                                   0,
                                   0,
                                   0,
                                   -0.24767737658989608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0073081621328724561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33534976973816322,
                                   0,
                                   0.60023376829908348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61642097287031183,
                                   0.054840538509810355,
                                   -0.16069268623549274,
                                   0,
                                   0,
                                   0.29167354510760279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10906036300568606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14658750208482521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80769379261435437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11437604488862756,
                                   0,
                                   0,
                                   0.52607018256781513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41807736897797648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19626992067523458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71472495040541839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0041416081580047635,
                                   0,
                                   0,
                                   0,
                                   0.12032576278804412,
                                   0,
                                   0,
                                   0,
                                   0.029807846413181936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011461211296375501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24496671273579623,
                                   0,
                                   0,
                                   0,
                                   -0.22273457259855631,
                                   0,
                                   0,
                                   -0.10699952531916083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58255554079005167,
                                   0,
                                   0,
                                   0,
                                   0.094097508409806768,
                                   0,
                                   0.050770432590188833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35344052160602402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1069609358574328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32505123690946386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25491246196668749,
                                   0,
                                   0.091118943145197528,
                                   0,
                                   -0.38694516827265152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39783222554382736,
                                   0.13027102291286935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13339533131299114,
                                   0.26583467533089117,
                                   -0.44371019251915372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26318745805408938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063965469728174892,
                                   0,
                                   0,
                                   0,
                                   0.31925904008476441,
                                   0.25957716244468593,
                                   0,
                                   0.039554599578799254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12117261481094571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098063860105529047,
                                   0,
                                   0,
                                   0,
                                   0.50243604718576562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1639342576191655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082133270081499954,
                                   0,
                                   0,
                                   -0.40008353218195841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86573296020725021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066812246405249215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21571640699551403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3862738927942776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20545802451560416,
                                   0,
                                   0.089935960559289055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22284550556521809,
                                   0,
                                   -0.50308641725061976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29182145511610325,
                                   0.26412122293986412,
                                   -0.67797181951823116,
                                   0,
                                   0,
                                   -0.2792614384313965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032055610615879623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060529778839823127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058402036441199193,
                                   0.23478336163508545,
                                   -0.20921971903245457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3571087771408335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16601259884709654,
                                   0,
                                   0,
                                   0,
                                   0.51717194134326094,
                                   -0.40508885988212817,
                                   0,
                                   0.024444501524124085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011079135324517594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24278118455499631,
                                   0,
                                   0,
                                   0,
                                   -0.068823245359710544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14381354834795831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36944901234973371,
                                   0,
                                   0,
                                   0.29911183263419228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14180309141490388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099609974059665596,
                                   0,
                                   0,
                                   0,
                                   -0.11507923584511083,
                                   0,
                                   0,
                                   0,
                                   0.22637311800136123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66751316917883985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35762656828117706,
                                   0,
                                   0,
                                   0,
                                   0.068888839854220021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36940640825140758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2846030557452825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37155012813877619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93694942029935346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15990700612717063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17955927662653251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97100639036812708,
                                   0,
                                   0,
                                   -0.25108879794993022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72129278228434046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087506112993945173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042512989795081405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11293791827186006,
                                   0,
                                   0,
                                   0,
                                   -0.56385264683293534,
                                   0,
                                   0,
                                   0,
                                   0.41218991542928124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49804900351328785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27308449812133562,
                                   0,
                                   0,
                                   0,
                                   0.18702078079738713,
                                   0,
                                   0,
                                   0.072453585392504238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8433276908738162,
                                   0,
                                   0,
                                   0,
                                   -0.30296276514389053,
                                   0,
                                   0.2538185600689476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74010354015433932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2799922281900406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67685143810498016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074575545742771338,
                                   0,
                                   0.3254002416027294,
                                   0,
                                   -0.74551343119197133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078090905884873038,
                                   -0.47164292959382642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018933829591884554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038297683402061515,
                                   0,
                                   0.30547675372150207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36165866474345204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67891407317529162,
                                   0,
                                   0,
                                   0.025500732574922844,
                                   0,
                                   0,
                                   0.15567057095999842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032348464194990947,
                                   0,
                                   0,
                                   0,
                                   0.34316730999677603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4116352780414273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11798879744443441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20103308857967411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089212763016993685,
                                   0,
                                   0,
                                   0.20732310162435158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10574350783253726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10812292438111612,
                                   -0.58826931441510566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025658556892394525,
                                   0,
                                   0.54099588062140458,
                                   0,
                                   0,
                                   0,
                                   -0.47165486220549163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023411382216220515,
                                   0,
                                   -0.097201886108800845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27890910056175355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66319648714512891,
                                   0,
                                   0,
                                   0.41843516039861556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67947547790663121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26837222947398065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50153330367972371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13424084755853924,
                                   0,
                                   0,
                                   0,
                                   -0.58277158645610361,
                                   0,
                                   0,
                                   0,
                                   0.049213709688848209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27653421144125656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51198397975688614,
                                   0,
                                   0,
                                   0,
                                   -0.49095803227953227,
                                   0,
                                   0,
                                   0.39884184372862697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14177703453021048,
                                   0,
                                   0,
                                   -0.19534223704650516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037924801379742891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44422635283197803,
                                   0,
                                   0,
                                   -0.25397836083389874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056261717168947623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019458471122489579,
                                   0.46986328057319426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24450422809886468,
                                   0,
                                   0.34689825138293567,
                                   0,
                                   0,
                                   0,
                                   -0.15147388714291313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17950699866622868,
                                   0,
                                   -0.48883302749340507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089065089601485986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55636177005232368,
                                   0,
                                   0.58304401950766782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16452712786053067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012125889899839259,
                                   0,
                                   0,
                                   0.22303975172595908,
                                   0,
                                   0,
                                   -0.21724588919997953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28499777645423163,
                                   0,
                                   0,
                                   0,
                                   -0.064963015200192195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3646724774300153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28105821058711739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3356387007094942,
                                   0,
                                   0,
                                   -0.2043958870220291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28374916547091178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20723064664608906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56963407519827214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11050538700425439,
                                   0,
                                   0,
                                   0,
                                   0.19181834970111536,
                                   0,
                                   0,
                                   0,
                                   -0.55814533328212002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00026680068559947756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0049958833570003594,
                                   0,
                                   0,
                                   0,
                                   -0.55936152225696734,
                                   0,
                                   0,
                                   -1.1592985014263111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25276773465482122,
                                   0,
                                   0,
                                   0,
                                   -0.75644884818722224,
                                   0,
                                   0.42636014354935636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37196804928388044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0016340994260634067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21610671338209123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1158154433016341,
                                   0,
                                   -0.11084417509755519,
                                   0,
                                   -0.022707156356772007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71566066380407545,
                                   -0.058036238784933109,
                                   -0.3226794302311668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25994571195460353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29075056973485225,
                                   0,
                                   0,
                                   0.0064404129938702686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3355333626922048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32968168641476953,
                                   0.094341708914117223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2075079933512973,
                                   0,
                                   0.23656045647787788,
                                   0,
                                   0,
                                   0,
                                   -0.12306630263227593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043980685185449869,
                                   0,
                                   0.63044095453666882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36179348226204139,
                                   0,
                                   0.078846822973486663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1449338698810419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022803275214880181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13712610458700053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75725473431610124,
                                   0,
                                   0.14300000419957165,
                                   0,
                                   -0.41427608162792029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50590578961754251,
                                   -0.011386432894552861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15418860353326488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066077756407314919,
                                   0,
                                   -0.04619511658960989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71111661222439948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54827790656431752,
                                   0,
                                   0,
                                   -0.03317308536777086,
                                   0,
                                   0,
                                   -0.25503319569923716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28917557567514218,
                                   0,
                                   0,
                                   0,
                                   -0.028672725080748529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11332737362113623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54020042407787983,
                                   0,
                                   -0.094807632057537283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14657676329909441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14868214205828792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58236146386535559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18853187732899962,
                                   0,
                                   -0.1512321290052219,
                                   0,
                                   -0.76748333416334702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10120963221281565,
                                   0.67648819807179195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07843719052420961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48607579848332738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039067307471675375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20227752137269756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5446916747492897,
                                   0,
                                   -0.64687437309303908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47117833871483294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5950576633476079,
                                   0,
                                   0,
                                   0,
                                   -0.091832794295375303,
                                   0,
                                   0,
                                   0,
                                   0.069942360829620714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42772940352398647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30877348088542206,
                                   0,
                                   0,
                                   0,
                                   0.9485077648768957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12792549963452127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082068756895279676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070125520631607582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057893122937775349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30237068082325869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11959017739561767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34071718790825845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39474520208077257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012784038106726084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48039058233285048,
                                   0,
                                   0.69487241242128417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093227978458881255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54151311458025053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053807211874622826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5396879677106754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80900073806493422,
                                   -1.1583377024762402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80848274464997583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54594030944519101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82377321709877926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089696736930141713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57538868445713531,
                                   -0.59833015802570921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19874323631277888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1451797384013212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5064933064165752,
                                   0,
                                   0,
                                   0.15261096975062796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25263365141070226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041478864589289954,
                                   -0.055850646145835216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25194010303464243,
                                   0,
                                   -0.090849996116704107,
                                   0,
                                   0,
                                   0,
                                   0.21560235557964472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68693437919299083,
                                   0,
                                   0.029053140565760333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094033419948827968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59384341833863397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30804922678780716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51034983301305337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32476268070227332,
                                   0,
                                   0,
                                   -0.73650877654459002,
                                   0,
                                   0,
                                   0,
                                   -0.082518823798436308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29295919841185958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23799930382299239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60396252288527119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093615359544461138,
                                   0,
                                   0,
                                   0.49884216878166066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19036299760764297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29953202012869673,
                                   0.26209398134145762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14604886474775969,
                                   0,
                                   -0.056593522595585449,
                                   0,
                                   0,
                                   0,
                                   -0.14818218287612239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19073016874683388,
                                   0,
                                   0.20846689461500634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82999674168931636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13153092023326246,
                                   0,
                                   0,
                                   0,
                                   -0.38836889207927222,
                                   0,
                                   0,
                                   0,
                                   -0.15699379487429888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09225929267182266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32582035612802729,
                                   0,
                                   0,
                                   0,
                                   0.24042900265167527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46726520206253741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84889831329752197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37054904892330881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0073929070623438634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17448742374521023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20537169418186049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31141646502183151,
                                   0,
                                   0,
                                   0.038675982033785083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14521237348485277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23004726792497854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13091675641072389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12519028511578756,
                                   0,
                                   0,
                                   0,
                                   -0.16021615926422128,
                                   0,
                                   0,
                                   0,
                                   0.16318079544826447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76116763707661383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19505943923460889,
                                   0,
                                   0,
                                   0,
                                   -0.70671512143281567,
                                   0,
                                   0,
                                   -0.15197825098903905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71458978537685169,
                                   0,
                                   0,
                                   0,
                                   -0.020522830455393704,
                                   0,
                                   0.099206463418648333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46966705153891447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068075467598344111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10860497718230372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38512562860692928,
                                   0,
                                   0.73925911121539778,
                                   0,
                                   0.32962371170977633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65202213218463312,
                                   0.51676083146525342,
                                   0,
                                   0.0084682490671265029,
                                   0,
                                   -0.79474304763771808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41841631727297568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23040956969239546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54333185407821427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11734276868507668,
                                   0,
                                   -0.88687707163880714,
                                   0,
                                   0.22726908595511477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61531371746736241,
                                   -0.27497993407023497,
                                   0.55496844136140078,
                                   0,
                                   0,
                                   0,
                                   -0.87455770706504321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36913607108245505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15221029277767958,
                                   0,
                                   0,
                                   0,
                                   0.47846491578806982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50210801401732541,
                                   0,
                                   0,
                                   0,
                                   0.12058868557395611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42513360096949232,
                                   -0.31359777269321865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13460535505756308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32059051733944366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12584287604546307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45368020227851175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13915087295140588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4679669168262377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29709745835975071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36306314379476906,
                                   0,
                                   0,
                                   0,
                                   -0.30170800688517563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24078847153317059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18583306927747029,
                                   0,
                                   0,
                                   0.33200032671374258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12099583091211444,
                                   -0.12194327540436276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46471297903657016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14390277775998997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031367925443266692,
                                   0,
                                   0,
                                   0,
                                   0.13718000077395026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59136583931624254,
                                   0,
                                   0.71708838591412705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27980728307720792,
                                   0.0012629957910999445,
                                   0.19737939974353635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47234399413587697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49750057239164891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79946203923242831,
                                   0,
                                   0,
                                   0.17335799690365084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44041845020884551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5096854139968523,
                                   -0.11219539448679426,
                                   0,
                                   0,
                                   0.41493981843726713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19023120478812733,
                                   0,
                                   0.14738391151912322,
                                   0.52268240261028676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21834126598490866,
                                   0,
                                   0,
                                   -0.40902684526200761,
                                   0,
                                   0,
                                   0,
                                   0.19549878007907578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088521537812708384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18543303118970361,
                                   0,
                                   0,
                                   0,
                                   0.71621875953038872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83767030363082395,
                                   0,
                                   0,
                                   0,
                                   -0.17243388879406837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35512236077192749,
                                   0.42711704209891982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15465795750025063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059237424648324322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5770538966607901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37811211525731236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01621303915720565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19618501268523772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23865212483232315,
                                   -0.046601537969775786,
                                   0,
                                   0,
                                   -0.48716432828361833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058504188595438794,
                                   0,
                                   0,
                                   0,
                                   -0.010167003105124476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48797627517203496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037182438385750582,
                                   -0.12486091102696592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020005630340720726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087570185806794321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59127313188886321,
                                   0,
                                   0,
                                   0,
                                   0.22014859296154957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017262730387574587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26345096973998833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039283524357908564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48586139870063677,
                                   -0.22087293641605241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026238090618880938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34125921271080117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09951881910438283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073234738110830963,
                                   0.70223313231224793,
                                   0,
                                   0,
                                   -0.13659888897868383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93491441794818086,
                                   0,
                                   0,
                                   0,
                                   0.45508099811215152,
                                   0,
                                   0.4756416626287982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50135814782204435,
                                   0,
                                   0,
                                   0,
                                   -0.50158511455215926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34690692969001818,
                                   0,
                                   0,
                                   0.2143898091228143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46490047690683767,
                                   -0.17255095326906128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19316436703416112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72130999260860862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33388974702393981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4345954764238768,
                                   0,
                                   0,
                                   -0.48123209638596076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65552372499553913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34969500150160859,
                                   -0.26066977981388417,
                                   0,
                                   0,
                                   -0.40777201199391722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12057455010146567,
                                   0,
                                   -0.29764152307782499,
                                   0.57804075843392722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19475007977851566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89811037494712009,
                                   -0.73129155718231598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034735237249415525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32734648557790436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52100304679749243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56830862319788433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5317698399756936,
                                   0.089703924607408447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20916944075405183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094681684269061525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28319297748021255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.874761219530791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27300363268378652,
                                   0,
                                   0,
                                   0,
                                   -0.0032864437293550763,
                                   0,
                                   -0.34258267158788402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2402128279918673,
                                   0,
                                   0,
                                   0,
                                   0.54303732428833984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33721642383382627,
                                   0,
                                   0,
                                   0.38671833797966149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50155282200591877,
                                   -1.1318771656214712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10495028389541333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52700701911799197,
                                   0,
                                   0,
                                   0,
                                   0.17038126625429645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54216403186620621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5943104022268989,
                                   0,
                                   0,
                                   0,
                                   -0.00071332725845921208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09408606524120211,
                                   0,
                                   0,
                                   0,
                                   0.16158563113996741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7537754490867008,
                                   -0.193382283538268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012742330582488554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7253836950444944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21383818488115791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074099664736331033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2535757006650875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63362164414605948,
                                   0,
                                   0,
                                   0,
                                   0.16010573491799399,
                                   0,
                                   -0.054150332059104495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57458392716767404,
                                   0,
                                   0,
                                   0,
                                   -0.22857606219824875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67062992698077772,
                                   0,
                                   0,
                                   0.14245236835892636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52223313196154186,
                                   0.61108773784849735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5458246015397521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55936078927150845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35453377540447928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30783185409109176,
                                   0,
                                   0,
                                   0,
                                   0.35776890144650036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25372877746671679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019160185094954277,
                                   0,
                                   0,
                                   0.092328009950644024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039039359368096813,
                                   0.47648553488761242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17263528147678442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016284573320125617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082229808358888518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31540625319595084,
                                   0,
                                   0,
                                   -1.2173234704673339,
                                   0,
                                   0,
                                   0,
                                   0.42423612406879407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10601940940494475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37349378928727855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32000169432739767,
                                   -0.7132097301821736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31629242559122817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081808001312222364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22172046134068052,
                                   0.46631641919343464,
                                   0,
                                   0,
                                   -0.080776602778889262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028537011793282278,
                                   0,
                                   0,
                                   0,
                                   -0.59748693352705673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15589120076584195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077809057346963084,
                                   0.075187626887460723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15652711143932302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06788144989164932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31142507035047812,
                                   0,
                                   0,
                                   0,
                                   -0.37222471561422044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24841838190924326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27274019971634056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059329473808210451,
                                   -0.53463498025702805,
                                   0,
                                   0,
                                   -0.11086619376422213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13800170791897343,
                                   0,
                                   0,
                                   0,
                                   0.014362265385912794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36613423403818296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073817198826082314,
                                   -0.46978144283659323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18865239992708263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32141353651223092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1049911624832138,
                                   0,
                                   0,
                                   0,
                                   -0.22443121832179333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21030789402006372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38681427614373209,
                                   0,
                                   0,
                                   1.0149461754063143,
                                   0,
                                   0,
                                   0,
                                   0.53320846333056182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86423597924201401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71712677963400828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23603128012822006,
                                   -0.42439293664526512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60522040927207443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4893732611122692,
                                   0,
                                   0,
                                   0,
                                   0.47505439873057392,
                                   0,
                                   -1.0604865870332367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49760566014827351,
                                   0,
                                   0,
                                   0,
                                   0.56219837915664395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46013344699431691,
                                   0,
                                   0,
                                   0.16501523717530145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20014263082861083,
                                   0.13509001575943119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12549037760288201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24862277044721082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24709591682362919,
                                   0.33842155159167875,
                                   0,
                                   0,
                                   0.045750254546712214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49614056379075583,
                                   0,
                                   0,
                                   0,
                                   0.11974804828960302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15321431987821127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41498735993999714,
                                   -0.3369915883568016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13474421859533742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020308736459774279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20282245847336228,
                                   0,
                                   0,
                                   0,
                                   -0.36162424349686345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016824972730690911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091250282689162701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12676439976351056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60355471658164328,
                                   0.20203664339130967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3078788055430442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055643126015202243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26965802781829162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04853332798719448,
                                   0.57570589733195199,
                                   0,
                                   0,
                                   0.25712514305384188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27448505497801706,
                                   0,
                                   0,
                                   -0.32926196937916896,
                                   0,
                                   0,
                                   0,
                                   0.64159415202136461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70183302155291527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53036777660041967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12434494134799005,
                                   0.83354304228988285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0050210982773531282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34598107252139088,
                                   0,
                                   0,
                                   0,
                                   0.40071210018978548,
                                   0,
                                   -0.057389594698023919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48724725984935635,
                                   0,
                                   0,
                                   0,
                                   -0.31510729313618313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34395295988834146,
                                   0,
                                   0,
                                   -0.57512095642514027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16948278661476351,
                                   0.29754630781102681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1072460976557408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84670389364960719,
                                   0.20188753873265577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4015210764727527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31783213296098306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51556694312682461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73787787249426906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51242960197896226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15352422267532526,
                                   0,
                                   -0.1702651975222568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22479043070494764,
                                   0,
                                   0,
                                   0,
                                   -0.26570757632557229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21111413773347001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57240436581763554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43761717010300866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44982256804491572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12323170991953579,
                                   0,
                                   -0.20998372157946979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46767230622936573,
                                   0.42173578259957811,
                                   -0.58463833545248822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39861706821421966,
                                   0,
                                   0,
                                   0,
                                   0.054237000602101931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8866913563839145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64850940171055138,
                                   0,
                                   0,
                                   0,
                                   0.045602581646710501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39871463081122832,
                                   0,
                                   0,
                                   0,
                                   -0.102150904588152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027598754229744865,
                                   -0.58749569965447157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076197218481601672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49691372947515766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1276138274812377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22341612081051421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012216569535625417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23563356772608118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36804873043528319,
                                   0,
                                   0.022851445502008613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23544285280994992,
                                   -0.53304303641884032,
                                   -0.68478211834877056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20069510840542429,
                                   0.01831238613517297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21130749835636478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3912532447719539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80574974407136468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058243883120502493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70400972327723266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22287115849741507,
                                   0,
                                   -0.175651319244849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01159431852985366,
                                   0,
                                   0,
                                   0,
                                   -0.18631171063510599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055547719000156759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26299167695708719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56280433306070621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15756560022840002,
                                   0,
                                   0,
                                   0,
                                   0.16001019463174782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45371407509245082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035224134527481139,
                                   0,
                                   0,
                                   0,
                                   0.46103390106232933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21891244681227373,
                                   0,
                                   0,
                                   0,
                                   -1.0017524974700052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082731842501280059,
                                   0.016064337602879047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28428963232619325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35935660429373961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53794648997505534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067442493400676859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13663755996722832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037914393859228311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67043459068766176,
                                   0,
                                   -0.079239642643296859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32224434594301316,
                                   0,
                                   0,
                                   0,
                                   0.38951980091384741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35594286765201855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.399467959934307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031047826637103551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30366734866780221,
                                   0,
                                   0,
                                   0.38216164963786414,
                                   0,
                                   0,
                                   0,
                                   -0.59860146489275601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94885630904623008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35667924576676874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46204742447597213,
                                   0.028088544068140098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57233621966850734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48878409169144871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18607391921311361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1254105256786105,
                                   0.39914715580318783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10903061748437967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43523220324576195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18205001001492155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49322298912536316,
                                   -0.27052817100076992,
                                   0,
                                   0,
                                   -0.022560931211860199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075694594963001377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33789701698665187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0057950494152819582,
                                   -0.29702900644433816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43616627422208787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52066375750844007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.282341386914711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47785685875170003,
                                   0.065309679295417866,
                                   0,
                                   0,
                                   -0.13481529347818511,
                                   0,
                                   0,
                                   0,
                                   0.4022853189297233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42717711526549207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076394684510438723,
                                   0,
                                   0,
                                   -0.83323175519260695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64240856949132974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30962470439390399,
                                   0.50316677641715812,
                                   0,
                                   0,
                                   0.076707461012057165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11822934689287042,
                                   0,
                                   -0.083897348443978337,
                                   0.14338396878581891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29213184810976922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39840466888175957,
                                   0,
                                   0,
                                   0,
                                   -0.27437418523086621,
                                   0,
                                   -0.67642418228122914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91563059334493724,
                                   0,
                                   0,
                                   0,
                                   -0.99448636645118538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1159512210072766,
                                   0,
                                   0,
                                   -0.37886103010550082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32762648357240992,
                                   -0.42763424528480964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0012083063750521761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46290862145088096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10140229965131334,
                                   0.15014607128173627,
                                   0,
                                   0,
                                   0.080405032122345177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2315661741507366,
                                   0,
                                   0,
                                   0,
                                   -0.099146910579306607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36442795312388315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16749114456283262,
                                   -0.47697189625877817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0748410412102756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016659118425879315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31394863107491922,
                                   0,
                                   0,
                                   0,
                                   0.39022330958807888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19465733659465878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43804302739619744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29884988591688566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26506036042203224,
                                   0,
                                   0,
                                   -0.47689370303407741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11824917824827647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033629603783204579,
                                   -0.32881574377148987,
                                   0,
                                   0,
                                   -0.86057982532125099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067276592230132354,
                                   0,
                                   -0.93305536563978086,
                                   0.29598836149515373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30234360072067823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29406553077666681,
                                   0,
                                   0,
                                   0,
                                   0.4929187823387558,
                                   0,
                                   -0.12751034715322271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71851696332962633,
                                   0,
                                   0,
                                   0,
                                   -0.63147798649797338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20589273129275776,
                                   0,
                                   0,
                                   0.38419421276603433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32756617718105541,
                                   -0.37067177150303082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76475457431175908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22230323565046015,
                                   0,
                                   0,
                                   0,
                                   -0.038660702796229421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39541673240782221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24745807875700304,
                                   0,
                                   0,
                                   0,
                                   -0.037167212794709997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40735141030365191,
                                   0,
                                   0,
                                   0,
                                   -0.23610815950126443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47719847155426542,
                                   -0.32779596838852809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48150413918669727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049948091289804417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10570721723489916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92128559839789725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1152625849631873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062601140546011957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019752590167569462,
                                   -0.12838857096172709,
                                   0,
                                   0,
                                   0.17588305795362577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5635039570253273,
                                   0,
                                   0,
                                   0,
                                   -0.39761617045621522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28348298296678831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.337011060114626,
                                   -0.24825501645059642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34411727733655362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19212274361111348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051377722490047101,
                                   0,
                                   0,
                                   0,
                                   -0.13848587134488219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19980406150780264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0200807137279332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23505222884204696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1667394259409242,
                                   0,
                                   0,
                                   0,
                                   0.074160824019828278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.201356247283413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22376465988465555,
                                   0,
                                   0,
                                   0.29345009435468489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48903609114637164,
                                   0.22278323029310662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28308820535368201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34705561448914962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49491639067388077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33165146629089165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47961836603902347,
                                   0,
                                   0.0047863865322791133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27368654248268098,
                                   0,
                                   0,
                                   0,
                                   0.66013999870236617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25785905457163572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24516082745635939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15055349083487429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43911868450501468,
                                   0,
                                   0,
                                   0,
                                   0.090418364338391732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1338794854487266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14444628924357489,
                                   0,
                                   0,
                                   0,
                                   0.080919252575273826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11504253619645044,
                                   0,
                                   0,
                                   0,
                                   0.57540356156486228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16457909928055053,
                                   -0.37366712335295327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69590403258252453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27873850899500918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55503470598804772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23648086820857023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51013677160400517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2157585598583009,
                                   0,
                                   0,
                                   0.25920953492027426,
                                   0,
                                   0,
                                   0,
                                   0.20974496832093073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23230980947520941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82475792381091029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61867427010786191,
                                   0.20413156599550547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2575745888388824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16661104797724974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25599524401360491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0066108436067255152,
                                   0,
                                   0,
                                   0,
                                   -0.028414186683088927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23596922424130734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10482792453615164,
                                   0,
                                   0,
                                   -0.21100885845417688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086163047566562664,
                                   -0.1863481553245144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0032576339358188384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73988639304209225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45284525506186324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0035972835015832122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1964164566692817,
                                   0,
                                   -0.72067740218930276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39218211043087636,
                                   0,
                                   0,
                                   0,
                                   0.31948402080823429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32114575405541745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16279238599872706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2377370679843184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43100426944701892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47860969787613628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16661801231636084,
                                   0,
                                   0,
                                   0.6993033004972069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028915608060362502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38841258231697268,
                                   0.057184484110288585,
                                   0,
                                   0,
                                   -0.45233002403102607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4331176590961292,
                                   0,
                                   -0.22312156838297956,
                                   -0.48646616251225527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50077459335147634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025380203408616513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14040226522622079,
                                   0.27809714916302014,
                                   0,
                                   0,
                                   0.14340490975731984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23656032201900271,
                                   0,
                                   0,
                                   0,
                                   0.18682631997044225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13249128461098245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52560856960080671,
                                   -0.34344774656103827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26988019069266223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15947772958755724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032266630526144938,
                                   0,
                                   0,
                                   0,
                                   -0.22011176345600111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48097998494561234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10453317173621327,
                                   1.0475734611537961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28027182869179257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70924270743596818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57139992077308888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23527977827729024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19477101399986815,
                                   0,
                                   0,
                                   0,
                                   -0.25087033247439716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20179624263692691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44170301628255776,
                                   0,
                                   0,
                                   0,
                                   -0.41873128082201244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1431009113160614,
                                   0,
                                   0,
                                   0,
                                   -0.073551091163474205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20674599841418667,
                                   -0.2362542966980801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38801287989752686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54822815910173817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36930172276330803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67621287889663306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.105048122568807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023875669194974244,
                                   0,
                                   0,
                                   0,
                                   -0.7129714655539755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47737059001572629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15300102298729437,
                                   0,
                                   0,
                                   0,
                                   0.15762276194504984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57860755478177195,
                                   0,
                                   0,
                                   0,
                                   0.30963633558371711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1045607375188254,
                                   0.073729616606824727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77028616698772456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46161980784267381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37852611286226268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14275480346463032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97976202100644538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25828498896651847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45053729204999282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12470125011094384,
                                   0,
                                   0,
                                   -0.00046668699329173446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14656004177031312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050030100147408434,
                                   0.56511427658402869,
                                   0,
                                   0,
                                   -0.15087470939179787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25501758233820193,
                                   0,
                                   0.26675228671936951,
                                   0.48777177758828938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85888331467583579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0045170549714545639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24589373689827437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12622394537356516,
                                   0,
                                   0,
                                   0.43381425894136216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29929934633451671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28601794610411291,
                                   0.27126817035959988,
                                   0,
                                   0,
                                   -0.14277734906118392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8823866598584198,
                                   0,
                                   -0.49387678924802181,
                                   0.60195818647918042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27210451828328697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00022613176684742591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18093870922939237,
                                   0.12221372665204908,
                                   0,
                                   0,
                                   0.30898247186621042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094347890449848176,
                                   0,
                                   0,
                                   0,
                                   -0.10023032630671901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21654732459698839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026494107333249209,
                                   -0.28272551564114834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46756410526383663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2358139038229537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20260554699481476,
                                   0,
                                   0,
                                   0,
                                   0.34071590255739703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52822154851556913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30942954584198701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081048585651635335,
                                   -0.044182554171790678,
                                   0,
                                   0,
                                   0.34468669274501873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065093168658792042,
                                   0,
                                   0,
                                   0,
                                   0.19897602953838522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2328552100787136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42697776308247631,
                                   0.27600200158366162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30958667999062012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39559660184982304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37888818647677153,
                                   0,
                                   0,
                                   0,
                                   -0.15401016323350389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027753410219880578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56251151780107478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05092416690723172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75869618107129344,
                                   0,
                                   0,
                                   -0.19660911089247585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86326969329579128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5072412296378882,
                                   0.23642439318987299,
                                   0,
                                   0,
                                   0.10131230389142924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23083745759966773,
                                   0,
                                   -0.072964843013274619,
                                   0.39861771864180051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29819845458850769,
                                   0,
                                   0,
                                   0,
                                   -0.0090096052455708071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022534844657863651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017834137433256125,
                                   0,
                                   0,
                                   0,
                                   -0.12654866773481865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2167927990644794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14310793748681994,
                                   0,
                                   0,
                                   -0.46537765442463841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11765439910433506,
                                   0.35484117608721777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55224513407269626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17343842450952646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47351096313762786,
                                   0,
                                   0.20884035282150026,
                                   0,
                                   0,
                                   0,
                                   0.68713482894797107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2679696843945738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18450067134932949,
                                   0,
                                   0,
                                   0,
                                   0.66744867773058092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10790215590362309,
                                   0,
                                   0,
                                   0,
                                   0.12696723139472271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48668834896006985,
                                   -0.83431727734683869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69115764857311357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070656909498935105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26568049875873412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033242313045117267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20637726908520829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44216953092290018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47095071524134985,
                                   0,
                                   -0.55314384214082657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44507471705790375,
                                   -0.053326271568406462,
                                   0.27529661210261736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57684631685376941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11860787869221176,
                                   0,
                                   0.17306997684789147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28010265030210191,
                                   0.71302286911198909,
                                   -0.19070441624485718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44164755074773843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51359333787625572,
                                   0,
                                   -0.32441881559602997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60910439410115436,
                                   0.16357613739802029,
                                   0.19533673657437856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29549938743495352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17006554043356908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19843223388220427,
                                   -0.30223002226521867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29355348682318128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38121328486481221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47312929761614192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22471421563198518,
                                   -0.17085331526249417,
                                   0,
                                   0,
                                   0.46690855816842408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42648030189113917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28221461819550242,
                                   0.37363231978426303,
                                   0,
                                   0,
                                   -0.15511584959390801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39770794732604958,
                                   0,
                                   0,
                                   0,
                                   0.30919315565540617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18432613597268915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39443341238300378,
                                   0.021826036473050401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18036664601263594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013334599235318084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0054653379644609215,
                                   0,
                                   0,
                                   0,
                                   0.27714824672143656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14647262248371845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22016402317696673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25769578988214914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19911120965568563,
                                   0,
                                   0,
                                   0,
                                   -0.69132074708617586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028611588006109908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33759502665758573,
                                   0,
                                   0,
                                   -0.084403445927580076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1693011103890224,
                                   0.29321237454237126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27696799872812616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053991791136053201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22666124181984959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41745291870409623,
                                   0,
                                   0,
                                   -0.21371296211960142,
                                   0,
                                   0,
                                   0,
                                   0.035261107227802652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36138359151552357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0768104920305626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5926407791311944,
                                   0.82760922082224808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38172143986952101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87678550908031772,
                                   0,
                                   0,
                                   -0.056301875222836917,
                                   0,
                                   0,
                                   0,
                                   -0.55465035002019936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049004072529693812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50602743652303184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0725071076032586,
                                   -0.22365180652092867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30994599358468244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50190995715103703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30381270796604093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52790450692361612,
                                   0,
                                   0,
                                   0,
                                   0.28680537750214541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11619531153750572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1879334905220868,
                                   0,
                                   0,
                                   0.27794044962939607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091956261037262121,
                                   -0.10878370377763133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2313804531944732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30759207552729212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018244242216747253,
                                   0,
                                   -0.49184730952482841,
                                   0,
                                   0,
                                   0,
                                   -0.83142836713068613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2845071466539501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023000720320624952,
                                   0,
                                   0,
                                   0,
                                   -0.048990143365755412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60943773053226769,
                                   0,
                                   0,
                                   0,
                                   -0.23007639940803334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40363098945529963,
                                   -0.49050593646165069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30243409049478015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19688287617126934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097655564835786468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27205781052872063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02969225197921891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38301178479981951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072377514304419216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30647626098045483,
                                   -0.57074514343714156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48369690718430758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086949071155655075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30934984798542947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28071881242870483,
                                   -0.082802111203245571,
                                   0,
                                   0,
                                   -0.074204731060473789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11179178854780529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39227157130909363,
                                   0,
                                   0.17468187914761124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21943198036949627,
                                   0,
                                   0,
                                   0,
                                   -0.24290595996974235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075267885016220698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57360211512186376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60106032232101592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19165187392514735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22852360546865721,
                                   0.10693478131636769,
                                   0,
                                   0,
                                   0.19196260806387005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017449371884964586,
                                   0,
                                   0,
                                   0,
                                   -0.094322938458369629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24718055469369993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15690007172483175,
                                   -0.10066945438733675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38371597549666309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68350775016887944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083206468464201044,
                                   0,
                                   0,
                                   0,
                                   0.33163791148521704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16242696827403508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19331998410650839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098395941093537734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20055588882519801,
                                   0,
                                   0,
                                   0,
                                   -0.14659108483765304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36586525598092356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48569480477811755,
                                   0,
                                   0,
                                   0.41708862925818307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37321784546499692,
                                   0.20771802718328414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36516069210944596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046877437995962903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17186068195127574,
                                   0,
                                   0,
                                   -0.096387010114416097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31203349507007594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017102166285874097,
                                   0,
                                   0,
                                   0,
                                   -0.022373079716409595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69201646147629314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34501178816281464,
                                   0,
                                   0,
                                   0.35185226918988616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31004011305433132,
                                   -0.094848626142611012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.142513174045371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15272709994532657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14857645092768398,
                                   0,
                                   -0.054614246460960747,
                                   0,
                                   0,
                                   0,
                                   0.065940348827582929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16831311718154002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068177626265911437,
                                   0,
                                   0,
                                   0,
                                   -0.51034246880159206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026317572628385806,
                                   0,
                                   0,
                                   0,
                                   -0.45283531521901838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55941864889243742,
                                   0.031059716109284749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23537124736616483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57857133014726991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52724822238892488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29896111869921871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55093453457815955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49563496075729413,
                                   0,
                                   0,
                                   -0.0047038505227802035,
                                   0,
                                   0,
                                   0,
                                   -1.1906460141512785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32789211611070856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39624904016362167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34925717731967171,
                                   0.21029651960409657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0948295042445937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27451522376137105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053664820592311001,
                                   0,
                                   -0.27172611826197413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74800592117963716,
                                   0,
                                   0,
                                   0,
                                   -0.039302520939017149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46011752518774046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1621655520235708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22104987240070978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66250983988687673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046089136158206423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012852347588848035,
                                   0,
                                   0,
                                   0.027832715370453925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35673376182553523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35794685887460365,
                                   -0.35353807804158555,
                                   0,
                                   0,
                                   -0.56396484386960144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.596944454005777,
                                   0,
                                   0.81941273269153314,
                                   -0.098268504617170432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24068620477347424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32621698070133892,
                                   0.32746670234737646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2174166683189322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36191543256752073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60565314709649787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46699277892141189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49301309678327476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27728973884303593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35663924575196132,
                                   0,
                                   0,
                                   -0.11528550235734053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39846913025353958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37901711703255136,
                                   -0.25185122529322895,
                                   0,
                                   0,
                                   -0.34390233146307003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57230810201234794,
                                   0,
                                   0.5593577342245255,
                                   0.756154179369249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35562991625452167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029981717353776687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12049597885539758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019751969552120455,
                                   0,
                                   0,
                                   0.23922496682910163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13173394655503504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8661735376990034,
                                   -0.65419305041317155,
                                   0,
                                   0,
                                   0.55550471842709981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60834071097216524,
                                   0,
                                   -0.10253346503578291,
                                   0.49520479922500354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14567408541711671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28986303609473696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087924428480059297,
                                   -0.20459361462122874,
                                   0,
                                   0,
                                   0.088307949240304065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26862038253915849,
                                   0,
                                   0,
                                   0,
                                   -0.50122388040834398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02772087395653014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11565616986596786,
                                   0.15527000912967615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38551560848783084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11863340577051733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13930921849157746,
                                   0,
                                   0,
                                   0,
                                   0.24602361189429892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50430662140972238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090132051300567256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089768577728865387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45356259644006025,
                                   0,
                                   0,
                                   0,
                                   -0.20955507614744442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25319609338262289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41802939899657038,
                                   0,
                                   0,
                                   -0.1749466037168162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23350258143701563,
                                   -0.42351449021364868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22815586231680948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051269119864653274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41970311358229495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0024520764108045337,
                                   0,
                                   0,
                                   0,
                                   -0.12717010770302695,
                                   0,
                                   0.14303164831787069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10497966934564097,
                                   0,
                                   0,
                                   0,
                                   0.14920487146607045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44771408381303146,
                                   0,
                                   0,
                                   -0.57606476812142526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93094980991354381,
                                   -0.059279446951512521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65804440717929946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71904629564597744,
                                   0,
                                   0,
                                   0,
                                   0.94549883890689213,
                                   0,
                                   0.43405413013534622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49076013998020324,
                                   0,
                                   0,
                                   0,
                                   0.027467390060772107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41782727268980874,
                                   0,
                                   0,
                                   -0.12177380647345176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85013226515186424,
                                   0.17636876585846373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11018155936487327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42728828612087399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20786059474148316,
                                   0.13726790747943723,
                                   0,
                                   0,
                                   -0.61489282044915372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15308434922931094,
                                   0,
                                   0,
                                   0,
                                   -0.12502486442506952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047644769307799525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.139178059488063,
                                   -0.014001134196482296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14405201607001339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34454845319925392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41795959526147652,
                                   0,
                                   0,
                                   0,
                                   0.039332956617853243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026047786914002322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0030606394857618582,
                                   0,
                                   0,
                                   0,
                                   0.1900593704128001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1106238350183619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52990225913889111,
                                   0,
                                   0,
                                   0,
                                   -0.36710857266663288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64387926462939493,
                                   0,
                                   0,
                                   0,
                                   0.17415746618634248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70349082930199547,
                                   0.61744382488948324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34091515421289104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4575491364760832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41224552852906338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41104107756297903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44410321450890544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017103588375506087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46459409628007214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27045996734245287,
                                   -0.45179187901360629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3119482946208878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34122437981539289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50675842683787109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1358552796000275,
                                   -0.12686793964992957,
                                   0,
                                   0,
                                   0.038642553152356651,
                                   0,
                                   0.17656755104395072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53691606477234022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35977795760171294,
                                   0,
                                   0,
                                   0,
                                   0.054297230248127708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14703847928505046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42132909995915074,
                                   0,
                                   0,
                                   0.0028505274925061455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3110660310515373,
                                   -0.46568601004386295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16364900324527384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077635190719559419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050756932760470358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20612390370872088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22782914487057165,
                                   0,
                                   0.55689297519666559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095493623568569247,
                                   0,
                                   0,
                                   0,
                                   0.3802090268259119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66230707972849301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04113057058322761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038166783030279677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71961911300206904,
                                   0,
                                   0,
                                   0,
                                   0.18135007379521495,
                                   0,
                                   0.1944438296656118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33959934139444609,
                                   0,
                                   0,
                                   0,
                                   0.18026698972602492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85004955561671292,
                                   0,
                                   0,
                                   -0.79059022343331775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53917502133043071,
                                   -0.43475697435628929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43016734640349025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47387381776582455,
                                   0,
                                   0,
                                   0,
                                   -0.22185064719899117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0024545771728037985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51153269818291969,
                                   0,
                                   0,
                                   0,
                                   0.50477714037259802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52580385973874444,
                                   0,
                                   0,
                                   0,
                                   0.42047558425297538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26413969622471928,
                                   0.31729252582448908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10167526852645342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13378717563740938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22568586524902456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30454027310609633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52112996960594193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13715867107351698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75948066717058915,
                                   0.18714330450310127,
                                   0,
                                   0,
                                   0.15071742854587289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19035786041424002,
                                   0,
                                   0,
                                   0,
                                   -0.06734928340108122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38742327437485036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032425968929609292,
                                   0.21536758551559126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24677247989024281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095548928507535505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11554277549566785,
                                   0,
                                   0,
                                   0,
                                   0.15252582019307365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041161477323071877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12798637871993265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47018508391696551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21787047336092036,
                                   -0.15767067065160592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30886321325100979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20428593938565648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25127398142851903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45569160390365904,
                                   -0.079946664390027733,
                                   0,
                                   0,
                                   -0.52526539947872475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65233180507700972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048827425540578645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27496200246243829,
                                   -0.061839772030049145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28197725779741512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31916173360092642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053122298778837451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34041099008305364,
                                   -0.16383416031662931,
                                   0,
                                   0,
                                   0.40710219773820688,
                                   0,
                                   0,
                                   0,
                                   -0.13365037427197804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71277600657210827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095959103416965466,
                                   0,
                                   0,
                                   -0.044696175969114488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30119734222827055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51154623725648729,
                                   0.75703176981974307,
                                   0,
                                   0,
                                   -0.16481135904979247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22905774584771646,
                                   0,
                                   -0.018918643807751337,
                                   0.22027803962671894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44139858786059805,
                                   0,
                                   0,
                                   0,
                                   0.23136564547756799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3203978227089182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2264025371102236,
                                   0,
                                   0,
                                   0,
                                   -0.36002668330545573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14705431191325763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1645320454535488,
                                   0,
                                   0,
                                   0.34826002542011969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54735018724089235,
                                   -0.040530171785592303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079862746992645062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38647074506786966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18969560987827441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037412129006419617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60010257175398152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23318604785110109,
                                   0.11383564109899651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33171940673252731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083746217847813692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40275095470132616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22220357188674356,
                                   -0.11227146496232014,
                                   0,
                                   0,
                                   -0.47948317525951334,
                                   0.029085688737416349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19138182502250362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38032292016901087,
                                   0,
                                   0,
                                   -0.001204337940510336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37176079487281793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13645352917400924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39613513828684122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71002207269346074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018794143267524974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40948962912945697,
                                   0,
                                   0.024838742648835354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045155676746257312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30570596201541872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44297476374043515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25017725889503123,
                                   -0.093993349945782817,
                                   0,
                                   0,
                                   0.20310994668897656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060535541804728393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023456513060119831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63425751087583659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083987678255886877,
                                   0,
                                   0,
                                   -0.11574933191508888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4713781555719363,
                                   0,
                                   0.52682285016633001,
                                   0,
                                   0,
                                   0,
                                   -0.10352380636704141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07466994177780395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49987678879742486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58761992596530144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28220618282875265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84070545101342553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34070386379176842,
                                   0,
                                   0,
                                   -0.0032287434100784496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50471579707979941,
                                   0,
                                   0,
                                   0.23092337124025092,
                                   -0.30276712589447896,
                                   0,
                                   0.25572508870540284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15205986217246598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2291029606736385,
                                   0.33054625538050408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.311061571889928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18381603874428679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12940862987313559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039559933664485597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44848934504009191,
                                   0,
                                   0,
                                   0,
                                   0.5139069261475494,
                                   0,
                                   -0.014231286680970297,
                                   0,
                                   0,
                                   0,
                                   -0.903577880741669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35206613019047683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62367729587366227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52116615942943012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45208501977988697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14461229718010926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021750089967726201,
                                   0,
                                   0,
                                   0.039975407514881572,
                                   0,
                                   0,
                                   -0.40204875940538204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081526099751811049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23509637589105634,
                                   0,
                                   0,
                                   0.14985722462349566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0040177284192968454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54030512947871456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65623904683412493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1771647107029512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13097374206423729,
                                   0,
                                   0,
                                   -0.0607454279718493,
                                   -0.58534446354927194,
                                   0,
                                   -0.13617060552826804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22164415049707889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093732740029263462,
                                   0.41437631107883843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33436969855848431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22419858368519277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2534865301389117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0035148983641893686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40252917677269195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018720025925839101,
                                   0,
                                   0,
                                   -0.099407270183796026,
                                   0.090484486338811065,
                                   0,
                                   -0.24216618068280113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15269694789500501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48206702308827459,
                                   0.14450858886377174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3415942245315427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055187360096299085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15410077148597295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64804897047290222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28792598732509467,
                                   0,
                                   0,
                                   0,
                                   -0.49304490505053061,
                                   0,
                                   0.064972582054797806,
                                   0,
                                   0,
                                   0,
                                   -0.47459725676679709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21125254314739339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19080569379163792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39990235222002279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66804531678186696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83602287293424582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0893352549485953,
                                   0,
                                   0,
                                   -0.29327122812239181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24281743070423742,
                                   0,
                                   0,
                                   -0.486265799223909,
                                   0.27010548402326551,
                                   0,
                                   -0.20159100990435716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12242357048398761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30299118808841258,
                                   0.042755147725183691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17589761369016901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61190987896620175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25953172180574824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028306099543399278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094013543589179377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041960907799516778,
                                   0,
                                   0,
                                   0.003635951990709374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15341653788626833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23449052135165083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6340687274817659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57379875395509405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41322350674839919,
                                   0,
                                   -0.05714309775182036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11966106077284384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0088143373443008589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024185247175883329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95388474219063912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19549228533839527,
                                   -0.26420398385933275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045020604482015142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62201216702267137,
                                   0,
                                   0,
                                   -0.8152951088007957,
                                   -0.30137098341822222,
                                   0,
                                   0,
                                   0,
                                   0.15610449480778521,
                                   0,
                                   0,
                                   -0.33013699858345913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27408126904318453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12453518344097808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24735435486550988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23210931423504705,
                                   0,
                                   -0.061884555521118059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16311598647279729,
                                   0,
                                   0.33526223867136318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90671335082544624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35956461443979998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61109882387504233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31508062839476636,
                                   0,
                                   0,
                                   0.57516436309358765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068949444545238978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11700745126200482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16556016085007924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066035569045630252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17532993221312645,
                                   0,
                                   0.50615036229465427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036546723637702415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48107180633890295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97087085716869792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14608584536596511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074591448468297003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22167376569027727,
                                   0,
                                   0.34187598046304379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32614132284765207,
                                   0,
                                   0.89199223636275204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011674077094911944,
                                   0,
                                   0,
                                   0,
                                   -0.3674794187896146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033966038272138517,
                                   0.29405220367594581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16461698970683633,
                                   0,
                                   0,
                                   -0.23393769238368806,
                                   0,
                                   0,
                                   0,
                                   0.47957017734543694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20212317897210214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28767344825538238,
                                   0,
                                   -0.45736175177760136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060127958660480652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0482116644209407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22497855268190542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076864016279439146,
                                   0.16571474534186514,
                                   0,
                                   0,
                                   -0.50764594521882789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10916780124973223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49680802700605409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19791102960579748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070334272330367639,
                                   0,
                                   0,
                                   0.12934442773298432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68947091313126818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12637903886270968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4313018243406011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12690593134791214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52421539911971782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17812926406690435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16151362381436307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20571863682459557,
                                   0,
                                   0.26908442013458728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58294724769876272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16654244636989657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11621866093910041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1958959192329148,
                                   0.22003590512274845,
                                   0,
                                   0,
                                   0.13180476496927945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28881678878288686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17507130782433841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26506504355644073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43314889529141726,
                                   0,
                                   0,
                                   0.044833687506909692,
                                   0,
                                   0,
                                   0,
                                   -0.43748404307124444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34756727436726353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51927680219077665,
                                   0,
                                   0,
                                   0.37218106475132956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14466340283369947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12936253922230798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39889087539128681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28785666997681258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35457144472781427,
                                   0,
                                   -0.81142142661603922,
                                   0,
                                   0,
                                   0,
                                   0.11129621553190525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1155086376622032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042351019267171608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2782447573299448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093468584774368396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045137426128127295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1123942290343346,
                                   0,
                                   0,
                                   0.19486060887271911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10202179074279524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94870170073010618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03290497782624785,
                                   -0.17457253751808119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33096899395359564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35277734885437878,
                                   0,
                                   0,
                                   -0.31980054643131023,
                                   -0.44571600372310727,
                                   0,
                                   0,
                                   0,
                                   0.077613870938084334,
                                   0,
                                   0,
                                   0.27006004542364898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92046552994337205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29994941460062935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40467368193712017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25088145127487638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30295220079029656,
                                   0,
                                   0,
                                   -0.63241396495672542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26125478937727187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38578584423365786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18524844899571558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1736907570331209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30069420534768931,
                                   0,
                                   0,
                                   -0.1244628072108775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47334198238647091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58850854166641409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25824490582187254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22391225925136915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085352996025289909,
                                   0,
                                   0.10553527095502446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31388800334618921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29986902369355434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02896633573661142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38344473598442547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58685044002145448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46279256526028056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057178815069707255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53878685167094309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062171428372588308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19839623479892582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67518822955748059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076489258128954851,
                                   0,
                                   0.13206466876247624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071657550174528017,
                                   0,
                                   -0.31873186314620872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1072415509528695,
                                   0,
                                   0,
                                   0,
                                   -0.23242815821578922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5360232216035129,
                                   -0.012060243071676857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85616847815205943,
                                   0,
                                   0,
                                   -0.21804093988734394,
                                   0,
                                   0,
                                   0,
                                   0.30402990907141697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05703071538441154,
                                   0.43429083429417559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39370306680742345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065877256544405474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2060149696336346,
                                   0,
                                   0,
                                   0,
                                   -1.0234123394350385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25742374714025168,
                                   -0.5841564228452073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67030633430788278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.007281413553816442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82335361398696982,
                                   0,
                                   0,
                                   0,
                                   0.49960015644307798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23080310993104702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069402115519604027,
                                   0,
                                   -0.35978863862819482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051795485431343893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077401605327569234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30184691932977692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038398220925422347,
                                   0.441142323416023,
                                   0,
                                   0,
                                   0.20972266818682239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54476370590583256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28947098667015109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2880714882400382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027221908167210075,
                                   0,
                                   0,
                                   0.091259686317314778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25180287229930881,
                                   0,
                                   0,
                                   -0.059960387164674916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0070589975263576493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20358115695633189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40728775055269406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63654124140097545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38440463284465209,
                                   0,
                                   -0.33827073889588527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21459226756295802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11042204925259236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42229983715828462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03390068825255374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38106031981495514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3387899042982338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079117086772148348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74449211605019405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21480061970890074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18533226693665386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54982194181269928,
                                   0.31329220825290688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0551056882710361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089071058979692766,
                                   0,
                                   0,
                                   0.28344193969577791,
                                   -0.31228541438214974,
                                   0,
                                   0,
                                   0,
                                   -0.72933017702041236,
                                   0,
                                   0,
                                   0.17219737373649008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20394452801422003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41913698240111119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79103298350707985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43264588012132155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30742975178486104,
                                   0.75448432981526425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14967775040120537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067424822146526467,
                                   0,
                                   0,
                                   0.61684840908283489,
                                   -0.267232398235906,
                                   0,
                                   0,
                                   0,
                                   0.79808502909571866,
                                   0,
                                   0,
                                   0.36115129253308681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070399228155351809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18625031630353575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23765441807095666,
                                   0,
                                   -0.1470281360008045,
                                   0,
                                   0,
                                   0,
                                   0.34673360350579352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10910857253971951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65037369012854418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2882955244158027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11197144185823532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43716110509024353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49744171269499987,
                                   0,
                                   0,
                                   -0.82175071571621605,
                                   0,
                                   0,
                                   0,
                                   0.27673433925167096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069365537829691098,
                                   0,
                                   0.13789995978042757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37018758799130624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16898174896000112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14665019140274488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10704730974930583,
                                   0.51294383491143813,
                                   0,
                                   0,
                                   -0.04786274213190083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51921446979366659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37745192879501976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13438391029162416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041327204154021635,
                                   0,
                                   0,
                                   -0.061710814165557293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044870544014838892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049777318153594347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48314990981255779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59609866744580675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62752066324746791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11383854089084477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028211868898161914,
                                   0,
                                   0,
                                   0.17407561291283505,
                                   0.58512031023408817,
                                   0,
                                   -0.1186519893417211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18287978040264838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21161646981793983,
                                   0.59622983614396718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3854223097309516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060981623052728098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048560462063457349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062796166507322546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14202304510256603,
                                   0,
                                   0.53356175972292286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046257849653724148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48623318517891645,
                                   0,
                                   0,
                                   0.32941446111699962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081736036914040688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41791834994366261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43203449322812426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01565669363662367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35311342791028899,
                                   0,
                                   0,
                                   0.1537797553373827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5682203260402594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28840441848052178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20307397031534863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2734438467256548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025227928908921414,
                                   0,
                                   -0.45099902490678634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16171575741267522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31529687052397098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34122152024709229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00027072053005360031,
                                   0,
                                   0.56607716997851898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21834260453763535,
                                   0,
                                   -1.0081967026969392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56307365020843991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18548954207925877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1735891842257658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43165491075574053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32863901414669155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16157851232678724,
                                   -0.41970092430363898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7073888227964189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86721073167875595,
                                   0,
                                   0,
                                   0.78170353277044913,
                                   0.20534117923910769,
                                   0,
                                   0,
                                   0,
                                   -0.42713959737600993,
                                   0,
                                   0,
                                   -0.43170023139321828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14394486143594201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72426705555399307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23437198868621884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36583919434822654,
                                   0,
                                   0.233409387664514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0553387121063302,
                                   0,
                                   -0.34146096163949807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36579428307261452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29818856157040535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1424121409263184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30232298421310821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22781043601332859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33671876132661582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20902532428943943,
                                   0,
                                   0.18633894161597034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15377317035490942,
                                   0,
                                   0.3253018752012567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0871698865285315,
                                   0,
                                   0,
                                   0,
                                   0.22538523047378384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28603809861547858,
                                   0.72382233915716787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32164177581823994,
                                   0,
                                   0,
                                   -0.29861948176939224,
                                   0,
                                   0,
                                   0,
                                   -0.19801098314096072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41788005913067777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038890300199465849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4309335430047041,
                                   0,
                                   0,
                                   0.39681532518205742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17427038468783701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54492478401245081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15561276032955862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35940111513148293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14022865149336522,
                                   0,
                                   0.54899263818703836,
                                   0,
                                   0,
                                   0,
                                   0.3137930651486549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33191713328026162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0050898127588109854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20256115632985111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6597414643026096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35976629043671421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51545539997111123,
                                   0,
                                   0,
                                   -0.66628831170916458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57819294816976963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33140427982822773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26719664377625996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40788857031834119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46862522433835663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31382699831351352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25841372254107409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062783674164511707,
                                   0,
                                   -0.069398024467823699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18825889485299369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33567573552124186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05627803810837391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18596092582358434,
                                   -0.12201033857673427,
                                   0,
                                   0,
                                   0.10044607092677602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093730364719031289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16553302076949392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12256890749837564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056859762961818106,
                                   0,
                                   0,
                                   0.81189747517543598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92564277665256256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38680556740637606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033633460380011193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031370647816528791,
                                   0,
                                   -0.057261287509761755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23683850649978569,
                                   0,
                                   0.84995629840026488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43487294296196444,
                                   0,
                                   0,
                                   0,
                                   -0.060664676871423871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023603962143204205,
                                   0.055818906530750861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26795646701855408,
                                   0,
                                   0,
                                   0.35738944294858088,
                                   0,
                                   0,
                                   0,
                                   0.23535662381226824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33253520153294247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34438221640246203,
                                   0,
                                   -0.46658171722830083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70101421219551696,
                                   0,
                                   0.094802297151733717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18794683252212946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059363967529065503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84164001345065254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08314118710776483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2384186741526495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19244119625516026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43064884725882047,
                                   0,
                                   -0.29344675801949488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22920976292168377,
                                   0,
                                   0.13081613051033408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1581543937055504,
                                   0,
                                   0,
                                   0,
                                   0.19790430873443224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16840579550928644,
                                   0.31800208985422712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27893854432357945,
                                   0,
                                   0,
                                   -0.39330129515578843,
                                   0,
                                   0,
                                   0,
                                   -0.09032716203853744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010858456145266593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80427336802386173,
                                   0,
                                   0.63856118555764063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58550156168884893,
                                   0,
                                   0.68685410981914707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27764946145098401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016685367005867174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16212043946517019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13386718680712456,
                                   0,
                                   0,
                                   -0.48700681768246201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25924905720088826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40710412828379672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019285364095448392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21722365483991712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24463648694419526,
                                   0,
                                   0.45548092570208443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36982447940628066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24560541407027534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22982359252009577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12295494328460316,
                                   0,
                                   0.056834281871543886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32757983328098156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24881039640579389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26614312051262984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17553787367702847,
                                   0.30471835341227732,
                                   0,
                                   0,
                                   -0.41856377400163591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1063777326795967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24179551532063129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088941012172868691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55739255027832024,
                                   0,
                                   0,
                                   0.039306953835376628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46154114830674531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12617205047249266,
                                   0,
                                   -0.0056021091547936927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21272218302492235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39436120716255141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014982988518572986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46640669888499431,
                                   0.09031468858882058,
                                   0,
                                   0,
                                   -0.26148792034713941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011188609439687244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021975921516630095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35679907453475102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3811859911558288,
                                   0,
                                   0,
                                   -0.052427758721527704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062184345370177113,
                                   0,
                                   0,
                                   0.43298482860928628,
                                   0.083310069367064365,
                                   0,
                                   -0.018446978446952277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10503147324471108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40606735907886399,
                                   -0.46280672531676764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095520054156984682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57024600687279647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11763381155584395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14745623454640855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20341673334647897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10629051890253838,
                                   0,
                                   0,
                                   -0.067790338462274419,
                                   -0.0046855715375941423,
                                   0,
                                   -0.15263969201603905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38834244920644417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27321242101178445,
                                   0.19668333575257901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24811689422701905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16768087814440691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010302553485983509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70089325472751252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34001526260253367,
                                   0,
                                   0,
                                   0.18165830824577431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052735696449634051,
                                   0,
                                   0.12134640041977784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39373256433806658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47171169311627198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50222418227607257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12175597918004905,
                                   -0.2147741165928751,
                                   0,
                                   0,
                                   -0.045513474135365883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0097621585489940741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10487440389251448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055359258644251105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28679853146384349,
                                   0,
                                   0,
                                   -0.4003647987943974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2254872052451895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2027507816829483,
                                   0,
                                   -0.82527613210650597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69383424762133794,
                                   0,
                                   0.11381181603264418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32349669271149784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12530644154249829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061457362069104016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057944395466327556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20116564292187858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86360079854895533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60343428663677934,
                                   0,
                                   0.47432369061303681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0051110329647856903,
                                   0,
                                   0.31994494663283468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094773352316427834,
                                   0,
                                   0,
                                   0,
                                   -0.10443033760483551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081968715457267,
                                   -0.1140469643962187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1337994222932968,
                                   0,
                                   0,
                                   0.11452679804433352,
                                   0,
                                   0,
                                   0,
                                   -0.28895829901047321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13027592586337444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34227403409318319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37645644549856616,
                                   0.0039564977908703057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42073258298067567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17735989678514538,
                                   0,
                                   0,
                                   -0.42133605606733043,
                                   -0.2070282635027173,
                                   0,
                                   0,
                                   0,
                                   0.6916095410441776,
                                   0,
                                   0,
                                   -0.16984137742905603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60636739015434649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1010812925987761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13218519340435345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012207141320396249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22350138900367847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52198314553030567,
                                   0,
                                   -0.14728587135644824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64204525708095783,
                                   0,
                                   0.0086918351846903795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6180956427110732,
                                   0,
                                   0,
                                   0,
                                   0.62673336793218259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16866629659713123,
                                   0.020416208218720949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17048953963268615,
                                   0,
                                   0,
                                   -0.49371395459432904,
                                   0,
                                   0,
                                   0,
                                   -0.14126889525671382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21284246847435265,
                                   0,
                                   -0.42224467508516339,
                                   0,
                                   0,
                                   0,
                                   0.26882033408577927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29631368692809801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21238418258831765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83136598781191973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56149940580887248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27298588812798158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6100420949854406,
                                   0,
                                   0,
                                   0.4439720855918442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13849056120356346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4497330428221441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067638532909372009,
                                   1.1313884377306582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21143363702145768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44407630878568466,
                                   0,
                                   0,
                                   -0.601737632487514,
                                   0.71358658453735668,
                                   0,
                                   0,
                                   0,
                                   0.1984392834717946,
                                   0,
                                   0,
                                   -0.12279484646305995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57862884413745153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11427106335031942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30272174465742291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095555041250031225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43923618679794507,
                                   0.26448507947720057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096914906270384613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59309228427434768,
                                   0,
                                   0,
                                   0.23975116582556943,
                                   -0.690102256345697,
                                   0,
                                   0,
                                   0,
                                   -0.27720384860433822,
                                   0,
                                   0,
                                   0.32051637177001213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49128210695736607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029675774015937934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22014696102492057,
                                   0,
                                   0,
                                   0.06504252954682925,
                                   0.22498912845999186,
                                   0,
                                   0.56602264473877972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12033199504470499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24153770073254788,
                                   0.21853365310379161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38772423616590529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18825701764400882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49429211904710973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020681885959986109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1587532922880206,
                                   0,
                                   0,
                                   0.22943685093929994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26851320556756525,
                                   0,
                                   0.39090240809419302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18398777358350038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26342273958366397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24961274115806342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30536858910210074,
                                   0.45127005979726664,
                                   0,
                                   0,
                                   0.060674446738695972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36347852989515189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21238309560678892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26309210619308165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099316252052289875,
                                   0,
                                   0,
                                   -0.0049709438598222813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24974481496912171,
                                   0,
                                   0,
                                   -0.36888380232689716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12159853817892659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48722738221419259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11696451026044023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23133183747188613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062285047655751144,
                                   0,
                                   -0.11297235388811334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00080455976612876096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68230315725551316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99983629285516462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11171146840223194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55326391685253662,
                                   0.32818978369154878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56341767387828634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72015235077222484,
                                   0,
                                   0,
                                   -0.14921354168066991,
                                   0.23810260480736983,
                                   0,
                                   0,
                                   0,
                                   -0.30592080694653095,
                                   0,
                                   0,
                                   0.072410656763981021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11585317437688361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20087608567729523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29747998284673854,
                                   0,
                                   0,
                                   0.049807906583624467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40395625927893636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17389161597528574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21486479161569574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023861835270870858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35415194525035115,
                                   0,
                                   0.41029242707851576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59923737077651484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12657294455706758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20334379258153562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52709181960072293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49484631315608107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45422111681696731,
                                   0,
                                   -0.98112793058997572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29562723448611283,
                                   0,
                                   -0.39370512555427678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03406676634159643,
                                   0,
                                   0,
                                   0,
                                   -0.36922574732639551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49142199240909257,
                                   0.12153338367866878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13183634549542908,
                                   0,
                                   0,
                                   0.076950839977371344,
                                   0,
                                   0,
                                   0,
                                   -0.26927899021886875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60534050172086384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44977644276598633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94795377406070058,
                                   -0.0033041895724858421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92658667678675166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51757668532096357,
                                   0,
                                   0,
                                   -0.092707460537543501,
                                   -0.32396519126945872,
                                   0,
                                   0,
                                   0,
                                   -0.023694242998222929,
                                   0,
                                   0,
                                   0.42744646112225776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0919014601354778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24169544933978385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17034830897746223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73992552134035849,
                                   0,
                                   0.047721926146959928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097042460621437829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23500341597595886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26146424286678416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19585619594722914,
                                   0.08495199839020473,
                                   0,
                                   0,
                                   -0.27588922937148597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20650105330035634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25276230344705691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17499422521543495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13482398135720333,
                                   0,
                                   0,
                                   -0.10575248938172731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69125644161956745,
                                   0.90687305480267322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088295311791125874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74555122480445279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57921338293742175,
                                   0,
                                   0,
                                   0,
                                   -0.035827778910569041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075778809653628321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50824557029799022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17015744218768564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56668669055672327,
                                   0,
                                   0.28641921397179287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22574699565465628,
                                   0,
                                   -0.020361300030556261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49786957141064969,
                                   0,
                                   0,
                                   0,
                                   -0.73807008484805403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14778009775177031,
                                   0.016399500356501118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21644103994158981,
                                   0,
                                   0,
                                   -0.0093642556848195363,
                                   0,
                                   0,
                                   0,
                                   -1.1511857526522529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43379356983425621,
                                   0,
                                   0,
                                   0.12391464988846841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3502085007355113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1615874739978525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48556513533506884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15516814536114215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58371658891377343,
                                   0,
                                   0.027407810876852498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16633131103455678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13681662649181953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26827251790542245,
                                   0,
                                   0,
                                   -0.12377597857980065,
                                   -0.13852804693500501,
                                   0,
                                   -0.35249842036711077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67511692894995878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14047095213777447,
                                   0.022700055558106932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43327650959601738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05469268861907535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023947894735385965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17286562945005712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26843641142586677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095567818027715606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85061309549462305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13982291740783401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36501043786050086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31980853854290747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11074107018615068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013919611104035251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11618695470730203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12500365561625371,
                                   0,
                                   0,
                                   0.27912117257214564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79633869553128533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22351902641254834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052653565613731697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45374422524849345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60927574758767056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21889518928702226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5083049747736561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63772969850818317,
                                   0,
                                   0.40795548650048674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1385850968232363,
                                   0,
                                   -0.21242839570451588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24128009630177155,
                                   0,
                                   0,
                                   0,
                                   -0.45608797602016998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14101615947290064,
                                   0.19264739073352349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074082025542188221,
                                   0,
                                   0,
                                   0.0048852477377631012,
                                   0,
                                   0,
                                   0,
                                   0.15876990768317778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10982853931966652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10753949813775866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29287604290661767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17383312923356037,
                                   0,
                                   0.3201778179271827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17383313439549075,
                                   0,
                                   -0.63513520709634197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56288416933542162,
                                   0,
                                   0,
                                   0,
                                   -0.27364752551086252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52626713684088178,
                                   0.62571778074126727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092748263791199728,
                                   0,
                                   0,
                                   -0.047380614428158274,
                                   0,
                                   0,
                                   0,
                                   0.45553865871335947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40929007991634259,
                                   0,
                                   0,
                                   0.28215285796985168,
                                   0.16396319436685225,
                                   0,
                                   -0.50744365211518716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062626594420199369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34995040493597573,
                                   -0.07458650078228321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13191628189505958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15859888388779128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52287450935582291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070797938886568101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12478890822468768,
                                   0,
                                   0,
                                   0,
                                   1.2317222883431509,
                                   0,
                                   0.10391852513461002,
                                   0,
                                   0,
                                   0,
                                   0.61606731428074535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54173236756636733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31767801335984613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11805135428484589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54048117928119377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013623310551796913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027996351746212313,
                                   0,
                                   0,
                                   0.13382984633231262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93144253404464772,
                                   1.0664572232761493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16937650026894713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45007504361367301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29123468750220455,
                                   0,
                                   0,
                                   0,
                                   0.82907964891640307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1511690780080043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86938502791173911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03005652020109708,
                                   0,
                                   0,
                                   -0.30852921303524117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31841786924065985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048227530008977976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07317660015912375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12709549355111319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51331140401994557,
                                   0,
                                   0,
                                   0.48513061706855937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23855734697157843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029759922039497115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027219481227802111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1046624510198742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33606866836574106,
                                   0,
                                   -0.14921420916332453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53860536289371796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07979054022129721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43824429510843638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8311723944261632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53706425454891538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16836932237578234,
                                   0,
                                   -0.067880819377760165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28652333470830599,
                                   0,
                                   0.24585315623661969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71863715477775891,
                                   0,
                                   0,
                                   0,
                                   -0.14496446071182265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60735472055072348,
                                   0.10056693349261107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011438901850308131,
                                   0,
                                   0,
                                   -0.32874862841839597,
                                   0,
                                   0,
                                   0,
                                   -0.53617313762915209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3466969158088638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19618410150484544,
                                   0,
                                   0.36443503079660455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26010109993883967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37174182438569614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28087875535994278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57284012016721286,
                                   0.047376879690579424,
                                   0,
                                   0,
                                   -0.026524673166743826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26553672981142745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085436341236858115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050278367292533592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045962385677946055,
                                   0,
                                   0,
                                   0.10109008421888563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94956090591390374,
                                   0.13280441104793361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0248304826076566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74990455214513541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070847417285751571,
                                   0,
                                   0,
                                   0,
                                   -0.11311917559084564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13386547412883276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16527794629562723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34980232628224239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.213317631866764,
                                   0,
                                   0.65228693261883786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17007513101754784,
                                   0,
                                   0.20981188262810507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30341172847085496,
                                   0,
                                   0,
                                   0,
                                   -0.11093256022820183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62568107268239104,
                                   -0.54975108485749813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54010958605696868,
                                   0,
                                   0,
                                   -0.42593824597011259,
                                   0,
                                   0,
                                   0,
                                   -0.0056107952443672782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4231067499522792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32393800045940596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15086512718565262,
                                   0.94200815896237988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24789385719479934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12304870027857245,
                                   0,
                                   0,
                                   0.4943800987258688,
                                   -0.28857533785092565,
                                   0,
                                   0,
                                   0,
                                   -0.1048446195353766,
                                   0,
                                   0,
                                   -1.0835039680699983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73227737717004837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11031908935394524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42391773421175633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39426733859932478,
                                   0,
                                   0.38341575713348891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13856798865658887,
                                   0,
                                   -0.00824392757079348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20265455002272245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.383815511513155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56194044204261451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24915883519570553,
                                   -0.67506292255004885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99231324976028645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.092732346701685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28571715617523386,
                                   0,
                                   0,
                                   0,
                                   0.50537907533472004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57493513587537892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036947402036674223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041756840299233565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34674389134472805,
                                   0,
                                   0.22749738015345911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058244327456120876,
                                   0,
                                   -0.18922643106090098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34134329377436906,
                                   0,
                                   0,
                                   0,
                                   0.36432367495495549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14284159663605273,
                                   0.41392037565098844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077948891484561827,
                                   0,
                                   0,
                                   0.70780716096415708,
                                   0,
                                   0,
                                   0,
                                   -0.45145213006507096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32546886178058532,
                                   0,
                                   0,
                                   -0.60604694181876473,
                                   0.093790540346528464,
                                   0,
                                   0.20596803280551332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12592412006564521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35837781807314545,
                                   -0.17806294341985909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2152694369837661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10325066314658157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43063733685394789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1512102615581406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18505400015657081,
                                   0,
                                   0,
                                   -0.43901590212029568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032979963882413539,
                                   0,
                                   0.25442571830166666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24035875942654958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1480413049155602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2685046254567075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10178967314563883,
                                   0.10714574155411966,
                                   0,
                                   0,
                                   0.23905031186766806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16375439557727794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47485932890416743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026260844792449476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45141538259590336,
                                   0,
                                   0,
                                   0.23216988482737608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059740430954808341,
                                   0,
                                   0.34643599255171825,
                                   0,
                                   0,
                                   0,
                                   0.2085101097957979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25980558343102578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13170464785136099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97866060355334006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45826253850336607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54316588773922669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052332462951590025,
                                   0,
                                   0,
                                   0.76303590788225195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29763206859829222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62107573436435237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24543176510740075,
                                   -0.10841730356377496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057367280706323506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26152700578300841,
                                   0,
                                   0,
                                   0.0078247730059790577,
                                   1.0383026475147417,
                                   0,
                                   0,
                                   0,
                                   -0.14633460445483643,
                                   0,
                                   0,
                                   0.25180679080734475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62128852420659497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59085933438786109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20650506785742173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026243010006687127,
                                   0,
                                   0.44034374040088653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055468944306991549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067774778839595373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1375598549597965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33514653104833841,
                                   -0.26638205118806879,
                                   0,
                                   0,
                                   -0.49398146524658265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20553556697225275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2378744561570561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36177768039975977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15008986238939287,
                                   0,
                                   0,
                                   0.23797467943612224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27743426119905429,
                                   0,
                                   0.68560170147776756,
                                   0,
                                   0,
                                   0,
                                   0.1945676295186004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0099297000958974424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.933807009804412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2777047331901128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33020304007502499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32737938569309588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16987897790574399,
                                   0,
                                   0,
                                   0.24491964757220272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50887468443654649,
                                   0,
                                   0,
                                   -0.088432411806978764,
                                   -0.17245431202804321,
                                   0,
                                   -0.18574910056428387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4517960457142654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035270086118071059,
                                   0.049137418626199907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15090770242850968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.327421548454017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32840185658743359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050286598367272124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46994721804403178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84927163640165015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78828466798201657,
                                   0,
                                   -0.66481631566144628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12722034772837831,
                                   0,
                                   -0.65050044857856515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58186965033447435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32955230528415885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20729976233449382,
                                   -0.12279180000587422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094153606906546866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17997330561281666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36924169966124593,
                                   0,
                                   0,
                                   0,
                                   0.0021118259627879235,
                                   0,
                                   0,
                                   -0.10912621245902317,
                                   -0.27388139964601477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39868770746012011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050513576651235584,
                                   -0.50177925916990918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4157929180447491,
                                   0,
                                   0,
                                   0,
                                   -0.09583716681660244,
                                   0,
                                   0.15689353822371524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31691230256065966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21497797276276404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06801750851119312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25639323432355299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20987743722734697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23863235757373671,
                                   0,
                                   0,
                                   0,
                                   -0.39537531147100829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71391486519714065,
                                   -0.053851248143555984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27973592713899154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045363043937582143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090302226091142829,
                                   0,
                                   0,
                                   0.15832290767940807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35760273660050723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25631103068159355,
                                   0,
                                   0,
                                   0.4857616763865979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34385301535054968,
                                   0,
                                   0.71501444082932453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28022652443058371,
                                   0,
                                   -0.5770692707472771,
                                   0,
                                   0,
                                   0.65098135800779633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38426659225793358,
                                   -0.43905548977338255,
                                   0,
                                   0.37992635957774579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17627842045155628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57340685231248545,
                                   0,
                                   0,
                                   -0.27739291730305093,
                                   0,
                                   0,
                                   -0.20194310538117369,
                                   0,
                                   0,
                                   -0.14954206004829534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040611367357422844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85082812560632282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39879402986499524,
                                   0.57855693016708265,
                                   0,
                                   0.84503255931997512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50189754967063216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13035607232270591,
                                   0,
                                   0,
                                   -0.0077132769922515776,
                                   0,
                                   0,
                                   0.088089026985233063,
                                   0,
                                   0,
                                   -0.23994254077163671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4003696718393227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92002547420122149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66265728197871598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046969877945257192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056739242548937946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23965602497319932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35327559526726771,
                                   0,
                                   0,
                                   -0.43976736756037338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35678791119571407,
                                   0,
                                   0.0047202717074702055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059687456580637233,
                                   0,
                                   -0.22123140477681749,
                                   0,
                                   0,
                                   0,
                                   0.24637511049654187,
                                   -0.085284758792498791,
                                   0,
                                   0.37961118194835447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62075491312390674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71913803717967817,
                                   0,
                                   0,
                                   0.055782556723653232,
                                   0,
                                   0,
                                   0.63790497693048265,
                                   0,
                                   0,
                                   0.16928395030254914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42825837363635105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31938327697534385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18512144471946518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25272871456728063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49320241568337614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23567904543254786,
                                   0,
                                   0,
                                   0,
                                   -0.23913059461372949,
                                   0,
                                   0,
                                   0.25224570747091196,
                                   0.074607373623105697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44082859549098002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1911498318570603,
                                   -0.052452604500845691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45826946039119187,
                                   0,
                                   0,
                                   0,
                                   0.043879005915909278,
                                   0,
                                   -0.15481907159086208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084633438269785588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18368110654772032,
                                   0,
                                   0.33165370063971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69354960159375079,
                                   0,
                                   0,
                                   0.56881518797576702,
                                   0,
                                   0.29962093158289788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1577889269262624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44627874387092553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47678742501585503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44526688686410237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024709175644088126,
                                   0,
                                   0,
                                   -0.66202986417945775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39866013359844327,
                                   0,
                                   0,
                                   0,
                                   -0.061662511029057697,
                                   0,
                                   0,
                                   0,
                                   -0.27440332423559877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26410730819844563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48659770902699473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42459605156149838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1189970054963434,
                                   0,
                                   0,
                                   -0.3066574808443151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35482711031413261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82565165285425313,
                                   0,
                                   -0.35824653782444144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073888901651182629,
                                   0,
                                   0,
                                   0.32268464634256255,
                                   0,
                                   -0.5973113232338233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06314068715519873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25993271389222244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14917408139668287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66937559188690565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61329745112845058,
                                   0,
                                   0,
                                   0.58891477238437584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12278937679275966,
                                   0,
                                   0,
                                   0,
                                   0.4943889007628478,
                                   0,
                                   0,
                                   0,
                                   -0.030028948105286363,
                                   0,
                                   0,
                                   0,
                                   -0.38734428784990516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62500921255756103,
                                   0,
                                   0,
                                   -0.59139622410968129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57153228079639518,
                                   0,
                                   0.12137348236201105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1749464352400264,
                                   0,
                                   -0.65327922366478353,
                                   0,
                                   0,
                                   0.7863446885975055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16401572823348537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18930944282785367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41067944442716947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32611054691214841,
                                   0,
                                   0,
                                   0,
                                   -0.02494872289269973,
                                   0,
                                   0,
                                   -0.14423608365817372,
                                   -0.42781437487104129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24098071654372902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070646977704451053,
                                   0.14632926260618639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067829968543079766,
                                   0,
                                   0,
                                   0,
                                   0.47033427686651774,
                                   0,
                                   0.37979875332417962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057150423990507092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59479923011570712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083678714004081084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084457827851276757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096178129102111834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43254678327221918,
                                   0,
                                   0,
                                   0,
                                   -0.096279936548326214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11987565917155904,
                                   0.34420604628810403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0075720530835204705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026529928546075818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5113561386530574,
                                   0,
                                   0,
                                   -0.1771089946183525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43203290726739485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13904549015498369,
                                   0,
                                   0,
                                   0.26244534243360401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8112007831945266,
                                   0,
                                   -0.64343687379892733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81579141408493339,
                                   0,
                                   -0.80092056279904555,
                                   0,
                                   0,
                                   -0.17037278011859297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010340682512304342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019760911865667724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17303629570300816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16639709943082995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0061894425214666648,
                                   0,
                                   0,
                                   -0.056131221949448432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25141990506937434,
                                   0,
                                   0.15307230850596676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86301795240169565,
                                   0,
                                   -0.3274765832505967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43296400188631151,
                                   1.0834468370309966,
                                   0,
                                   0.2806567722564518,
                                   0.32972868518666532,
                                   0,
                                   0,
                                   0,
                                   -0.24494814099596932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30579404224858991,
                                   0,
                                   0,
                                   -0.38588685569774361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25696163379173448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18172130189471919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37386150431273912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24797023496309817,
                                   0,
                                   0,
                                   0.69046876553229808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34924738353513701,
                                   0.14538356123652577,
                                   0,
                                   -0.70543593550144501,
                                   -0.42421908824976412,
                                   0,
                                   0,
                                   0,
                                   -0.79296527275511819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42175817763485279,
                                   0,
                                   0,
                                   -0.49944843835187852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48720930185288258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04197538990680634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21015827455639316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020895014840547212,
                                   0,
                                   0,
                                   -0.39301918539074249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72030211404537481,
                                   -0.22599869346301305,
                                   0,
                                   0.49777669012002046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17307147452634972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64930830657170946,
                                   0,
                                   0,
                                   0.38997729065108111,
                                   0,
                                   0,
                                   -0.69054631928683152,
                                   0,
                                   0,
                                   0.11871613488964522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10995315536300314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39624009098999552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47037573051919546,
                                   -0.061475363884129726,
                                   0,
                                   0.38520889694792654,
                                   0.49747662221680594,
                                   0,
                                   0,
                                   0,
                                   -0.25734330108270498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.427442591767144,
                                   0,
                                   0,
                                   0.30981846587056883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81708690270637785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67141594768662405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15308418004355845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012293249826548409,
                                   0,
                                   0,
                                   -0.51117225448028103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80556530569649254,
                                   -0.049965235026549551,
                                   0,
                                   -0.16406060525810964,
                                   -0.033258057580046185,
                                   0,
                                   0,
                                   0,
                                   0.25978906987078404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0076927031405996937,
                                   0,
                                   0,
                                   -0.22331329357193486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20974592209328213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61768860968303108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26087627012266368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22268543239586591,
                                   0,
                                   0,
                                   -0.18619099522898069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29606569602758087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25958716201765814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061093105302336984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3038167383306315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3274475927577567,
                                   0,
                                   0,
                                   0,
                                   0.15396236213538711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067878315176359935,
                                   0.021216763294645176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22465789323293239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33074047422384145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41245256299006705,
                                   0,
                                   0,
                                   0.53194091050998327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010534648205030755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13663966196859778,
                                   0,
                                   -0.25832264851929521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15972233539290157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068861005024867,
                                   0,
                                   -0.17552656017386092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86210555412697942,
                                   -0.33196296631827549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10132057569277361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7933648008620362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13691145955606276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23128290168202578,
                                   0,
                                   0,
                                   -0.81939200774122944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31276201504274759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057788332683943316,
                                   -0.045232186940618355,
                                   0,
                                   -0.20591051456015685,
                                   0.82629894834023698,
                                   0,
                                   0,
                                   0,
                                   -0.46650086968194693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034513570822121781,
                                   0,
                                   0,
                                   -0.53277084901514526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26175481987594662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064540273641375101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75138441141535051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11895687130168366,
                                   0,
                                   0,
                                   0.041900674603171706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36696903540373904,
                                   0,
                                   -0.58592077103152196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47425635733684202,
                                   0,
                                   0,
                                   0.14018049493450102,
                                   0,
                                   0.40698482997817859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076909890516315776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5125574696829347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24573168828330363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14156086558979747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18691753362259766,
                                   0,
                                   0,
                                   -0.31793024831686623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50858695277269583,
                                   0,
                                   0,
                                   0,
                                   0.59453394259857528,
                                   0,
                                   0,
                                   0,
                                   0.053674100942894626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4070005759574053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09974759926245727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14537753474017073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67910812553325361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57155239249932921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12412226418980937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019703916166207397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042759235934848622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81066011915926617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21657519944842923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087801389588333972,
                                   0,
                                   0,
                                   0,
                                   0.28680122941692804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24323668090116249,
                                   -0.17048717049517711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17311562180387888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10467726518489594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20350787329107509,
                                   0,
                                   0,
                                   -0.18213447592361345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038659750337083493,
                                   0,
                                   -0.92990262818276681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40123490749050345,
                                   0,
                                   0,
                                   -0.033127441021320994,
                                   0,
                                   0.40433073447798362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37464143595905153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27000771427443881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13813096827650587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66412173980839795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022710658962783233,
                                   0,
                                   0,
                                   0.13483348169976983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49807559162237869,
                                   0,
                                   0,
                                   0,
                                   -0.17701240626331158,
                                   0,
                                   0,
                                   0,
                                   0.15361100302858438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52922137189522944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075276077485597975,
                                   0,
                                   0.22154687379427465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25141189444249457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36186461665021186,
                                   0,
                                   -0.13554309055599417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12209540183428282,
                                   -0.66162079501976157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34004471934114766,
                                   0,
                                   -0.18619858509020021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0048463849377764386,
                                   0,
                                   0,
                                   1.1137617375135931,
                                   0,
                                   0.0077747478851362449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81245451459961515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23649969823391737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029635728707937202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50363197060515741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0626304634797413,
                                   0,
                                   0,
                                   0.33647667224171068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024151267247025335,
                                   0,
                                   0,
                                   0,
                                   -0.34429640007720019,
                                   0,
                                   0,
                                   0,
                                   -0.076086123916614734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3257438347007971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32608906984560487,
                                   0,
                                   0.27528904084162187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56468339191614725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10338104488308017,
                                   0,
                                   0.56402176100453161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16363196897419419,
                                   -0.19318870300843455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22496656006927462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0059144690112404481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071068250551963905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23409960255446993,
                                   0,
                                   0,
                                   0,
                                   0.29151685616096934,
                                   0,
                                   0,
                                   0.18610926062373331,
                                   -0.079199006968285801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.243842492762746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65623340129995167,
                                   -0.44473975513176445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22017340389125289,
                                   0,
                                   0,
                                   0,
                                   0.1637585929056028,
                                   0,
                                   -0.0089461286264604332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018504132824432459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18732668698673988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21533094516129883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051546357629221579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34387751654225257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40925024919375014,
                                   0,
                                   0,
                                   0,
                                   -0.40438213035096826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40453820778774363,
                                   0.052675565596909307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33505354763199757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31869005254257704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26144256707236119,
                                   0,
                                   0,
                                   -0.13423683249853305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090830919151292211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35257891440842343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5455575997869474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13727427237498699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43989669451536534,
                                   0,
                                   0,
                                   -0.28956167895373763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32052265553027914,
                                   0,
                                   -0.005932214262140148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044141457876381851,
                                   0,
                                   0.41095867524313534,
                                   0,
                                   0,
                                   0,
                                   1.072506127184909,
                                   0.081733980667820436,
                                   0,
                                   -0.69973023749758445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25539394795782977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29050778262457888,
                                   0,
                                   0,
                                   -1.018052696888079,
                                   0,
                                   0,
                                   0.26588045772806601,
                                   0,
                                   0,
                                   -0.63654481777829286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010787724472523325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15724240567859032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22667163488320449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3813136650033529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0093181032157979432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30087530934691809,
                                   0,
                                   0,
                                   0,
                                   -0.34679088874974084,
                                   0,
                                   0,
                                   0.063422309755473846,
                                   -0.22440768769870381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49814354851633424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12466105414450011,
                                   -0.06184521859939815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15604313428911626,
                                   0,
                                   0,
                                   0,
                                   -0.46620922701384271,
                                   0,
                                   0.092714385166552296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14196230156351647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12962469989923481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6345099852886853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094623180039281773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21462661568246733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061604765238013601,
                                   0,
                                   0,
                                   0,
                                   -0.0086071603229508804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039430447321054336,
                                   -0.35435331933854813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.307550297297497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41677450548574863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30582750185627011,
                                   0,
                                   0,
                                   -0.1810179142835813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42970749936069308,
                                   -0.72609332247520786,
                                   0,
                                   -0.035471295689785409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61816875888232681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79722675922702801,
                                   0,
                                   0,
                                   -0.4422059217865637,
                                   0,
                                   0,
                                   0.15548707573306611,
                                   0,
                                   0,
                                   0.099790758506725946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36688284095626189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80570577572963586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021086963809304689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2620824871761171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30520216191261995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19862920428064409,
                                   0,
                                   0,
                                   0,
                                   -0.26562872576352331,
                                   0,
                                   0,
                                   0.17209412745725403,
                                   -0.31985307440384436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31197564164442515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089807459904817963,
                                   0.30475789638399003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053485575174011188,
                                   0,
                                   0,
                                   0,
                                   0.41197754672904197,
                                   0,
                                   -0.14349089999342954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45203737809839223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5891597757098378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097367302568748912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34050284589156032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066547004890297662,
                                   0,
                                   0,
                                   0,
                                   0.0035202764997821559,
                                   0,
                                   0,
                                   -0.52122171650218918,
                                   0.27152939475894378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10328220415278122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094307820806746115,
                                   0.23394936150216439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17401414444523139,
                                   0,
                                   0,
                                   0,
                                   0.17814042736959582,
                                   0,
                                   0.063003932073218583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19325910209678915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20982907590509731,
                                   -0.86281003107074794,
                                   0,
                                   -0.36392992564230287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27173427255170263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14932994223063814,
                                   0,
                                   0,
                                   1.0323853221919777,
                                   0,
                                   0,
                                   0.31546293172319606,
                                   0,
                                   0,
                                   -0.82963449980562365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3966906274925267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36494011255948122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047201836561639933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042130500641925847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88723278683748141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16934863699072455,
                                   0,
                                   0,
                                   -0.57011422031375458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58905491417363476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37099644407710608,
                                   0,
                                   0.21157761333971614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16358388193920798,
                                   0,
                                   0,
                                   0.59828095477526289,
                                   0,
                                   -0.10162285073986793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69537547648343001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15618156864919089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47304897696373671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18822490423570037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0298573485534992,
                                   0,
                                   0,
                                   -0.03349062276973272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19769603787692799,
                                   0,
                                   0,
                                   0,
                                   -0.36908799005738613,
                                   0,
                                   0,
                                   0,
                                   0.35490866250917386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040121306856607183,
                                   0.13551036425864232,
                                   0,
                                   0.32139741003926164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35257960233194519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03905291932538691,
                                   0,
                                   0,
                                   -0.57501683969301676,
                                   0,
                                   0,
                                   -0.98511340943231973,
                                   0,
                                   0,
                                   -0.22937944101542326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.125812158585886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03683819397141401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33802599745893352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16078086778016082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25792071734204608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43873546937064484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75883205043203095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1582717546397476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03287438477736529,
                                   0.14297599400959543,
                                   0,
                                   -0.33761645377316418,
                                   0.21504092213171219,
                                   0,
                                   0,
                                   0,
                                   0.2131172925895638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3885784476585008,
                                   0,
                                   0,
                                   0.53974373766573847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86733480099615679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6589692926469084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33245813839382959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39520755851513961,
                                   0,
                                   0,
                                   0.43216985217827358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41281778420863757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68123662721717659,
                                   0,
                                   0.32399717954145701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17428323897349743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35365621688796806,
                                   0,
                                   -0.1560643081651498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26659536107038262,
                                   0.098221384993786881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1911995522114241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15811579745664189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22274341040573215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25056335999413848,
                                   0,
                                   0,
                                   0,
                                   -0.39065792796336241,
                                   0,
                                   0,
                                   -0.22749608044956418,
                                   0.30907208420457222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023360977418510627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09083064611834446,
                                   -0.29160747411100985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26494558196427986,
                                   0,
                                   0,
                                   0,
                                   0.33294540020197111,
                                   0,
                                   -0.48549675566577033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1247601854171218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24472631393540953,
                                   -0.09241571166954389,
                                   0,
                                   -0.18552200679611566,
                                   0.40405994843423793,
                                   0,
                                   0,
                                   0,
                                   -0.64878151434773967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26767539932921192,
                                   0,
                                   0,
                                   0.59898512382216607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011325514675994831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31814692228218572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30284315905425757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76948013541453764,
                                   0,
                                   0,
                                   -0.2530031229022256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28987241434345951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064300981361892454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05462211684455693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29645061995499583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58934821196118459,
                                   0,
                                   0,
                                   0,
                                   0.25774608188821763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027585429763644708,
                                   -0.35354583448630006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17484534084928238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10922861560868835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47550965449797017,
                                   0,
                                   0,
                                   0.11332094062707034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29458975277231736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0098403374140950545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09423884554225348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43010883964333724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16842644331444359,
                                   0,
                                   0,
                                   0,
                                   -0.033741798285096075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2933313010459086,
                                   0.0060311220500050555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46124547746636591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22146735189977554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033067089494720668,
                                   0,
                                   0,
                                   0.58375616327264646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15754693352796603,
                                   0,
                                   -0.24369630342668394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59876630260766095,
                                   0,
                                   0,
                                   0.048653818135208513,
                                   0,
                                   0.23765418215097706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28884343229607556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47820431088606735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62860546516701865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028138645240915423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70581419438003301,
                                   0,
                                   0,
                                   -0.59827816584407723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60167529119268659,
                                   0,
                                   0,
                                   0,
                                   0.069176032019495917,
                                   0,
                                   0,
                                   0,
                                   0.11064325074193079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0063961388712144348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9126847169065242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1984916426616421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25416822695031194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033673202179928807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24865918963546332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023012919477517421,
                                   -0.72748450199568726,
                                   0,
                                   -0.013658564909121679,
                                   0.09041664329354622,
                                   0,
                                   0,
                                   0,
                                   0.39975262810089929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87457016710793811,
                                   0,
                                   0,
                                   -0.30213597615335952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51383880603557841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024246883415631235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22510557857926089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22092148964990602,
                                   0,
                                   0,
                                   0.197110704585643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13875456797679292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12339138662921978,
                                   0,
                                   -0.061069876410488458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47864716508252836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45596302400251454,
                                   0,
                                   0.7175406827860431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099382020773602989,
                                   0.0067379790246217125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32659365288916659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.663210395656745,
                                   0,
                                   0,
                                   -0.030293625199911432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38875683181055909,
                                   0,
                                   1.0013889056709426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43111753921589252,
                                   0,
                                   -0.42549229014278078,
                                   0,
                                   0,
                                   -0.64427339460302568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58939906320431268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085857435693257697,
                                   0,
                                   0.22790367134084411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28563574942019132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06759407169085925,
                                   0,
                                   0.012223480064602943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35938170794729946,
                                   0.61468349276097367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48071322503354469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87062755813640902,
                                   0,
                                   0,
                                   -0.46462561937283264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52725498828158002,
                                   0,
                                   0.0062195235876097085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33069012546440701,
                                   0,
                                   0.40553822758515051,
                                   0,
                                   0,
                                   -0.031505144756005077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15947869789266889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20198452733401151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18932934679125449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48197194557271833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014552950827592032,
                                   0,
                                   0,
                                   -0.63118776879392791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21869695405197245,
                                   0,
                                   -0.45193384487287014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10233665907450142,
                                   0,
                                   -0.066866286452862383,
                                   -0.3918321175860861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24093691374591331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24289082529762762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2302683518400952,
                                   0,
                                   0,
                                   0,
                                   0.1963224454801023,
                                   0,
                                   0,
                                   0.32241628885609575,
                                   0.3861408615318474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17854306681162715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0014058369291573454,
                                   0.19355906522735442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24720750183468237,
                                   0,
                                   0,
                                   0,
                                   -0.12645313149898155,
                                   0,
                                   0.00050758366645695108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48821212766585109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096055802722991829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35728382507406875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11491710593330966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029977220078944294,
                                   0,
                                   0,
                                   0,
                                   0.027143875371051542,
                                   0,
                                   0,
                                   -0.55896530748024686,
                                   -0.050277999328085701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091948199403634662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17976833646455456,
                                   -0.20724848815890379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50033619542539431,
                                   0,
                                   0,
                                   0,
                                   -0.1877615934184462,
                                   0,
                                   -0.091956805254139934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39438591953764984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52941116360077745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5145677579179917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24017808087534981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34851327508553626,
                                   0,
                                   0,
                                   -0.12141242889555043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9805078695920898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19603106348136565,
                                   -0.28810714964910911,
                                   0,
                                   -0.66638367651902064,
                                   0.41251457321456653,
                                   0,
                                   0,
                                   0,
                                   0.37468130162776259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34453293029184062,
                                   0,
                                   0,
                                   -0.098027262078526384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25908559539533377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30587308380982575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71239891991102833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34308644240982411,
                                   0,
                                   0,
                                   0.79549133388473992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7861848075499942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01943297800493363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30748366829371149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47579498214539612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13219529364756336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20768519633997365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83453677423857131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12758011737754679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33410994641599773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1717207441709496,
                                   0,
                                   0,
                                   -0.19785292319270259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57182278404478848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10163038731859772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28460034229309006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19398424829919228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25657581614590247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5428226619907468,
                                   0,
                                   0,
                                   -0.2091164890374948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20133541615660977,
                                   0,
                                   -0.20009309104978795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30123580169671599,
                                   0,
                                   0.54360879320907252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52943089578644753,
                                   0,
                                   0.18930415593228472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013736372626225058,
                                   0,
                                   0,
                                   0.044584778917997572,
                                   0,
                                   0.41607960247382053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26549693571423783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10019829818961583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54565340225028036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44634309504229713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10983147537925318,
                                   0,
                                   0,
                                   -0.29754483497089468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39442171924203973,
                                   0,
                                   0,
                                   0,
                                   -0.32156866600912598,
                                   0,
                                   0,
                                   0,
                                   -0.95196054992393619,
                                   0,
                                   0.013430376159210113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097342256128021665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061766083128015209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2710126142849425,
                                   0,
                                   0,
                                   0,
                                   -0.14297065210957863,
                                   0,
                                   0,
                                   0.17532571232041502,
                                   0.46076694279339392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28386035522365138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25622884746777191,
                                   -0.30566587973290904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16755625358612342,
                                   0,
                                   0,
                                   0,
                                   0.30538981967112139,
                                   0,
                                   0.52310019111019601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12231897692414487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22672882391373764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48246619546902092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41311678579158212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16128374648145005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07971743116876355,
                                   0,
                                   0,
                                   -0.33271369692397107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33602773917775208,
                                   0,
                                   0.44238551034668067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13859197947076718,
                                   0,
                                   0.27251035588815459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27197562867200942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56843521941255559,
                                   0,
                                   -0.070023408305979168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024509494080220913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70195577341251314,
                                   0,
                                   -0.27966920839780313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051304695640828832,
                                   0.15432990630853202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051685234641392998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24398803039038347,
                                   0,
                                   -0.80178255948195098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50074669157969631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15276994274564754,
                                   0,
                                   0.12293482444993506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048518540010578919,
                                   0.058226115575783305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25580939082906307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6409281901801297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019261090978341767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14444592749658852,
                                   0,
                                   0,
                                   0,
                                   -0.42732608867505495,
                                   0,
                                   0,
                                   0.14695103800667469,
                                   -0.1039305250563175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061881557041382762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12661549753383078,
                                   -0.25225888862805274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12662642216918518,
                                   0,
                                   0,
                                   0,
                                   0.011759212244113998,
                                   0,
                                   0.081301296838002246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42574106965036967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0036698396036891553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58175624507745827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2008519217775285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11051207166666896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049976586829965849,
                                   0,
                                   0,
                                   0,
                                   -0.19442577609524056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034272033685523701,
                                   0.046030246175122018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24165813294376826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53990196205604224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071636117049059062,
                                   0,
                                   0,
                                   0.45866641310637812,
                                   0,
                                   0,
                                   0,
                                   -0.20899027649909704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11231004054625526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38401640373205115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44644516597315526,
                                   0,
                                   0,
                                   0,
                                   -0.45665606769100819,
                                   0,
                                   0,
                                   0.058912596684513319,
                                   0.045320005039463283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16423590243759773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45531956705669463,
                                   0.17794578912782039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28138428209879263,
                                   0,
                                   0,
                                   0,
                                   -0.1898330528915545,
                                   0,
                                   -0.034568380776081944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022484543734718448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53388932815472989,
                                   0,
                                   -0.13852302908636735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052916976997635465,
                                   0,
                                   0,
                                   -0.64165749711377373,
                                   0,
                                   0.27488215728955723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089736865513391384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17403403312409801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82730482114467152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16619069028009639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097952487962692097,
                                   0,
                                   0,
                                   0.54769799703303923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69058785481911023,
                                   0,
                                   0,
                                   0,
                                   -0.23881288988363195,
                                   0,
                                   0,
                                   0,
                                   -0.30618664407240925,
                                   0,
                                   0,
                                   0,
                                   0.044459551684047575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39576923077345683,
                                   0,
                                   0,
                                   -0.84460654058566209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9329635904603808,
                                   0,
                                   0.36081863094853117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2261075097724534,
                                   0,
                                   -0.1982130521197672,
                                   0,
                                   0,
                                   0.081868731016211352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22794813966015279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02088179987716211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78738474792516977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015264785736544566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26721256671859706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50595779003614461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3080525700782433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28190972089482391,
                                   0,
                                   0,
                                   0.2306959348765939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1329534310904984,
                                   0,
                                   -0.39030305935153159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040752881300184951,
                                   0,
                                   -0.014776668871018417,
                                   0,
                                   0,
                                   -0.5491677919537955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14709109834587922,
                                   -0.28888572021586789,
                                   0,
                                   -0.31277899692040784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35596463684429502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16608381493505953,
                                   0,
                                   0,
                                   0.092748122490154794,
                                   0,
                                   0,
                                   -0.36446960441928483,
                                   0,
                                   0,
                                   1.2034260020140453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48835951633594865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40615181223659852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58849784744771905,
                                   0,
                                   -0.30893287235943329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085823382346809515,
                                   0,
                                   0,
                                   -0.2444193741184823,
                                   0,
                                   0.256726069187169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44087670506420279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11913913960857367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10192079071054944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88884318321564515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10286931499776977,
                                   0,
                                   0,
                                   0.37476223375313894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18295439395221363,
                                   0,
                                   0,
                                   0,
                                   -0.47764566925348989,
                                   0,
                                   0,
                                   0,
                                   0.31485555265113541,
                                   0,
                                   0,
                                   0,
                                   -0.0071701900715119282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18339712707429592,
                                   0,
                                   0,
                                   -0.86434691357046955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77273722334358619,
                                   0,
                                   -0.43744366309572758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57560044259857668,
                                   0,
                                   -0.72231369483244035,
                                   0,
                                   0,
                                   -0.57690148184231249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4069336941017036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15569707051345738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26077605576518414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31973009144756209,
                                   0,
                                   0,
                                   0,
                                   0.25079231060294493,
                                   0,
                                   0,
                                   0.19939573801426638,
                                   -0.1772350334835941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1441772913025387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40398969354684211,
                                   -0.143677551875207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04008176203184477,
                                   0,
                                   0,
                                   0,
                                   0.17467927289522611,
                                   0,
                                   -0.49832836588408502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14413760337698542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3446148419862145,
                                   0,
                                   0.73087147592451052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55991637247854709,
                                   0,
                                   0,
                                   -0.028615102674788413,
                                   0,
                                   0.0028655535681815737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34251681176880927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51907980191235292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23608834284256366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045182935146847771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18220495424564451,
                                   0,
                                   0,
                                   0.53920407205789733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59695133924599642,
                                   0,
                                   0,
                                   0,
                                   0.79086111474854837,
                                   0,
                                   0,
                                   0,
                                   -0.51165315813485257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45393841079465397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083313440082531928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2869398904545874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72922592331238378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037349650794608169,
                                   0,
                                   0,
                                   -0.163653872138222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090931121017370387,
                                   0,
                                   -0.24876659141888691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10191489109884204,
                                   0,
                                   -0.25333046571287143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22360934600957019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36109949643033579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39802311015766079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23475087953284615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086543317740050821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77368333092322328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50833292361043603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43888915458130362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33808201795342863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080591462957507229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30286918871237256,
                                   0,
                                   0,
                                   0.066088724977912294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54815582620108194,
                                   0,
                                   -0.14810897935610601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0150537995586549,
                                   0,
                                   0.097182058599998081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20103559973567109,
                                   0.32649697686621743,
                                   0,
                                   -0.58170452855609178,
                                   -0.15965065574287529,
                                   0,
                                   0,
                                   0,
                                   -0.042140388875790878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41576137392164147,
                                   0,
                                   0,
                                   0.68856154434146433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38234761480473944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64099447090719597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47794604094757809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31077551299406986,
                                   0,
                                   0,
                                   0.39379988180981285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39824260593743044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28251443409775329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23322756213129001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36398866087115289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20894412909828042,
                                   0,
                                   0,
                                   0,
                                   -0.59081712286226562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12874984596683303,
                                   -0.37197840749316691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10635447489647649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11796647113931948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042372141358184352,
                                   0,
                                   0,
                                   -0.003979839911911226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66805834109564444,
                                   -0.81973238846585028,
                                   0,
                                   -0.18254004221164627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.717483808396147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41378507983760304,
                                   0,
                                   0,
                                   -0.56278349086666568,
                                   0,
                                   0,
                                   -0.11217745149194414,
                                   0,
                                   0,
                                   0.19623555929703418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082230959197744466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13157795887691215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36949877245740592,
                                   0,
                                   0.29235375595568225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17935381704796471,
                                   0,
                                   0,
                                   -0.17402520333374516,
                                   0,
                                   1.0134574845058981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86354815763177761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084961973602494967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48219158643608839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12525066181161904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076280898978819553,
                                   0,
                                   0,
                                   0.24053114183826965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087438010972203287,
                                   0,
                                   0,
                                   0,
                                   0.10163422247306682,
                                   0,
                                   0,
                                   0,
                                   0.86075196982560165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94095814465798322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89571936086548753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36972299326071295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4655623846890633,
                                   0,
                                   0,
                                   -1.0656934856220002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72905626195767737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6786814608146311,
                                   -0.28442726582808658,
                                   0,
                                   -0.33472723970492596,
                                   0.34195112219233653,
                                   0,
                                   0,
                                   0,
                                   -0.42022813158587202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036585689919206632,
                                   0,
                                   0,
                                   0.27861112817203876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15886316757205238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41131745125524777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11965440443603501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84195829451536319,
                                   0,
                                   0,
                                   -0.50611603038338349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095112567447866753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15123736026900939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35319853254023448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4117290192047357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10985085970239902,
                                   0,
                                   0,
                                   0,
                                   -0.024238239228377631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0090833309708075738,
                                   -0.65037051866152185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16371210424385013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3246156310088863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32538188960866943,
                                   0,
                                   0,
                                   -0.0064431830716971811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44766893596641638,
                                   0,
                                   0.64375347131871119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6104907948086411,
                                   0,
                                   0,
                                   -0.084264383612151009,
                                   0,
                                   0.54378708969349421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51511884839015798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69661006946776671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056563682833206688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24647957428819964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31334410372502808,
                                   0,
                                   0,
                                   0.25214514101963731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47962379490596307,
                                   0,
                                   0,
                                   0,
                                   0.47195227986791111,
                                   0,
                                   0,
                                   0,
                                   -0.15373786706497342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27397907055571186,
                                   -0.55246212106820458,
                                   0,
                                   0.25545331790286313,
                                   -0.67440243725337501,
                                   0,
                                   0,
                                   0,
                                   -0.55152364400483234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18044183544804479,
                                   0,
                                   0,
                                   0.17445151137395304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20234618515720965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24057480876044532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36152608971227945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093314844014609849,
                                   0,
                                   0,
                                   0.81933472681443631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34870499780440106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15757025511010064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15253290119069179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23680675303620186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18927401611267877,
                                   0,
                                   0,
                                   0,
                                   -0.33139839045091773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37727988431165216,
                                   0.17962645134496846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54274520550864003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36036540444603338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13016063077739656,
                                   0,
                                   0,
                                   -0.11224982340811254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0093648591962189713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024489352851753254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32433720473654315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12937272622403337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47586476743079881,
                                   0,
                                   0,
                                   0.36394905182119303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1765984232413855,
                                   0,
                                   -0.48205753024903403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34392716760259212,
                                   0,
                                   0.36962426186925046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40304948701253812,
                                   0,
                                   0.18468124122824575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045028277229797617,
                                   0,
                                   0,
                                   0.30698279972758069,
                                   0,
                                   0.36479757243622379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28459942016759454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69051308217268403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72915588399116449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067718441460964923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48006581881863813,
                                   0,
                                   0,
                                   -0.06646380144719749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25510926714576793,
                                   0,
                                   0,
                                   0,
                                   -0.24002356395424057,
                                   0,
                                   0,
                                   0,
                                   0.34152913335479801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028457830937049455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56423236742144478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3510505109208894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12995954403860019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24668567934902697,
                                   0,
                                   0,
                                   -0.056326291313624779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40687395392779463,
                                   0,
                                   0.46938732620683876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019137861527991407,
                                   0,
                                   0.30073648512687567};

const double rot_27_30[9000] = {-0.073019404935417725,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11793601662366453,
                                0,
                                0,
                                0,
                                -0.077486409414125906,
                                0,
                                0,
                                0,
                                0.098704134757824732,
                                0,
                                -0.24200307636310975,
                                0,
                                -0.2166519699846384,
                                0,
                                0,
                                0,
                                -0.23282968977552226,
                                0,
                                -0.89738474642442823,
                                0,
                                -0.92474752100468682,
                                0,
                                -0.53798753249113318,
                                0.13450149825565305,
                                0,
                                -0.22740073259196741,
                                0,
                                0,
                                -0.29662397506052751,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90577600888927534,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21980440723999428,
                                0,
                                0,
                                0.48932318529353908,
                                0,
                                0,
                                0.13901272716170077,
                                0,
                                0,
                                0,
                                0.18818185951285743,
                                0.99554009395687593,
                                0,
                                0,
                                0,
                                0,
                                0.10669030509675698,
                                0,
                                -0.57848383315677998,
                                0,
                                0,
                                0,
                                0,
                                -0.093536010001740791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20173217266652166,
                                0,
                                1.0698970226628308,
                                -0.56270582464545493,
                                0,
                                1.3308319975998817,
                                0,
                                0,
                                -0.41240051804943656,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24290587091789972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0446712696834175,
                                0,
                                0.33965444399837513,
                                0.19983998767838146,
                                0,
                                0.11102175771709449,
                                0,
                                0,
                                0.39766248467601706,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0973845636979158,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25677326791963617,
                                0,
                                0,
                                -0.66088083159212552,
                                0,
                                0,
                                -0.48048765551441597,
                                0,
                                0,
                                0,
                                -0.70465088392302633,
                                0.41382192782561111,
                                0,
                                0,
                                0,
                                0,
                                0.34876364682098232,
                                0,
                                -0.28243967545002624,
                                0,
                                0,
                                0,
                                0,
                                -0.88760709659431236,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59850588673438909,
                                0,
                                -0.03737037357326034,
                                0.11272200266762233,
                                0,
                                -0.72997430514215034,
                                0,
                                0,
                                -1.2845434908684132,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40602814141676735,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24557733340829052,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24757047458780224,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18733116015420043,
                                0,
                                0,
                                1.300887716659975,
                                0,
                                0,
                                -0.42286274294044801,
                                0,
                                0,
                                0,
                                -0.50452034259433598,
                                -0.13316228357438178,
                                0,
                                0,
                                0,
                                0,
                                0.17813345107679129,
                                0,
                                0.49866631732406658,
                                0,
                                0,
                                0,
                                0,
                                -0.065567274943729298,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43824531473762873,
                                0,
                                0.76014123397083522,
                                0.66990147330773298,
                                0,
                                -0.35200802404836212,
                                0,
                                0,
                                -0.023937250577568125,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45330572897873955,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58241312225713271,
                                0,
                                0,
                                0,
                                -0.24130686766374349,
                                0,
                                0.37250367880917379,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26074460961819079,
                                0,
                                -0.44001268625638612,
                                0,
                                0.44967548788336109,
                                0,
                                0.41191689307438101,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25677306874797468,
                                0,
                                0,
                                0,
                                0.55250704774719817,
                                0,
                                0,
                                0,
                                -0.21615734030164391,
                                0,
                                -0.071846036522507262,
                                0,
                                -0.34028079530424832,
                                0,
                                0,
                                0,
                                0.52914903067613506,
                                0,
                                -0.10701617404258526,
                                0,
                                0,
                                1.1314426723017157,
                                0,
                                0,
                                0.11596328896769065,
                                0,
                                0,
                                -0.14449132329089309,
                                0,
                                0,
                                0,
                                -0.13734517077112116,
                                -0.40597122690057064,
                                0,
                                0,
                                0,
                                0,
                                0.37335388913305267,
                                0,
                                0.16698850123433517,
                                0,
                                0,
                                0,
                                0,
                                0.21470393117518471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3575251504075207,
                                0,
                                0,
                                0.14441599933484606,
                                0,
                                0,
                                0.86162165421682813,
                                0,
                                0,
                                0,
                                -0.58345167342354731,
                                -0.040499484959098775,
                                0,
                                0,
                                0,
                                0,
                                -0.61643545983166759,
                                0,
                                0.23075247315547792,
                                0,
                                0,
                                0,
                                0,
                                -0.1259272641036478,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.055607678769275137,
                                0,
                                0,
                                0,
                                0.73313324955597281,
                                0,
                                0.39664981684746214,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44758421648234881,
                                0,
                                -0.093370946349033174,
                                0,
                                0.30502882287750344,
                                0,
                                -0.18647858857530042,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11189387304812616,
                                0,
                                0,
                                0,
                                0.5847385834990213,
                                0,
                                0,
                                0,
                                0.15056620379484292,
                                0,
                                0.16922565253682548,
                                0,
                                0.71542229671713531,
                                0,
                                0,
                                0,
                                -0.01910967602725501,
                                0,
                                -0.21745008757234352,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3059297013794276,
                                0,
                                0,
                                0,
                                -0.34491799644518462,
                                0,
                                0.12815408414509871,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.064169796221077838,
                                0,
                                0.55061200459663817,
                                0,
                                0.68097267339158429,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60710936468945798,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19464694718495748,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38990605644977322,
                                0,
                                0,
                                0.14846182725622376,
                                0,
                                0,
                                -0.96423417929370059,
                                0,
                                0,
                                0,
                                -0.48687521125528122,
                                0.49397759524951146,
                                0,
                                0,
                                0,
                                0,
                                -0.82561982297416381,
                                0,
                                -0.16801797511105776,
                                0,
                                0,
                                0,
                                0,
                                0.028080377907548554,
                                0,
                                0,
                                0,
                                0,
                                -0.60471201267701558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11630562434913318,
                                0,
                                0,
                                0,
                                0.078716440361812703,
                                0,
                                0,
                                0,
                                -0.58177544594401021,
                                0,
                                0.44707283529816677,
                                0,
                                -0.22363814042764962,
                                0,
                                0,
                                0,
                                0.098147392947561862,
                                0,
                                -0.12890456673214748,
                                0,
                                0,
                                0.40308050576755877,
                                0,
                                0,
                                -0.24422421466295732,
                                0,
                                0,
                                0.21081779571626547,
                                0,
                                0,
                                0,
                                0.48428511698450338,
                                -0.047704765212218031,
                                0,
                                0,
                                0,
                                0,
                                -0.47637686363658099,
                                0,
                                0.51841398967279972,
                                0,
                                0,
                                0,
                                0,
                                -0.88619303007749461,
                                0,
                                0,
                                0,
                                0,
                                -0.02228829737630228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27006650738589749,
                                0,
                                0,
                                0,
                                -0.28875608093054306,
                                0,
                                0,
                                0,
                                -0.39826053966703251,
                                0,
                                -0.49415399860482334,
                                0,
                                0.44064991576181178,
                                0,
                                0,
                                0,
                                0.47345441100916347,
                                0,
                                -0.14851323091275204,
                                0,
                                0.15761951835786139,
                                0,
                                -0.16646607439602135,
                                1.013698174519484,
                                0,
                                0.50497954177340498,
                                0,
                                0,
                                -0.23234843580021375,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3131849493985317,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55834487787600995,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65119313103713783,
                                0,
                                0,
                                0,
                                0.071206535459138659,
                                0,
                                0,
                                0,
                                -0.18224087951515999,
                                0,
                                0.35756162845067385,
                                0,
                                0.071868114814629055,
                                0,
                                0,
                                0,
                                -0.21614166012497615,
                                0,
                                -0.21490424209920275,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59906657879411607,
                                0,
                                0,
                                0,
                                -0.35737644387911921,
                                0,
                                0.52374581096623363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10114430557141274,
                                0,
                                -0.42927876364653095,
                                0,
                                -0.21114262847689474,
                                0,
                                0,
                                0,
                                -0.10692954027292537,
                                0,
                                0,
                                -0.63749254039776893,
                                0,
                                0,
                                -0.33143064067847189,
                                0,
                                0,
                                0,
                                -0.24044666453060154,
                                0.98919367162342708,
                                0,
                                0,
                                0,
                                0,
                                0.06466277021940886,
                                0,
                                0.85666182157271009,
                                0,
                                0,
                                0,
                                0,
                                0.007249779448671001,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.090821936368544187,
                                0,
                                0,
                                0,
                                0.30981703635509905,
                                0,
                                0.45892874268991335,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7298937168210472,
                                0,
                                0.34584206824344188,
                                0,
                                -0.18110111807971641,
                                0,
                                0.21642335383440914,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42891032472002028,
                                0,
                                0,
                                0,
                                0.025475828922345928,
                                0,
                                0,
                                0,
                                -0.62495681302105033,
                                0,
                                -0.17590505531046727,
                                0,
                                0.16316117135454405,
                                0,
                                0,
                                0,
                                -0.55330902528698334,
                                0,
                                0.11942275946119743,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44382470519864803,
                                0,
                                0,
                                0,
                                0.24822105286721757,
                                0,
                                -0.450067991989894,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42963687756001401,
                                0,
                                -0.43658920007325075,
                                0,
                                0.40453277540254839,
                                0,
                                -0.25584549731167566,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4616914241078528,
                                0,
                                0,
                                0,
                                0.50151457277367806,
                                0,
                                0,
                                0,
                                -0.0025363404982707421,
                                0,
                                -0.55206895906900022,
                                0,
                                -0.22241601050562548,
                                0,
                                0,
                                0,
                                -0.28065347748357672,
                                0,
                                0.19195160578313475,
                                -0.39156771685339814,
                                0,
                                0.22165335566178368,
                                0,
                                0,
                                0.021917864593184594,
                                0,
                                0,
                                0,
                                0.99963128129547629,
                                0,
                                0.46341859993879325,
                                0,
                                0,
                                0,
                                0,
                                0.32841237007541574,
                                0,
                                0,
                                0,
                                -0.14273083668653114,
                                -0.27464328846880959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28698342896541151,
                                0,
                                0.72655511787130478,
                                0,
                                0,
                                0.047601613104245113,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.088041224468176082,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15975379127566933,
                                0,
                                0,
                                0,
                                0.21701346783442821,
                                -0.55418774107459168,
                                -0.00091105019318471481,
                                -0.22985414478494051,
                                0,
                                -0.79238776023822566,
                                0,
                                0,
                                -0.15375108205624713,
                                0,
                                0,
                                0,
                                0.24984105126586112,
                                0,
                                0.29218656440814622,
                                0,
                                0,
                                0,
                                0,
                                -0.53911142647697574,
                                0,
                                0,
                                0,
                                0.10911512105017654,
                                0.1054676153134015,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22911034109208406,
                                0,
                                0.00061431000545131287,
                                0,
                                0,
                                0.56410800812970863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26383870606596416,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58618056287164322,
                                0,
                                0,
                                0,
                                -0.3945475323510057,
                                -0.013397167735715823,
                                0.24540675397619588,
                                0,
                                0,
                                0,
                                0,
                                -0.20927428086336838,
                                0,
                                0,
                                -0.28153294525119854,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73302229485973813,
                                0.43878173315792685,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36476220748240989,
                                -0.11849436267331559,
                                0,
                                0,
                                0,
                                -0.72479315605642014,
                                0,
                                -0.30352582191780753,
                                0,
                                0,
                                0.81979585466288829,
                                0,
                                0,
                                0,
                                -0.14849732109962599,
                                0,
                                -0.058169485221166162,
                                0,
                                0,
                                0,
                                0,
                                0.45497974950520026,
                                0,
                                0,
                                0,
                                0.1629486621454434,
                                0.70815715273351809,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45124079902515829,
                                0,
                                0.21975957758875625,
                                0,
                                0,
                                -0.41848891418535389,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18980499756644748,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13592347622345338,
                                0,
                                0,
                                0,
                                -0.6340548694951621,
                                0.30712926710638205,
                                -0.14865868734592719,
                                0,
                                0,
                                0,
                                0,
                                0.36448213064135837,
                                0,
                                0,
                                -0.13118302574159879,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49166092820784207,
                                0.69158686499644295,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31868181785666244,
                                0.16841267471951193,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50748629771956377,
                                0,
                                1.0292835510127429,
                                0,
                                0.84596140826295152,
                                0,
                                0,
                                0.37106847734787773,
                                0,
                                -0.3588672548568887,
                                0,
                                0,
                                0,
                                0,
                                0.16036983788291942,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67685691335336939,
                                0,
                                -0.24708751282275315,
                                0,
                                0,
                                0.41428196177608934,
                                0,
                                0,
                                0,
                                -0.33134165519667175,
                                0,
                                1.0779157696133101,
                                0,
                                0,
                                0,
                                0,
                                0.27050205920597409,
                                0,
                                0,
                                0,
                                -0.39492305683111023,
                                -0.51959975083620924,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1862847282735303,
                                0,
                                0.011756808181469319,
                                0,
                                -0.2305397736311216,
                                0,
                                0,
                                -0.56995948173880673,
                                0,
                                -0.69060286781958657,
                                0,
                                0,
                                0,
                                0,
                                0.45942203751759092,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15145889167970406,
                                0,
                                -0.8402580057042357,
                                0,
                                0,
                                -0.58045314727465835,
                                0,
                                0,
                                0,
                                0.23208809425425039,
                                0,
                                -0.35527982144384429,
                                0,
                                0,
                                0,
                                0,
                                0.88652433523485175,
                                0,
                                0,
                                0,
                                -0.54237292620328781,
                                0.17078538747795866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17892590115645063,
                                0,
                                -0.21405233483896541,
                                0,
                                0.19854387761203957,
                                0,
                                0,
                                0.70406259161544071,
                                0,
                                -0.79252819027837551,
                                0,
                                0,
                                0,
                                0,
                                0.58932664069712759,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17948690365185052,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25259762625219395,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21211366524722733,
                                0,
                                0.18426248227997841,
                                0,
                                0,
                                0.012365205505338109,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54348952167797138,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42748473624919803,
                                0,
                                0,
                                0,
                                0.32019707311582102,
                                0.51429812651288298,
                                0.27522616857018267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0643048400297792,
                                0,
                                -0.5039989118046404,
                                0,
                                0.98891778629859739,
                                0,
                                0,
                                0.19886108791586218,
                                0,
                                0.66979744092089244,
                                0,
                                0,
                                0,
                                0,
                                -0.49074741365536423,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20190699625105415,
                                0,
                                0.4692935052713727,
                                0,
                                0,
                                -0.73258384758960082,
                                0,
                                0,
                                0,
                                -0.73834387657434497,
                                0,
                                1.1580983858083491,
                                0,
                                0,
                                0,
                                0,
                                0.31331496084220822,
                                0,
                                0,
                                0,
                                0.15297439529262111,
                                0.39689376530256343,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33051601764639504,
                                0,
                                0.16968446871803716,
                                0,
                                -0.83049410518783517,
                                0,
                                0,
                                1.227376461935777,
                                0,
                                0.40555515412078708,
                                0,
                                0,
                                0,
                                0,
                                -0.09386371048000601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43572421436906633,
                                0,
                                0,
                                0.26467024515675852,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40820548193983086,
                                -0.03681472958717863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.077349633827425851,
                                0.75241216410128342,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0054479990726890998,
                                0,
                                0,
                                0.18073568847263116,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.091277123746849875,
                                -0.44315578027893576,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87139978486610969,
                                0.056998124877907147,
                                0,
                                0,
                                0,
                                -0.6581182302339641,
                                0,
                                0.37392590574178503,
                                0,
                                0,
                                -0.012094163528198615,
                                0,
                                0,
                                0,
                                -0.8291764964748275,
                                0,
                                -0.19948294596253494,
                                0,
                                0,
                                0,
                                0,
                                -0.26955661078002013,
                                0,
                                0,
                                0,
                                -0.61817615392496472,
                                -0.6998176688834713,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28471989124340213,
                                0,
                                0.27449142615090971,
                                0,
                                0,
                                0.27642453411318174,
                                0,
                                0,
                                0,
                                0.25862101927312009,
                                0,
                                -0.17932152516805111,
                                0,
                                0,
                                0,
                                0,
                                -0.15499969943888856,
                                0,
                                0,
                                0,
                                -0.97407931728315378,
                                0.79974358641590826,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26950371675147716,
                                0,
                                -0.33719750265011006,
                                0,
                                -0.57548091091980613,
                                0,
                                0,
                                -0.33266746470787828,
                                0,
                                1.0262376772313955,
                                0,
                                0,
                                0,
                                0,
                                1.0504069081186327,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59476677824961399,
                                0,
                                0.18978703974389313,
                                0,
                                0,
                                -0.58986519828104456,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33151696605000253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28183758766118239,
                                0,
                                0,
                                0,
                                0.21516108752936511,
                                0.1081170751160057,
                                0.12236374780365275,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.073669017254724439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60052789029433451,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19717238517500718,
                                0,
                                0,
                                0.89247987292012099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.040937329575326489,
                                0.34815358571962712,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0083516099853323533,
                                -0.20407398992851022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77109975402357578,
                                0,
                                0,
                                -0.065529864710210536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21049644451719224,
                                0.1011182953410131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00036145932928438596,
                                0.58870808786354001,
                                0,
                                0,
                                0,
                                0,
                                0.16369085034257425,
                                0,
                                0.3984904289044946,
                                0,
                                0,
                                0.38497938883463279,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24841865300298732,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20515693652543671,
                                0,
                                0,
                                0,
                                0.16966926307642372,
                                0.518344683494949,
                                -0.51471495825694913,
                                0,
                                0.075718020731717017,
                                0,
                                0.32410157181432775,
                                0,
                                0,
                                0.079629357326333999,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.078137360443727488,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55186315879853221,
                                0,
                                0,
                                0,
                                -0.17052706191085865,
                                0.17791292232122058,
                                0.71518755444059257,
                                0,
                                -0.47985733687797044,
                                0,
                                -0.30002462859656709,
                                0,
                                0,
                                0.04170677968570316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64304767293312137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.059815903466795453,
                                0,
                                0,
                                0,
                                0.4341937644279068,
                                0.14779036884500443,
                                0.22478485901957782,
                                -0.89499054544082424,
                                0,
                                -0.052594495496112954,
                                0,
                                0,
                                0,
                                -0.17145687375418336,
                                0,
                                0,
                                -0.35440082699010755,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15357768328260907,
                                0,
                                0,
                                -0.1328240644000741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35982425396552276,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21202359599960666,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32212358912011529,
                                0,
                                0.31510716141021866,
                                0,
                                0,
                                0,
                                0.74504755943470635,
                                0,
                                0,
                                0.44001678821651913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.093844839871588454,
                                0,
                                0,
                                -0.19856076263413192,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3432524137941001,
                                -0.22756389337968319,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67778233484159811,
                                0.09503840439494024,
                                0,
                                0,
                                0,
                                0.06288990034153831,
                                0,
                                0,
                                0,
                                0,
                                -0.38315515017198187,
                                0.20694980759014953,
                                0,
                                -0.4103413598350204,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14566716692631534,
                                -0.34841302774125338,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33511279247428805,
                                -0.053394768250095682,
                                0,
                                0,
                                0,
                                0.28915794712815579,
                                0,
                                0,
                                0,
                                0,
                                0.5502220254751955,
                                -0.57782020359245834,
                                0,
                                -0.14834106052745921,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6688503804304009,
                                0,
                                -0.26945426074324952,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1516136154494383,
                                0,
                                0,
                                0,
                                -0.26740852139700966,
                                0,
                                0,
                                0,
                                0.14008516240829996,
                                0,
                                0.13699466886884767,
                                0,
                                0,
                                0,
                                -0.6977725449971981,
                                -0.93893270680762886,
                                0.25170110815863089,
                                0,
                                0.20708883651682441,
                                0,
                                0,
                                0,
                                0.17160490430070152,
                                0,
                                0,
                                -0.25571498901331652,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80716038186128092,
                                0,
                                0,
                                -0.38394594034740515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18758414541273577,
                                0,
                                0.042713876008732887,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43333727921510928,
                                0,
                                0,
                                0,
                                -0.87127848135070785,
                                0,
                                0,
                                0,
                                -0.36085483025658671,
                                0,
                                -0.14823477260601639,
                                0,
                                0,
                                0,
                                -1.1841381331861474,
                                0.21744221574613176,
                                0,
                                0.41022395125749589,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43176203723949508,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10969682007934529,
                                0,
                                0.3632290686579096,
                                0,
                                0,
                                0,
                                0.056562909969847953,
                                0,
                                0,
                                0.023761519392818078,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34402323471742474,
                                0,
                                0,
                                0.85668856227501688,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40701711576848709,
                                -0.25513838731613125,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4478727377885296,
                                0.66746409270642992,
                                0,
                                0,
                                0,
                                -0.094825695839361193,
                                0,
                                0,
                                0,
                                0,
                                0.048926124475884666,
                                -0.20283535585290638,
                                0,
                                -0.26573540722114997,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23217104372009645,
                                0.062018631992669507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.049022256692360669,
                                0.16277688205101559,
                                0,
                                0,
                                0,
                                0.43119101923207365,
                                0,
                                0,
                                0,
                                0,
                                -0.67372712185646189,
                                -0.4929524945032725,
                                0,
                                0.17468459901729264,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41455824464990765,
                                0.4914474361754213,
                                0,
                                0,
                                0,
                                -1.1943594811500746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3687208795407434,
                                -0.15324176528371983,
                                -0.27424486074044579,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3897076148572232,
                                0.53211121379555326,
                                0,
                                0,
                                0,
                                0.41433641556158407,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30774333782613972,
                                0.71724746454755672,
                                0.13690029401902531,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0294437974959039,
                                0,
                                -0.3428859125437192,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11061760020338027,
                                0,
                                0,
                                0,
                                -0.2256861407887206,
                                0,
                                0,
                                0,
                                0.078493977103162416,
                                0,
                                -0.41193435811374002,
                                0,
                                0,
                                0,
                                0.24515104951767594,
                                -0.57953391309557067,
                                0,
                                0,
                                0,
                                -0.16190042125840229,
                                -0.18994721389114932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36245810244402987,
                                0.55422221978969521,
                                0,
                                0,
                                0,
                                -0.15131316719406804,
                                0,
                                0,
                                0,
                                0,
                                0.10060643179446713,
                                0.1642960776182327,
                                0,
                                0.66269120621142008,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.078257196617197849,
                                0,
                                0.49557191953619323,
                                0,
                                0,
                                0,
                                -0.61867941888489775,
                                0,
                                0,
                                0.55056408660617928,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.092916718479111593,
                                0,
                                0,
                                -0.23187438487174913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60065605869342309,
                                -0.77918339412484761,
                                0,
                                0,
                                0,
                                -0.020496900948027752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.86130966345149307,
                                1.1438722730053765,
                                -0.090057519035286165,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3755845056905599,
                                0,
                                -0.3420110180507544,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31302598254218778,
                                0,
                                0,
                                0,
                                0.24221564110213106,
                                0,
                                0,
                                0,
                                0.83993798040660228,
                                0,
                                0.50176543354803271,
                                0,
                                0,
                                0,
                                -0.29379215168518347,
                                0.6500262221230475,
                                0.1171208260631957,
                                0,
                                0.69103446072590025,
                                0,
                                0,
                                0,
                                0.0097388555161030278,
                                0,
                                0,
                                -0.55830968202773623,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43487200022789158,
                                0,
                                0,
                                -0.088520524493792302,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58323135442271634,
                                0.21896933284768455,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.019594394216917332,
                                0.39813077209580328,
                                0,
                                0,
                                0,
                                0.31887844007310318,
                                0,
                                0,
                                0,
                                0,
                                0.13719708877724607,
                                0.37049652050565757,
                                0,
                                -0.44184544141243737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40508158739746175,
                                0.073439264360485146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1391953583151419,
                                0.060252811330170034,
                                0,
                                0,
                                0,
                                -0.76954989593035139,
                                0,
                                0,
                                0,
                                0,
                                -0.16416638513323983,
                                -0.33880067238130412,
                                0,
                                -0.27123106940746883,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13355487919847031,
                                0,
                                0.031908668596906518,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1437673610809425,
                                0,
                                0,
                                0,
                                -0.5695383827405488,
                                0,
                                0,
                                0,
                                0.046929371561091823,
                                0,
                                -0.045287052304314783,
                                0,
                                0,
                                0,
                                0.46484983792712908,
                                0.34015256777743441,
                                0,
                                0,
                                0,
                                -0.33306287574534277,
                                -0.81759420912268943,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27236407234217808,
                                -0.21635916934465318,
                                0,
                                0,
                                0,
                                -0.02699551728856367,
                                0,
                                0,
                                0,
                                0,
                                -0.19557749334306537,
                                0.24516214553685567,
                                0,
                                -0.023055595561501441,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11969668014253469,
                                0,
                                -0.13482558335244257,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5464426233804035,
                                0,
                                0,
                                0,
                                0.28972126300157242,
                                0,
                                0,
                                0,
                                -0.88684650382369989,
                                0,
                                0.62870281894385893,
                                0,
                                0,
                                0,
                                -0.62663990437416228,
                                0.044989617638042961,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36002058652114011,
                                0.86028878041367962,
                                0,
                                0,
                                0,
                                0.27100716194871982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.085800532515203878,
                                0.82794494431524135,
                                -0.82534243985016142,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.050187090834850429,
                                -0.15463771591134176,
                                0,
                                0,
                                0,
                                -0.11396414705799762,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3168206339226654,
                                -0.77860453957187459,
                                0.058194020005986176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51983172904584618,
                                1.0697209670703083,
                                0,
                                0,
                                0,
                                -0.1577538853508825,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21485718830142672,
                                0.051804861293264448,
                                0.95906502279537165,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51145879442395015,
                                0,
                                -0.87929960698579734,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39486837687361914,
                                0,
                                0,
                                0,
                                -0.31138501506952321,
                                0,
                                0,
                                0,
                                -0.3679828095240476,
                                0,
                                0.61994112742322516,
                                0,
                                0,
                                0,
                                0.40680186557305065,
                                0.29047638625258554,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45796290570585174,
                                0,
                                -0.44250938899567016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12415183275424539,
                                0,
                                0,
                                0,
                                0.36010522115413596,
                                0,
                                0,
                                0,
                                0.13325720671599481,
                                0,
                                -1.217363911803899,
                                0,
                                0,
                                0,
                                -0.11817472306225915,
                                -0.034961539588134805,
                                -0.83554260133699132,
                                0,
                                0,
                                0,
                                1.4155673165647364,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43552592644698707,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.037406253685380364,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10488429387205503,
                                0,
                                0,
                                -0.53685841404703183,
                                0,
                                0.27422953021058105,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0076448730845167512,
                                0.65356060097502555,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45350546114619816,
                                -0.22131589585425293,
                                -0.051224696435661216,
                                0,
                                0,
                                0.48932322267205197,
                                -0.029818563192843511,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41786352084175754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34595818828121433,
                                0,
                                0,
                                0,
                                0,
                                -0.029499862407340732,
                                0,
                                -0.98971932737791457,
                                0.6759273970262073,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22696791587233003,
                                -0.67872730081423738,
                                0.10918039634627749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25759736604194938,
                                0,
                                0,
                                0,
                                0,
                                -0.56253601019953647,
                                0,
                                0,
                                0.26692487700186712,
                                0,
                                0,
                                0,
                                -0.30091653168273191,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.81513849963816898,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.03392328526276378,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32452140317485434,
                                0,
                                0,
                                -0.48251763407494325,
                                0,
                                0,
                                0,
                                -0.74215464261842923,
                                0,
                                0.049178813404885134,
                                -0.30722871447247968,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23238599973859692,
                                -0.052922298907218564,
                                0.39469903058533962,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63607497838522487,
                                0,
                                0,
                                0,
                                0,
                                -0.24561207857799433,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35496152163888012,
                                0,
                                0.18039996988154813,
                                -0.32363824767325211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3743567201109731,
                                0.097240166330345004,
                                -0.38979621075571891,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54094118193700835,
                                0,
                                0,
                                0,
                                0,
                                -0.73384582540159449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54914534273935012,
                                0,
                                0,
                                0.047752445429396856,
                                0,
                                0.24349920897175417,
                                -0.34600084550635801,
                                0,
                                0,
                                0,
                                -0.59037906600881918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41061320614510649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.017043374673932354,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46224304367361946,
                                0.18546914331379952,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.023399071456117151,
                                0.45558025171139005,
                                -0.47976386082097877,
                                0,
                                0,
                                -0.082162677618857483,
                                0.55373020397639972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57473920346992979,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24561661987473438,
                                -0.43853897594723507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16842185059511477,
                                0.44338341389606867,
                                0.17642110957353974,
                                0,
                                0,
                                0.31526254618943733,
                                -0.24811537276474649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1498287326831341,
                                0,
                                0,
                                -0.024144088402481632,
                                0,
                                -0.80601342708427004,
                                0.10329145993980812,
                                0,
                                0,
                                0,
                                -0.47037215456842835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30885543499800522,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.82451439615723465,
                                0,
                                0,
                                0,
                                -0.78221221322048884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15259134046557682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7684918903002278,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10312088901488789,
                                0,
                                0,
                                -0.35818422534749278,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45421626122496822,
                                0,
                                0,
                                0.69168960150092096,
                                0,
                                -0.19964039290699545,
                                -0.22722855808840614,
                                0,
                                0,
                                0,
                                0.46348400651329646,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.094586229598690008,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65798140004547201,
                                0,
                                0,
                                -0.3545072706353245,
                                0,
                                0.11385395085468866,
                                0.61241355554764298,
                                0,
                                0,
                                0,
                                0.21778525223712175,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.07708158681020244,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14217666614432228,
                                0,
                                -0.64541278015555947,
                                0.59420968224460402,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18876790673216343,
                                0.57037574666983382,
                                0.025365002713335263,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40743590616008729,
                                0,
                                0,
                                0,
                                0,
                                0.20153395653726613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36235827161532302,
                                0,
                                -0.82061805584435887,
                                -0.80136432617939213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59901800902299129,
                                -0.22836189555344527,
                                0.52553516436879022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.041262415477794773,
                                0,
                                0,
                                0,
                                0,
                                -0.089054247823167426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74587137012374582,
                                0,
                                -0.41407694812194168,
                                0.068678000308115439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61530127296469961,
                                -0.35151215723714546,
                                0.29389358347963124,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28853066224593638,
                                0,
                                0,
                                0,
                                0,
                                -0.20432803057754392,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1252791917911506,
                                0,
                                0,
                                0.11210841057579421,
                                0,
                                -0.37883047923944391,
                                0.33080053883637428,
                                0,
                                0,
                                0,
                                0.12558018599581386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.83846581133183962,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.074441124716302196,
                                0,
                                0,
                                0,
                                -0.05010360583307924,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28374527010137213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23734944464886301,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1556804931858473,
                                0,
                                0,
                                0.2428320428009435,
                                0,
                                -0.2628626638385953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58109021032320707,
                                0.15079029206418704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12769884063261083,
                                0.61601946909139471,
                                0.16407174374184427,
                                0,
                                0,
                                0.35931185075593702,
                                0.13670461535260439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51968699479998104,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17128905885202267,
                                0.0071625262127829013,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29102753397161391,
                                -0.21769235035525963,
                                0.38795162377473841,
                                0,
                                0,
                                -0.052345227828288959,
                                0.64436070160505321,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46959816222582318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30714098915205829,
                                -0.35840807794692864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14303575009223501,
                                -0.2500927794247681,
                                0.22471293181589697,
                                0,
                                0,
                                0.54606693043397181,
                                0.35354633376048888,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10780997778527251,
                                0,
                                0.45701094674827436,
                                -0.18807319791959692,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21187097827672263,
                                -0.57876159506710623,
                                -0.50705153300832861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56999049126436518,
                                0,
                                0,
                                0,
                                0,
                                0.66393524456672381,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14506527064537555,
                                0,
                                0,
                                -0.61681323062259663,
                                0,
                                -0.30776443911526297,
                                -0.57749641738153723,
                                0,
                                0,
                                0,
                                0.39010815311252034,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1345067752352791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.090337292121059148,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49695369664426237,
                                -0.41265667955583668,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58334288549548319,
                                -0.094689661059087549,
                                -0.38452979394413633,
                                0,
                                0,
                                -0.11552291661468247,
                                0.25323289912296554,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16225881552866178,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13281966153621999,
                                -0.15688341156587593,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55106006307527533,
                                -0.22021485154264742,
                                -0.60024428092411242,
                                0,
                                0,
                                0.45939301190124254,
                                -0.089003928822351336,
                                0,
                                0,
                                0,
                                0,
                                -1.0392278621410955,
                                0,
                                0,
                                0,
                                -0.9117774590440435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39507410570852031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0555062220257101,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13314742993245623,
                                0,
                                0,
                                0.34485345511853016,
                                0,
                                0,
                                0,
                                -0.020069127637207702,
                                0,
                                -0.82404306728092569,
                                -0.87807754836027285,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36794562376548517,
                                0.033694340013945528,
                                -0.59495733943211881,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.029035774666867901,
                                0,
                                0,
                                0,
                                0,
                                -0.19935019960607897,
                                0,
                                0,
                                0,
                                0,
                                0.16484232538593749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40547368682565038,
                                0,
                                0.11311767196377204,
                                0,
                                0,
                                0,
                                -0.065481871717448376,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31490752745868333,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62344738441037251,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56728859280559207,
                                0,
                                0,
                                0.84497096928799897,
                                -0.28650653070904725,
                                0,
                                0,
                                0,
                                0.23111587151946178,
                                0,
                                0,
                                0,
                                0,
                                -0.64511585763299939,
                                -0.62434896438265752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084154965094794587,
                                0,
                                0,
                                -0.22678470968630621,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27524956126444555,
                                -1.0181200313309449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25298211580363278,
                                0,
                                0,
                                0,
                                -1.0713927336370541,
                                0,
                                0,
                                0.53676217921119951,
                                0,
                                0,
                                0,
                                -0.26741230256555887,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1773446205732199,
                                -0.029053718424066677,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45749990426859866,
                                0,
                                0,
                                0,
                                0.46652071170989412,
                                0,
                                0,
                                -0.28525689570315504,
                                0,
                                0,
                                0,
                                -0.10979953965420097,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33625165547160318,
                                0,
                                -0.25908899240720346,
                                0.45399539836574976,
                                -0.22627174046792806,
                                0,
                                0,
                                0,
                                -0.17422924494300968,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27926733458083375,
                                -0.62964315700113094,
                                0,
                                -0.24020911060725503,
                                0,
                                -0.46985916719787924,
                                0,
                                0,
                                0,
                                -0.74252224830585678,
                                0,
                                0,
                                0,
                                0,
                                -0.15570354024848448,
                                -0.062623324142782932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28002735171169441,
                                0,
                                0,
                                0.34829941557754884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46744903725793668,
                                0,
                                -0.26499467817109368,
                                -0.22083519409892263,
                                -0.60376927794122182,
                                0,
                                0,
                                0,
                                -0.1475105705794259,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15200408847465627,
                                0.20128476612566223,
                                0,
                                -0.46106781035907402,
                                0,
                                0,
                                0,
                                0,
                                0.0092673584465464403,
                                0,
                                0.28663789340674467,
                                0.16957124505966256,
                                -0.16415491202159058,
                                0,
                                0,
                                0,
                                -0.81532546241083215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13494165713543588,
                                0.20194516330337964,
                                0,
                                0.37189364389745139,
                                0,
                                0,
                                0,
                                0,
                                0.44128735350169762,
                                0,
                                -0.12662729516297919,
                                0.37345805567259432,
                                0.21482941184817467,
                                0,
                                0,
                                0,
                                -0.23986869817880249,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69895114861069108,
                                -0.17090343874308364,
                                0,
                                -0.16831731441830405,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38772385263275161,
                                0,
                                0,
                                0,
                                0,
                                0.85674162934360942,
                                0.73437145761412648,
                                0.16488900189183159,
                                0,
                                -0.15396041959261461,
                                -0.6050019437354115,
                                0,
                                0.40641452134153577,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11059996355516497,
                                0.65119271493430919,
                                0,
                                0,
                                0,
                                0.014493012370030575,
                                0,
                                0,
                                0,
                                0,
                                -0.13261589289560294,
                                -0.35224832299752751,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5720766821454154,
                                0,
                                0,
                                0.32680332656102046,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.046852157139411321,
                                0,
                                0,
                                0,
                                -0.14370941834057185,
                                0,
                                0,
                                0,
                                0,
                                0.076403390506975102,
                                0.096748820645247036,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58427422037901644,
                                0,
                                0,
                                -0.78776792361385439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31894607173989076,
                                0,
                                -0.12300196983674677,
                                0.29121285126553104,
                                0.59926869238821845,
                                0,
                                0,
                                0,
                                -0.049048491421141746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57785476943070746,
                                0.23005359858125551,
                                0,
                                -0.22353854485162317,
                                0,
                                0,
                                0.22862357161969121,
                                0.74548392606170022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.09896736244364,
                                0,
                                0,
                                0,
                                -0.015427005054744015,
                                0,
                                0,
                                -0.41301866151257771,
                                0,
                                0,
                                0,
                                -0.52207643757723421,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10259517877184149,
                                0,
                                0,
                                0,
                                0,
                                0.48196370808926181,
                                -1.0460418018998148,
                                -0.10912359040579303,
                                0,
                                -0.32181440048005161,
                                0.042063743399206072,
                                0,
                                0.71770186804082747,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24992613747362336,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1994329711367773,
                                0,
                                0,
                                0,
                                0,
                                0.67386761630011849,
                                0.32835581092068433,
                                0.43724994524736038,
                                0,
                                0.40534536733948184,
                                0.50326125561298163,
                                0,
                                -0.16437194314966708,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2295186670277764,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35050195322232103,
                                0,
                                0,
                                0,
                                0,
                                0.20824949026165102,
                                -0.52517836273108753,
                                -0.31576948640792629,
                                0,
                                0.49072379866994664,
                                -0.9900156096513355,
                                0,
                                -0.12949005806819822,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47983330279375341,
                                0,
                                0.22678658304636024,
                                -0.7333070625591237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87279537127917195,
                                0,
                                0,
                                0,
                                0.586187809521443,
                                0,
                                0,
                                0.28568520945643505,
                                0,
                                0,
                                0,
                                1.3504305756355446,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.098498540198924178,
                                0,
                                0,
                                0,
                                0,
                                -0.051805936941978839,
                                0.41715321836507496,
                                -1.0669765833864981,
                                0,
                                0.0868050895128019,
                                0.015469940091500167,
                                0,
                                0.60747133913937246,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37373754165033418,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1025583245401382,
                                0,
                                0,
                                0,
                                0,
                                -0.41980740616991208,
                                -0.015674395758472327,
                                0.239595176758506,
                                0,
                                -0.36382508678654019,
                                -1.0261701774687331,
                                0,
                                0.055548931056887518,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22843866699644627,
                                0,
                                -0.62753503194919324,
                                0.40184227400027689,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14447086758177805,
                                0,
                                0,
                                0,
                                -0.0057031658056658982,
                                0,
                                0,
                                1.0908100232994391,
                                0,
                                0,
                                0,
                                0.21559688644279135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41685429952517838,
                                0,
                                0,
                                0,
                                0,
                                -0.11866139798897073,
                                0.48867453705709091,
                                0.70256411353045345,
                                0,
                                0.77954015362239437,
                                -0.041863480015619306,
                                0,
                                0.57009264387835046,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47180885771213649,
                                0.015843081858502278,
                                0,
                                0,
                                0,
                                -0.22887611536574171,
                                0,
                                0,
                                0,
                                0,
                                0.64706481868522492,
                                -0.6840461598735299,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20692727327044041,
                                0,
                                0,
                                -0.13391712262181754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61954358047001001,
                                0,
                                0,
                                0,
                                0,
                                0.103245339718652,
                                0,
                                0,
                                0,
                                -0.02486566424320874,
                                0.72285912223940585,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28220296981652004,
                                0,
                                0,
                                0,
                                -0.77287512822452353,
                                0,
                                0,
                                -0.62752906857075852,
                                0,
                                0,
                                0,
                                1.0514631993704484,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52023868657210803,
                                0,
                                0,
                                0,
                                0.56744994862133913,
                                0,
                                0,
                                0,
                                0,
                                0.34273109732693663,
                                -0.070059444467337362,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4505947545922776,
                                0,
                                0,
                                0.28625810224917064,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17007055887638667,
                                0,
                                -0.66207973984853352,
                                0.19833539234146211,
                                -0.14763786501142356,
                                0,
                                0,
                                0,
                                0.17179660956230336,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.046476791401905609,
                                0.10064622616066234,
                                0,
                                0.65558273772934339,
                                0,
                                0,
                                0,
                                0,
                                -0.11623691789743242,
                                0,
                                0.28540296863097159,
                                0.66912654634061264,
                                -0.32432668379953689,
                                0,
                                0,
                                0,
                                0.35255495818231775,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0725498141919457,
                                0.4576323366050854,
                                0,
                                -0.11458691891908909,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.019298016666957657,
                                0,
                                0,
                                0,
                                0,
                                -0.18155667893166216,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57397229611628386,
                                0,
                                -0.47908354149613802,
                                -0.070869465900639139,
                                0.15829574996776682,
                                0,
                                0,
                                0,
                                -0.26339584591586962,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22543924174001814,
                                0.46964074231730762,
                                0,
                                -0.26493789403786344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18347357225884825,
                                0,
                                0,
                                0,
                                0,
                                -0.44320696529592696,
                                -0.058703158950310114,
                                0.053015331078084649,
                                0,
                                -0.036597538471568505,
                                0.42166239319052873,
                                0,
                                0.82386156635139896,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.9418999278978244,
                                0.19582707582143855,
                                0,
                                -0.35448027264349319,
                                0,
                                0,
                                0,
                                0,
                                0.71112755709339381,
                                -0.42102766690699511,
                                0,
                                0.40645819379484632,
                                -0.88883031309800808,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23595543456821524,
                                0,
                                0,
                                0,
                                0,
                                0.21508136190613047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29498838441373726,
                                0.085374736895893755,
                                0,
                                0,
                                0.38596302761711365,
                                0,
                                0,
                                0,
                                0,
                                -0.63917186922285862,
                                0,
                                0,
                                0,
                                0,
                                0.56975710052037376,
                                1.5078097802591546,
                                1.4785437675423732,
                                0,
                                0.33043626512073399,
                                0,
                                0,
                                0,
                                0,
                                -0.64376037768058403,
                                0.08989823162237115,
                                0,
                                -0.8808591418479581,
                                -0.23102004362585421,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55960073247546427,
                                0,
                                0.26148106352980238,
                                0,
                                0,
                                0,
                                0.046765692660236412,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22690736638476158,
                                0,
                                0,
                                0.10330942483383634,
                                -0.2878869341688306,
                                0,
                                0,
                                0,
                                0.3589601069621276,
                                0.58514665527857035,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.090091230233641656,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21626764815358912,
                                -0.40316719828810144,
                                0,
                                0,
                                0,
                                0.37197104846514428,
                                0,
                                0,
                                0,
                                0,
                                0.38369560206529568,
                                0,
                                0,
                                0,
                                0,
                                -0.70497043121050185,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.083040498833072074,
                                0,
                                -0.50723452438564265,
                                0,
                                0,
                                0,
                                -0.075128785301402393,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38326367307836318,
                                0,
                                0,
                                0.10033835086429008,
                                -0.74377156782169018,
                                0,
                                0,
                                0,
                                -0.14139794455616403,
                                0.0049726113495498214,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13585807912221778,
                                0,
                                0,
                                0,
                                0,
                                0.77576158597263745,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34475433110864934,
                                -0.90947832273531193,
                                0,
                                0,
                                -0.8158021807414706,
                                0,
                                0,
                                0,
                                0,
                                -0.23316891747824131,
                                0,
                                0,
                                0,
                                0,
                                0.36493392147211523,
                                -0.16686037469664336,
                                0.32541104168217072,
                                0,
                                -0.11588040511808409,
                                0,
                                0,
                                0,
                                0,
                                -0.73765387497582924,
                                -1.0687397532649057,
                                0,
                                0.57048186154170344,
                                0.12818596217695516,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20830643619713718,
                                0,
                                -0.99719558117795992,
                                0,
                                0,
                                0,
                                0,
                                -0.047595014510716765,
                                0.31630397458782439,
                                0,
                                0.55155096398297676,
                                0.41539716335199112,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1510446904698747,
                                0,
                                0.32313908740882952,
                                0,
                                0,
                                0,
                                0.13112049131017675,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74883030556298258,
                                0,
                                0,
                                -0.39692841889514269,
                                0.018758391598337698,
                                0,
                                0,
                                0,
                                0.33718448410767676,
                                0.15241324940293544,
                                0,
                                0,
                                0,
                                0,
                                -0.41095421333942184,
                                0,
                                -0.46749444106353072,
                                0,
                                0,
                                0,
                                0,
                                -0.9674414438362714,
                                0.45811870672023169,
                                0,
                                0.109340936698422,
                                -0.41609039169787493,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.087740805291393664,
                                0,
                                -0.64056771278973101,
                                0,
                                0,
                                0,
                                0,
                                0.048587337634553168,
                                -0.74766817664649032,
                                0,
                                -1.1041044864438216,
                                0.35395547422084844,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21560490053808612,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17436677020548688,
                                -0.40717917849759055,
                                0,
                                0,
                                0,
                                0.43074124514207446,
                                0,
                                0,
                                0,
                                0,
                                0.43712421312476085,
                                0,
                                0,
                                0,
                                0,
                                0.61700913683965208,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15998098605826017,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64621377003317515,
                                -0.57318473001611281,
                                0,
                                0,
                                0,
                                -0.37287970152773431,
                                0,
                                0,
                                0,
                                0,
                                -0.23954203661103748,
                                0,
                                0,
                                0,
                                0,
                                0.17847535874883008,
                                0,
                                0,
                                0,
                                -0.27156473670162085,
                                0,
                                0,
                                0,
                                0,
                                -0.80815583748374786,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15093393509180689,
                                -0.36032820600111715,
                                0,
                                0,
                                -0.77242198398744466,
                                0,
                                0,
                                0,
                                0,
                                -0.33489882218886807,
                                0,
                                0,
                                0,
                                0,
                                -0.66815484984220186,
                                0.32671637487028737,
                                0,
                                -0.65446835060572994,
                                0,
                                0,
                                0,
                                0,
                                -0.17237270938916716,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.042333412931209666,
                                0.37520734101352021,
                                0,
                                0,
                                -0.17117553713934264,
                                0,
                                0,
                                0,
                                0,
                                0.62626893127778005,
                                0,
                                0,
                                0,
                                0,
                                1.0101535458348874,
                                -0.17992716936481837,
                                0,
                                0,
                                0,
                                -0.16707093902804426,
                                0,
                                0.57402294617492444,
                                0,
                                0,
                                0,
                                0.39562966917948633,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.048717771466984208,
                                0,
                                0,
                                -0.10850550862269802,
                                -0.36396788006470321,
                                0,
                                0,
                                0,
                                -0.47754226281360934,
                                -0.33376043251374427,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47292136229922555,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24650837794917574,
                                -0.3726041312255054,
                                0,
                                0,
                                0,
                                0.38399182723732561,
                                0,
                                0,
                                0,
                                0,
                                -0.65367747394786702,
                                0,
                                0,
                                0,
                                0,
                                0.044734804611956613,
                                0,
                                0,
                                0,
                                0.80984584130966608,
                                0,
                                0,
                                0,
                                0,
                                0.10370849573103014,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35750517578905805,
                                0.49554029884300632,
                                0,
                                0,
                                -0.48350600303033964,
                                0,
                                0,
                                0,
                                0,
                                0.37807984054314919,
                                0,
                                0,
                                0,
                                0,
                                0.25938037088259025,
                                0.14889704213636593,
                                0,
                                0,
                                0,
                                -0.31741287823322484,
                                0,
                                -0.24257255520220891,
                                0,
                                0,
                                0,
                                0.14858653225038698,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17612228451935935,
                                0,
                                0,
                                -0.26329841796357945,
                                0.36065042068014508,
                                0,
                                0,
                                0,
                                -0.61267145093602993,
                                0.46103092509386839,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68015314985844566,
                                0,
                                -0.02063049263689154,
                                0,
                                0,
                                0,
                                -0.12667506217142069,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34560424791646238,
                                0,
                                0,
                                0.27025375880502678,
                                0.29052836926534159,
                                0,
                                0,
                                0,
                                0.12427245442030162,
                                -0.47811059132096928,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24564251495338493,
                                0,
                                0,
                                0,
                                0,
                                -0.22496669771184502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45134034485235935,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64174400672135157,
                                -0.40010477416116003,
                                0,
                                0,
                                0,
                                -0.37398999049939619,
                                0,
                                0,
                                0,
                                0,
                                -0.094958857361130827,
                                0,
                                0,
                                0,
                                0,
                                -0.27474896733955345,
                                0,
                                0,
                                0,
                                0.31464325610182242,
                                0,
                                0,
                                0,
                                0,
                                -0.53083487784027306,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3557392156106907,
                                -0.52916926383795793,
                                0,
                                0,
                                0.43115717128766118,
                                0,
                                0,
                                0,
                                0,
                                0.77155124649574336,
                                0,
                                0,
                                0,
                                0,
                                0.15389375566999525,
                                -0.15784094411431449,
                                0,
                                0,
                                0,
                                -0.2554575531603564,
                                0,
                                -0.19970330213796825,
                                0,
                                0,
                                0,
                                -0.18974867113275953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28345224981113848,
                                0,
                                0,
                                -0.81683829837316213,
                                -0.10703319665941201,
                                0,
                                0,
                                0,
                                0.1729990760704162,
                                -0.26438740955529694,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.024623049816864341,
                                0,
                                0.37586048939901195,
                                0,
                                0,
                                0,
                                -0.86274221531908069,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.087722420095072778,
                                0,
                                0,
                                -0.018595865635569163,
                                -0.07189512214961688,
                                0,
                                0,
                                0,
                                -0.29778455928406317,
                                0.10914616937753674,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37539507138272321,
                                0,
                                0,
                                0,
                                0,
                                0.03838559491683334,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70174173268259754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18063927221904302,
                                0.21024491239038137,
                                0,
                                0,
                                0,
                                0.49974194405411437,
                                0,
                                0,
                                0,
                                0,
                                -0.40988814988219585,
                                0,
                                0,
                                0,
                                0,
                                -0.11390682462838903,
                                0,
                                0,
                                0,
                                -0.10030330496066182,
                                0,
                                0,
                                0,
                                0,
                                -0.32802962598240787,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7768384396915089,
                                -0.69410660536533442,
                                0,
                                0,
                                0.096681476819220041,
                                0,
                                0,
                                0,
                                0,
                                1.091721868086555,
                                0,
                                0,
                                0,
                                0,
                                0.052872717840542816,
                                0.37914533751566776,
                                0,
                                0.63375991870469894,
                                0,
                                0,
                                0,
                                0,
                                -0.46987197255890278,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28277572190375311,
                                -0.82180381309362205,
                                0,
                                0,
                                0.39269722059706025,
                                0,
                                0,
                                0,
                                0,
                                -0.69829443064504992,
                                0,
                                0,
                                0,
                                0,
                                0.72882507975697708,
                                -0.47911539339657155,
                                0.41828070578407889,
                                0,
                                1.1476881495138684,
                                -0.41482073053240198,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15607050937859698,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21571635260052702,
                                0,
                                0,
                                -0.63585596034263459,
                                0,
                                0,
                                -0.12943008663079944,
                                -0.62513028443408258,
                                0,
                                0,
                                -0.38951780812774978,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.032580739514599916,
                                0,
                                0.16182354141060948,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.096017870197429966,
                                0,
                                0,
                                0,
                                0.055631080694899693,
                                0,
                                0.89928486336245617,
                                0,
                                0,
                                0,
                                0,
                                0.65231789293705034,
                                0,
                                0.11379424302026533,
                                0.62523786194280673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3447966112828031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64101428750013234,
                                0,
                                0,
                                0.34898571115552546,
                                0,
                                0,
                                -0.04792317320741727,
                                0.5230401970913604,
                                0,
                                -0.7047120175101933,
                                0,
                                0.097187199448926939,
                                0.045999470274289744,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                3.1840138773629734e-05,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30008938299906351,
                                0,
                                0,
                                0.94108511446291199,
                                0,
                                0,
                                0.2714913712473746,
                                -0.70106955613472843,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0061798604612815,
                                0.69686381369478578,
                                -0.71812735360470026,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.045049396024197802,
                                -0.16511517578574253,
                                0.67035759790981553,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0617953004808445,
                                -0.33597344884622493,
                                0.8050950839447284,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17654735802758456,
                                0.60324269056424384,
                                0.39252550486703192,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71341644603349708,
                                -0.18260064582590818,
                                -0.16120296703791664,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.9930531156179373,
                                -0.27346444629633265,
                                -1.135560948169634,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37307480998513975,
                                -0.09730183644933818,
                                0,
                                0.019627987377713568,
                                0,
                                0.0098454459390199534,
                                0,
                                0.81826677129190895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28580622099069253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21080526366444596,
                                0,
                                0,
                                0.23490590443366433,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24600001889634754,
                                -0.40908875748971585,
                                0,
                                -0.051997482524817423,
                                0,
                                0.42011765056261763,
                                0,
                                0.10431471574807578,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65957889952764592,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20874187723044529,
                                0,
                                0,
                                -0.32160339668907911,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12302070694274844,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55797119131509554,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33087969128929179,
                                -0.3675037723524946,
                                0,
                                0.088971925481461323,
                                0,
                                -0.42907271688331028,
                                0,
                                -0.092908466821280969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.059004881180349661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74190266115588088,
                                0,
                                0,
                                -0.030117925909982326,
                                0,
                                -0.41517750424791344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49656642864563211,
                                0,
                                -0.20443870762351499,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13155382256079184,
                                0,
                                0,
                                0,
                                -0.71045970176796036,
                                0,
                                -0.13112909923906083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17016917600647241,
                                0.61249674008858568,
                                0,
                                -0.24983066163496634,
                                0,
                                0.24763061789417826,
                                0,
                                -0.18534680198951498,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15225880267555597,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55464775473995398,
                                0,
                                0,
                                0.32708347660575809,
                                0,
                                -0.55111360362319972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46853883129426127,
                                0,
                                -0.43837372456308188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52438742947630868,
                                0,
                                0,
                                0,
                                0.040115175721467083,
                                0,
                                -0.089343346521235933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.09738414665158672,
                                0.18904169971042589,
                                0,
                                -0.5229626904478879,
                                0,
                                -0.58839368751861332,
                                0,
                                0.30169849944193117,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46742942250944058,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15413701295890345,
                                0,
                                0,
                                -0.042567455671868176,
                                0.35643097792196782,
                                0,
                                -0.72672970832397543,
                                -0.53465391692105813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51800532560261792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.082267711993282394,
                                0,
                                0,
                                -0.065167377231199058,
                                0,
                                0,
                                -0.62206826532348447,
                                -0.71563135633853481,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32377225169788482,
                                0.98130116617421592,
                                0.024592221072249579,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22436424553471818,
                                -0.017414289967006946,
                                -1.094468617789528,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.044792906101365715,
                                -0.37683897129791455,
                                -1.0794443040992514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.82221177290276604,
                                0.18032030795835813,
                                -0.050209308447032683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30744393888402899,
                                -0.025368581144275093,
                                -0.76956762512166643,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65704268502607255,
                                0.97677005860066446,
                                -0.23547104417080328,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19787533802341206,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0027866606492429058,
                                0,
                                -0.8252512321022063,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46820695182346367,
                                0,
                                0,
                                0,
                                0.17455869730494147,
                                0,
                                0.17352089354806921,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59644201872667124,
                                -0.32377731085036349,
                                0,
                                0.04762998609210016,
                                0,
                                -0.33774760062854936,
                                0,
                                -0.37568510003827821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13475097708365036,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11139986364198465,
                                0,
                                0,
                                0.50137417577599919,
                                -0.48635897994758898,
                                0,
                                -0.27924530122756214,
                                -0.14135810258324744,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.097728033246091972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79607911918700414,
                                0,
                                0,
                                -0.83602636787062212,
                                0,
                                0,
                                0.50206398136563302,
                                0.22567405484131886,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15147031162815722,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11735576473657715,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40434989664136423,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56570947255466419,
                                0,
                                0.00073410201534484382,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.011432207616630816,
                                0,
                                0,
                                0,
                                0.67769007026327177,
                                0,
                                -0.23891188362625435,
                                0,
                                0,
                                0,
                                0,
                                0.70728850773172536,
                                0,
                                -0.049077976786419661,
                                -0.34376939811605145,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1985394026410213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33275530331793141,
                                0,
                                0,
                                -0.50966715708859334,
                                0,
                                0,
                                0.92972143665034646,
                                -0.27051108292178894,
                                0,
                                0,
                                -0.4117327102715021,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46129889237733762,
                                0,
                                0.24250010080671899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6922019496308961,
                                0,
                                0,
                                0,
                                0.028432333057620773,
                                0,
                                -0.28092930010367917,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51729808670787425,
                                0.10471405467236158,
                                0,
                                -0.25573897879147783,
                                0,
                                -0.19005817269348746,
                                0,
                                -0.18278551328375092,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3612569583668821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12476717135556076,
                                0,
                                0,
                                -0.66364835649505338,
                                0.50488717786344184,
                                0,
                                -0.31461362045452046,
                                -0.3476632802048788,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66595300395567514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55178471289054898,
                                0,
                                0,
                                0.695552411521001,
                                0,
                                0,
                                0.14169864103455024,
                                -0.36750010552412066,
                                0,
                                0.39572608661471786,
                                0,
                                -0.50873259379265934,
                                0.85469438004079645,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35979888687836498,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17348474179177564,
                                0,
                                0,
                                -0.43687900485524978,
                                0,
                                0,
                                0.12090112994460989,
                                -0.80698348881027526,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1704000999227922,
                                -0.40178839867500177,
                                0,
                                -0.76512654146670567,
                                0,
                                0.28561727072789034,
                                0,
                                -0.10488416486964852,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29908440200822828,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.046896520148196577,
                                0,
                                0,
                                0.19970625346892742,
                                0.32202337925096347,
                                0,
                                0,
                                0,
                                0,
                                -0.62273327498243214,
                                0,
                                0.51202180552824317,
                                0,
                                0,
                                0,
                                -0.23872740870651368,
                                -1.0379273928958928,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15893951106251078,
                                0,
                                0,
                                -0.81025644908225303,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19600414980164904,
                                0,
                                0,
                                0.098889851637071771,
                                0,
                                0.21334546677955768,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69500155661775842,
                                0,
                                0,
                                0,
                                -0.23776888198298721,
                                0.083254607284530796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0023006860861172207,
                                0,
                                0,
                                0,
                                0,
                                -0.3372745849036981,
                                0,
                                0,
                                -0.53334091882653234,
                                0,
                                0,
                                1.0172526135068083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15677089312056025,
                                0,
                                0,
                                0,
                                0,
                                -0.62203885339760046,
                                0,
                                0,
                                0.024625578358109967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61635461974964734,
                                0,
                                0,
                                0,
                                0.53321465201340112,
                                0,
                                0,
                                0,
                                0.42453729149826941,
                                0,
                                -0.0037337437750550179,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1026655640305324,
                                0,
                                0,
                                0,
                                0.79341026608877596,
                                0.20458144094634312,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35600702656836353,
                                0,
                                0,
                                0,
                                0,
                                -0.006279056448543964,
                                0,
                                0,
                                -0.10526197516837621,
                                0,
                                0,
                                0,
                                0,
                                0.33479212367288663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23700325602000893,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.025666900427912,
                                0,
                                0,
                                0,
                                0,
                                -0.65674768843424491,
                                0,
                                0.23847845118345112,
                                0,
                                0,
                                0,
                                0.36673406371161976,
                                0.40314089020975974,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58789977314157016,
                                0,
                                0,
                                -0.16926719744205537,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.011796975442745494,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5700958313079536,
                                0,
                                0,
                                0.6307897643195336,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1110434559162628,
                                0,
                                -0.15269510376002393,
                                0,
                                0,
                                0,
                                -0.43428560394079485,
                                -0.22987950485127706,
                                0,
                                0,
                                0,
                                0,
                                -0.0019044918091534746,
                                0,
                                0,
                                0,
                                0,
                                -0.53177949845788275,
                                0,
                                -0.34465467210373546,
                                0,
                                0,
                                0,
                                -0.23744365144355492,
                                0.78691353137541076,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.020517806044760764,
                                0,
                                0,
                                -0.63621371323160159,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22435899910083262,
                                0,
                                0,
                                0,
                                0.74739697241792347,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64413765381421062,
                                0,
                                0,
                                0,
                                0,
                                0.32258396083309704,
                                0,
                                0,
                                0.55470266481004515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45572881933172815,
                                0,
                                0,
                                0,
                                0.92778040858104827,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35264433180655752,
                                0,
                                0,
                                -0.16332846544681262,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34956655553804306,
                                0,
                                0.24934151008240518,
                                0,
                                0,
                                0,
                                -0.29646337547759394,
                                -0.75941246317072131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76211003689364043,
                                0,
                                -0.081263167642773596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36035783121994891,
                                0,
                                0,
                                0,
                                0.47126854707841359,
                                -0.073089809954821533,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16601211280849387,
                                0,
                                0,
                                0,
                                0,
                                -0.097345383591180557,
                                0,
                                0,
                                0.13510926555497449,
                                0.17148435488109295,
                                0,
                                0,
                                0,
                                0,
                                0.21050452289373139,
                                0,
                                -0.47124611035796571,
                                0,
                                0,
                                0,
                                0.61055074779674356,
                                0.17991358078754868,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.95524600242574087,
                                0,
                                0,
                                -0.57274730455417844,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16324458745031523,
                                0,
                                0.58195463246170498,
                                0,
                                0,
                                0,
                                0,
                                -0.20152137184779684,
                                0,
                                0.48455393814536973,
                                0,
                                0,
                                0,
                                0.98884316986906284,
                                0.33917059935069566,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36779093444038863,
                                0,
                                0,
                                0.40308156226567787,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39497559188701103,
                                0,
                                0,
                                0,
                                -0.62864142675774481,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23024645771362948,
                                0,
                                0,
                                0,
                                0,
                                -1.0861114702425505,
                                0,
                                0,
                                0.84032261145940956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32213596614054224,
                                0,
                                0,
                                0,
                                0.20897390915895692,
                                0,
                                0,
                                0,
                                0.04158507543151703,
                                0,
                                -0.05968526936187106,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17778999466052917,
                                0,
                                0,
                                0,
                                -0.17401387556251519,
                                -0.22195475743189788,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57293750981055069,
                                0,
                                0,
                                0,
                                0,
                                -0.48374141654879138,
                                0,
                                0,
                                0.56682552558408772,
                                0,
                                -0.060390150331216641,
                                0,
                                0.26412901272994016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49899996128620128,
                                0,
                                0,
                                0,
                                0.19811055117500795,
                                -0.39151480831681484,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10320324903479426,
                                0,
                                0,
                                0,
                                0,
                                -0.60994608785714832,
                                0,
                                0,
                                -0.31995492915698875,
                                0,
                                0,
                                0.32541175302149539,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2820716752871497,
                                0,
                                0,
                                0,
                                0,
                                0.77118558724146613,
                                0,
                                0,
                                0.065443284140925984,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22136005309292636,
                                0,
                                0,
                                0,
                                0.29151709947830928,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.019694448935501922,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36028158229646468,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17252170122354413,
                                0,
                                0,
                                0.14473093905395287,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.089165804235649251,
                                0,
                                0.95597122575428706,
                                0,
                                0,
                                0,
                                -0.0097863810156387891,
                                0.16541438727924429,
                                0,
                                0,
                                0,
                                0,
                                -0.74695374937312464,
                                0,
                                0,
                                0,
                                0,
                                0.90395209297341217,
                                0,
                                0.69058522204936368,
                                0,
                                0,
                                0,
                                0.10763847090110169,
                                0.27923315868348819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25791905123596059,
                                0,
                                0,
                                -0.82256821550709847,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42243053162805499,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10535661043437317,
                                0,
                                0,
                                0.5081094685441272,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13960584166881032,
                                0,
                                0.014914611644834031,
                                0,
                                0,
                                0,
                                0.78842808674466425,
                                -0.29898773884084051,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45040268080866924,
                                0,
                                -0.30169053369720417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27505649582175251,
                                0,
                                0,
                                0,
                                0.12798125863155518,
                                -0.5262404773167636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54338019486378375,
                                0,
                                0,
                                0,
                                0,
                                -0.034774540035110296,
                                0,
                                0,
                                0.20170429785150407,
                                0.30526851460633231,
                                0,
                                0,
                                0,
                                0,
                                0.19528660443070839,
                                0,
                                0.71742934618744436,
                                0,
                                0,
                                0,
                                0.037869453030665766,
                                -0.10811405036202221,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10238388924134703,
                                0,
                                0,
                                -0.62929610236903266,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.302894067080858,
                                0,
                                0,
                                0,
                                0.082854706550732932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54387292701181567,
                                0,
                                0,
                                0,
                                0,
                                0.18238253017625428,
                                0,
                                0,
                                1.3589526057541979,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50773791229013332,
                                0,
                                0,
                                0,
                                -0.71248853295784542,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35970461498557715,
                                0,
                                0,
                                -0.27202502138598839,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71968585332001078,
                                0,
                                -0.0021797407263913215,
                                0,
                                0,
                                0,
                                0.16009430453643383,
                                -0.50302317303921573,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6167508050848346,
                                0,
                                0,
                                0.4714957015719391,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56576012143437782,
                                0,
                                -0.020120518314328185,
                                0,
                                0,
                                0,
                                -0.27597223346556204,
                                0.025694822819827472,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1447003454050777,
                                0,
                                0.50536366860344728,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0065936123470487218,
                                0,
                                0,
                                0,
                                0.051255400999652589,
                                0.49518393257285409,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43643650469480533,
                                0,
                                0,
                                0,
                                0,
                                -0.27000044322211975,
                                0,
                                0,
                                0.46088457512833542,
                                0,
                                0,
                                -0.38578972098696857,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23389783343817527,
                                0,
                                0,
                                0,
                                0,
                                0.52894772842327209,
                                0,
                                0,
                                -0.045720145346881194,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52827296404638113,
                                0,
                                0,
                                0,
                                1.0606348082863357,
                                0,
                                0,
                                -0.58934497845321587,
                                0,
                                0,
                                0,
                                0,
                                0.077961791270228689,
                                0,
                                -0.49013680036080831,
                                0,
                                0,
                                0,
                                0.78017297194297242,
                                0.10499736819765222,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1030627342977428,
                                0,
                                0,
                                -0.30384853559385283,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40152947211926032,
                                0,
                                0,
                                0.00035134147094087465,
                                0,
                                -0.72672552324476025,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14235538822641147,
                                0,
                                0,
                                0,
                                -0.057767870762158571,
                                0.47030740749438515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14507419728769289,
                                0,
                                0,
                                0,
                                0,
                                -0.44337434293154221,
                                0,
                                0,
                                -0.097217893114326631,
                                -0.28253549298850156,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27877972945989926,
                                0,
                                0.21323890157455783,
                                0,
                                -0.022818278943197837,
                                0,
                                -0.79913700617461392,
                                0,
                                -0.39729598539078104,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2952624242146158,
                                0.21691250217278302,
                                0,
                                0,
                                0.029694371246505341,
                                0,
                                0,
                                0.31507485487868697,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12253835084932423,
                                0,
                                0,
                                0,
                                0,
                                0.24391896644545166,
                                -0.71391828432823135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.053639063261601352,
                                0,
                                0,
                                0,
                                0,
                                -0.68132379344407834,
                                0.45489312959405342,
                                0,
                                0,
                                -0.73999123610267081,
                                0,
                                0,
                                0.065517138749670273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45591571466419489,
                                0,
                                0,
                                0,
                                0,
                                -0.26338720866826504,
                                0.28164135629863574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4890955359448631,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36313975324313036,
                                0,
                                0,
                                0.55887384637224802,
                                0,
                                0,
                                0,
                                0.075716774976661502,
                                0,
                                0.033845771952386236,
                                0,
                                0,
                                0,
                                0.20664446657532803,
                                -0.040470583594558657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.705328087166045,
                                0,
                                0,
                                0,
                                0,
                                0.084163310983398201,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3160947912912343,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47332033496960624,
                                0,
                                0,
                                -0.60440851922620309,
                                0,
                                0,
                                0,
                                -0.83193666769067987,
                                0,
                                0.67886983967012737,
                                0,
                                0.55694703973631299,
                                0,
                                0.63172559849519794,
                                0.44090553056957493,
                                0,
                                0,
                                -0.59723820017977058,
                                0,
                                0,
                                -0.63741625875437102,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.059876919821934597,
                                0,
                                0,
                                0,
                                0,
                                -0.40970164530498793,
                                -0.74978867291086926,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14560818248969015,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60207357138640105,
                                0,
                                0,
                                -0.12519016021436108,
                                0,
                                0,
                                0,
                                -0.61987300287679659,
                                0,
                                -0.1505759552318931,
                                0,
                                0,
                                0,
                                0.20792867641363807,
                                -0.34582901865312865,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20607112849350417,
                                0,
                                0,
                                0,
                                0,
                                -0.098090905887318558,
                                0,
                                0.17642302514463676,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39470933800065888,
                                0,
                                -0.53273273325719195,
                                0,
                                -0.60946610657257239,
                                0,
                                -0.38091400577438655,
                                0,
                                0.11283117811313952,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20249675176541393,
                                -0.91434622011017119,
                                0,
                                0,
                                0.22653825423057236,
                                0,
                                0,
                                0.19002936475252052,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1437114542923229,
                                0,
                                0,
                                0,
                                0,
                                -0.47076741507730102,
                                -0.4656855811686994,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60255537906512346,
                                0,
                                0,
                                0,
                                0.22556814862319546,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42562308393332793,
                                0,
                                -0.030685388667656743,
                                0,
                                0.17324838688239347,
                                0,
                                -0.33695945198289556,
                                0,
                                0.78959846240613807,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56929105033791205,
                                0,
                                0,
                                0.071193788213947506,
                                0,
                                0,
                                0,
                                -0.25912720387270932,
                                0,
                                -0.005841653407345597,
                                0,
                                0,
                                0,
                                0.5825087542099725,
                                -0.1505289403820079,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14166220398996335,
                                0,
                                0,
                                0,
                                0,
                                -0.47075951520967563,
                                0,
                                -0.64046920870965074,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50356190126140576,
                                0,
                                -0.33343116595874833,
                                0,
                                -0.37385833284819647,
                                0,
                                0.27509176054313617,
                                0,
                                0.097993530916416771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15635832086030077,
                                0,
                                0,
                                -0.54277138615685772,
                                0,
                                0,
                                0,
                                0.43399445323405855,
                                0,
                                0.37305420176010329,
                                0,
                                0,
                                0,
                                0.45513861196742361,
                                -0.31653968997531146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11169644927252012,
                                0,
                                0,
                                0,
                                0,
                                0.18331952095760135,
                                0,
                                -0.57515230842766307,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47636750149015672,
                                0,
                                -0.2836606208427106,
                                0,
                                0.53400209941116061,
                                0,
                                -0.16449083028316711,
                                0,
                                0.22269935427546836,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25480688930430523,
                                -0.14778327063136332,
                                0,
                                0,
                                -0.16080221884122298,
                                0,
                                0,
                                -0.87101364329037445,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.08455244027237234,
                                0,
                                0,
                                0,
                                0,
                                0.59149774402989708,
                                -0.030967589235185413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33749809217405674,
                                0,
                                0,
                                0,
                                0.31171563408406017,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32377585839968637,
                                0,
                                -0.69147937239257562,
                                0,
                                0.41603736888941695,
                                0,
                                -0.0031911315555757519,
                                0,
                                -0.38309471271169332,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21764020452384536,
                                0,
                                0,
                                -0.32233540615087253,
                                0,
                                0,
                                0,
                                -0.51784033154857767,
                                0,
                                0.019163731886598367,
                                0,
                                0,
                                0,
                                0.071702114567151171,
                                0.32539121784862551,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34949784932145511,
                                0,
                                0,
                                0,
                                0,
                                0.58909879065532333,
                                0,
                                0,
                                0,
                                0,
                                -0.22258277464386483,
                                0,
                                0,
                                0.3908350598807333,
                                0,
                                0,
                                0,
                                -0.20988346918496015,
                                0,
                                0.59670814425037066,
                                0,
                                0,
                                0,
                                -0.14752752379890546,
                                -0.46238963266134714,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22437350063929723,
                                0,
                                0,
                                0,
                                0,
                                0.33418733352508134,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13505895044702476,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0297059598103404,
                                0,
                                0,
                                0.26774645087538951,
                                0,
                                0,
                                0,
                                -0.53486843012854834,
                                0,
                                0.3448829973635828,
                                0,
                                -0.034105216373706601,
                                0,
                                -0.07637259322103164,
                                -0.32904864444660648,
                                0,
                                0,
                                0.74136597250737035,
                                0,
                                0,
                                0.36628423149978279,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2578903137181763,
                                0,
                                0,
                                0,
                                0,
                                0.41364476324534072,
                                0.028241096080312236,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20196893403251398,
                                0,
                                0,
                                0,
                                0,
                                -0.64249358211964258,
                                0.12828638514996579,
                                0,
                                0,
                                0.56482450898595082,
                                0,
                                0,
                                -0.45877063372691151,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16046877179678753,
                                0,
                                0,
                                0,
                                0,
                                -0.59209538805936279,
                                0.2284059710409525,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34244026678283024,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0644674814074169,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.021056345235014429,
                                0,
                                0,
                                -0.84177416214939826,
                                0,
                                0,
                                0,
                                -0.056146031736601487,
                                0,
                                0.66205732130654726,
                                0,
                                -0.2131318558584534,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34752444118102976,
                                0,
                                -0.066625219107294881,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10121029594651733,
                                0,
                                0,
                                -0.32964040457863691,
                                0,
                                0,
                                0,
                                -0.10423557697690589,
                                0,
                                0.01183436479607089,
                                0,
                                0,
                                0,
                                -0.57946723624333119,
                                -0.4400336629927793,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50364531618038688,
                                0,
                                0,
                                0,
                                0,
                                -0.29498824554384118,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57542186686896335,
                                0,
                                0.15622473737346418,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41837684157412658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39711220961522442,
                                0,
                                0,
                                0.96393649206683829,
                                0,
                                0,
                                0,
                                0.11413152287137387,
                                0,
                                0.52409632567522446,
                                0,
                                -0.90531222028236114,
                                0,
                                0.33111657572548708,
                                -0.73236092056324531,
                                0,
                                0,
                                -0.45429784585742594,
                                0,
                                0,
                                0.14243964008756435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48264664560820031,
                                0,
                                0,
                                0,
                                0,
                                0.2601217733333468,
                                0.42519065301152126,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0430175282407683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67425564214490175,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54167321225366605,
                                0,
                                0,
                                -0.57817274723766221,
                                0,
                                0,
                                0,
                                0.24917282957897643,
                                0,
                                0.36007815282744227,
                                0,
                                -0.15558740594503198,
                                0,
                                0,
                                0,
                                -0.22347893761351792,
                                0,
                                0,
                                0.083684885694676747,
                                0,
                                0,
                                0,
                                0.17734599500327508,
                                0,
                                -0.69311606014966654,
                                0,
                                0,
                                0,
                                0.070059144531273349,
                                -0.49253917903670086,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.036767970527867934,
                                0,
                                0,
                                0,
                                0,
                                0.42700997563633425,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33820944064647213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.03835843199549667,
                                0,
                                0,
                                -0.072162336252162423,
                                0,
                                0,
                                0,
                                0.55980835674892326,
                                0,
                                0.72752601545377127,
                                0,
                                0.92335882995808671,
                                0.53515712643780733,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34478561132220775,
                                0,
                                0,
                                -0.76887135535227569,
                                0,
                                0,
                                -0.24057820173819397,
                                0,
                                0.58320772462587778,
                                0,
                                0,
                                0.83192443998983934,
                                0,
                                0,
                                0.34251911407660984,
                                0,
                                0,
                                -0.18096427697544604,
                                0,
                                -0.083505845670035037,
                                0,
                                0,
                                0,
                                0,
                                0.40214824787861886,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55266023951512311,
                                0,
                                0,
                                0,
                                0,
                                0.42440224741740828,
                                0,
                                0.28701040405396894,
                                0.33661635050741695,
                                0,
                                0,
                                0,
                                0,
                                -0.17272757595558297,
                                -0.2628363158722764,
                                0,
                                -0.57923399273020471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.75106978830641469,
                                0,
                                0,
                                0,
                                -0.01271186418265563,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.036094581745449605,
                                0,
                                0,
                                -0.79433767705634972,
                                0.26474602710546574,
                                0,
                                -0.097114975568404205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18944710160167444,
                                0,
                                0,
                                0,
                                -0.019939954760659517,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50320778149767387,
                                0,
                                0.29287179070006841,
                                0,
                                0,
                                0.044102587561567257,
                                0,
                                -0.28235902730774309,
                                0,
                                0,
                                0,
                                0,
                                -0.27483120000739342,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6071972706476465,
                                0,
                                0,
                                0,
                                0,
                                -0.22483321510277998,
                                0,
                                -0.49123240489782394,
                                -0.31060343118795236,
                                0,
                                0,
                                0,
                                0,
                                -0.028196396717701383,
                                0.57797857698251487,
                                0,
                                0.48498606682186207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56692260846836395,
                                0,
                                0,
                                0,
                                -0.3249149742528033,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.054435817838926343,
                                0,
                                -0.35369317470683181,
                                0,
                                0,
                                -0.12550101865074778,
                                0,
                                -0.6993292246861964,
                                0,
                                0,
                                0,
                                0,
                                0.23288116941002895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.063069150582128697,
                                0,
                                0,
                                0,
                                0,
                                0.21922288344870697,
                                0,
                                0.17628842729497227,
                                -0.48243303051988179,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28092017288017357,
                                -0.01764516777242358,
                                -0.1319318169383108,
                                0,
                                0,
                                0.33377775528680509,
                                0.20764808924359651,
                                1.1423090612359206,
                                0.37422347064001221,
                                0.40494889938922018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64644617409303717,
                                -0.25394943087329291,
                                0.27103104720242754,
                                0,
                                0,
                                -0.36567515191364419,
                                0.89378429839400675,
                                0.00090465259667815712,
                                -0.75923500539172939,
                                -0.21311531524507657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.92572550636931561,
                                0.065027673155192547,
                                0.2752595261870327,
                                0,
                                0,
                                0.12952783873717927,
                                -0.12712834365142764,
                                -0.082444410564315757,
                                -0.86353451846259321,
                                0.46846848893239323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.09420579885989501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42842921266521811,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13252420613075,
                                0,
                                0,
                                -0.93204804275464692,
                                0,
                                0.091116321558723817,
                                0,
                                0,
                                0,
                                0,
                                -0.030019197955569923,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19553164160208739,
                                0,
                                0,
                                0,
                                0,
                                0.01374306442758947,
                                0,
                                -0.24981748514085522,
                                -0.060746801700088018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55163797813299453,
                                1.0166591415247848,
                                0.13143961461750625,
                                0,
                                0,
                                0.80759662235820096,
                                0.051799694019266457,
                                0.31514692694241098,
                                -0.035622780756180257,
                                -0.69383451490741432,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10385610633776693,
                                -0.79372817018609843,
                                -0.054251789139887735,
                                0,
                                0,
                                1.022701428333491,
                                0.64713801808062976,
                                -0.55627674779284153,
                                0.012492628724062038,
                                -0.018445117685913004,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11246696817221055,
                                0.95743283279922053,
                                -0.94449293197298101,
                                0,
                                0,
                                0.33083288880350575,
                                0.53318718539081433,
                                -0.10516966664919426,
                                0.27526094088656455,
                                0.45408267592129847,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1390761555390883,
                                0.30139908275120525,
                                0.44687040680842471,
                                0,
                                0,
                                -0.34772726038519036,
                                0.46678206228113317,
                                0.079199624270371416,
                                0.40019475968322882,
                                0.083788503168254591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55297928083248293,
                                -0.059253919483560964,
                                0.80000430086207075,
                                0,
                                0,
                                0.48872078628062338,
                                0.3039955529602868,
                                -0.47221189469542335,
                                0.26728579341649616,
                                0.7412597405391641,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32953070578870614,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66413322358813653,
                                0,
                                0,
                                0.057823063356461299,
                                0,
                                0,
                                0.1743326569333114,
                                0,
                                0.93609022790283114,
                                0,
                                0,
                                -0.56491042598458996,
                                0,
                                0,
                                0,
                                0.23438930010284423,
                                -0.34056513870917821,
                                0,
                                0.41853794427062641,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22722595511840629,
                                0,
                                0,
                                0,
                                0.27335851536930011,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72632397653845704,
                                0,
                                -0.022856999859624832,
                                0,
                                0,
                                -0.22223443890773609,
                                0,
                                0.060332335670563619,
                                0,
                                0,
                                0,
                                0,
                                -0.50414873283790318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24068847479566657,
                                0,
                                0,
                                0,
                                0,
                                -0.2784181155032876,
                                0,
                                0.73161418425829461,
                                -0.14688966139063198,
                                0,
                                0,
                                0.59509546448804851,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51852191570561545,
                                0,
                                0,
                                0.60801850761396103,
                                0,
                                0,
                                -0.42194432188271935,
                                0,
                                -0.13323877387837174,
                                0,
                                0,
                                1.3992069765445438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44141071215052541,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3687883918713587,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52788577872862019,
                                0.53979628371754462,
                                0,
                                -0.49458217377034325,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.092087019470661877,
                                0,
                                0,
                                0,
                                -0.054372636461809752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41702355729456003,
                                0.6239879537115105,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29999984511703442,
                                0,
                                0,
                                0.39154878860306547,
                                0,
                                0,
                                1.2181014632662059,
                                0,
                                -0.0013112516025805265,
                                0,
                                0,
                                0.32120779636671348,
                                0,
                                0,
                                -0.52444840210091559,
                                0,
                                0,
                                -0.030048331255131407,
                                0,
                                0.37058806637840963,
                                0,
                                0,
                                0,
                                0,
                                -0.30980045963915748,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30547463648470286,
                                0,
                                0,
                                0,
                                0,
                                0.59393217826664468,
                                0,
                                -0.16940070964328321,
                                -0.12638174410960645,
                                0,
                                0,
                                -1.2316146347172099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16269567504777371,
                                0,
                                0,
                                -0.23480283273871927,
                                0,
                                0,
                                -8.8057638983049524e-05,
                                0,
                                0.20743712623017793,
                                0,
                                0,
                                0.54372451432119029,
                                0,
                                0,
                                0.34022937792648689,
                                0,
                                0,
                                0.1053686771010071,
                                0,
                                0.47492413206326189,
                                0,
                                0,
                                0,
                                0,
                                0.32773375743295952,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.035620938873803229,
                                0,
                                0,
                                0,
                                0,
                                0.082466954430341188,
                                0,
                                0.12823574744533808,
                                -0.71809818863609409,
                                0,
                                0,
                                0,
                                -0.51275788160348745,
                                0,
                                0,
                                -0.13946048322773694,
                                0,
                                0.22227948172643422,
                                0,
                                0,
                                0,
                                0,
                                0.50005811816543078,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36215086198047453,
                                0,
                                0,
                                0,
                                0,
                                -0.53292807707250134,
                                0,
                                -0.049285341678830183,
                                0.023858161326304035,
                                0,
                                0,
                                -0.29492082114564305,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.97420540293214963,
                                0,
                                0,
                                0.87383814787972469,
                                0,
                                0,
                                -0.52258816060781554,
                                0,
                                0.67372715669497096,
                                0,
                                0,
                                0.33493140015425243,
                                0,
                                0,
                                0,
                                -0.069253614625852056,
                                0.34554700855390758,
                                0,
                                0.0077227436286055051,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13598187732578848,
                                0,
                                0,
                                0,
                                0.90343223580893373,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20263436360048029};

const double rot_27_2[32]
    = {-1.7594898756663908,   -1.2633998546142737,  -0.68773951870224603, -2.1988702870345307,  0.3639716766330956,
       0.93141001637779963,   -0.93141001637779963, 0.36397167663309576,  -0.46767514851975184, 0.88390042168619187,
       0.88390042168619198,   0.46767514851975195,  0.70793998853846385,  -0.70627259087986705, -0.70627259087986682,
       -0.70793998853846352,  0.12849818380875508,  -0.99170974420838043, 0.99170974420838054,  0.12849818380875513,
       -0.061879113673118602, -0.99808365144963163, -0.99808365144963118, 0.06187911367311609,  -0.5888189937695536,
       -0.80826492722139731,  -0.80826492722139709, 0.58881899376955327,  0.63071860653950396,  0.77601162321505612,
       0.77601162321505646,   -0.63071860653950396};

const double rot_26_50[25000] = {0.32453246583205364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19565411483904538,
                                 0,
                                 0,
                                 -0.025968243789124212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44792797202834184,
                                 -0.42016787465860811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23234676035524759,
                                 0.27578322915515668,
                                 0,
                                 -0.16423381997125119,
                                 -0.47754526980975753,
                                 -0.30574441350680831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65482917045518385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0095771226689823907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40538108359984187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03439494201235152,
                                 0,
                                 0,
                                 -0.58090988516460773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26102472408526378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29808497726521471,
                                 0,
                                 0.33031108933851216,
                                 0,
                                 0,
                                 0,
                                 0.21296196654469196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51456895746407538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31075498216043557,
                                 0,
                                 0,
                                 -0.19095793069499067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38140406790084291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46195591365886796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6620039426378026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80097143567769924,
                                 0,
                                 -1.0321914066340054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051735909721201262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24157448594877062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40754296287288172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32342184067453872,
                                 0,
                                 0.34289426074170615,
                                 0,
                                 0,
                                 0,
                                 0.20319703412745643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52594876811375046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33139285033211063,
                                 0,
                                 0,
                                 0.58802010525119242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065600858302716586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0042848017001491795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22358945504869313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58315961415162176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39576368894401448,
                                 0,
                                 0,
                                 -0.22040382543559123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18051144305261133,
                                 0,
                                 0.55042592373620591,
                                 -0.56081517869421216,
                                 -0.67320901808421263,
                                 0,
                                 -0.41245097021338867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070281278773115394,
                                 0,
                                 0,
                                 -0.31732758867627497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31691837141815787,
                                 -0.14612149700520843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15788229991332459,
                                 0.068219747773373723,
                                 0,
                                 -0.70106950207877772,
                                 0.2516068564859899,
                                 0.13443951380319555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5984591537988071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31024294376433276,
                                 0,
                                 0,
                                 0.52151146227138578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56665969593272592,
                                 0,
                                 0,
                                 0,
                                 0.38906873205268977,
                                 -0.034387687631720926,
                                 -0.010612297236099355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16270373762155582,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49716243492411816,
                                 0.75117688355074153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52480055824773741,
                                 0,
                                 0.16726593989683,
                                 0,
                                 0,
                                 0,
                                 0.18829862704647926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035910976615403344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27119357389730747,
                                 0,
                                 0,
                                 0.33616622692796749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26698797732894358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6340538159619048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25341562108449101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76841227095319697,
                                 0,
                                 0,
                                 0.16134337585549163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14538298414175752,
                                 0.14570189146306517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053976156590246849,
                                 0.4692928914750592,
                                 0,
                                 0.0058113204013994502,
                                 0.19363773737911505,
                                 -0.12746598919398505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1810675610912802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11916218371272078,
                                 0,
                                 0.66445054035940909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93147552466883887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055383715949521461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13809284703981203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2341082026050213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25304211410238653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20311265020641467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12102407539191301,
                                 0,
                                 0,
                                 -0.67555415351648807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60736154647123008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91943859185122279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27181096771604013,
                                 0,
                                 -0.094335487326856121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79643183002418516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31667409078392533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76169932536347562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0053318249349559848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25979519570473636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063906303486624294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36213705075530334,
                                 0,
                                 0,
                                 0.38596067313929955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68249841844775616,
                                 0,
                                 0,
                                 0,
                                 -0.33335055304497396,
                                 -0.34140835294434679,
                                 0.26391892576659204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96290228307288495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63565471238304239,
                                 0.18046122191065428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43464259800830196,
                                 0,
                                 0.016491215877022986,
                                 0,
                                 0,
                                 0,
                                 -0.28146791419408029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018252604873046183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73833094947601807,
                                 0,
                                 0,
                                 0.20896443396176592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34286109364392359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15781017818962817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014718669936572726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24329393946524722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51222364592181524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74098286582425721,
                                 0,
                                 0,
                                 -0.27883201550182218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2267497652025367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13098128444950288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29966599575634062,
                                 0,
                                 0,
                                 -0.58219604011047199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31481956308475734,
                                 0,
                                 0,
                                 0,
                                 -0.61003872408459059,
                                 0.55008517168707161,
                                 0.19502077782411251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18689735654444192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50874707717193901,
                                 0.68340027562006378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10766702008076295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70327882957122434,
                                 0,
                                 0.15710230046708723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16464430421835588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19105707240510925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1030511057289809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3210410435994463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5535248023966125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33613997555625696,
                                 0,
                                 0,
                                 -0.51280730961133825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21449249715457375,
                                 0,
                                 0.096925845109118974,
                                 0.38698594239626144,
                                 -0.83484096099542016,
                                 0,
                                 0,
                                 0,
                                 0.16557155852600552,
                                 0,
                                 -0.69842943190611495,
                                 0,
                                 0,
                                 0,
                                 0.65845368748645972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092817822345322779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.067868880011884125,
                                 0,
                                 0,
                                 0.02830201208771756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13057163101162048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14195013687140673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16722018201392569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17900880518406539,
                                 0,
                                 0,
                                 -0.43489592498864404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35655738656303887,
                                 -0.16309258564650037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32012742831685598,
                                 0.034780135798040165,
                                 0,
                                 0.57888830745469488,
                                 -0.11696328972150723,
                                 0.38031975962263403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32825844839202417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34753577108727274,
                                 0,
                                 0,
                                 -0.15665343232548695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070041655568314681,
                                 -0.26645153444452624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48148368778533956,
                                 -0.63801799168399953,
                                 0,
                                 0.066896828266823832,
                                 0.04232884028353498,
                                 -0.16081763468078417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52897653668281264,
                                 0,
                                 -0.18617597100677066,
                                 0,
                                 0,
                                 0,
                                 -0.22948703311890711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084652403334017481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.120144814787996,
                                 0,
                                 0,
                                 -0.017191657588529363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71824296386853359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30836458768973568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59937261862712488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68131187951602667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17313163104816184,
                                 0,
                                 0,
                                 -0.495407584602088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1995733706519765,
                                 0,
                                 -0.84654451222710847,
                                 -0.37501060060971703,
                                 -0.11812165715003323,
                                 0,
                                 0,
                                 0.10989690067282329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41933847360440657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44706055191922173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64457022713656953,
                                 0,
                                 0,
                                 -0.21693559531387446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3868888063387747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28078857604107899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20763252747353597,
                                 0,
                                 0,
                                 0.41049147461623753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22497935151718507,
                                 0,
                                 0,
                                 0,
                                 -1.1034020081978999,
                                 0.31043482806219891,
                                 0.73104437216474949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017922242507887154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66469051704464166,
                                 -0.26230980977105239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80573086752903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3701140881495702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5173942912936087,
                                 0,
                                 0,
                                 -0.36402908979611814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060460546625126482,
                                 0,
                                 0.096691233410700322,
                                 -0.69326447865880714,
                                 -0.080477931619222773,
                                 0,
                                 0,
                                 -0.50636002342537678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56328065397830918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15455338137127531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041249865812494645,
                                 0,
                                 0,
                                 0.2056534645697099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59869256293864526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27469526522445098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51622968562159366,
                                 0,
                                 0.10883019499573721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078104248420404365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.446939550893743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12870666478415838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55505691107230493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59957495295306285,
                                 0,
                                 0,
                                 0.45872739843184018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49524271839731748,
                                 0,
                                 0,
                                 0,
                                 0.60756216486356251,
                                 0.36789928796131005,
                                 0.12646342797610044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032779421828342231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20022828998082992,
                                 0.28004378778685501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18400032785221457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48610929972437172,
                                 0,
                                 0,
                                 0.47822421907429224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.191767520230853,
                                 0,
                                 0,
                                 0,
                                 -0.11210146030213225,
                                 -0.1224054033806346,
                                 0.30986266839189047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48365682371277108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73428920277788867,
                                 0.12341017349389614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34027155836816364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11462840152589288,
                                 0,
                                 0,
                                 0.51546048652760157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45659275901956525,
                                 0,
                                 0,
                                 0,
                                 0.35673005542833486,
                                 0.99549814144544813,
                                 -0.69968829887062878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84866494457536623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069097913158521138,
                                 -0.51838148165696307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00028514412540473801,
                                 0,
                                 0.11866662062974329,
                                 0,
                                 0,
                                 0,
                                 -0.037099036537193715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66005405295056951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035456031408241523,
                                 0,
                                 0,
                                 -0.63723501345317968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071031641254325095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36945821674379409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49769234035544441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61931912261802002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55523731878224247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13394858921964339,
                                 0,
                                 0,
                                 0.19765778029752562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058709929965856666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070890771101830757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015285299498996624,
                                 0,
                                 0,
                                 -0.051575641387843665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62752000960759602,
                                 -0.69189029121319845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30028397254219807,
                                 0.074706916355774311,
                                 0,
                                 -0.087045763624823691,
                                 -0.065618018498856942,
                                 0.10932976282965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3920090632761799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42339623000959187,
                                 0,
                                 0,
                                 0.078902220857706221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08490116564297806,
                                 0.18895927562234244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49663387544787913,
                                 -0.51327803983979536,
                                 0,
                                 -0.28382092672467235,
                                 -0.14364391860118131,
                                 0.08147210733340636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3099835649337082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50003575069472128,
                                 0,
                                 0,
                                 -0.064858862222068631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087654810260793886,
                                 0,
                                 0,
                                 0,
                                 0.14725112900159562,
                                 0.4247766548522014,
                                 -0.0079428265478106996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58686640073168117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11389963308881265,
                                 -0.23573780835592772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040203753250871166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019233011039709785,
                                 0,
                                 0,
                                 -0.68105381790093844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33808253069142047,
                                 0.37341689943366174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054722546478592426,
                                 0.074339062786944632,
                                 0,
                                 -0.07912806891173596,
                                 -0.37171288406398834,
                                 -0.35705307094894012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25488562359215428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062431743958972996,
                                 0,
                                 0,
                                 -0.19215557743381645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1439923959199603,
                                 -0.16270052989380479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25910451552444791,
                                 -0.046843012369852777,
                                 0,
                                 0.19661950989108484,
                                 0.60596553924934882,
                                 -0.60977346087071871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5471266494700795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17242878876783321,
                                 0,
                                 0,
                                 -0.38636605357958864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098614827485131187,
                                 0.054345066124054889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42062007490816167,
                                 0.11841118775589532,
                                 0,
                                 -0.094108499491512454,
                                 0.35408019884242792,
                                 0.42870979786183994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18703915820517347,
                                 0,
                                 0.45664135267738981,
                                 0,
                                 0,
                                 0,
                                 0.55774161671211631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074306090976537661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39323464086489368,
                                 0,
                                 0,
                                 -0.23222518896017297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35131717119257738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32849984203271748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1690363255782914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44889063009754315,
                                 0,
                                 0,
                                 0.68552521669081989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14298982100863733,
                                 0,
                                 0,
                                 0,
                                 -0.6049236006257267,
                                 -0.55624538432095483,
                                 -0.89364651609865697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15806896310264354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23480502757896948,
                                 0.42035765270161929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51321642791206257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83696785220769754,
                                 0,
                                 0,
                                 -0.12508136637974593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0717769815579576,
                                 0,
                                 0,
                                 0,
                                 0.23137378819541563,
                                 -0.22777435203905458,
                                 0.65473339978392531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0046329398040538261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069966143456980157,
                                 -0.29158857390255494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68996331009054035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12675638522712027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58430851965167974,
                                 0,
                                 0,
                                 -0.19590314298328354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63177775663887725,
                                 0,
                                 0.37989085951504414,
                                 0.034467211999695074,
                                 0.43706487285951517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091539145138252564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96371277315758042,
                                 0,
                                 0.90488216900003415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.99366174050121403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13772294778060656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46915293301765815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25495026735021409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.02772151307627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2800787358041002,
                                 0,
                                 0,
                                 -0.57868635285228898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5185443008745303,
                                 0,
                                 -0.057220297049651231,
                                 0.03830856642474912,
                                 0.5074940952336634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61764385711060399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51055066557867534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53659925048520662,
                                 0,
                                 0,
                                 -0.53862508174159762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57397920718173023,
                                 0,
                                 0.29353128425047847,
                                 0.603233772208146,
                                 0.27118222320236207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058393828660066968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51364839815401098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36802582570354586,
                                 0,
                                 0,
                                 -0.4053008319737671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60424764835601419,
                                 0,
                                 0.47629033644627661,
                                 -0.16463881581979328,
                                 0.27240833966968597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49326724132794714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31438945753099484,
                                 -0.15076156111361025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24265575031408751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3720883713943734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53474385773510846,
                                 0,
                                 0,
                                 -0.49914392762589133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14454391177494552,
                                 0,
                                 0,
                                 0,
                                 -0.2553299391636133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39844373287511076,
                                 0,
                                 -0.39947564068538499,
                                 0,
                                 0,
                                 0,
                                 -0.30073717954132223,
                                 0,
                                 0.2587678886481759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35624372252415965,
                                 0,
                                 0.19710740809755622,
                                 -0.11380943955901074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38599050486982067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49389445526581671,
                                 0,
                                 0,
                                 -0.20030225787663,
                                 0,
                                 0,
                                 0,
                                 -0.26694687700945474,
                                 0,
                                 0,
                                 0,
                                 -0.82117676378537852,
                                 0,
                                 0.14197879316348871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66352347712028992,
                                 0,
                                 0,
                                 -0.27080678983663331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45774892748437451,
                                 0,
                                 0,
                                 0,
                                 0.21441233012312771,
                                 0,
                                 0,
                                 -0.69833544163159533,
                                 0,
                                 0,
                                 -0.061947097177231791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54968291665607805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62665528216749167,
                                 0,
                                 0.065735420474211909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15346728826677067,
                                 0.19699816355248215,
                                 0,
                                 0,
                                 -0.48833412532007131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2513429022838185,
                                 0,
                                 -1.3846109952673316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34216276712402049,
                                 0,
                                 0,
                                 -0.77165018603293856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22095241157520024,
                                 0,
                                 0,
                                 0,
                                 0.57397632218472583,
                                 0,
                                 0,
                                 -0.035513937367664096,
                                 0,
                                 0,
                                 0.25130054502773069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25445842304307353,
                                 0,
                                 0,
                                 0,
                                 -0.027228489069142284,
                                 0,
                                 -0.054246774314492791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63434074333220769,
                                 0,
                                 -0.34036237541940101,
                                 0.38983200710240484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035802444774453039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057658509280231494,
                                 0,
                                 0,
                                 0.25645575201236287,
                                 0,
                                 0,
                                 0,
                                 0.43702084309968237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58646356556596935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68062836780034797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18683739360651247,
                                 -1.0830820699952255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29323950750220701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50632946324586658,
                                 0,
                                 0,
                                 0,
                                 0.31667751655574267,
                                 0,
                                 0,
                                 0,
                                 -0.055493520598610326,
                                 0,
                                 0.0428002764938058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2176273142080313,
                                 0,
                                 -0.25015090168540027,
                                 -0.10085904416398228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62008895707670653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25763953812332269,
                                 0,
                                 0,
                                 0.54550723985089067,
                                 0,
                                 0,
                                 0,
                                 0.16194966099379934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48770975139845196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.264746901677474,
                                 0,
                                 0.3936863228409731,
                                 0,
                                 0,
                                 -0.55380357716708506,
                                 -0.24289591867352847,
                                 -1.2908903650165739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14210456322459386,
                                 0,
                                 -0.37707080565845874,
                                 0,
                                 0,
                                 -0.14104518983336056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076358161403833252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48523062274784751,
                                 0,
                                 -0.063428606260506185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14105231202873977,
                                 0,
                                 0,
                                 -0.38689828392014874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71828762938894342,
                                 0,
                                 0,
                                 0,
                                 -0.22842293200162389,
                                 0,
                                 0,
                                 -1.0018820303590847,
                                 0,
                                 0,
                                 -0.74040701751712246,
                                 0,
                                 0,
                                 0,
                                 -0.42046028937659941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20346109896731102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082061908140944911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096744166130683318,
                                 0,
                                 0,
                                 0.47134467858162332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12790792089964031,
                                 0,
                                 0,
                                 0,
                                 0.35401458545876724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63393262011248586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19620495726755338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79058611380504484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3197863510649015,
                                 -0.066202943045683971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29442927959661519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2154733271462381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75265820845209241,
                                 0,
                                 0.31421280988962463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24394124409832885,
                                 0,
                                 0,
                                 -0.4065284266999894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18526489397044929,
                                 0,
                                 0,
                                 0,
                                 -0.38109179843630031,
                                 0,
                                 0,
                                 1.0063656092676874,
                                 0,
                                 0,
                                 -0.64296472572100694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3231662059285918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04649898573775009,
                                 0,
                                 0.39148615188557201,
                                 0,
                                 0,
                                 0.50651140003765538,
                                 -0.36457964038121038,
                                 0.11102262477355584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59530054530044363,
                                 0,
                                 -0.40234595366742398,
                                 0,
                                 0,
                                 -0.39765642528469797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72117858259592638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11569424854426172,
                                 0,
                                 0,
                                 0,
                                 -0.73509833175974826,
                                 0,
                                 -0.28867576306621434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30739260831679627,
                                 0,
                                 -0.031676007424162614,
                                 0.086101795652321303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14089710833022484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17176960710769984,
                                 0,
                                 0,
                                 -0.2906859333734631,
                                 0,
                                 0,
                                 0,
                                 0.35517513719896676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50528294060396961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035476329333391468,
                                 0,
                                 0.48891750841540887,
                                 0,
                                 0,
                                 0.076023107149459632,
                                 -0.17219115894054254,
                                 0.50254159102232954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80768936939781888,
                                 0,
                                 0.024480785917488909,
                                 0,
                                 0,
                                 0.099064579824464649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55369077059520366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52558871700680809,
                                 0,
                                 0,
                                 0,
                                 0.077890554617487867,
                                 0,
                                 -0.47145039280866713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044883295307960605,
                                 0,
                                 -0.093057782319987598,
                                 -0.18570596942612935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21819281495406062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3732500527969641,
                                 0,
                                 0,
                                 0.30573171428154616,
                                 0,
                                 0,
                                 0,
                                 -0.41214989205446606,
                                 0,
                                 0,
                                 -0.42272758524220033,
                                 0,
                                 0,
                                 0,
                                 0.0025206721725024861,
                                 0,
                                 0.13264417278766472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42948679994962979,
                                 0,
                                 -0.50420573447318984,
                                 -0.022286766781768524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40299963977278047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44290282441509921,
                                 0,
                                 0,
                                 0.077125590115029008,
                                 0,
                                 0,
                                 0,
                                 0.0012434427689781979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39698924590873425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36713382473486456,
                                 0,
                                 -0.025058345212843385,
                                 0,
                                 0,
                                 0.27832620249277934,
                                 0.54342999314381213,
                                 -0.48935592302507952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26104314046558713,
                                 0,
                                 -0.69159693958367041,
                                 0,
                                 0,
                                 -0.11115223408015333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60982252266840331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099306315806487744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32789623783007571,
                                 0,
                                 -0.87494263653621063,
                                 0,
                                 0,
                                 0.10156539144617092,
                                 0.42537458117420912,
                                 -0.51101815648582682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0937698377823721,
                                 0,
                                 0.38216455773458341,
                                 0,
                                 0,
                                 0.14405879628407214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35932243280934056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15387634660522323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26260760268490757,
                                 0,
                                 -0.39923693519448311,
                                 0,
                                 0,
                                 -0.10420353622276071,
                                 -0.26851927841539858,
                                 -0.26863641540425492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47484698786911977,
                                 0,
                                 0.37567825593898008,
                                 0,
                                 0,
                                 -0.98720210217801563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42615767175352215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1590560782273844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1676396519487009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96308739312676794,
                                 -0.52679866624239613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022137215367511204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15554255860485244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18583949670947592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74619684179699253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65119654520213188,
                                 -0.36337335839117962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10660653477396317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3519882173037596,
                                 0,
                                 0,
                                 -0.10465536197190664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46057544100085529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54269288471962351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43465395167548992,
                                 0,
                                 0,
                                 -0.20228217909010104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38511656357855795,
                                 0,
                                 0,
                                 0,
                                 0.063475605412364758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31656893960480004,
                                 0,
                                 0,
                                 0,
                                 -0.01933778253477586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23338065992887688,
                                 0,
                                 0.6514839296181314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33821565218157806,
                                 0.62509049137739936,
                                 0,
                                 0,
                                 0.12490099037267684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41514839911597717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40212713931091126,
                                 0,
                                 -0.81179384941000887,
                                 0,
                                 0,
                                 0.92396609305787636,
                                 -0.7579260388810668,
                                 -0.33379891154865116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56982970134191446,
                                 0,
                                 -0.51923637286986091,
                                 0,
                                 0,
                                 0.026346445652914753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57363841419999839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017792782860889117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26045592569050652,
                                 0,
                                 -0.29667959708366953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54676245141823832,
                                 0.62405949859944265,
                                 0,
                                 0,
                                 0.39424346316961273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18580312919262532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29840072204784357,
                                 0,
                                 -0.64992270795370799,
                                 0,
                                 0,
                                 -0.88636568994904186,
                                 -0.35599475431769129,
                                 0.14973059604733824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5091638474110739,
                                 0,
                                 -0.46165277172069424,
                                 0,
                                 0,
                                 0.1689035664506939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1648554351118463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60114584737872989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40596427146966479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093934539774608056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44459885338896732,
                                 0,
                                 0,
                                 -0.25247850240475045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43867704911611738,
                                 0,
                                 0,
                                 0,
                                 -0.1046558019886228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01374982851926259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20561716544505787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32969030032298519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.99461117956839051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35754411903755207,
                                 0,
                                 0.58960561550565682,
                                 0,
                                 0,
                                 0.25640714515355267,
                                 -0.83884298571510663,
                                 -0.67992715940129622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21697556171269361,
                                 0,
                                 0.42812430034716775,
                                 0,
                                 0,
                                 0.56892900502482335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20190453275710069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62777553247284557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041091558756015695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14452827829010167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44166438167613598,
                                 0,
                                 0,
                                 0.243002996252217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26999817081969602,
                                 0,
                                 0,
                                 0,
                                 -0.21732889948267664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4572441321402424,
                                 0,
                                 -0.31761594500750728,
                                 0,
                                 0,
                                 0,
                                 0.15845499854598144,
                                 0,
                                 0.32231657006269476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36674575824921929,
                                 0,
                                 0.41290765518135913,
                                 0.6209804547549177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17819367593595248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12243554365737278,
                                 0,
                                 0,
                                 0.16932349896723303,
                                 0,
                                 0,
                                 0,
                                 0.064018354323306853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56858198779293445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63766846709144509,
                                 0,
                                 0.0084256088301763732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42860295041932872,
                                 0.060099179657960647,
                                 0,
                                 0,
                                 -0.28759356363940114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54623261086285901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13872560289343924,
                                 0,
                                 -0.27823394409457858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011688385852485772,
                                 0.36484900553897504,
                                 0,
                                 0,
                                 -0.68681846151567028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28242708196198629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71849360386068717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32043964385090212,
                                 -0.46239571531259338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27869355329710671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90931359167372516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11818978030987749,
                                 0,
                                 -0.7160452445832769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54766879826201542,
                                 0,
                                 0,
                                 0.9675798701583328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30085453011300822,
                                 0,
                                 0,
                                 0,
                                 0.086949369101439439,
                                 0,
                                 0,
                                 0.26475759818504213,
                                 0,
                                 0,
                                 -0.56429257706055191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27477739384554234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24317374211568471,
                                 0,
                                 0.6369800955195406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61585037005636467,
                                 -0.21042013952087571,
                                 0,
                                 0,
                                 -0.18992619480807055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086830672318425173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49631816628823539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63489382714193709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31183280793912221,
                                 0,
                                 0,
                                 0.19297876920231277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044189860677689707,
                                 0,
                                 0,
                                 0,
                                 0.41549363059446043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1843104286055475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74425408263476445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81939789367769744,
                                 0,
                                 0.38409350785265012,
                                 0,
                                 0,
                                 -0.31207696363579274,
                                 -0.025625775973446951,
                                 0.013912327706350522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12625083816565358,
                                 0,
                                 0.18833306893509863,
                                 0,
                                 0,
                                 -0.57374377431595236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55508535902480505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87568046451877812,
                                 0,
                                 0.029009660329682885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09108451735349779,
                                 0,
                                 0,
                                 0.019276440969990122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40088873397008273,
                                 0,
                                 0,
                                 0,
                                 0.92237909663767459,
                                 0,
                                 0,
                                 -0.16740121259658453,
                                 0,
                                 0,
                                 -0.63937463633489688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22687343937254525,
                                 0,
                                 0,
                                 0,
                                 0.4887664371185636,
                                 0,
                                 -0.37884577557060473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069639429561295152,
                                 0,
                                 0.24754269429995707,
                                 -0.23514416388672793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16264930525304044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28210315915357442,
                                 0,
                                 0,
                                 -0.22415156097661315,
                                 0,
                                 0,
                                 0,
                                 0.53703907319033162,
                                 0,
                                 0.016873450603598062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52359349380386988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012608123160242277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094470257089834808,
                                 0,
                                 0,
                                 -0.16829143747123937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71586497375071989,
                                 0,
                                 0,
                                 0,
                                 -0.28789545444474118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30465239931361615,
                                 0,
                                 0,
                                 -0.35316072423644512,
                                 0,
                                 0.071399462534478847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68743017782097793,
                                 0,
                                 0,
                                 0.71687511391665015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20286634871436401,
                                 0,
                                 0,
                                 0,
                                 0.73257431292800101,
                                 0,
                                 0,
                                 -0.085255993160723728,
                                 0,
                                 0,
                                 0.50679910255880789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23101598036784859,
                                 0,
                                 0,
                                 0,
                                 -0.08459185400490668,
                                 0,
                                 0.53064510594827796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010083736835321919,
                                 0,
                                 0.11348722844195704,
                                 -0.58200443565599946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077774853408844241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3747839703003446,
                                 0,
                                 0,
                                 0.19404012498170389,
                                 0,
                                 0,
                                 0,
                                 0.34931059012404075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41397681443793483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018654382402234174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095610038154200577,
                                 0,
                                 -0.11091311707286217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1352565750729193,
                                 0,
                                 0,
                                 0.095002961583099649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94747025545552988,
                                 0,
                                 0,
                                 0,
                                 0.46544893227882561,
                                 0,
                                 0,
                                 -0.073672797812290899,
                                 0,
                                 0,
                                 0.28858503226826937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048673749590697944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.317457537960256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26299235329266774,
                                 0.17524468496853979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2120661764816716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22158961280210185,
                                 0,
                                 0,
                                 0,
                                 -0.036583805606871272,
                                 0,
                                 0,
                                 0,
                                 0.29687872839184182,
                                 0,
                                 0.27581630935412421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05406628665826943,
                                 0,
                                 -0.52363215930414464,
                                 0.053574980416168767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41363471886922043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29384798943999446,
                                 0,
                                 0,
                                 -0.54410184221022495,
                                 0,
                                 0,
                                 0,
                                 -0.031285666117181615,
                                 0,
                                 -0.16195253618163782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024792263733562803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35684627289536769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12986769871360748,
                                 0,
                                 0,
                                 -0.54718624786855674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18622535729683087,
                                 0,
                                 0,
                                 0,
                                 0.7012472500993876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05578045093097133,
                                 -1.316304915200412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31735358163829347,
                                 0,
                                 0,
                                 0,
                                 -0.14191204166586849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12380239893469003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0546189023488637,
                                 0,
                                 0.31417030075047669,
                                 0,
                                 -0.4542350317593582,
                                 -0.18860468093392921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053809843180497516,
                                 -0.14588218526107244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1383600623073738,
                                 0,
                                 0,
                                 -0.35072725459245491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13355321826526206,
                                 0,
                                 0.29072320323477141,
                                 0,
                                 0.23291046240220453,
                                 0.65967026505108173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40024529102967876,
                                 0.12705946380857142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.089208172245835785,
                                 0.19416956798044335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02856719266674361,
                                 0,
                                 0,
                                 0.26233268711813895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47470217186052815,
                                 0,
                                 0.14814993371483137,
                                 0,
                                 0.63617596499566387,
                                 -0.23739154164719867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43425631185351699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7633789495615505,
                                 0.8840161650505457,
                                 0,
                                 0,
                                 -0.098117091471063581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22936303553919538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097236935149893622,
                                 0,
                                 0,
                                 0,
                                 -0.37398416395463174,
                                 0,
                                 0,
                                 0.83789451341948817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72301122826448361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48737183782861393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41374777909968663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77335341748659903,
                                 0.10805113727837853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018922465870661358,
                                 0,
                                 0,
                                 0,
                                 -0.33462661961034434,
                                 0,
                                 0.16764499395877888,
                                 0,
                                 0,
                                 -0.079810067648391922,
                                 0,
                                 0,
                                 -0.19472052974077561,
                                 0,
                                 -0.71473285481711979,
                                 -0.44313251117361901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16651766225253001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24715843781117103,
                                 0,
                                 0,
                                 0,
                                 -1.4390900179275439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95395218939659299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081021435752522575,
                                 0,
                                 -0.7135028779755499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054303591554685393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38575366841837949,
                                 -0.28277782031796389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088834146742842027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49765613392907387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49626585416658781,
                                 0,
                                 0,
                                 0.20038262357105407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47570558592113776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088263926943251914,
                                 -0.48998690336925255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12143416684007614,
                                 0,
                                 0,
                                 0,
                                 0.78459952745471284,
                                 0.30072755986002175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17703833796525359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31193546976775144,
                                 -0.2305893890621433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82323629668256626,
                                 0,
                                 0,
                                 0,
                                 -0.1314456102783062,
                                 -0.022920745638766626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39243278040324325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52952409144424561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0004594787846564,
                                 0,
                                 0,
                                 0,
                                 0.69547352018522235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44245776291456529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40708544115872752,
                                 0,
                                 -0.4301124286642099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1350026333931456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10567489066499752,
                                 -0.21334171077821745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39355350216835089,
                                 0,
                                 0,
                                 0,
                                 0.39207103314213637,
                                 0,
                                 0.70053621107078268,
                                 0,
                                 0,
                                 -0.48668661069621666,
                                 0,
                                 0,
                                 -0.63041722118519172,
                                 0,
                                 -0.67787153123969279,
                                 0.017776846384263745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045579492321596221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31566599572058113,
                                 -0.12526448666296489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3545976798630105,
                                 0,
                                 0,
                                 0,
                                 -0.3752630671331203,
                                 0,
                                 -0.34698843884549041,
                                 0,
                                 0,
                                 -0.1070235934482022,
                                 0,
                                 0,
                                 0.19870079530032594,
                                 0,
                                 -1.0936489807170533,
                                 1.0059248278775015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62280911715414222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071829322754986463,
                                 -0.17036061998350194,
                                 0,
                                 0,
                                 -1.097030950499962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30064760099399351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21428672849798977,
                                 0,
                                 0,
                                 0,
                                 0.08793576222827254,
                                 0,
                                 0,
                                 0.22765857850828192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38832235567101131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48204651399679688,
                                 -0.37738967468344592,
                                 0,
                                 0,
                                 -0.14914007986915034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7686249864229312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23993917264502124,
                                 0,
                                 0,
                                 0,
                                 -0.31854143704308296,
                                 0,
                                 0,
                                 0.4191687236842318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13413930042007016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30427224998466057,
                                 -0.29015114262522784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11492504555631514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21298244425405191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83815585464197317,
                                 0,
                                 0,
                                 0.10537540705026222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1818209549727024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1828745271165915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29394826740810032,
                                 0.3123972446395315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60081941709060238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038394540531664134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045624932072373309,
                                 0,
                                 0,
                                 -0.51830308117461421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38649897009417289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51274769910945073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36401334706532551,
                                 0.41737112047835617,
                                 0,
                                 0,
                                 0.098635847906809945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59085917859824832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55701152391816688,
                                 0,
                                 0,
                                 0,
                                 0.55080416470520965,
                                 0,
                                 0,
                                 -0.017386965058403939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59723881728589256,
                                 0.12057783384245674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11584653850397061,
                                 -0.33129614473803515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23815928617104593,
                                 0,
                                 0,
                                 -0.023449467214727029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30412244742236005,
                                 0,
                                 -0.24985147234253269,
                                 0,
                                 0.43903188685427452,
                                 0.3172605917480058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052710457323888821,
                                 -0.13026411387885595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17064399385843471,
                                 0.22120575114898614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46026657151044298,
                                 0,
                                 0,
                                 -0.41670233291097714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54735636571822233,
                                 0,
                                 -0.37073779871117335,
                                 0,
                                 -0.19247995821416988,
                                 0.20644931445682982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21553719338330843,
                                 0.4847106079851069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10898519596111714,
                                 0,
                                 0,
                                 0,
                                 -0.024872309099674667,
                                 0.45987373830058309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70329160729953777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84292531683741478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16430654782613763,
                                 0,
                                 0,
                                 0,
                                 0.60469743865262504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0069737288657326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36687762985964129,
                                 0,
                                 0.56846788436703977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43895739958679697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17710086270259859,
                                 -0.80085903801952307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75474815175868848,
                                 0,
                                 0,
                                 0,
                                 0.34558724601923874,
                                 0,
                                 -0.028977464055003475,
                                 0,
                                 0,
                                 0.77002115910432534,
                                 0,
                                 0,
                                 -0.32397303002658256,
                                 0,
                                 0.04623370806768555,
                                 -0.41397139432204388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50883930755662687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57013731677294421,
                                 -0.24190395676346477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16704715510163484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097898607083497569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13690863989001423,
                                 0,
                                 0,
                                 -0.026926302501191185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54822493930052252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87811083055272721,
                                 -0.19772106703383266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36755545734484768,
                                 0,
                                 0,
                                 0,
                                 0.01298410897281263,
                                 0.15367645110173372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1759138879792643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15331177861474973,
                                 -0.44000525479832753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18843164111128849,
                                 0,
                                 0,
                                 0,
                                 -0.54461676772731049,
                                 0.65887906566772692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12905558512140652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041704443180227119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7366296658640975,
                                 0.32977368683345021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040931363768101553,
                                 0,
                                 0,
                                 0,
                                 0.42968813523926441,
                                 0,
                                 0.18763965523248793,
                                 0,
                                 0,
                                 0.76542052546678385,
                                 0,
                                 0,
                                 -0.047512570370536626,
                                 0,
                                 -0.73743737279723187,
                                 0.00010068907616592182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18249608116374511,
                                 -0.3926173304022974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20644791348139355,
                                 -0.0089338954416010585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51760200964447112,
                                 0,
                                 0,
                                 0.37293464363115986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43127449789236744,
                                 0,
                                 -0.098561068637052718,
                                 0,
                                 -0.39554119778760072,
                                 0.10338932256442154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37107639829201139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56702395562529251,
                                 -0.50942069726600303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95442528852363495,
                                 0,
                                 0,
                                 0,
                                 0.42927775799414347,
                                 0,
                                 0.55005998881785334,
                                 0,
                                 0,
                                 0.17847581292845222,
                                 0,
                                 0,
                                 0.060689226138126127,
                                 0,
                                 -0.12186783131230612,
                                 0.49677005879703678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50444630531223855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51317717311602418,
                                 -0.5142181977674315,
                                 0,
                                 0,
                                 -0.087514231428771794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15390427883991609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78153066039331209,
                                 0,
                                 0,
                                 0,
                                 -0.51285332651284121,
                                 0,
                                 0,
                                 0.26189293821282167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23812691068014702,
                                 -0.34978705016931172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53693840249432323,
                                 -0.30711992859695525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29181648402920429,
                                 0,
                                 0,
                                 0.022787399571820403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19025772664679561,
                                 0,
                                 -0.46184061430268014,
                                 0,
                                 0.23400849406390412,
                                 -0.21997326777695289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22047269445309672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.010755674098335,
                                 -0.19192605523868231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10664255567755739,
                                 0,
                                 0,
                                 0,
                                 -0.34794707689919957,
                                 0,
                                 0.32488786689125199,
                                 0,
                                 0,
                                 -0.49890587392759478,
                                 0,
                                 0,
                                 0.55428002360617823,
                                 0,
                                 -0.27867605415228475,
                                 0.0085127623256800247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23209120615343473,
                                 -0.48897724904756834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35363041782866167,
                                 0,
                                 0,
                                 0,
                                 -0.2640662616104037,
                                 -0.48970975504174563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52195192769306198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34997627324499814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035396309408073201,
                                 0.41471487560026171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17887562874002871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39762574940763418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0059017767625819326,
                                 0,
                                 0,
                                 0.5333578689243198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.479235961651584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57582998314637401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054782028003816326,
                                 -0.40329689544610692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48070417734780141,
                                 0,
                                 0,
                                 0,
                                 -0.52940243713834445,
                                 0,
                                 -0.1136352364195036,
                                 0,
                                 0,
                                 0.65030406534190932,
                                 0,
                                 0,
                                 0.58493737427814596,
                                 0,
                                 0.0095472611170747956,
                                 -0.43259415155393077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069805738384131066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00053384495904367987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31902134067809285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19664804340228945,
                                 -0.62229111008519533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55861918753481632,
                                 0,
                                 0,
                                 0,
                                 -0.70623029437843043,
                                 0,
                                 -0.68762861565277889,
                                 0,
                                 0,
                                 -0.042278903266240453,
                                 0,
                                 0,
                                 -1.0338003568194867,
                                 0,
                                 -0.13766965862378266,
                                 0.063994500258959058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29336995380816805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13068483608089279,
                                 -0.3715479863756016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59402596620754888,
                                 0,
                                 0,
                                 0,
                                 0.24389363369618311,
                                 0,
                                 -0.76627172960397261,
                                 0,
                                 0,
                                 -0.56284365966657179,
                                 0,
                                 0,
                                 0.24258436764590174,
                                 0,
                                 -0.36725465656950806,
                                 -0.35718627950770709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043988939392431654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28657919106385571,
                                 0.47648845330690726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31708728632982403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65883997059206501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13542334239538761,
                                 0,
                                 0,
                                 0.34710114568373718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12435012393737385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22167165715111714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63247899880165714,
                                 0.75330913637572061,
                                 0,
                                 0,
                                 -0.072090496237147389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1779019205067443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75916334925845286,
                                 0,
                                 0,
                                 0,
                                 -0.26643999091583703,
                                 0,
                                 0,
                                 0.63761686408784657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16691539751739987,
                                 0.67528352401135394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62555723216945225,
                                 0.010587273592840118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02175889355326191,
                                 0,
                                 0,
                                 -0.18229425170907523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18171799555305665,
                                 0,
                                 0.076033846524807158,
                                 0,
                                 -0.22814706552950059,
                                 0.011796961432919251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73882067307836585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50691712793515553,
                                 -0.30496324264764302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032899312262818704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20993840003421202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.089377818762403805,
                                 0,
                                 0,
                                 -0.20989340036131407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083524418666576811,
                                 0,
                                 0,
                                 0.012280284566066293,
                                 -0.065713858537048586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089542438847174777,
                                 0.57678307490182634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51523195437232461,
                                 0,
                                 0,
                                 -0.42491529839519487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18384057333888226,
                                 0,
                                 -0.31690356524134577,
                                 0,
                                 0.19554898763684606,
                                 -0.19066386471641711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42745306319955451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48685768938400487,
                                 -0.3695070881900398,
                                 0,
                                 0,
                                 0.93626354856560767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54890606605117309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17496042038813642,
                                 0,
                                 0,
                                 0,
                                 0.95072994773308406,
                                 0,
                                 0,
                                 0.6962313243246514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37811755004294567,
                                 -0.32974129005774389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46377344901931672,
                                 0.47939558590554571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28071467127643451,
                                 0,
                                 0,
                                 0.11869329021037264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029999879185220367,
                                 0,
                                 0.42520035554155161,
                                 0,
                                 0.092589096479516325,
                                 0.14224964139883156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11405245963462758,
                                 -0.26687374849424128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035461380608832235,
                                 -0.35399724344103667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11691194360702964,
                                 0,
                                 0,
                                 -0.5162455096486086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27352780052094133,
                                 0,
                                 0.42853698500038107,
                                 0,
                                 -0.034048212475208381,
                                 -0.49940000621071634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84815144715689561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25032333433548631,
                                 -0.34429791201972931,
                                 0,
                                 0,
                                 0.59615894184972307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45413150601298546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25186212213987669,
                                 0,
                                 0,
                                 0,
                                 -0.45964621011967266,
                                 0,
                                 0,
                                 0.057560934915651174,
                                 0,
                                 0,
                                 0,
                                 0.56136154260698423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47173785057507189,
                                 0,
                                 0,
                                 0,
                                 0.85031301099062584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67626375128385985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89579172938313745,
                                 0,
                                 -1.0764977754462624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12815158544846486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082491546459049298,
                                 0.43325189263081981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67556554222309939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24427054169536724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063455875167935799,
                                 0,
                                 0,
                                 -0.47997360015379903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19648640951571811,
                                 0,
                                 0.46400339463597984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84296647968478178,
                                 0,
                                 0,
                                 0,
                                 -0.23969874182339673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23921205468604739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2490524077375345,
                                 0,
                                 0.67125050739048397,
                                 0.60990016032838823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46421294995716289,
                                 -0.052582522027457154,
                                 0,
                                 0,
                                 -0.50802575892980228,
                                 0,
                                 0,
                                 0,
                                 0.55441844805470786,
                                 -0.18252841624200011,
                                 0,
                                 0,
                                 0.21332049720475074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14547473921168502,
                                 0,
                                 0,
                                 0,
                                 0.18772093792284336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076082644777880307,
                                 0,
                                 0,
                                 -0.30079041173264598,
                                 0,
                                 0,
                                 0,
                                 0.6609358197595856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49607650589572527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77955449075891448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46263596447778083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54012334301367093,
                                 0,
                                 0,
                                 0,
                                 0.37597815603285029,
                                 -0.20801087049053146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23552234810914752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18983814481277084,
                                 0,
                                 0,
                                 0.30841622276927305,
                                 -0.2478909240992585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50438108694717276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39659649819187559,
                                 0,
                                 0.24023568677868762,
                                 0,
                                 0,
                                 0,
                                 -0.3570313777832097,
                                 0,
                                 0.3802175667736325,
                                 0,
                                 0.1023776066433123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18075013854499766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5231300454632134,
                                 0,
                                 0,
                                 0.41107887089369899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41484154593761358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22019169519875686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54524928949071771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023340376854630581,
                                 -0.07911417763027398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36055194476426716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12824599292278974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.016431222612718593,
                                 0,
                                 0,
                                 0,
                                 -0.39795756530992588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066819795170272894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30635882961212774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92620882528875415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33487343775877576,
                                 0,
                                 0,
                                 0,
                                 0.3730307261848913,
                                 -0.76609627162952076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028767758770500501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39564388019001512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41035515720242904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12282426990916087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7181822862716809,
                                 0,
                                 -0.37864942029236387,
                                 -1.2722187590787188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5889747896612022,
                                 -0.34284014613109898,
                                 0,
                                 0,
                                 0.25048119497951227,
                                 0,
                                 0,
                                 0,
                                 0.015909245561951585,
                                 -0.47389419262368593,
                                 0,
                                 0,
                                 0.46571522417893901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23193170657665674,
                                 0,
                                 0,
                                 0,
                                 0.55531905792218439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18236906687328414,
                                 0,
                                 -0.15511113597832182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24374310449692604,
                                 0.30912171492359103,
                                 0,
                                 0,
                                 -0.61910840375656229,
                                 0,
                                 0,
                                 0,
                                 -0.74947931166286252,
                                 -0.17083111802727563,
                                 0,
                                 0,
                                 0.22895035068201636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3588080985252512,
                                 0,
                                 0,
                                 0,
                                 -0.29759941967551296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0002637895297553719,
                                 0,
                                 0,
                                 0,
                                 -0.37324116821341025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10747154661908795,
                                 0,
                                 0,
                                 0.24505786028633286,
                                 0.50254569712511155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18921088757947815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56931143753773794,
                                 0,
                                 -0.029819044503446523,
                                 0,
                                 0,
                                 0,
                                 -0.3097971015116549,
                                 0,
                                 -0.24087329279449887,
                                 0,
                                 0.14743042033184606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18427917680836542,
                                 0,
                                 0,
                                 0,
                                 -0.78884425172110373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1235907604736407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85702216646661822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36603427547698031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28207562946764597,
                                 0,
                                 0,
                                 0,
                                 -0.051098895724990961,
                                 -0.18611566491325526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6303649607487436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059612083469086287,
                                 0.032886254432189163,
                                 0,
                                 0,
                                 0.63174988516799391,
                                 0,
                                 0,
                                 0,
                                 -0.91774216061245184,
                                 0.31546232880798952,
                                 0,
                                 0,
                                 0.49467238319525308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.074451641760815174,
                                 0,
                                 0,
                                 0,
                                 0.7958705000987929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28012094230824613,
                                 0,
                                 0,
                                 0,
                                 -0.068378127524593185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049211415486331858,
                                 0,
                                 0,
                                 0.39696090968663783,
                                 -0.32728177133415798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61908637867678962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24098042405608316,
                                 0,
                                 0.279137698072215,
                                 0,
                                 0,
                                 0,
                                 -0.15777542014591314,
                                 0,
                                 0.17405852648779124,
                                 0,
                                 0.39212820508531149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081904900912653678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20487728675517308,
                                 0,
                                 0,
                                 -0.090872689031848766,
                                 -0.44628133482384796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41534333466176088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44533722183573388,
                                 0,
                                 -0.091124551241308915,
                                 0,
                                 0,
                                 0,
                                 -0.0020244448967432251,
                                 0,
                                 0.03565767668309458,
                                 0,
                                 -0.60289089413546926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61505511577170324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013871358694109971,
                                 0,
                                 0,
                                 -0.37805046870631315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59772446642977151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10558792999976181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013347519849766828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081035679689535442,
                                 -0.3215965588788206,
                                 0,
                                 0,
                                 0,
                                 -0.41327506576705325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28729513148528224,
                                 -0.63780214383674716,
                                 0,
                                 0,
                                 0.29287998360231726,
                                 0,
                                 0,
                                 0,
                                 0.092158167158118878,
                                 -0.22194664035627323,
                                 0,
                                 0,
                                 -0.50950789758013015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68446259521092645,
                                 0,
                                 0,
                                 0,
                                 0.33854991276174501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50850439577638162,
                                 0,
                                 0.078081487497324867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084894582639959082,
                                 -0.28750240542336142,
                                 0,
                                 0,
                                 -0.12682560753724403,
                                 0,
                                 0,
                                 0,
                                 -0.058955729281100135,
                                 0.90396813229909134,
                                 0,
                                 0,
                                 0.32356476481827479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21583513515902425,
                                 0,
                                 0,
                                 0,
                                 -0.59696436315043322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3503047122172509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082580475104489723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26452108780769201,
                                 0,
                                 0,
                                 -0.1899568809350714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21498711472260032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50906962755527474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15607297658182759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74655077869898101,
                                 0.0075669168616730705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86804630894241608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43449662133626438,
                                 -0.97548529627602742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20437868923038827,
                                 0,
                                 0.255145619835079,
                                 0,
                                 0,
                                 0,
                                 0.32134004195000504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12275358022925681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0062441092733371006,
                                 -0.28832532136175848,
                                 0,
                                 0,
                                 0.2663201241461351,
                                 0,
                                 0,
                                 0,
                                 -0.26026861076179342,
                                 -0.0020418341351272629,
                                 0,
                                 0,
                                 0.77209961464671539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62245020838723897,
                                 0,
                                 0,
                                 0,
                                 -0.19631965687325625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0441956399048546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41305853522516378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50402344104937924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01654335966727085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29698418989909769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15751077228588822,
                                 0,
                                 -0.67975001446501071,
                                 0,
                                 -0.83866728541173696,
                                 0,
                                 0,
                                 0,
                                 -0.67041745887443138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68233802464837756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71179137139248871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66055044551028641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82739944633954787,
                                 0,
                                 0,
                                 0,
                                 -0.48880589166961608,
                                 0.36838511740130486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13692102745282322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047414125998829493,
                                 0,
                                 0,
                                 0.098011913300325132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099804477434124295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53506938436999041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51026404343196907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41453595178820413,
                                 -0.49084474999512034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2510694693079574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69222927308707127,
                                 0.72698053689606379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069344868983765934,
                                 0,
                                 0.64713211035272411,
                                 0,
                                 0,
                                 0,
                                 0.13868025032673659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17871579181166289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63962311762154778,
                                 0.18428974806966242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32233789589465384,
                                 0,
                                 -0.88108532595774258,
                                 0,
                                 0,
                                 0,
                                 0.19891579163177547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075529700643230779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16582652680582166,
                                 -0.50444979652528832,
                                 0,
                                 0,
                                 -0.87142662505478341,
                                 0,
                                 0,
                                 0,
                                 -0.42393342280969221,
                                 0.35331103577273415,
                                 0,
                                 0,
                                 -0.3384794140782742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44615512109717115,
                                 0,
                                 0,
                                 0,
                                 0.15402131016506565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24577455993771963,
                                 0,
                                 0,
                                 0,
                                 0.73220386952360395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2726398771520756,
                                 0,
                                 0,
                                 0.39169573734742519,
                                 0.22447894826967085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20186016145776009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17254013236751581,
                                 0,
                                 -0.062878312507300013,
                                 0,
                                 0,
                                 0,
                                 0.29735878770940927,
                                 0,
                                 -0.043039789752670227,
                                 0,
                                 -0.14485394573113158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33921196236624057,
                                 0,
                                 0,
                                 0,
                                 -0.11730084365964855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77293215364164913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46319906970120078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11834791083569821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.027040769217944,
                                 0,
                                 0,
                                 0,
                                 0.78371862595775743,
                                 0.35412159149881151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20492314159890035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6038050849176827,
                                 0,
                                 0,
                                 -0.17023421631741359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23258173864432469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55184552163385958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18091774353022763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04110688284825656,
                                 -0.41400179518916602,
                                 0,
                                 0,
                                 0,
                                 0.21400231689184418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87077523912592902,
                                 0.17714086360253872,
                                 0,
                                 0,
                                 -0.014346538125832281,
                                 0,
                                 0,
                                 0,
                                 0.026428191125690795,
                                 0.13973983659391997,
                                 0,
                                 0,
                                 -0.59646246571291173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54510417475881801,
                                 0,
                                 0,
                                 0,
                                 -0.6854888727983508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45791886246796831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6417767932385614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30085541447128133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36554025744756824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58969634155742123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058579877398439062,
                                 0,
                                 -0.11320561004952492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19042579316042424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40858389174028309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79024007580591893,
                                 0,
                                 0,
                                 0,
                                 -0.65675845628066432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50532885514206405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046161290698840507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83468859946030727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25820218018626623,
                                 0,
                                 0,
                                 0,
                                 0.6636963807334364,
                                 -0.16936953429422699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046215268533292102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40823370858732871,
                                 0,
                                 0,
                                 -0.42725272373508821,
                                 0.025803183583563982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1532599857817897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2233918526010828,
                                 0,
                                 -0.34265535008154019,
                                 0,
                                 0,
                                 0,
                                 -0.034175300433227668,
                                 0,
                                 0.62337804053543988,
                                 0,
                                 0.25966387760708237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23592665329715162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27939526801714859,
                                 0,
                                 0,
                                 0.7157555844061998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080392878176805446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22076130014217282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11552656771513189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36223401740980704,
                                 -0.39269887209676124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15939358766769657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61186170638510395,
                                 0,
                                 0,
                                 0.16437187600541039,
                                 0.35904120405855605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099579233887263155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022110350077604576,
                                 0,
                                 -0.043502478931535894,
                                 0,
                                 0,
                                 0,
                                 0.46961514959645972,
                                 0,
                                 0.45642447538179065,
                                 0,
                                 0.055957029077747023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70043807500330391,
                                 0,
                                 0,
                                 0,
                                 0.15681346600635732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45592370248918057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036125221338950464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64703402842683055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62406452655692779,
                                 0,
                                 0,
                                 0,
                                 -0.37309369863768471,
                                 -0.53818469821269643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35664157995669504,
                                 0,
                                 0,
                                 0,
                                 0.13581231572366775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54594145754467716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53244114677339216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21623348687481531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51465431801346895,
                                 0,
                                 0,
                                 0,
                                 -0.3811046341040914,
                                 -0.66312825988107305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16556444130969886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74929537882341379,
                                 -0.10688805151854128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0727863188468578,
                                 0,
                                 -0.67580376170312118,
                                 0,
                                 0,
                                 0,
                                 0.41084601513686747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068822686077639389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19121465226541248,
                                 0,
                                 0,
                                 -0.30124837601461074,
                                 -0.034144773852172225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0083894160893294295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31103718676887043,
                                 0,
                                 0.74106361870508097,
                                 0,
                                 0,
                                 0,
                                 0.45051671743274624,
                                 0,
                                 -0.053493535279675458,
                                 0,
                                 0.12234080750282164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67534881984611439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020932030274984297,
                                 -0.014462804972023929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40134270854855869,
                                 0,
                                 1.0926423937533947,
                                 0,
                                 0,
                                 0,
                                 1.2242321165238756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049449455958420069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084352138727368936,
                                 0,
                                 0,
                                 -0.11593364272747794,
                                 0.43009383490184333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12296662847420385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27875263468393308,
                                 0,
                                 0.4230687381007619,
                                 0,
                                 0,
                                 0,
                                 -0.3989637139766119,
                                 0,
                                 0.33261160782513427,
                                 0,
                                 -0.50040448110618296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21759762512194916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66686410404202923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04221688141207687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50592677091807325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49960349497147633,
                                 0,
                                 0.024407488319067833,
                                 0,
                                 0,
                                 -0.47221794605935191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49897348794219287,
                                 0,
                                 0,
                                 0.46022877075348112,
                                 -0.11663517169944636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25431787859387367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087114012748874037,
                                 0,
                                 -0.061276587176433278,
                                 0,
                                 0,
                                 0,
                                 0.28176448200444998,
                                 0,
                                 0.23147110307227539,
                                 0,
                                 -0.30599025383375694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30171861267650835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63281056288609827,
                                 0.25263985593688243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60482361105414073,
                                 0,
                                 0.40649184702876384,
                                 0,
                                 0,
                                 0,
                                 -1.1525264826271888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21868048724918546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36519944756527051,
                                 0,
                                 0,
                                 0.30096413483318774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25839952978255198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12773764530136689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56556418613472781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039496497840019115,
                                 0.56896287448281169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64652428736243339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27912381273842346,
                                 0,
                                 0,
                                 0.10264939250951996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53583949441831635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15915318783979646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22772005088425579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35950951642001938,
                                 -0.001459548203613735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4926184579828034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19392612106128576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17025595169409441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47548031391929479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39570098790155595,
                                 0,
                                 -0.55504218270907058,
                                 0.49543413752254162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1581438765989609,
                                 -0.55621623333294257,
                                 0,
                                 0,
                                 0.16046872578956864,
                                 0,
                                 0,
                                 0,
                                 -0.25374085070618568,
                                 -0.97364125427521131,
                                 0,
                                 0,
                                 -0.060929882646599404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35501257424630994,
                                 0,
                                 0,
                                 0,
                                 -0.6387049357654474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44638955771916988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35588753643437099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12883026365955566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8166675751063166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2587071471155592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22313680612908149,
                                 0,
                                 -0.27033585431439633,
                                 0.32778603414229668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42115953848314813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048092928139201616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77310473343254194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080810475375577423,
                                 0,
                                 0,
                                 -0.2492394359781592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06119032452095087,
                                 0,
                                 0.20683862110593784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42458779817361619,
                                 0,
                                 0,
                                 0,
                                 -0.23450108649077067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44962184970266966,
                                 -0.36336331598659904,
                                 0,
                                 -0.029126710936673052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3624910913168069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29102601308575937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41424030764886333,
                                 0,
                                 0,
                                 0.20490156332845477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0042136610912740478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44910976598077268,
                                 1.0096453121960989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56144776264842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41646824381261854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37194377668585021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070757298640750366,
                                 0,
                                 0,
                                 -0.71588937264680763,
                                 -0.58976128711540976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60694194651562638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22367114816357542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50495404510246389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39225006241215654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20542539930118603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43348814986263007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29357802666752536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60570843128572338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7920605334807751,
                                 0,
                                 0,
                                 0.12251414722286361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53802662580979732,
                                 0,
                                 0,
                                 0,
                                 0.79192105178115058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071792267804598964,
                                 0,
                                 0,
                                 0,
                                 0.058602031980897334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45844604292146068,
                                 -0.20132363825440822,
                                 0,
                                 -0.22047952809554058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14639000524113233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37388300469010555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49398184166618203,
                                 0,
                                 0,
                                 0.31842078289893444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43066004983411837,
                                 0,
                                 0,
                                 0,
                                 0.48527454527895497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29667539512195851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38855357876812474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19346801554652795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.389422552257225,
                                 0,
                                 0,
                                 0.39481281720098382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42255290764167192,
                                 0,
                                 -0.044838871878804809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29633090890157432,
                                 0,
                                 0,
                                 0,
                                 0.47698373208713574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0083392183771516248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023367221844527331,
                                 0.43216412971661872,
                                 0,
                                 0,
                                 0,
                                 -0.82037175637190141,
                                 0,
                                 -0.37270194320118544,
                                 0.6966467768950817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091227357408216622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012371101733897064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75322220018843167,
                                 0,
                                 0.11590964175363136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32487286918004143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27558773627332134,
                                 0,
                                 0,
                                 0,
                                 -0.48726242871684772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017481880312956222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67843338033835554,
                                 -0.23700868709566342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4960138981166376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.5842184993383968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29025364508043427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51342148603855242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35928947913243009,
                                 0,
                                 -0.45631841845694221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42692690391559773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50410271430230913,
                                 0,
                                 0,
                                 0,
                                 -0.10627185632009568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46368603155806748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45400493817924792,
                                 0,
                                 0,
                                 0,
                                 -0.29461871382089894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13342029935116062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50747627040342269,
                                 0.26500161722569382,
                                 0,
                                 0,
                                 0,
                                 -0.29610812039898982,
                                 0,
                                 0.94407191849447192,
                                 0.19318106721570352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42794419693431679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84028092258557541,
                                 0,
                                 0,
                                 -0.40665207809578152,
                                 0,
                                 0,
                                 0,
                                 0.59171174149033345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0089165637324203698,
                                 -0.53392395269301307,
                                 0,
                                 0.016337322663277393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29703509381325066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096078381075429695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24882751891590305,
                                 0,
                                 0,
                                 -0.1986634907889884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015712506926234777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29648879463285915,
                                 0,
                                 0,
                                 0,
                                 0.43904096273474025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44447089781532989,
                                 -0.057236463987560479,
                                 0,
                                 0.085358405870969073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069505281176183487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52899690028287272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.304689437913372,
                                 0,
                                 0,
                                 0.071930843850418619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3585283446778505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.036133636859133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19300960296350861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84630162794948482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0025594256601767229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26189616044532765,
                                 0,
                                 0,
                                 -0.25294500568418521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68612252930025974,
                                 0,
                                 0,
                                 0,
                                 0.82052536764268025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35334572851598256,
                                 0,
                                 0,
                                 0,
                                 -0.21636675033630959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015509096352194635,
                                 0.19941375564910413,
                                 0,
                                 -0.18114088331793171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60310022368986704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019133199850572092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14633917434968563,
                                 0,
                                 0,
                                 0.1922442581338703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57710038986418322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91865371474200208,
                                 0,
                                 0,
                                 0,
                                 -0.11402350354829494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41372233527572916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23729270761801174,
                                 0.26591953998582296,
                                 0,
                                 0,
                                 0,
                                 0.41225067768278334,
                                 0,
                                 0.10709216952831888,
                                 0.75815210854317927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89846528388085034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066732788921900626,
                                 0,
                                 -0.091229410529413676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71185232842482415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57042334902430791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30643463612647015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038102886985831336,
                                 0,
                                 0,
                                 0.12700407018800397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15341321604013983,
                                 0,
                                 0.15665565787353691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55350752498819578,
                                 -0.23239185541454052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57934362430823561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52392386361506438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76599350951487011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0113541755704938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16908706168389268,
                                 0,
                                 0.67631793641574367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22479895653288465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41942550428564862,
                                 0,
                                 0,
                                 0,
                                 -0.16958518006278761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50871618477593727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79581818675332827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66475749441452792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20168518966949367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052338505266356472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16176750738107237,
                                 0,
                                 0,
                                 -0.45153662395701188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37398015766696385,
                                 0,
                                 0,
                                 0,
                                 0.8691772870735831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32733771562860348,
                                 0,
                                 0,
                                 0,
                                 -0.33988408194384662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34586098681805677,
                                 0.082843438357801127,
                                 0,
                                 0.2730621441939845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21774723369194329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51893867884123712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.093209139900014337,
                                 0,
                                 0,
                                 -0.33738465968522785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37021004330638696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38370789287336571,
                                 0,
                                 0,
                                 0,
                                 0.0088815694781450572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28380881568003813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60004474253819939,
                                 -0.4070041181960285,
                                 0,
                                 0,
                                 0,
                                 0.31645705043986072,
                                 0,
                                 -0.37465749684306487,
                                 0.56936647693618136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1947636500075289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.99258795423630697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56258852163161688,
                                 0,
                                 0,
                                 0,
                                 0.43650038780866179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64988851767310918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12696317801796014,
                                 0.45668084524624186,
                                 0,
                                 0,
                                 0,
                                 -0.19859862596730413,
                                 0,
                                 0.018484866578696624,
                                 -0.84201686448612023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091504906189442653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17899624517938742,
                                 0,
                                 0.53880652239876636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26297286627188171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29953792464580087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22299278446404913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08871939536770318,
                                 0,
                                 0,
                                 0.49370569769844158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45742931440762047,
                                 0,
                                 -0.20056427415522782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022956523990938615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33486186841041338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47928553148742253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89800216128099897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7463942437119192,
                                 0,
                                 0,
                                 0.24145031748068421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028286535391574785,
                                 0,
                                 0,
                                 0,
                                 0.33416282369858413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11244163288867937,
                                 0,
                                 0,
                                 0,
                                 -0.10760831179328741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30563951472426876,
                                 -0.18404450071062162,
                                 0,
                                 0.75397526143414395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12968725092506586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14192435535238851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16653862022619917,
                                 0,
                                 0,
                                 0.40867734782744292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21976613028427391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19438858716617233,
                                 0,
                                 0,
                                 0,
                                 0.58452003534742314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1785849637517178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42663826848794156,
                                 0.63396869857044058,
                                 0,
                                 0,
                                 0,
                                 -0.044897004905574356,
                                 0,
                                 -0.0014649640881913145,
                                 -0.28085475004773924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50820784449352119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17916951553199584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1727680268346547,
                                 0,
                                 0.2858253292141944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42570705229534944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57511443488766678,
                                 0,
                                 0,
                                 0,
                                 0.39339781596535039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47086106325198862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68029465773984599,
                                 0,
                                 0,
                                 0,
                                 -0.77721800372007277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41934767469000545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.496560459434917,
                                 -0.52296427812118262,
                                 0,
                                 0,
                                 0,
                                 -0.77392604910698148,
                                 0,
                                 -0.097931777204961573,
                                 -0.2675236858581439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071180142260728579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11172273006824336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040326066044862961,
                                 0,
                                 0,
                                 0,
                                 -0.11451786121028316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57779246012447016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.93323726515469674,
                                 -0.74689564579418799,
                                 0,
                                 0,
                                 0,
                                 -0.050429639904015638,
                                 0,
                                 0.34811062467249254,
                                 -0.15321268265383081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18880121938237496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81721396386236811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11690003505591828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.049587058431756939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58735749501101098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94729294847025514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1794166960696681,
                                 0,
                                 0,
                                 0.24688721129654384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12290662074112962,
                                 0,
                                 0,
                                 0,
                                 0.65016375531125292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25410114548898555,
                                 0,
                                 0.19371506431975846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61483390812539085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14115184864662761,
                                 0,
                                 0,
                                 0,
                                 -0.68333020129118049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18172049626563799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50918980497399469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24141332548898281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08467195093442377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33895661783002506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50707293046755642,
                                 0,
                                 0,
                                 0.32109606684866243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13563807888597121,
                                 0,
                                 -0.42633448293396503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17466987205366871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23845408843183469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67819320520584914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0208337937407055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04381654454827788,
                                 0,
                                 0,
                                 0.80475659624826601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54034375404841162,
                                 0,
                                 0,
                                 0,
                                 0.25829620321244068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53509010949870961,
                                 -0.099378615795849931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11857185019187455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0014977435400237091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80192058343008465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0611426034106815,
                                 -0.085802540284159595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018856312946649884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011604107715765172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19404742895130278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69057907956960651,
                                 0,
                                 0,
                                 0.20916228241410603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39753604662604297,
                                 0,
                                 -0.52517622723558932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42492442817988035,
                                 0,
                                 0.44912232169314287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32001443369129001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3785942971189607,
                                 0,
                                 0,
                                 0,
                                 0.31752240742246746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52073506862496366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55736616351867796,
                                 0,
                                 0,
                                 0,
                                 -0.33078941560361685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20678644931296869,
                                 -0.52247320353617155,
                                 0,
                                 0.060065907193796925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46766115807835645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1484256826735291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041736662104574732,
                                 0,
                                 0,
                                 0.10376785258433899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085601792056993697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2864977843567707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22068901782680941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60874866351206447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52934994323502549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13103169799917344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08988091873166551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26337767224072778,
                                 0,
                                 0,
                                 -0.65833851625116879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80943164482789554,
                                 0,
                                 0,
                                 0,
                                 -0.12660046087837135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056701322828605696,
                                 0,
                                 0,
                                 0,
                                 0.22801128799224496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3018703532916009e-07,
                                 0.28585433570285579,
                                 0,
                                 0.51316577123521567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2817140339423736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4041706900149542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53616423173977557,
                                 0,
                                 0,
                                 -0.20472001826145503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16626752439582315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012037661693220864,
                                 0,
                                 0,
                                 0,
                                 -0.97644099367636128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099761414333715992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31639767378124045,
                                 0.45784537259065805,
                                 0,
                                 0,
                                 0,
                                 -0.53380792633045249,
                                 0,
                                 -0.7461882687929382,
                                 -0.3464617357173328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27628996962190949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38312965699081852,
                                 0,
                                 0.29981587396509118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21316966815373189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098629573506713114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23620742402233769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2876792677208837,
                                 0,
                                 0,
                                 -0.58224354859821159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22231775097101886,
                                 0,
                                 -0.57267381728774436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42819299751170303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88270472231695263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41805745987411191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49923600581366884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40948787512274065,
                                 0,
                                 0,
                                 0.53372680638422254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46919350939988447,
                                 0,
                                 0,
                                 0,
                                 -0.12272961039641216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043632166006869484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23375762129272915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64387548013200702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1136278546266051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12535947799585082,
                                 0,
                                 0,
                                 0.19044185130451338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59922434253427381,
                                 0,
                                 0.32390395980526521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052736789596352696,
                                 0,
                                 0,
                                 0,
                                 0.25173239124438335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36605604903246036,
                                 0.32232419097825338,
                                 0,
                                 -0.013666594527996651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16756213077657894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10609664637429969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28737410770530725,
                                 0,
                                 0,
                                 0.66445529148582849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36380580683548536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054838424775372464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11679677006081103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55603189747936455,
                                 0,
                                 0,
                                 0,
                                 0.38562093848864853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14866425727761334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39470178615245899,
                                 -0.6808215449800249,
                                 0,
                                 0,
                                 0,
                                 -0.43634473041668931,
                                 0,
                                 -0.63097204981474975,
                                 -0.64660597683060095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66099757008192883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15352002245609078,
                                 0,
                                 0,
                                 0,
                                 -0.49271339866332087,
                                 -0.43078274335246591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92506087083099864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80994787637089849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01019420834929452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064586021876751609,
                                 0.38751941976789511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29797871588393143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092507433151494081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75376686607930332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3973289612987147,
                                 0,
                                 0.16261908593061492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68474774680229378,
                                 -0.29087660054364461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55373368374320375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84532885260119039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18380995593966815,
                                 0,
                                 -0.67474124570371297,
                                 0,
                                 -0.067694232590952655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26476894062320011,
                                 0,
                                 0.18814294158583947,
                                 -0.31336960337852915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65938955722919779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41634891457264944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29173792808853899,
                                 0,
                                 -0.059003971760290347,
                                 0,
                                 0.90885688642007656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47337055356520069,
                                 0,
                                 0,
                                 0,
                                 0.74434706928647953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44101416156314438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62396889000375511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1760370102299875,
                                 -0.25332618044052879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.5154531377700158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32799726684557645,
                                 0,
                                 0.099478803757152914,
                                 0,
                                 0,
                                 -0.27197962322593011,
                                 -0.11697458840191607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11739202356626786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39888093583589684,
                                 -0.60869614744021217,
                                 -0.47904811353431659,
                                 0,
                                 0,
                                 -0.07962517108096423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12506254328792582,
                                 0,
                                 0,
                                 0,
                                 -0.70850804945990409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39668586850522536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031419162463528626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41723107513576835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31147777407243837,
                                 0,
                                 -0.26185745742444927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060936820823546609,
                                 0,
                                 0.20516955673709256,
                                 0,
                                 0,
                                 0.078073556933788008,
                                 0.17606341935153266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054751648155979563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30209758704582418,
                                 -0.046770441038277773,
                                 -0.34080596246413414,
                                 0,
                                 0,
                                 -0.37977859202195957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74851165434565647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016439386150292945,
                                 -0.55272009494817309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015538307456390524,
                                 0.63839459541506438,
                                 0,
                                 0,
                                 0,
                                 -0.3124143570763333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36951708468056893,
                                 0,
                                 -0.15990135446314452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16348423542446042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46760343784841496,
                                 0.48476018546562338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22418487424253575,
                                 0.14985696832654052,
                                 0,
                                 0,
                                 0,
                                 -0.39230213602762454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076475476833216011,
                                 0,
                                 -0.4306637956594393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35835436278075694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21090565170151512,
                                 0,
                                 0.59786741153932565,
                                 0,
                                 0,
                                 -0.052717599488605278,
                                 0.14183115496497301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40336424271588039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18289331975594508,
                                 0.29942511909202574,
                                 -0.41141674744030993,
                                 0,
                                 0,
                                 0.17987001194856855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29623149825088807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0557531693480047,
                                 0,
                                 0.085933646186408502,
                                 0,
                                 0,
                                 0.30554471561444635,
                                 -0.10748665013604886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46271150388651927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66881533266683646,
                                 0.19806393880734721,
                                 0.13192437709823315,
                                 0,
                                 0,
                                 0.092404753639363499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39750239081094102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1167420234559189,
                                 0,
                                 0,
                                 0.47335003486808336,
                                 0,
                                 0,
                                 0,
                                 0.29956784274665704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7789705839649923,
                                 0,
                                 -0.39758040099333519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38324859768833641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28106321322311956,
                                 0,
                                 0,
                                 0.41943165469316523,
                                 0,
                                 0,
                                 0.32539326855993556,
                                 -0.22793327710835998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17963094540366831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2889894358887273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14805811800751179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78924502899246796,
                                 -1.1831194036277353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22947931839899377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49359746032509944,
                                 0.22116390416719506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3084293539894003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12805345259811768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85386158286519154,
                                 0,
                                 0.34514983757793849,
                                 0,
                                 0.81539588029576615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14465779041693577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1433690605752018,
                                 0,
                                 0,
                                 -0.045695622869188976,
                                 0,
                                 0,
                                 0,
                                 0.44335583662949274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15303899026788681,
                                 0,
                                 0.35572424785938639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39559634601036192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.98514876046253674,
                                 0,
                                 0,
                                 0.46505508656953193,
                                 0,
                                 0,
                                 -0.061730652681222138,
                                 0.26618619307985764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11085087378845274,
                                 -0.13409931213270948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095740030945061005,
                                 -0.1619772048770444,
                                 0,
                                 0,
                                 0,
                                 0.50679776707246238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67282595630559583,
                                 0,
                                 -0.091938378022390771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46511856585086714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28403111779323054,
                                 0.47018763187730517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0033858923742529634,
                                 -0.15783058180730355,
                                 0,
                                 0,
                                 0,
                                 -0.23216594369127258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61920849238106601,
                                 0,
                                 0.088075335415416206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47775570219360408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3321713185107114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13277371157926854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4311189420643648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69605678975043117,
                                 -0.54495903992311212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92692950974024502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42047729117299626,
                                 0,
                                 0,
                                 0.07665411874578669,
                                 0,
                                 0,
                                 0,
                                 -0.35504051617123134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19139459944898762,
                                 0,
                                 0.58886974363655231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23587161943086898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16682219612581051,
                                 0,
                                 0,
                                 0.11915425730886001,
                                 0,
                                 0,
                                 0.17665795398146711,
                                 -0.87123833810970142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50251297887491142,
                                 0,
                                 0.089855707019945039,
                                 0,
                                 0,
                                 -0.34272103778829693,
                                 -0.32131724259379246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15681868684445083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28225975095143307,
                                 0.082635586017981072,
                                 0.16668724387291095,
                                 0,
                                 0,
                                 0.5394188455063087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29808646742651346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6502316091637228,
                                 -0.32899200486569535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061954448729991535,
                                 -0.52590886629303624,
                                 0,
                                 0,
                                 0,
                                 -0.13993140431187656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063423326291114079,
                                 0,
                                 -0.073233449686213953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39947236629370397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042871512141740536,
                                 0,
                                 0.077405774612042469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46716475803377905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7908990331216893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2997303412145097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095652031055415671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23758067018668277,
                                 0,
                                 0.028348631756607529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094942989643876569,
                                 0,
                                 -0.34725648470284759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59592150173349978,
                                 0.88365660583726791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2189123217968022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19142005303864584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46521982002663392,
                                 0,
                                 0.092444061701196595,
                                 0,
                                 0.34792260510719941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78591717256180482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054380446967061867,
                                 -0.2104053933390079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62603493496382434,
                                 -0.21514744966886409,
                                 0,
                                 0,
                                 0,
                                 -0.3369635587823539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11847718592799766,
                                 0,
                                 0.54004714002587195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30875876597196944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39446342919678673,
                                 0,
                                 0,
                                 -0.44396432467127933,
                                 0,
                                 0,
                                 0,
                                 -0.025459163105900788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54935066658243492,
                                 0,
                                 0.21391329366631592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28997367778605349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31989823392825523,
                                 0,
                                 0,
                                 -0.58494849819061367,
                                 0,
                                 0,
                                 -0.032021996423584831,
                                 0.94899153643441281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44940673926316504,
                                 0.23532806219520502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31734352183639969,
                                 0.42106224370060036,
                                 0,
                                 0,
                                 0,
                                 0.46882628305685314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026201427249357284,
                                 0,
                                 0.39404978952502501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.298151181159928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59918835309677954,
                                 0,
                                 0,
                                 -0.50023353289811956,
                                 0,
                                 0,
                                 0,
                                 -0.012460125754823626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19008056738401855,
                                 0,
                                 0.00097867873784784898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2956359420678879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030559257562970982,
                                 0,
                                 0,
                                 0.62215639639886422,
                                 0,
                                 0,
                                 0.81268355249907298,
                                 0.074120779332225495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37802051099636985,
                                 0,
                                 -0.28153096286193652,
                                 0,
                                 0,
                                 0.73234608874868701,
                                 -0.0033256413127083218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049785616815496474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18068520433118709,
                                 0.0036818553676138538,
                                 -0.36015145911129059,
                                 0,
                                 0,
                                 0.23796228020288995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14150805473976483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076389129116268745,
                                 0,
                                 0.032941482117653659,
                                 0,
                                 0,
                                 0.13906141959787133,
                                 0.37628449518625601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49789037923260754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27290540727506341,
                                 -0.58220543795638202,
                                 0.40972122413955581,
                                 0,
                                 0,
                                 0.054232405289590974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0018605478620340749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.055829274441473696,
                                 0,
                                 0.014686296797030075,
                                 0,
                                 0,
                                 -0.079756459094518617,
                                 0.64710696256226141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3749338715437146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25000344325036972,
                                 -0.051691231682545087,
                                 -0.10497051244680249,
                                 0,
                                 0,
                                 0.57119746649067227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16889175151116917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46933354273697908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32145850953254024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26596769812702009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86827174210068059,
                                 0.86565998913201969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096809071667752628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17054175065478822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65501265585527912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5730645326345446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38703211806470406,
                                 -0.75780565571203851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47365187796587194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6583881763554309,
                                 0,
                                 0.284235450666594,
                                 0,
                                 0,
                                 0.020663622231633483,
                                 0.39610432910188675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045059347625576202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13799888367733334,
                                 0.25807154255704168,
                                 0.28698699845132403,
                                 0,
                                 0,
                                 -0.34305866090038312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20170238749571948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2478569858095539,
                                 -1.1312868571020098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26548710957080029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073262259003883445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90225958553680119,
                                 0,
                                 0.66392168112983474,
                                 0,
                                 -0.59064948355104019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32581737882528694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43604744385547878,
                                 0,
                                 0,
                                 -0.7637290406373608,
                                 0,
                                 0,
                                 0,
                                 0.43305869865410263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35281215168792679,
                                 0,
                                 -0.43929854317426686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20621472063957652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19140614308823722,
                                 0,
                                 0,
                                 0.24650858502305453,
                                 0,
                                 0,
                                 -0.35874725116134054,
                                 -0.66157440367615739,
                                 0,
                                 0,
                                 0.31590161541590916,
                                 0.18127821894073862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63153373462067064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51154324429535192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41979826964548672,
                                 0,
                                 0.54233591550140159,
                                 0,
                                 -0.33659883678799779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33306191130257246,
                                 -0.033206940076233399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10585958298920303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42771892460420791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42075163481659955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76203591417414862,
                                 0,
                                 0.21683379963343602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.99372669808845482,
                                 0.088632534424544968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61857388646796452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71877328883901381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15695878476757055,
                                 0,
                                 0.54516515259480358,
                                 0,
                                 0.37556026014873062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06320420914019162,
                                 0,
                                 0,
                                 0,
                                 -0.70455591374056015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30265422368265499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.4444912264222385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13197456924387949,
                                 -0.25429240171222378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5878107107434063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65914735220799403,
                                 0,
                                 0,
                                 0.1144934517763867,
                                 0,
                                 0,
                                 0,
                                 -0.020615073420105851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27640383283384851,
                                 0,
                                 0.59223996502046528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63676599967005154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10884091734307709,
                                 0,
                                 0,
                                 0.1692455785180681,
                                 0,
                                 0,
                                 -0.70444754488604144,
                                 0.34127363387508158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24574454935497014,
                                 -0.11208728239510314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66622599844616626,
                                 -0.13669728717343388,
                                 0,
                                 0,
                                 0,
                                 0.29125243328800554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05242923195874194,
                                 0,
                                 -0.56609277831407379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23762363169962944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083901857571897304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34191038862051704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72746220628115643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26531835612705051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32767415897518715,
                                 0,
                                 0.41120836363557561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29804178064620768,
                                 0,
                                 0,
                                 0.067611316187316112,
                                 0,
                                 0,
                                 0,
                                 0.049948143670269785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27683709341700385,
                                 0,
                                 0.41346500337506509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29398479204881128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84498695079965669,
                                 0,
                                 0,
                                 0.60888979831753398,
                                 0,
                                 0,
                                 -0.04258341402778943,
                                 0.20600337446926076,
                                 0,
                                 0.34851098896774441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014790566531203315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43413384291623464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034331650094458863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024446451163375862,
                                 0,
                                 -0.82950156417724819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057174195487421392,
                                 0,
                                 -0.64323793121701356,
                                 0,
                                 0,
                                 -0.3793154700273188,
                                 0.3211810228401949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43456349471582656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02294877734424889,
                                 0.28868413102434498,
                                 -0.2212484609600513,
                                 0,
                                 0,
                                 -0.11849266417916673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015381879317029208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63067958891464126,
                                 0,
                                 0,
                                 -0.14536261453022084,
                                 0,
                                 0,
                                 0,
                                 1.0474362495031082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090090246343369096,
                                 0,
                                 0.38423319223347074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23123293123137567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20755737893716777,
                                 0,
                                 0,
                                 -0.79295949773373742,
                                 0,
                                 0,
                                 0.35011350794129403,
                                 0.051649243577849058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58731525541271301,
                                 0,
                                 0,
                                 0.3575352890330934,
                                 0,
                                 0,
                                 0,
                                 0.5202258132583053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0850454312501485,
                                 0,
                                 -0.065090475860856256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64909845561789137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26442420896257934,
                                 0,
                                 0,
                                 0.23595396336345004,
                                 0,
                                 0,
                                 0.64339378720732376,
                                 -0.095767601040707917,
                                 0,
                                 0,
                                 0.57733875418011926,
                                 0.54635717552407836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58766578313769091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045622815436476505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65342196310876233,
                                 0,
                                 -0.02051618234149441,
                                 0,
                                 -0.11211507819719013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71037851697532672,
                                 0.17566679133797866,
                                 0,
                                 0.29200439244723081,
                                 0.70563639898620667,
                                 0,
                                 0,
                                 0,
                                 0.28691117130644628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54677343548588975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068356972320620601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79224589171355375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40477694803923731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69294781685099671,
                                 0,
                                 0.25815931141304171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17275943321531456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34611687097185045,
                                 0,
                                 0,
                                 0.81777627335252467,
                                 0.11141851212725293,
                                 0,
                                 0,
                                 0,
                                 -0.078426091749588145,
                                 0,
                                 -0.57922982719040572,
                                 -0.095031635619408777,
                                 0,
                                 0,
                                 0,
                                 0.46070034451519049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13450909498207739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64728173123304278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74957037357280698,
                                 0,
                                 0.42223072921349014,
                                 0.18611156100635595,
                                 0,
                                 0,
                                 0,
                                 0.18515830855947712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35403680119313286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25612945438170909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33864403355283573,
                                 0.24376181949499809,
                                 0,
                                 0,
                                 -0.48340622265144373,
                                 0,
                                 0,
                                 0,
                                 -0.40460112188156461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51452201315950041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29824058858324026,
                                 0,
                                 0.25011430525650996,
                                 0,
                                 0.11081170322428989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36770131438685916,
                                 -0.063369481630006219,
                                 0,
                                 0,
                                 -0.3260278435273184,
                                 0,
                                 0,
                                 0,
                                 0.5391844344912522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080029523188813151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.561984705404586,
                                 0,
                                 0.14183825040709203,
                                 0,
                                 0.34844859028893665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54738259017118862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43404742005463648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31064893074503946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49292883640674728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82836107946808379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79741611862377848,
                                 -0.28337279639240653,
                                 0,
                                 -0.23779703632169061,
                                 0.26300021721001271,
                                 0,
                                 0,
                                 0,
                                 -0.79646850453158891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25847071754965323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30465410384145003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24413388497346941,
                                 0.81421699667602565,
                                 0,
                                 0,
                                 0.3430836818510527,
                                 0,
                                 0,
                                 0,
                                 -0.15349050555773047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19423337576870756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2980444527224001,
                                 0,
                                 0.036353823775704536,
                                 0,
                                 -0.091131113888552745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32476369160966129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72434545953999951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66836103346146769,
                                 0,
                                 -0.17220979421652458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35260541759564851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76526811533327976,
                                 0,
                                 0,
                                 0.44334533176162189,
                                 0.0406654114632478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12086747944894037,
                                 0,
                                 0,
                                 0.43360464425363543,
                                 0.31516863939835271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13668065396007403,
                                 0,
                                 0,
                                 -0.36470937702469025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39481275310704933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095968513927940813,
                                 0.20433693808089465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29782791644826695,
                                 0.50080948974110295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37061641003633117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47812677486655558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2412162379022893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.182315051078074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21644332959788459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1297635370375494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096227639190165998,
                                 0.10172580241272403,
                                 0,
                                 0,
                                 0.041038029589233443,
                                 0,
                                 0,
                                 0,
                                 -0.0075324945794067455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29902886949919827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39771734817118853,
                                 0,
                                 0.72953787870708675,
                                 0,
                                 0.44590175367841539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53641320521279146,
                                 0,
                                 0,
                                 -0.34954242989367618,
                                 -0.37484143333226705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033010086765172572,
                                 0,
                                 0,
                                 0.31896660422299417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088912339467906984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38360997468839048,
                                 0.14294418742430007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.067530958340952005,
                                 0.40827688466781931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5796940576982047,
                                 0,
                                 0,
                                 0.069003529217699117,
                                 0.39157275117673146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1223606580686027,
                                 0,
                                 0,
                                 0.037621678282240868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086733679836249841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21080876142214802,
                                 -0.50832256229442496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42088802587873669,
                                 0.044440396770026647,
                                 0,
                                 0,
                                 0.39534133966096008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65492646464629078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3687460331175243,
                                 0,
                                 0.035275846099875802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1626909597259405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51398227044930289,
                                 0,
                                 0,
                                 0.20175609048771312,
                                 0.1104780427738439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35804202518233813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75556880275742466,
                                 0,
                                 0,
                                 -0.38736768362099838,
                                 0,
                                 0.47035841452802046,
                                 0,
                                 0.28223385533082918,
                                 0.1458058079849672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14718800931689127,
                                 -0.17541057037587282,
                                 0.35335825953139077,
                                 0,
                                 0,
                                 0,
                                 -0.72194711759877817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26789808544577376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068644561801128268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52210385490053612,
                                 0,
                                 1.3364206179634994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17539039974957532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34907950598526977,
                                 0,
                                 0,
                                 -0.3407451405325026,
                                 -0.21682116171815374,
                                 0,
                                 0,
                                 0,
                                 -0.52997995230701889,
                                 0,
                                 -0.067663065864154257,
                                 -0.35054794476505124,
                                 0,
                                 0,
                                 0,
                                 0.14247146570966926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.635258540449406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40964321834511092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28645652961090684,
                                 0,
                                 0,
                                 -0.29600133744844059,
                                 -0.28128509399941909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081752463768954592,
                                 0,
                                 0,
                                 -0.3161291687682703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24655057943179665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70295468580899989,
                                 0.21991840782165453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15581269495401645,
                                 -0.13041956739964017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10564634359686473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48158344964654559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79631148576001531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8239407752074166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57454792479244077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24111876945050537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90252943955386256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21557130093784069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20565189818330451,
                                 0,
                                 0,
                                 -0.13011830043854961,
                                 0.49341957462961838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17367284001745439,
                                 0,
                                 0,
                                 0.24807927764192111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19776155957292474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16702108331863866,
                                 0.54400439215472618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058905307781283063,
                                 -0.48907236069497889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13716993054421153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22522453685092622,
                                 0,
                                 0,
                                 0.325376996914154,
                                 0,
                                 0.5491560376514536,
                                 0,
                                 -0.10537045966566484,
                                 -0.076970254990804329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38417160083601981,
                                 0.87556846199173544,
                                 -0.086284323301107468,
                                 0,
                                 0,
                                 0,
                                 -0.18704808289709249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19988969466489381,
                                 0,
                                 0.58294230625922494,
                                 -0.51609666893474626,
                                 0,
                                 0,
                                 0,
                                 -0.128426538777211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29537016093446489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50012968120444889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00967020344939791,
                                 -0.42828264610088362,
                                 0,
                                 0,
                                 0.43931523631452329,
                                 0,
                                 0,
                                 0,
                                 -0.15553516889333566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064078028658852926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44646010559319943,
                                 0,
                                 0.52043556269896418,
                                 0,
                                 -0.35356131296910281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49617678614854543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40732896690989434,
                                 0,
                                 0,
                                 0.2089503923882729,
                                 0,
                                 -0.1909928981319387,
                                 0,
                                 0.013041310899097984,
                                 0.91296700282463517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039289757363260597,
                                 0.27175727603388178,
                                 0.47562407460796652,
                                 0,
                                 0,
                                 0,
                                 -0.027044217295825873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1245938253439156,
                                 0,
                                 0,
                                 -0.15216904578456322,
                                 -0.019444648903725274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32160410684501206,
                                 0,
                                 0,
                                 0.060021898617121011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63923885468137576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19254245113290119,
                                 -0.41286934008035875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38680313764600882,
                                 -0.29687433010148256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0461420936897423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36382013137836205,
                                 0,
                                 0,
                                 -0.57521714559137516,
                                 0,
                                 -0.32769220595633231,
                                 0,
                                 -0.97824699190453324,
                                 -0.285486678456988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065009102061311927,
                                 0.065966919921749217,
                                 -0.34123870954804703,
                                 0,
                                 0,
                                 0,
                                 -0.34572363667603723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27606137555575311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25226392153883542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097518740280913757,
                                 0,
                                 0.028840106048054093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91641132167774808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38786971212358456,
                                 0,
                                 0,
                                 0.41686427620525557,
                                 0.39281737575767989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68424874159455462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75336010190471037,
                                 0,
                                 0,
                                 0.3974746361761537,
                                 0,
                                 -0.12061580830348598,
                                 0,
                                 -0.53577964095704533,
                                 -0.086996584541601599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12961470956133786,
                                 0.090992942735172055,
                                 0.55448361069109253,
                                 0,
                                 0,
                                 0,
                                 -0.050283674083133764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40927955168475483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23467922159583143,
                                 0,
                                 0,
                                 -0.045099592353669282,
                                 0,
                                 0.21982284768172294,
                                 0,
                                 -0.40373030647822261,
                                 -0.69191728339508107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40890768032869856,
                                 -0.49118848711537821,
                                 0.55399326882317845,
                                 0,
                                 0,
                                 0,
                                 -0.2108495326978774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76950633034088145,
                                 -0.004572236278361428,
                                 0,
                                 0,
                                 -0.25700959503921972,
                                 0,
                                 0,
                                 0,
                                 -0.16945626034513928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2824416322442897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33503286026581924,
                                 0,
                                 0.2151064997236915,
                                 0,
                                 -0.27345684632542799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41712928360593127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042723638797057123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20138262099173138,
                                 -0.26356140200411782,
                                 0,
                                 0,
                                 -0.19321811689825322,
                                 0,
                                 0,
                                 0,
                                 -0.66946337369143993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52101949229874034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19126573584315121,
                                 0,
                                 -0.19144695426247432,
                                 0,
                                 0.24447934179568104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95514569034629992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1418046757727594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42354772576143512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55517548493135604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66186584219041755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22220696688456459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22015082169718611,
                                 -0.10176190190662873,
                                 0,
                                 0,
                                 0.49421522338322893,
                                 0,
                                 0,
                                 0,
                                 -0.14447900316797288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49636370092818716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00774159712966703,
                                 0,
                                 -0.17321001880496983,
                                 0,
                                 0.63215243027816581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48203682649053003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83061065958535441,
                                 0,
                                 0,
                                 0.059619828247847367,
                                 0,
                                 -0.20940318196238791,
                                 0,
                                 -0.10806799875146506,
                                 -0.030421991064715371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020152009373935104,
                                 0.2001342874462318,
                                 0.22665552068918698,
                                 0,
                                 0,
                                 0,
                                 0.65479957758637586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37653004934094464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074510437445109115,
                                 0,
                                 0,
                                 -0.10081399378439918,
                                 0,
                                 0.34444902824781454,
                                 0,
                                 -0.30258044007204343,
                                 0.35939594223207266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72894602557971488,
                                 -0.52654696183312855,
                                 -0.3919561055760985,
                                 0,
                                 0,
                                 0,
                                 0.0087084115849378682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17263914922708259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23046282339883906,
                                 0,
                                 0,
                                 -0.18164740639379923,
                                 0,
                                 -0.93580724419639005,
                                 0,
                                 0.15703932632703771,
                                 -0.48954727463880143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58342601688562123,
                                 -0.12606741751686534,
                                 -0.069364462729790854,
                                 0,
                                 0,
                                 0,
                                 -0.41681293101623096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34702106585606707,
                                 0,
                                 0,
                                 -0.031396471611788837,
                                 0.02448954524833619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46365222105108184,
                                 0,
                                 0,
                                 0.27222524966141515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36049299069879343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24859209988550596,
                                 0.31109817049231797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44422609409164571,
                                 0.32099659208957732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083549139027883565,
                                 0,
                                 0,
                                 -0.13415555950642885,
                                 -0.23840765771314409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26841380624757305,
                                 0,
                                 0,
                                 -0.51030787578227577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30474399449855383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36834813163385016,
                                 -0.024055954039937769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58683215408399181,
                                 -0.11056040087892158,
                                 0,
                                 0,
                                 -0.074277742932234242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0054779263299341088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19756163224539822,
                                 0,
                                 0.1351777357308494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46014043676143612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31395858403525762,
                                 0,
                                 0,
                                 1.0922461164631714,
                                 -0.89815227283133658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045297955424106223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19619014375395749,
                                 0,
                                 0,
                                 0.8646685666616456,
                                 0,
                                 -0.10749605598114099,
                                 0,
                                 -0.37688547733515376,
                                 -0.30468016062550607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18442019150138694,
                                 -0.46622433360880566,
                                 -0.38354267649455903,
                                 0,
                                 0,
                                 0,
                                 -0.49983198371688842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57194481527639884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70697343787605771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2729111217814949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67124230675250707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58784704946528943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18575503057782339,
                                 0,
                                 -0.67389728196435139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37743485354215656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22750398576680841,
                                 0,
                                 0.86026380103687639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63463317849917722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18027071237693643,
                                 0,
                                 0,
                                 0.27792676402894811,
                                 1.0087435154226223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10077067241984103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16668587290271344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0967508529390948,
                                 0,
                                 -0.26556169803186103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23363366408414088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1339487655571123,
                                 0,
                                 0,
                                 0.65732713047784896,
                                 -0.10029910128810257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30632540805414965,
                                 0,
                                 0,
                                 -0.57370533153596592,
                                 0.34607887834357565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50164940457536467,
                                 0,
                                 0,
                                 0.12701583701478786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065305385158085816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11950786419890808,
                                 -0.22928106466604889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057564267295917154,
                                 0.3391766862993299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022219875285790551,
                                 0,
                                 0,
                                 -0.45740722857973687,
                                 0.32659239873254503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5350796216914655,
                                 0,
                                 0,
                                 -0.4980909955797993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30509461942595922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16828149598411279,
                                 0.12134662622458767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084881260752922391,
                                 0.076721882353271598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64331174930382495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70264295985110359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23012759332397151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1442195318123138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30227191207529802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52407153031417164,
                                 0.62337115790370945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85703330558488933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82262549371212579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17398750125093015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20640973165771942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00058635216427027625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67127955731261568,
                                 0,
                                 0,
                                 0,
                                 0.55315788881147354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41920012530949935,
                                 0.53343891597197035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11563018051319454,
                                 0,
                                 0,
                                 0.23043005409566852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23568766114756184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19542543966410925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61577766074783424,
                                 0,
                                 0,
                                 0,
                                 -0.017997939601804017,
                                 0,
                                 0.070944076765665942,
                                 -0.63535662682166349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32717631085317622,
                                 0,
                                 0,
                                 -0.1226670523239928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42922073039852227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3330686026952544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34625712149637633,
                                 0,
                                 0,
                                 0,
                                 0.23267622767302226,
                                 0,
                                 0,
                                 0,
                                 0.091993378388355862,
                                 0,
                                 0,
                                 0,
                                 -0.23148144647143803,
                                 0,
                                 -0.053884153279113479,
                                 -0.083646061189125404,
                                 0,
                                 0,
                                 0.35509281914670293,
                                 0,
                                 0,
                                 0.26004996972071254,
                                 0,
                                 0,
                                 -0.6460302414225999,
                                 0,
                                 0,
                                 0,
                                 -0.075855297862591431,
                                 0,
                                 0,
                                 0,
                                 -0.57992685638076669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3249410876932026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.291944568665436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37673332880537053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21650706471846945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45939940576994881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45145239764826672,
                                 0,
                                 0,
                                 0,
                                 0.063186828994884231,
                                 0,
                                 0,
                                 0,
                                 0.47975976139576082,
                                 -0.3046473707050838,
                                 0,
                                 0.30192838518751347,
                                 0,
                                 0,
                                 0.0060353291958210771,
                                 0,
                                 0,
                                 -0.32617879012287238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11707180260810983,
                                 0,
                                 0,
                                 0.46516633843418953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39872564042972708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42152269572718526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033684448224900632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80059122996831655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81432733786624101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29447551585291609,
                                 0,
                                 0,
                                 0,
                                 0.064869835864543354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7382897298462241,
                                 0,
                                 0,
                                 0,
                                 0.0021300223900593308,
                                 0,
                                 0.45376410741798989,
                                 -0.74929998152048449,
                                 0,
                                 0,
                                 0.5969902628460021,
                                 0,
                                 0,
                                 -0.17861083728015881,
                                 0,
                                 0,
                                 -0.41118824389316116,
                                 0,
                                 0,
                                 0,
                                 1.0703032685815861,
                                 0,
                                 0,
                                 0,
                                 -0.26155283079403951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57161019883236075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1386959925105766,
                                 0,
                                 0,
                                 0.52661379024562982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13700278381415507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62084711228578859,
                                 0,
                                 0,
                                 0.43565077081415365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33080030814260136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072300041892651865,
                                 0,
                                 0,
                                 0,
                                 -0.56956631102909094,
                                 0,
                                 0.59575898445460629,
                                 -0.33371961956868967,
                                 0,
                                 0,
                                 -0.69611950335396333,
                                 0,
                                 0,
                                 0.95729659350152496,
                                 0,
                                 0,
                                 0.373876405403407,
                                 0,
                                 0,
                                 0,
                                 0.4168110457852201,
                                 0,
                                 0,
                                 0,
                                 0.16416303554627074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11794909505715662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51800872931946096,
                                 0,
                                 0,
                                 0,
                                 0.82940279656856275,
                                 0,
                                 -0.60719111855675234,
                                 0.57165905802766659,
                                 0,
                                 0,
                                 -0.23776419090128198,
                                 0,
                                 0,
                                 0.42619316859349149,
                                 0,
                                 0,
                                 -0.51299706865836181,
                                 0,
                                 0,
                                 0,
                                 0.81349756126662776,
                                 0,
                                 0,
                                 0,
                                 -0.083448753240615597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51538953254527964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43068728722301447,
                                 0,
                                 0,
                                 -0.62588668301298267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29335158679939699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23184818052502321,
                                 0,
                                 0,
                                 -0.022264916994129635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53147893827718506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23865101196615809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49735627878152855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3550630414885641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1714051495629772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74610074825032457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97008416482018789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63351618199069926,
                                 0,
                                 0,
                                 0,
                                 -0.083589146416558208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6271169394637427,
                                 0,
                                 0,
                                 0,
                                 -0.23034583524720653,
                                 0,
                                 0.40411581940880126,
                                 1.2044336257008674,
                                 0,
                                 0,
                                 -0.37461355385522416,
                                 0,
                                 0,
                                 0.018763273795834548,
                                 0,
                                 0,
                                 -0.049842000027097294,
                                 0,
                                 0,
                                 0,
                                 -0.10179135283274075,
                                 0,
                                 0,
                                 0,
                                 -0.15157906941155291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098758579743979086,
                                 0,
                                 0,
                                 0.57622445660280575,
                                 -0.1409556116815206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14002784133996687,
                                 0,
                                 0,
                                 0.17395969403333172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27870110930312936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033346770970489145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44284406240466256,
                                 0,
                                 0,
                                 0,
                                 -0.5686210870006233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33680703250865107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.067870403115904643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13077690880578938,
                                 0,
                                 0,
                                 0,
                                 0.61986879939282424,
                                 0,
                                 0,
                                 0,
                                 -0.27837420278545189,
                                 0.32740401533435565,
                                 0,
                                 0.32105660858597845,
                                 0,
                                 0,
                                 0.34417746646281677,
                                 0,
                                 0,
                                 0.24872718740035088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11193046400786566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63313975276008738,
                                 0,
                                 0,
                                 0,
                                 -0.11214556209888608,
                                 0,
                                 -0.76068312360670043,
                                 -0.10267772461676924,
                                 0,
                                 0,
                                 -0.5677195537874008,
                                 0,
                                 0,
                                 0.24837197588188961,
                                 0,
                                 0,
                                 0.036794030550234197,
                                 0,
                                 0,
                                 0,
                                 -0.13265359780745756,
                                 0,
                                 0,
                                 0,
                                 -0.1816832512195922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13936495412936806,
                                 0,
                                 0,
                                 -0.079716971586719809,
                                 0.1105080249914045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45364622153906864,
                                 0,
                                 0,
                                 0.32708424095953992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34291663927560873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71079825412603292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021879352370002846,
                                 0,
                                 0,
                                 0,
                                 0.21295422097710068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40165690131471332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45341273023587508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0031623172834507329,
                                 0,
                                 0,
                                 0,
                                 -0.52360170138156858,
                                 0,
                                 -0.38025037694396258,
                                 0.077679841137403713,
                                 0,
                                 0,
                                 0.4033899122900757,
                                 0,
                                 0,
                                 -0.63331454270037324,
                                 0,
                                 0,
                                 -0.27023508343570057,
                                 0,
                                 0,
                                 0,
                                 0.36871951455191415,
                                 0,
                                 0,
                                 0,
                                 0.83895976583261656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094446549296819532,
                                 0,
                                 -1.2973139244350034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11326555086439877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11749785636482291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38425182530948276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46439413502172516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92256305393644555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69967997939644078,
                                 0,
                                 0,
                                 0,
                                 0.15965790692735826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66610978299850265,
                                 -1.2288015509438133,
                                 0,
                                 0,
                                 -0.53304130891212376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24614121277429135,
                                 0,
                                 0,
                                 0.66899838268405065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099761965053771592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16207629891265884,
                                 -0.36792081574216279,
                                 0,
                                 0,
                                 0.98355366218383344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2201139469921933,
                                 0,
                                 0,
                                 0.69885878318226169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19429934707896909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47702299520380081,
                                 0,
                                 0,
                                 0,
                                 0.072743505786815044,
                                 0,
                                 0.22691872458754211,
                                 -0.088256086240673839,
                                 0,
                                 0,
                                 -0.40647158161056263,
                                 0,
                                 0,
                                 -0.79291064419009805,
                                 0,
                                 0,
                                 0.18095582821967554,
                                 0,
                                 0,
                                 0,
                                 0.74680526251860058,
                                 0,
                                 0,
                                 0,
                                 -0.75488947612455404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34403009440810994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16643431518789131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4629120319958091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25343253754510797,
                                 0,
                                 0,
                                 0,
                                 0.35652729043272835,
                                 0,
                                 0,
                                 0,
                                 0.33880591188095432,
                                 -0.61795822524478994,
                                 0,
                                 -0.049266213123842162,
                                 0,
                                 0,
                                 0.10432769099537514,
                                 0,
                                 0,
                                 0.23031547139079828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060447102101422144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70842126599038191,
                                 -0.10973583198778317,
                                 0,
                                 0,
                                 -0.33583078110177106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69585631444098861,
                                 0,
                                 0,
                                 0.79899791254988328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71364306757412443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26857682188874832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39166016763172751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60368512315970102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088654713723894413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76436734141589935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066465906842884961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33022335003277503,
                                 0,
                                 0,
                                 0,
                                 -0.45914784807760112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65190240337044458,
                                 0,
                                 0,
                                 0,
                                 -0.83816356440439355,
                                 0,
                                 -0.086202287146283557,
                                 0.26579847546215579,
                                 0,
                                 0,
                                 0.10523237244187326,
                                 0,
                                 0,
                                 -0.2824592882449099,
                                 0,
                                 0,
                                 -0.089832538517988517,
                                 0,
                                 0,
                                 0,
                                 -0.24279507434259814,
                                 0,
                                 0,
                                 0,
                                 -0.50354578104899905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43949827148564941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023242890372547842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30830744561369872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091864471753763624,
                                 0,
                                 0,
                                 0,
                                 0.31674175218321615,
                                 0,
                                 0,
                                 0,
                                 0.1080622301371979,
                                 -0.025420596998128223,
                                 0,
                                 -0.40688503693563816,
                                 0,
                                 0,
                                 0.0015741124260582467,
                                 0,
                                 0,
                                 0.13550860581476815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7742078032309665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29263733685713367,
                                 0,
                                 0,
                                 0.11721376543432868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56375007782895425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44665014896502508,
                                 0,
                                 0,
                                 0.55119912862610887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28194562782397803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46996348911721963,
                                 -0.1225319233819418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42111069252379046,
                                 0,
                                 0,
                                 0.1117385877508415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72122151432714821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036665214031306917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11693810570363183,
                                 0,
                                 0,
                                 0,
                                 0.19779076845194632,
                                 -0.49426913241163489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43215809674686306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028076325927046987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58225381162112666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7732691021360204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14311640038538767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20510798330633834,
                                 0,
                                 0,
                                 0,
                                 -1.0096816142950402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50808192922964812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11160725495892079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082207569991553153,
                                 0,
                                 0,
                                 0,
                                 -0.46196264830372158,
                                 0,
                                 0,
                                 0,
                                 -0.0037642340186897182,
                                 -0.020553372256404509,
                                 0,
                                 0.37964822804894938,
                                 0,
                                 0,
                                 -0.20885476288514188,
                                 0,
                                 0,
                                 0.43544902856271661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36252371612561157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3092666962049781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11453772119417206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15486719191804305,
                                 0,
                                 0,
                                 0,
                                 0.13976555626970849,
                                 0,
                                 0,
                                 0,
                                 0.38178783577230124,
                                 0.23860739508201387,
                                 0,
                                 -0.040688624891565182,
                                 0,
                                 0,
                                 -0.44112306440605514,
                                 0,
                                 0,
                                 0.59841050506601079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30113330592730359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0730881449181264,
                                 -0.14064864654583001,
                                 0,
                                 0,
                                 -0.36931640572999203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88422267501824359,
                                 0,
                                 0,
                                 0.040367174705123993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42739001767408386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15872934308677419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47863743720681073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41565672086040589,
                                 0,
                                 0,
                                 0,
                                 0.14096986230859593,
                                 0,
                                 0,
                                 0,
                                 -0.40675465663879939,
                                 -0.41583006470417272,
                                 0,
                                 0.30928944968126904,
                                 0,
                                 0,
                                 -0.33105325546669662,
                                 0,
                                 0,
                                 0.096156047318138607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01421221964737026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57359234668763459,
                                 0,
                                 0,
                                 -0.51440347236786954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073542027390922998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43351720844638264,
                                 0,
                                 0,
                                 0.37148484593634618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27392388881765845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37815013286806864,
                                 1.2944389733986907,
                                 0,
                                 0,
                                 -0.52465258332265907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48214569942708813,
                                 0,
                                 0,
                                 0.06210517501620328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52180729868958187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49448731490313302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044784872176621013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33414454685098971,
                                 0,
                                 0,
                                 0,
                                 0.2372085194482286,
                                 0,
                                 0,
                                 0,
                                 0.1357901206750376,
                                 0.30054162038129706,
                                 0,
                                 -0.14756744924189188,
                                 0,
                                 0,
                                 -0.56683829564055566,
                                 0,
                                 0,
                                 -0.36266598225917329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046728022771390682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53150719455758455,
                                 0,
                                 0,
                                 -0.01405378766837114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40535828167267735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10889911096924146,
                                 0,
                                 0,
                                 -0.2970766909538069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67295889918115992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094448649409011209,
                                 0.45935519623570775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34305019586093316,
                                 0,
                                 0,
                                 -0.26263115612521665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17407756510903233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36563536021095516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46881807360955025,
                                 0,
                                 0,
                                 0,
                                 0.45785488292069387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43349734970605242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35403998437429457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01189989601266013,
                                 0,
                                 0,
                                 0,
                                 -0.212631610075458,
                                 0,
                                 0,
                                 0,
                                 -0.17004366630349887,
                                 -0.16442139240280848,
                                 0,
                                 -0.59406958122731823,
                                 0,
                                 0,
                                 0.14934767632800861,
                                 0,
                                 0,
                                 0.25479081614116877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38117047321376907,
                                 0,
                                 0,
                                 0.4566675455151129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51753825557759359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0149782227084552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0685957499593166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0078029064075761378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40109950952261186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24347262745771203,
                                 0,
                                 0,
                                 0,
                                 -0.013439348550438733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084088022254834027,
                                 0.35795925144801166,
                                 0,
                                 0,
                                 -0.31516756297284848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83185721134132184,
                                 0,
                                 0,
                                 0.38311444089581659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0969178282337588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31325260305071673,
                                 0,
                                 0,
                                 -0.22890231062812127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6384646953308406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40187403796975868,
                                 0,
                                 0,
                                 0.52880681623224379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026457142690633519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49888928125757248,
                                 0.1642170369166942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5269239236352069,
                                 0,
                                 0,
                                 0.30688374036568233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12037379861077355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37365466966105743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096257949997968134,
                                 0,
                                 0,
                                 0,
                                 -0.4346752143190778,
                                 0.7300517905117937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0068063550338032242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073801225428016759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7025697593850001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12148573724421738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058826611123353217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43942214216840647,
                                 0,
                                 0,
                                 0,
                                 -0.93522643005551864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0043935412220379721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30493590052406438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6253913762720138,
                                 0,
                                 0,
                                 0,
                                 -0.17331060340583837,
                                 0,
                                 0,
                                 0,
                                 0.45529353832408764,
                                 0.26428731088359697,
                                 0,
                                 0.14709244340845934,
                                 0,
                                 0,
                                 0.42332279849686377,
                                 0,
                                 0,
                                 0.083261247569009572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030545897977067252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22240672816059423,
                                 0,
                                 0,
                                 0,
                                 0.044377525042024968,
                                 0,
                                 0.38839580356497688,
                                 -0.41505362158189374,
                                 0,
                                 0,
                                 -0.95485336617864003,
                                 0,
                                 0,
                                 -0.078070478904443283,
                                 0,
                                 0,
                                 -1.1189276637107906,
                                 0,
                                 0,
                                 0,
                                 -0.28859792795104072,
                                 0,
                                 0,
                                 0,
                                 0.37540694296636312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096185250112288803,
                                 0,
                                 0,
                                 -0.046605037647188041,
                                 -0.16338870174620804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28551034791540408,
                                 0,
                                 0,
                                 0.78674674600554262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0011993187470038871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26434195942353694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24820114629759268,
                                 0,
                                 0,
                                 0,
                                 0.37304635447855217,
                                 0.66284337835891294,
                                 0,
                                 0.43879642222515575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07751079067549832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34956660065835254,
                                 -0.46279590566215428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18493349296954126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17204670984931117,
                                 0,
                                 0,
                                 -0.66038280815981187,
                                 0,
                                 0,
                                 0.083170552965547262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041700111456230357,
                                 0,
                                 0,
                                 0,
                                 -0.74820814229617871,
                                 0,
                                 0,
                                 0,
                                 -0.69683806886499655,
                                 -0.15555820072584639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012454119076212716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37510489922503826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10161826887198384,
                                 0.4524893319586662,
                                 0,
                                 0,
                                 0.37439359425204255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58690228019937252,
                                 0,
                                 0.072574942175620383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19813072488978178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32670774224983817,
                                 0.63133112121565771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11440738602754594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70888159210781121,
                                 0,
                                 0,
                                 -0.11089504435064527,
                                 0,
                                 0,
                                 -0.12565754573192306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.065294406995509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20988448939642787,
                                 -0.67013619747614739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14020809639983456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52898787551598148,
                                 0.3255625911008061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058709914709340755,
                                 0,
                                 0,
                                 -0.27539734996828424,
                                 0.14865375886613513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40451047844176807,
                                 -0.16257494539347092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1383254755414762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46248679187142527,
                                 0.68344268522083129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19430359500180039,
                                 0,
                                 0,
                                 0.11006360995044953,
                                 0.2448487305950644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80256248716683931,
                                 0,
                                 0,
                                 0,
                                 -0.43572321395210073,
                                 -0.058556415437789194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3463887286707622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27413040035724812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0038659954999302115,
                                 0.73594708229333561,
                                 0,
                                 0,
                                 0.66967512018094111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61934478210123267,
                                 0,
                                 0,
                                 0,
                                 1.0450236442580128,
                                 -0.4477372068928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31424434096083609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36232619024719737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22431324684069895,
                                 0.35587646943259477,
                                 0,
                                 0,
                                 0.16388594380720317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18845803922814211,
                                 0,
                                 0.07344916204010668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60829723316784912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64093906588242666,
                                 -0.12759911215577041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82239229680347481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46193224082766848,
                                 0,
                                 0,
                                 0.037745382824224065,
                                 0,
                                 0,
                                 0.042533025213141715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019923881256443208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27593956927523366,
                                 0,
                                 0,
                                 0.058795083576311268,
                                 -0.13544585743506149,
                                 0.16271313581400976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52333501715927444,
                                 0.064449293565383328,
                                 -0.0091054177531594681,
                                 -0.63276565470376955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083277360795197555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43604551888577858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00040955719525028779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049620253977145146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22134905926609003,
                                 0,
                                 0,
                                 0.83763806916019556,
                                 0,
                                 -0.47650576567009428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.4576898615990714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65684065031664629,
                                 0.39408307921761254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10489931955399376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18918116308652544,
                                 0.23175745543454723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2981032838864357,
                                 0,
                                 0,
                                 -0.41233084698712558,
                                 0.23210276531272905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25598467873961134,
                                 0,
                                 0,
                                 -0.52003386310155642,
                                 0.3487476518796524,
                                 0.052296292224957089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19102462727724101,
                                 -0.12395144788541496,
                                 0.060781935804320036,
                                 -0.20816291209543047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54948086158264731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37264858782655064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21410880938446308,
                                 0,
                                 0,
                                 -0.16122238147263393,
                                 0.60063718555422774,
                                 -0.47006416593585737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00091390247237291278,
                                 0.15039092606757309,
                                 -0.34877322612800421,
                                 0.016178019834021493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41952974069721022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16097034481120326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44748588262971378,
                                 0,
                                 0,
                                 -0.030887631988190126,
                                 0.22843865858598097,
                                 -0.17050418224829902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086959674487502914,
                                 -0.38456977577759383,
                                 0.6859020106299224,
                                 -0.17960523103879578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048474204990045164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23879109898791706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56030641171269391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0028188440015473465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24674053556986372,
                                 0,
                                 0.22843997617353176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9072843921177145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33473361035467386,
                                 -0.54685730462023696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25635875498447458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12770286914073994,
                                 0,
                                 0,
                                 0.77735390624275436,
                                 0,
                                 0,
                                 0.44163606839711272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24949085331038884,
                                 0,
                                 0,
                                 -0.30188121760725656,
                                 0,
                                 0.44837063458304738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18525841466711124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16306210622760522,
                                 -0.35242455675485584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66098668900571056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27702865601966647,
                                 0,
                                 0,
                                 -0.32145706460723339,
                                 0,
                                 0,
                                 0.61710595341515795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75355765914763184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31213428113649733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0161334772827213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62641283755952459,
                                 0,
                                 0,
                                 -0.17490364181633322,
                                 0,
                                 -0.96233010309191025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23804394991743943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11462600305615991,
                                 0,
                                 0,
                                 0.18822093995942721,
                                 0.36475851223025768,
                                 0.26851984419030561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22995943012621295,
                                 0.55091552441478309,
                                 0.4014236843873995,
                                 0.40866171831392045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16038006551628911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18980433043822653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33983171226346526,
                                 0,
                                 0,
                                 0.25094823263351895,
                                 -0.21642191851876064,
                                 -0.3460053283963041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38315927901318997,
                                 0.14732319505506045,
                                 0.38625813443308321,
                                 -0.090842163179240376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2706262922686638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50574683962946021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32812814132596346,
                                 0,
                                 0,
                                 0.18560064694309097,
                                 -0.24903575680496301,
                                 -0.61067713913856281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13095103277883458,
                                 0.0087241321562610413,
                                 -0.11677769250526923,
                                 0.18372746356808262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58318973183209977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13495032112691693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42970531685693536,
                                 0,
                                 0,
                                 -0.60579411596325916,
                                 -0.41938362006739527,
                                 0.068239649235168537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28454274536629359,
                                 0.40299528558911463,
                                 0.060846340427157614,
                                 0.078156757533693721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11770086376728217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028169768366818011,
                                 -0.024599959925944243,
                                 0,
                                 0.018801166685678994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71087324470698698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68498234027794991,
                                 -0.35650127753982608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.248968959534068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75832258268226216,
                                 0,
                                 0,
                                 0.074923971752290125,
                                 0,
                                 0,
                                 0.48342599214336196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03941490886668686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33625748960424029,
                                 -0.55912018420352438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18732228992904021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65614806021181216,
                                 -0.31242265364942001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011256247012983722,
                                 0,
                                 0,
                                 0.030898345432009644,
                                 -0.1000313836587796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060486279610909507,
                                 -0.017375315073915695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25358839499915953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090746358239919375,
                                 0.34129339405101367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33611417504206709,
                                 0,
                                 0,
                                 -0.3022690033473176,
                                 -0.77632278268849353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3025665617819247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17389160215266714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30591451457772101,
                                 0,
                                 0,
                                 -0.43712253239606302,
                                 -0.16860638762427754,
                                 -0.22599276050919043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60042169954822677,
                                 -0.21438035020112772,
                                 0.23813485971682433,
                                 0.35206185309569371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20880572201027017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071544521031052272,
                                 0,
                                 0.084028655410752828,
                                 0,
                                 0,
                                 0,
                                 0.23735567453618331,
                                 -0.30245534056241319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10169061545021747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13315412669684551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5250994563054695,
                                 -0.6745645595164993,
                                 0,
                                 0,
                                 1.0977635855672321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10959574324715567,
                                 -0.43992267874509183,
                                 -0.70705776422874933,
                                 0,
                                 0,
                                 -0.14079410790534791,
                                 0,
                                 0,
                                 0,
                                 0.41435071778174987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32096203776237153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.614766185912476,
                                 -0.19417756951101039,
                                 0.36744807823610887,
                                 0,
                                 0,
                                 -0.50686493280523348,
                                 0,
                                 0,
                                 0,
                                 0.31914728585176905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3009526005599712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27703118160080226,
                                 0.27643957150242471,
                                 0.18260693903364184,
                                 0,
                                 0,
                                 -0.26462405786125365,
                                 0,
                                 0,
                                 0,
                                 -0.20654752886974473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83713906841338526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0755923664469262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16480889382791897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14034865298769095,
                                 0,
                                 0,
                                 0.92397972467597034,
                                 0,
                                 -0.84084142240440041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58762702866931826,
                                 0,
                                 0,
                                 -0.11806659884138161,
                                 0,
                                 0,
                                 0,
                                 -0.23365224081403882,
                                 -0.69770483903030789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90150693434351326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14882883799785906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1580402633627935,
                                 -0.72218147801709698,
                                 0,
                                 0,
                                 -0.25237176082746787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7256267865608732,
                                 -0.031136601512880641,
                                 0.23633896832826032,
                                 0,
                                 0,
                                 -0.56506549177462706,
                                 0,
                                 0,
                                 0,
                                 0.29760371471612451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093665306884480659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23556627329961918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2408677949937596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87684818844281398,
                                 0,
                                 0,
                                 -0.69034893333571068,
                                 0,
                                 -0.50914291427400016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021515680766232614,
                                 0,
                                 -0.28459825380934933,
                                 0,
                                 0.72788815084717839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23421003684670988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1050490903855735,
                                 0.075375390994653096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60950798816418805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42672924307570037,
                                 0,
                                 0,
                                 0.50503487667247327,
                                 0,
                                 0,
                                 -0.50249977649880984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099202292461020122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2968262326618838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057166293360623358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58804589232479987,
                                 0,
                                 0,
                                 0.48499235362608695,
                                 0,
                                 -0.13437615249769258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23531538318918782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082166054163129484,
                                 -0.83085872878075129,
                                 0.35546556146361941,
                                 0,
                                 0,
                                 0.14790852190784654,
                                 0,
                                 0,
                                 0,
                                 -0.34699595519099607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18515837327426932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44065555523986283,
                                 0,
                                 0.4294193539282124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032793460681016767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42669237005868893,
                                 0.55991190064664276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25396412951287006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065333032918620124,
                                 0,
                                 0,
                                 0.16475837280706992,
                                 0,
                                 0,
                                 0.57490686847507699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27497288174426854,
                                 0,
                                 0,
                                 0,
                                 0.15794509429807754,
                                 0,
                                 0,
                                 0,
                                 0.39104504984901289,
                                 -1.2260730690474739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13539199028229612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55986876371572314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23227611833965628,
                                 -0.12823061208103329,
                                 0,
                                 0,
                                 -0.18189515775636378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18189890048977395,
                                 0,
                                 0,
                                 0,
                                 0.44926288983790941,
                                 -0.053429597567990206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031404196272907733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21352984953517551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0613067380544463,
                                 -0.33933539193205259,
                                 0,
                                 0,
                                 0.51850864545467668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32756790618116272,
                                 0,
                                 -0.82048115222052964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38546117035432387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47102377906745668,
                                 0.0097774150871544341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57697849935560475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30954057738912799,
                                 0,
                                 0,
                                 0.28239513983553022,
                                 0,
                                 0,
                                 0.67034110611003639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15872387360800033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39633928767087723,
                                 0.075367940506052084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36475537171136196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16943470313231052,
                                 -0.13717658866773838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27615809943662828,
                                 0,
                                 0,
                                 -0.73168022159120705,
                                 0.21223473736375559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030862066811020036,
                                 0,
                                 0,
                                 0,
                                 0.15723780683190697,
                                 0.58325412253761855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36144298770335787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0781784919964024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11422960521238767,
                                 0.51234639067653154,
                                 0,
                                 0,
                                 -0.074132272556260773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0044204423077699737,
                                 -0.032381420400544571,
                                 -0.38664461760650948,
                                 0,
                                 0,
                                 -0.55862610592869899,
                                 0,
                                 0,
                                 0,
                                 -0.68907361507552412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25010451767261199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063415955762779586,
                                 0.16122662862616027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7248210694527093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032088098520034719,
                                 0.16740388732026618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48928455557414685,
                                 0,
                                 0,
                                 0.068704122655187466,
                                 -0.414059739293968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28817708149736249,
                                 -0.1568239664238289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43862866639094306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044557146330277964,
                                 -0.33507163986185501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6642074804241922,
                                 0,
                                 0,
                                 -0.33110136324909295,
                                 -0.18683434734863658,
                                 0,
                                 0,
                                 0,
                                 -0.80085610161964982,
                                 0,
                                 0.10453444021686831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26985144529591409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56332546035869402,
                                 0.46389479793522315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26201532202962091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18702872904065709,
                                 0,
                                 0,
                                 -0.45980373263207802,
                                 0,
                                 0,
                                 0.30592171082492292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11255454130826267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62946848645658582,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0864731880154475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.848615340187311,
                                 0,
                                 0,
                                 0.021162036228311865,
                                 0,
                                 0.06561001240521358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39002307905683337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31260176106162291,
                                 0,
                                 0,
                                 0.090823235829472077,
                                 -0.029385092297101463,
                                 0.31666859205260101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15412947340174513,
                                 -0.52566025145259376,
                                 -0.14047945533795783,
                                 0.42975289907588216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12750204069821186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52166598645691276,
                                 0.43628887773051717,
                                 -0.30736236426531849,
                                 0,
                                 0,
                                 0.38396430296151729,
                                 0.70083212413063389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21354121660894199,
                                 0,
                                 0,
                                 -1.0137572704036586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26552146800416698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058959616273533674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21649874319956852,
                                 0,
                                 0.30170728861652857,
                                 0,
                                 0,
                                 0,
                                 -0.15702049614116317,
                                 0.21915514585492263,
                                 0,
                                 0,
                                 -0.99809950804381553,
                                 0.1559510229877005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33304806410248999,
                                 0,
                                 0,
                                 -0.54347191907369052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068413069713576719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26367545641884477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53975452142334335,
                                 0,
                                 -0.26224299394543538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20982986418793945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24037242257490779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42234960450842207,
                                 0,
                                 0.037291727987056281,
                                 0.22375286749349493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0065850992562077257,
                                 0,
                                 0,
                                 0,
                                 0.80363054545348112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14997300532436225,
                                 0,
                                 0,
                                 0,
                                 0.00011536963582039345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052837287308896419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10690735867163788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45719392614183751,
                                 0,
                                 -0.84373633686807892,
                                 0.25467966579408224,
                                 0,
                                 -0.38936135024710056,
                                 0.26473636027211539,
                                 0,
                                 0,
                                 0.056195515955631783,
                                 0.48067934729100725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67133965557532538,
                                 0,
                                 0,
                                 0.1224829288822642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86291703714407186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25807358474045422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55424584165708857,
                                 0,
                                 0.65836794903554408,
                                 0,
                                 0,
                                 0,
                                 0.65950013892984016,
                                 0.8058601870895723,
                                 0,
                                 0,
                                 0.38625430023024099,
                                 0.41184387841202047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13151039256863939,
                                 0,
                                 0,
                                 0.038990613002375774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20496856434532601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69273922168217439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20225962314309243,
                                 0,
                                 0.49821785032263088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42318658770869833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074887052778914581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41797438577269985,
                                 0,
                                 0,
                                 0,
                                 -0.86797131230158386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74137402632531824,
                                 0,
                                 0,
                                 0,
                                 0.6778850369369851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48529076580182784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2584467804607774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24381532112327287,
                                 0,
                                 -0.31913715366195483,
                                 0.68920525371824104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16505623549437276,
                                 0,
                                 0,
                                 0,
                                 -0.067767905823660296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17194117874120396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11862181440297888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092287111841986874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60319338373409159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028861657145225719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58831109230534684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43780464789322965,
                                 0,
                                 0.31228341418725103,
                                 -0.0045787272658851311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013629467715360827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33415419248603512,
                                 0.26290802253966905,
                                 0,
                                 0.29293147679627085,
                                 0,
                                 0,
                                 0.37195897219159468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35835023837985308,
                                 0.63914895182512099,
                                 0,
                                 0,
                                 0.089448376072391311,
                                 0,
                                 -0.15071956164214576,
                                 0.16501085914743299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58372483738566583,
                                 0,
                                 0.64479434379530454,
                                 0.45274346523023734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40442828196743297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63216980202900808,
                                 0,
                                 0,
                                 0,
                                 0.20585064033869976,
                                 0,
                                 -0.61235923768071232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0271385146249479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23057749173933501,
                                 0.044497068925342012,
                                 0,
                                 0,
                                 0.37241982553406927,
                                 0.18118836825767126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55959969054438408,
                                 0,
                                 0,
                                 0.54020053561968417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13028565855834709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2715005820629719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.135744798066985,
                                 0,
                                 0.12030604111105966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92556589630109365,
                                 0,
                                 0.2789609823649602,
                                 -0.26899717984532967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47374545614652941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28870126871643231,
                                 0,
                                 0,
                                 0,
                                 0.23296112360544394,
                                 0,
                                 0.28698082139304448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18398594446893107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56912581125634687,
                                 0,
                                 -0.72524496221698931,
                                 1.06117953679823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055446571854924791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11760991122174719,
                                 0,
                                 0,
                                 0,
                                 0.13584144706170886,
                                 0,
                                 -0.45437049699342047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10207870595142414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97110849005713429,
                                 0.53675304859141415,
                                 0,
                                 0,
                                 0.62114711529989619,
                                 0.3676144299404191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40772001529612278,
                                 0,
                                 0,
                                 -0.21889325879735608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38526478827415456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.427632456454413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022325369828436775,
                                 0,
                                 -0.53265369200745682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13752057624401065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080604180860402774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071353882571759841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0039004057370291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80000964607443104,
                                 0,
                                 0,
                                 0,
                                 -0.2852907624025523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30353758414752469,
                                 0,
                                 0,
                                 0,
                                 0.19748913731521484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24115326755044778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080324380807840323,
                                 -0.31897419391968329,
                                 0,
                                 -0.1929237953538824,
                                 0,
                                 0,
                                 0.51042878979357365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2710704362751985,
                                 -0.4342243713011229,
                                 0,
                                 0,
                                 0.025687779336691398,
                                 0,
                                 -0.14833574031442437,
                                 0.50119664686710463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29987986377560838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55914388968072637,
                                 -0.3168464560847204,
                                 0,
                                 -0.21427794196643782,
                                 0,
                                 0,
                                 0.25049903901873305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50776472542241757,
                                 0.13341432934165356,
                                 0,
                                 0,
                                 -0.32617417827947909,
                                 0,
                                 -0.0062859662117150938,
                                 -0.079499614049435285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36616993861127922,
                                 0.90909485346846641,
                                 0,
                                 0,
                                 -0.11342499372653551,
                                 0.27858479091996868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35760315539404142,
                                 0,
                                 0,
                                 0.20269968737092231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095931260556034292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50021233323272152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61605276422281818,
                                 0,
                                 -0.60003256775707581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33532630216255493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31941403318977812,
                                 -0.027743590701709134,
                                 0,
                                 0.30484395903618455,
                                 0,
                                 0,
                                 -0.1394803547138751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19814011366837786,
                                 0.1121171953658848,
                                 0,
                                 0,
                                 -0.33895963955938013,
                                 0,
                                 0.096528680130149286,
                                 0.70451077881272817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059565970319621908,
                                 0,
                                 -0.39240594363697878,
                                 -0.80934778557133524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24120105167802497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18215029539902233,
                                 0,
                                 0,
                                 0,
                                 0.20989694671086351,
                                 0,
                                 -0.55964263028178451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41462268716002909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33822871640828012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46477387372718265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22103407599070593,
                                 0,
                                 -0.49756095791443472,
                                 0.12216950641922525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35567520648227824,
                                 0,
                                 0,
                                 0,
                                 0.063990366536549576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47711487536360653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077288838566645784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33835763436928351,
                                 -0.28676294372416561,
                                 0,
                                 0.47128393681113578,
                                 0,
                                 0,
                                 0.27993288582781595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23839749236267316,
                                 -0.035398204521614657,
                                 0,
                                 0,
                                 0.11056730397494101,
                                 0,
                                 -0.59134929436049599,
                                 -0.27718419370969294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058603676700647728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30082404405820901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40826199821185982,
                                 0,
                                 0.46565968815364095,
                                 0.048615201569390615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70256400381627859,
                                 0,
                                 0,
                                 0,
                                 -0.13242195317003022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095176195947228551,
                                 0,
                                 0,
                                 -0.35563085384388626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23650625715368317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65049887480245006,
                                 0,
                                 0.42083029450099235,
                                 0.14709521502135769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044714771404651459,
                                 0,
                                 0,
                                 0,
                                 0.43914455846292766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029329284696797908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28140973941870573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47006054622787097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16674400453011778,
                                 0,
                                 0,
                                 0,
                                 -0.092578269610801081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38075032045279422,
                                 0,
                                 0,
                                 0,
                                 1.1963418075388343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052670339455617887,
                                 0,
                                 -0.17859332529474167,
                                 0.13936325636620767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08899913063937237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49999060393804934,
                                 0,
                                 0,
                                 0,
                                 0.85921891212810175,
                                 0,
                                 0.58667283694543204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33106771391854761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5068808716750588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21462355049472887,
                                 -0.16383115805599341,
                                 0,
                                 0.063373499358466617,
                                 0,
                                 0,
                                 0.40805662861513681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15408485166324165,
                                 -0.04139187687267798,
                                 0,
                                 0,
                                 0.30384884882926355,
                                 0,
                                 0.59215543002155102,
                                 -0.17667441057863709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31095776046080964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35239316330499154,
                                 -0.48769131436986451,
                                 0,
                                 0.59089682301528501,
                                 0,
                                 0,
                                 -0.27054362271664423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069951797840443392,
                                 -0.058537280956971048,
                                 0,
                                 0,
                                 0.058839129189151511,
                                 0,
                                 0.32722967925185603,
                                 -0.0082116332805524626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25669950542798237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76600115510474009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91642113444811846,
                                 0,
                                 0,
                                 0,
                                 0.5202723494786885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020566610339606661,
                                 0,
                                 0,
                                 0,
                                 0.67681784006851475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022159491386934016,
                                 0,
                                 0.10055298473366435,
                                 0.032236829199359843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34408019748613972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51224872035392288,
                                 0,
                                 0,
                                 0,
                                 -0.09091905186771608,
                                 0,
                                 -0.34324645189193725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0069788177777805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16987615068825729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026822625524292612,
                                 0.024666455480739605,
                                 0,
                                 -0.11094542110372403,
                                 0,
                                 0,
                                 -0.018372302193923294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53022800523692415,
                                 0.16555662416919745,
                                 0,
                                 0,
                                 0.74063993176889109,
                                 0,
                                 0.049228470821015294,
                                 0.31248374997065209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095120238005338614,
                                 0,
                                 0.098169811575906304,
                                 0.041366873682870765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3580155081978017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.060412722031379,
                                 0,
                                 0,
                                 0,
                                 0.65610259808466709,
                                 0,
                                 -0.044527544585322376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62359776153028013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39812794516287797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41795040423033819,
                                 -0.4351778096315857,
                                 0,
                                 -0.29602830219963011,
                                 0,
                                 0,
                                 0.083106881567588567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023261432877958413,
                                 0.56202025728647842,
                                 0,
                                 0,
                                 -0.19374182667148901,
                                 0,
                                 0.15509847576726818,
                                 -0.069950460856392199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43855147795819927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084200137663968444,
                                 -0.43711421775349296,
                                 0,
                                 -0.25080118855421424,
                                 0,
                                 0,
                                 -0.43999279072109998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36588223857928415,
                                 0.15132569165778428,
                                 0,
                                 0,
                                 0.27561058667024529,
                                 0,
                                 -0.33469768250205034,
                                 0.090918617172693061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25235183995322008,
                                 0.2026040652330971,
                                 0,
                                 0,
                                 -0.083950645170967175,
                                 0.58341225368644523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014238987634709863,
                                 0,
                                 0,
                                 0.074420479239342474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0957240808874411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27292682731320794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.536268946115951,
                                 0,
                                 0.2558378588061983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0638598614953252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36710795309875383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33325284394912719,
                                 0,
                                 0,
                                 0,
                                 1.2387112949239163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028996465674570412,
                                 0,
                                 0,
                                 0,
                                 0.18217831894283348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57849492924386614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23107747732417375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28656147484827521,
                                 0,
                                 -0.17340967472691765,
                                 -0.59576082243027162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07907114044102094,
                                 0,
                                 0,
                                 0,
                                 0.18371029317566823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3237680458976615,
                                 0,
                                 0,
                                 0,
                                 -0.10366402021082444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092686520100202341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11039418568636861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34520148456568772,
                                 0,
                                 -0.09775155994366358,
                                 -0.91638238266256244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28283326756135874,
                                 0,
                                 0.63827356713414773,
                                 0.098009371829531483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88076204841153727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41419608698839977,
                                 0,
                                 0,
                                 0,
                                 0.19776243980084768,
                                 0,
                                 -0.36989932971419848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31129856124440458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67966992367140322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14859650374503552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.542083219961075,
                                 0,
                                 0,
                                 0,
                                 -0.35243162544756168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1055293679116909,
                                 0,
                                 0,
                                 0,
                                 0.11847329394218525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3196144822866957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54324028966757765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20313168781181923,
                                 0,
                                 -0.40783029757479344,
                                 -0.039557156323424714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58663348562468698,
                                 0,
                                 0,
                                 0,
                                 0.090737517017852903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20300646323242899,
                                 -0.29946675569327147,
                                 0.31334205920129088,
                                 0,
                                 0,
                                 0.086330579215601888,
                                 -0.43435121788512959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83970902938522651,
                                 0,
                                 0,
                                 0.14530889470764247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23088326997789169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38639995955690759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48681866018498915,
                                 0,
                                 0.72361257570040727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021347961007144478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83839162367919307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31847020345802468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40394537844763051,
                                 0,
                                 0.15372193472035831,
                                 0.091750626327238946,
                                 0,
                                 0.32036113713905584,
                                 0.3357488026601092,
                                 0,
                                 0,
                                 0.1983608953036527,
                                 -0.65782342428635265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51575412804630183,
                                 0,
                                 0,
                                 -0.37062471123449037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33015856206119376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36325626977099196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2800457374194863,
                                 0,
                                 0.23790789778995552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76418062300677914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16786071338577735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31456444833645142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39405418222902022,
                                 0,
                                 -0.3181333846097234,
                                 -0.1800344834467893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20244441065339963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50666231461849187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65566755025025425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40210219090968047,
                                 0,
                                 -0.23705149647948498,
                                 -0.23351667857335454,
                                 0,
                                 0,
                                 0,
                                 0.19836365731234634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4055545320108751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010593924880636318,
                                 0,
                                 -0.24261151762761926,
                                 -0.281973789512243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01488425809562623,
                                 0,
                                 0,
                                 0,
                                 0.30516291488762814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75123207969275108};

const double rot_26_20[4000] = {-0.44550401421077401,
                                0,
                                0,
                                0,
                                0,
                                -0.48126939483757569,
                                0,
                                0.51256031780245848,
                                0,
                                1.0593585226250104,
                                0.064615269301677825,
                                0,
                                -1.2767860730254212,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48909061890460148,
                                0,
                                0,
                                -0.096310008785597992,
                                0,
                                -0.63761251426237664,
                                0,
                                0,
                                0,
                                0,
                                0.046408448364308533,
                                0,
                                0,
                                0,
                                0,
                                0.58115984830960465,
                                -0.071165419948302416,
                                0,
                                0,
                                0,
                                0,
                                0.14618031221045349,
                                0.037765194027774743,
                                0,
                                0,
                                0,
                                0,
                                -0.24947561152260195,
                                0,
                                0,
                                0,
                                0,
                                -0.75481353045262112,
                                -0.30349326509013907,
                                0.16847228675288928,
                                0,
                                0,
                                0.46669264123547416,
                                0.083249415619620945,
                                0,
                                0,
                                -0.27452735630170688,
                                -0.52486608371484866,
                                0,
                                0,
                                0,
                                0,
                                -0.030842242064985519,
                                0,
                                0,
                                0,
                                0,
                                -0.091086053264524347,
                                -0.63217665421816882,
                                0.087840424609730891,
                                0,
                                0,
                                -0.44504099209448528,
                                -0.18568162223114779,
                                0,
                                -0.016215900805960914,
                                0,
                                0,
                                0.39477960684633007,
                                0,
                                -0.61503002073928215,
                                0,
                                0,
                                0,
                                0,
                                0.20865989208802543,
                                0,
                                0,
                                0,
                                0,
                                -0.61347014484609264,
                                0.21386820938389497,
                                0,
                                0,
                                -0.7164107563014499,
                                0,
                                0,
                                0,
                                0,
                                0.50544077943191623,
                                0,
                                -0.41096388900367553,
                                0,
                                -0.016507341797257838,
                                -1.2136389844886304,
                                0,
                                -0.40591824270696131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.071524872734823858,
                                0,
                                0,
                                0.39032533418177923,
                                0,
                                -0.082936928193820647,
                                0,
                                0,
                                0,
                                0,
                                -0.23624568052582515,
                                0,
                                0,
                                0,
                                0,
                                -0.055175527183957761,
                                -0.881359989817319,
                                0,
                                0,
                                0.16927185979418935,
                                0,
                                0,
                                0,
                                0,
                                -0.6851106348536159,
                                0,
                                -1.2808491292528181,
                                0,
                                -0.43304765352343644,
                                -0.46054763784903485,
                                0,
                                -0.42403126505764821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15495818573097481,
                                -0.21331409039050855,
                                0,
                                0,
                                0,
                                0,
                                0.451677207200532,
                                0,
                                0,
                                0,
                                0,
                                0.071292805340823939,
                                -0.032120695555293684,
                                0.54493114037996715,
                                0,
                                0,
                                -0.008187294259669381,
                                0.65064689140264897,
                                -1.127680344559489,
                                0,
                                0,
                                0,
                                0,
                                -0.64728210037180467,
                                0,
                                -0.052672637418697155,
                                0,
                                0.059068122241946325,
                                -0.083515566685531409,
                                0,
                                0.63697004710222704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5028176166390681,
                                0,
                                0,
                                0,
                                0,
                                0.38147830941388361,
                                0,
                                0.038994565401330172,
                                0,
                                0.9007233567040146,
                                -0.1399941017116893,
                                0,
                                0.83110289123705861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.81028956335756996,
                                0,
                                0,
                                -0.23381973259997135,
                                0,
                                -0.43141722212790728,
                                0,
                                0,
                                0,
                                0,
                                -0.2466383296179725,
                                0,
                                0,
                                0,
                                0,
                                0.19647583644147121,
                                0.056613749831614074,
                                0,
                                0,
                                0.50048230739971844,
                                0,
                                0,
                                0,
                                0,
                                -0.53603186309876394,
                                0,
                                0.76467624494782094,
                                0,
                                0.20259120632752961,
                                -0.90135040055095939,
                                0,
                                -0.062031173276877752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30867166398901225,
                                0.56792579769147733,
                                0,
                                0,
                                0,
                                0,
                                0.11314796976769717,
                                0,
                                0,
                                0,
                                0,
                                -0.41165095393729306,
                                0.14313747911566208,
                                0.26220657805860681,
                                0,
                                0,
                                -0.55734854588049276,
                                0.0067150671501265552,
                                0,
                                0,
                                -0.62638521773637512,
                                -0.17571138152066068,
                                0,
                                0,
                                0,
                                0,
                                -0.042823231241461909,
                                0,
                                0,
                                0,
                                0,
                                0.093368835867789379,
                                0.28292648015731592,
                                0.49840668491783197,
                                0,
                                0,
                                0.39387987184136097,
                                -0.28743265397903267,
                                0,
                                0,
                                0.2875186804265234,
                                -0.017776344381916581,
                                0,
                                0,
                                0,
                                0,
                                0.7262346933050523,
                                0,
                                0,
                                0,
                                0,
                                -0.17207323922332965,
                                -0.015223937912638756,
                                0.036584592560999496,
                                0,
                                0,
                                0.10337404784551699,
                                -0.5896902458945088,
                                0,
                                0.23865575518772311,
                                0,
                                0,
                                0.74283066759279637,
                                0,
                                0.14869804179243964,
                                0,
                                0,
                                0,
                                0,
                                0.26666402854905707,
                                0,
                                0,
                                0,
                                0,
                                0.4941983550641072,
                                0.23193361959067305,
                                0,
                                0,
                                0,
                                0.2046603470885576,
                                0,
                                0,
                                -0.27577256870902905,
                                0,
                                -0.008825758083907953,
                                0,
                                0,
                                0,
                                0,
                                0.87553133240813541,
                                0,
                                0,
                                0,
                                0,
                                0.0053389925827431392,
                                -0.33970887506995756,
                                0,
                                0,
                                0,
                                0,
                                0.51321659866360936,
                                -0.29294452117120018,
                                0,
                                0,
                                0,
                                0,
                                -0.39934239964987689,
                                0,
                                0,
                                0,
                                0,
                                -0.079744519461015975,
                                0.40327481798610931,
                                0.3990906098290129,
                                0,
                                0,
                                -0.31660463340857109,
                                -0.25063180615904029,
                                0,
                                0,
                                0.21344578176336151,
                                0.48789321674270525,
                                0,
                                0,
                                0,
                                0,
                                -0.17683580446515523,
                                0,
                                0,
                                0,
                                0,
                                0.45026055303936346,
                                -0.49377595993972573,
                                0.43494590494713808,
                                0,
                                0,
                                0.085825517675752985,
                                -0.20502922135817533,
                                -0.071290286393143817,
                                0,
                                0,
                                0.33635215752627057,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79553565108731195,
                                0,
                                0,
                                0,
                                0,
                                -0.2258355104630845,
                                0,
                                0,
                                -0.0089165333127886603,
                                0,
                                -0.44477721017387051,
                                0,
                                0.071885066262933645,
                                0,
                                0,
                                0,
                                -0.39397226070584995,
                                0,
                                0,
                                0.46476077789278342,
                                0,
                                -0.14434686893460086,
                                0.30185305464875728,
                                -0.55098594638292631,
                                -0.44328911697904866,
                                0,
                                0,
                                0,
                                0,
                                -0.1075814800959189,
                                0,
                                0,
                                0,
                                0.2855331557766278,
                                0,
                                -0.49219598148645788,
                                0,
                                -0.097505419070294863,
                                -0.16176590695801674,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47099553430105773,
                                -1.1576461773335802,
                                0,
                                0,
                                0,
                                0.059395150231816185,
                                0,
                                0,
                                0.39256389553853799,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34866652951633087,
                                0,
                                0,
                                0,
                                0,
                                0.2309049064275065,
                                0,
                                0,
                                0.67039107489627203,
                                0,
                                -0.46696486605601384,
                                0,
                                0,
                                0.5069650047225962,
                                0,
                                1.1017229770121353,
                                0,
                                0.38849280102440548,
                                -0.26941660338979573,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42265547931426867,
                                0.32070690915676753,
                                0,
                                0,
                                0,
                                0,
                                -0.34293918349701213,
                                0,
                                0,
                                0,
                                -0.39777430299517047,
                                0,
                                0,
                                0.17081552844410708,
                                0,
                                0.13926390984634121,
                                0.22119088615772758,
                                0.51314467039470413,
                                0.089136833826876635,
                                0,
                                0,
                                0,
                                0,
                                -0.59616080291928442,
                                0,
                                0,
                                0,
                                -1.0221050448902425,
                                0,
                                0.43137312640389047,
                                0,
                                -0.58745810002916166,
                                -1.1588275466163009,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.067177692489040625,
                                -0.042589102861786576,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42734040220550223,
                                0,
                                0.46294041850446277,
                                0,
                                0.33813365095101006,
                                0.5934382708378152,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71922801602044817,
                                -0.9995842619073646,
                                0,
                                0,
                                0,
                                0,
                                -0.29080189988206229,
                                0,
                                0,
                                0,
                                0.63785290224955038,
                                0,
                                0,
                                0.54631844794445616,
                                0,
                                0.38438107058687898,
                                -0.043268203586352437,
                                -0.17128720902154634,
                                0.057504916024803773,
                                0,
                                0,
                                0,
                                0,
                                -0.16687425009226112,
                                0,
                                -0.36937106263893799,
                                0,
                                0,
                                0.40841262303626469,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4251592809849376,
                                0,
                                0,
                                0,
                                0,
                                -0.089676286135773844,
                                0,
                                0,
                                -0.6294814154163485,
                                0,
                                -0.33423800587652386,
                                0,
                                0.025221858146106037,
                                0,
                                0,
                                0,
                                -0.1960350435944504,
                                0,
                                0,
                                0.047129842293494539,
                                0,
                                0.29093932691127267,
                                -0.76788672135377434,
                                0.11479461544578637,
                                -0.51666009484571529,
                                0,
                                0,
                                0,
                                0,
                                -0.06558758574308618,
                                0,
                                0,
                                -0.85249624580487948,
                                0,
                                0,
                                0,
                                -0.075028069792212437,
                                0,
                                0,
                                -0.083118717854666277,
                                0,
                                -0.39103934699010467,
                                -0.18731299571126353,
                                -0.15155377040903062,
                                -0.024354351690640583,
                                0,
                                0,
                                0,
                                0,
                                0.22170387760658827,
                                0,
                                0,
                                0.18394074829283036,
                                0,
                                0,
                                0,
                                0.07801713312702438,
                                0,
                                0,
                                0.59984030041032443,
                                0,
                                -0.52197960032173518,
                                -0.124434570777222,
                                0.49039922583882789,
                                3.7802966612987543e-05,
                                0,
                                0,
                                0,
                                0,
                                0.26801618303906988,
                                0,
                                0,
                                0.15122825089134256,
                                0,
                                0,
                                0,
                                -0.23047502239072271,
                                0,
                                0,
                                0.16225953831632905,
                                0,
                                -0.17567997262827395,
                                -0.46233794257046773,
                                -0.35525360401787986,
                                0.65785939819919614,
                                0,
                                0,
                                0,
                                0,
                                -0.30672330449779484,
                                0,
                                0.27981104853877448,
                                0,
                                0,
                                0.23221845467814556,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21521638206857979,
                                0,
                                0,
                                0,
                                0,
                                -0.87298073323516323,
                                0,
                                0,
                                0.15748244672570966,
                                0,
                                0.18591985823283716,
                                0,
                                0,
                                1.2656466714679369,
                                0,
                                -0.53415409948468462,
                                0,
                                -0.32796385553041796,
                                -0.20496763973526008,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.632722855398134,
                                0.14555339127108299,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22309623856270194,
                                0,
                                0.059262418544724083,
                                0,
                                -1.3495128326755059,
                                0.52207381745824477,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.076883324890684251,
                                -0.10388701411182794,
                                0,
                                0,
                                0,
                                0.80788041947746969,
                                0,
                                0,
                                0.37322304570974163,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.033415308180870268,
                                0,
                                0,
                                0,
                                0,
                                0.30387517529172769,
                                0,
                                0,
                                -0.33221512003175963,
                                0,
                                0.064886015588373092,
                                0,
                                -0.092570701119845611,
                                0,
                                0,
                                0,
                                -0.4200485426491411,
                                0,
                                0,
                                0.24716217539709767,
                                0,
                                0.52070828555423532,
                                0.064114562306868725,
                                0.030246540762196066,
                                0.30320420672528414,
                                0,
                                0,
                                0,
                                0,
                                0.62113227755194544,
                                0,
                                0.35212204449656953,
                                0,
                                0,
                                -0.61052362022259821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13175580027073175,
                                0,
                                0,
                                0,
                                0,
                                -0.1822194483256277,
                                0,
                                0,
                                -0.13813704345359906,
                                0,
                                -0.6585025542111973,
                                -0.37773463365561877,
                                0,
                                -0.082631478062134056,
                                0,
                                0,
                                0,
                                0.1825999732670624,
                                0,
                                0,
                                0,
                                -0.84597736139727053,
                                0,
                                0,
                                -0.31767832916926403,
                                0,
                                -0.023422602603628079,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27047272344755013,
                                0,
                                -0.088153135193062879,
                                0.021654286614719277,
                                -0.61637439227750834,
                                0,
                                0.3515463113332184,
                                0,
                                0,
                                0,
                                0.21574967435549647,
                                0,
                                0,
                                -0.28895588556110074,
                                0,
                                0.53390916478867945,
                                0,
                                0,
                                0,
                                -0.096758402695720488,
                                0,
                                0.79623293168187648,
                                0,
                                0,
                                0,
                                0.20038415215099695,
                                0,
                                0,
                                0,
                                -0.167296290253241,
                                0,
                                0,
                                0.48556352731971647,
                                0,
                                -0.22964567007483835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61549820961946367,
                                0,
                                0.029723983205382058,
                                0.14429246284565367,
                                0.060916229684077228,
                                0,
                                -0.14246599286776562,
                                0,
                                0,
                                0,
                                0.36298754053781718,
                                0,
                                0,
                                0.66306235692455151,
                                0,
                                0.063554181804343662,
                                0,
                                0,
                                0,
                                0,
                                0.24524673968785685,
                                0,
                                0.57712062785230656,
                                0.13466524187394016,
                                0.44002121827080903,
                                0,
                                0.053445291822523763,
                                0,
                                0,
                                0,
                                -0.35189217120053107,
                                0,
                                0,
                                -0.16616111198825703,
                                0,
                                0.49065099936201928,
                                0,
                                0,
                                0,
                                0,
                                0.15747028764962556,
                                0,
                                -0.13417839184163199,
                                0.42825315965163419,
                                -0.42949358043076735,
                                0,
                                -0.2685098141077098,
                                0,
                                0,
                                0,
                                -0.70099367152045766,
                                0,
                                0,
                                0.13977662290658457,
                                0,
                                -0.079414175009452137,
                                0,
                                0,
                                0,
                                -0.42063026474838505,
                                0,
                                0.22302234776326019,
                                0,
                                0,
                                0,
                                -0.64213933958199942,
                                0,
                                0,
                                0,
                                -0.022297307834817648,
                                0,
                                0,
                                0.088634567062862463,
                                0,
                                0.59383080496211949,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3464109375382991,
                                0,
                                0.40396836899020527,
                                -0.21728637127535133,
                                -0.24287569715818288,
                                0,
                                -0.52036103083239982,
                                0,
                                0,
                                0,
                                0.16698794042599865,
                                0,
                                0,
                                -0.44036489249596905,
                                0,
                                -0.34354800915954398,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23761671868119305,
                                -0.45205644526779076,
                                0,
                                0,
                                -1.2232338208655162,
                                0,
                                0,
                                0,
                                0,
                                -0.33618019965467277,
                                -0.68718592073509011,
                                -0.67465029029730039,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2145760675671262,
                                -0.31677711988444102,
                                0,
                                0,
                                -0.80075329582273014,
                                0,
                                0,
                                0,
                                0,
                                0.59098256064260068,
                                0.84307431464295779,
                                -0.39498416384054519,
                                0.083374176482309381,
                                0,
                                0.36646556835092686,
                                0,
                                0,
                                0,
                                -0.48239295885368971,
                                0,
                                0,
                                0,
                                0.063535333441164743,
                                0,
                                0,
                                -0.60349254684995424,
                                0,
                                -0.50774873161691592,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0070412610788547214,
                                0,
                                -0.41232087884524715,
                                -0.50810932056073677,
                                0.10460230487448004,
                                0,
                                -0.54358364422431693,
                                0,
                                0,
                                0,
                                -0.13723951955288971,
                                0,
                                0,
                                0.023711228227292769,
                                0,
                                0.49592852644873286,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56772905674012952,
                                0.16587833924731338,
                                0,
                                0,
                                -0.26481893062428946,
                                0,
                                0,
                                0,
                                0,
                                0.3655140295665017,
                                0.54107657339386106,
                                0.58363336282654543,
                                -0.69179508452743899,
                                0,
                                0.095927727617453828,
                                0,
                                0,
                                0,
                                0.41237028403950915,
                                0,
                                0,
                                0,
                                0.50173795599538096,
                                0,
                                0,
                                -0.30025945819215966,
                                0,
                                -0.016476110546111332,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.061060401010905957,
                                0,
                                -0.30267234664244314,
                                0.67466182847485756,
                                0.25372529893049905,
                                0,
                                -0.33724515951848522,
                                0,
                                0,
                                0,
                                0.34133698670089857,
                                0,
                                0,
                                -0.37161438406300679,
                                0,
                                0.12951247560258083,
                                0,
                                0,
                                0,
                                -0.43068880429156953,
                                0,
                                -0.40736598780960936,
                                0,
                                0,
                                0,
                                -0.33377880696704659,
                                0,
                                0,
                                0,
                                0.0077052094216836647,
                                0,
                                0,
                                0.44843445150584171,
                                0,
                                -0.57965419545094077,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58248185845635059,
                                0,
                                0.4641809452679263,
                                0.12891178895984118,
                                -0.32246184204234779,
                                0,
                                -0.31807488753163637,
                                0,
                                0,
                                0,
                                0.20794542385196785,
                                0,
                                0,
                                0.31164896318029639,
                                0,
                                0.28829331605614505,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.077453905280477714,
                                1.053132295573536,
                                0,
                                0,
                                -0.31302602183130351,
                                0,
                                0,
                                0,
                                0,
                                0.042108948615573322,
                                -0.55609513141175593,
                                -0.16157651712449039,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.040505308757184659,
                                -0.32565766920803924,
                                0,
                                0,
                                0.026024369796634063,
                                0,
                                0,
                                0,
                                0,
                                1.2659990913839885,
                                -0.26481514724958732,
                                -0.49367497705849783,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46931177178702888,
                                0.12202297870912526,
                                0,
                                0,
                                0.044990594939692041,
                                0,
                                0,
                                0,
                                0,
                                -0.21899321008848482,
                                0.61865159444659157,
                                -0.80986966561687634,
                                -0.010000500974146488,
                                0,
                                0.80511214039166779,
                                0.12311164809486451,
                                0,
                                0,
                                0,
                                0,
                                -0.2452782446278815,
                                0,
                                0,
                                0,
                                0,
                                0.056917870610942542,
                                0,
                                0.52262500150199587,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0798057435546318,
                                0,
                                0,
                                0,
                                0.75318477145216034,
                                0,
                                0,
                                0,
                                0,
                                0.23804571449755083,
                                0,
                                0,
                                0,
                                0.28450673230350021,
                                0,
                                0.7973493512139036,
                                0,
                                0,
                                0.0046626634962361468,
                                -0.37138623124962694,
                                0,
                                0.14367229902913442,
                                -0.7590976722112257,
                                0,
                                0,
                                0,
                                0,
                                -0.30219976319064018,
                                0,
                                0,
                                0,
                                0,
                                -0.38944208650667705,
                                0,
                                -0.1490349830013957,
                                0,
                                0,
                                0,
                                0,
                                -0.48855480509930832,
                                0,
                                -0.30447381715642796,
                                -0.1093174251420221,
                                0,
                                0,
                                0,
                                0,
                                -0.30542457717025884,
                                0,
                                0,
                                0,
                                0,
                                0.70199934828077604,
                                0,
                                0.26565455071318433,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48124195979437534,
                                0,
                                0.44517091249606966,
                                0.15891386278270531,
                                0,
                                -0.1938294088499995,
                                0,
                                -0.055337244785439998,
                                0.48846880703581452,
                                0,
                                0,
                                0,
                                0,
                                -0.022769464274142698,
                                -0.51499819870583674,
                                0,
                                0,
                                0.52103399139737583,
                                0,
                                0,
                                0,
                                -0.055113558072245508,
                                0,
                                0,
                                0,
                                0,
                                0.37471417479315833,
                                0,
                                0,
                                0,
                                0.27859989993211887,
                                0,
                                0.86323624768249663,
                                0,
                                0,
                                0.34553606199917347,
                                0,
                                0,
                                0,
                                0,
                                0.15370486231678976,
                                0,
                                0.29655211224057271,
                                0.19168735551741722,
                                0,
                                -0.15383947692727606,
                                0,
                                -0.47201143940749929,
                                -0.5856071766721368,
                                0,
                                0,
                                0,
                                0,
                                0.51203867196791442,
                                -0.010337659657544941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14186211794683826,
                                0,
                                0.1257764738341412,
                                -0.45485752440683702,
                                0,
                                -0.10521957404489655,
                                0,
                                -0.61603055341853807,
                                0.29041682691205017,
                                0,
                                0,
                                0,
                                0,
                                -0.2025759879680451,
                                0.49113774529121867,
                                0,
                                -0.63987454538228594,
                                0,
                                -0.1762891965435914,
                                0.34830794108233654,
                                0,
                                0,
                                0,
                                0,
                                0.27435762216720194,
                                0,
                                0,
                                0,
                                0,
                                -0.48393324081710637,
                                0,
                                0.35874890539738663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.044501544455039177,
                                0,
                                -0.10892745464098608,
                                -0.44618479465931077,
                                0,
                                -0.088994034168085656,
                                0,
                                0.26861911366285685,
                                0.3004968361278233,
                                0,
                                0,
                                0,
                                0,
                                0.78262439169176912,
                                0.064792729878497851,
                                0,
                                0,
                                0.052773079793271505,
                                0,
                                0,
                                0,
                                0.30350795044321011,
                                0,
                                0,
                                0,
                                0,
                                0.21600041061469266,
                                0,
                                0,
                                0,
                                -0.15617398579320985,
                                0,
                                -0.65833966733605576,
                                0,
                                0,
                                1.4462294277693268,
                                0,
                                0,
                                0,
                                0,
                                0.36227157600596671,
                                0,
                                -0.29891361831879609,
                                -0.12419577064627781,
                                0,
                                -0.76887294628469516,
                                0,
                                0.23701207857479786,
                                -0.26613343771210829,
                                0,
                                0,
                                0,
                                0,
                                -0.2047663153271902,
                                0.062360092008462514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22495231653002379,
                                0,
                                -0.56167603045285397,
                                0.61308988219446736,
                                0,
                                0.0069560494845415932,
                                0,
                                -0.23496095470852607,
                                0.32834986641343411,
                                0,
                                0,
                                0,
                                0,
                                0.19411151731745258,
                                0.23935190758023653,
                                0,
                                -0.46227712081128475,
                                0,
                                0.42894772916759627,
                                0.25265226874221997,
                                0,
                                0,
                                0,
                                0,
                                0.1699599246257405,
                                0,
                                0,
                                0,
                                0,
                                0.23296337996497746,
                                0,
                                -0.67476827721248611,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52338133366157669,
                                0,
                                0,
                                0,
                                -1.0684411235156341,
                                0,
                                0,
                                0,
                                0,
                                -0.10619950016502328,
                                0,
                                0,
                                0,
                                -0.93756384102293699,
                                0,
                                0.50961839206555126,
                                0,
                                0,
                                0.37066293176753334,
                                0.012119792864689435,
                                0,
                                -0.15288679267942715,
                                0.45990472490025075,
                                0,
                                0,
                                0,
                                0,
                                -0.80688985164031302,
                                0,
                                0,
                                0,
                                0,
                                -0.25264365082731433,
                                0,
                                -0.2237550810061282,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11300185460059911,
                                0,
                                0,
                                0,
                                -0.29713505455268208,
                                0,
                                0,
                                0,
                                0,
                                1.6318523906035858,
                                0,
                                0,
                                0,
                                0.18306091446489475,
                                0,
                                0.25672005548591592,
                                0,
                                0,
                                -0.30577989451883414,
                                0,
                                0,
                                0,
                                0,
                                0.70838993770848213,
                                0,
                                0.091785017526393342,
                                -0.058276783623147491,
                                0,
                                0.5094695976964867,
                                0,
                                0.29753132493087853,
                                -0.20915673776068294,
                                0,
                                0,
                                0,
                                0,
                                -0.049729602906321752,
                                0.30341273630738963,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19752265724595838,
                                0,
                                -0.52243754440537893,
                                -0.37057539968327635,
                                0,
                                0.26267701382866132,
                                0,
                                -0.35012405586425499,
                                -0.14640694967701157,
                                0,
                                0,
                                0,
                                0,
                                -0.040968549897256609,
                                -0.57967076874425927,
                                0,
                                0,
                                -0.037629182216336904,
                                0,
                                0,
                                0,
                                -1.0183763348929826,
                                0,
                                0,
                                0,
                                0,
                                0.16008992294596913,
                                0,
                                0,
                                0,
                                0.96332665585311683,
                                0,
                                0.00016228548907139262,
                                0,
                                0,
                                0.065147353548391324,
                                0.28074216171626232,
                                0,
                                0.34038331768222696,
                                0.21129289485024411,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43815490806563107,
                                0,
                                -0.09540710464044333,
                                0.2073200147151652,
                                -0.32896893836650298,
                                0,
                                0,
                                -0.63905708530222072,
                                0,
                                0,
                                -0.22175458397381576,
                                0,
                                0,
                                0,
                                -0.19181247121217376,
                                0,
                                -0.20899669560695092,
                                0,
                                0,
                                -0.8067104679806395,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2187474103546091,
                                0,
                                -0.41439239002793476,
                                0.25613076489930936,
                                0,
                                0.14066438105995133,
                                0.32661464074266594,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40471809005066034,
                                0,
                                -0.19728713876790621,
                                -0.43492543323858479,
                                -0.25493180245654051,
                                0,
                                0,
                                0.59250665456740825,
                                0,
                                0.49306902136240133,
                                0,
                                -0.25935791653097384,
                                0.029245387781417442,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33045454457051554,
                                0,
                                0.55756104164476217,
                                0.047351260469871911,
                                -0.51294336518759764,
                                0,
                                0,
                                0.057736986876601157,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49747663592944902,
                                0,
                                0.752883974450265,
                                0,
                                -0.15199236035762775,
                                -0.78871190578811179,
                                0,
                                0,
                                0.35349191132816615,
                                0,
                                0,
                                0,
                                -0.37235311380344244,
                                0,
                                0,
                                0,
                                0,
                                0.16261547098513573,
                                0,
                                0,
                                0,
                                0.43683899319215314,
                                0,
                                0.025990127736826824,
                                0,
                                0,
                                -0.55435746528874741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27427420832362115,
                                0,
                                0.63207109980638876,
                                0,
                                0,
                                0,
                                0,
                                -0.12146228549846107,
                                0,
                                0.3606744469630434,
                                0,
                                0.99955855763636137,
                                -0.3623981798714534,
                                0,
                                0,
                                -0.49619171186813832,
                                0,
                                0,
                                0,
                                0.16215523305256063,
                                0,
                                0,
                                0,
                                0,
                                -0.51592160605066839,
                                0,
                                0,
                                0,
                                -0.67146577521309259,
                                0,
                                0.080187967517329928,
                                0,
                                0,
                                -0.023846941813277886,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21593719390730581,
                                0,
                                0.47888511215803292,
                                0,
                                0,
                                0,
                                0,
                                0.21154215670323992,
                                0,
                                0.00093034223926385939,
                                0,
                                0.99461331570237166,
                                0.42811805719049961,
                                0,
                                0,
                                0.58146668460378592,
                                0,
                                0,
                                0,
                                -1.29018694975704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.99885628023294193,
                                0,
                                -0.27539911125723121,
                                0,
                                0.017007661125260226,
                                0.46217036641392661,
                                0,
                                0,
                                -0.5653381710014338,
                                0,
                                0,
                                0,
                                -0.018715254433001427,
                                0,
                                0,
                                0,
                                0,
                                0.49233039836438103,
                                0,
                                0,
                                0,
                                -0.34147026246934825,
                                0,
                                -0.76993388073897273,
                                0,
                                0,
                                0.043849656958196447,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19260258306330161,
                                0,
                                0.095875495136673178,
                                -0.29643297760324111,
                                0,
                                -0.5480118856601518,
                                0.35241307313707276,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51199205173892648,
                                0,
                                0.29370993983394073,
                                0.35810869159350434,
                                0.045337934390568622,
                                0,
                                0,
                                0.094428468990330056,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16378698826224677,
                                0,
                                -0.58125869025163424,
                                0,
                                0.73295981859703652,
                                -0.21691001300772228,
                                0,
                                0,
                                0.90254253544595464,
                                0,
                                0,
                                0,
                                0.38033112454519857,
                                0,
                                0,
                                0,
                                -0.093558675388496104,
                                0,
                                -0.29539827414808811,
                                0.51666284680422858,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2166757717826843,
                                0,
                                -0.0069000530636395135,
                                -0.62205267547764187,
                                0.11448788725623807,
                                0,
                                0,
                                -0.43588201203403554,
                                0,
                                0.1685837851072447,
                                0,
                                0.49687305439159074,
                                0.44886406838383353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11248882290645144,
                                0,
                                0.44589857467016952,
                                0.15431061879818594,
                                0.52186231103235425,
                                0,
                                0,
                                0.12484554621900459,
                                0,
                                0.22450177215630754,
                                0,
                                -0.19186866965315605,
                                0.42883182891105948,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38123363135421989,
                                0,
                                -0.59107971200453946,
                                0.4691027203021344,
                                -0.0029501378720483296,
                                0,
                                0,
                                0.11877818524367476,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0023878480022974241,
                                0,
                                0.88938488456300713,
                                0,
                                -0.17506603079354077,
                                0.79313646498599222,
                                0,
                                0,
                                0.20090157696350419,
                                0,
                                0,
                                0,
                                0.81490620397741376,
                                0,
                                0,
                                0,
                                0,
                                0.20528447651531059,
                                0,
                                0,
                                0,
                                -0.13902107218371063,
                                0,
                                0.02558183367597483,
                                0,
                                0,
                                -0.0065382622017576969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87453248022473962,
                                0,
                                0.4159653677120817,
                                0.66107226218176551,
                                0,
                                -0.35470073908579408,
                                -0.26704257258497399,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26066505331665724,
                                0,
                                -0.081160641785978829,
                                -0.080966918060415893,
                                0.52551530727810758,
                                0,
                                0,
                                -0.09275674904598584,
                                0,
                                0,
                                -0.61128967931839495,
                                0,
                                0,
                                0,
                                0.43079529241837278,
                                0,
                                -0.59645802318942698,
                                0,
                                0,
                                0.19842329401377329,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16849790333517811,
                                0,
                                0.1312052724791069,
                                0.23897870189969106,
                                0,
                                0,
                                0.19867486148008751,
                                -0.12255859343178491,
                                0,
                                0,
                                -0.8723070954971992,
                                0.14411823900407372,
                                0,
                                0,
                                0,
                                0,
                                0.32666058066721998,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18362004700517104,
                                -0.64054002793513498,
                                0,
                                0,
                                0.35270328513140059,
                                0.15780172540178286,
                                0,
                                0,
                                0,
                                0,
                                0.57525511930778539,
                                0.24143757042935632,
                                0,
                                0,
                                -0.051364672479152579,
                                0,
                                -0.12182888321279696,
                                0,
                                0,
                                0,
                                -0.18088550091468791,
                                0.30951416774045531,
                                0,
                                0,
                                0.12880210442417184,
                                0.45830977784022214,
                                0,
                                0,
                                0,
                                0,
                                0.40655785882778028,
                                -0.64112293527654907,
                                0,
                                0,
                                -0.0018726030027591267,
                                0,
                                0.26174828290644814,
                                0,
                                0,
                                -0.69020434481319115,
                                0,
                                0,
                                0.69559744056801964,
                                -0.11544459415565186,
                                0,
                                0,
                                -0.073676946259870785,
                                -0.051203828167482479,
                                0,
                                0,
                                0,
                                0,
                                -0.1355897648303758,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36102980776840332,
                                0,
                                0,
                                -0.37559802968869999,
                                0.62284881634055367,
                                0,
                                0,
                                -0.42436619543579723,
                                -0.28573922267532759,
                                0,
                                0,
                                0,
                                0,
                                -0.28090813227158196,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24750928738277833,
                                -0.21983369540012787,
                                0,
                                0,
                                0.010173275914063688,
                                -0.41717188214555151,
                                0,
                                0,
                                0,
                                0,
                                -0.10777296532937435,
                                -0.32124897890280457,
                                0,
                                0,
                                -0.75203006186590104,
                                0,
                                0.18950274873546125,
                                0,
                                0,
                                0,
                                -0.76711465385448063,
                                0.40747597314277206,
                                0,
                                0,
                                -0.17423714569206555,
                                0.047480813615261824,
                                0,
                                0,
                                0,
                                0,
                                0.089986890217015697,
                                0.41852930950530215,
                                0,
                                0,
                                -0.11847493225362039,
                                0,
                                -0.12483867851820571,
                                0,
                                0,
                                -0.066992394769874605,
                                0,
                                0,
                                -0.11673684587000202,
                                -0.34278874473919224,
                                0,
                                0,
                                -0.0036972992718523195,
                                -0.85728968883603007,
                                0,
                                0,
                                0,
                                0,
                                0.35975147495593518,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14608003354027493,
                                0,
                                0,
                                0.38293572616931315,
                                0.67620046241419662,
                                0,
                                0,
                                0.22556519374324535,
                                -0.099788942585642137,
                                0,
                                0,
                                0,
                                0,
                                0.56030018593980657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.4574895042314064,
                                -0.7051086670405966,
                                0,
                                0,
                                0,
                                -0.17450066858143234,
                                0,
                                0.1708886991080443,
                                0,
                                0.38557344108491465,
                                -0.24446960477061649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1684388964687159,
                                0.28368889091665911,
                                0,
                                0,
                                0,
                                0.44383342803206355,
                                0,
                                0.3780310747564043,
                                0,
                                1.2382875252106631,
                                0.43048910974933963,
                                0,
                                -0.063633957042702097,
                                -0.35045257506032851,
                                0,
                                0,
                                -0.77362953973142912,
                                0.27894437523596055,
                                0,
                                0,
                                0,
                                0,
                                0.011729585487829503,
                                -0.24906316741205836,
                                0,
                                0,
                                -0.029275049861047175,
                                0,
                                -0.36577863502727931,
                                0,
                                0,
                                0,
                                0.053065819199805506,
                                0.20722879678847458,
                                0,
                                0,
                                -0.090104166041837283,
                                -0.6627405835324961,
                                0,
                                0,
                                0,
                                0,
                                0.52148512048288131,
                                -0.22722661593025489,
                                0,
                                0,
                                0.21782741511242926,
                                0,
                                -0.36860406151918873,
                                0,
                                0,
                                0.55707922523274078,
                                0,
                                0,
                                0.41872587527469518,
                                0.094657804487461653,
                                0,
                                0,
                                -0.051691820011233791,
                                -0.38737288772618245,
                                0,
                                0,
                                0,
                                0,
                                -0.59383623991630574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.059466256001406301,
                                -1.0921400937577956,
                                0,
                                0,
                                0,
                                0.31028754568640926,
                                0,
                                -0.852614275499749,
                                0,
                                0.25745892167537215,
                                -0.013823951987194494,
                                0,
                                0.12241228132329923,
                                -0.05677800758408514,
                                0,
                                0,
                                -0.46735256498894995,
                                -0.14397876614518459,
                                0,
                                0,
                                0,
                                0,
                                0.35284069215552311,
                                0.26549581344693951,
                                0,
                                0,
                                0.071486093744928508,
                                0,
                                0.7365788101323697,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14581248510616424,
                                0.4612203123217245,
                                0,
                                0,
                                0,
                                0.15808100136761502,
                                0,
                                -0.86937511431298597,
                                0,
                                0.96461794608200968,
                                -0.69700928401632711,
                                0,
                                0.51184797168946305,
                                0.33250775408827932,
                                0,
                                0,
                                -0.059232479154368418,
                                0.22582963809999246,
                                0,
                                0,
                                0,
                                0,
                                0.295801850175401,
                                0.26105395760297678,
                                0,
                                0,
                                -0.60361955513281285,
                                0,
                                -0.23008316894397643,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.036515247927088886,
                                -0.59016897486584496,
                                0,
                                0,
                                0,
                                0.9218982965019169,
                                0,
                                0.41481931828946195,
                                0,
                                -0.38109051362476604,
                                -1.2570403366487262,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7003614988682112,
                                0.42082525656130476,
                                0,
                                0,
                                0,
                                1.2147421178320055,
                                0,
                                -0.04580267471444395,
                                0,
                                0.20923889318368633,
                                0.55452907946139796,
                                0.53271004923039234,
                                0,
                                0.045262384936742547,
                                -0.08602109609900041,
                                0,
                                -0.027286668130475689,
                                -0.10376505865136076,
                                0,
                                0,
                                0,
                                -0.09947236026092926,
                                0,
                                0.6556593231206197,
                                -0.50544637982617058,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52129767886217104,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.84008473175115572,
                                -0.60439000418714217,
                                0,
                                0.89100117765128006,
                                0,
                                0,
                                0,
                                -0.15339733998380106,
                                0,
                                0,
                                -0.28597604437461932,
                                0,
                                -0.59872614876048913,
                                0,
                                0.018421528220096378,
                                0.5036371646000235,
                                0,
                                -0.14329273848520038,
                                0.20967707476539049,
                                0,
                                0,
                                0,
                                0.25698257868811603,
                                0,
                                0.30571562832369276,
                                -0.40439816615166518,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21359675483667068,
                                0,
                                0.12353649584499035,
                                0.24170677459292547,
                                0,
                                0.75621505128880095,
                                -0.31092489582759758,
                                0,
                                0,
                                0,
                                -0.34636186711869149,
                                0,
                                0.25431562179480555,
                                0.16587502075204241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.051668118079225306,
                                0,
                                0,
                                -0.29117737812978539,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.015592167994029474,
                                0,
                                0.1725072875143247,
                                0.61676526260280407,
                                0,
                                -0.70862181093853238,
                                -0.12441512648367459,
                                0,
                                -0.42015735728275549,
                                -0.31315328487822852,
                                0,
                                0.2412348173182394,
                                -0.4541910246752871,
                                0,
                                0,
                                0,
                                0.65959503712355827,
                                0,
                                0.070741347405322202,
                                -0.073280395606008117,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19669998609017691,
                                0,
                                -0.2952384538685543,
                                0.45734873206540472,
                                0,
                                -0.33813211219894596,
                                -0.19296327048280509,
                                0,
                                0,
                                0,
                                0.086276261219870781,
                                0,
                                0.36136400371766314,
                                0.61268248107737933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52984961761205174,
                                0,
                                0,
                                0.45614014293352628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.054469952793736148,
                                0,
                                0.10208531489372147,
                                -0.42084176225592562,
                                0,
                                -0.56630325496854561,
                                0,
                                0.03072179990646071,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57440727224473642,
                                0.11709603614733971,
                                0,
                                -0.34419235466769516,
                                0,
                                0,
                                0,
                                -0.98487833233255107,
                                0,
                                0,
                                -0.64290731558761149,
                                0,
                                0,
                                0.53001273502272794,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22745942107520215,
                                -0.39816426515124614,
                                0,
                                -0.68840690719536113,
                                0,
                                0,
                                0,
                                0.83807594409647757,
                                0,
                                0,
                                -0.60012682112268734,
                                0,
                                0.26587159507138081,
                                0,
                                -0.63051501248704123,
                                0.21645442762767708,
                                0,
                                0.39233699626775181,
                                0.55677091171131698,
                                0,
                                0,
                                0,
                                -0.0070698452702802304,
                                0,
                                -0.11166512180771372,
                                -0.092029048752169842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28530622779144632,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28124929143757937,
                                1.0887006692881911,
                                0,
                                0.27542554223762833,
                                0,
                                0,
                                0,
                                0.73483580340363674,
                                0,
                                0,
                                -0.14043737529246536,
                                0,
                                0.13944595145640992,
                                0,
                                -0.20862484063487291,
                                0.43466654452038589,
                                0,
                                -0.13732889648560259,
                                -0.54025934621072758,
                                0,
                                0,
                                0,
                                -0.21571261200292552,
                                0,
                                -0.47717245457437568,
                                -0.40389432802106517,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40965905567111838,
                                0,
                                -0.52685789676087857,
                                -0.37081996421264268,
                                0,
                                -0.24808530429468589,
                                -0.056530753829301589,
                                0,
                                0,
                                0,
                                -0.56125532591111205,
                                0,
                                0.19031930765532262,
                                -0.033492458901028893,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47091627376962447,
                                0,
                                0,
                                0.1607017237792146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19789538549935951,
                                0,
                                0.8214174518721532,
                                -0.19626606821142628,
                                0,
                                0.0017988051776206965,
                                0,
                                -1.1903838297882992,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20695557790426156,
                                0.37348539180199003,
                                0,
                                -0.68202372509154152,
                                0,
                                0,
                                0,
                                -0.34495886814236704,
                                0,
                                0,
                                0.11700493115671726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53052350594701136,
                                0,
                                0,
                                0.068606516063630427,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68407000247241811,
                                0,
                                -0.2243490596205418,
                                -0.3025552436301332,
                                0,
                                -0.32251203281114604,
                                0,
                                0,
                                0,
                                0,
                                -0.19898173143832559,
                                0,
                                0,
                                -0.82133524801361824,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.032029282378988055,
                                0,
                                0.16254462055228375,
                                -0.50264031715841762,
                                0,
                                -0.075635731575104559,
                                0,
                                0.65490357489288176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0594902111356947,
                                -0.17582062723932509,
                                0,
                                -0.10515138861756895,
                                0,
                                0,
                                0,
                                0.42544442990836873,
                                0,
                                0,
                                0.82219061281409123,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41686776270292603,
                                0,
                                0,
                                -0.045037948093293895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69903482154011976,
                                0,
                                -0.45644270152369754,
                                -0.24451071259853829,
                                0,
                                -0.25964926646397268,
                                0.69525398866789911,
                                0,
                                0,
                                0,
                                0,
                                0.40069205035847821,
                                0,
                                -0.25617060062747121,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17475489593217117,
                                -0.48406438441423949,
                                0.15995872431491617,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31754302158103254,
                                0,
                                0.17342615298402325,
                                0,
                                0,
                                -0.66287419144568183,
                                0,
                                0,
                                0.13781290505375265,
                                0,
                                0.48620968995993724,
                                -0.30923308769259739,
                                0,
                                0,
                                0,
                                -0.26698898747648681,
                                0,
                                0.085948379005505254,
                                0,
                                0,
                                0,
                                -0.61467882649746197,
                                0,
                                0.77082068806148796,
                                0,
                                0,
                                0,
                                0.069354054633757142,
                                0,
                                0.835171276984773,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48432689928711486,
                                0,
                                0.14291706199306387,
                                0,
                                0.51895655173634636,
                                0,
                                0.16404615193775524,
                                0,
                                0,
                                0.24116315911077457,
                                0,
                                0,
                                -0.44684684489676951,
                                0,
                                -0.21667531489425929,
                                -0.59351066525022322,
                                0,
                                0,
                                0,
                                0.20713653975148377,
                                0,
                                0.06190749055923922,
                                0,
                                0,
                                0,
                                0.52946070346511587,
                                0,
                                0.096103198152687253,
                                0,
                                0,
                                0,
                                0.81611958435669596,
                                0,
                                -0.36149322634768355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29462292949748303,
                                0,
                                -0.47541028324265328,
                                0.22247972904121321,
                                0,
                                0,
                                0,
                                0,
                                -0.8163990916047591,
                                0,
                                -0.46463746254092519,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22965609788977692,
                                0.01328165216540611,
                                0.12324364573478302,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41845743642279448,
                                0,
                                0.85180331214848048,
                                0,
                                0,
                                0.16410662282791827,
                                0,
                                0,
                                0.060347303349293849,
                                0,
                                0.17371054405629197,
                                -0.11482962452474367,
                                0,
                                0,
                                0,
                                0.14781471060275733,
                                0,
                                0.05950904286258827,
                                0,
                                -0.16879686033215524,
                                0,
                                0,
                                0,
                                0,
                                0.078405281842651817,
                                0,
                                -0.57609252276020606,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.77889004209347146,
                                -0.11551382750671232,
                                0.11603661027168585,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34111993656568995,
                                0,
                                -0.70162485761724958,
                                0,
                                0,
                                0,
                                -0.35031689891247114,
                                0,
                                -0.33140607354321377,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.94351112449085317,
                                0,
                                0.17485655388968932,
                                0,
                                0.077952597991641337,
                                0,
                                -0.21350933715053733,
                                0,
                                0,
                                0.44680785512178778,
                                0,
                                0,
                                0.061169783135694343,
                                0,
                                0.72220025606583038,
                                -0.10311897495004939,
                                0,
                                0,
                                0,
                                0.1732914721913239,
                                0,
                                -0.42745933895278732,
                                0,
                                0,
                                0,
                                0.90052831198831162,
                                0,
                                0.65783238683430401,
                                0,
                                0,
                                0,
                                -0.21378842690382607,
                                0,
                                0.085890588947149238,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2593113980298451,
                                0,
                                0.30411687002748755,
                                0,
                                -0.11178143976191665,
                                0,
                                -0.14935130056621976,
                                0,
                                0,
                                0.17413272090151097,
                                0,
                                0,
                                0.73853170524616962,
                                0,
                                -0.25504014120755558,
                                -0.5620971489592097,
                                0,
                                0,
                                0,
                                -0.091421245261296233,
                                0,
                                0.0095546858234822341,
                                0,
                                0,
                                0.22085704579639726,
                                0,
                                0.15131561180618702,
                                0,
                                0,
                                0.46839225909880611,
                                0,
                                0,
                                -0.010836454385415605,
                                0,
                                0.064347110482616557,
                                0.15123615910193147,
                                0,
                                0,
                                0,
                                -0.80107250771245708,
                                0,
                                0.20021719396292106,
                                0,
                                0.19436712202782758,
                                0,
                                0,
                                0,
                                0,
                                -0.36770356432155638,
                                0,
                                0.61274099426918882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42263844635623704,
                                -0.38555380682179929,
                                0.35254643709538891,
                                0,
                                0,
                                0,
                                0,
                                0.10696176873033408,
                                0,
                                0,
                                0,
                                0,
                                0.17085909293841139,
                                0,
                                -0.006153528540395619,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.032010597226761521,
                                0.57231554010128527,
                                0.7942032036579838,
                                0,
                                0,
                                0,
                                0,
                                0.62402955318945419,
                                0,
                                0,
                                0,
                                0,
                                -0.048910887654010735,
                                0,
                                0.10543559657905369,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36111102268440981,
                                0.52532371897332297,
                                -0.43670584650190253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.024991886731428131,
                                0,
                                0.21268889092402279,
                                0,
                                0,
                                -0.14912804183648048,
                                0,
                                0,
                                -0.058100308481828317,
                                0,
                                -0.2934541971142095,
                                -0.019406837912833777,
                                0,
                                0,
                                0,
                                -0.28461713326986449,
                                0,
                                -0.87236753656642296,
                                0,
                                0,
                                0,
                                0.063011472870058899,
                                0,
                                0.71238938783243178,
                                0,
                                0,
                                0,
                                -0.49816096324167802,
                                0,
                                -0.50343462176044207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11972365925367684,
                                0,
                                -0.68127949496444362,
                                0,
                                0.62190817157227518,
                                0,
                                0.28533895664349851,
                                0,
                                0,
                                0.062587604317452639,
                                0,
                                0,
                                0.47437306708212501,
                                0,
                                -0.097989755934352732,
                                0.43485447680959377,
                                0,
                                0,
                                0,
                                0.32070280979848409,
                                0,
                                -0.036251765254496582,
                                0,
                                0,
                                0,
                                0.12369513785102315,
                                0,
                                0.67599733416263752,
                                0,
                                0,
                                0,
                                0.22005460208213284,
                                0,
                                -1.4452366666872718,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24947402458053905,
                                0,
                                0.46505200549573361,
                                -0.89996448003852814,
                                0,
                                0,
                                0,
                                0.6356878112111165,
                                0,
                                0.26045996296339241,
                                0,
                                0,
                                0.52263111903450188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57597998585689503,
                                0,
                                0.64082739110236264,
                                0,
                                0.051491689270811297,
                                -0.33363606525097361,
                                -0.10343796002980098,
                                0,
                                -0.58466197703395872,
                                0,
                                0,
                                0.30624765727585535,
                                0,
                                -0.21921346095417432,
                                0.60281444618861146,
                                0,
                                0,
                                0,
                                -0.16816395972788892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2617441830209673,
                                0.14712807335012906,
                                -0.64289359685545666,
                                0,
                                0.46785076581543061,
                                0,
                                0,
                                0.026967930054269423,
                                0,
                                0.15824716616775608,
                                0.34457336867281729,
                                0,
                                0,
                                0,
                                -0.36489252593751859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77949522723600206,
                                0.18121121346028896,
                                -0.35614353254998493,
                                0,
                                -0.00043018065016969809,
                                0,
                                0,
                                0.38508009379269903,
                                0,
                                -0.19873298536149953,
                                -0.18920802005050463,
                                0,
                                0,
                                0,
                                -0.095551729667491925,
                                0,
                                0,
                                0,
                                0,
                                -0.033278196603592158,
                                0,
                                0,
                                0,
                                1.0360972251431264,
                                0,
                                -0.68453702524998883,
                                0,
                                0,
                                -0.039558466743341569,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49950801218596186,
                                0,
                                -1.1718659549446113,
                                0,
                                -0.37597010278933962,
                                0.31461432537900802,
                                0.21998730715338133,
                                0,
                                0.035650812684488192,
                                0,
                                0,
                                -0.63681896735207111,
                                0,
                                -0.22365889110540782,
                                0.46886406949912862,
                                0,
                                0,
                                0,
                                -0.18602069751530476,
                                0,
                                0,
                                0,
                                0,
                                -0.38449639874616581,
                                0,
                                0,
                                0,
                                0.27942210597021244,
                                0,
                                -1.2705188337692819,
                                0,
                                0,
                                -0.72078519448492551,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29056438307309684,
                                0,
                                0.73238672603918942,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12092438118487558,
                                0,
                                0,
                                0,
                                0,
                                0.71047440725745203,
                                0.4125361057275207,
                                -0.30178313921492117,
                                0,
                                -0.40890900027143207,
                                0,
                                0.22833689697682513,
                                0,
                                0,
                                0.10841111992737035,
                                -0.30082423384848128,
                                0.2228375513877375,
                                0,
                                0.17589600609103762,
                                0,
                                0,
                                -0.0016095003129953378,
                                0,
                                -0.44689676172821019,
                                -0.32782939505616515,
                                0,
                                0,
                                0,
                                -0.71411792565443843,
                                0,
                                0,
                                0,
                                0,
                                -0.87954942245710765,
                                0,
                                0,
                                0,
                                -1.1423464692569789,
                                0,
                                -0.50101376525896557,
                                0,
                                0,
                                0.055541321236142124,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.015928061528174019,
                                0,
                                -0.41448084003836466,
                                0,
                                0.23274587480262726,
                                0.57941399094658297,
                                -0.14308818468341886,
                                0,
                                -0.59551322578760379,
                                0,
                                0,
                                -0.099584564087554436,
                                0,
                                0.13058678977021143,
                                -0.29926698026997228,
                                0,
                                0,
                                0,
                                -0.34419156530463202,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33579117085940552,
                                -0.36147127378763655,
                                0.09454723765859141,
                                0,
                                -0.098609105694043728,
                                0,
                                0,
                                -0.12368952200299235,
                                0,
                                0.76645277228602893,
                                -0.011746814378096375,
                                0,
                                0,
                                0,
                                -0.36746827656038999,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61518991398932743,
                                0,
                                0,
                                0,
                                0,
                                -0.2129432479745694,
                                -0.093148614085311332,
                                -0.4276477181455422,
                                0,
                                -0.51946737104203999,
                                0,
                                -0.33880814357009303,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22368442540023564,
                                0,
                                0,
                                0,
                                0,
                                0.20411271206294743,
                                -0.083501436687894517,
                                0.83443013599361537,
                                0,
                                -0.44808665050439012,
                                0,
                                -0.065387234718757403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.085825297801409642,
                                0,
                                0,
                                0,
                                0,
                                0.58506192270797674,
                                -0.27984324965583457,
                                -0.043876468112687056,
                                0,
                                0.37539211582842863,
                                0,
                                -0.65511826061896461,
                                0,
                                0,
                                0.034538927703593653,
                                0.42230717970436976,
                                0.56717351613769795,
                                0,
                                0.20667778125305683,
                                0,
                                0,
                                0.57135037726231763,
                                0,
                                0.18211456955604516,
                                0.25510766581629035,
                                0,
                                0,
                                0,
                                -0.17713078380374697,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15064032188558943,
                                0,
                                0,
                                0,
                                0,
                                0.22718665439039976,
                                -0.77516600382540779,
                                -0.14086682174642681,
                                0,
                                -0.019716784014280231,
                                0,
                                0.55188691863609685,
                                0,
                                -0.82200156351081888,
                                0,
                                0,
                                0,
                                0.18381127221449317,
                                0,
                                0.71029243081893312,
                                0,
                                0,
                                -0.63215880427525917,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.03505560693121347,
                                0,
                                -0.56915076340032145,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72582742664749889,
                                0,
                                0,
                                0,
                                0,
                                0.11961630830561759,
                                0.36738294648993386,
                                0.089454503929045012,
                                0,
                                0.46995472267170113,
                                0,
                                0.3082802402155419,
                                0,
                                0.42714986265723509,
                                0,
                                0,
                                0,
                                -0.77775448658335633,
                                0,
                                -0.42676748884856097,
                                0,
                                0,
                                -0.4166364527035355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1147956945366546,
                                0,
                                0.32607535065672738,
                                -0.72408714497251636,
                                0.24858862906790832,
                                0,
                                0,
                                0.31061452612252277,
                                0.036512998602063793,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52601822403514742,
                                0.15965621439422917,
                                0,
                                0,
                                0,
                                0,
                                0.052600910880418739,
                                0.10552147857768512,
                                0,
                                -0.39544567005544717,
                                -0.57285847094161513,
                                0,
                                0,
                                -0.24894808632564569,
                                -0.26634632695407001,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.077885495557656531,
                                -0.25130530269387219,
                                0,
                                0,
                                0,
                                0,
                                -0.46124911188365825,
                                -0.31712636273877259,
                                0,
                                0,
                                0,
                                -0.41482799757218214,
                                0.00533468860565358,
                                0,
                                0,
                                -0.43889248853284862,
                                -0.28010269566897489,
                                0.59128583076131347,
                                0,
                                0,
                                0,
                                0,
                                0.4551771119652811,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.06313344629312162,
                                0.40694257789327626,
                                0,
                                0,
                                -0.78137057636886931,
                                0.17060737405701445,
                                -0.37583108517860164,
                                0,
                                0,
                                0,
                                0,
                                -0.22252201682654929,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.094523972532603973,
                                -0.13732460872671542,
                                0,
                                0,
                                -0.48095290572223026,
                                0.25069370766321702,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21983844408079248,
                                -0.50835972851184075,
                                0,
                                0,
                                0,
                                0,
                                0.32700924438312251,
                                0.51415030573714937,
                                0,
                                -0.39010810789551498,
                                0.066280574040724363,
                                0,
                                0,
                                -0.36265164828748608,
                                0.45456679621873941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51644152020275624,
                                0.40551470915781646,
                                0,
                                0,
                                0,
                                0,
                                -0.22656087219615043,
                                0.15096856456178703,
                                0,
                                0,
                                0,
                                0.60240456036534773,
                                0.394325534522594,
                                0,
                                0,
                                -0.026990724280457373,
                                -0.69086389479181176,
                                0.056651757523041364,
                                0,
                                0,
                                0,
                                0,
                                0.01962846198656365,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.045860514373084527,
                                -0.70523284487907967,
                                0,
                                0,
                                -0.25327841160400238,
                                -0.46961314116375097,
                                -0.4632781580584136,
                                0,
                                0,
                                0,
                                0,
                                0.035076200661822252,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.03212063368633794,
                                0.2150425792903507,
                                0,
                                0,
                                0.12511493230179491,
                                0.13121151851846083,
                                -0.46857991566734858,
                                0,
                                0,
                                0,
                                0,
                                0.83683188738247705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15468275623462849,
                                -1.279464752370443,
                                0,
                                0,
                                0,
                                0.18392406260617092,
                                0.61287073576482065,
                                0.73123247089258192,
                                0,
                                0,
                                0.38645016809854504,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.6587510184784486,
                                0.15436979333907619,
                                0,
                                0,
                                0,
                                -0.34182593920371462,
                                0.19594526413228686,
                                0.5628423101803679,
                                0,
                                0,
                                -0.23013222890700227,
                                0.29463115269155599,
                                0.012161578396910094,
                                0,
                                0,
                                -0.4455800454010525,
                                -0.23234177447845022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49498497510852385,
                                0.53511260882636802,
                                0,
                                0,
                                0,
                                0,
                                -0.26666903129790065,
                                0.24094045091191157,
                                0,
                                -0.026514755152860267,
                                -0.60774545924517953,
                                0,
                                0,
                                0.41075383341521393,
                                -0.17724108488749407,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18041313165597211,
                                0.25355911618224142,
                                0,
                                0,
                                0,
                                0,
                                0.098687488390720293,
                                0.56853229182761333,
                                0,
                                0,
                                0,
                                -0.67668731638287982,
                                0.36780426290955304,
                                0,
                                0,
                                0.34102962719932595,
                                -0.4211765873405432,
                                -0.26782242442169202,
                                0,
                                0,
                                0,
                                0,
                                -0.20345644412857958,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3935067080673324,
                                1.0927315219029499,
                                0,
                                0,
                                0,
                                -0.47254073171963362,
                                0.82230567804277066,
                                0.56104571275072712,
                                0,
                                0,
                                -0.58227144263585506,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.078564173016312439,
                                -0.81917644081079111,
                                0,
                                0,
                                0,
                                -1.1982014685725044,
                                0.12963617705734948,
                                -0.76935978328785404,
                                0,
                                0,
                                -0.10425892940535794,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.039596393481251824,
                                -0.067942926523748004,
                                0,
                                0,
                                0,
                                1.100211284074871,
                                0.56028367715348215,
                                -0.54743498561326542,
                                0,
                                0,
                                -0.33587141152621991,
                                -0.2363000662200421,
                                -0.014499912069506196,
                                0,
                                0,
                                -0.3329116035651361,
                                -0.48854363472001439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18507048774711043,
                                0.24695523299895267,
                                0,
                                0,
                                0,
                                0,
                                0.67026077532532147,
                                -0.22351629238246851,
                                0,
                                -0.12187346560272236,
                                0.46591094475145883,
                                0,
                                0,
                                -0.0249224123026686,
                                -0.57807970246266893,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30064561062386314,
                                -0.27723478947927244,
                                0,
                                0,
                                0,
                                0,
                                -0.31002649351443612,
                                0.41220534026454009,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.053719095777541304,
                                0.20649521430499074,
                                0,
                                0,
                                0,
                                -0.42202254525069288,
                                0.90074179196897441,
                                -0.13443026809692185,
                                0,
                                0,
                                0.91426522897180718};

const double rot_26_10[1000] = {-0.51528101311854524,
                                0,
                                0,
                                0.00081372209920536334,
                                -0.25714147787351688,
                                0.02141918888490589,
                                0.81064851507418045,
                                0.10369801872954827,
                                0,
                                0,
                                0,
                                0.97312403117153101,
                                -0.86874638511416147,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42022815815255288,
                                0.35214654127457673,
                                0,
                                0.23626541444680488,
                                -0.81243304757056511,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83402841889238288,
                                -0.28817550478350107,
                                -0.044272827853360952,
                                0,
                                0,
                                -0.51351916168884315,
                                0.65142855126527766,
                                -0.42244407361306774,
                                0.2264113911640292,
                                -0.28329792888237071,
                                0,
                                0,
                                -0.70881188715399501,
                                0,
                                0,
                                0.45192369715110148,
                                0.27714068076255399,
                                -0.28391795248431506,
                                -0.36348788115839159,
                                0.061732326677656976,
                                0,
                                0,
                                -0.018400946406052027,
                                0,
                                0,
                                0.3075996339245245,
                                -0.094726315074624076,
                                0.14648204436397325,
                                0.073340035651947438,
                                -0.93232775645840604,
                                0,
                                0,
                                -0.2777500446718455,
                                0,
                                0,
                                -0.21222362415869589,
                                0.39740809806359567,
                                0.84481881533890091,
                                -0.075398433990313402,
                                0.021888239499718548,
                                0,
                                0,
                                -0.39067559524333506,
                                0,
                                0,
                                -0.62642316284318511,
                                -0.5155636477155574,
                                -0.072780486410515072,
                                -0.38522687150892915,
                                -0.18831883536791116,
                                0,
                                0,
                                0,
                                0.29863721891338568,
                                0.23845757731397005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33263104127921322,
                                -1.1665100747963759,
                                0,
                                -0.50710126010755829,
                                -0.38832779020405078,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15654722602274368,
                                -0.1085203303078458,
                                -0.90515553942720695,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2351531043793407,
                                0.68725966961556806,
                                0,
                                -0.58082694516849298,
                                0,
                                0.069682548386355458,
                                0.68199031457038217,
                                -0.0018491217811895111,
                                -0.52744575357558754,
                                -0.49258753713209091,
                                0,
                                0,
                                0.095857338417225629,
                                0,
                                0,
                                0.15196872239968578,
                                -0.22797634014716384,
                                0.45079264410672742,
                                0.029247019240903255,
                                -0.46534154276501544,
                                0,
                                0,
                                -0.71015501702598405,
                                0,
                                0,
                                0.37060168386658476,
                                0.53390669123457724,
                                0.37980363915356369,
                                0.6396591191324249,
                                0.12362994304893685,
                                0,
                                0,
                                0.094334941290881408,
                                0,
                                0,
                                0.47783694166759738,
                                -0.41911520996313628,
                                0.41391711606170628,
                                -0.23029704041348714,
                                -0.15278324856212958,
                                0,
                                0,
                                0.59017579679453536,
                                0,
                                0,
                                -0.22308262678853982,
                                -0.13832141708073886,
                                -0.28739360345589565,
                                0.50805638759103589,
                                -0.70781614661621395,
                                0,
                                0,
                                0.2989669772932419,
                                0,
                                -0.25391088352044122,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68130361091702685,
                                -0.77163781899956974,
                                0,
                                0.53819428278952797,
                                -0.0023142926172313519,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.003241281909790221,
                                0.19323864718129918,
                                0,
                                0.27856846481955899,
                                0,
                                -0.74606316125427674,
                                0.055400997956480597,
                                0.63135513475175653,
                                -0.02497559641067687,
                                0.034409091372914716,
                                0,
                                0,
                                0.19975839577377824,
                                0,
                                0.24900272087294295,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34705359650768464,
                                1.1048461386502144,
                                0,
                                0.3297632837048125,
                                0.25874442606811765,
                                -0.66990476592543624,
                                0,
                                0.14149076683672546,
                                -0.4118516278873956,
                                0,
                                0,
                                0,
                                0.10093579157375951,
                                -0.53333806544714446,
                                -0.2588629512014709,
                                0.40335156119735777,
                                0,
                                -0.55469592077145646,
                                -0.4296704631628826,
                                0,
                                0,
                                0,
                                -0.20400142923390804,
                                -0.48618580399919487,
                                0,
                                0,
                                0.86772329084870725,
                                0,
                                0,
                                0.12475018496502238,
                                -1.1242335154919256,
                                0.11558711029587004,
                                0,
                                0,
                                -0.36649540219377669,
                                0.016437477852421514,
                                0,
                                0.32200740527192123,
                                0.59726811175053185,
                                0,
                                0,
                                0,
                                -0.18429676851528434,
                                -0.60912040209099638,
                                0.016600339539558875,
                                0.091156279476589733,
                                0,
                                0.48891617529872361,
                                -0.34896960450664788,
                                0,
                                0,
                                0,
                                -0.78075385273871201,
                                0.14498127994522314,
                                0,
                                0,
                                0.50274654661554841,
                                0,
                                0,
                                -0.095448814536165244,
                                0.7081042394616911,
                                0.58961498748847818,
                                0,
                                0,
                                0,
                                0,
                                0.11082857148688101,
                                0,
                                0,
                                0.81589930559272028,
                                0.17142851173442189,
                                -0.24616554118652703,
                                0,
                                0,
                                0,
                                0,
                                -0.25244576383864903,
                                0,
                                0,
                                0.74556905077318902,
                                -0.46597188438402731,
                                0.56631775217877067,
                                0,
                                0,
                                0.068144231138085598,
                                -0.49265884006676031,
                                0,
                                -0.57290517189593504,
                                0.33739620061310421,
                                0,
                                0,
                                0,
                                -0.54017419362779251,
                                0.13710922445979651,
                                0.85252754039651879,
                                0.37046286184711125,
                                0,
                                -0.036669699694201335,
                                0.23111977699921371,
                                0,
                                0,
                                0,
                                -0.11342550831689915,
                                -0.26139567082248027,
                                0.6793267853250311,
                                0,
                                0,
                                0,
                                0.035252674718165011,
                                -0.21402055147313367,
                                0.41861748875981042,
                                0.31034496428750957,
                                0,
                                -0.46894879513452581,
                                0,
                                0.085790719519876629,
                                0.51097114656217635,
                                -0.58048924428929527,
                                0,
                                0,
                                0,
                                0,
                                -0.4251637417899235,
                                0,
                                0,
                                0.71682162051399012,
                                1.0764809126953374,
                                0.45014399417498674,
                                0,
                                0,
                                0,
                                0,
                                -0.21120442988173926,
                                0,
                                0,
                                -0.4207838266486118,
                                -0.13348015835598687,
                                0.48537907660300361,
                                0,
                                0,
                                0,
                                0,
                                -0.35831229796902764,
                                0,
                                0.14703076053288747,
                                0,
                                0,
                                0,
                                -0.057053999262399076,
                                -0.082464797518966126,
                                -0.0026169876046425455,
                                -0.91516762221384484,
                                0,
                                -0.36164586050828368,
                                0.52324399023357504,
                                0,
                                0,
                                0,
                                0.55826576647165671,
                                0.23529228828593965,
                                -0.57788641850764033,
                                -0.031799184407730989,
                                0,
                                0.15565570634848547,
                                0.24332976647805557,
                                0,
                                0,
                                0,
                                -0.77986231231558234,
                                0.18258069886963263,
                                -0.50759552488175907,
                                0.1336249324779043,
                                0,
                                -0.15414554004605843,
                                0.317866376331779,
                                0,
                                0,
                                0,
                                -0.20918500666662945,
                                -0.63916102826460675,
                                0.0092046976029249994,
                                -0.13681084805000854,
                                0,
                                0.65412066557263782,
                                0,
                                0.68133656431566136,
                                -0.84791318931394732,
                                0.19893898482020206,
                                0,
                                0,
                                0,
                                0,
                                -0.14399611851494909,
                                0,
                                -0.28786175922648138,
                                0,
                                0,
                                0,
                                0.17859963856310349,
                                -0.67094691901704451,
                                -0.48276484280317028,
                                0.16902723904731387,
                                0,
                                -0.41645636932933533,
                                -0.67486204576796205,
                                0,
                                0,
                                0,
                                -0.52728370225821541,
                                0.38223004608316935,
                                0.28699967526785264,
                                -0.027335059657399796,
                                -0.19317683426250043,
                                0,
                                0,
                                -0.31561989363545057,
                                1.2187008618580206,
                                0.75419894229094964,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30227405772273885,
                                0,
                                -0.50403257771999765,
                                -0.23151754392142809,
                                -0.17631337515622778,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2072181103632258,
                                0,
                                -0.83801102440265807,
                                -0.09710219711744171,
                                0.31347362059256367,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.029861863212851975,
                                0.059649127190068152,
                                0,
                                0,
                                0,
                                0.51816707970413745,
                                0.59381116875799322,
                                0.27250682917059788,
                                -0.54761232859661546,
                                0.034553156425893274,
                                0,
                                0.12334570123462166,
                                0,
                                0,
                                0,
                                0.063981712496799514,
                                0.21431854926853172,
                                0.53593159853274008,
                                0.60644451399620625,
                                0.52892543050074237,
                                0,
                                0.10979533229885044,
                                0,
                                0,
                                0,
                                0.24421932787953723,
                                -0.2261578831785139,
                                0.52799795955702222,
                                0.21364529476819494,
                                -0.74345703271856711,
                                0,
                                0.69711458832938222,
                                0,
                                0,
                                0,
                                -0.52314523107501287,
                                0.42906081158832998,
                                -0.048808007672746956,
                                0.0072496845648854225,
                                -0.23199646195949053,
                                0,
                                -0.16662915272551915,
                                0,
                                0,
                                0,
                                0.34067154621903895,
                                0.46916466086474734,
                                -0.52438961587384014,
                                0.53469777783673722,
                                -0.27418235026075838,
                                0,
                                0,
                                0.67240005207872033,
                                -0.6195985598988335,
                                0.8308328537502454,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.016699426337292343,
                                -0.48581863944181564,
                                0,
                                -0.3899253785876125,
                                0,
                                -0.23179044138373894,
                                -0.48129220134390427,
                                0,
                                0,
                                -0.54591471355198329,
                                0.16895733911356542,
                                0,
                                -0.2434066796033372,
                                0,
                                0.54103220486923653,
                                0,
                                0,
                                -0.022585634189042993,
                                0.95974043764109929,
                                0,
                                0,
                                -0.17130687035422429,
                                0,
                                -0.21681709619036682,
                                0,
                                -0.64429838029711595,
                                0.24352580640382959,
                                0,
                                0,
                                0.16513771462907853,
                                -0.64957572071158842,
                                0,
                                -0.37713824994328116,
                                0,
                                -0.26292165583078553,
                                0,
                                0,
                                -0.47253249645664597,
                                -0.59558136445781473,
                                0,
                                0,
                                0.63919380717510288,
                                0,
                                -0.25019453775262751,
                                0,
                                0.21054454206379616,
                                -0.17839247006864295,
                                0,
                                0,
                                -0.47095711279378094,
                                -0.48050025024618692,
                                -0.5482643695685524,
                                0,
                                -0.10668559379077902,
                                0,
                                0.66690524718205302,
                                0.27584834958213411,
                                0,
                                0,
                                -0.085958533676822546,
                                -0.39972562457402938,
                                0,
                                -0.37354403693994059,
                                0,
                                -0.4573205885789563,
                                0,
                                0,
                                1.1730930853663752,
                                0.53727909372623395,
                                0,
                                0,
                                0,
                                0.39586127772541163,
                                0,
                                -0.35068812332295224,
                                0,
                                0,
                                -0.65588997971956475,
                                0.32183723481453341,
                                0,
                                0,
                                -0.10405270754673207,
                                0,
                                0.76511927652805567,
                                0,
                                -0.18370453001090276,
                                0.17525896838748892,
                                0,
                                0,
                                -0.56899708785284597,
                                -0.12467870870995806,
                                -0.12101527888302133,
                                0,
                                0.37624714746337073,
                                0,
                                0.091180157771904025,
                                -0.75526227709073313,
                                0,
                                0,
                                0.34894054385611001,
                                -0.37854848406558889,
                                0.065211800989591173,
                                -0.49015284212864468,
                                -0.31281325802244014,
                                -0.59275104457060879,
                                0,
                                0.1010808395341225,
                                0.54412713680703417,
                                0,
                                0,
                                0,
                                -0.16629386763381951,
                                -0.22799468797567532,
                                -0.67400858793561658,
                                0.097066514239727467,
                                0,
                                0.40342094435691811,
                                -0.54213174478056203,
                                0,
                                0,
                                0,
                                0.37238863009967699,
                                0.61899723231215631,
                                -0.02427517026533875,
                                -0.56492351284051667,
                                0,
                                0.35392833765448045,
                                -0.18214282065465362,
                                0,
                                0,
                                0,
                                0.23538529483727116,
                                0.41238639692994056,
                                -0.65686985907148843,
                                0.29364026349909245,
                                0,
                                -0.36356180581536551,
                                0.35306007965977887,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18743564131774962,
                                0,
                                0,
                                0.762038942591868,
                                -1.2532196393541339,
                                -0.22639773843211286,
                                -0.066017680764650588,
                                -0.075323412050966709,
                                -0.10126622640972607,
                                -0.44470185291162345,
                                0,
                                -0.75362868180654274,
                                -0.4625983925476756,
                                0,
                                0,
                                0,
                                0.87730035197325296,
                                -0.385843081086235,
                                0.074418712264781417,
                                0.19000361386795803,
                                0,
                                -0.040442065342768646,
                                -0.19543318689072697,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.011425766227356915,
                                0,
                                0,
                                -0.94972936691061882,
                                -0.66623012253209268,
                                0.22559398514252488,
                                0,
                                0,
                                0,
                                0,
                                0.42828951995489278,
                                0,
                                0,
                                -0.14832511563080764,
                                0.16883886132843026,
                                -0.34782752691522434,
                                0,
                                0,
                                0,
                                0,
                                -0.7321106306030486,
                                0,
                                0,
                                0.47399000561020843,
                                -0.098025674358343806,
                                0.87935354226957185,
                                0.17342673223057681,
                                0.52538800006411934,
                                -0.47415244517422889,
                                0,
                                -0.14707897367274947,
                                0,
                                0.62071704080577905,
                                0,
                                0.24929542199654711,
                                0,
                                -0.1826558657742933,
                                -0.53174606799855806,
                                -0.75815037424548049,
                                0,
                                -0.29635347043493782,
                                0,
                                -0.10961281335037304,
                                0,
                                -0.096180120650459083,
                                0,
                                0.75026325855700959,
                                0.10148989350403141,
                                -0.21904050702114969,
                                0,
                                0.17016595631841919,
                                0,
                                -0.19878070191049296,
                                0,
                                -0.55709593475279229,
                                0,
                                0,
                                0,
                                0,
                                0.10451896183211923,
                                0,
                                -0.93843482073176776,
                                0,
                                0.76916966061065273,
                                0,
                                0.16718692584791894,
                                0.52346705082158551,
                                -0.1394358020046742,
                                0.1711870324396646,
                                0,
                                -0.58831764309927093,
                                0,
                                -0.24582553652050129,
                                0,
                                0.5202759461675055,
                                0,
                                0,
                                0,
                                0,
                                -0.49548171353158138,
                                0,
                                0.17762193941101226,
                                0,
                                0.41418820644032905,
                                0,
                                -0.71766111819778111,
                                -0.055930816056200289,
                                0.31351122133574172,
                                -0.35084202964998012,
                                0,
                                0.43991496891154669,
                                0,
                                -0.60179551246465657,
                                0,
                                0.46883825510286131,
                                0,
                                0,
                                0,
                                0,
                                -0.26406870868475513,
                                0,
                                0.52929154627980801,
                                0,
                                0.95142932315880502,
                                0,
                                0.061825894917150098,
                                -0.31067513036116207,
                                0.55962643012023883,
                                0.0036871677801797245,
                                0,
                                -0.56740031223153919,
                                0,
                                -0.37495811195720774,
                                0,
                                -0.35741981875205425,
                                0,
                                0,
                                0,
                                0,
                                -0.5683613609049234,
                                0,
                                -0.23068028355488923,
                                0,
                                -0.028026769535725842,
                                0,
                                -0.54190504643849002,
                                -0.22216457089635902,
                                -0.1460890577749224,
                                0,
                                -0.084177098464635169,
                                0.93440590104358812,
                                0,
                                0,
                                -0.072287412466877504,
                                0.20946419461261287,
                                0,
                                0.34639181166143518,
                                0.6453593437714199,
                                0,
                                0.4150382606945624,
                                0.13929557944598431,
                                0,
                                0,
                                0.25927188230103337,
                                0.4523738553180876,
                                0,
                                0,
                                0,
                                -0.64438319739647232,
                                0,
                                0,
                                -0.67870115268971976,
                                -0.64966113931911973,
                                0,
                                0,
                                0.15704181241449261,
                                -0.030603151806639528,
                                -0.58392647215992444,
                                0,
                                0.15715782350584045,
                                -0.10422607209220497,
                                0,
                                0,
                                0.7143904797850934,
                                0.33492970756552459,
                                0,
                                -0.50230571397157464,
                                0.36227016426621755,
                                0,
                                0.094737109405723371,
                                0.11209815408729237,
                                0,
                                0,
                                0.53195448590802985,
                                -0.55850927178340237,
                                0,
                                0,
                                0,
                                0.54376555058958098,
                                0,
                                0,
                                0.48907515993612427,
                                0.46493927063061058,
                                0,
                                0,
                                0.38759242970316149,
                                0,
                                0,
                                0.36072030304074376,
                                0,
                                0,
                                0.051458699461751634,
                                0.50013039520211322,
                                0,
                                0,
                                0.96461363896422481,
                                -0.039020180003322052,
                                0.28031509369250063,
                                0,
                                -0.86662186729903767,
                                -0.090927232092355786,
                                0,
                                0,
                                0.26311728983568661,
                                0.30227296136662413,
                                0,
                                0.7588711739260211,
                                -0.10669093704207944,
                                0,
                                -0.1896056327886706,
                                0.27529170320262525,
                                0,
                                0,
                                0.25493642374363479,
                                -0.48580159257523658,
                                0,
                                0,
                                0,
                                0.028289887553701154,
                                0,
                                0,
                                0.47590458665354862,
                                -0.35961528546556798,
                                0,
                                0,
                                -0.27907759348270028,
                                0.052509359899261462,
                                -0.64981092511429606,
                                0,
                                0,
                                0.58738907733978785,
                                0,
                                -0.025019586454827464,
                                0,
                                0.46746244959863181,
                                0.1039974954307116,
                                -0.22916596168233361,
                                -0.41046119175815321,
                                0,
                                0,
                                -0.6496377927528596,
                                0,
                                -0.45625746464649986,
                                0,
                                0.30078154904161736,
                                -0.24152618078451374,
                                0,
                                0,
                                -0.9397170225576239,
                                -0.59810693620775957,
                                0,
                                0.030811933300359459,
                                0,
                                0.89860140657680088,
                                0,
                                0,
                                0,
                                0,
                                -0.76908497702901935,
                                -0.70074127252557938,
                                0,
                                -0.1659057496628788,
                                0,
                                -0.47103022297944841,
                                0,
                                0,
                                0.71757669222606557,
                                0.03184014944981349,
                                0,
                                0,
                                -0.38360070305110233,
                                0,
                                0.17330933741380833,
                                0,
                                0.36157269333594555,
                                0.41970162886816303,
                                0,
                                0,
                                0.39539516624589283,
                                -0.21661884211311733,
                                0,
                                0.29999235304211863,
                                0,
                                0.56717237628320383,
                                0,
                                0,
                                0.62574206076153072,
                                -0.20785953460223966,
                                0,
                                0,
                                0.079680701928866809,
                                0,
                                -0.092788374198075479,
                                0,
                                -0.31489388148649566,
                                -0.67165797399049987,
                                0,
                                0,
                                -0.13168145315815849,
                                0.86306318504658308,
                                0,
                                0.23843881707373474,
                                0,
                                -0.093993222149534622,
                                0,
                                0,
                                0.027975158691238323,
                                -0.51347350938535019,
                                0,
                                0,
                                -0.1227358385006439,
                                0,
                                -0.090346498346375828,
                                0,
                                -0.67903718048205763,
                                0.50124273297750899,
                                0.19358120723146713,
                                0.31842258961955855,
                                0,
                                0,
                                0.25373649787815844,
                                0,
                                -0.86278319852868612,
                                0,
                                0.0049856123503837224,
                                0.2287606965311364};

const double rot_26_100[100000] = {-0.56980495617504912,
                                   0,
                                   0.7157913099721086,
                                   1.4394268328439535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42942198760655137,
                                   0,
                                   0.30356204943889614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061703477268952422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41592645923059895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13177549877239117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058220101428148589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11932506808834233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35002042455526355,
                                   0,
                                   0,
                                   0.24088225426057525,
                                   0,
                                   0,
                                   -0.068049228594941336,
                                   0,
                                   -0.34956775155944181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15633409181875776,
                                   0,
                                   0,
                                   0.66570906488621062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092538528665970038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092049938947662752,
                                   1.3294459468024173,
                                   0,
                                   -0.94571256627895584,
                                   0.85347508712485054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1134011244385312,
                                   0,
                                   0.19058307602103952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28431725609867892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37807083575593448,
                                   0,
                                   -0.29439540362338645,
                                   0.031301416542982491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60908019643899269,
                                   0,
                                   -1.058476754787222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2551123809453282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37428045550349254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0015932901667776028,
                                   0,
                                   0,
                                   0,
                                   -0.066962870117139667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089909142666005221,
                                   0,
                                   0,
                                   0,
                                   1.0236412236168797,
                                   0,
                                   0,
                                   -0.67710548005435978,
                                   0,
                                   0,
                                   0,
                                   0.38413560684805753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38128552715243347,
                                   0,
                                   -0.25604082705501502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20756788969469203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071954824516447788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068779088876419731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59908662618222286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19497071419611345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36223534541154073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14058324999414407,
                                   0,
                                   0,
                                   0.27218419552828277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39970417517709966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36730057535634159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27099465464613043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10743209713848702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29485338546088746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42375990866051821,
                                   0,
                                   0,
                                   0,
                                   -0.44961144276792764,
                                   -0.14304335698599105,
                                   0,
                                   0,
                                   -0.4605613089267982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71262258171926229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17384372299011777,
                                   0,
                                   0,
                                   -0.38771166735342061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51418745666707011,
                                   0,
                                   0,
                                   0,
                                   0.60506847741545577,
                                   0,
                                   0,
                                   -0.52530171989398255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65605780493994681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14570073642656645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35357020670265349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14912853304363199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022607499165809009,
                                   0,
                                   0,
                                   -0.012471339477387787,
                                   0,
                                   0,
                                   -0.27262249105895553,
                                   0,
                                   -0.40920774309564778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26738162103297286,
                                   0,
                                   0,
                                   0.22461635498172017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026226234201748577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18982717146714553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3581390951336535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090862856430693154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4684300455374763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37425214098175952,
                                   -0.015555749575369121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11373717412620649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40530392473731097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2099311992052077,
                                   0,
                                   0,
                                   0,
                                   0.43494699059917197,
                                   -0.017963765813296624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10823664717653841,
                                   0,
                                   0,
                                   0,
                                   -0.206801697188847,
                                   0,
                                   0,
                                   0,
                                   -0.092592706915894732,
                                   0,
                                   0,
                                   -0.17294897136573237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099806511457748631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20217772958884597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44095104349497916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0029723351102261542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16832908509765074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55334254434952468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64820378634209019,
                                   0,
                                   -0.0050366147735327327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26563058643498505,
                                   0,
                                   0.10459832137711403,
                                   0,
                                   0,
                                   0.70764854501039631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61269115566344112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081446042651978759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11271076417937442,
                                   -0.33834537998133768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47030298557826966,
                                   0.084900073805918422,
                                   0.078787811763393931,
                                   -0.15933907289855798,
                                   0,
                                   0,
                                   -0.41975189178665823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21641722599919017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7728532031956129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32761663131670593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57203063523936926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23341619997407989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8001369486198624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066866494963773976,
                                   0,
                                   0,
                                   0,
                                   1.0342955596855532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14183751151308155,
                                   0,
                                   0,
                                   -0.013800422075698562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078643315303489808,
                                   0,
                                   0.16374752704376949,
                                   0,
                                   0,
                                   -0.021287003377434999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33994334515813379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36626317281263193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12047227657922188,
                                   -0.40104871444693713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091660139404762322,
                                   0.095300122461049769,
                                   0.57319627077105773,
                                   -0.086682540152908036,
                                   0,
                                   0,
                                   0.51128526895477799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62559015198919288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52835255999103914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25851317955721786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29729354026987392,
                                   0,
                                   0,
                                   0,
                                   0.54305964694512454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64473267806013179,
                                   0,
                                   0,
                                   0,
                                   0.091289309933442253,
                                   0,
                                   0,
                                   0.56299547294454599,
                                   0,
                                   0,
                                   0,
                                   0.101600943446813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2370092146596581,
                                   0,
                                   -0.24334155432685986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.402192869607649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28566996260277056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11319382836540781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079205824586913665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34502850084387193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37923929560934694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42360541723182704,
                                   0,
                                   0,
                                   0.46965424905240422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37288211188503756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095703173212500214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29702243588871224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39033669873494509,
                                   0,
                                   0.062320193522691789,
                                   0,
                                   0,
                                   0.17508343087461586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11567984257163326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056104734975919279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21771480477582167,
                                   -0.30589997436883515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22235793157522254,
                                   -0.088443185790832879,
                                   0.2763725421386003,
                                   0.20312090514503095,
                                   0,
                                   0,
                                   0.10434959952859141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96695133871065975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073766135514637385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079923582387497527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22210150808246912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20738612484980229,
                                   0,
                                   0,
                                   0,
                                   0.48252063867030265,
                                   0.21523988051073786,
                                   0,
                                   0,
                                   -0.30708105284153164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59685724799779949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25646714970729811,
                                   0,
                                   0,
                                   -0.24815822174951591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1454916543346603,
                                   0,
                                   0,
                                   0,
                                   0.35766973398489155,
                                   0,
                                   0,
                                   0.081091947893688454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17336173391089396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31149323677317775,
                                   0,
                                   0,
                                   0,
                                   -0.10576858028465712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60305318294965993,
                                   0,
                                   0,
                                   0,
                                   -0.22124322204637381,
                                   0,
                                   0,
                                   -0.85783447026770754,
                                   0,
                                   0,
                                   0,
                                   -0.022377939523076144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028323017869213332,
                                   0,
                                   0.55215711486609231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4126719786978042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49141266884230811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19043803643898655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02781255362754112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38376334927850692,
                                   0.0042818415608555926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11886440644347274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10377142766795833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052945000098950153,
                                   0,
                                   0,
                                   0,
                                   -0.28959512679544142,
                                   -0.54256783869465264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24464418619106126,
                                   0,
                                   0,
                                   0,
                                   -0.16856320738521785,
                                   0,
                                   0,
                                   0,
                                   -0.27756490251150207,
                                   0,
                                   0,
                                   0.054115879287107566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67366789187906251,
                                   0,
                                   -0.73617124790018473,
                                   0.18190297558520108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83437178146482316,
                                   0,
                                   0.67592947664805547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76605437863277537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63781416229630961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1741067763449676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27376250985564676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25299647805308123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12464083692600106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12351825446453492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16567041327778415,
                                   0,
                                   0.60472143326004502,
                                   0,
                                   0,
                                   0,
                                   -0.24549334630322947,
                                   0,
                                   -0.0071088056950772138,
                                   0.47967258133504775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.161014160112964,
                                   0,
                                   0.44996042113867707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1674695875502451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10038445714627736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28320684333996682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31309171052809742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42957555269685083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84053553089589905,
                                   0,
                                   0,
                                   0,
                                   0.069412763608813877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47018685623606893,
                                   0,
                                   0,
                                   0.18707628544257066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85100359443138118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019377364467294579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11598343552177515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24809856037364841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1343469950335901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029595065345024284,
                                   0,
                                   0,
                                   0.26156527173335881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11198757287674173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31642627685262653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020103918283338733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23431379423420318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10514028248719143,
                                   0,
                                   0,
                                   0,
                                   -0.80226932378329607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21449698224990713,
                                   0,
                                   0,
                                   0,
                                   0.11184287524963696,
                                   0,
                                   0,
                                   0.58889190532367497,
                                   0,
                                   0,
                                   0,
                                   0.78059921787737085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05895982530305291,
                                   0,
                                   0.37842679232239085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22735085771264607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57519929387386559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41432206364405766,
                                   0,
                                   0,
                                   0.55215093254274206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065653210130778267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20330627806938256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38336478828135739,
                                   0,
                                   0,
                                   0.57018095422920534,
                                   0,
                                   0.65619237260334973,
                                   -0.43351057190041431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47627343198157496,
                                   0,
                                   0.53898452308646383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66314372548826916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48174484420532143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10260471353041781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30821999495772279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085795005747060865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49706148550918317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066923763540306158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036076978145006648,
                                   0,
                                   0.63417928906972776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38046140486083674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30015309347317398,
                                   0,
                                   0,
                                   0,
                                   0.08004559545176658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24510406536304008,
                                   0,
                                   0,
                                   0,
                                   0.099068979997657514,
                                   0,
                                   0,
                                   0.26859556758002334,
                                   0,
                                   0,
                                   0,
                                   -0.32207945122161974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71077044105108855,
                                   0,
                                   0.18251196822697496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57930493343993483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024195783359448442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020579315016618357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023230439063901077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35754319669095147,
                                   -0.41197613251162568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27071109827006157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18495660691133106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24169284542676389,
                                   0,
                                   0,
                                   0,
                                   -0.03992978651071856,
                                   0.33402600177019831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065530791760694942,
                                   0,
                                   0,
                                   0,
                                   -0.19208690070208922,
                                   0,
                                   0,
                                   0,
                                   -0.022275327317466176,
                                   0,
                                   0,
                                   0.61654314090656637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27709697678414824,
                                   0,
                                   0.3447364051688343,
                                   0,
                                   0,
                                   -0.09917091348661719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13265499404665526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78370464587365529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53646307772977686,
                                   -0.26953567802570583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53219986537590458,
                                   0.098822207354217775,
                                   -0.27352984946148334,
                                   0.18301465949755538,
                                   0,
                                   0,
                                   -0.041895651827318317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096480490865364824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50677442830900299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16681233474884999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0091505729070019415,
                                   0,
                                   0,
                                   0,
                                   0.2559292272066423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018643063989145822,
                                   0,
                                   0,
                                   0,
                                   -0.22758531052837322,
                                   0,
                                   0,
                                   -0.43006524304467397,
                                   0,
                                   0,
                                   0,
                                   0.45004035858827368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87082607198449224,
                                   0,
                                   -0.7631847898841424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17816109311671507,
                                   0,
                                   0,
                                   -0.2729166979143488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44276867967702843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1885486747978459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11541388045137912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50599426725732355,
                                   0,
                                   0,
                                   0.33726235655876052,
                                   0,
                                   0,
                                   0.16884033917076291,
                                   0,
                                   0.24797884865429143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11056505889797054,
                                   0,
                                   0,
                                   0.117177585571895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14553223624576955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4167611905772956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11153534052337177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82658090154027497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54394023955120419,
                                   0,
                                   0,
                                   0,
                                   0.30874793040995352,
                                   -0.47323982524004199,
                                   0,
                                   0,
                                   -0.012380558684444778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20272097525313573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39334105867609931,
                                   0,
                                   0,
                                   0.37214410164251449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35772315013731587,
                                   0,
                                   0,
                                   0,
                                   -0.094164699452268255,
                                   0,
                                   0,
                                   0.61078280710203114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60964134346736432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12867226500358178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31694457755567662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66426380787575734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096313480083494926,
                                   0,
                                   0,
                                   0,
                                   0.58505149339777607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75183792352947243,
                                   0,
                                   0,
                                   -0.31817148975165266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74136792575771071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48538005465737177,
                                   0,
                                   0,
                                   0,
                                   0.037630552202558114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24909280770685086,
                                   0,
                                   0,
                                   0,
                                   0.35042023236207265,
                                   0,
                                   0,
                                   0.018483380553167644,
                                   0,
                                   0,
                                   0,
                                   -0.26472078292454043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59377380601946972,
                                   0,
                                   -0.051786974507455036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045419123870191702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23765362590792422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23791948755758338,
                                   0,
                                   0,
                                   -0.015693946415604603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93078012588394643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074016523368707968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1218141334449051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047452262783771973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29913408358681426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51688660246234008,
                                   0,
                                   0,
                                   0,
                                   0.59564704720267325,
                                   0.14573783821559791,
                                   0,
                                   0,
                                   0.53647531065065024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12533736353256059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16892577708417569,
                                   0,
                                   0,
                                   -0.88076269239307581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15897782405203187,
                                   0,
                                   0,
                                   0,
                                   0.47684646867670533,
                                   0,
                                   0,
                                   -0.22195860070948975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21460476661216837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25073540948176026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24560237031946314,
                                   0,
                                   0,
                                   0,
                                   0.24001566775531682,
                                   0.39849251376884198,
                                   0,
                                   0,
                                   -0.47881316799742657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32343761434541951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40749611841016598,
                                   0,
                                   0,
                                   -0.92399451785260589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2400596338197942,
                                   0,
                                   0,
                                   0,
                                   -0.61075061491148563,
                                   0,
                                   0,
                                   0.52630870584148015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15944788013638031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54026037249667047,
                                   0,
                                   0,
                                   0.68645610226762221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016944844450994812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31438037716614609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33518796784598426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2165088152333616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15203869479865068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50009715573899727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023097654550193726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28843293487693356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2269061168011724,
                                   0,
                                   0,
                                   0.15655174076774339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32635728022856486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52812507325747893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36710208760492091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79308089987535368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041022746428591501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063240056925934859,
                                   0,
                                   0,
                                   0,
                                   -0.35636975061537651,
                                   0.22076171147713392,
                                   0,
                                   0,
                                   0.026466398564428686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69918673824608724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69373272017608445,
                                   0,
                                   0,
                                   0.216488904776175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40161913125797649,
                                   0,
                                   0,
                                   0,
                                   0.67600702312583227,
                                   0,
                                   0,
                                   0.44339024762855989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29654806376536574,
                                   0,
                                   -0.016350466906804244,
                                   0,
                                   0,
                                   -0.094103939628115946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13760044513183378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19380971613150746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10182733476974135,
                                   -0.11922182418965736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081362787634457506,
                                   0.11830685427396857,
                                   0.16098156942874234,
                                   1.2227554630058708,
                                   0,
                                   0,
                                   0.19984881617397712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42543004972993365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24954968904609962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20167782284721159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36761092283818325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16823307177027286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016008124779430026,
                                   0.051507360740402075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062586810738997495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055387648021712102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34818582863526659,
                                   0,
                                   0,
                                   0,
                                   -0.67053842708350075,
                                   0.22128779530582765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17542840567571555,
                                   0,
                                   0,
                                   0,
                                   0.041579510970455202,
                                   0,
                                   0,
                                   0,
                                   0.26448415377969525,
                                   0,
                                   0,
                                   -0.25241323139402588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10534641600309425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34636333760754223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060148682409300568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37551228356726679,
                                   -0.15184098880670643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26908407913986071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044371036533960122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42758616627932489,
                                   0,
                                   0,
                                   0,
                                   -0.12301674799169253,
                                   -0.23341188235516575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1056455464555779,
                                   0,
                                   0,
                                   0,
                                   -0.084096826131712113,
                                   0,
                                   0,
                                   0,
                                   0.56404927801839777,
                                   0,
                                   0,
                                   -0.19505771733223151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16994886091781422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26672515875842961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41876906487628396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16876187308609752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24877483435644129,
                                   0,
                                   0,
                                   -0.034794711410019816,
                                   0,
                                   0,
                                   -0.11088965808070758,
                                   0,
                                   0.10998752595722686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32034347432223709,
                                   0,
                                   0,
                                   0.18535700820415191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073091689446462452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68287191732354913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38672963328035531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23363193946165883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34787765324584746,
                                   0,
                                   0,
                                   0,
                                   0.12686860653028195,
                                   0.046763733136676491,
                                   0,
                                   0,
                                   -0.48575727291574466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46879052076606509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51212954551551804,
                                   0,
                                   0,
                                   0.73609014309736587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39131865908404839,
                                   0,
                                   0,
                                   0,
                                   0.69223797792635533,
                                   0,
                                   0,
                                   0.6038380663015942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17347928490476008,
                                   0,
                                   -0.17636990033670677,
                                   0,
                                   0,
                                   0.80294707706189505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076052580618030857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41925502478269577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56732838585720247,
                                   0.22855018518033854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04962976729169196,
                                   0.16006968331591853,
                                   -0.85192652937010216,
                                   0.007799903636865918,
                                   0,
                                   0,
                                   0.5491340739437629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1598978933954972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29197632382015692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069913923868093503,
                                   0,
                                   -1.0179261098011232,
                                   0,
                                   0,
                                   0.64694576049248043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1991333958092254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23646860262128838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53599988809124011,
                                   -0.28474180887540956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53011401415825077,
                                   0.032253636313397199,
                                   0.41289235979347438,
                                   -0.20444018309984907,
                                   0,
                                   0,
                                   0.48222567116561166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1839290463117281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28723688653588131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075797475565624661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26812928579440826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61803973625138842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18126805309320612,
                                   -0.42496621696965514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19861390234784407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16004112957913014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16225062818616653,
                                   0,
                                   0,
                                   0,
                                   0.13089394908626539,
                                   0.22776200606048308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23072903358986491,
                                   0,
                                   0,
                                   0,
                                   0.12275866387263198,
                                   0,
                                   0,
                                   0,
                                   -0.043774496711484673,
                                   0,
                                   0,
                                   -0.310350557422924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13763827265911369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51229147870412706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18298020498672152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65034391076920595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11622377831884068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36615688357076237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33621863668918273,
                                   0,
                                   -0.039527045992496346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16417593459150565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45216555045665274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21618134045521026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35556132099168364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37171607589244859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35989098343019615,
                                   0,
                                   0,
                                   -0.24613599107323683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22188497810905916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13047953650245664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44821781808143502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48452679139198618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92815867109426775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32457679723034066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59297179460432925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34553302823942822,
                                   0,
                                   0,
                                   0,
                                   0.14833381901450277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6411386804641156,
                                   0,
                                   0,
                                   0.29153155142270076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53728684570090812,
                                   0,
                                   0.28307920583625007,
                                   0,
                                   0,
                                   0.614611737460935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25418281662170022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062626971064650261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91956927177826064,
                                   0.40425194478075099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080002579244759467,
                                   0.49719305043197581,
                                   -0.24778763014627983,
                                   0.44930572257156665,
                                   0,
                                   0,
                                   0.032438675623542926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0064206263358919519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031159051850527961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02949056937065098,
                                   0,
                                   0.1142169507172778,
                                   0,
                                   0,
                                   0.34212630779768183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1490581404107639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4102545481149899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62219148955199721,
                                   0.87783573394823633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052768154555303586,
                                   -0.15447832490708902,
                                   0.82834397727801179,
                                   -0.089949538666438039,
                                   0,
                                   0,
                                   0.078407254331549381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27983961566342824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2001833592543707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057902960411456504,
                                   0,
                                   -0.23175386406401743,
                                   0,
                                   0,
                                   -0.013594632413766156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30082847186496919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66106805067924834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063050450058271243,
                                   0.28452172290251837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47100145423280926,
                                   0.26683927070182867,
                                   -0.25868225120687677,
                                   0.10748056638949192,
                                   0,
                                   0,
                                   -0.81028021904719871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29187408150626803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45348057941630537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32298819416956914,
                                   0,
                                   0.1124110281523851,
                                   0,
                                   0,
                                   -0.031863564242344419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90271244237834747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087618870575964208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077711604848581736,
                                   -0.6795157348839771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19091010227348726,
                                   0.01151260687054631,
                                   0.30966616488337517,
                                   -0.22974271115761097,
                                   0,
                                   0,
                                   -0.36942115355659721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17190292549062597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25224258631712498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22007310175206968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1620974999284111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18508360839448604,
                                   0,
                                   0,
                                   0,
                                   0.17513384833413684,
                                   -0.68248222544591886,
                                   0,
                                   0,
                                   -0.5641908752661301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32168824727866224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69992623844491297,
                                   0,
                                   0,
                                   0.072590757909137951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50014112854258674,
                                   0,
                                   0,
                                   0,
                                   -0.22449051794895286,
                                   0,
                                   0,
                                   -0.44468730581010762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59024548589352677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.502676246389681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85142825028522673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24730388845314019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26822582503578535,
                                   0,
                                   0,
                                   0,
                                   0.40071177164150529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18896837649341944,
                                   0,
                                   0,
                                   0.26632328406493755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83235576669752553,
                                   0,
                                   0.55473593903122898,
                                   0,
                                   0,
                                   0.11507135332710335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31596395012202566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080513449956055916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22459481714179289,
                                   -0.10798266448111789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56537524291821362,
                                   0.082820662534340783,
                                   -0.081971473850346033,
                                   -0.28352783480733268,
                                   0,
                                   0,
                                   -0.10001566029003567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35146970174399877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13887119542767043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17351923843390177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25357980457439583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12661723538657524,
                                   0,
                                   0,
                                   0,
                                   -0.37414159678886227,
                                   -0.53364349595501037,
                                   0,
                                   0,
                                   -0.21929108179875734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4379999888756671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27793671431960726,
                                   0,
                                   0,
                                   -0.46581602787771503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10095790201200391,
                                   0,
                                   0,
                                   0,
                                   0.69148183930222351,
                                   0,
                                   0,
                                   0.63119916582714486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10947645435189715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47220724690009463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20406551375988474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016992786377672431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43455290149986825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17981117792575751,
                                   0,
                                   0,
                                   0.040522576301561697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45740109420526465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020866503076967094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53911241702696888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49931331120046241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36927423251974373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47703308902972569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6607733726395576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29796363035892026,
                                   0,
                                   0,
                                   0,
                                   0.29512813373111568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2228776765732331,
                                   0,
                                   0,
                                   -1.0180086060833982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10479725874454725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36136655018117064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10276227314600905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20581629645421495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19883542916744057,
                                   0,
                                   0,
                                   0.41927266757803106,
                                   0,
                                   0,
                                   -0.37112218989816009,
                                   0,
                                   0.023838164474954411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19561111780771961,
                                   0,
                                   0,
                                   -0.34489293745524241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54283315054533332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.001898858478078861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052057028079603704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34894001296912941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39635552052600609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38527024367107338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19701305995089707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29474931409721544,
                                   0,
                                   0,
                                   -0.52190895537377735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.197933885477484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15248710902107723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3308922343870393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13406274173614896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26192720011223419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16351628936349294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36630427325011339,
                                   0.67196433123067389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24017298425500688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042917129801250085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36479895923001959,
                                   0,
                                   0,
                                   0,
                                   -0.0066658256610740091,
                                   0.23981243506945296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016205435778836978,
                                   0,
                                   0,
                                   0,
                                   0.064895546527270767,
                                   0,
                                   0,
                                   0,
                                   -0.13509665056832557,
                                   0,
                                   0,
                                   0.16758893097340286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38252371302131954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27998302488490528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65239230055027486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26309541067529701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18947078520797969,
                                   0,
                                   0,
                                   -0.069001314186461479,
                                   0,
                                   0,
                                   0.25594374040384554,
                                   0,
                                   -0.36466931817573678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13333585471424469,
                                   0,
                                   0,
                                   0.13513530596494708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036109596038136016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062889046286999373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61431473310476947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02910708342959234,
                                   0,
                                   0,
                                   -0.3451611609287154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061959919131485103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37140915240956263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60070805662868432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067636641947226558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27623150918824224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11089963351839613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64219745868090206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45286384923353484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40205056084358026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22671156973189013,
                                   0,
                                   0.27618232760156336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16421881520582593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36637702408541062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.117813366301557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018637593524779915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37717624583962694,
                                   0,
                                   0,
                                   -0.20853988407663121,
                                   0,
                                   0,
                                   0.032856046575465953,
                                   0,
                                   -0.36222992576067042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32888644590443772,
                                   0,
                                   0,
                                   -0.31629565707142537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4562001780151822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3003398504869334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17500877393736267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026403355073676801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18243821487266959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66629723396356433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056943751454750766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67301696169975733,
                                   0,
                                   0,
                                   -0.042852124929316553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16773846595482156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038603816613907674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061497250817128354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13412838769221691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41878556712827664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10018693488961508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80920589136968979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084850035721679526,
                                   0,
                                   0,
                                   0.24332412634492032,
                                   0,
                                   0,
                                   0.16375865434605924,
                                   0,
                                   0.16285838047169957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069003476792897339,
                                   0,
                                   0,
                                   0.11886340741196441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030825418734565541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046803033793797424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46516879429661084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1005632233449321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88663153474724532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042146748574582144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074699750421585609,
                                   0,
                                   0,
                                   0,
                                   0.049042176265629928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67600976990444861,
                                   0,
                                   0,
                                   0.40884904387334858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12051346560096361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12154153803247467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014035016824627031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17557726149203792,
                                   -0.060884882736604626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51016356727907874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076591971662379355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30269857153480739,
                                   0,
                                   0,
                                   0,
                                   0.10505738913714108,
                                   -0.10371942526360424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038633604562592835,
                                   0,
                                   0,
                                   0,
                                   0.70357834442597511,
                                   0,
                                   0,
                                   0,
                                   -0.16513356837335316,
                                   0,
                                   0,
                                   -0.18064966452884701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17329533962204399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28480446604246928,
                                   0,
                                   0,
                                   0,
                                   -0.16925656708123754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50935496773573607,
                                   0,
                                   0,
                                   0,
                                   -0.39228593734662376,
                                   0,
                                   0,
                                   0.21557151657212861,
                                   0,
                                   0,
                                   0,
                                   0.11839683813791972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041254517740875074,
                                   0,
                                   -0.48150842331433413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1595712379230567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59397949816768858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53463683369738257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35053638828595629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70009476067457876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8060823056316947,
                                   0,
                                   0,
                                   0,
                                   -0.33646361052911328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04074732586046724,
                                   0,
                                   0,
                                   -0.59202013942742748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56453888788201978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45662839378485376,
                                   0,
                                   0,
                                   0,
                                   1.0097230921215903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70902344365356895,
                                   0,
                                   0,
                                   0,
                                   -0.11330660462977694,
                                   0,
                                   0,
                                   0.010841044420273588,
                                   0,
                                   0,
                                   0,
                                   0.35379760164368407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13733743348546673,
                                   0,
                                   0.28625643759003644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66393002790195899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13556119295915819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31955557727075568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23257244923892179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081198256496948645,
                                   0.22923861617444261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038718190650731447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2705972759676486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39511506308004529,
                                   0,
                                   0,
                                   0,
                                   0.40817205163117298,
                                   -0.20189302176357518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010957397628959947,
                                   0,
                                   0,
                                   0,
                                   -0.022140826800620753,
                                   0,
                                   0,
                                   0,
                                   0.57047438470640177,
                                   0,
                                   0,
                                   0.044939229842215829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048439126341105823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24376910305008881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077931740306119462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13321883464027975,
                                   -0.14673919265408703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058601256559924091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65950531958206138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10739610913171549,
                                   0,
                                   0,
                                   0,
                                   -0.083175662958296689,
                                   -0.21132790019404768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3855175071978687,
                                   0,
                                   0,
                                   0,
                                   0.12807397809280197,
                                   0,
                                   0,
                                   0,
                                   0.2633816972794078,
                                   0,
                                   0,
                                   0.39621672055988894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55431175782377118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23562866430553633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61370823749100423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1110252294923654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35813295732769479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093297955191240123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25450971618699264,
                                   0,
                                   -0.21567170919485931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01971185756889968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11205180996273625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16082338554416439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034600060646572478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21202510868820204,
                                   0,
                                   0,
                                   0.65361958091180372,
                                   0,
                                   0,
                                   0.064301337970496197,
                                   0,
                                   -0.30739053141772654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37315263558938555,
                                   0,
                                   0,
                                   -0.34051087992552986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35556835185706609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087053450521371867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27576511854958569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011252804829538814,
                                   0,
                                   0,
                                   -0.26784026773866426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079619780092391318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83675128181595348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38157115686314563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88207407728453535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53944879703408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33826781766847319,
                                   0,
                                   0,
                                   0,
                                   -0.38034816571252039,
                                   0.51465718759306878,
                                   0,
                                   0,
                                   0.48887058385976867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25173169240421639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10822509346404573,
                                   0,
                                   0,
                                   -0.096739372962925466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38347222350947047,
                                   0,
                                   0,
                                   0,
                                   -0.052130963789130708,
                                   0,
                                   0,
                                   0.10548882382410607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28253666709472269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35804351036247473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21763769717214451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33554045508222141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31401879268828459,
                                   0,
                                   0,
                                   0.061003813018085357,
                                   0,
                                   0,
                                   -0.12127339808794599,
                                   0,
                                   -0.40754104199265684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25351041606411456,
                                   0,
                                   0,
                                   -0.024966511833144311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27299005497397588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45769387036525067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04056598323589683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57578262828025684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38457111607138755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21014204319191829,
                                   0.27024692234773645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19589250910713324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31528645405682632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38230706817502008,
                                   0,
                                   0,
                                   0,
                                   -0.16318977446988647,
                                   0.15779834657900341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19091272168130682,
                                   0,
                                   0,
                                   0,
                                   -0.15021752052960663,
                                   0,
                                   0,
                                   0,
                                   0.057155252773299386,
                                   0,
                                   0,
                                   -0.063180007300547125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087919242132511316,
                                   0,
                                   -0.46158217545067021,
                                   0,
                                   0,
                                   -0.63094540873293037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033040119457360018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26114878190587937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45212944301509556,
                                   0.036799100439413007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27679232142557403,
                                   1.2352485550850738,
                                   0.021965787350451575,
                                   -0.38943528488804591,
                                   0,
                                   0,
                                   -0.13588530317705105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36098835841186183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41224970552421503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48270255685314967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29069901227352302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20105354395024161,
                                   0,
                                   0,
                                   0,
                                   0.18728732212457216,
                                   0.41644555313488513,
                                   0,
                                   0,
                                   -1.0229702266119218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42735997367111356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43236676129569535,
                                   0,
                                   0,
                                   0.38242156329913435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059112427270182129,
                                   0,
                                   0,
                                   0,
                                   0.1883136652119955,
                                   0,
                                   0,
                                   -0.5972810897082832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028630103604966005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63658888689302962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29060828094738694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00018170501111903006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40163334912998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20409281312583258,
                                   0,
                                   0,
                                   -0.37327753962535692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28871240689684102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17604929120554144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22985679967768613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11946195335174417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077990905200954516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27661339239605837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27365379836277998,
                                   0.0064361861045172733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62737008799613925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089015151064813849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11315226078605192,
                                   0,
                                   0,
                                   0,
                                   -0.056238235747313944,
                                   0.17097729952752982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025793072631805559,
                                   0,
                                   0,
                                   0,
                                   0.54295227126949097,
                                   0,
                                   0,
                                   0,
                                   0.18445252167154871,
                                   0,
                                   0,
                                   0.22803935365407643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064290167207697632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87139879232027373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90254971704643561,
                                   0,
                                   0,
                                   0,
                                   -0.40852889036501261,
                                   0.13890591659142879,
                                   0,
                                   0,
                                   -0.41523434001445964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2543455456159236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098356570464947474,
                                   0,
                                   0,
                                   0.022801929941961244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4172843642927711,
                                   0,
                                   0,
                                   0,
                                   -0.43762320666787091,
                                   0,
                                   0,
                                   0.11721987480002899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26717219738454984,
                                   0,
                                   -0.16010680053030096,
                                   0,
                                   0,
                                   0.31467968531092311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031268790507452571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32174417166893443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094986918016093963,
                                   -0.45970001373582847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68340938949377439,
                                   -0.062764743158028796,
                                   0.043090675608457127,
                                   -0.13615772218151409,
                                   0,
                                   0,
                                   -0.75722620690365461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34619851481830949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21786190959289714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012987939667719488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034228477014599114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35589795149707526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091523819112932239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038203187228825861,
                                   0,
                                   0,
                                   -0.090571384358681978,
                                   0,
                                   0,
                                   -0.79271516397463793,
                                   0,
                                   0.12085642182372877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24699785164495991,
                                   0,
                                   0,
                                   0.041142976786753029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38365262244458187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032611047276222931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33398957645896149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21022671184407382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14954377140922023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26259429727443617,
                                   0.13368064766835491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017341435695803459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1335048438846472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077415162399343818,
                                   0,
                                   0,
                                   0,
                                   0.020005163057219943,
                                   -0.23181498426107786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72030227948936165,
                                   0,
                                   0,
                                   0,
                                   0.15995615006295125,
                                   0,
                                   0,
                                   0,
                                   0.025706820419723699,
                                   0,
                                   0,
                                   0.3342575629347907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26274602065498237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061889396612497233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089781119773470225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24851066671127894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30552461303611905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071386985165351025,
                                   0,
                                   0,
                                   0.36963417313135244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41596590939312561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63536860316561961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2133642843720753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045482501853561022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11278029950146158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23233404607649891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2446986481645009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58440379528023223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32485743943476925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5626254042105332,
                                   0,
                                   0.32824976973726727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62566938395819749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0365279122587834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17747012246488614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1826241830327098,
                                   -0.058645262225653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16949576842527903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34506575940761852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083737332002086634,
                                   0,
                                   0,
                                   0,
                                   -0.16933785926054329,
                                   -0.42052277964442963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35002923242882905,
                                   0,
                                   0,
                                   0,
                                   0.094740610124687291,
                                   0,
                                   0,
                                   0,
                                   -0.21351118088659293,
                                   0,
                                   0,
                                   0.038831761760492099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13529400376757983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7150500679190771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39902293954658646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1451011926120199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14380270113053378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51393005170018924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072938114727427214,
                                   0,
                                   -0.0014096306764828856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36580583377194292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69200897899197544,
                                   0,
                                   0,
                                   0.18107023875184494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34477897926755818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12749754470037822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46839626937225537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56852148599030672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90124311408124202,
                                   0,
                                   0,
                                   0,
                                   0.60257689777701651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056784830128399834,
                                   0,
                                   0,
                                   0,
                                   -0.13908133225419433,
                                   0,
                                   0,
                                   -0.045017832912324987,
                                   0,
                                   0,
                                   0,
                                   0.33079239577570757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21859740269179284,
                                   0,
                                   0.47959912048203179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14111661163745309,
                                   0,
                                   0,
                                   -0.1028488477641399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18359737039748608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026334502219833449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18116022457123965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43489929748391853,
                                   0,
                                   0,
                                   -0.32322464929507289,
                                   0,
                                   0,
                                   0.043222428847071559,
                                   0,
                                   -0.26512334769619672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59643428287614098,
                                   0,
                                   0,
                                   -0.29773017116842293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33323337125082986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0317782642806788,
                                   -0.12325666656479689,
                                   0,
                                   0,
                                   0.088713893793377976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26227628545660697,
                                   0,
                                   0.48548327502586491,
                                   0,
                                   -0.059248386712972674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064663308003277895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17022316021447065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061465158948357898,
                                   0,
                                   -0.44719921612910529,
                                   0.65728383159647663,
                                   0,
                                   0,
                                   0,
                                   0.25401680967327778,
                                   0,
                                   0,
                                   -0.6938376777747115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24330836084609539,
                                   0.27103846415343408,
                                   0,
                                   0,
                                   -0.53384427305725635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32620890122294055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71655572334986317,
                                   -0.47192082170657484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14944224082772237,
                                   0,
                                   0,
                                   0,
                                   -0.22258621964022443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6841305170519647,
                                   0.27517259217257023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14359464890170698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094232690385436559,
                                   0,
                                   0,
                                   0,
                                   -0.96267220365651185,
                                   0,
                                   0,
                                   -0.13725392427566638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12465445762215493,
                                   0.85695652273839196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33491070800887596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6642338544078924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39632116514601695,
                                   0,
                                   0,
                                   -0.083315157745540006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025367897662718547,
                                   0,
                                   0.15265004151279629,
                                   0,
                                   -0.12712261056541824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20172105701692286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2040824183070665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.801287528521059,
                                   0,
                                   -0.20638753664936343,
                                   -0.16995251710646375,
                                   0,
                                   0,
                                   0,
                                   0.0057581196114714073,
                                   0,
                                   0,
                                   0.32636995580993045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37078974933539627,
                                   -0.64139210745716813,
                                   0,
                                   0,
                                   0.16102677156050954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51004565899778553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42406269281336312,
                                   0.42222896201386301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33477307176143062,
                                   0,
                                   0,
                                   0,
                                   0.06456366811352382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29993108770972099,
                                   0.64301176490084078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025933875377005894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23739229569379189,
                                   0,
                                   0,
                                   0,
                                   0.72080012042160169,
                                   0,
                                   0,
                                   -0.66791094718336264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51794975444591274,
                                   0.24529390993588804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52597745552799535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33672512042516906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16459023549143495,
                                   0,
                                   0,
                                   0,
                                   0.22635160967760218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092826515389160869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067425871782219871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24270938024212266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43834745052905211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093507897236475401,
                                   0,
                                   0,
                                   0,
                                   -0.43229866990004595,
                                   0,
                                   0,
                                   0,
                                   -0.42589324024542619,
                                   -0.46275609294971953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2569474096338133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016720364236843192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17850154276670874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03366598560658321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17960671423653529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24416146186118989,
                                   0,
                                   0,
                                   -0.14355205394716611,
                                   0,
                                   0,
                                   -0.19146250897014774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21914197252171877,
                                   0,
                                   0,
                                   0,
                                   -0.25477304185273064,
                                   0,
                                   0.52999620741088938,
                                   0,
                                   0.42889416801961888,
                                   0.17315310638783354,
                                   0.1484204974754427,
                                   0,
                                   0,
                                   0,
                                   0.11190682168060076,
                                   -0.41899027624083512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030449323108467041,
                                   -0.61890950556804947,
                                   0,
                                   0.15913266154074651,
                                   0,
                                   0.41956696209898087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8904083724385603,
                                   -0.60736946610511411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53869973173766339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52994121147467665,
                                   0.12132442457987935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12113924230818948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10702630171361036,
                                   -0.12572838565135452,
                                   0,
                                   -0.40742834740447281,
                                   0,
                                   -1.1428010170459675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19465057406530539,
                                   -0.73295500294630989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016230484811885007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06026975163444992,
                                   0.56401292212020493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3103973988198051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0048174944586081431,
                                   0,
                                   0,
                                   0,
                                   -0.47612581695272316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10197615210586503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30504601651623203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08602964620410336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0069986448359261599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36235335504992178,
                                   0,
                                   0,
                                   0,
                                   -0.048723699716028968,
                                   0,
                                   0,
                                   0,
                                   -0.48845548917228138,
                                   -0.08456729410336436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50169365052199455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17682716248762972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70428569084407577,
                                   -0.51923436733425565,
                                   0,
                                   -0.5778811381042408,
                                   0,
                                   0.088350995738366592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88342555217691132,
                                   0.24348506471967282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27223597606510858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5322105481523115,
                                   -0.022404149029197989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82031425466872199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19923110393435653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49417606279604021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75773987900285256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34384034686311593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23214698882756488,
                                   0,
                                   0,
                                   0.22159570910684803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51216193949367739,
                                   0,
                                   0.40327091540992183,
                                   0,
                                   0,
                                   -0.45879860206532358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28087433010584162,
                                   -1.1195148881018697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01383556404670706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94569628144999363,
                                   0.24886612759570573,
                                   0,
                                   -1.1312601235040005,
                                   0,
                                   -0.10314185120215252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24899402422013578,
                                   0.42855417495924292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41599307282573861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16369356591686909,
                                   -0.024444464392632925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24763652531621339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67095183064112263,
                                   0,
                                   0,
                                   0.40640401567040457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45218200558218519,
                                   0.077952235998804478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.4590518026687818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45438160407912664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053762967216972268,
                                   0,
                                   0,
                                   -0.51498363371632772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051385698583884643,
                                   0.5986616665248421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5981865585986087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98904609868922033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37689764254354013,
                                   0,
                                   0,
                                   -0.81007242856424211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10136021558448713,
                                   -0.71314093745029106,
                                   0,
                                   0,
                                   -0.1379389506073202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089149320736366833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76783464066807261,
                                   -0.59565262306664435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15029149094823402,
                                   0,
                                   0,
                                   0,
                                   0.46190907111654256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068515590348535244,
                                   -0.35274838578247769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020160570427874197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038087422688231537,
                                   0,
                                   0,
                                   0.47392781117412391,
                                   0,
                                   0,
                                   0.04965350072829141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26811783305346581,
                                   -0.39997354340896024,
                                   0,
                                   0,
                                   -0.38751438283072026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059973497718538896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25012627512353947,
                                   0.51014617191064804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3903315510819082,
                                   0,
                                   0,
                                   0,
                                   -0.074437802271937595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13964416285337117,
                                   0.1690087256304238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79799584045077532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87730120144249979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24035401536413198,
                                   0,
                                   0,
                                   0.87076162307473859,
                                   0,
                                   0,
                                   0.16852148421037172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46852889000402753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.003600009604612063,
                                   0,
                                   0,
                                   0,
                                   0.53883636674546531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19576172287862881,
                                   0,
                                   0,
                                   -0.323087903857043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093815040170750486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32753013673288561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73631732758986868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19972942861648704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0041858611073893326,
                                   0,
                                   0,
                                   0.098031332041186983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11217868358039851,
                                   0,
                                   -0.020769241684235745,
                                   0,
                                   0,
                                   -1.0094048088896246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44424240103541984,
                                   0.44173559595730272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3230197532442326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15923961146194998,
                                   0,
                                   0,
                                   -0.22354382630094413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13393715487751556,
                                   -0.70701573289260655,
                                   0,
                                   0,
                                   0.28709875786509226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076953260990923422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3623166143465994,
                                   -0.37012364620448868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064328819453447914,
                                   0,
                                   0,
                                   0,
                                   -0.79163074393194888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89272097228128033,
                                   0.64446669476897278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0030107500119970765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022735037618068235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21570179492897218,
                                   0,
                                   0,
                                   0.15956952991504397,
                                   0,
                                   0,
                                   -0.082337026958335918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33124767272835243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.790304702899151,
                                   0,
                                   0,
                                   0,
                                   -0.44940685442218747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35340426816503062,
                                   0,
                                   0,
                                   -0.29185031061862998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1447242640390316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35547387765821054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13873932990348581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29696476488706042,
                                   0,
                                   0,
                                   0.19689244838807243,
                                   0,
                                   0,
                                   0.20894586575073953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38125624983894474,
                                   0,
                                   0,
                                   0,
                                   0.03270684336655947,
                                   0,
                                   -0.27822139633866916,
                                   0,
                                   0.52824806952461445,
                                   -0.19568008581508928,
                                   -0.22804963745687457,
                                   0,
                                   0,
                                   0,
                                   0.19613000368281824,
                                   0.17660118899120847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49967964218726552,
                                   0,
                                   0,
                                   -0.74261359352223733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48043882675988209,
                                   -0.52582859571136831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036177950213220511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27679275023112426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77063278716135575,
                                   0,
                                   0,
                                   -0.34615797026148049,
                                   0,
                                   0,
                                   0.11688025515448486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21161626567847489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012577837909965655,
                                   0,
                                   0,
                                   0,
                                   0.30197546554624605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36188130607147856,
                                   0,
                                   0,
                                   -0.46510625767632774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73451688985215602,
                                   0,
                                   0,
                                   0,
                                   -0.057461018047792189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44577852903800974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032014404595008455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061315918163683231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19651260201803866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064229789981269103,
                                   0,
                                   0,
                                   0,
                                   -0.28689825163850413,
                                   0,
                                   0,
                                   0,
                                   0.035783573470783064,
                                   0.34407151783772161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012555141811580267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093827120195264846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020788643284928229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74859367488544049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063597074810037013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17847093772790107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34420070448165074,
                                   0,
                                   0,
                                   -0.60306383792339568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49604906209741328,
                                   0,
                                   -0.061475863527825914,
                                   0,
                                   0,
                                   0.031882100189550788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055507742962749067,
                                   0.30215418681854433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88415231195069088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13224658371743583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14910380793132547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060822297724663535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099650484294461369,
                                   0,
                                   0,
                                   0.038634598409572632,
                                   0,
                                   0,
                                   0.16994298172867686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11023438108963329,
                                   0,
                                   0,
                                   0,
                                   0.56136927198247399,
                                   0,
                                   -0.03956952344523143,
                                   0,
                                   0.08691729958249865,
                                   0.27623158830658212,
                                   0.17391073508660357,
                                   0,
                                   0,
                                   0,
                                   -0.60199226245685833,
                                   -0.3330542219133476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29710106731163144,
                                   0.18909458926968223,
                                   0,
                                   -0.44443500854742879,
                                   0,
                                   0.079156345165312642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41050008901253671,
                                   -0.91638883886260203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96050310333811983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37653922925326527,
                                   -0.44743297660609738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050093372973553263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046372635814232725,
                                   -0.20626839568674818,
                                   0,
                                   0.10314374338402428,
                                   0,
                                   -1.0012041267647036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19033912893240706,
                                   -0.021259937117209679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058088524310891801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61378133713079563,
                                   -1.2018341384604576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41223561339655601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23670736386239249,
                                   0,
                                   0,
                                   -0.61691708084020136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10117735218089767,
                                   -0.1920167532811394,
                                   0,
                                   0,
                                   0.77776973269265526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80256911218842242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25183802039350961,
                                   0.43811261094631604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49032489485534586,
                                   0,
                                   0,
                                   0,
                                   0.34246237646106292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14592951426885062,
                                   -0.24730046917386467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16063073895691965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62766298879808469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074982983548994742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22797164933598588,
                                   0,
                                   0,
                                   0,
                                   0.63953292748033097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29979280194617813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41319728273876366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2041527641197787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12849490581428613,
                                   0,
                                   0,
                                   -0.46325705981253523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012451420862047646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29823938144560225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76606205773930514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53924422190580512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23051905525265481,
                                   0,
                                   0,
                                   0.58598435681772121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.668113064411471,
                                   0,
                                   0.17022873968161639,
                                   0,
                                   0,
                                   -0.1821979213413624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20121757706762988,
                                   -0.39546092045048004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089511971236569135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067206042140740149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57220590068522248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28564582995182858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52907732622748638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5436242031969194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10497677610981171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29326281779843555,
                                   0,
                                   0,
                                   -0.61826574672575008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1694549974523212,
                                   0,
                                   -0.14250720879582082,
                                   0,
                                   -0.22374320227496278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036323011698277494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1351398969329575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4168075909609254,
                                   0,
                                   -0.42446196218368204,
                                   -0.24327224809382081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58337153576852818,
                                   0,
                                   0,
                                   0.25944160333992083,
                                   0,
                                   0,
                                   -0.14518782574738537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57588272252290018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3991126165488878,
                                   0,
                                   0,
                                   0,
                                   -0.22261979113357966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63716245280140449,
                                   0,
                                   0,
                                   -0.41263440644317273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12824224094334313,
                                   0,
                                   0,
                                   0.11111713367938725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025724467773902453,
                                   0,
                                   -0.31747472820837902,
                                   0,
                                   -0.26025398391597709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84923292292898123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18654257427618468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043018247187480096,
                                   0,
                                   -0.056859790604769887,
                                   0.2023475426600112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38074505205627751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13029597433823983,
                                   0,
                                   0,
                                   0,
                                   0.36906838002954534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53877670778590081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22134455005445258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5339491915858039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15445916721509662,
                                   0,
                                   0,
                                   -0.23154172635819334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58705336619449233,
                                   0,
                                   0,
                                   0.16410337515727025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63475059480367613,
                                   0,
                                   0.1760030177143766,
                                   0,
                                   -0.019859505499751108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080967172442190913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32993353351969928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26418921594574168,
                                   0,
                                   0.065160453611301308,
                                   -0.068593014249926892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23919158650412095,
                                   0,
                                   0,
                                   0.16908252365614274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95248580079038869,
                                   0.33442235265300907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089273590882105708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1716072801062917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40171593678873629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061544221176936913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13418973936765954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62325063451038976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60116215765891889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25882896978387387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2803537928173549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40636732036274437,
                                   0,
                                   0,
                                   0,
                                   0.092593595537326448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41046594526033231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11516679897666141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038797216478884095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7440660346434611,
                                   0,
                                   0,
                                   -0.10396444650970134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27822552103344816,
                                   0,
                                   0,
                                   -0.0026111916795858864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03726830718472593,
                                   0.56441255498591669,
                                   0,
                                   0,
                                   -0.18499394175927944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54627055850888351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04404071794599676,
                                   -0.68393276114463619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58058874196697319,
                                   0,
                                   0,
                                   0,
                                   0.68815849787476269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.675109403128622,
                                   0.461945767902468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12265491489903642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31878103028631433,
                                   0,
                                   0,
                                   0.38951294272121839,
                                   0,
                                   0,
                                   0.007851315484820565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3113794635517777,
                                   0.44366118018021744,
                                   0,
                                   0,
                                   0.83864210873066647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092696535755284262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06688982704666685,
                                   -0.51794100292268297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3229017920542302,
                                   0,
                                   0,
                                   0,
                                   -0.34479121628267878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5512069866412912,
                                   -0.04093725783004553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15995431563426557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17397803932055758,
                                   0,
                                   0.35002854830786401,
                                   0,
                                   0,
                                   -0.23803389449921952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53150802077241932,
                                   0,
                                   -0.260142550636557,
                                   0,
                                   -0.38865179094594948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32532701698812716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19864205125340673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23199568893079328,
                                   0,
                                   -0.26349154141660819,
                                   0.22593941322242378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11843237148682656,
                                   0,
                                   0,
                                   0,
                                   -0.2609631366915624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27174201860339964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28682105640263661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58174249569083925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071457612305108498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034462116353335286,
                                   0,
                                   0,
                                   0,
                                   0.36561468453667223,
                                   0,
                                   0,
                                   0,
                                   0.34203446835289775,
                                   -0.28244435213878516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023992321428759539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29331159857067818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65382746009097759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051109543054299648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41301447663671426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24512838500445849,
                                   0,
                                   0,
                                   -0.096278586947702943,
                                   0,
                                   0,
                                   -0.16809321446742584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061707653913125986,
                                   0,
                                   0,
                                   0,
                                   -0.21999366626368189,
                                   0,
                                   0.30322068112431078,
                                   0,
                                   -0.10519423761027367,
                                   -0.078149972861181471,
                                   0.23243277531847067,
                                   0,
                                   0,
                                   0,
                                   -0.17046472986789316,
                                   0.2393729196752451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64495631129579101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13236364944479909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72393248684223366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1751676131399573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029300378165411201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10435885427702794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13204132963560139,
                                   -0.85165542328532817,
                                   0,
                                   -0.11536314429232092,
                                   0,
                                   0.33020333842686794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41190882676361268,
                                   0.52206595202645889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36778700631851907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12014780388604751,
                                   0.23937821532705728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99193741271791924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11058869999077901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1884066556497804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3650941664620147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2414357871498361,
                                   0,
                                   0,
                                   -0.58268155813301625,
                                   0,
                                   0,
                                   0.20509090831780175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062048878410726899,
                                   0,
                                   0,
                                   0,
                                   0.30080730888267249,
                                   0,
                                   0.050209298259728474,
                                   0,
                                   -0.17507739872447831,
                                   -0.2541024859555171,
                                   -0.23198614521962993,
                                   0,
                                   0,
                                   0,
                                   0.25209468655229883,
                                   -0.26393646485726724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18848827057325529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49412986196336611,
                                   0,
                                   0,
                                   0,
                                   0.077021486933368119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16399801035463121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40655909063235357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1385616516953197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2778811564030304,
                                   0,
                                   0,
                                   0.65251255309184364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85276895386623297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053903325036943256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26180510343239261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24683765126946045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7498692189569256,
                                   0,
                                   0,
                                   0.008952597646785198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65471363801396687,
                                   0,
                                   -0.29830455254716953,
                                   0,
                                   0,
                                   -0.25852124386099617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50493663517962517,
                                   -0.43230283738550251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077218621581001456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3561213495749978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44652211996695335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092613424398708288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11874600616466864,
                                   0,
                                   0,
                                   -0.14896165814309739,
                                   0,
                                   0,
                                   -0.29753383769185365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27269884458489291,
                                   0,
                                   0,
                                   0,
                                   0.30936998208503252,
                                   0,
                                   0.20230120506190413,
                                   0,
                                   -0.27644826433858122,
                                   -0.082232404418454641,
                                   0.2057549508389836,
                                   0,
                                   0,
                                   0,
                                   0.0062456439713949943,
                                   0.45148822570632774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47256753375142213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3270604109648918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49274056952509243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24358998922582448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49273254986676251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35326575862716031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29775165678183529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53020871657189916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054874953896620574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1142809461683004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20556126524460006,
                                   0,
                                   0,
                                   -0.24836093819372324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082142543009535912,
                                   0,
                                   0.37090922214508043,
                                   0,
                                   0,
                                   0.55374249568232481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57511764000097576,
                                   -0.13963024968641133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53338979694070943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099004029777939151,
                                   0,
                                   0,
                                   0,
                                   -0.38083400443318133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16639304175377254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037881984698237808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36069104310103517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59377741913995152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3421324605565948,
                                   0,
                                   0,
                                   0,
                                   -0.14443282274004382,
                                   0,
                                   0,
                                   0,
                                   0.33764654772521169,
                                   -0.053925575045333705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24408293369351114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13772154437934717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024667563472799317,
                                   0,
                                   0,
                                   0.17029740525707429,
                                   0,
                                   0,
                                   0.05125006445775987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8523516477262475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29760245947868319,
                                   0,
                                   0,
                                   0,
                                   0.80840060525071811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59319672506965793,
                                   0,
                                   0,
                                   0.28716327358339921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33421240275256847,
                                   0,
                                   0,
                                   0.14553397667174409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12895118584182358,
                                   0,
                                   -0.67027927850476321,
                                   0,
                                   0.4730910994295735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17346643950077348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19407982808518043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12233404857527723,
                                   0,
                                   -0.25194173288634586,
                                   0.17665271604156185,
                                   0,
                                   0,
                                   0,
                                   0.034550913972497904,
                                   0,
                                   0,
                                   -0.38328772988481208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36166662735336252,
                                   -0.26377316086501212,
                                   0,
                                   0,
                                   0.44997181124517094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52578033353541764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52349577890424293,
                                   0.35892919341284496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75572744390284896,
                                   0,
                                   0,
                                   0,
                                   0.39257668487582015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0055545553604590498,
                                   0.030946526466561909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74433041096089347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21408252812092171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43834765734596493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62490295271805962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36491256612279876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48868458152396388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022887782907908799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21177813684027402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5988584309070597,
                                   0,
                                   0,
                                   -0.44016488614513566,
                                   0,
                                   0,
                                   -1.2634883534221735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71482652878733322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1641016055893344,
                                   0,
                                   0,
                                   0,
                                   0.28921576839453184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17108056401418875,
                                   0,
                                   0,
                                   -0.33845929526714197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13856500198400878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3973253308441923,
                                   0,
                                   0,
                                   0,
                                   0.56968814416836244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098419600294928078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16798241499184655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22645741801352945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36392113298308798,
                                   0,
                                   0,
                                   0.52608143610564428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10060963402270282,
                                   0,
                                   0,
                                   0.47888052724041019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58953579446764048,
                                   -0.13938116598840145,
                                   0,
                                   0,
                                   -0.15140415528832585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64480532636641674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19071524905052101,
                                   -0.21261117916538858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5614050523478944,
                                   0,
                                   0,
                                   0,
                                   -0.75842173534988011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.105250404906747,
                                   -0.8170474351468715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35400336352781531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17636828894419179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6307783319889636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035155438109450182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76832386119167195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75602315882332649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22694937708784635,
                                   0,
                                   0,
                                   -0.0072426253569494179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50623580405283919,
                                   0,
                                   0.076151038269253374,
                                   0,
                                   0,
                                   -0.28843795809117917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068829790493894108,
                                   -0.23049787459554041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38336952357568843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051674634907799444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39217389973086969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019154070161492801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052947461609899112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31449810401989725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8610749067010568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34044222701170151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70212410507227996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18641032877962088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58664696428541574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53358651534825596,
                                   0,
                                   0,
                                   0.07507085667291015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48034579480493123,
                                   0,
                                   0.74631604449016842,
                                   0,
                                   0,
                                   -0.55943758211303618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64065342356147048,
                                   -0.37998406851391642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53515454007390562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74696044787489235,
                                   0,
                                   0,
                                   -0.47886092988378415,
                                   0,
                                   0,
                                   0.39733920106314363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33696943319867523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068068631529148438,
                                   0,
                                   0,
                                   0,
                                   -0.073697445776213136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23004367928671299,
                                   0,
                                   0,
                                   -0.70925660479155073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47496172649665658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26342614281220555,
                                   0,
                                   0,
                                   0,
                                   -0.25445687716660326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43112375579433759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39135476042540762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53171312720900588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067281942487448898,
                                   0,
                                   0,
                                   -0.11831218263522271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19364834398167552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18338800005111378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15535407163123804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12734672465951632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43463759976729566,
                                   0,
                                   0,
                                   -0.42464367801793057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086637462030080575,
                                   0,
                                   -0.74664750342692598,
                                   0,
                                   0,
                                   -0.2742511544644447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070112161916522961,
                                   -0.3635528330322601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13483805369034144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18020766695620749,
                                   0,
                                   0,
                                   -0.67148122561757961,
                                   0,
                                   0,
                                   0.3598509688803111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68857356626013544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50107977924436753,
                                   0,
                                   0,
                                   0,
                                   0.041528639006169099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76651436171375142,
                                   0,
                                   0,
                                   0.38931778508797599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55073318172729435,
                                   0,
                                   0,
                                   -0.099527517042392571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1589153103916271,
                                   0.027990050408198307,
                                   0,
                                   0,
                                   0.29551313337435858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54896945946073195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13152483116944902,
                                   0.17802995467671598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079536963830326657,
                                   0,
                                   0,
                                   0,
                                   -0.0031814203421488964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3278797046419199,
                                   -0.16840334033031795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.003645940018852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47360515010339016,
                                   0,
                                   0,
                                   0.96168470522455696,
                                   0,
                                   0,
                                   0.043644208984171588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97298601960151554,
                                   0.6238052348113583,
                                   0,
                                   0,
                                   0.19234620345331613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17385723518102478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2154222928770356,
                                   0.23983771196043285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10497285061473607,
                                   0,
                                   0,
                                   0,
                                   0.15921489942791345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38328055908512509,
                                   0.38936838327545203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14079783106404348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068438921094476746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14551015798439648,
                                   0,
                                   0,
                                   0,
                                   0.54991142253791758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056661719756765164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5149990140668762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0066002703331134865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21232747274991554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0061320829098875842,
                                   0,
                                   0,
                                   0,
                                   -0.056244186494099388,
                                   0,
                                   0,
                                   0,
                                   0.010074100656352423,
                                   0.35012087637154765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3686533203301342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31791629391452642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13262292783737684,
                                   -0.86134605183333368,
                                   0,
                                   -0.082171608693918929,
                                   0,
                                   -0.11540136385643171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24054103862163839,
                                   0.33201753678645585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29325638317915648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86130699405043243,
                                   -0.079697962346525847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27256393725719519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63651963176353354,
                                   0.37937775590984435,
                                   0,
                                   1.0644516504490562,
                                   0,
                                   -0.040543094299465905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43010041993170012,
                                   -0.032301564695336127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74849568807662625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4694225795927624,
                                   0.39561502351225591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33236121102435973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32885710137570556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041844784883481166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59823095318955644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13618690741539602,
                                   0,
                                   0,
                                   0.33801965776790921,
                                   0,
                                   0,
                                   -0.35954558625018662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10642658643233312,
                                   0,
                                   0,
                                   0,
                                   0.069396629055791664,
                                   0,
                                   0.22308265760241106,
                                   0,
                                   0.1469068175791014,
                                   0.0085585627980510615,
                                   -0.38672207629769551,
                                   0,
                                   0,
                                   0,
                                   -0.18172166528806533,
                                   0.0021409323873056302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38531111354478698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16848071463771777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30824083650598122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55496663170239779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70042856432995126,
                                   0,
                                   0,
                                   0.54445551304295481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27915674468611362,
                                   0,
                                   0.16541399319574057,
                                   0,
                                   0,
                                   -0.03382112456838271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41680759969319475,
                                   0.4731328428212796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066869414283925566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3878665104275375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89805999882342491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41618292452521743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18540030753281639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34632295143019515,
                                   0,
                                   0,
                                   0.17367539902386483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96139071070139792,
                                   0,
                                   -0.25005595279122678,
                                   0,
                                   0,
                                   0.010492614830812451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1517279714278002,
                                   0.41464629306765644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11789568508748687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17340429141342414,
                                   0,
                                   0,
                                   0,
                                   -0.011292863114230445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3305106638670765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53328134437457009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058741605750998474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11537758594498231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27804901183246461,
                                   0,
                                   0,
                                   0,
                                   0.31570326249158587,
                                   0,
                                   0,
                                   0,
                                   -0.43302296221166858,
                                   0.11502727051372617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21531151783932875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36787981295807332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37101438083847443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30134279152878707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067807147243967789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.008642391170997743,
                                   0,
                                   0,
                                   0.046143412105454015,
                                   0,
                                   0,
                                   -0.30083605744624586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45725720985489743,
                                   0,
                                   0,
                                   0,
                                   0.39035303113016284,
                                   0,
                                   0.078068851082120028,
                                   0,
                                   0.051814084507534372,
                                   0.20766724079722465,
                                   -0.0997229247163329,
                                   0,
                                   0,
                                   0,
                                   0.48569381675447076,
                                   -0.12259235349060155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83207509699170235,
                                   0.1848516416222758,
                                   0,
                                   0.30919643999955848,
                                   0,
                                   -0.72340927069038174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35406836414763304,
                                   0.59972067803098827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82103107582021073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048823540114443953,
                                   0.32339719061864014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22208947029361029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12044508471318049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15471932678261588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34662871886585978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094077068279259213,
                                   0,
                                   0,
                                   -0.23697349189079853,
                                   0,
                                   0,
                                   -0.2746540831034977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13493935535029677,
                                   0,
                                   0,
                                   0,
                                   -0.028070741200793781,
                                   0,
                                   -0.49588844161239998,
                                   0,
                                   0.17837995999704617,
                                   0.45346970585910545,
                                   0.39096886316699053,
                                   0,
                                   0,
                                   0,
                                   0.20363715318615208,
                                   0.065427652429143335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01814302587565228,
                                   0,
                                   0,
                                   0,
                                   -0.01801864347534346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15524223779759941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20383981136968038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27596328093730671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29061274791058167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76249569138190043,
                                   0,
                                   0,
                                   0,
                                   -0.027527587091885495,
                                   0,
                                   0,
                                   0,
                                   -0.10775072890671254,
                                   -0.010114195141495046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25675684071470734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33658549749770861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037392184257547229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16110509991330568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28002104882246387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48033306441327206,
                                   0,
                                   0,
                                   -0.28657318652990932,
                                   0,
                                   0,
                                   -0.37092799111710512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29326676662741663,
                                   0,
                                   0,
                                   0,
                                   -0.035488713271239411,
                                   0,
                                   -0.26823989676950227,
                                   0,
                                   0.18488879926498669,
                                   -0.013514438028682657,
                                   -0.30088114357128676,
                                   0,
                                   0,
                                   0,
                                   -0.35601391423185508,
                                   0.18150537111895113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29897130717926873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26027827462921344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23388810546151217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38739435041774839,
                                   0,
                                   0,
                                   -0.15709851890118709,
                                   0,
                                   0,
                                   -0.22378676933695238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54056396411382801,
                                   0,
                                   0,
                                   0,
                                   0.17382768922933634,
                                   0,
                                   0.088925529297702491,
                                   0,
                                   0.010359882633565062,
                                   0.17820739690044302,
                                   -0.43708283929002389,
                                   0,
                                   0,
                                   0,
                                   -0.0031219869101960229,
                                   0.10041569883203083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08840527286915395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55251617950473719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073626205543076667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40535613849633489,
                                   0,
                                   0,
                                   0.37866604925977559,
                                   0,
                                   0,
                                   0.19387259315285385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030634383550398641,
                                   0,
                                   0,
                                   0,
                                   0.29234364328411738,
                                   0,
                                   0.19248993571007833,
                                   0,
                                   -0.020814118918868335,
                                   0.26025710213790931,
                                   0.079143817839313804,
                                   0,
                                   0,
                                   0,
                                   0.22233619976775063,
                                   0.29813023958417301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46218866503124456,
                                   0,
                                   0,
                                   0,
                                   -0.18046499193968385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45383034962405416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052343575621124044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26229895320867508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23077597740003702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0027042818501355325,
                                   0,
                                   0,
                                   0,
                                   -0.31908357534190046,
                                   0,
                                   0,
                                   0,
                                   0.18393795324135531,
                                   0.3643709411428091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11310892735309987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37661554909570494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36091270558508576,
                                   0,
                                   0,
                                   0,
                                   -0.070823174922259882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36774169743381846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17306682088314762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37545230907019289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41334454380856506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18130344339570845,
                                   0,
                                   0,
                                   0,
                                   -0.29386865727147898,
                                   0,
                                   0,
                                   0,
                                   0.098663233250813664,
                                   -0.381105272243211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0704524429927951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32947372106469619,
                                   0,
                                   0.88622089484032163,
                                   0,
                                   0,
                                   0.44225624045616113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58562782380111478,
                                   -0.43913028080752547,
                                   0,
                                   0,
                                   3.953733166262019e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55553121633156288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42548390557754051,
                                   -0.31625950027353467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19239742461481874,
                                   0,
                                   0,
                                   0,
                                   0.26325062424902557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18085952745169731,
                                   -0.35017575187348765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24654053154783506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34671599615724402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056339291640923932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088065397641271553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059954210871314272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26525393636016936,
                                   0,
                                   0,
                                   0.38134109971647018,
                                   0,
                                   0,
                                   -0.42183228597435407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29664230441445988,
                                   0,
                                   0,
                                   0,
                                   -0.015656568173363972,
                                   0,
                                   -0.29190283768326641,
                                   0,
                                   -0.38313503173295804,
                                   -0.24911729607689209,
                                   0.054345829004992796,
                                   0,
                                   0,
                                   0,
                                   0.085684044692164618,
                                   -0.44626958673322437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032908898585206105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29925893608275073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087070140953792396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25854896398485938,
                                   0,
                                   0,
                                   0.00071612869662381062,
                                   0,
                                   0,
                                   0.18317134547091463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081712725726924909,
                                   0,
                                   0,
                                   0,
                                   -0.33034628523849502,
                                   0,
                                   -0.029250585755026554,
                                   0,
                                   -0.41677930467679919,
                                   0.60615043234271315,
                                   -0.37735758456485075,
                                   0,
                                   0,
                                   0,
                                   0.0067900718746325955,
                                   -0.033921100790100987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2243563720386004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098939239661322911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21205865219974093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17753360271631871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22852790227321901,
                                   0,
                                   0,
                                   -0.61959798681607647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32232533304728561,
                                   0,
                                   0.89935819125971095,
                                   0,
                                   0,
                                   -0.24348091048763987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028900739914012801,
                                   0.16510515444259841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42852723699784417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66991744756080229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19401986507018276,
                                   0,
                                   0,
                                   0,
                                   -0.21875473332306258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46573058756643365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031958039905773575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27131135339897666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41310490687071921,
                                   0,
                                   0,
                                   -0.059341899085493977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11728186252234582,
                                   0,
                                   0,
                                   0,
                                   -0.30450980783053494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45052213849549494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074321754442448915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36098340062298484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17652720958904891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062703424056525708,
                                   0,
                                   0,
                                   0,
                                   -0.44041465882027542,
                                   0,
                                   0,
                                   0,
                                   -0.091592018407985101,
                                   0.26022753699740692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052176535233677379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49681716876607956,
                                   0.060096235596913072,
                                   0,
                                   0,
                                   0.26536663687342782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35387802856447836,
                                   0,
                                   0.041694103502285598,
                                   0,
                                   -0.30720439644253489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16096564608021258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63802065816582765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072837644451490519,
                                   0,
                                   -0.14308176325031396,
                                   -0.49585116623031961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20422142949275662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50680243422692817,
                                   0,
                                   0,
                                   0,
                                   -0.055980039766235841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10957739138392417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6475515063432542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49487745157478635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14545827220147106,
                                   0,
                                   0,
                                   0.030317922858394859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24584663553778702,
                                   0,
                                   0,
                                   0.49851259349127319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092244836067383998,
                                   0,
                                   -0.24928132341522144,
                                   0,
                                   -0.57953015979888767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23067030440795033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44735988221282902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12963819239321678,
                                   0,
                                   0.0602687022762717,
                                   0.1037357261212777,
                                   0,
                                   0,
                                   -0.28703045179350184,
                                   0,
                                   0,
                                   -0.40851490755798153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2557627894956791,
                                   0,
                                   -0.090001946239577038,
                                   0,
                                   -0.23884464325735461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10492219977814297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28832362599610684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13373948211651351,
                                   0,
                                   0.6424663659284362,
                                   0.30883476144362948,
                                   0,
                                   0,
                                   0,
                                   0.25292933828873559,
                                   0,
                                   0,
                                   -0.70387146396387434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7457202390117007,
                                   0.5061803559571183,
                                   0,
                                   0,
                                   -0.22345055531783675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52219177626582103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050587529871635784,
                                   0.99677430992823368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42812246042384106,
                                   0,
                                   0,
                                   0,
                                   -0.37302845633447423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27746117534718989,
                                   -0.19897270876342776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2284467197054259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19116225395832415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018465047080445246,
                                   0,
                                   0,
                                   0,
                                   -0.26919613220350891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0045929417987664867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4339297769570245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20416902317469679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11568787040499878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20501241273082715,
                                   0,
                                   0,
                                   0,
                                   0.29693501387557597,
                                   0,
                                   0,
                                   0,
                                   -0.31076623881540544,
                                   0.3098276970361753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59439364528600813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087946064051158387,
                                   -0.23878853527502397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65265400704027099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9045270069065916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23788855937053593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1023973203000732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22208083462371841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33459734381655692,
                                   0,
                                   -0.45278859145768346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019985259119525131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44363479220133467,
                                   0.19900570156349762,
                                   0,
                                   0.26635809395318022,
                                   0,
                                   0,
                                   -0.40480357774976522,
                                   0,
                                   0,
                                   -0.17221326100050433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016986278438862377,
                                   0,
                                   -0.31005157447151155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14099801306275186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20321437636353404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13670270381840521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07387799444553303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85255146095473788,
                                   0,
                                   0,
                                   0.076341367961867995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088619134292775598,
                                   0,
                                   0,
                                   0,
                                   -0.30108423167629211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33130935428930774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2430165595080932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076195024386386631,
                                   0,
                                   0.28665472618089899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1013637373779431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25768936273324655,
                                   -0.0085871482710026537,
                                   0,
                                   0.20599891010103602,
                                   0,
                                   0,
                                   -0.071445318394138896,
                                   0,
                                   0,
                                   0.0057346687396916396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37546113235487405,
                                   0,
                                   -0.14859337538607867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65248562706194257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1999853633859261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17909034940923307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35614928865746004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.385343660946738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19429894353187266,
                                   0,
                                   -0.18498597986881049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.190360747631965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11867464787279042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47701609744669893,
                                   0,
                                   0,
                                   -0.03806814410303852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53305955618920242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34807000293011869,
                                   0.053447540968933539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21637365369814884,
                                   0,
                                   0,
                                   0,
                                   0.21270761298638638,
                                   0,
                                   0,
                                   0,
                                   0.012372174461177374,
                                   0,
                                   0,
                                   -0.058563496992134222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42772391263360421,
                                   0,
                                   0,
                                   0,
                                   0.32886271441350784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38236162017334813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74774220635694155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55799479216730452,
                                   0,
                                   0.30612251251804462,
                                   0.53586561339261252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33506524248151631,
                                   0.24972585906124034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32746002703878369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13932126158010916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080663864199412683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49039975030207139,
                                   0,
                                   0,
                                   -0.0094308661842770203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089011150506396144,
                                   0.4393953895395219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52966714970298034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56445136557918396,
                                   0,
                                   0.57369675610833482,
                                   0,
                                   0,
                                   0,
                                   0.44922026421409789,
                                   0,
                                   0.62584295941623325,
                                   0,
                                   -0.53410862106937651,
                                   0,
                                   0.17793349617185161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67159111275093419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56014266209275265,
                                   0,
                                   0.16427355916760267,
                                   -0.051829355684706577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0030881696728551344,
                                   0.41914769702573645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59489918585025503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11925721092914032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3357773985150857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16772694314426692,
                                   0,
                                   -0.6909536339077299,
                                   0.51281457538962549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17090211976508768,
                                   0.018514863552680977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15865348248585587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31040173005881116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28355151800012202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17637053627814164,
                                   0,
                                   0,
                                   -0.056010085728981446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27752181449544189,
                                   0.21853336129914211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60808728451354555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66498274587562611,
                                   0,
                                   -0.52327082651919232,
                                   0,
                                   0,
                                   0,
                                   -0.40401159344428506,
                                   0,
                                   -0.066259355879073459,
                                   0,
                                   -0.85166070537414285,
                                   0,
                                   0.37779322515569658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097261292132518537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42310536721476721,
                                   0,
                                   0,
                                   0,
                                   0.36023135246976012,
                                   0,
                                   0,
                                   0.1845210250222841,
                                   0,
                                   0,
                                   0,
                                   0.41873180758880268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48466263442951563,
                                   0,
                                   0,
                                   0.086731832723625862,
                                   0,
                                   0,
                                   0,
                                   -0.35484290800504636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19608029572514948,
                                   0,
                                   0,
                                   0,
                                   -0.70064655458596903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3864136948349165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047984050958046337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91952785351095068,
                                   0,
                                   0,
                                   0,
                                   0.25915039336475776,
                                   0,
                                   0,
                                   0,
                                   0.41978803196573838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11291959507841859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077045428449778713,
                                   0,
                                   0.2870837110702037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15256899525668638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35241699741789823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48023266808220999,
                                   0,
                                   0,
                                   -0.21743915378629297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041848373705334993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37950793593424142,
                                   0.27743360342831902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069788627306437589,
                                   0,
                                   0,
                                   0,
                                   -0.49588350822924887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78694650346313977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85086883720572104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05297270374374391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10949127407618114,
                                   0,
                                   0,
                                   0.018617449575639461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35393276455705053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39472077764441826,
                                   0,
                                   0,
                                   0,
                                   -0.34027127370437105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63429040574543361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26195607434559059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16640161077521665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032249209110573329,
                                   0,
                                   -0.43551860404258114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01023956853043724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12392211267114178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013220551176166759,
                                   0,
                                   0,
                                   0.5561209181768737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081863524933971935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24965171535294312,
                                   0.27190808839690994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34670895323096984,
                                   0,
                                   0,
                                   0,
                                   -0.43990739720609129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50578979707202798,
                                   0,
                                   0,
                                   0,
                                   0.065916913206444244,
                                   0,
                                   0,
                                   -0.30644994267075798,
                                   0,
                                   0,
                                   0,
                                   0.48497227748272276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0017316776711617798,
                                   0,
                                   0,
                                   -0.98089425577235489,
                                   0,
                                   0,
                                   0,
                                   -0.12301929525456512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49904214275676329,
                                   0,
                                   0,
                                   0,
                                   0.042422561585273022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80251362052085151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25374299270982859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080390650894450827,
                                   0,
                                   0,
                                   0,
                                   -0.37284240585999073,
                                   0,
                                   0,
                                   0,
                                   0.015996561777601045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15223776909285458,
                                   0,
                                   0,
                                   -0.01766338729131221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36119481358011302,
                                   0.24393303666923885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68548822061122727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11410845331010469,
                                   0,
                                   -0.27666180100947857,
                                   0,
                                   0,
                                   0,
                                   -0.26219793669369923,
                                   0,
                                   0.44249589017151869,
                                   0,
                                   0.41806936726431171,
                                   0,
                                   -0.38778444862185008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21851442482102043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0091298917118298531,
                                   0,
                                   0,
                                   0.70359501776156719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62018306616568675,
                                   0.091786841172669026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43314470045577652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13310078660567989,
                                   0,
                                   0.35180112201156505,
                                   0,
                                   0,
                                   0,
                                   -0.66868628164054733,
                                   0,
                                   0.29336805412082861,
                                   0,
                                   -0.12535105235558081,
                                   0,
                                   0.50442200450655672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17292100094337068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36741690100825009,
                                   0,
                                   0,
                                   0,
                                   0.72289078211922331,
                                   0,
                                   0,
                                   0.3781025148604909,
                                   0,
                                   0,
                                   0,
                                   -0.44859627768816868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40640980616370304,
                                   0,
                                   0,
                                   -0.23865817587892263,
                                   0,
                                   0,
                                   0,
                                   0.15521794215219897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13423966781017754,
                                   0,
                                   0,
                                   0,
                                   0.50280109122622108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49321457286748288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4874887722073159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024848269290333402,
                                   0,
                                   0,
                                   0,
                                   -0.58352082646397885,
                                   0,
                                   0,
                                   0,
                                   -0.4114045227401919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14089954795781107,
                                   0,
                                   -0.31730283287766087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52802274625692469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092390110301583311,
                                   -0.34438850585235264,
                                   0,
                                   0.076633573816453443,
                                   0,
                                   0,
                                   0.29830044527020755,
                                   0,
                                   0,
                                   0.096725194311109916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17857062691817027,
                                   0,
                                   -0.0030832376656811447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29182391411866226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015422229572425495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40389867298844723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29812255016020994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45548436484653743,
                                   0,
                                   0,
                                   -0.45407788138171551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026482675231229338,
                                   0,
                                   0,
                                   0,
                                   0.14206232850386266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6290110076172104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4120793443613488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13057973113137175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31494570107585762,
                                   0,
                                   0.16149741321951494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34532416361976226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62100358404781775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066750403010287646,
                                   0,
                                   0,
                                   0.38310246703793183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1403907823355274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023346055284753753,
                                   -0.27744886285413445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28026818484021948,
                                   0,
                                   0,
                                   0,
                                   0.1605510566379704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51367945347704747,
                                   0,
                                   0,
                                   0,
                                   -0.70486316393785986,
                                   0,
                                   0,
                                   0.22436738469020162,
                                   0,
                                   0,
                                   0,
                                   0.62923685610184432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17571785598076647,
                                   0,
                                   0,
                                   -0.34156017499281982,
                                   0,
                                   0,
                                   0,
                                   0.02640555169003269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66716796348026142,
                                   0,
                                   0,
                                   0,
                                   0.14940765267464851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8833987542018874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3452381078163923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0025372293372794927,
                                   0,
                                   0,
                                   0,
                                   -0.24785827762633866,
                                   0,
                                   0,
                                   0,
                                   0.084392199032510357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15462589631231299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05840690697422514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17971610727938889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92387143015261375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86421015468942819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66450283037044855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11692926182751251,
                                   0,
                                   0,
                                   -0.017940357624226765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87972171600463778,
                                   0,
                                   0,
                                   0,
                                   -0.30094842101112051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049350809398191114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34509410193351642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3371023402076323,
                                   0,
                                   0,
                                   0,
                                   -0.78206884587606229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54309112510679547,
                                   0.39827998350923749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26789706806744501,
                                   0,
                                   0,
                                   -0.2081654163722389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092253757099758193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29587266940203782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41065705409574738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027917575834426223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23968355248076456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13135564662097801,
                                   0,
                                   0,
                                   -0.84600675945895343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16030370813269951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92692894987880781,
                                   0,
                                   0,
                                   0,
                                   -0.33305683681279008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10131216079107686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43361480425659177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42415774759323138,
                                   0,
                                   0,
                                   0,
                                   0.094564496500165643,
                                   0,
                                   0,
                                   -0.086397404978219058,
                                   0,
                                   0,
                                   0,
                                   0.52868295044746094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2835533954834335,
                                   0,
                                   0,
                                   0.5358254298861338,
                                   0,
                                   0,
                                   0,
                                   0.58358757885588519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75129980272671626,
                                   0,
                                   0,
                                   0,
                                   -0.52109362220757938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10601590750744375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14517843604084407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10051645473189355,
                                   0,
                                   0,
                                   0,
                                   -0.033119892975893017,
                                   0,
                                   0,
                                   0,
                                   -0.64749036868518162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46824279996780094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46954505428393167,
                                   -0.06360707787065234,
                                   0,
                                   0,
                                   0.18279636098313745,
                                   0,
                                   0,
                                   0.26798527338544786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031709824424613606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.121981361119301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30411074680928291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27285881137441481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51786040868684435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46474673054178856,
                                   0,
                                   0,
                                   0,
                                   -0.073252453674122572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1283799125333423,
                                   0.39735868431662269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36725964905252351,
                                   0,
                                   0,
                                   -0.84055252152868154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32089030814923991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59684789507900127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13329069000502503,
                                   0,
                                   0,
                                   0,
                                   -0.20227480022232974,
                                   0,
                                   0,
                                   0.37579730284770141,
                                   0,
                                   0,
                                   0,
                                   -0.43893523054211031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33693399479730529,
                                   0,
                                   0,
                                   0.31842518875147674,
                                   0,
                                   0,
                                   0,
                                   0.95093818039542832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35088696230851224,
                                   0,
                                   0,
                                   0,
                                   -0.64230673988108977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28530170966424395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33138921744939792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10962813704907116,
                                   0,
                                   0,
                                   0,
                                   -0.29214391182019311,
                                   0,
                                   0,
                                   0,
                                   0.67192106503996474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20506998980371161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29631597571030566,
                                   0,
                                   -0.19785125869025749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43317102717129435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13787493655498906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17758774010180908,
                                   0,
                                   0,
                                   -0.0048059558287191079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32532090256811208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38604886959955542,
                                   0.49216295194351717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17650288632864769,
                                   0,
                                   0,
                                   0,
                                   0.25405869830401684,
                                   0,
                                   0,
                                   -0.19107465560889314,
                                   0,
                                   0.12204868629241486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2077549263290889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35910835290294013,
                                   0.02261946026240402,
                                   0,
                                   0.11048498197295147,
                                   0,
                                   0,
                                   0.39946692886451945,
                                   0,
                                   0,
                                   0.29418533368423555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34188365494064465,
                                   0,
                                   -0.39732823175325255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21268251296989205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041127731525912307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25515965602964236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36173238399613478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082944198753837017,
                                   0,
                                   -0.21738963187771271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35088074566773947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13351747919482226,
                                   0.17418884718566691,
                                   0,
                                   0.18237720957992451,
                                   0,
                                   0,
                                   0.011036567951966537,
                                   0,
                                   0,
                                   0.57021343158296567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012757463237041994,
                                   0,
                                   -0.10066557681043432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07087569408407704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2416358727118893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48892309203629297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32139705711808991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044421822517898883,
                                   0,
                                   0,
                                   0,
                                   0.48782034047842676,
                                   0,
                                   0,
                                   -0.57643317957435791,
                                   0,
                                   0,
                                   0,
                                   -0.12420825740692201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92007817873864239,
                                   0,
                                   0,
                                   -0.42450022895045969,
                                   0,
                                   0,
                                   0,
                                   -0.29549166318726289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017912659463747788,
                                   0,
                                   0,
                                   0,
                                   -0.37067803049325332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43362702644082551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27988815666609052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11710087460523119,
                                   0,
                                   0,
                                   0,
                                   0.041994814011378556,
                                   0,
                                   0,
                                   0,
                                   0.26488452855717409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16803000228661488,
                                   0,
                                   0.21933081714978836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0064344394342656375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18463505096429236,
                                   0.164571867997307,
                                   0,
                                   0.34130342187005175,
                                   0,
                                   0,
                                   0.28458932411412341,
                                   0,
                                   0,
                                   -0.38049808217939968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40605423210167613,
                                   0,
                                   -0.098404077129554776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35172021808854242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21183908457480211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0050760016113252232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42073094764324076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82012187691320226,
                                   0,
                                   0,
                                   0,
                                   -0.19912530586369631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63164020909300567,
                                   0.19386493224405363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12713026517615886,
                                   0,
                                   0,
                                   -0.32413848032571346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80277995996065321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67487598546752781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068842057317127225,
                                   0,
                                   0,
                                   0,
                                   0.42049501109706944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38790426091881347,
                                   0.61362456725570436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74800135348915464,
                                   0,
                                   0,
                                   0.43753433801605601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082772182242229944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064326652632151315,
                                   0,
                                   0,
                                   0,
                                   0.17485627619402586,
                                   0,
                                   -0.26167335979978279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11182454555142993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2816316455066063,
                                   0.090751887981874474,
                                   0,
                                   -0.26686775786428668,
                                   0,
                                   0,
                                   0.15124119912084275,
                                   0,
                                   0,
                                   0.14715998392943302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43094734691210584,
                                   0,
                                   -0.55743662715202102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12247822884389989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00040138432045820974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4035600351529437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10408634609180328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10954076866143408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45772674372249506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83630308041104695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38342963211225867,
                                   0,
                                   0,
                                   -0.0029867291081253078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28368681456751993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24693056789251105,
                                   0,
                                   0,
                                   0,
                                   -0.128958353535437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56026732228176579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46950028111356873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60546827495798994,
                                   0,
                                   0,
                                   0,
                                   0.07912589266240011,
                                   0,
                                   0,
                                   -0.61123550997219855,
                                   0,
                                   0,
                                   0,
                                   -0.67967369412597045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83902099054139667,
                                   0,
                                   0,
                                   -0.19602898402701302,
                                   0,
                                   0,
                                   0,
                                   0.17844538701512402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18219784895284874,
                                   0,
                                   0,
                                   0,
                                   -0.28612637523467066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20129906486900859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47639420406389232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43630080497647378,
                                   0,
                                   0,
                                   0,
                                   0.28606363240460875,
                                   0,
                                   0,
                                   0,
                                   0.37669687258007944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22051693588682822,
                                   0,
                                   0.17906733489803486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10140215504682557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16610292609992122,
                                   0.31133504472952572,
                                   0,
                                   -0.16448318346025767,
                                   0,
                                   0,
                                   0.40258467678696674,
                                   0,
                                   0,
                                   -0.31899159243941233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3403606001225965,
                                   0,
                                   -0.29012170808084931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2027969371023064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21793567875006589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44945881405282184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054484665624247378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12713239389868883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10857903168265887,
                                   -0.089720852082420727,
                                   0,
                                   0,
                                   0.64659114193977696,
                                   0,
                                   0,
                                   0.3153614940249051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3977405076456943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31115418731466959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22880937580998464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30826073779964086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2099340077748228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38961723263528825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21541484258918309,
                                   -0.27467355765697543,
                                   0,
                                   0,
                                   0.0872468105296198,
                                   0,
                                   0,
                                   -0.0087669720961367908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080705745124781875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68571559902280765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19524717452619744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32070510101859795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3177544768897187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0041745716689379417,
                                   0,
                                   0,
                                   0,
                                   -0.6186267331705797,
                                   0,
                                   0,
                                   0.060683807184081631,
                                   0,
                                   0,
                                   0,
                                   -0.19629358902439054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055593396899567646,
                                   0,
                                   0,
                                   0.015882566748477597,
                                   0,
                                   0,
                                   0,
                                   -0.13035976321886245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65292836673190024,
                                   0,
                                   0,
                                   0,
                                   -0.90826481408997772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15284677399266955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63943996294796857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01132420702715049,
                                   0,
                                   0,
                                   0,
                                   0.0025777258037434879,
                                   0,
                                   0,
                                   0,
                                   -0.76947621974596037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22783550946002626,
                                   0,
                                   0,
                                   0.58605068485260037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57689990073906783,
                                   -0.2738804629917363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39838612145161301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64306664191660057,
                                   0,
                                   -0.35608851129003694,
                                   0,
                                   0,
                                   0,
                                   -0.26004854373496245,
                                   0,
                                   0.15230553613689457,
                                   0,
                                   -0.071203159459566456,
                                   0,
                                   -0.40383139378403471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.467974342970851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45441015243619221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38858004812153402,
                                   0.28813992334269478,
                                   0,
                                   0,
                                   -0.31812828699007933,
                                   0,
                                   0,
                                   0.075591411278000092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2011298508384709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083854494798727156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22347672639001021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54609586833129287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23859031383492149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88100049639401612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25838541865575093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19637231043773168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62079125737761665,
                                   0,
                                   0,
                                   -0.38383170114947457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4781657530871517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59947312435685207,
                                   0,
                                   0,
                                   0,
                                   -0.65586996388711283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27269009347080059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30174853452677752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04132534643619637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3973845225323262,
                                   0,
                                   -0.30866827327456176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57953838192580975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074986242419228313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36291217168646922,
                                   0,
                                   0,
                                   0.016562628870435796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21242777728768791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30849082324438171,
                                   0.082296019685095465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35010593764132703,
                                   0,
                                   0,
                                   0,
                                   -0.044670631735495576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27216904296898087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10428732501721838,
                                   0.5366873400394141,
                                   0,
                                   0,
                                   0.062991013742212124,
                                   0,
                                   0,
                                   0.37671745310579297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33297478178469248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13686679052375603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40531137568643938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27139826993543059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33703397722947476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25147840113545356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33045397672726534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5189511132539899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17257347277806551,
                                   0,
                                   0,
                                   0.21331039331912968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93712755289873173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39397500638100869,
                                   0,
                                   0,
                                   0,
                                   -0.59279216197037943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24402484663796153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22505321631465272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098024207238505731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54507815161132034,
                                   0,
                                   -0.42065869381093329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20611399268106342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48194891409060214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3242013273020703,
                                   0,
                                   0,
                                   -0.3179580887745399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056710214139140541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.117810069093243,
                                   0.087002436854352605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0076831536355237706,
                                   0,
                                   0,
                                   0,
                                   0.10316021763771305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21546464891801073,
                                   0,
                                   0,
                                   0,
                                   0.40950611769900147,
                                   0,
                                   0,
                                   -0.33540971105819584,
                                   0,
                                   0,
                                   0,
                                   0.11673744963359937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26971621940860629,
                                   0,
                                   0,
                                   -0.30234915098258119,
                                   0,
                                   0,
                                   0,
                                   0.84160839513100438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83124448425121922,
                                   0,
                                   0,
                                   0,
                                   0.077580837501394148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35419752571274099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5440168669539529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27944863470612025,
                                   0,
                                   0,
                                   0,
                                   -0.17648833811214409,
                                   0,
                                   0,
                                   0,
                                   -0.27888990178225459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11579729015825674,
                                   0,
                                   0.27618946778192233,
                                   0.361220645286425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52921964069309757,
                                   -0.087908359056206711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16696123649406289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27679407992593419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62252524931623965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22038353059161869,
                                   0,
                                   -0.099170439819053935,
                                   -0.078352203447393534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60669659877326088,
                                   -0.1960734414080017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31021226535290758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6458904356784021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12460174019719221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47435802281331091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27024608584451831,
                                   0.18707576729309519,
                                   0,
                                   0,
                                   0.021327356829837989,
                                   0,
                                   0,
                                   -0.2370117367156106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31092001963586835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38125753312224192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42244054677961285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040413477461119222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43382822312868641,
                                   0,
                                   0.03783398479574393,
                                   0,
                                   0.054089511612887137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68726047262295886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24512531599996479,
                                   0.26695177630498523,
                                   0,
                                   0.099856427678986226,
                                   0,
                                   0,
                                   0.014360159319745526,
                                   0,
                                   0,
                                   0.33718139035073275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25378489074741445,
                                   0,
                                   0.13000797673966713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13899182178829977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090862046924370832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19558406548659679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34779428661638823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4716258183094269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.008964792282085382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056867688193689439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0367470555544078,
                                   0,
                                   0,
                                   -0.28579056933290975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37313888508485193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29339245815667792,
                                   0,
                                   0,
                                   0,
                                   -0.51053606637945959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66968345506875815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26224544620402385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33180019661511051,
                                   0,
                                   -0.12155228332600676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050754364725617923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42510027053160843,
                                   0.60767537896043611,
                                   0,
                                   0.36364174300080498,
                                   0,
                                   0,
                                   -0.053875117710454376,
                                   0,
                                   0,
                                   -0.046814930119863804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023884927439210245,
                                   0,
                                   0.13784371450074331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014967488926263553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16057675432021512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15285818097274551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34103174974279959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28095973752777975,
                                   0,
                                   0,
                                   0,
                                   0.74755178693038848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15429322913591495,
                                   0.23304475094105295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72336289481087201,
                                   0,
                                   0,
                                   -0.44601953878816519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55502276154136276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.008225598466087912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12071868388618806,
                                   0,
                                   0.11325076194243287,
                                   -0.25997359737982967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44485877387332728,
                                   -0.62807345184526742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18362649015953342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17948675661714655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49669429194573339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023672796429344153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023624460504622049,
                                   0,
                                   0.27710895158084087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31363229475502291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15726837356398005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37374779322564944,
                                   0,
                                   0,
                                   -0.040167318480303749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16489773951378586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32250578083655113,
                                   0.43603850882763318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47478547961600748,
                                   0,
                                   0,
                                   0,
                                   -0.33307754723572064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18480588925533778,
                                   0,
                                   0,
                                   0,
                                   -0.059783746645693484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37365484965873907,
                                   1.058162962029892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55395937698115183,
                                   0,
                                   0,
                                   0.40062851106440045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75748028865918393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18903712063029199,
                                   0,
                                   0,
                                   0,
                                   0.64042007035529536,
                                   0,
                                   -0.16107134379827059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093146611751332445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12225952951556597,
                                   -0.0097757073127486618,
                                   0,
                                   0.31329037077301952,
                                   0,
                                   0,
                                   0.33049181639386471,
                                   0,
                                   0,
                                   -0.063277509572884333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061686701640441599,
                                   0,
                                   0.28279976858422995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056906460425098032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43095928031227804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1526495916480482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18103056215765706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35379519873682619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54493592430440585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017315076900890576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59580090514731576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1837922800542287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34600103590017423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36391499198053401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2357784648964284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0018703600412343091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42932041716218522,
                                   0,
                                   0,
                                   0.88171180113946268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095513601883363414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50960068554915372,
                                   0,
                                   0,
                                   0,
                                   -0.95112159975078492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19224105115360554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017648631548442706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70928125072970838,
                                   0,
                                   0,
                                   0,
                                   -0.71614052518597038,
                                   0,
                                   0,
                                   0.078780176056579901,
                                   0,
                                   0,
                                   0,
                                   -0.38859365178582345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34498588562167937,
                                   0,
                                   0,
                                   0.28034549087180649,
                                   0,
                                   0,
                                   0,
                                   -0.38828218444428481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32291038162741992,
                                   0,
                                   0,
                                   0,
                                   0.44144012810649058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022856961906593597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26645752513202481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82317262390686718,
                                   0,
                                   0,
                                   0,
                                   0.42532196489883872,
                                   0,
                                   0,
                                   0,
                                   0.034030440279962312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18083738956403464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57949919472819134,
                                   -0.48856183954208987,
                                   0,
                                   0,
                                   0.15615268213369027,
                                   0,
                                   0,
                                   -0.23536325090964122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28630493142168201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11642746490701772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071242955056693175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38581019282084905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25210196131976842,
                                   0,
                                   -0.26605372837406194,
                                   0,
                                   -0.52665962215473339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16456898899353345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3689012365723488,
                                   0.10878191291325598,
                                   0,
                                   -0.22342733882226862,
                                   0,
                                   0,
                                   0.39595972491762738,
                                   0,
                                   0,
                                   -0.15118665429856853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072602712080678117,
                                   0,
                                   0.32526239031415954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33077868198870081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12607073278318992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060984272089532228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084764197056974508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049579746354574822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91479994200409798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0326198366654087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34350391155577359,
                                   0,
                                   0,
                                   0.47206913555710006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38904265292479256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18513300193761478,
                                   0,
                                   0,
                                   0,
                                   0.44773403613379881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55097639003485155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067164122251578542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26401293989859481,
                                   0,
                                   0,
                                   -0.47074054217863415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28837866247524135,
                                   0.54463542982983082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52905921867538908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52310302219700522,
                                   0,
                                   0.45394977630193178,
                                   0,
                                   0,
                                   0,
                                   0.11389164098602128,
                                   0,
                                   0.31123909600491778,
                                   0,
                                   -0.42508440645792489,
                                   0,
                                   -0.59071242543969438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020911205491013385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034045847258953862,
                                   0,
                                   0,
                                   0,
                                   0.1006615799437203,
                                   0,
                                   0,
                                   -0.027695027204351463,
                                   0,
                                   0,
                                   0,
                                   0.28649016492038831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28293148747412411,
                                   0,
                                   0,
                                   -0.43432678132137659,
                                   0,
                                   0,
                                   0,
                                   0.58237651453947092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12588634918487118,
                                   0,
                                   0,
                                   0,
                                   0.19305942843034424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0082072509366707229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39997155409411317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18071377707870925,
                                   0,
                                   0,
                                   0,
                                   1.1497609591218321,
                                   0,
                                   0,
                                   0,
                                   0.38942691689308434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16192349537601561,
                                   0,
                                   0,
                                   -0.33915217262213526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10675839820565949,
                                   0.74393686558637373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4176188501305505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.498659380851115,
                                   0,
                                   -0.79600848389620449,
                                   0,
                                   0,
                                   0,
                                   0.26636307603320408,
                                   0,
                                   -0.20691968845489156,
                                   0,
                                   0.13465131568534097,
                                   0,
                                   -0.02144812831456798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0011896728937240732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49927050658757299,
                                   0,
                                   -0.30482447034964411,
                                   -0.4890284160160141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0017264895909324951,
                                   0.52079161791149442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0662317692633137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012026030772192844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37802651907988116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28093205795708598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85024216560279064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49336370227276194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24334186237489341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49434658917441754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46210897940572498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28608367617618585,
                                   0,
                                   0,
                                   0,
                                   -0.13325522670702847,
                                   0,
                                   0,
                                   -0.70649251050584294,
                                   0,
                                   0,
                                   0,
                                   0.0042131635658002875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2702288462628048,
                                   0,
                                   0,
                                   0.26459704084082331,
                                   0,
                                   0,
                                   0,
                                   -0.060780228527571228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14606536374863671,
                                   0,
                                   0,
                                   0,
                                   0.42814227511779196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45861903653630354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6657496292988565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25352127227093291,
                                   0,
                                   0,
                                   0,
                                   0.011471963882303843,
                                   0,
                                   0,
                                   0,
                                   0.17860032189931849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12322220664869106,
                                   0,
                                   0,
                                   0.21356444870911673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26227842839458304,
                                   -0.051541367472366179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55640947518026806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12661026770166911,
                                   0,
                                   -0.0042814957004154372,
                                   0,
                                   0,
                                   0,
                                   -0.42319047886536931,
                                   0,
                                   -0.85116194465837558,
                                   0,
                                   -0.30731911465955242,
                                   0,
                                   -0.99403070364431112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03047103054583284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073802538543087812,
                                   0,
                                   -0.047521076527365237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075044553392020208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10059955072468912,
                                   0.37112385718453506,
                                   0,
                                   -0.53704748653490353,
                                   0,
                                   0,
                                   -0.17313026064477119,
                                   0,
                                   0,
                                   -0.11071170437306149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010607467637317375,
                                   0,
                                   0.010775255727609042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22630059680327352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6217943010027045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12884347062419735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23127799698250487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32924374169993098,
                                   0,
                                   0,
                                   0.64876076745998978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32323413918554411,
                                   0.45042015043810268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24294914555654715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49736319378843041,
                                   0,
                                   0.41850594214304854,
                                   0,
                                   0,
                                   0,
                                   0.38751662329226277,
                                   0,
                                   -0.3060285128231936,
                                   0,
                                   0.51169841200125588,
                                   0,
                                   0.2338077344204193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10625881036060195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0285944383614596,
                                   0,
                                   0,
                                   0,
                                   -0.100011970448627,
                                   0,
                                   0,
                                   0.43384686097305619,
                                   0,
                                   0,
                                   0,
                                   -0.081373740721531043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29915883527217257,
                                   0,
                                   0,
                                   -0.58437231231033515,
                                   0,
                                   0,
                                   0,
                                   -0.00296024977870794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56555483651158978,
                                   0,
                                   0,
                                   0,
                                   0.047986341295246697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28515732923954912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36374675164415282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60732731571164456,
                                   0,
                                   0,
                                   0,
                                   0.47420791195011774,
                                   0,
                                   0,
                                   0,
                                   -0.32881244138080806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62047886444004341,
                                   0,
                                   0,
                                   0.17154703402658142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58526472674786501,
                                   0.42266911964922355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43943003673925851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1093638290280862,
                                   0,
                                   0.040950897336611725,
                                   0,
                                   0,
                                   0,
                                   -0.03445623748241939,
                                   0,
                                   0.058337336160398323,
                                   0,
                                   -0.0059731717344483713,
                                   0,
                                   0.55739605050707086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8708312529472656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57565505159224084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12966721423724314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035144137988977059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074519171179235899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25444599775808524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.5630480788936938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66097671101943645,
                                   0,
                                   0,
                                   0.46373734551581058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1852756376945221,
                                   0.044590796511299297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0080133995310154027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26539501987012415,
                                   0,
                                   -0.066985455587489501,
                                   0,
                                   0,
                                   0,
                                   0.53223567248531833,
                                   0,
                                   0.37290219916181289,
                                   0,
                                   -0.37627653122296262,
                                   0,
                                   -0.24476898892193028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2129407405022479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5694546726430546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18982926597730931,
                                   0,
                                   0.2174160014160002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11274140187752014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093391489368883251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12410521721866719,
                                   0,
                                   0,
                                   -0.091228791459001563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3878678614232357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084820322026101236,
                                   0.42435056260306692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15674588783544513,
                                   0,
                                   0,
                                   0,
                                   0.43009356924681946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15742777238074052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51655068290881001,
                                   0,
                                   0.28940452973309699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2249683738032674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03105082282016014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0743734612356763,
                                   0,
                                   0,
                                   0.59942231208968944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061536370033220919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27452567028703373,
                                   0.22281194943923877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091259413908602441,
                                   0,
                                   0,
                                   0,
                                   0.26664386349541547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15220126281968874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012476138938417425,
                                   0.49389788205141877,
                                   0,
                                   0,
                                   0.30748188223307565,
                                   0,
                                   0,
                                   -0.35020101093977302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07317417242754766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39402714184149978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42063649865170244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29733178706774976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29934101636171973,
                                   0,
                                   0,
                                   0.18185202938008665,
                                   0,
                                   0,
                                   0.10938623313079124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18596649355896336,
                                   0,
                                   0,
                                   0,
                                   0.83084535501966961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40297699990902092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26016627043440738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.645706668639907,
                                   0,
                                   0,
                                   -0.31064408531327597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6318684733943809,
                                   0.2183301929214673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25875484500969587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33307816567972248,
                                   0,
                                   0.24948010241931198,
                                   0,
                                   0,
                                   0,
                                   -0.42982674845085678,
                                   0,
                                   -0.042338562881472287,
                                   0,
                                   0.30653715740459048,
                                   0,
                                   0.229822798971628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097659312475309693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81968451032254652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60294910280805925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049276818793082419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41626769239619171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87288244241322466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49681798953727996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27519670885238551,
                                   0,
                                   0,
                                   0,
                                   -0.24749736143392639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50415205605920077,
                                   0.082358037359509334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32973839107971514,
                                   0,
                                   0,
                                   0.3400851049974204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3720085919111344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29194561850474587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75283360413111478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84215791498075177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16702975974219431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4133487512337205,
                                   0,
                                   0,
                                   0.66558781654443444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17648711575024983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31253915905134139,
                                   0,
                                   0,
                                   0,
                                   0.3480152179010727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13899875578140286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37868919432647696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33714747894030389,
                                   0,
                                   0.27939050056571008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071527164597364218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19624880054017094,
                                   0.2973587660484428,
                                   0,
                                   -0.20449530658439341,
                                   0,
                                   0,
                                   0.13160418455937131,
                                   0,
                                   0,
                                   0.35506848733971763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41133754272965395,
                                   0,
                                   0.29562692514772115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23605388048843218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37911994537120447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1086856790541635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15214842476460538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073756291612490088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38703572509164658,
                                   -0.044001690344965733,
                                   0,
                                   0,
                                   0.16835862325809006,
                                   0,
                                   0,
                                   0.55925351802952228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63169920043270189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2795034450906797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064018256471500778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07657686407797612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12078773043997494,
                                   0,
                                   0,
                                   0.13709236390918372,
                                   0,
                                   0,
                                   0.87878802083746343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0019331772905875292,
                                   0,
                                   0,
                                   0,
                                   0.011913826324468267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4284307302601722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15886702340943629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22286302430188243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014770602883598546,
                                   0,
                                   0.36959390471796394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061872391778738926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045883382371014858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32613041947995758,
                                   0,
                                   0,
                                   -0.055290999627489346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58534944306490333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061207143042707531,
                                   -0.14563137869908746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55764123968097512,
                                   0,
                                   0,
                                   0,
                                   -0.14003602744302296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14466419809283784,
                                   0,
                                   0.45828723506737951,
                                   -0.061874778130345781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11161411842554585,
                                   0.22301694779666345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59285826522576635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58640304474795246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087594907518341023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28079100009724295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35990934102282568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30364018159118822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059547050677085434,
                                   0,
                                   0,
                                   -0.016514309639479727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64256756554410566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41183692909517655,
                                   0,
                                   0,
                                   0,
                                   0.26946075931026409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52113837801007523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88467179853230671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57224783609907737,
                                   0,
                                   0,
                                   0,
                                   0.040433061747730814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3013484949589943,
                                   0.27630286031117812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54845450924333461,
                                   0,
                                   0,
                                   -0.41739759618519057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16429423694570794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72630346519268096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58425865759963014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09806765384588767,
                                   0,
                                   0.10870407546795402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29938638200913315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40900428605723621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043251560232676713,
                                   0,
                                   0,
                                   -0.14675824365738338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0972433974124777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47281637927919373,
                                   0.2676546308981036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16274400347971213,
                                   0,
                                   0,
                                   0,
                                   0.16045675433344181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21423576246221215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025682900270815295,
                                   0.14778209727420472,
                                   0,
                                   0,
                                   0.53664853919430811,
                                   0,
                                   0,
                                   -0.36612619667311019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31609812465305109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0064355570175732638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48811610318547199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33322806706050512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24557303651316595,
                                   0.44161135208415103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84782186931789794,
                                   0,
                                   -0.20906583690354241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15505327795922746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48347030620103015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67886972666509515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18492491278725576,
                                   0,
                                   -0.18215720535669422,
                                   -0.17729485952395971,
                                   -0.53523841063264688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63441013554506709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50715820517811117,
                                   0.028235013060561275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40588350029205916,
                                   0,
                                   0,
                                   -0.7181106730267135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12276935618520106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43750833709990616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66464803318671595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028427333336029911,
                                   -0.66037575632084522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6405320552263003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20672874026552257,
                                   0,
                                   -0.44587428220291725,
                                   0,
                                   0,
                                   0.61184165954653413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19050430060265744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13333023706182617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067425241406541436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080868885712471861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047311228708091138,
                                   0,
                                   0,
                                   0.017502051379346767,
                                   0,
                                   0.21594523204291122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39548881988244217,
                                   0,
                                   0,
                                   0,
                                   0.22952566373567596,
                                   0.34110915315179541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59129135360095164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20109198570575787,
                                   0,
                                   0.22486088760244116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34582284542012109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36290621692990632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061153498142692747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77722319020810493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31488884167555042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35668916641945148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05503965627461558,
                                   0,
                                   0,
                                   -0.51422051909792277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74531454786799167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77447193057941011,
                                   0.26917308263002321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10962864018393118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16095911317498332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28595267478481612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45611826673880124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13920201813153629,
                                   -0.33400002073347268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74752993702367898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42676642994807823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2698011306404734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23525208123630925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13422715653673617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68972311912012196,
                                   0,
                                   0.19515353213410946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016122110358441518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27852128191912751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34412381247039447,
                                   0,
                                   0,
                                   0.2306453703759242,
                                   0,
                                   0,
                                   0.46768330757635446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094228182555323711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17984149607605271,
                                   0,
                                   0.30525163376585784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10959305617843457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43669384497638597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10209122250677656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29173082225604346,
                                   0,
                                   0.34052286435733092,
                                   -0.23413392512219855,
                                   0.66295241617704259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85027150375946248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23413037096080469,
                                   1.0054577135133684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47659368729018187,
                                   0,
                                   0,
                                   0.42295310777407685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09334443846885393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52270272519557825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59817560499557265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98269149514376231,
                                   0.16146594510966059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13043941573795187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0751923358665742,
                                   0,
                                   -0.18580742846808423,
                                   0,
                                   0,
                                   -0.41407864443459264,
                                   0,
                                   0,
                                   -0.70648364496798699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48384842099038211,
                                   0,
                                   -0.56044974363916789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45067005393554183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19091018021791989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59031020113379329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20962785724235694,
                                   0,
                                   -0.65808551056221254,
                                   0.10327888942321758,
                                   0.013475355020222485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15573793472611008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056094296728504967,
                                   -0.064387225169677292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47066111126162186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11819045831341038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47179259539527096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52491663247046483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85462738076902967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23447901664347209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23815978981681782,
                                   0,
                                   0,
                                   0.87087137579048413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15983139987485478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29876914837274332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090423166606551086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17154543837156805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50920448166965937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32637791305826824,
                                   0,
                                   0,
                                   0.00062800212905727085,
                                   0,
                                   -0.28915285250131245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14727248649444108,
                                   0,
                                   0,
                                   0,
                                   -0.18986999482733882,
                                   -0.19739086747287335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43775869273078766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19847255727888533,
                                   0,
                                   0.29048518811629087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10771568302476535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46705382488844349,
                                   -0.46898237838571372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018831107936147382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014428692865309817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27803458384173202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52144968326614038,
                                   0,
                                   0,
                                   0,
                                   0.024884091630319169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4584282020399183,
                                   -0.036247106899961024,
                                   0,
                                   -0.0071390773920096129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2772413954507828,
                                   -0.30881437022383168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32804706577049975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063581945336163861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20120066306088807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58905188865272951,
                                   0,
                                   0,
                                   0,
                                   -0.034614824512902133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21075109144089202,
                                   0.40520636604970217,
                                   0,
                                   -0.34473629082258989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066327639813284323,
                                   0.78339942533728701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069107723640260937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59494913600961807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13375163505690571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072499191666417523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40819424006950256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10043439859406578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1111510946650331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6198697403610991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20495488928549091,
                                   -0.51638538913000409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0726200214990396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25192523349666351,
                                   0,
                                   0.66489727106045249,
                                   0,
                                   0,
                                   0.19494006503132999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29789282257203487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1454485237050076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0043611979070310725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1295101564659191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42404832918797625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26337934894635079,
                                   0,
                                   0,
                                   -0.2317281533887674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12791880169408382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11519480751311539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35507032895673818,
                                   0,
                                   0.23348821408529249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056854248048060219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20430434398050321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1693267794244831,
                                   0,
                                   0,
                                   -0.097677699316411778,
                                   0,
                                   0,
                                   -0.85026661114935254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72875469515473801,
                                   0,
                                   0.27062714748130834,
                                   0,
                                   -0.51209423050348968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15557727226131621,
                                   0,
                                   -0.11381405214163474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011512237638158743,
                                   0.17426768299905143,
                                   -0.039865919249349846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047389833209732002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079063013918222624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2301643406722243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052112241004118091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0074928090089218524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53056560483726367,
                                   0,
                                   -0.62140316249503824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0021764693371173344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10626618225305653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55136978602090603,
                                   0,
                                   0,
                                   0.088487564927056589,
                                   0,
                                   0,
                                   -0.0957401578498428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1499205696001667,
                                   0,
                                   0.32823890256939914,
                                   0,
                                   0.23841275353604779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30539307724758435,
                                   0,
                                   0.022542064434591887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17767834354819823,
                                   0.25173922523473169,
                                   0.032939653767354499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24238418156988295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5583099242766979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24599300275053249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43837136745108035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12629061817172349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20948981876831005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1156000387493037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17583668815819453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03591960716156091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44151906893210691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09306387465007801,
                                   0,
                                   -0.2911478270204933,
                                   0,
                                   0.026704210047142511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038952100550329834,
                                   0,
                                   -0.42803199914941359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00095074167575691241,
                                   0.24633725266015277,
                                   0.35305507353583493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49850513300412302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47489922654185079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063839090966564718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24018197547853049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017809013049811889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15915156207126288,
                                   0,
                                   0.29754463008240556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0046912709832932498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2835976736439334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4069451453227963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0731587036909993,
                                   0,
                                   -0.33064119380395446,
                                   -0.12556219227109147,
                                   0.11449435772208826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061432677972584518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11992732482035322,
                                   0.14138413692400797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19525724540494427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28368877512802193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10456418776961116,
                                   0,
                                   -0.6411435591383341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021553698087533366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43380699654512145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51228797963431538,
                                   0,
                                   0,
                                   -0.21391490987558898,
                                   0,
                                   0,
                                   -0.025890368483941023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61988576210407353,
                                   0,
                                   -0.39935047873620783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89759645622752848,
                                   0,
                                   0,
                                   0.59993150299868481,
                                   0,
                                   0.12329186729745294,
                                   0,
                                   0,
                                   0,
                                   -0.59381014049212977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037558441535787815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13738889903776877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32362695018063814,
                                   0,
                                   0.50654317670416094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29458773851743958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10485834233199626,
                                   0,
                                   0,
                                   -0.33454124639776778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12643196465459303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62924032928704987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0077333632709694206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37044715792325766,
                                   0,
                                   0,
                                   0.42582004245663485,
                                   0,
                                   0.16431014574090386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23382473748241292,
                                   0,
                                   0,
                                   0,
                                   0.18070768492752889,
                                   0.087872461502832344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1323655308421961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0087869364227494418,
                                   0,
                                   -0.020220635984414273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13222981370048076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16529562161528838,
                                   0,
                                   -0.071485892920179955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57504931649531954,
                                   0,
                                   0,
                                   -0.011435479756422409,
                                   0,
                                   0.66259551127575889,
                                   0,
                                   0,
                                   0,
                                   -0.25774028623315381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61234730046505514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32741089754837782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041333425981504746,
                                   0,
                                   0.81456693838193373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65525022618336837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20640410009056173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037427327611761665,
                                   0.13470288498283195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12112916827686368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016882922842527098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1833427334896674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15227481920488736,
                                   0,
                                   0,
                                   0,
                                   0.20717241132994235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28658346448530941,
                                   0.55127074592956238,
                                   0,
                                   0.69263620717967533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4278811482653479,
                                   0,
                                   -0.33283875566527021,
                                   0,
                                   0.53633903248525339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21421318322742311,
                                   0,
                                   0.35071854738434588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027124049023522168,
                                   0.25948687988455216,
                                   0.085755233684919413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30338183861901852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047217901319856495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05942391078455142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27633558261188024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28870775293456868,
                                   -0.0667644810716507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30833013920591884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12479444363546313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30778934227522037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84072286179184563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12882717701544494,
                                   0,
                                   0.44897842857810255,
                                   0,
                                   0.13896290917382403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23426088071641404,
                                   0,
                                   -0.085877739320580113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099221051476444042,
                                   -0.18705758994064126,
                                   -0.33448541601921872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15054533881282858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39428372319248017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30024658554790018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52466243869450513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26614507221987471,
                                   0,
                                   0.68778169508165843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16934346154344193,
                                   0,
                                   0,
                                   0.69108937607318854,
                                   0,
                                   0.0037554288565658928,
                                   0,
                                   0,
                                   0,
                                   0.009604473087075252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16759913280794803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22201000833461082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25161204393704628,
                                   0,
                                   0.20300639889807703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30072924455795741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0497337488157215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73080652424732873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28138885695426114,
                                   0,
                                   0.21443441418956569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30778121649599616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32041833113086549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027983986822129849,
                                   0,
                                   0,
                                   -0.37120445291848747,
                                   0,
                                   0,
                                   0.069188032008975803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030547137160605406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0071651155991400359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1450075501298137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49150141302187011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27653298887268246,
                                   0,
                                   0,
                                   -0.2817232400270997,
                                   0,
                                   0.52811927496816047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19480785615094132,
                                   0,
                                   0,
                                   0,
                                   0.1406551628435477,
                                   -0.22267204816228123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24539135072870774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32176148922590653,
                                   0,
                                   0.13783242064846424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10772323150031862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53506658076348901,
                                   0,
                                   0.35501750806799559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75030760108385164,
                                   0,
                                   0,
                                   -0.3964035851457674,
                                   0,
                                   -0.03336292428327664,
                                   0,
                                   0,
                                   0,
                                   0.42634482095322701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066659147220949677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1060740579742207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14914075861735324,
                                   0,
                                   -0.19650728827056718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80615845044090551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28055219206998144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63880993499639216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21419659962346424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36605877976607187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66507843664865418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61509208165725127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7498746488214677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74099553048571909,
                                   0,
                                   0.020510437838753809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048515919808335195,
                                   0,
                                   0,
                                   -0.31332555610099255,
                                   0,
                                   -0.15309797057901325,
                                   0,
                                   0,
                                   0,
                                   -0.1574056405810691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0229055838075021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76147065954561088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82031918051876729,
                                   0,
                                   -0.42794220092692925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1944374658712128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19871200459294425,
                                   -0.3137728156825092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4668040380787668,
                                   0,
                                   -0.0098015961290539647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83216480256592196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18958772892464676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086470781418398882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030542752172311519,
                                   0,
                                   0.8278764593603325,
                                   0.15070850504651534,
                                   -0.12954376766498915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50599499824489591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52256447814135054,
                                   0.16322168386505925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12061834129459778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5409903502422132,
                                   -0.41658295843745224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14107650453858026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49522203775731383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49497260631058865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15376199749312186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4427020588265988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061193948007381191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012340336913424607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034287810857697915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21113235720218079,
                                   0,
                                   0,
                                   -0.21603032624445015,
                                   0,
                                   -0.1970890614031611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44431235132491664,
                                   0,
                                   0,
                                   0,
                                   -0.45197435386938867,
                                   0.17496066551227146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048086441878104617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22426757610122677,
                                   0,
                                   0.17010931947966251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39370195450483025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47713285665672622,
                                   0,
                                   -0.18351882146013948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30683883828338182,
                                   0,
                                   0,
                                   0.16396768283183272,
                                   0,
                                   0.61299225175175498,
                                   0,
                                   0,
                                   0,
                                   0.52847789991425953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47892783351151558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29691203782608555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92517992086687029,
                                   0,
                                   -0.25583549177196641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030998839578113967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40690935906702236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099017087902000298,
                                   0.2753363527248382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34547316312765658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3639604807972428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2348855885120284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00043896974738784345,
                                   0,
                                   0,
                                   0,
                                   -0.68126501748985024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36858073023999105,
                                   0.073516588568622213,
                                   0,
                                   -0.044907362519614351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46685503547021512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48173158262640281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079668608849299674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12807356745103976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28233058645620529,
                                   0,
                                   0,
                                   0.17016304491351131,
                                   0,
                                   0.27135304498779922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11633937836800048,
                                   0,
                                   0,
                                   0,
                                   0.086795929913700498,
                                   0.344188170650507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14316178929277137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21679879316451414,
                                   0,
                                   0.017148198013097221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37095508995440502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10977175701794741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57307536027036876,
                                   0,
                                   0.36583768739170436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56685246749849416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59985458338526709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088029297173547599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41442825952173029,
                                   0,
                                   -0.63077794040366242,
                                   -0.3405168887565645,
                                   0.6237533842538705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23295618309949109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26588767097913657,
                                   -0.55874768566234845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14775483366705711,
                                   0,
                                   0,
                                   0,
                                   0.22191529531848359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090370049774772185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24419892959992323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22595398140989423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0692692717356648,
                                   0,
                                   0,
                                   -0.27353885660985622,
                                   0,
                                   -0.19722930513683271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15994714690130377,
                                   0,
                                   0,
                                   0,
                                   0.3072069066560375,
                                   0.47223285563213779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46222504367212291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28267639853953946,
                                   0,
                                   0.095073421648098622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2604178641286542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19310907569382563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50202128911263322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047271767412617072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082846649479435874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82970889702766548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046279581293214016,
                                   0,
                                   0,
                                   1.1367955430795824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15223296055276525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20283107370188078,
                                   0,
                                   -0.30009023519763861,
                                   0,
                                   -0.050281326252748004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29137331840072089,
                                   0,
                                   -0.4888891482157709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31344514108832056,
                                   0.050896361237264889,
                                   0.08772120086160369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54751216150391668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025193972616127436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25656666320575083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26000408368363104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094012754896891787,
                                   0,
                                   -0.40960524932943365,
                                   0,
                                   -0.15151179207610357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40073732490938019,
                                   0,
                                   -0.18044686284862324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49199417618559366,
                                   -0.045210281942662786,
                                   -0.48390894049799449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2651484736193242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22600354002954942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0028985948962850089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087281314748549471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094334720864376359,
                                   0,
                                   -0.2999573019361968,
                                   0,
                                   -0.14641116315862718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24841895857038129,
                                   0,
                                   0.41969573209346761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26159990227413604,
                                   0.16758109509347777,
                                   -0.47094183357938479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31326496862660724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25751550658825889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25302672336488086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30831480646570547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12895108913592723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1829156171022806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28166111786702164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36302347512933836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26868909778334626,
                                   0,
                                   0,
                                   -0.17725593388185715,
                                   0,
                                   0.087665891011162803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15589380873061456,
                                   0,
                                   0,
                                   0,
                                   0.064398739953087508,
                                   -0.068178764171178088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28272931031783177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21308660275415719,
                                   0,
                                   -0.67261770147351074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12899962129139705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080246931066355109,
                                   -0.09835989066040593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47380284108567883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61917882751707043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.002277892479977256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18094468115015971,
                                   0,
                                   0,
                                   0,
                                   0.54473711568929595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013814243526374753,
                                   -0.037637440270654618,
                                   0,
                                   -0.2119483602741945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059013577914429988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62535799439598749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22069752391364994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038778625385367776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5671688267996754,
                                   -0.10018694136346255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027286207631805948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71347857375846435,
                                   0,
                                   -0.14575962199841869,
                                   0,
                                   0,
                                   -0.49911910251019742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93744119726994857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5161074328744738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37581199708223756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0316341050832751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34608371211828215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30465266778891653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25118557902083244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082331961704576587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42166900686708458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074945655849804033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29104669395479288,
                                   0,
                                   0,
                                   0.12779047385310807,
                                   0,
                                   0.38407075049172973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22102114504437478,
                                   0,
                                   0,
                                   0,
                                   -0.56773541209018996,
                                   -0.13730971479782217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16392373669437926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024887898261301687,
                                   0,
                                   0.14606862354553432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24352100822293271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21204051680539204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2934698559250184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065407717196132892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2181398399858423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56444670274184949,
                                   0,
                                   0,
                                   0.0771381994027516,
                                   0,
                                   -0.0096707377195235384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1740332846627054,
                                   0,
                                   0,
                                   0,
                                   0.20060881681022283,
                                   -0.029373408915032154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03837841118470027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069587124170539597,
                                   0,
                                   0.55283704603744466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33025573417661447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010517752352652489,
                                   0,
                                   -0.016675545831034474,
                                   0,
                                   0.055954466450440984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54941144495731342,
                                   0,
                                   0.18301737998053125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10443542762857265,
                                   -0.16188949529109833,
                                   0.28056693563627916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0019726802560641084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0075551507150152242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73741455092394803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038185589296517018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37135394258761256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71435730418487497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92192366699810813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11081890841952784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1853802561426951,
                                   -0.14989792703264571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34261626652471533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54158470743775855,
                                   0,
                                   -0.1390098540621123,
                                   0,
                                   0,
                                   0.57171379879290429,
                                   0,
                                   0,
                                   0,
                                   0.987275012013896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070178495929941229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46883943307583598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10114960834171803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36363004925325465,
                                   0.39017023331758838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06248979820837406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23022111863640451,
                                   0,
                                   -0.60768443695133634,
                                   0,
                                   0,
                                   0.53717475794672831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081430214059565215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14498103670686938,
                                   0,
                                   -0.11398350227956949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69227881290333426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56188119631695477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35623829634704007,
                                   0,
                                   0,
                                   -0.18744134574225008,
                                   0,
                                   0,
                                   -0.048548583855431704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45426803729764997,
                                   0,
                                   0.13049296986235009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2967876416947719,
                                   0,
                                   0,
                                   -0.18566979687252708,
                                   0,
                                   0.33468020738031179,
                                   0,
                                   0,
                                   0,
                                   0.12167479043704292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28166144319639308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.802553721390866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78566403780137506,
                                   0,
                                   -0.2931872371434549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33793042560442466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64206083099033695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64194004717771913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59973401438335328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38254286398803106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093975524283302456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0609010323673818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85134067633143817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36266067963575116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072444666942521441,
                                   0,
                                   -0.071903917526395425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049635801369788755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23408191008578164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23122186094779981,
                                   0,
                                   0,
                                   0.84042093920349115,
                                   0,
                                   0,
                                   -0.20255831477184175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34019708511095814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97924967515956918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25522907452717741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08656528142868869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34509774597927118,
                                   0.74099446003487091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31229763487284257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081018783732572042,
                                   0,
                                   0.63176955937834578,
                                   0,
                                   0,
                                   0.45374800934577847,
                                   0,
                                   0,
                                   -0.5727142455076274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55483059182007333,
                                   0,
                                   0.89028609093745081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3323476550926438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67996611563987264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22206691985464799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20983387811960946,
                                   0,
                                   -0.33277568004291408,
                                   -0.17441411749485447,
                                   -0.42384201734478499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28496842704800834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040088058121082015,
                                   -0.2986916447919028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73568810726323997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.464699837800153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018059082326386644,
                                   0,
                                   0.21458534166865456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64776186080706355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4561051331414861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3245107889780543,
                                   0,
                                   0,
                                   0.06661668976125526,
                                   0,
                                   0,
                                   -0.017570006341489468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32362947692307825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55056259309404021,
                                   0,
                                   0.66146667320789476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55581414074589297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67523015761443017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57322836592608861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04572863135472105,
                                   0,
                                   0.21859859952019661,
                                   0.19687806834744362,
                                   0.047773261977687637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18718714053131974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039010695149891098,
                                   0.055636896940203323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52578705030249273,
                                   0,
                                   0.29987000509361927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035978257679169567,
                                   0,
                                   -0.22856104587636183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45462194081519158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096385620330719041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41823371320827896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44098955306891308,
                                   0,
                                   -0.40175358874286593,
                                   0.2528496822638881,
                                   -0.33876996913355956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44092114724269427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68805283949616403,
                                   0.88714214761381183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020782198179086116,
                                   0,
                                   0.44826159961811862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22870650219836355,
                                   0,
                                   0.39503107277144944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063628459837362206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34199652688917409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36736890906632247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44502124992307462,
                                   0,
                                   0.032258611786156494,
                                   -0.79158778881675462,
                                   -0.94309407475712026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43184986061330044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40091967648930349,
                                   0.10835834841339644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3678082833810028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019848058589845452,
                                   0.15580860350261486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55626848028851272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42092705291286836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69843880017652682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02997949326368364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33586700183396545,
                                   0,
                                   0.25062959049837508,
                                   0,
                                   0.052674012568479478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16762358583212211,
                                   0,
                                   0.029986996720795987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60507971450350262,
                                   0.5546692319720814,
                                   0.079055660823465018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02527140575962869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053407244587079752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29275981933620138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15289938684137588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34559375662404679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37240057624035416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41147517826587043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038660751996638515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26329664992738072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048016298452169807,
                                   0,
                                   0,
                                   0.61153272505562639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71443335419786158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1139769313213886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39834733786548959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31045456176316294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11031182172995464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092124376814400097,
                                   0,
                                   0,
                                   -0.00094826489576571582,
                                   0,
                                   -0.47875071554258641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37187215223179204,
                                   0,
                                   0,
                                   0,
                                   0.1696383587827815,
                                   -0.25182796144634029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061069271614884069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49624407528554632,
                                   0,
                                   0.010515300120666912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038810754905800569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18856981799879888,
                                   0,
                                   0.15013221296642545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092169941197322275,
                                   0,
                                   0,
                                   -0.473095870997638,
                                   0,
                                   0.17980036295771662,
                                   0,
                                   0,
                                   0,
                                   0.65851635134157116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27733022019030917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3035478734528248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47878058663481327,
                                   0,
                                   0.82700998383920044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59901030522266197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022216601602623981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49486460994860437,
                                   -0.15325453359538391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32513265051338153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34151966835356112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36017346504424197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45413436584877681,
                                   0,
                                   0,
                                   0,
                                   0.083520206017895338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050247140809144553,
                                   0.39333309934509914,
                                   0,
                                   -0.095398465766808022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65083530667650846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93272194011897336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2248289258839844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28838469311345993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22783528516760787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15897338152105209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7484190234759921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.810096706630969,
                                   0,
                                   0.44779328690501108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41419353752949867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0035557487871593898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29139040709955993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17256698417621355,
                                   0,
                                   -0.17253919249210309,
                                   0.70890327556868937,
                                   -0.84228451901418377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46999284526923008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0051446538010707678,
                                   0.26891909649985968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2136507667434327,
                                   0,
                                   0,
                                   0,
                                   0.31090462369777511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58281245331444009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066224488167971773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12558479812245743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22727209193248651,
                                   0,
                                   0,
                                   0.41992857555933771,
                                   0,
                                   -0.081120908636635736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35639168853297065,
                                   0,
                                   0,
                                   0,
                                   0.11276406065833926,
                                   -0.054499182770652049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023832624454114444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064629367726134729,
                                   0,
                                   -0.063981247741272479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39673422027081878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26150991814550778,
                                   -0.15754258878149124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47719186141694298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29895291052094636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25099682521116862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24831117473061329,
                                   0,
                                   0,
                                   0,
                                   -0.067016966218067076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48956863713441628,
                                   0.46443597218704435,
                                   0,
                                   -0.071976648086778922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11961300941007307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21609790122096592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23003491316366512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45385369197680653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043148590641786881,
                                   0,
                                   0,
                                   0.40950422102967582,
                                   0,
                                   -0.14538201011583857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051526707412749985,
                                   0,
                                   0,
                                   0,
                                   -0.32611058912328678,
                                   0.45113919625776794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10870916102542229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34759001071898848,
                                   0,
                                   -0.15191110110335007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14546676972972278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018132132054678785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8681859455120029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34581958273125291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35723577321739491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86641138754337377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33994652145732412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17687598191875395,
                                   0,
                                   0.51397950324727482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22183884282013031,
                                   0,
                                   0,
                                   -0.57642637686241305,
                                   0,
                                   -0.28232127439262317,
                                   0,
                                   0,
                                   0,
                                   -1.0822448122567607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24040736448853708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15651389757229836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21575851017928036,
                                   0,
                                   0.18551367367601987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31378376179942308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048327835919126955,
                                   0,
                                   0,
                                   0,
                                   -1.1243449353371855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30874040644884593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19781738699342627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38903838564745613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32148932505141004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15165017952789778,
                                   0,
                                   0,
                                   -0.29961872554415603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.108263562665341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25723619287173538,
                                   0,
                                   0.21188269273642532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26182737152533925,
                                   0,
                                   0,
                                   0.12615835541694817,
                                   0,
                                   -0.26884525498877804,
                                   0,
                                   0,
                                   0,
                                   -0.072273646020046795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2199337875298575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29187124146729509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071764890934077896,
                                   0,
                                   0.04911723108883656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17186102007994244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58680821612606138,
                                   0,
                                   0,
                                   -0.22308191719241105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20645353937252084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26042896203056531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070658212718294311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10463486717804019,
                                   0,
                                   0,
                                   0.43682895229711477,
                                   0,
                                   -0.016326934626928472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34834486924118219,
                                   0,
                                   0,
                                   0,
                                   0.19514651753586074,
                                   -0.34787529808574486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14195009721584972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46608771042424818,
                                   0,
                                   0.02680523845173452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33795172770226412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65029324036220193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026712169752234172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6811782727982354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28042258821968857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6365180580684574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99692500753682434,
                                   0,
                                   0,
                                   0.15639466349947007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012095055330576691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18461858360322836,
                                   0,
                                   0.10214589894877987,
                                   0,
                                   0.53854432225131121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088895077980632772,
                                   0,
                                   -0.43617902530765268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055165119534629256,
                                   0.030441399245550511,
                                   -0.41806264825191708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32179783991316013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3428547545459692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14495696053804649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21548951231779842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73958905650261653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26464097010718446,
                                   0,
                                   0.61714134687160704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60096094582837167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66374736926996913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15355201523199019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03609173912999919,
                                   0,
                                   -0.020230989902142095,
                                   0.61539459879147751,
                                   0.11568038988063772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41598913118592346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1574585098690835,
                                   -0.49646489128702653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078442649551247315,
                                   0,
                                   0.41937588515258134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28697086755156331,
                                   0,
                                   0.063185373560345912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036122737068582739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52768266859442092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70330591570292766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11290626876691011,
                                   0,
                                   -0.226641011925939,
                                   -0.12439436791869767,
                                   -0.06369486173337463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36022494279454603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51605451584864115,
                                   0.52386496334340238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72722983615586934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14524149421296922,
                                   0,
                                   0.018048187252120873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049853604948363744,
                                   0,
                                   0,
                                   -0.37181253881692916,
                                   0,
                                   0.76232651743573365,
                                   0,
                                   0,
                                   0,
                                   -0.098685106999644195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.131883199044211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50224938349677284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030199092231565541,
                                   0,
                                   -0.47696068520898438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35977944835153214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53590917222009815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32764068751540221,
                                   0.27171006824295912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28167942800305273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4317491301626003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18961606210701171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082544676973431833,
                                   0,
                                   0,
                                   0,
                                   0.18891920850055824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42228034851605606,
                                   0.15939779188650841,
                                   0,
                                   -0.52046893883912027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1599409247254085,
                                   -0.096499574238432667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047907706701334374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25705120125346365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74972735768837828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04846065369918548,
                                   0,
                                   0,
                                   0,
                                   -0.328045561380364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30687495239362289,
                                   0.30141596342034693,
                                   0,
                                   -0.19914569733398665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88941298318900852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0079519786600795728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64507669923335798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024547678965023245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28666716695477518,
                                   0.10233551016697556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12892068452216754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73951873811476898,
                                   0,
                                   0.018099319523449925,
                                   0,
                                   0,
                                   0.68687183783201289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49106540890763206,
                                   -0.67053293931125479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34417384617311741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14533859052194403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051520713311531616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21936451173075411,
                                   0,
                                   0,
                                   0,
                                   -0.19907381136224861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1120702284797081,
                                   -0.19261959600956524,
                                   0,
                                   0.17202848320208869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14633416276205241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71447042381076331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40258674381246912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1500894777364759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34604486038208004,
                                   0.53950722101995341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32101248412668537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.007454085361325441,
                                   0,
                                   0.31665958630140378,
                                   0,
                                   0,
                                   -0.51274003242382726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17950388354318733,
                                   0,
                                   -0.023617862898701006,
                                   0,
                                   0.17429799413256242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36768782409836359,
                                   0,
                                   0.024154470020203253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41097979879082192,
                                   -0.61297751616368079,
                                   0.17335018308387418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058203949558893402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24563232492431941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091644676009689452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39274060832791136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69635798744030075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50801196127542192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60669329736666577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019177629758071718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68816552201693093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0477185465824737,
                                   0,
                                   0,
                                   -0.17705093744670641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041355889042410734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54116771361132188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39059783726749941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0056311406771906644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029106915871281835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081630167961297712,
                                   0.66184500597633578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73796998580103224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38398221232733559,
                                   0,
                                   -0.6119504594958779,
                                   0,
                                   0,
                                   0.086513423654232202,
                                   0,
                                   0,
                                   0.34443132490390316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20568748690245528,
                                   0,
                                   0.077245418703459745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15584986878621238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45580975042547484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33736481506793664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28658686196421418,
                                   0,
                                   -0.72447918738984274,
                                   0.65248661506483563,
                                   -0.01422083055603484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031742601119437872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8612354324816327,
                                   0.1893944645069148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68569063022288579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73857618611529463,
                                   0,
                                   0.55268562430152679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31767685231749115,
                                   0,
                                   0,
                                   0.39786638433189986,
                                   0,
                                   0.22415865356023737,
                                   0,
                                   0,
                                   0,
                                   0.037326411638531412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14011075752112828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44744621022141123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066492400151792058,
                                   0,
                                   0.21869671869226565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028786606320412231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54123831033768666,
                                   0.0027443943587266637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072863569291445884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08422362596604531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30140035661964421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18763084168821825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45804688573586538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18741474802697794,
                                   0,
                                   0,
                                   -0.10007898699191847,
                                   0,
                                   0,
                                   0,
                                   -0.17260494901541087,
                                   0,
                                   0,
                                   0,
                                   0.055954366062978406,
                                   0,
                                   0,
                                   -0.3470286730054431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45716272937225033,
                                   0,
                                   0,
                                   0,
                                   -0.2759894591902573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40996950938190768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56910331066067055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10273421618594977,
                                   0,
                                   0.51026660814256197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1774318952530301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27552087507181877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29783440070647293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36517086452261305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27522022207789909,
                                   0,
                                   0,
                                   0,
                                   -0.4994478528283387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2114581010491228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4681982499272298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074838240701981751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45115562642756984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27637465232405761,
                                   0.45228461235277795,
                                   0,
                                   0.48359359859709533,
                                   0,
                                   0.5689500077032259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56180650317469905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24239066732172479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54764410339788749,
                                   -0.1716046613443242,
                                   0,
                                   0,
                                   -0.76536586645715143,
                                   0,
                                   -0.17614204719974685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45661077495932478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61677685468243615,
                                   0,
                                   0,
                                   0,
                                   0.59778691625667701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052692096015597933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66081521391925446,
                                   -0.33393096708389786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4810038396147574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094485228319532127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1920746404133194,
                                   -0.061255118951626449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25716567609974328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43852880228215296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2581026489017374,
                                   0,
                                   0,
                                   0.16011518721008647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25727046841303214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.213323666933629,
                                   -0.11617314290931298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080621351651189554,
                                   0,
                                   0,
                                   0,
                                   -0.68413526172423622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28098996549827154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30026839643112557,
                                   0,
                                   0,
                                   -0.39105929084145996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30408434794868799,
                                   0,
                                   -0.66624500374491713,
                                   0.32636846681574239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39027855552935287,
                                   -0.58927720295055996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17462870567443894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10441632659988326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60210459442875386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026812310127367161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47366789967907375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13744911217493155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058478188898702932,
                                   0,
                                   0,
                                   -0.37114193885816343,
                                   0,
                                   0,
                                   0,
                                   0.23371800317576044,
                                   0,
                                   0,
                                   0,
                                   0.27079926116710457,
                                   0,
                                   0,
                                   -0.043223114943466423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17822964686863901,
                                   0,
                                   0,
                                   0,
                                   -0.16534081700012579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14834302476094191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22089623943325645,
                                   0,
                                   -0.63088244005763994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046523499619100822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063774889925239928,
                                   -0.21423267509010235,
                                   0.23781310409250728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20366474075155161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38223635605235945,
                                   0,
                                   0,
                                   -0.3913837172058553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32209415000516345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67182760995974122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47446825813863908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062157819474377332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82718817561121583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33386295512986763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42139079894436504,
                                   -0.31679755502740814,
                                   0,
                                   0.12790015155085435,
                                   0,
                                   -0.63491217897169339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046878930238140812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13665706048233234,
                                   0,
                                   -0.12193153824503167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19257265543827964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052592834693624226,
                                   0.75861862140656267,
                                   -0.25819707154134613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10995156954002967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082101234933294839,
                                   0,
                                   0,
                                   -0.50925101561375108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079201111703189234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62105492763769155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58490878729244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21826690863602843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30483786116947559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36163651717147943,
                                   0.028721974952957439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23704583723622846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030702774377729648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42156041766310098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055854908375898252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40003258603243419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36258048244784946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2881643691693776,
                                   0,
                                   0,
                                   -0.17926734235820896,
                                   0,
                                   0,
                                   0,
                                   0.21549992760950257,
                                   0,
                                   0,
                                   0,
                                   -0.16890345435016044,
                                   0,
                                   0,
                                   -0.2688593777423221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35907833027360514,
                                   0,
                                   0,
                                   0,
                                   0.12238888412873924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25337175732149025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3356796188927314,
                                   0,
                                   0,
                                   0.20160995701232445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094262553436204141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73798731834617781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24246691997256553,
                                   0,
                                   0.25872084654568783,
                                   0,
                                   -0.055262486335890898,
                                   0,
                                   0.036168016327909377,
                                   0,
                                   0,
                                   -0.2367614920947739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30152995059584148,
                                   0.35636385048443975,
                                   -0.09229508446856699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42002092042430517,
                                   1.0118186062705237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14321212729118055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35829081243009209,
                                   0.051653696911631714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06655646654891248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5931402751663748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22960052889317439,
                                   0,
                                   0,
                                   -0.17240033018274542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086806488121002112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37537518734222192,
                                   -0.0096545638161700253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24574347030124638,
                                   0,
                                   0,
                                   0,
                                   -0.44815342070648656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044562017583436565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3584397843895536,
                                   0.14079542678721269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21154158791933131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056639644150044736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49887626503628801,
                                   0,
                                   0,
                                   0.32117604682984868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053977841178610354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42429381522439236,
                                   0.2454151858127942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45411203926322929,
                                   0,
                                   0,
                                   0,
                                   -0.018360696105476009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24208292735806428,
                                   0,
                                   0,
                                   -0.35789562374181288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28083036660287086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11914456855183483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062558556027715526,
                                   0,
                                   -0.41603709077232126,
                                   0,
                                   -0.14600851106121066,
                                   0,
                                   0.16268895832162816,
                                   0,
                                   0,
                                   -0.24842592538245814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094058341335144818,
                                   -0.76714934018033365,
                                   -0.35359225439311082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43345935878114866,
                                   0.17502403319127713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65049209726042156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13801716648503648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86347875546167974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66426825791523025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48279870330989638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27258002340032422,
                                   -0.39312968441864621,
                                   0,
                                   0.33934649042117798,
                                   0,
                                   0.88196453588980006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22723600229614702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27808765197525698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094719331552533564,
                                   0,
                                   0.34832082908268158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69127476898789841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16972604470811967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52972024551775099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039572026256920044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059421257234117592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47910913154671653,
                                   0,
                                   0.45894236823130513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14223078207665557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19626653520984677,
                                   0.18764459276246986,
                                   0.33627203051486748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40700111794599958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28618848382100642,
                                   0,
                                   0,
                                   -0.31119484541072123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091601488560662719,
                                   0,
                                   0,
                                   0,
                                   -0.23248726817756951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90407264783916097,
                                   0,
                                   0.032961181934683198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12514134952966161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076340936478508287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22544109997018241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071728852555441147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2237383835212047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1161170038518313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0035729345401138944,
                                   -0.63517296828590264,
                                   0,
                                   0,
                                   0.22944653523934255,
                                   0,
                                   0.17334987047548131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31956037598842046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049340731498742518,
                                   0,
                                   0,
                                   0,
                                   0.53248754982278901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31965922751930897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23461813025957187,
                                   -0.17001837521525365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53996474999124489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40629830324133304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15299614460098199,
                                   -0.40669809791958944,
                                   0,
                                   0,
                                   -0.027360721512385361,
                                   0,
                                   0.20017250566738667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68444040745678203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18765878531208902,
                                   0,
                                   0,
                                   0,
                                   0.41403032985496041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19167771022181906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066493455191206668,
                                   0.22954057663411143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2652152746224679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49075814377241178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076605552536610166,
                                   0.19517623336612722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090038721179929948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30928162413796656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50056896603043921,
                                   0,
                                   0,
                                   -0.40505149019978626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26718358246547069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034846040293633487,
                                   -0.1875932751889032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086193599375693541,
                                   0,
                                   0,
                                   0,
                                   0.28561213390010831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10019575759556948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39410922192468223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75838818971616273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27631285292654861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085555670951669216,
                                   -0.4193059974867987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6683626933298582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14705018913172285,
                                   0.075604039746755156,
                                   0,
                                   0,
                                   -0.25225748818773763,
                                   0,
                                   0.45454673301458232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66077387528578868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15564332834306843,
                                   0,
                                   0,
                                   0,
                                   0.64438655488118635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80528647884945082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080499393506491393,
                                   0.044585871935485438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17292616590666302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053437205236045754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014364132407615526,
                                   0,
                                   -0.71422538716464312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079297470949885179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095081666153713218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56075885332403519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29629083991279453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26315939578727326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11035912756460975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046349244413381396,
                                   0.20708341858839879,
                                   0,
                                   0,
                                   -0.47679613784421521,
                                   0,
                                   -0.14536413905170897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012657673635458166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94839277688066592,
                                   0,
                                   0,
                                   0,
                                   -0.20541201768881184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057534232651649725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87425450721640918,
                                   -0.58168008598323595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19103088616099273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3490631276295531,
                                   0,
                                   0,
                                   -0.18806826491050749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14149127363412881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40809067393450332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44201348930495388,
                                   0,
                                   -0.008843778274380331,
                                   0,
                                   0.68287332164692094,
                                   0,
                                   0.50202656399517798,
                                   0,
                                   0,
                                   -0.44106126278452645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29696862593439294,
                                   0.37088881857414441,
                                   -0.61446618934256725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2990608281701182,
                                   0.13265930192929101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21282871986494689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3495294546784124,
                                   -0.31347616112928306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23185824238209332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26635908672027131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0094870782704449055,
                                   0,
                                   0,
                                   0.27024085164641215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63107795749957452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14749872314230023,
                                   0.14907280946029106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30404069574420217,
                                   0,
                                   0,
                                   0,
                                   -0.041970865673720784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11291296712494041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4639458106828751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17481287444431887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30023892258443169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15649293721239285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19014128257080723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59431966941160974,
                                   0,
                                   0,
                                   -0.10285408024115442,
                                   0,
                                   0,
                                   0,
                                   0.026132424892020313,
                                   0,
                                   0,
                                   0,
                                   -0.11756455285182729,
                                   0,
                                   0,
                                   0.11662400709172657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21014403300446746,
                                   0,
                                   0,
                                   0,
                                   -0.38334311012689853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087438409492793995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10866578750456823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90671038117955627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37833791443269582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10574151549297636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44769115095557954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051486926837881974,
                                   -0.70362161766477138,
                                   0,
                                   -0.52132878490978884,
                                   0,
                                   0.30010867738809582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47823692089245717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41776672888208011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1434186614222509,
                                   0,
                                   0.1554662380312882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17042317606483248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2243536432443364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2306907962382031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063218308488456831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80258263278819164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27844534004101873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10867140220259609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18352105010941117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38929862984780894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70317240361392086,
                                   -0.48059743103138686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17130494397939289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2044318972704535,
                                   -0.3346850765914931,
                                   0,
                                   0,
                                   -0.063698350969119924,
                                   0,
                                   0.21890997173318993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.262217316768318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11691497697692144,
                                   0,
                                   0,
                                   0,
                                   -0.58113725098350799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36447985473968481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41041094436254705,
                                   -0.20226290601492317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045169118160165632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37668734793249309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29887980042041307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061601854944413906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035582478499623434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20012448103049901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22754916422160751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012515368007909339,
                                   0,
                                   0,
                                   -0.32366661061974494,
                                   0,
                                   0,
                                   0,
                                   -0.35234568513655401,
                                   0,
                                   0,
                                   0,
                                   -0.063275872215646345,
                                   0,
                                   0,
                                   -0.45146234574625344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098622627661862222,
                                   0,
                                   0,
                                   0,
                                   -0.33320458861894842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33800913916340303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30593073689279865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3688245557740405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33995809660597309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043916665418462703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59831470247223306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69985125242855961,
                                   0.46997993455775938,
                                   0,
                                   0.57137096210952676,
                                   0,
                                   0.67971541733470409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070793552770994486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13774102094066937,
                                   0,
                                   -0.093984650313218371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68061791119438741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29986353176374758,
                                   0.3485490090733761,
                                   0.3999950446172853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29702179651119481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040067857177649213,
                                   0,
                                   0,
                                   0.11646933500390093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18482554940557483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050165088628315216,
                                   0,
                                   0.19146142625500739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52845058223468422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56011387385188283,
                                   0.19546570936055349,
                                   0.33306759354623455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2016370865224773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2635857664043475,
                                   0,
                                   0,
                                   0.18889084304581893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26996820125427234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43012761581171033,
                                   0,
                                   -0.23727922816425603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06617036560161435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3788853852347886,
                                   0.082472630724327589,
                                   0.052053997832403484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12504874552784709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079327912187603211,
                                   0,
                                   0,
                                   0.077254789795924844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75719639929418037,
                                   0,
                                   0,
                                   0.18430357529111976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31143116561742046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14639236768033509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049536639348408053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30747264582112871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11392034037302956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12640614783778778,
                                   0,
                                   0,
                                   0.17795931813806845,
                                   0,
                                   0,
                                   0,
                                   -0.19015526322029513,
                                   0,
                                   0,
                                   0,
                                   -0.100866177550282,
                                   0,
                                   0,
                                   0.57537903465091067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46095035532380335,
                                   0,
                                   0,
                                   0,
                                   -0.22365438584698394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22383555227054086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78330371526973697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0083864792382024878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046297476882990046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36832156977398989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091403017482094784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18901012856464461,
                                   -0.26576372603292719,
                                   0,
                                   -0.10843928641159259,
                                   0,
                                   0.47793293434657363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98679812475222817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28830553098050021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49528790519467236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54046919714275354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46061361528017275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69636137792906294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0582209466110739,
                                   -0.14324533871823969,
                                   0,
                                   0.41578549344647947,
                                   0,
                                   -0.17065494148661287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29674875080299129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46300206843415892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67700099092511645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14984228798014784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037650512689044791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44752566497368984,
                                   0.32116856902425389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24931253225475367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27313666224402139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25846367656418445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83116976588447322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35462685512987291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18320167664597592,
                                   0.70830844988573083,
                                   0,
                                   -0.67641152007866023,
                                   0,
                                   -0.45403920667559916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82876978990631089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39088336135211493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31663472353640387,
                                   0.23734648975336647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21835389679367567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26508321287721431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0069051246801020844,
                                   0,
                                   0,
                                   0.1414362964745475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59374947899442276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14331266241478136,
                                   0.19289634295530916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19567626905245578,
                                   0,
                                   0,
                                   0,
                                   0.32255958884971714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54571249276731337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68962805722552301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63687651086251251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13171154670901841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83635706909058749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41200832087755579,
                                   0.19785251180118568,
                                   0,
                                   -0.79448405246047282,
                                   0,
                                   0.44158006329239585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087704850553367353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58283877695229203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35355117785876394,
                                   0,
                                   -0.16777048525894961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44645570603242052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41763066841157059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26982826123465392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16138092252057726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18591509790789687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45343026524324032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0062952274497833985,
                                   -0.36736865042521871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52393533618032795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15412826270826324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22786273870349835,
                                   0,
                                   0,
                                   -0.097225359326145844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15909308607395733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3552996506742031,
                                   0.1287267561410109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22494865646698839,
                                   0,
                                   0,
                                   0,
                                   0.28468009363055047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10370917176836172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27868832393594656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23228403471944978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030868056600511267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12984729166711445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35594421164340473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41948714525199671,
                                   0,
                                   0,
                                   0.02240803596137167,
                                   0,
                                   0,
                                   0,
                                   0.33725806061346081,
                                   0,
                                   0,
                                   0,
                                   -0.19953512821405336,
                                   0,
                                   0,
                                   -0.16665556964919875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0078953301675165795,
                                   0,
                                   0,
                                   0,
                                   0.088996424696312443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58934394409680702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33113175488178725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31787088479655279,
                                   0,
                                   0,
                                   0.017431137429122084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35581744228830903,
                                   0,
                                   0.50631319594034374,
                                   0.12694201773224378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67973397216339171,
                                   0.029685133432046651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10702929858854635,
                                   0,
                                   -0.060454665512437479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27001934913213732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14330475089662043,
                                   0.31192515785730013,
                                   -0.4276842121420607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5095936216244894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27885807396232121,
                                   0,
                                   0,
                                   0.48394434125121627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.198953669639062,
                                   0,
                                   0,
                                   0.26379283740732018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24838552850529746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40885021787254355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28692599411092923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19464749562720959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13921724814737807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0013449305328203168,
                                   0,
                                   0,
                                   -0.46488449915491226,
                                   0,
                                   0,
                                   0,
                                   -0.073267851694322483,
                                   0,
                                   0,
                                   0,
                                   0.2910759192735885,
                                   0,
                                   0,
                                   0.39383097899662101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2879492268296619,
                                   0,
                                   0,
                                   0,
                                   -0.0229982512386512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13116615264733819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38940468838565268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52636811631666491,
                                   0,
                                   0,
                                   -0.54004051335176295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58773295679903637,
                                   0,
                                   -0.15611618973538022,
                                   -0.20185110559325481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61433720012909765,
                                   0.46277670872114374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24928582538250396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12165785152973208,
                                   0.66053365395103669,
                                   0,
                                   0,
                                   -0.5749481249967372,
                                   0,
                                   0.7853157678143774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38534371073119511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25436205518702215,
                                   0,
                                   0,
                                   0,
                                   -0.61255433832533568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098541915311776238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58113523191624883,
                                   -0.31973119925574606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39477416606982096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38393061575014537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035475185524247589,
                                   0.010001330778094938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081682324770888742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31109754062511952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47131020122601064,
                                   0,
                                   0,
                                   0.28841609567159859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022262577327959179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64596123757371682,
                                   -0.13353733976460119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081440766691477845,
                                   0,
                                   0,
                                   0,
                                   -0.015542603112639553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08535860386204458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36718271726309515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10733407400971859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60093144644698659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050551299191980752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43692881935428474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034906860162008169,
                                   0,
                                   0,
                                   0.27975696165805108,
                                   0,
                                   0,
                                   0,
                                   0.15485771211263463,
                                   0,
                                   0,
                                   0,
                                   -0.22271699423733954,
                                   0,
                                   0,
                                   0.0042987157264346293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15159647607761206,
                                   0,
                                   0,
                                   0,
                                   -0.31154115614141087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13662081683963739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071433742768918701,
                                   0,
                                   0,
                                   -0.54668606389296626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.395869266072291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049875963532479244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59701862280797902,
                                   0,
                                   -0.27385839824990266,
                                   0,
                                   0.19840074612410452,
                                   0,
                                   -0.63971670521929358,
                                   0,
                                   0,
                                   0.67151750416636313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61473934018439935,
                                   -0.32749862953095998,
                                   0.24393353820285629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37299541417984389,
                                   -0.010515724143662017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18426567309927236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14134653166152636,
                                   -0.78961836950695496,
                                   0,
                                   0,
                                   0.012364617917771714,
                                   0,
                                   -0.25970954481805131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52908683175170179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34044856565223425,
                                   0,
                                   0,
                                   0,
                                   0.072068984766276434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99446176987951007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018873685632401972,
                                   -0.5015409673249217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018485531272033257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41767486020726718,
                                   0,
                                   -0.27380233577004842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16290679604827213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44194352155480032,
                                   0.17499719233170802,
                                   0.50441641676801552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29054014905135178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15099410653335688,
                                   0,
                                   0,
                                   0.2456596044326782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27587300182703728,
                                   0,
                                   0,
                                   0.36347088512262221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21500604098170298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27741408708090282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11637048747728278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31369641597378378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016673364633208398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27533962937309975,
                                   0,
                                   0,
                                   0.17483271776340337,
                                   0,
                                   0,
                                   0,
                                   -0.4305470018118015,
                                   0,
                                   0,
                                   0,
                                   0.0090765300679790384,
                                   0,
                                   0,
                                   -0.15877038179539088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0036408188841573798,
                                   0,
                                   0,
                                   0,
                                   0.56077325959905544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030947959705281552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11364521875236293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12141666537478932,
                                   0,
                                   0.21938007345650318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4859939444394033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7041393931463269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2984701889625937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28197993587308035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15367369341436612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11268681569825439,
                                   0,
                                   0.42990499851396563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1507113551800508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26193771322799447,
                                   -0.056761946025561852,
                                   0.18069017290320527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12557458714872738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76429748071303316,
                                   0,
                                   0,
                                   -0.088028696609593143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2600357112785287,
                                   0,
                                   0,
                                   0.31942280496163888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23319523736774228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25064901789186494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56678763772008089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36371181651265844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21081558532678019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28725809474236963,
                                   0,
                                   0,
                                   0.25036051589248248,
                                   0,
                                   0,
                                   0,
                                   0.0095696250876418539,
                                   0,
                                   0,
                                   0,
                                   0.093538510266165636,
                                   0,
                                   0,
                                   -0.13866119639738811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13368312942224689,
                                   0,
                                   0,
                                   0,
                                   -0.24401794072234431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17917842112378615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1425670580444488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63278848282981914,
                                   -0.78238464952117437,
                                   0,
                                   0,
                                   -0.72905441539435023,
                                   0,
                                   0.22608618706998251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07128166695340088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31791626786847749,
                                   0,
                                   0,
                                   0,
                                   0.23565384936012981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2769546150446453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63651705108590806,
                                   -0.51480995266265028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36210541495973914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013936860473941368,
                                   0,
                                   0,
                                   0.7278912331272025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19446278234192718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29120511522960285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08278133262213673,
                                   0,
                                   0.48586924904709805,
                                   0,
                                   -0.025925352992477217,
                                   0,
                                   -0.065366358095450688,
                                   0,
                                   0,
                                   0.36620934536006389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72979485223551155,
                                   -0.2268081304707677,
                                   -0.21874860992878914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35983275880607168,
                                   -0.29409544523002917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31593045456659075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21998428234786424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32452817738354323,
                                   0.082483099255530726,
                                   0,
                                   0,
                                   -1.3341724430715483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56729242348042264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60841503525077845,
                                   0,
                                   0,
                                   0.41182454332617563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53132318583819349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45731726115339522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58249102899261573,
                                   0,
                                   -0.14594944212237904,
                                   0,
                                   -0.43385738872991997,
                                   0,
                                   -0.36927850695653697,
                                   0,
                                   0,
                                   -0.59223383443220912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12573095800821057,
                                   -0.020482699555324835,
                                   0.30865105421048966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083878321675008666,
                                   -0.19098101800946599,
                                   0,
                                   0,
                                   0,
                                   -0.06452296336674325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31053791366333638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11350104458332465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014748409926157398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30871101757149888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32553016082331759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21924790400549321,
                                   0,
                                   0,
                                   -0.032614708264221214,
                                   0,
                                   0,
                                   0,
                                   -0.044858523715261542,
                                   0,
                                   0,
                                   0,
                                   0.65404177713265588,
                                   0,
                                   0,
                                   -0.027097339276971524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41546969122513744,
                                   0,
                                   0,
                                   0,
                                   0.10330860166569086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1486348458202672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61825959952646781,
                                   0,
                                   0,
                                   0.145086228841839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61762845780300191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11937552651610209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30521307268711251,
                                   0,
                                   0.011550335475934981,
                                   0,
                                   0.069535615451192051,
                                   0,
                                   0.61438331448261674,
                                   0,
                                   0,
                                   0.0015700451373770229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037097960027886338,
                                   0.1391951908312305,
                                   0.63928535489231864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23995757762036368,
                                   0.62859903048913224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061006625691527344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21658578991682562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91137593952363716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68187635516139367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030214727332444936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29198451164337702,
                                   0.069495550932990285,
                                   0,
                                   -0.33014860963536147,
                                   0,
                                   0.36570924161695934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26455191291448288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16922608220098564,
                                   0,
                                   0,
                                   -0.17645393173170265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47957721236546913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097265105323329437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01155379077566776,
                                   0,
                                   0.82026834878707799,
                                   0,
                                   -0.079571538506130066,
                                   0,
                                   -0.21148591056457167,
                                   0,
                                   0,
                                   -0.67841480289630318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020894899084569041,
                                   -0.25369618637511088,
                                   0.27524939412296379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021357584099866482,
                                   0.15126391981174933,
                                   0,
                                   0,
                                   0,
                                   -0.42833265757328842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33102382751889398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08253530521811997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15651030448164313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0164281442983196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15529366664993208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31837129552521282,
                                   0,
                                   0,
                                   -0.3265438460576584,
                                   0,
                                   0,
                                   0,
                                   -0.50452121444655373,
                                   0,
                                   0,
                                   0,
                                   -0.40708019043000521,
                                   0,
                                   0,
                                   0.13130617611477691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043529715548932341,
                                   0,
                                   0,
                                   0,
                                   0.040771010506838241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047066712534502841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26408954736241946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96638874262616092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085147381623656732,
                                   0.19533866057014432,
                                   0,
                                   0,
                                   -0.22036263015560476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85632379114048796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19789913682753765,
                                   0,
                                   0,
                                   -0.33914913888398746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53293274107308863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25737651122066618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27775718013466477,
                                   0,
                                   0.47310812984993628,
                                   0,
                                   -0.42628739088069234,
                                   0,
                                   -0.24515137434800433,
                                   0,
                                   0,
                                   0.1530605904027233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19956290409057134,
                                   0.30631288896638786,
                                   -0.69004260238352888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010791211199993447,
                                   -0.17215169110412742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44786686345020399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17187291494822621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3952619808614854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049404851893410068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34977064330399943,
                                   -0.69918709792731004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33431143694943688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05366113564716693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40600762268531954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82177445933021864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21172884471528702,
                                   -0.019281863896755541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47860611853979729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024808765040079797,
                                   0.3124714828046613,
                                   0,
                                   0,
                                   0.068038434294985156,
                                   0,
                                   0.48879492820535403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18971274680285868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.875627540246942,
                                   0,
                                   0,
                                   0,
                                   0.56428433973753278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46417606201850969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2785579304367678,
                                   -0.33869524529901718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50194800459443101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18952030829852468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14030271660779647,
                                   -0.28081651613179914,
                                   0,
                                   0,
                                   0.77764428544789543,
                                   0,
                                   0.83480448594935064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11864270919715036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27501293328172105,
                                   0,
                                   0,
                                   0,
                                   -0.35711233044835755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031972358644730858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63849724506380368,
                                   -1.0611710301260555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16738293876204552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32290258678831485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27233297661991973,
                                   -0.46952676765790041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27028703160557677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19634509064345923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02318800243328804,
                                   0,
                                   0,
                                   -0.097654885500010807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12716622468758065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052050169493155871,
                                   0.67707371041509679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030846667115838656,
                                   0,
                                   0,
                                   0,
                                   -0.034232360387272523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08420530517789887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28118234716837281,
                                   0.23316902196359363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64509987044765882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047681814992263982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14525028894430464,
                                   0,
                                   0,
                                   -0.0032832875902547021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15772277165230003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11287505541566639,
                                   0.27681690324493757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54874878630094992,
                                   0,
                                   0,
                                   0,
                                   -0.067618469720346547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98341251374976335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069916101525050053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97601014151441001,
                                   -0.29882563282437713,
                                   0,
                                   0,
                                   0.5053050552856081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46108911001218345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6100952146091343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025754288583950811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97224335690613128,
                                   0.040961645930267965,
                                   0,
                                   0,
                                   -0.076034967614706725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82779008072365279,
                                   0,
                                   0,
                                   0,
                                   0.40709712281921151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027721911316663427,
                                   -0.50016566604277124,
                                   0,
                                   0,
                                   0.25991112539944472,
                                   0,
                                   0.89935639797501776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36700280539599112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21829183889164971,
                                   0,
                                   0,
                                   0,
                                   0.065397422011350695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038247606705117232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44421943618589643,
                                   0.84839956866103194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5880837818118938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2617427676703396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40665528119980415,
                                   0,
                                   0,
                                   0.27384118367847043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094955564025680478,
                                   0,
                                   -0.50749362335719161,
                                   0.63350237338932469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21024071461803692,
                                   0.36627179943673271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052374618220013325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56266175088946024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35431574992335957,
                                   -1.0989680160118145,
                                   0,
                                   0,
                                   -0.099495769908263476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31078510848955304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82046246249734545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4352111382813616,
                                   0,
                                   0,
                                   -0.30504187131614369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39559997522639573,
                                   0,
                                   0.075188002606590254,
                                   0.35809732359582763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07133155221931721,
                                   0.83917613493772347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94673441032273919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76668795676551937,
                                   0,
                                   0,
                                   0.32527610866048828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70505226600044291,
                                   0,
                                   -0.39732241289010334,
                                   -0.34053945171904759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12611398998328507,
                                   0.023326941548411445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1921567031556316,
                                   0,
                                   0,
                                   -0.14043427131446723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045392477340367034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43692098533404444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50126334804345984,
                                   0,
                                   0.24058170808396381,
                                   0,
                                   -0.39530168690712586,
                                   0,
                                   0.49343863054864034,
                                   0,
                                   0,
                                   0.25792072118094783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20587244023162327,
                                   -0.21893684657845452,
                                   0.3929398297243854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30192508225710285,
                                   -0.65540314447032277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31295447450507136,
                                   0,
                                   0,
                                   -0.1488935791426734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61273554073651093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28500387788742515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01861947932180838,
                                   0,
                                   -0.23496445162544038,
                                   0,
                                   -1.0692527117873056,
                                   0,
                                   0.46714408902620808,
                                   0,
                                   0,
                                   0.18134343295348923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095349319753815789,
                                   0.20357043468752012,
                                   -0.038079379364705165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52682112914135437,
                                   0.081935553177836407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080061283256827986,
                                   0,
                                   0,
                                   -0.016036634452800791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47463071038427168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53197070458889206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60575939827523018,
                                   0,
                                   -0.1865427220397505,
                                   0,
                                   0.086953447254913219,
                                   0,
                                   -0.066315547135415598,
                                   0,
                                   0,
                                   0.21001316441637197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26248245128502018,
                                   0.23276948451220653,
                                   0.37931563195736895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63661373265493537,
                                   0.051589120443934627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.004667678273357706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56605704789727829,
                                   -0.0052481681311419975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018971068607786162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022690722353417875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28939800985212916,
                                   0,
                                   0,
                                   0.69332242296174273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015010703367076217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17488593543896777,
                                   -0.1533725099884658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10940063735640282,
                                   0,
                                   0,
                                   0,
                                   0.21887459770283646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011000783337553569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58373609043357311,
                                   0,
                                   0,
                                   -0.75423430325376717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64751277748866842,
                                   0,
                                   -0.4124594883741477,
                                   -0.76764143501379256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26472637056638954,
                                   0.45652654208805266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36796858012180422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50688055701271839,
                                   0,
                                   0,
                                   0.37794525573000137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33871415931519799,
                                   0,
                                   -0.49042405825055335,
                                   -0.4504032203905069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34082497685735691,
                                   0.47062789832867108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46399742969570323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021848621571860537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069030073474965745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086916501544486033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19432071228198156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16472484503847654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15529803414572799,
                                   0,
                                   0,
                                   0.4210313254907852,
                                   0,
                                   0,
                                   0,
                                   -0.3507783747045356,
                                   0,
                                   0,
                                   0,
                                   0.30091554403549725,
                                   0,
                                   0,
                                   -0.10784766200990752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25609392234940376,
                                   0,
                                   0,
                                   0,
                                   -0.28576415054020204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36490783169988739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25547506455782087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054878830383476004,
                                   -0.60922201074465154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066283526096684725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23220817872714286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04050734897274514,
                                   0,
                                   0,
                                   -0.038810987989471704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18465849121256278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022666059301201885,
                                   -0.48844314444877457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46631917548785734,
                                   0,
                                   0,
                                   0,
                                   0.092006941978498097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10776078971020285,
                                   0,
                                   0,
                                   -0.64580106268981619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46724361364433353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039793364784717171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64775507744448924,
                                   0,
                                   0.32790506405553965,
                                   0,
                                   0.041969984989416453,
                                   0,
                                   0.010872273389786268,
                                   0,
                                   0,
                                   -0.29953468017663809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41308681118848917,
                                   0.48694280591165512,
                                   0.52677215121004184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25541893630631951,
                                   -0.038590351118398557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6102848041053125,
                                   0,
                                   0,
                                   0.30477157309004832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056015046478736973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38010556069918183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31355680258867036,
                                   0,
                                   0.50754648522857493,
                                   0,
                                   -0.01422347541684621,
                                   0,
                                   0.13179482570746093,
                                   0,
                                   0,
                                   0.65885210248080739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34701692412905816,
                                   -0.52380481597783157,
                                   0.10470516421534226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17345691282559017,
                                   0.45058182353138054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5457832632141304,
                                   0,
                                   -0.1061090556521303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26735646451732276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35069172547697341,
                                   0.21390050247863415,
                                   0.14164038823343511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52573429634196089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056244247124343477,
                                   0,
                                   0,
                                   0.36486570126169127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13377205345381848,
                                   0,
                                   0,
                                   0,
                                   0.12139810303499324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051096905424514949,
                                   0,
                                   -0.081559438052362779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064434459924723339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39981325379611266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22429213623771624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81400120603096149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31478929709468106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0899768109184229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63560358204336787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33347563757220183,
                                   0.78450307514466866,
                                   0,
                                   0,
                                   -0.08170974515830115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91445848881141745,
                                   -0.20008019333590668,
                                   0,
                                   -0.46564385150380105,
                                   0.16778416640140772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15517869040561905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063284383037439745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043261565307397172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48788155919790083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42780853692143267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062635319024837766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0074773259025646757,
                                   0,
                                   0,
                                   0,
                                   0.16849690085545388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48126544849278152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17162384481758755,
                                   0,
                                   0,
                                   -0.58118783670894869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12658511893923757,
                                   0,
                                   0,
                                   -0.51340950436775945,
                                   0,
                                   0,
                                   0,
                                   0.23057897589365267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35063903423872855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60576125326946539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16559987112917154,
                                   -0.16354627562755017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23094444169362996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.389305447933048,
                                   0,
                                   -0.96919301705058292,
                                   0,
                                   -0.40775366031933191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29320450963684008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20609801613577958,
                                   0,
                                   0.14997691553162149,
                                   -0.030886391292752603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089996637632284132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77619222189704817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051660334491725531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04141584875445814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31736473408760901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26798863723643856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28928217010022717,
                                   0,
                                   0,
                                   0,
                                   0.19584292193239672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1566583302596051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15449566435124373,
                                   0,
                                   -0.35185894543987312,
                                   -0.26993190304387765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066535713889110476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0086189125758072433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43431153124002264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07410879723619189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095167433388598524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31697140423470854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53782271311179419,
                                   0,
                                   0,
                                   0,
                                   0.31358373183164068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28935703545699704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38724361931213475,
                                   0,
                                   0,
                                   -0.025504546394018127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25716570723783455,
                                   0,
                                   0,
                                   -0.18309702976151182,
                                   0,
                                   0,
                                   0,
                                   -0.2883180892420229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13571815877595556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29559849342919226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68827768725511806,
                                   -0.28601001554513406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010566384804148336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14174736461142015,
                                   0,
                                   0.13788090806666803,
                                   0,
                                   0.42066627358230618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91079304205082734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52440242247882951,
                                   -0.027099594346985313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080458999308932688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10872832738232821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32643361575154484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37082860428723297,
                                   0.047670945289761013,
                                   0,
                                   0,
                                   0.036484999930164921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45626894306929716,
                                   0,
                                   0,
                                   0.19203588802214036,
                                   0,
                                   0,
                                   0.31398430061679145,
                                   0,
                                   -0.023770334655844147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047025375711580907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3344758459771528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047845995617387269,
                                   -0.36417394556348154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11261925102218193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07810940722073062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12651320647024775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38723621096028416,
                                   -0.31633098319937142,
                                   0,
                                   0,
                                   -0.064852811393235885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26223093464262087,
                                   0,
                                   0,
                                   -0.65553577542263186,
                                   0,
                                   0,
                                   -0.27108200030383145,
                                   0,
                                   0.034923825194021318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053123279489114827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0074730910676241158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52098655768173718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66357787020828551,
                                   0,
                                   -0.42548384983474485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38894095555980257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5627735992921119,
                                   -0.23869738338312985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15565140819079093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21742384099524015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8450904481985364,
                                   0,
                                   0,
                                   0,
                                   -0.61200384826374898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10512580397113261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33083060686733123,
                                   0,
                                   0,
                                   -0.85954222098863409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5567950087134822,
                                   0,
                                   0,
                                   0,
                                   0.5533884869912713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092159956203926877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070058181116874715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55459654965365812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25027215491419114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079916801960462774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43285374632395562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67916112149617325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66186502725202712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95058583636521488,
                                   -0.41438038169260688,
                                   0,
                                   -0.63084226784060116,
                                   0,
                                   -0.20450833309691754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10913171637283342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21583806691382401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.007161067191339146,
                                   0,
                                   -0.29985740660727156,
                                   -0.042708523093009439,
                                   0,
                                   0,
                                   0,
                                   -0.28197989564192605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20264304734178928,
                                   -0.71089634535141222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31478959701547904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02268210152290099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36887222396204705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2273119537981193,
                                   0.50682941557347938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44173981469530404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49926546726614568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17413352737287638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10000211620089697,
                                   0.1260693847015549,
                                   0,
                                   0,
                                   0.080616792324840647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12964823093655919,
                                   0,
                                   0,
                                   -0.24227618148191116,
                                   0,
                                   0,
                                   -0.23432569102459566,
                                   0,
                                   0.067564817842671362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16438308418884962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14945212800261856,
                                   0,
                                   0,
                                   0,
                                   0.38871450662268098,
                                   0,
                                   0,
                                   -0.077461877167300949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27599224696622765,
                                   0,
                                   0,
                                   0.16970368874721181,
                                   0,
                                   0,
                                   0,
                                   -0.4355472206215209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049579058220128418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33901929095468308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17225412709149662,
                                   -0.11126314936115611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36767531888921356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15846415863921803,
                                   0,
                                   0.26391723893162078,
                                   0,
                                   -0.42817102515031769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54200954723229522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31408838848130688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54180791739390199,
                                   0,
                                   0,
                                   0.42930041872970104,
                                   0.34430459494628868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31673466998754762,
                                   0,
                                   0.45235750250852802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31779418465365461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28349469546807582,
                                   0,
                                   0,
                                   0.70201565278383571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20121885205654932,
                                   0,
                                   0,
                                   0,
                                   -0.18776379069855542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076177191700010916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056938731038737367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69093734249178218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51382059540014047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17281228142704652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21055193311971604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44722653119862288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061782674810682871,
                                   0,
                                   0,
                                   -0.27494033336410328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049855665042757451,
                                   0,
                                   0,
                                   0.93451142488744565,
                                   0,
                                   0,
                                   0,
                                   0.41951996535509156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34828387585325493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014493834320474436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2121120340917233,
                                   0.89498230981108584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48757525253117517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5060625752839697,
                                   0,
                                   -0.49826591927152153,
                                   0,
                                   0.065426934047348895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088033759715397009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029235760950093177,
                                   0.18752412470017774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.268681852207035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36948169347249105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31516885715605242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11449672715948969,
                                   -0.37753533594599686,
                                   0,
                                   0,
                                   -0.43556618328491203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13587063894303236,
                                   0,
                                   0,
                                   -0.087944811679161877,
                                   0,
                                   0,
                                   0.005021002051904172,
                                   0,
                                   -0.46641489508473422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078705393849965055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24621911012797296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16005533419590018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48857799457011764,
                                   0,
                                   0,
                                   -0.066286372105618038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94575058063946293,
                                   0,
                                   0,
                                   0,
                                   -0.4087127714619615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61657880348994931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94013269575623082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28714955945680143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37521468242169892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12449518808372724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24619315332360792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36421970473408694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098343989887348493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31164747601010445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59362395242114929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084915377520460994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24819712323936302,
                                   0,
                                   -0.39703938854899906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15555867134379558,
                                   0.53866845447651013,
                                   0,
                                   -0.01972950788624004,
                                   0,
                                   0,
                                   -0.1883965904950651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68012785576027335,
                                   0,
                                   0,
                                   0.37589189493100322,
                                   0,
                                   0,
                                   0,
                                   -0.46029926058503617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60617792035241835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13152764870885089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60539979442481384,
                                   0.53587683235368921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060793084207355096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22840603949491736,
                                   0,
                                   -0.24811488456740113,
                                   0,
                                   -0.49813371387956784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31597983864326595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014846855126343775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66978185122240419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43310111683038954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090775953779687751,
                                   0,
                                   0,
                                   0,
                                   0.059031286659496543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2511877819031281,
                                   0,
                                   0.21157968451749945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27491956501056997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025346849541493688,
                                   0,
                                   -0.43479854849467836,
                                   0.25118062754226811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51832505393868822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34047867126614983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083048588281057101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38471953292199373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12835492339946711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13405767808496527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056943539678668276,
                                   0,
                                   0,
                                   0,
                                   -0.41200887045359269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016821241922562395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25622956440653544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093743760988286656,
                                   0,
                                   0,
                                   0.00055966728492651274,
                                   0.735017308610036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60191756115128658,
                                   0,
                                   0.15166743221167789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044495299445208303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82662632153299498,
                                   0,
                                   0,
                                   0.33594644142414398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17058740654448809,
                                   0,
                                   0,
                                   0,
                                   -0.17914714480522487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1035981553063188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66373462959265994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3556589292377953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22165694143705539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28243388108161738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50805358074448304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25773911948572953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091378531867689877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013053830543405559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33255341034537783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4829413333988693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069932807238833716,
                                   0,
                                   -0.62534016908276113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43994768838257081,
                                   -0.24116501834740448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60291913301651712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68130829892776223,
                                   0,
                                   0,
                                   0.24433649854665854,
                                   0.26930553802166335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14330955439032211,
                                   0,
                                   -0.1398001972246079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56321605603215796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19198236454569301,
                                   0,
                                   0,
                                   -0.77356020372559775,
                                   0.077781103264198265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13754015601166131,
                                   0,
                                   0.15022603836329274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11449660869481176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71630252565826302,
                                   0,
                                   0,
                                   -0.047519309526068254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48455755618187035,
                                   0,
                                   0,
                                   0,
                                   -0.26928321902932617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84134625361691406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095548955543374003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046417819200089999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40853886912503262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67278337027915258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10356214025417812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13090398724096466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32196936240111756,
                                   0,
                                   0,
                                   0.42679801405139339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53561565525643862,
                                   0,
                                   0,
                                   -0.22345275239747109,
                                   0,
                                   0,
                                   0,
                                   -0.089347940916322005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31117666427625773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78735904652379651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64500003178932142,
                                   0.060568580623028473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64318420743952021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49019068228700563,
                                   0,
                                   -0.53215117123450051,
                                   0,
                                   -0.1659530239486518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16457427288783871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046215578142227723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13472912789229291,
                                   0,
                                   -0.44351183963056912,
                                   -0.55606585502018402,
                                   0,
                                   0,
                                   0,
                                   0.41139077753394326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32358570501928824,
                                   0.11560706186795532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16487825625423633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38742000956674544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095948002260880627,
                                   0,
                                   0,
                                   0,
                                   0.087290047802100673,
                                   0,
                                   0.006550631233291488,
                                   0.61596784890213341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18957761669611753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20756113665631865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27886137552010271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31208637134938771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070998279615411442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014571004995228379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51320564308909944,
                                   0,
                                   0,
                                   0,
                                   -0.093259330395700391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28532064955682468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23331137534733509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15349850566556522,
                                   0,
                                   -0.20231144816851199,
                                   -0.46399676441428911,
                                   0,
                                   0,
                                   0,
                                   -0.70995612896902083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085864759501722981,
                                   0.044801728560373316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32298363674893521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043109990986522351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21491052474835934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11344696580022291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020789566555538486,
                                   0,
                                   0.41552343096273792,
                                   -0.042675143055473312,
                                   0,
                                   0,
                                   0,
                                   -0.014857670167615994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12832501593369725,
                                   -0.28880286524880139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24053650847555069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6475486654814292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48471068611059559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68914666131884195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50229652461414709,
                                   0,
                                   0,
                                   -0.24475166162422612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18017406562932839,
                                   0,
                                   0,
                                   0,
                                   -0.55821475019279954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51980948652895953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2645648543529972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38521011606860861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22249743646041689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51799197285859289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80293726052564574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15900390950211304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045227567523322437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79950822753409356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42322819486834662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26543714254153394,
                                   0,
                                   0,
                                   0,
                                   -0.23639171041024748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25738278024387268,
                                   0,
                                   -0.024176428693529983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84449063689052739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049907160712922838,
                                   0,
                                   -0.40757838427102766,
                                   -0.19568330933833494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16799244659571189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1441171821921467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23155593799168195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36492775896810309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66403229524141227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027005080407710855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32653966703462189,
                                   0,
                                   0,
                                   0,
                                   0.079549362709085303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051875945140042318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14098931579294538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060890295099675334,
                                   0,
                                   -0.34775452888853481,
                                   -0.13637408264443615,
                                   0,
                                   0,
                                   0,
                                   0.26976442776655785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31622361359290835,
                                   -0.18269990106498082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13770182424350683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46973343604944151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62539788498313453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24860582517717511,
                                   -0.11052802722155543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21641291933336504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2908730293503014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22132457917113904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23073218652088565,
                                   0.30934897282987156,
                                   0,
                                   0,
                                   0.0088529938676934899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029611736635875963,
                                   0,
                                   0,
                                   -0.21802278344101217,
                                   0,
                                   0,
                                   -0.087931742833168153,
                                   0,
                                   -0.57176838100622063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42863237852040931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17248877185832751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18509044378333667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26452277917988576,
                                   0,
                                   0.74429440083082077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18513910431268193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035267199929639031,
                                   -0.9586903547472333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085938472359465806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82043393265301789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084734477158406776,
                                   0,
                                   0,
                                   0,
                                   -0.56255377217835367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32689866152617558,
                                   0,
                                   0,
                                   -0.21878492889457735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67489653120932813,
                                   0,
                                   0,
                                   0.00014360515020533926,
                                   0,
                                   0,
                                   0,
                                   -0.036141822433901585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69033548649933651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59222890255316285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55729488832445939,
                                   0.18208377127044245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40931048035193152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59732259055937886,
                                   0,
                                   0.0089687527838904491,
                                   0,
                                   -0.12906406378754126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21543036056575085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16031006694307517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13377711450179691,
                                   0,
                                   -0.30011916963062146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91980541985300623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1559286872067247,
                                   -0.67356121597032437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088226747185974952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044668663621811239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51688533307961515,
                                   0,
                                   0,
                                   0,
                                   0.75061324235542526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89821522814966726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043912767160768001,
                                   0,
                                   0,
                                   0.38081515131704757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28850526126027226,
                                   0,
                                   0,
                                   0,
                                   0.51288142631405753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29488751382163003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33577145823010041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00093490014763286666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7821615312142034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35405476054153012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43266045661627378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15586312341978339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034562388364529864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49175151572613462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55918321062049692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34211057412252682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045065825808239451,
                                   0,
                                   0.20756579514250795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22480793692105944,
                                   0.4812559440190578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37114838950199469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10711276317628746,
                                   0,
                                   0.33102990472449312,
                                   -0.14616948698271356,
                                   0,
                                   0,
                                   0,
                                   0.098526469272963824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64321206708876644,
                                   -0.39021141385557301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1452268568030923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34781031856835554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045523385742186839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61266725206565353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38221002461999298,
                                   0,
                                   0.046370873990260519,
                                   -0.16969823752148205,
                                   0,
                                   0,
                                   0,
                                   0.24995194585208136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47811888190161911,
                                   0.0027627887922588024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07700233213756362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087770247829360257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37801102699144745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45135112961424173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13600573548811207,
                                   0,
                                   -0.62819395205535045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52407458402277429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24297599839221234,
                                   -0.12615430110086154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71541253443283892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35182788108226015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45612003489373715,
                                   0,
                                   0,
                                   0,
                                   0.44819853045232971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029655284190400061,
                                   0,
                                   0.15076264971307929,
                                   -0.11243392673403178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4485459316292853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17751934662057098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17930023566790546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53297508216787048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12263281880928049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0074365841656692192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19313488550878882,
                                   0,
                                   0,
                                   0,
                                   -0.26034232032968158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54282492294823037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065879104002843414,
                                   0.17571670959312385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11215646429588155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3557720991450169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38142395842851223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14968717288042982,
                                   0.040716209112519192,
                                   0,
                                   0,
                                   -0.730852990623861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062883920815196004,
                                   0,
                                   0,
                                   0.21158927444547981,
                                   0,
                                   0,
                                   -0.044800136291846829,
                                   0,
                                   0.044689582341228037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23724302643943906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11368139734537507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11394540089808343,
                                   -0.018372072818673257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39073288043234222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31314784479570723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57883018072119496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15531390131138828,
                                   -0.18270436174186752,
                                   0,
                                   0,
                                   0.042542151703106254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39268758469072174,
                                   0,
                                   0,
                                   0.27741538232334645,
                                   0,
                                   0,
                                   -0.016740338572718706,
                                   0,
                                   0.078379298904634701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31967293201360725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042549748103975993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6983130962355768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17672458341108979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13057689647880888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10636915731862791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33939983570175619,
                                   0,
                                   -0.32995514435864115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47545539236836687,
                                   -0.051400795967355743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17915910011349309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16636897168735382,
                                   0,
                                   0,
                                   -0.77485774550076059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098205358673530141,
                                   0,
                                   0,
                                   0,
                                   -0.42494999767728958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45758169480894251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070221482490134629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57203762877497599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19822309276602373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26810385709073692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68072174323593948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40951594310000256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18328437615972754,
                                   0.59653887651538406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36277461433021152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33498293886694852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10285708147676298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19206133983722978,
                                   -0.0044008635574229226,
                                   0,
                                   0,
                                   0.23559868723104563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15909948240412708,
                                   0,
                                   0,
                                   -0.2342016916404572,
                                   0,
                                   0,
                                   0.13581278116336817,
                                   0,
                                   0.14273855021427073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2647158076130296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27327463826481868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41978186992152666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7855834685706421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56469047601357092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065647582950263045,
                                   0,
                                   0,
                                   0,
                                   0.77089325592882629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45594750761218106,
                                   0,
                                   0.06357449673402249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68685803967801995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20145243683725714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060003762554965256,
                                   0,
                                   -0.08716495040597097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16737207503096982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65843276142049367,
                                   -0.002882321060009907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43067146039400139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56254941733938713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33318297069302422,
                                   0,
                                   0,
                                   0,
                                   0.78465787373614204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52122806314904913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55020136921868101,
                                   0,
                                   -0.50500541663969523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48863551258907495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51635325535156185,
                                   -0.27994407967766588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2223619266472891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12200621429434774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40620654140330459,
                                   0,
                                   0,
                                   0,
                                   -0.54695581297451679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14147851841187928,
                                   0,
                                   0,
                                   -0.43848129382864154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083877523012869881,
                                   0,
                                   0,
                                   -0.8785415597815639,
                                   0,
                                   0,
                                   0,
                                   -0.34670098444155489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40901882501768921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27040383328556783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23842489644235584,
                                   0.63237731291266752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33834788770128715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099527116858459969,
                                   0,
                                   0.17243158430945221,
                                   0,
                                   0.32683321554622574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7206000889386257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41152559903153668,
                                   0,
                                   0,
                                   0.10670977549171488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27814138656666382,
                                   0,
                                   0,
                                   0.030380080899863049,
                                   0,
                                   0,
                                   0,
                                   -0.85421700414346025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53675715393455659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22451972963566375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45446544611094986,
                                   0.2501572960006721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55363664683097735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12547951352019604,
                                   0,
                                   -0.22414365283928386,
                                   0,
                                   -0.21611936771353271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028835736676729867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014117709408159623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22181952511909631,
                                   0,
                                   0,
                                   -0.40676941615682993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094888024462353185,
                                   0,
                                   0,
                                   0,
                                   0.24997853487831972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49571260624172059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39580036522736384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29549871593613064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21011397753001382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81998394642754169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37467019547122216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76016310485229299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6298042863598714,
                                   0,
                                   0.20317441514071205,
                                   0.17736839079005254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29127565260672228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18774634445644528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33718115786829567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14260182409554903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25920276666307251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0088699415368663787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021788988299350231,
                                   0,
                                   0,
                                   0,
                                   0.38201484782966799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25063062196468616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16886236066360696,
                                   -0.23026881852431974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2641772265194185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33864084749606749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036981238103994299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47727771803661534,
                                   0.59334400130057807,
                                   0,
                                   0,
                                   -0.086913732920661485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23842935061431403,
                                   0,
                                   0,
                                   0.12344646268723704,
                                   0,
                                   0,
                                   -0.17650599611467344,
                                   0,
                                   -0.055401931206926061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11897715682058392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15733696937242114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22702588985893507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45754717225257446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78295759331431247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12726997347322652,
                                   0,
                                   0,
                                   0,
                                   -0.1373785028379417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35741963251502623,
                                   0,
                                   -1.0955591041559267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49358337894748372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24691960380712044,
                                   0,
                                   0,
                                   -0.081695210522982384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24716516251664122,
                                   0,
                                   0,
                                   -0.15441734872707358,
                                   0,
                                   0,
                                   0,
                                   -0.17246668325983341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3961755131557651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48431775530399024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12215756850459933,
                                   -0.23696137882416696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14953914530915846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077200249034671778,
                                   0,
                                   -0.3267657115364313,
                                   0,
                                   -0.941072772745704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32000121565826112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47371504887627897,
                                   -0.17821165568615882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28536272573203664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037762592441761098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062877219431158607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37853676875302661,
                                   0.06784519181767909,
                                   0,
                                   0,
                                   -0.056875708236784742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35400675204778198,
                                   0,
                                   0,
                                   -0.14350277782603529,
                                   0,
                                   0,
                                   -0.18404827058495471,
                                   0,
                                   0.36641677258443472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23303669018443987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37086435459770661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61432539354009796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01302166467502943,
                                   0,
                                   -0.37939087880070482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67913081296413869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12332639802942137,
                                   -0.42849287387441015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2188597162381791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6519143421178637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57113668727535194,
                                   0,
                                   0,
                                   0,
                                   -0.11445122265182882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02536094881640516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023187480247572001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17903971832480098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1515943753218276,
                                   0,
                                   0,
                                   0,
                                   0.49749809839675341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1029773229519422,
                                   0,
                                   -0.48394963218517872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19994817577840282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17646180776215045,
                                   0.034807049257401176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081327967175679597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16465156593667449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.006863426311930175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062291911762954275,
                                   0.28034762580857331,
                                   0,
                                   0,
                                   -0.35197477323142995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011104850956770732,
                                   0,
                                   0,
                                   -0.42042968479571124,
                                   0,
                                   0,
                                   0.56956179507714177,
                                   0,
                                   0.19056224559129165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14991327657169204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40919905451062527,
                                   0,
                                   0,
                                   0.22075111172299844,
                                   0,
                                   -0.32103117971996259,
                                   0.44260763078175425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26340875157059918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31902385257602706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17059365086714723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19229886886571665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15443825840379904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28831494190472889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44733097128659738,
                                   0,
                                   0,
                                   0,
                                   0.14589807757108572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29444362380480898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35597738718867833,
                                   0.28929144494904929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.310788104278998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17523352946921289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20093001648157555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087081380932964247,
                                   0.098623446348406321,
                                   0,
                                   0,
                                   -0.046980261813538621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024130528076506508,
                                   0,
                                   0,
                                   0.065129546655342818,
                                   0,
                                   0,
                                   -0.50784777430613703,
                                   0,
                                   -0.11537610960549309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01022099405034399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.571187481473729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13896660944366157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058097427687635622,
                                   0,
                                   0,
                                   -0.28274151882403425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54282352351231511,
                                   0,
                                   0,
                                   0,
                                   0.37209808219846557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015780640636466985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28759814375360226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58764660054539142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61316103714902859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45805459530665393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33217885342405062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89223017904840241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74010130290719811,
                                   0,
                                   0,
                                   0.36536947472313291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47546409292998676,
                                   0,
                                   0,
                                   -0.12372198222775549,
                                   0,
                                   0,
                                   0,
                                   0.28546470099517435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33603801627458235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41275486173390391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16509313920932644,
                                   0.26481732104162092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19969337651843899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68231966182461379,
                                   0,
                                   -0.32169141681456481,
                                   0,
                                   0.093698522039033255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48336542105946911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19809254898063455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15230051261591127,
                                   0,
                                   0.53851772880495807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38427771795249782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22283868593531342,
                                   -0.22919927892905453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46743780022154519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67566245943736836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3456994662001277,
                                   0,
                                   0,
                                   0,
                                   -0.15776349934467837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4749240780288439,
                                   0,
                                   0,
                                   -0.87164203929945638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6695673173842438,
                                   0,
                                   0,
                                   -0.038558515692038484,
                                   0,
                                   0,
                                   0,
                                   -0.04741427453126959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48376656525346329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22371711690684834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17609405291270269,
                                   -0.43676203877130282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30602065515064147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055823414635348539,
                                   0,
                                   -0.051839660778130237,
                                   0,
                                   0.10828781204551709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45958946148405577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68905603128606785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15291850141088273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40204200599031537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76055513196173652,
                                   0,
                                   0,
                                   0,
                                   0.098718401607862549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31345881637234263,
                                   0,
                                   0.65282791995884959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023393270184347725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0079289291834106386,
                                   0,
                                   0,
                                   0.14397463943396896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31047285476593922,
                                   0,
                                   0,
                                   0.23559085171042624,
                                   0,
                                   0,
                                   0,
                                   -0.52772331588787924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52790014976346911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095134913812846972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24902577261643663,
                                   -0.4326487524381703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08674688034351212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35666768452898889,
                                   0,
                                   -0.35034719128297476,
                                   0,
                                   0.74039056355519728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60395199908168373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20519083803119695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12414449560897589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31795454000271706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94478023020291801,
                                   0,
                                   0,
                                   0,
                                   -1.0070928695081642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23349604496769016,
                                   0,
                                   -0.018758610686648382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99273581178615466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099221516693021289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28288047624449897,
                                   -1.2996076137261803,
                                   0,
                                   0.050662187082524568,
                                   0,
                                   -0.12333808903525467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5993796516805866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28785143785329109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7564355905090977,
                                   -0.20476126488379592,
                                   0,
                                   -0.28403755804684261,
                                   0,
                                   -0.55674449953371696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15186060661337317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31703414324910628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57260188282243307,
                                   0,
                                   0,
                                   0.1214261406492928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32411830696760152,
                                   0,
                                   0,
                                   0,
                                   0.50133030260167977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88228712558871503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32097357507375857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33666567186684837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48150669990737893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12226851135991162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18067336863188391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51965567851755434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17879776067154921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17550819049558339,
                                   -0.49657674467766216,
                                   0,
                                   0.20042524065162098,
                                   0,
                                   0.13500820121952528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3629680033122316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016724819754622422,
                                   0,
                                   0.081805258212252915,
                                   0.011294577085639537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24815432394922327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026900423969631077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37126448404155715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16875116051945921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11509844751935375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51821904125798224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028891637657431819,
                                   0,
                                   0,
                                   0,
                                   -0.60388560552953507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34201017738321832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90412818524350047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22748082041245932,
                                   0.80161533262860996,
                                   0,
                                   1.13370970345934,
                                   0,
                                   -0.41694988306474501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083690273295506448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.349019099362185,
                                   -0.048904001864489038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066381088377005043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030260605046614129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36139777883945995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37723694184482831,
                                   -0.31928062114549133,
                                   0,
                                   0,
                                   0.16658057655574776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52857458447539241,
                                   0,
                                   0,
                                   0.095661725096117811,
                                   0,
                                   0,
                                   0.252260965308859,
                                   0,
                                   -0.2634620396373189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1301722847995786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17126506860087612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21272690008144912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44122299000927656,
                                   0,
                                   0,
                                   0.15013711447816172,
                                   0.16384689558396925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16725145347326018,
                                   0,
                                   -0.82626238692304022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18270996777200002,
                                   0,
                                   0.017937130238378979,
                                   0.10888253747387716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38635985712479193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097686552349988048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59074766107768473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070929013924976886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078218515033258176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65112082525775783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05072918383201086,
                                   0,
                                   0,
                                   0,
                                   -0.047206002499920775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082044331513753052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33123760927343693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044049228460110695,
                                   0,
                                   0,
                                   -0.36751050433582899,
                                   0.48557463269397971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68552638667040611,
                                   0,
                                   -0.21805547491506477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5418825602287477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73142454972148541,
                                   0,
                                   -0.20046243624512913,
                                   0.29905148629592404,
                                   0,
                                   0,
                                   0,
                                   -0.097856935105188905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038154859493754044,
                                   -0.050920801272902487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086831797808232788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11198420214472281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08977480431323738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018787872137973498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37622538221849333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33829476283299126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70307612310475931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38019091061937943,
                                   0,
                                   -0.25265477990223345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15040218215301321,
                                   -0.13543158225982693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91257454940976968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068415111291831587,
                                   0,
                                   -0.45449211791615518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   4.4115962854099355e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37450340181035852,
                                   0.43758424820524611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53866744852171577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2036161689448015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10885989925943951,
                                   0,
                                   0,
                                   0,
                                   0.049626130717110528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42506168673379346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087664151303415178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028638801421149621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17084764053537868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35569580419693314,
                                   0,
                                   0.34576473591276524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69081930135881786,
                                   0.24150444503137553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89419954369138832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21315239955340248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74321763272926811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38633170485640872,
                                   0,
                                   0,
                                   0,
                                   0.074393139408657188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51173512516062825,
                                   0,
                                   0.33638476071808465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.152398983598797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12840871940773557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49464169668777902,
                                   0,
                                   0.4672461464040254,
                                   -0.54818272493686293,
                                   0,
                                   0,
                                   0,
                                   -0.078841745709304453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29266574441909754,
                                   0.13461925260852139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13377271406078914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25060052974458452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17126051762760836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039230551799814439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1940237365896058,
                                   0,
                                   -0.060488241425875278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048546600572043949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49923542355861933,
                                   0.22125969488103667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0013891478229904469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29964945637607771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39123131731126082,
                                   0,
                                   0,
                                   0,
                                   0.12247082616463562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78918444657110787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036805937571093544,
                                   0,
                                   0,
                                   0.15684216212871926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043266113392307737,
                                   0,
                                   0,
                                   0,
                                   -0.81422783503828888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088006420343866132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50644763350826971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19093679575365069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48174237943830395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7079889227368843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057669998618613903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43986707360837979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0000490928626748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49326088680815117,
                                   0.58998674005906415,
                                   0,
                                   0.10118341651379548,
                                   0,
                                   -1.0358499736290874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099043755224699701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63477814511460784,
                                   0,
                                   -0.3279955856861807,
                                   -0.40650435763093312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25356960573260007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18672171947124472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082415021810981953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036061804894610056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34540724204189338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17060538746835363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1116551533123404,
                                   0,
                                   0,
                                   0,
                                   -0.21962906529466433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088647694525176068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24155480425438222,
                                   0,
                                   0,
                                   0.19990684965773151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38358445250120016,
                                   0,
                                   0,
                                   -0.39771666852470922,
                                   0,
                                   0,
                                   0,
                                   0.24118870013128096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19624770190685595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47230925083228043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24266034279466694,
                                   0.27975181590745535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43999823081683809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5109425430040696,
                                   0,
                                   -0.57248522856193951,
                                   0,
                                   -0.27007744816091178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31692777761509028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20213325565274295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12994317552258083,
                                   0,
                                   -0.092869382777233958,
                                   0.11469781680288144,
                                   0,
                                   0,
                                   0,
                                   -0.29366345313091274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031019134416436944,
                                   0.43529300249943348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80008095657808109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059559137673826534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010925670163548909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15770963974609695,
                                   -0.056893138726496359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33316151968188884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0014232823597723305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17702925492187213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1670793723515788,
                                   -0.24811158353474635,
                                   0,
                                   0,
                                   -0.20511856881545712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20290549548200454,
                                   0,
                                   0,
                                   0.12985809645212396,
                                   0,
                                   0,
                                   -0.18318446059067683,
                                   0,
                                   0.40534565804975198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66444716591718334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024877836299500675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42185760116940973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62414603965201798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18345276677854683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017814710717900195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50443750899144102,
                                   0,
                                   -0.056611438587796326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02011196343189442,
                                   0.3747519945725033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36626278430971559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3014390421650836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24158683387116758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32768992893568288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53922405291201247,
                                   0,
                                   -0.33580186849249988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073447110374514804,
                                   0.44757260496845591,
                                   0.44155091435656679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76383551241929992,
                                   0,
                                   0.22994738472259835,
                                   0,
                                   0,
                                   -0.53935045558283956,
                                   0,
                                   0,
                                   0.4563944138286839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31728664266039841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2975759078186061,
                                   0,
                                   0,
                                   0,
                                   -0.404552289068841,
                                   0,
                                   0,
                                   0,
                                   0.17509233731802265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5995456217485754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32858224065164598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54704736352864325,
                                   0,
                                   0.13382139749037403,
                                   0,
                                   0,
                                   -0.30436388833795625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25189592572234565,
                                   -0.37017349240723202,
                                   0,
                                   0,
                                   -0.42664728472647495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32535129530241919,
                                   0,
                                   0,
                                   -0.012073341662606655,
                                   0,
                                   0,
                                   -0.13607861622857875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24459401527215294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10130257995092903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19733997282683655,
                                   0,
                                   0.31328741315448966,
                                   0,
                                   0,
                                   0,
                                   0.41670119698261993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040119299411292095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04462460501202431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8620215585684895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34754566476687559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074523093106447211,
                                   0.026635282239338982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052567868818509438,
                                   -0.25797750866564073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24199293918800877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1035678433945276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22495112783106758,
                                   0,
                                   0,
                                   0,
                                   0.35040772588830604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34109490083757443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0052413434698340977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57083324925865186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32728996717814252,
                                   0,
                                   0,
                                   0.60714076582337573,
                                   -0.22568460486416331,
                                   0.36384209364576475,
                                   0.16813890233535328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060118605769484725,
                                   0.65908756151528325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086227265721771224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087833625371208562,
                                   0,
                                   0,
                                   0.18947677987213016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34503683089070059,
                                   0.29233201322395996,
                                   0,
                                   0,
                                   0.11187222783339591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39603679917996831,
                                   0,
                                   0,
                                   -0.49544376126228912,
                                   0,
                                   0,
                                   -0.26177813472612499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23575489754541473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13389200519792382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24113852656891166,
                                   0,
                                   0.36929844459663963,
                                   0,
                                   0,
                                   0,
                                   -0.01408833059493747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016955159933313622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33584368759470262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4180266043210511,
                                   0,
                                   -0.54929743915363616,
                                   0,
                                   0,
                                   -0.071516447454067406,
                                   0,
                                   0,
                                   -0.0060522137098953125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32264231490645445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4264164327658298,
                                   0,
                                   0,
                                   0,
                                   0.20023870630278395,
                                   0,
                                   0,
                                   0,
                                   0.66275749779829307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13268912316622913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73139813078130778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.527328761426066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0585424072811924,
                                   0,
                                   0,
                                   0.25443114063464684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31427221115514048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18453339373931882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94550157861051431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56281187487893602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12918623133280499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50012935715067164,
                                   0,
                                   -0.50725569117051672,
                                   0,
                                   0,
                                   -0.50112302357256722,
                                   0,
                                   0,
                                   0.35623208278779978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31752222752791825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62657235553349422,
                                   0,
                                   0,
                                   0,
                                   0.57021395696357968,
                                   0,
                                   0,
                                   0,
                                   0.62847002934264862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42856763718644264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086001513242390887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25368874711689304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50598054616876642,
                                   0,
                                   0,
                                   -0.50585549844804523,
                                   -0.51146026167808889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024615512833443376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034316908208208388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47404507027475284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46362680331254702,
                                   0,
                                   0,
                                   1.0306643947151719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40052098429740046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076385130412045837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87247845860604245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21897020458547412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35563401109330073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046935446023762782,
                                   0,
                                   -0.25370915536477168,
                                   0,
                                   0,
                                   0.24324875294589557,
                                   0,
                                   0,
                                   -0.36447482266832132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72922231110212976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66114805720995606,
                                   0,
                                   0,
                                   0,
                                   0.64109657996152714,
                                   0,
                                   0,
                                   0,
                                   -0.33403367732771877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66757496455472276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067004811861795022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29212545777586507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39881763463431941,
                                   0,
                                   0,
                                   0.046924786963710885,
                                   0.12136352470214895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62932801953094253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099465131853105987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64658053243481928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44899936858763301,
                                   0,
                                   0,
                                   0.6988547670355848,
                                   0.17103705294845409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19464038395400324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25355733576362538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42257745625262888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49124200314209732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42035395795524388,
                                   0,
                                   -0.066842564658906117,
                                   0,
                                   0,
                                   -0.42208040385265561,
                                   0,
                                   0,
                                   -0.43217550285384632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78422274255119429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48487384313133353,
                                   0,
                                   0,
                                   0,
                                   -0.54107800887002189,
                                   0,
                                   0,
                                   0,
                                   0.26589851517021773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25089981673888267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056397318250193618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33065633234065567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046012875091982999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063652873323753884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049844604455747038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62054364429751352,
                                   0,
                                   0,
                                   -0.40153975706892997,
                                   0,
                                   0,
                                   0,
                                   -0.50155228535057272,
                                   0,
                                   0,
                                   0,
                                   -0.16600457436593699,
                                   -0.01154470946439333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34643961875255924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21394426390115276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0228243380645998,
                                   0,
                                   0,
                                   0.25757059973213603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61932215207324237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082510795116205099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38210178481384149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0462025894374904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27453766989910133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34554965593868958,
                                   0,
                                   0,
                                   0,
                                   -0.38247963518882383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012055156908730158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079012931919914153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86330482420106991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44223003995769938,
                                   0,
                                   0,
                                   -0.40236880040620432,
                                   0.27622636299827408,
                                   -0.32362319653561517,
                                   0.094639845284991447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45873943817793261,
                                   0.116237139441006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33266346373444705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11789411527399175,
                                   0,
                                   0,
                                   -0.082601402220606995,
                                   0.35527924752983236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33729621731358522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83323503476702887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21214448103194919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41772955805553702,
                                   -0.22777939481947135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43448880682614488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50309558974198876,
                                   0,
                                   0,
                                   0,
                                   0.90492430366052812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059916293922615438,
                                   0,
                                   -0.63124648637997305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66047745653473999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48233461532952371,
                                   0.013613656118091233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24789931843302265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40752503840658894,
                                   0,
                                   0,
                                   0,
                                   0.44081542331261442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83662204595440881,
                                   0,
                                   -0.55482274563844924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89173313344094485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13890079793508317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071105251597653574,
                                   0,
                                   0,
                                   0,
                                   0.29140647090250732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073193069507283548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43545872778583083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041273237816838212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56882046098873051,
                                   0,
                                   0,
                                   -0.30324795152696638,
                                   -0.64471820562194515,
                                   -0.20950447524869806,
                                   -0.12370125578083066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014403788896973857,
                                   0.32872616358841039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6891742436340379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46879820414155404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50614572964400084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024735327360498022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14214619758793223,
                                   0,
                                   0,
                                   0.1789460859299328,
                                   0,
                                   0,
                                   0,
                                   -0.27312353734215622,
                                   0,
                                   0,
                                   0,
                                   -0.24920593779060274,
                                   0.27968241987164355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50516901685512794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032978886015045006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27735391432556999,
                                   0,
                                   0,
                                   0.032546537931014065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39443581575690539,
                                   0.2272464361739415,
                                   0,
                                   0,
                                   -0.15366113270741452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37833384837116174,
                                   0,
                                   0,
                                   -0.26691695530567622,
                                   0,
                                   0,
                                   -0.54117556654992705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27318784246975492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05085265420603842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25883005447461627,
                                   0,
                                   -0.16388507851783563,
                                   0,
                                   0,
                                   0,
                                   -0.11340193789726841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0014727154578887992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24320424800765467,
                                   0,
                                   0,
                                   -0.07413996882044499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14946383711417058,
                                   -0.65572772926641665,
                                   0,
                                   0,
                                   0.076710716295891379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42900314575214427,
                                   0,
                                   0,
                                   -0.12727743122868765,
                                   0,
                                   0,
                                   -0.20065681880095379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087491257292569194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29419571979944042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053916674305185409,
                                   0,
                                   0.018955169358223625,
                                   0,
                                   0,
                                   0,
                                   -0.30912308745284539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20884563124073247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86897118558548914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043412871136750894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079495796652079287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11352241649892639,
                                   0.10734210677341018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17731280632144331,
                                   0.3440432646062257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24993909941355652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59638303910049795,
                                   0,
                                   0,
                                   0.047957938165011302,
                                   0.17174551915171926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66852298841804858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20697215134804045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35038596720541249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38016611318171084,
                                   0,
                                   0,
                                   -0.082773935564196238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037455988806730428,
                                   -0.21840169679538554,
                                   0,
                                   0,
                                   0.04004576909504777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024885656506150003,
                                   0,
                                   0,
                                   -0.61603957450164093,
                                   0,
                                   0,
                                   0.26491208465525784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057876417506835184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1265488068795263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27673580908108442,
                                   0,
                                   -0.43646024240881853,
                                   0,
                                   0,
                                   0,
                                   0.15412191752251242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19343144348841967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28582587855420244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13330192487114029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074950735445348873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57147672262755866,
                                   0,
                                   0,
                                   -0.30343155707656166,
                                   0,
                                   0,
                                   0,
                                   -0.16802957397052559,
                                   0,
                                   0,
                                   0,
                                   -0.56843222137949445,
                                   0.083266381275961809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0013687764259682073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34347620742154461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52572464671374119,
                                   0,
                                   0,
                                   0.14092371420928904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61382782015598814,
                                   -0.25843809880029306,
                                   0,
                                   0,
                                   0.20318851022011025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19116345409295887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0203229799595803,
                                   0,
                                   0,
                                   0,
                                   0.43004685154600081,
                                   0,
                                   0.023865538742698311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23374478679669392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32535673576106383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061024381973863624,
                                   0,
                                   0,
                                   0,
                                   0.6446286917063373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35753957060519859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32524782307151434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081444854199505479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61281372192615102,
                                   0,
                                   0,
                                   -0.56041214560092256,
                                   0.14109678587259525,
                                   0.18379636369924393,
                                   -0.11833369351389178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23708188564980115,
                                   -0.07094490412708962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61435471936548969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30661980516249221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044511426387548132,
                                   0,
                                   0.20868071197610311,
                                   0,
                                   0,
                                   -0.15869876560386098,
                                   0,
                                   0,
                                   -0.51312023082452407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0088859155823353478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034076100962290579,
                                   0,
                                   0,
                                   0,
                                   0.32656736718825941,
                                   0,
                                   0,
                                   0,
                                   -0.02846031393298433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77016677253000232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38597398907654173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49111165238902388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093957030091864346,
                                   0,
                                   0,
                                   -0.080969020673902797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47855651299062379,
                                   -0.90694240654042835,
                                   0,
                                   0,
                                   -0.31478434908973318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1053276182551067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55488196259771838,
                                   0,
                                   0,
                                   0,
                                   -0.61542676302747623,
                                   0,
                                   0.86566661014767177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11516562249324055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0155836251423693,
                                   0,
                                   0,
                                   -0.30158699243092058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15325680316236678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69043254464188353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1772064306530608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67647647161045743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075157958261102234,
                                   1.310379754625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2429140640525505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14025740969138101,
                                   0,
                                   0,
                                   0,
                                   0.66420106442569771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78307916956155643,
                                   0,
                                   -0.17609544665190782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57540204094818281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3160732331819221,
                                   0,
                                   0,
                                   0.11805702024510695,
                                   0,
                                   0,
                                   -0.14525845994336084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1804754225541082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46838308640380233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2985490366227993,
                                   0,
                                   -0.15275509857670716,
                                   0,
                                   0,
                                   0.19494683036562635,
                                   0.12890590343957609,
                                   0,
                                   0.045810595890151851,
                                   0,
                                   -0.66499440917313124,
                                   0,
                                   0.041271253050140441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37619328763727161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20449962428412416,
                                   0,
                                   0,
                                   0,
                                   0.35275783254980109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063300328289727065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15446458992171652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48253432045391176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33409060659053647,
                                   0,
                                   0,
                                   -0.29905320411398217,
                                   0.59400724713457698,
                                   -0.46546798897125558,
                                   -0.19310010694192864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36865574362334524,
                                   0.6626254348032824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025066693072774412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03646646027940588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43067757845038951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39086745486960528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1179099427598037,
                                   0,
                                   0,
                                   -0.60542375046499242,
                                   0,
                                   0,
                                   0,
                                   0.45716772949936524,
                                   0,
                                   0,
                                   0,
                                   0.24069229652040314,
                                   0.057738010049129387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097510894091004163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013849708267969718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38452839825278284,
                                   0,
                                   0,
                                   0.054173980643438424,
                                   0,
                                   0,
                                   0.35422380803495213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1126719112107349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0016405143037641762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62486158068856923,
                                   0,
                                   -0.00099568763917115555,
                                   0,
                                   0,
                                   -0.31431776071131984,
                                   0.24630770920246364,
                                   0,
                                   0.10530698890402639,
                                   0,
                                   0.38684507104545263,
                                   0,
                                   -0.019394176618801329,
                                   0,
                                   0,
                                   0,
                                   -0.066180750667102189,
                                   0,
                                   0,
                                   0.25226595079143199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2859616314711525,
                                   -0.24699127138353288,
                                   0,
                                   0,
                                   -0.46591398846211118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082601270407217792,
                                   0,
                                   0,
                                   -0.14276587871736873,
                                   0,
                                   0,
                                   0.049009098070988973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19396179426406818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69105637997716252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11706053815728573,
                                   0,
                                   -0.058587920308428021,
                                   0,
                                   0,
                                   0,
                                   -0.09207698952786518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041550802884749542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10469983481786285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19379352739909508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39453403440249057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076188230161325143,
                                   0,
                                   0,
                                   -0.17437397959183296,
                                   0,
                                   0,
                                   0,
                                   0.34359733415047844,
                                   0,
                                   0,
                                   0,
                                   -0.23385986059713307,
                                   0.72323510787947243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18460858421664311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17238058122040847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47633751154312831,
                                   0,
                                   0,
                                   0.070092746643476395,
                                   0,
                                   0,
                                   0.00036311429309765844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12754402101831894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44346286159132176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088192603502792469,
                                   0,
                                   -0.012413837190409838,
                                   0,
                                   0,
                                   -0.36274370630791442,
                                   0.60578604272462988,
                                   0,
                                   -0.21714889702788123,
                                   0,
                                   0.025034665891093627,
                                   0,
                                   0.031472536210706364,
                                   0,
                                   0,
                                   0,
                                   -0.36222836656098484,
                                   0,
                                   0,
                                   -0.037026639396625337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35070318256586486,
                                   -0.10810361859393874,
                                   0,
                                   0,
                                   -0.26274515903385354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013113205993156261,
                                   0,
                                   0,
                                   0.12291571524972948,
                                   0,
                                   0,
                                   -0.1265978529544057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53133687888899794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098817557538823556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13650884104701846,
                                   0,
                                   0.24361485939035191,
                                   0,
                                   0,
                                   0,
                                   -0.4193748194165971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29403463829545667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53586244609929767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20586029017474539,
                                   0,
                                   0,
                                   0,
                                   0.11156690956932072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0050535783262638662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8558556342847714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14692568729230102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050348835877412984,
                                   0,
                                   0,
                                   -0.0051528156296717365,
                                   -0.53369801087529056,
                                   -0.26748115999734601,
                                   -0.66493374956345053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070159685639923211,
                                   0.27405053768249832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083512196274609624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54559055665918577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02745361183805034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27083182427245589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45582995144254884,
                                   0,
                                   0,
                                   0.39727768663321389,
                                   0,
                                   0,
                                   0,
                                   0.28557384185426749,
                                   0,
                                   0,
                                   0,
                                   -0.39973502414617301,
                                   0.060095195658351627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12366311259928475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048706827800181665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33325099907732642,
                                   0,
                                   0,
                                   0.27167651921216801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18080203370618375,
                                   0.0062282030972162835,
                                   0,
                                   0,
                                   -0.03262421139632992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19790209196766759,
                                   0,
                                   0,
                                   -0.07357130969928144,
                                   0,
                                   0,
                                   -0.035378115989520245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1750574757044954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070474610443986951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048212930166833423,
                                   0,
                                   -0.0039920457072941326,
                                   0,
                                   0,
                                   0,
                                   0.031190438596105305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83461877027724474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024228229542106697,
                                   0,
                                   0,
                                   0.27071234667410199,
                                   0,
                                   0,
                                   -0.024789312235827844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076888878510960254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46532245663219923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18785859794374132,
                                   0,
                                   -0.17282410618545041,
                                   0,
                                   0,
                                   0.33197978531557593,
                                   -0.04248311394349201,
                                   0,
                                   0.46101840892154944,
                                   0,
                                   0.44576238491264986,
                                   0,
                                   -0.33861471537599003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11728596023551474,
                                   0,
                                   0,
                                   -0.49435547753421227,
                                   0.73396577239044447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069019685872907133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43303535680135619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10424765246652036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25924323528388565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47709230546515902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021121897454976848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082730555766273667,
                                   0,
                                   0,
                                   0.31042254874724856,
                                   0,
                                   0,
                                   0,
                                   -0.18668394005024785,
                                   0,
                                   0,
                                   0,
                                   0.40829683117163729,
                                   0.4027260452775227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43062944363268524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22877075372410571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3006344364757787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19590407182325914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74231716212252308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17937209724635594,
                                   0,
                                   0,
                                   0.15660715912471962,
                                   0,
                                   0,
                                   0,
                                   -0.063677696263700775,
                                   0,
                                   0,
                                   0,
                                   -0.12868998685264721,
                                   0.19675082408689384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34958842314389249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2862982630299345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37562586273521814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061861492609170288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14262762558954939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52554389846268845,
                                   0.1003049553007262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19503762587061796,
                                   -0.59813746919124466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39073027342436484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62226847639785443,
                                   -0.42278217206654034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10315545813035357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87630650669497034,
                                   0,
                                   0,
                                   0,
                                   0.2410391528701378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11440440974293553,
                                   0,
                                   0.1999984736998624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89212883501093343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7346131892420531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086301931936604834,
                                   0,
                                   0.73006521773082356,
                                   0,
                                   0,
                                   0.13952456577476299,
                                   0,
                                   0,
                                   0.28974064786300319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29730507845567028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063785710381642699,
                                   0,
                                   0,
                                   0,
                                   0.1740913172644096,
                                   0,
                                   0,
                                   0,
                                   0.44929913226611834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21274336944506914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22824080666193475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42616602639892298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091564207700742556,
                                   0,
                                   0,
                                   -0.15100474720723775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50523211001672264,
                                   -0.016642473775997382,
                                   0,
                                   0,
                                   -0.011713848477123439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21183360116058642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070970570266718991,
                                   0,
                                   0,
                                   0,
                                   -0.63622859402819909,
                                   0,
                                   -0.38416581937239053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69758067915819411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41904852845106355,
                                   0,
                                   0,
                                   -0.36384035464152525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59425394003862653,
                                   -0.082501662524317301,
                                   0,
                                   0,
                                   0.70853471908025178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017325679457774468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24711833446663836,
                                   0,
                                   0,
                                   0,
                                   -0.12640236612592792,
                                   0,
                                   -0.040426825794739961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14075325366365127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58626317034129805,
                                   0.78690203142222137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83839710759066577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69186792898993765,
                                   0,
                                   0,
                                   0,
                                   -0.41901201711688241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92618650954765946,
                                   0,
                                   -0.39167311456811832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17705180459674974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57497749525046415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31448680782254934,
                                   0,
                                   -0.62621050762002228,
                                   0,
                                   0,
                                   0.97377850433987034,
                                   0,
                                   0,
                                   0.25517672302587407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12058981071542091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65765736383480777,
                                   0,
                                   0,
                                   0,
                                   -0.094303813625913377,
                                   0,
                                   0,
                                   0,
                                   0.04972055776004982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0041821858827251687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20272534218690824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042977563359515941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18302591610615876,
                                   0,
                                   0,
                                   0.08224004398050791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37908716624560324,
                                   -0.38697629791375054,
                                   0,
                                   0,
                                   0.62488275208377453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2229695422969652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43574141225743507,
                                   0,
                                   0,
                                   0,
                                   0.64387226667117226,
                                   0,
                                   -0.094140653035733476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10780091037198322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35993383712116478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27491788646285675,
                                   0,
                                   0,
                                   0,
                                   0.32864391092612155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19591153285646518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3065961551520392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55950652436167703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40663816435397171,
                                   0,
                                   0,
                                   -0.17895785464234454,
                                   0.70433909267039119,
                                   0.066300563572413776,
                                   -0.27810977034334994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044499706148798127,
                                   -0.31978994503554486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50045944072005855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21652668097663882,
                                   0,
                                   0,
                                   -0.31118743753444028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17011755915641602,
                                   -0.016154950902452812,
                                   0,
                                   0,
                                   0.17731988856638803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33227175735276732,
                                   0,
                                   0,
                                   -0.10307585166127745,
                                   0,
                                   0,
                                   -0.27392571516112796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50787756537852302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047827376049889188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27648258207968174,
                                   0,
                                   -0.1445340138210226,
                                   0,
                                   0,
                                   0,
                                   -0.49194142570861249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0021613765799510937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078675810743415564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69774026923630661,
                                   0,
                                   0.30183082943319667,
                                   0,
                                   0,
                                   -0.073093466815174868,
                                   0,
                                   0,
                                   0.20688735378218764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56499022714464908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45592662622729935,
                                   0,
                                   0,
                                   0,
                                   0.58868266827868065,
                                   0,
                                   0,
                                   0,
                                   -0.022433379059254115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22105212802794055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7243286995265763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13232311381618353,
                                   0,
                                   0,
                                   0,
                                   0.074631011920219231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.143758233236746,
                                   0,
                                   0,
                                   0,
                                   0.20370526554605042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80581565814523826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052876922704701707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065994418466893384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48269050108735839,
                                   0,
                                   0,
                                   -0.11715487008767952,
                                   -0.21629657431069849,
                                   0.71694421492373006,
                                   -0.26903087880985421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36066646354744358,
                                   0.24901195401313397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069315095831021495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28703432850885879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82575486509069596,
                                   0,
                                   0,
                                   0,
                                   0.061923547700297107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073190769608393741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10523886832790497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28712582468914527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10580949754238486,
                                   0,
                                   0,
                                   -0.53428383189403428,
                                   0.10750526922618761,
                                   -0.076253850127236067,
                                   0.257063039677352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27293365750367332,
                                   0.21918676826911049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33917221070442771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10198093393074914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0042939105371971875,
                                   0,
                                   0,
                                   0,
                                   -0.41386311121029284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094980058059810857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42087587729089476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23474314455881309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25311343760249283,
                                   0,
                                   0,
                                   0.085588795540906412,
                                   0.30360536234464641,
                                   -0.41114544177499501,
                                   -0.54899049706245828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97002064374899566,
                                   0.22850053147728039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12760776801677862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14140221616393517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40517674354757127,
                                   0,
                                   0,
                                   0,
                                   0.42972348153467504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57538180237356473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65815445690361329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14299830034726368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069425216416500762,
                                   0,
                                   0,
                                   -0.65375808824688342,
                                   -0.31967148467959239,
                                   0.015282314920526081,
                                   -0.4486833276101535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63793990957798941,
                                   -0.64204776319032753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58834703636363339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11106730477780545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31136600809863557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022101319106111281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59430181888451461,
                                   -0.24159469356910346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10355071050732362,
                                   0.63643317837441093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25078717357824687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034246954429419316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16109624195491182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76673400435720607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14920513838739274,
                                   0.28937953239562519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15485064376696744,
                                   0.073311870560124587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4996379430866883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46668796594296819,
                                   0,
                                   0,
                                   -0.13762623253666956,
                                   0,
                                   0,
                                   -0.50152092148867466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13273620003199427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16930206626205993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27516260390604652,
                                   0,
                                   0.19639573538756061,
                                   0,
                                   0,
                                   -0.24974728925343659,
                                   0.087483923909503492,
                                   0,
                                   0.20460080836761341,
                                   0,
                                   0.20685842075066568,
                                   0,
                                   0.44327333950107028,
                                   0,
                                   0,
                                   0.5224372357884417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059478162806822249,
                                   0,
                                   -0.27400657102442971,
                                   0,
                                   0,
                                   -0.74563224840375597,
                                   0,
                                   0,
                                   0.83121331954433575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1336891023648496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0046464011333782196,
                                   0,
                                   0,
                                   0,
                                   0.37828392937519606,
                                   0,
                                   0,
                                   0,
                                   -0.54989428913110605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030798339292385402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13482570772442212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58745219214382094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2302109318735463,
                                   0,
                                   0,
                                   0.76850348971576177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36060471966393803,
                                   0.34266310289919721,
                                   0,
                                   0,
                                   0.31357328237999144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10635505132904227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14566243468790116,
                                   0,
                                   0,
                                   0,
                                   -0.59702031799765098,
                                   0,
                                   0.44964955129062129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37977431463953487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0185169790663657,
                                   -0.33186269130004725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4390836819154591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71470946320158557,
                                   0,
                                   0,
                                   0,
                                   0.35505838008949125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45954344027117722,
                                   0,
                                   -1.0258558187859248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34231852658821038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44544500208654519,
                                   0,
                                   0,
                                   0.17723120302030046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22114183034653073,
                                   0.099132145087444265,
                                   0,
                                   0,
                                   -0.27478968602851628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28547295714778875,
                                   0,
                                   0,
                                   0.33363824111113111,
                                   0,
                                   0,
                                   -0.27592849304884615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36812787175000949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35338818193600308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29683981952432303,
                                   0,
                                   -0.12567641323095929,
                                   0,
                                   0,
                                   0,
                                   0.012105016564723348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050253971386016269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39509434767502888,
                                   0.13668786854182446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056095443891948156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23571590766576245,
                                   0,
                                   0,
                                   0,
                                   -1.0234937278177756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49935657453848148,
                                   0,
                                   -0.40911976767424807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079006419559180058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41608252192597595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1668625188810938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085118976498034765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038170491843621007,
                                   0,
                                   0,
                                   -0.16334828639241319,
                                   0,
                                   0,
                                   0,
                                   -0.3482839924921548,
                                   0,
                                   0,
                                   0,
                                   -0.017380569315393335,
                                   0.0027487130885322508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041072977161543608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8002180808834658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044531100359022711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076288399377017105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081856364964934314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3676776891126558,
                                   0.55591961206642304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71510525433276362,
                                   0.085504388641022527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15025502764809226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27227672958471938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16228172310963176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10878270441605463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33009044910678759,
                                   0.37884791056977291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58769598306061732,
                                   -0.019953338928559342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5379834569171813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26930767248183973,
                                   0,
                                   0,
                                   0.31302684806455638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040242402933649765,
                                   -0.057685292860652743,
                                   0,
                                   0,
                                   -0.019792905537676514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27274323570638176,
                                   0,
                                   0,
                                   0.067501984203939339,
                                   0,
                                   0,
                                   0.46825912952848342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23035573599226239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13393816034205419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4810708184847029,
                                   0,
                                   0.072156966327607153,
                                   0,
                                   0,
                                   0,
                                   -0.46548739541293305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040240434386850613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21036484695148114,
                                   0,
                                   0,
                                   -0.26516542000650406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63226579460926657,
                                   -0.53773926457229004,
                                   0,
                                   0,
                                   0.2037849896751639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48018572588466241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26714614408926701,
                                   0,
                                   0,
                                   0,
                                   0.080574699106277237,
                                   0,
                                   0.06598243021783598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85729133023655357,
                                   0,
                                   0,
                                   0.17093644489840518,
                                   0,
                                   0,
                                   -0.059601169264831652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34922737201295923,
                                   -0.14154442545835189,
                                   0,
                                   0,
                                   0.22169176455279652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10156168926493425,
                                   0,
                                   0,
                                   0.33799203323117882,
                                   0,
                                   0,
                                   -0.22699538027650315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020314397989282737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39268293817022792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40981381315347931,
                                   0,
                                   -0.50658981399273784,
                                   0,
                                   0,
                                   0,
                                   0.089989667762344988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11276086290292123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53156775944199097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42622704889450186,
                                   0,
                                   0,
                                   0,
                                   0.077087611165543357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098030682886459913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41676817192844984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36080909714835657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72494491139275219,
                                   0,
                                   0,
                                   0.23799591645917245,
                                   0.010626287565755593,
                                   0.44265760882991217,
                                   -0.58213957448622822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2942194771331027,
                                   0.46928844349436177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22455540834242807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25808590157712241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78167393379807781,
                                   0,
                                   0,
                                   0,
                                   0.0088067313251709023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43179857119774229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22960054821059744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42132087319809031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22568011266900978,
                                   0,
                                   0,
                                   -0.25957244301522575,
                                   0.090836734518469381,
                                   0.068730758416553156,
                                   0.73946709300023983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63833814328709848,
                                   -0.035623525453328642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56023516493822079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81715849063378854,
                                   0,
                                   0,
                                   0.19469887933679075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10006162234440433,
                                   0.37428522421319932,
                                   0,
                                   0,
                                   0.53426771874812362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73473154364416537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067425826113999082,
                                   0,
                                   0,
                                   0,
                                   -0.030362426197912878,
                                   0,
                                   0.055652870729380938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0089466953548761746,
                                   0,
                                   0,
                                   0.31164931660176348,
                                   0,
                                   0,
                                   0.22133329285605632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43854249925245165,
                                   0.14549114247179504,
                                   0,
                                   0,
                                   -0.48083565883860152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099104905120908984,
                                   0,
                                   0,
                                   -0.068588548845041217,
                                   0,
                                   0,
                                   0.0087028591072600223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0034591171230724596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26851983515311612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35909508974153553,
                                   0,
                                   -0.427547211574618,
                                   0,
                                   0,
                                   0,
                                   -0.055752896004025998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087321730120571581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45462472673631982,
                                   0,
                                   0,
                                   0.10265853499950282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10182242505161637,
                                   -0.23728036885871912,
                                   0,
                                   0,
                                   0.28774237826357679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65159736874603413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037223977937608607,
                                   0,
                                   0,
                                   0,
                                   -0.2815257948060288,
                                   0,
                                   -0.65947924180206685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34214354083563353,
                                   0,
                                   0.3634870062620108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59092558165691322,
                                   0,
                                   0.15308388568550127,
                                   0,
                                   0,
                                   -0.34134831275279032,
                                   0,
                                   0,
                                   -0.52336871888980963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31335953712108056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33476337625347141,
                                   0,
                                   0,
                                   0,
                                   0.3240002156293289,
                                   0,
                                   0,
                                   0,
                                   -0.23466616497208437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70567090567243684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10858793329122751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43491258614213746,
                                   0,
                                   0,
                                   0,
                                   0.57730533494188807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31508168817334059,
                                   0,
                                   0,
                                   0,
                                   -0.68599609044266929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37402281142977356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23327368143046809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058658886821907674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057526937867524122,
                                   0,
                                   0,
                                   -0.48486135424893595,
                                   -0.031865645393203718,
                                   0.62024664719537725,
                                   0.26718228926615273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094157553693101581,
                                   0.030421388151843698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0018482292454313487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14548306621618556,
                                   0,
                                   0,
                                   -0.45261805591279292,
                                   0,
                                   0,
                                   -0.060387268943344355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37994180382722381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28552271794295064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24549994000044045,
                                   0,
                                   0.072102245424981976,
                                   0,
                                   0,
                                   -0.3487196330584989,
                                   -0.40939132284930596,
                                   0,
                                   0.25303775048361266,
                                   0,
                                   -0.12931328658441366,
                                   0,
                                   -0.33018227178520337,
                                   0,
                                   0,
                                   0,
                                   -0.054365097627865316,
                                   0,
                                   0,
                                   0.66367263744003635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083531120437457668,
                                   -0.34762962352815829,
                                   0,
                                   0,
                                   0.31541704539191728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27733908295905729,
                                   0,
                                   0,
                                   0.033151404403293061,
                                   0,
                                   0,
                                   -0.26061590196279644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037763287196773659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054365571807782904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16994657791966825,
                                   0,
                                   0.060304948943564668,
                                   0,
                                   0,
                                   0,
                                   0.19653699350969159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32834086330810469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31492743859446609,
                                   0,
                                   0,
                                   0.020548995491524585,
                                   0,
                                   0,
                                   -0.25298012948881926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014997046625022818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14086764516124295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19547373174122867,
                                   0,
                                   -0.61005887693138883,
                                   0,
                                   0,
                                   -0.30932544550890168,
                                   0.031530407310811748,
                                   0,
                                   -0.3088142468634778,
                                   0,
                                   0.023172473512942549,
                                   0,
                                   -0.46191934673168999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11034717052675708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3100826393217907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49562702370419631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29284666196039377,
                                   -0.61889117431271368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19050865485725277,
                                   -0.19794556812214942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31900574218007061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21074911465202401,
                                   0,
                                   0,
                                   -0.11118977321433489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1016943599038074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86515378144263921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11086857533734795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.03140333786012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21199851838244735,
                                   0,
                                   0,
                                   0.24037059653294851,
                                   0,
                                   0,
                                   -0.42294220417094497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19836646111031692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46958008894694198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24919984214795141,
                                   0,
                                   -0.036817210698222538,
                                   0,
                                   0,
                                   -0.0066358115658065944,
                                   0.33089329685625601,
                                   0,
                                   0.50032097909150952,
                                   0,
                                   -0.14097720118988347,
                                   0,
                                   -0.12392600221138125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1266314833350935,
                                   0,
                                   0,
                                   0.54342224751062107,
                                   0,
                                   0,
                                   0.40999313168173573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14880774526684437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026858039512241038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33591638079209291,
                                   0,
                                   0.070933718945101143,
                                   0,
                                   0,
                                   -0.43334759845429793,
                                   -0.1772935128507856,
                                   0,
                                   0.26293458537642411,
                                   0,
                                   -0.30044039094067765,
                                   0,
                                   0.034694352944525747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62339754158096605,
                                   0.082952563308602387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.4593444627254948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44268747978920009,
                                   0,
                                   0,
                                   0,
                                   0.20052505851427654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17563589337267396,
                                   0,
                                   0.544138496713787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39308807113761579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1800810108688744,
                                   0,
                                   0,
                                   0.31181125805559123,
                                   0,
                                   0,
                                   -0.39366387147840576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57959408542379387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052204872137051571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14386899168143347,
                                   0,
                                   0.34186133647335248,
                                   0,
                                   0,
                                   -0.3152904824002562,
                                   -0.30278777905246734,
                                   0,
                                   -0.14859791020690466,
                                   0,
                                   0.065379517633547907,
                                   0,
                                   -0.14733249747231958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20687771772023977,
                                   0,
                                   0,
                                   -0.72653117943132617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61541130311581127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48889803294533563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16824494889157129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029084697303584817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29259913055908598,
                                   0,
                                   0,
                                   -0.098797195413267369,
                                   0,
                                   0,
                                   0.056236992227186283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046706838208401491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047723602183646859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19538691942161907,
                                   0,
                                   0.62392917480385413,
                                   0,
                                   0,
                                   0.12787383694758328,
                                   0.32963912194449252,
                                   0,
                                   -0.089077385490602623,
                                   0,
                                   -0.10820660787444464,
                                   0,
                                   -0.56998456979194878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23609516752449636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45206639641036483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2253343598577848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013052712504783013,
                                   0,
                                   0,
                                   0.11103614539354781,
                                   0,
                                   0,
                                   0,
                                   0.27711647135792122,
                                   0,
                                   0,
                                   0,
                                   -0.36227460133782924,
                                   -0.42870774670498407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50651746208409709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16802790106018509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08710104737845735,
                                   0,
                                   0,
                                   0.46971299443724485,
                                   0,
                                   0,
                                   -0.16891924055067889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6088931517938494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10569051125424747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26332170322259835,
                                   0,
                                   0.13474744302612349,
                                   0,
                                   0,
                                   0.19532332310642428,
                                   -0.19083926142235014,
                                   0,
                                   -0.41999116621301608,
                                   0,
                                   0.15043617100945458,
                                   0,
                                   0.015440460448915179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13619805691368284,
                                   0,
                                   0,
                                   0.86629238388002905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57390431108100537,
                                   -0.30605758170023317,
                                   0,
                                   0,
                                   -0.32295634781939586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46691164835305871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076597610009752293,
                                   0,
                                   0,
                                   0,
                                   -0.10938516766164072,
                                   0,
                                   -0.21359898487699186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094658335257315956,
                                   0,
                                   -0.23673400496336117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066220806199931953,
                                   0,
                                   0.63204145049737048,
                                   0,
                                   0,
                                   0.10104874516132246,
                                   0,
                                   0,
                                   0.49324049365558975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18525749846683409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17428896494724561,
                                   0,
                                   0,
                                   0,
                                   0.32998330329013903,
                                   0,
                                   0,
                                   0,
                                   -0.29688454085611776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34957684610001494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80383145923154986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12545046320167536,
                                   -0.64639630062876596,
                                   0,
                                   0.2282877510655682,
                                   0,
                                   0.55400647004282477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39489247724226173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29619997215587168,
                                   0,
                                   0,
                                   0.085891531298605814,
                                   0,
                                   0.20373618412146768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39196112273991007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40019022799388837,
                                   0,
                                   0,
                                   -0.62148502063299627,
                                   0,
                                   -0.19968799806708534,
                                   0,
                                   0,
                                   0.24499729957549035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44094464595543509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82114416971151627,
                                   0,
                                   0,
                                   0.43586821990495211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10553878768652045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022380193907411611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12492764475766159,
                                   0,
                                   0,
                                   0,
                                   0.01290402014090733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25323425103059027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84527460492683937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063161794634675861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3270421848686299,
                                   0,
                                   0.41098060101938494,
                                   0,
                                   0.26113644032957462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9274441965367668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30663742748761214,
                                   0,
                                   0,
                                   0.341382041430216,
                                   0,
                                   0.22420214221542129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22712424191375086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22285132531758253,
                                   0,
                                   0,
                                   0.46469503350321739,
                                   0,
                                   -0.29198882705006107,
                                   0,
                                   0,
                                   0.77725671714576228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43715597401915995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28805230026124351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1053230852733783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1492514506428915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27783417471013111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49678728659678695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23630560127811184,
                                   0,
                                   0,
                                   0.22721862632265602,
                                   0,
                                   0,
                                   0,
                                   -0.31909653641469998,
                                   0,
                                   -0.043570963972545375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24744582689968025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60845912630319365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17636449009005206,
                                   0,
                                   -0.15797330079620553,
                                   0,
                                   0.51441476345001835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020928036116661983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34383935744822403,
                                   0,
                                   0,
                                   -0.72968602976825314,
                                   0,
                                   0.38231683244466091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38568392893696346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56798157405206229,
                                   0,
                                   0,
                                   0.20171491851575435,
                                   0,
                                   -0.33888485413903729,
                                   0,
                                   0,
                                   -0.22034934157307462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31211995365546547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68406140333473464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15044387570675016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021788072440045755,
                                   0.059206334556401674,
                                   0,
                                   -1.1541316997658906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49337224430171922,
                                   0,
                                   0,
                                   0,
                                   -0.26527655328447247,
                                   0,
                                   0,
                                   -0.44838985659121988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59834904458872595,
                                   0.33351193437503052,
                                   0,
                                   0,
                                   0.58521431814143443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35189642488952028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38639713452087343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28667590419807198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066852232633855938,
                                   0,
                                   0,
                                   0,
                                   0.29129474327327087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0053514828009064708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17502061519374643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72436205309120938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31119043575345851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30351782254729509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8751579910677818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020549666066552286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20632082792989259,
                                   -0.046318052083410707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15971803639574836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60369769486208336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64450501308542318,
                                   0,
                                   0.36792493836056578,
                                   0,
                                   0,
                                   0,
                                   0.07078669959289359,
                                   0,
                                   0,
                                   0.64111482707835521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5222729134960431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31213772137842566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14737164293233088,
                                   0,
                                   -0.42129460483010933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56300208278385144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15003620750054084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18909038427247246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066336538666603898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44063633354361165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32604952931742842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36732620429284801,
                                   0,
                                   0,
                                   -0.42689813605605054,
                                   0,
                                   0,
                                   0,
                                   -0.22955841278455197,
                                   0,
                                   0.51651288277109364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13245428556706218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0719603819089428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037742867532387661,
                                   0.21795281194147442,
                                   0,
                                   0,
                                   -0.87505225322112123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31548208784783355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54865592928942652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70624918297873274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52691951092386702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69949549074232387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41688763406140084,
                                   0.13293382443272947,
                                   0,
                                   0,
                                   -0.70683005680252287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058381715535908291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88475641764580304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21497042016752255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028910346931925908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2238461167866808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19065539106832063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56068177675145792,
                                   -0.34292998717515405,
                                   0,
                                   -0.35661917032161616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049777595099181421,
                                   0,
                                   0,
                                   0,
                                   0.48439239551616131,
                                   0,
                                   0,
                                   0.51521519596459098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26481245428044026,
                                   -1.2466877330213753,
                                   0,
                                   0,
                                   0.013880615250635622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69346634650664152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15673387929138599,
                                   0.78548049304503653,
                                   0,
                                   -0.38524608206618283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047882393493174816,
                                   0,
                                   0,
                                   0,
                                   -0.27833874686714649,
                                   0,
                                   0,
                                   0.91982285135831832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028139085061360897,
                                   -0.13424435966531451,
                                   0,
                                   0,
                                   0.2385348115462036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21881219252035128,
                                   0.254437570604092,
                                   0,
                                   0,
                                   0.98443427985223786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28574660007581565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98725769463729707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087181843715016832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088585484043087123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64250219184910162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12772882780086231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18408469619104859,
                                   0.37047194975303499,
                                   0,
                                   -0.2134065344193003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1059665931933524,
                                   0,
                                   0,
                                   0,
                                   0.19218152879710038,
                                   0,
                                   0,
                                   -0.038516198875277075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29414982665863243,
                                   0.064297980871687893,
                                   0,
                                   0,
                                   -0.75855232504580727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15398782450734844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33839142049401333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34978942810879637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11546773127088263,
                                   0,
                                   0,
                                   0,
                                   0.4993238595689663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66291497524013554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04752931736190711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18722697005679159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013636494836901483,
                                   0,
                                   -0.38400510007786443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20164217558508676,
                                   0,
                                   0.2632588699962024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17068959248679677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11727328909917674,
                                   0,
                                   0,
                                   0.47455487583783473,
                                   0.19975217504200068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14354951331997245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34592960798600192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15832785041024727,
                                   -0.42593620959277373,
                                   0,
                                   0.22729425918549617,
                                   0,
                                   -0.18966366813193469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27699010737473184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60941644203702816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038370981851929817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57345578964729449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15942908716775092,
                                   0.44288437749376386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33636268348093312,
                                   0,
                                   0.14259720042474724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22486324475268302,
                                   0,
                                   -0.26348677976392337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11811307842713725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1865363565658103,
                                   0,
                                   0,
                                   0.12547280700182323,
                                   0.52728894401153548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34516242761338889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032288715978809383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081878089204999532,
                                   0.27521782815696816,
                                   0,
                                   0.23132546090045236,
                                   0,
                                   -0.38454368847730719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15835227074875269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05006751581040958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3108612706924294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50208589821353622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26299686770894048,
                                   0,
                                   0,
                                   0,
                                   0.54544893725456833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74789807077907222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12459893267600175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15786052381464469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018570238407608963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35548328436429899,
                                   0,
                                   0,
                                   -0.0440471856433957,
                                   0,
                                   0,
                                   0,
                                   0.40788313345559124,
                                   0,
                                   -0.28675268615354282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13998897076102174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057944779172138097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097908454731341077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29445290579612804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056348176687918888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30737011001030934,
                                   0,
                                   0,
                                   0,
                                   0.73509567265960896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3374306173530528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14595726201099013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36129119473444882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05146245819136578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64647300465296031,
                                   0.13626562868313957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18748120281283212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16780661705939526,
                                   0,
                                   0,
                                   0,
                                   -0.11484126765802945,
                                   0,
                                   0,
                                   0,
                                   0.01388123826143782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18539868613509861,
                                   0,
                                   0,
                                   0,
                                   0.16799049865379639,
                                   0,
                                   0,
                                   0,
                                   0.28688947472743315,
                                   0,
                                   0,
                                   0,
                                   -0.32797612493091821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48135131736473991,
                                   0.35552491488897736,
                                   0,
                                   -0.59787645258260103,
                                   0,
                                   0.51758218428695368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28562131377609945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50845751803366224,
                                   0,
                                   0,
                                   -0.1917335703764691,
                                   0,
                                   -0.11562719574536069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3644770119921793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47910513822019613,
                                   0,
                                   0,
                                   0.46931055386396464,
                                   0,
                                   0.51369976675538476,
                                   0,
                                   0,
                                   -0.17643657887315897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26480134004610689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81570197420494939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64727593629310043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23204410275661352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63636368243704566,
                                   0,
                                   -0.49353296691264797,
                                   0,
                                   0,
                                   0,
                                   0.081457807533829488,
                                   0,
                                   0,
                                   0.11298715158677056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078637006135661436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3247659430628802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12558421344647724,
                                   0,
                                   -0.29771034302071264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25995288945327577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91980010412767343,
                                   0,
                                   0,
                                   0,
                                   0.3177404651688423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22229519015186558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19061392397288618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8312341286702345,
                                   0,
                                   0,
                                   0,
                                   0.19705974440857882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19206894708001046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051910975479022389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20958107709701893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61850853712501397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44484525396761765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0017078305587965165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30861366919912803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11529463982800549,
                                   0.55769321499470015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079274709783823616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3210992884011985,
                                   0.23058127721567168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33346121347089114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31771869384035195,
                                   0,
                                   0,
                                   0,
                                   -0.63940755710001351,
                                   0,
                                   0,
                                   0,
                                   -0.28701992411579402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070340972250563044,
                                   0,
                                   0,
                                   0,
                                   -0.17182496879831899,
                                   0,
                                   0,
                                   0,
                                   -0.17126842124004343,
                                   0,
                                   0,
                                   0,
                                   0.24162803983874098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1090430085943795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040952589356911297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10672634836262843,
                                   0.074063485242739396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33734076252525536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15019055102761025,
                                   0,
                                   0,
                                   0,
                                   0.12047196731226253,
                                   0,
                                   0,
                                   0,
                                   -0.49112130094353018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40413592440230361,
                                   0,
                                   0,
                                   0,
                                   -0.38373554601045901,
                                   0,
                                   0,
                                   0,
                                   -0.21858748706718512,
                                   0,
                                   0,
                                   0,
                                   -0.032564087173435632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47953897586740241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57713543977195536,
                                   0,
                                   0.073110593411389785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16942856641106535,
                                   0,
                                   -0.06419617321034822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29263100286299831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35113729652834902,
                                   0,
                                   0,
                                   0.23626923184230428,
                                   -0.33070539484849248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24015931034386614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10277384400962158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088436843524282729,
                                   0.10551130047571596,
                                   0,
                                   0.29531386871101745,
                                   0,
                                   0.28323113589641685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36840422545295387,
                                   0,
                                   0.15613144581168301,
                                   0,
                                   -0.92241464618163116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52318180177227336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36953068180282167,
                                   0,
                                   0,
                                   0.032424310221280395,
                                   0,
                                   -0.024591085316390975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4190109079699067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27862570480003568,
                                   0,
                                   0,
                                   0.42911261713644921,
                                   0,
                                   -0.60127238379008452,
                                   0,
                                   0,
                                   -0.082254777358609227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38951203398454531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67157360770392749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11370039870057116,
                                   0,
                                   0.46767757969706675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37975164957989221,
                                   0,
                                   -0.28301541644785455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30898124984392927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087287756691248455,
                                   0,
                                   0,
                                   -0.18396499113630482,
                                   -0.045372669247796496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054053238660206115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07885935468406198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27234216036005626,
                                   -0.53048423535752554,
                                   0,
                                   -0.099152851401269282,
                                   0,
                                   0.17462784008334509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39245054950573294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12634824510200832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42605720419706378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22311611179227475,
                                   0,
                                   0,
                                   0,
                                   -0.058835733936591077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49372065345293581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35801046108834478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47256738046571589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68298330184232858,
                                   0,
                                   -0.35381417404584709,
                                   0,
                                   0.17944749202568672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087048193826725823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53024450343661012,
                                   0,
                                   0,
                                   0.29298717355412579,
                                   0,
                                   0.8499691426269298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55190943780921076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58279992672640502,
                                   0,
                                   0,
                                   0.19148087572654915,
                                   0,
                                   -0.12337238674991613,
                                   0,
                                   0,
                                   -0.21753083637898668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33562962390947881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055738717439978019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36226407345429673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097121252833823835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03074748796833647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55931603591061818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27591315044467279,
                                   0,
                                   0,
                                   0.099386179500598873,
                                   0,
                                   0,
                                   0,
                                   -0.017089582907779677,
                                   0,
                                   0.54197118897556995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22950387919217663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33593129347727346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2670693209474953,
                                   0,
                                   0.23519610366936256,
                                   0,
                                   -0.019031180649908552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32862822802338598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12007224049921053,
                                   0,
                                   0,
                                   0.44034292276450893,
                                   0,
                                   -0.33859111137635695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76645684237696787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46557200525035131,
                                   0,
                                   0,
                                   -0.34825640756057774,
                                   0,
                                   0.49929398224088123,
                                   0,
                                   0,
                                   0.39071525192906931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51143431649716531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26716005292576844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15799519096759404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24038306205093732,
                                   0.64418220793445979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15324954612468997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046116395003449787,
                                   0,
                                   0,
                                   0,
                                   0.066956298999483285,
                                   0,
                                   0,
                                   0,
                                   -0.14798079058830638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46085145975779951,
                                   0,
                                   0,
                                   0,
                                   -0.050192896502917618,
                                   0,
                                   0,
                                   0,
                                   -0.22979833815785422,
                                   0,
                                   0,
                                   0,
                                   -0.38566729927672083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18395446089906986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43637835757643123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19257814777350221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36124932162400997,
                                   0,
                                   0.028548912532724013,
                                   0,
                                   0,
                                   0,
                                   -0.57262656717714677,
                                   0,
                                   0,
                                   -0.08727786297603457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17903133477563771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13950019784571252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59822733293042019,
                                   0,
                                   0.81157060318467478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65534425128160523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2176339873766196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12269788999907304,
                                   -0.10926664455943463,
                                   0,
                                   0,
                                   0.39940436379762312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35962677990680347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19887976057096038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1548480702995272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0790563529084343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23094001483341248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10360685385270507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17798744348099343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51498310910499767,
                                   0,
                                   0.76617889873567657,
                                   0,
                                   0,
                                   0,
                                   -0.4583224906556787,
                                   0,
                                   0,
                                   0.31492474514121627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19431526700973509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86162593712467461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47485062780189086,
                                   0,
                                   -0.17636751406399684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38975594713954198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38643719015155664,
                                   0,
                                   0,
                                   0,
                                   -0.58757483064099081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52607653336884364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12716062674287423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35411180662203512,
                                   0,
                                   0,
                                   0,
                                   0.27171959073972424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31626568430541085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20483572575800729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14360051965548443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.305855025183768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094001626522043538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32366650272271974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027525122692555054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35540481577514849,
                                   0,
                                   0,
                                   0.39595526075700049,
                                   0,
                                   0,
                                   0,
                                   0.28717264526756459,
                                   0,
                                   0.45431139467706194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46050026640974095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089878484260180483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18569724002175092,
                                   0,
                                   0.11384217190707877,
                                   0,
                                   -0.24039004097223737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11697468223279826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057091106586567825,
                                   0,
                                   0,
                                   0.26214441987487747,
                                   0,
                                   0.43106017772573557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46125868669688841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42252151027857321,
                                   0,
                                   0,
                                   0.54832281723829124,
                                   0,
                                   0.73405063479857713,
                                   0,
                                   0,
                                   -0.066513838881755771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0725772461736127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25905814606833627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25019107034061527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013544179886244186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21440030237657348,
                                   0,
                                   0.19273304555248644,
                                   0,
                                   0,
                                   0,
                                   -0.87933755641069311,
                                   0,
                                   0,
                                   0.73557315375577204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20072186577070777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069136336631690692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85247259731209224,
                                   0,
                                   0.028982324475355092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14385551579046901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27424729054073083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31984299149305229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0079475021498666872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023645095115300871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39407639397748889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64398775898390848,
                                   0,
                                   0,
                                   0.1586715798663319,
                                   0,
                                   0,
                                   0,
                                   0.02416772147815438,
                                   0,
                                   0.20494137900290965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3801003074400815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33885661850632959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28493097157213676,
                                   -0.63918681679732847,
                                   0,
                                   0,
                                   -0.090108647555686844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.4937957357755136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071963096467775656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16020190556802194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60313354845339895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19231083473757396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069234994698613064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72142194134945115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059934266807378164,
                                   0,
                                   0.71419633353660505,
                                   0,
                                   0,
                                   0,
                                   0.021003238296479779,
                                   0,
                                   0,
                                   -0.15267821462410891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29701058229076066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22972948846291369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1515679868930655,
                                   0,
                                   -0.22198291881034091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83205839426400841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26060385632488736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99512231296299269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57263974955621855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045164935013857987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020832500490746794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0296387618926053,
                                   0,
                                   0,
                                   0,
                                   -0.36668344950671178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035540080911275279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35473550401589077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47313465656313902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1372369498517782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091503946505910164,
                                   0,
                                   0,
                                   -0.48573993294733919,
                                   0,
                                   0,
                                   0,
                                   -0.42870023338537638,
                                   0,
                                   -0.10464601500178791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40765287093934577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15804254098915174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54413258477144111,
                                   0,
                                   -0.47277831406123422,
                                   0,
                                   -0.25228108714010772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24936594555902275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4101234076408396,
                                   0,
                                   0,
                                   0.39176409745288404,
                                   0,
                                   -0.81650900301501894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50921816966759492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054718903534183169,
                                   0,
                                   0,
                                   -0.15048246470686996,
                                   0,
                                   0.30689689157577787,
                                   0,
                                   0,
                                   -0.18785195751373218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18786228125556917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094655051141542573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11480888908116563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11448864890770942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27824277243157131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085181957505135505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012046708758339401,
                                   0,
                                   0,
                                   0.47319343670602959,
                                   0,
                                   0,
                                   0,
                                   -0.39745781029805127,
                                   0,
                                   -0.28411098015968933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3083529326399288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57550483851048884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64053545206663798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088767425524971633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13766312171173314,
                                   0,
                                   -1.0083840349403013,
                                   0,
                                   0,
                                   0,
                                   -0.34982151192330529,
                                   0,
                                   0,
                                   -0.41174264849795511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3132342880343606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33098841350120828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63252217187856785,
                                   0,
                                   -0.57358913359841524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1896276112988366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22961686151941385,
                                   0,
                                   0,
                                   0.40877630346940319,
                                   0,
                                   -0.62996290182291703,
                                   0,
                                   0.51240254224087789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54731258553964557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50788196738172831,
                                   0,
                                   0,
                                   0.5987956276363392,
                                   0,
                                   -0.37294009726277177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27803087600060133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68928115858950434,
                                   0,
                                   0,
                                   0.24610529835567163,
                                   0,
                                   -0.3918769092304758,
                                   0,
                                   0,
                                   0.37148992412653037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0065754417018235763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038691892571012042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026181587077882512,
                                   -0.8963827576141481,
                                   0,
                                   0,
                                   0.50975857375650713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17617308160136985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43726658261528878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28517542234205956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98404556994862002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25629657394221783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0010003767233129623,
                                   0,
                                   0.35837795521080529,
                                   0,
                                   0.08871267516622347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24818284584317682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39856025392811945,
                                   0,
                                   0,
                                   -0.12579451931414898,
                                   0,
                                   0.1387426440018929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55290793054501386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80474589344173719,
                                   0,
                                   0,
                                   0.0060230409126762474,
                                   0,
                                   0.7212846927965203,
                                   0,
                                   0,
                                   -0.42524084475747065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4336363433503117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17363097446211284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95155818734114783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67035685319853155,
                                   -0.66439017983812798,
                                   0,
                                   0.14982329628350016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54833728397907222,
                                   0,
                                   0,
                                   0,
                                   -0.029681004040044857,
                                   0,
                                   0,
                                   0.08103052438957925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14343710373619273,
                                   0.45447582961836608,
                                   0,
                                   0,
                                   -0.0066534102480980406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47604752237093634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0035642249213643298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59993731114892179,
                                   0,
                                   -0.60908514317442175,
                                   0,
                                   0,
                                   0,
                                   -0.0097892391253941169,
                                   0,
                                   0,
                                   0.3457369298700872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37256614117921871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17513584048480674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6546584371454286,
                                   0,
                                   0.47652061429473791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64305611435000598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022169902315218478,
                                   0,
                                   0,
                                   0.60773662777955484,
                                   0,
                                   -0.9847974293298708,
                                   0,
                                   -0.50398172194306057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013907815050953499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25304555857434813,
                                   0,
                                   0,
                                   -0.1154684832419902,
                                   0,
                                   0.54264751619938278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24932266628026656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11691974809333523,
                                   0,
                                   0,
                                   -0.44650664600984713,
                                   0,
                                   0.22163597053088857,
                                   0,
                                   0,
                                   0.62321417877021235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24380227629204215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015069913571303549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12706147371268062,
                                   0,
                                   0.39326496831492258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08962424117254221,
                                   0,
                                   0.38587378781516779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48534262124976757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16532128655112441,
                                   0,
                                   0,
                                   0.31195043567341896,
                                   0.21679188354707304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095693735847751163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15211592250410763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30608245280306051,
                                   -0.28268225908748318,
                                   0,
                                   -0.1020063884648252,
                                   0,
                                   0.22083705129403636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52633949916016609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0216853528102121,
                                   -0.093714902997211608,
                                   0,
                                   -0.3991321740247844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64296925401609217,
                                   0,
                                   0,
                                   0,
                                   -0.19773544036932242,
                                   0,
                                   0,
                                   0.58560899380380516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49131045288039094,
                                   0.64964313382948813,
                                   0,
                                   0,
                                   -0.15433226504324618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1173298151261593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18221053395756664,
                                   0.30364633108059302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3685344233034924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27693779889871378,
                                   0,
                                   0,
                                   0,
                                   0.34125392451582126,
                                   0,
                                   0,
                                   0,
                                   0.12905987937060295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28895499890326726,
                                   0,
                                   0,
                                   0,
                                   -0.041153899220516876,
                                   0,
                                   0,
                                   0,
                                   0.25314349064496899,
                                   0,
                                   0,
                                   0,
                                   0.37701765561787481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47307135616499829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49681619357037538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55336299411001311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40621086394283062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47411607783852905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1535681987577715,
                                   -0.18326634616308662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31895577814037646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61354074314948881,
                                   -0.41002751996162634,
                                   0,
                                   -1.0398049970560816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49958522439426722,
                                   0,
                                   0,
                                   0,
                                   -0.14883037088561121,
                                   0,
                                   0,
                                   0.2755833403322272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43036067332657979,
                                   -0.025099265425808197,
                                   0,
                                   0,
                                   -0.53366217646284864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61522919723166691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2314417529034406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27864530161172096,
                                   0,
                                   -0.2903624163598284,
                                   0,
                                   0,
                                   0,
                                   0.16029189585714712,
                                   0,
                                   0,
                                   0.72316648738694744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59313717722935866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029378431369185765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15303165741867872,
                                   0,
                                   0.39200660701067952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064540592767171015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73823063985320925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11293626368456597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26829584538572204,
                                   0.36072729662586356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19130033285307479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067350811439486138,
                                   0,
                                   0,
                                   0,
                                   0.19648895630628149,
                                   0,
                                   0,
                                   0,
                                   0.38802238891700114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46276547545148861,
                                   0,
                                   0,
                                   0,
                                   -0.4661579409700955,
                                   0,
                                   0,
                                   0,
                                   0.17533507670244203,
                                   0,
                                   0,
                                   0,
                                   -0.20813103269863395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22208398561470599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07829338312265352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1102891370383008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15084828404849307,
                                   0,
                                   -0.14428235991384411,
                                   0,
                                   0,
                                   0,
                                   0.22538931243261418,
                                   0,
                                   0,
                                   0.71086937737543843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1111170617459605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12933751710876451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23049645207063921,
                                   0,
                                   0.23701871668866356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0055257115927587475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51166960512931248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54679156757726444,
                                   0,
                                   0.067748550552332101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40896377247429994,
                                   0,
                                   -0.0035127646225958237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.328078841394775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0073221031496264943,
                                   0,
                                   0,
                                   0.15817335412034347,
                                   0.21719148970400448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04521951040053418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25836054636006722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35744147940744714,
                                   -0.030867059358673024,
                                   0,
                                   -0.36370896563014282,
                                   0,
                                   0.13960208459487219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77088534439205869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10512512055459952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057718580539467046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7239148462564523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88575254607921261,
                                   0,
                                   0,
                                   0,
                                   -0.31946708235737353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44263036102257125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10871553539750876,
                                   -0.35637066045437854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28716470180216969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54292519092755398,
                                   0,
                                   0,
                                   0,
                                   -0.0037146280400617293,
                                   0,
                                   0,
                                   0,
                                   0.23223176489351116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36330184972019264,
                                   0,
                                   0,
                                   0,
                                   -0.31449118168724954,
                                   0,
                                   0,
                                   0,
                                   -0.022989702237185411,
                                   0,
                                   0,
                                   0,
                                   -0.04527839299922648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024717030343194141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068430453463845464,
                                   0,
                                   -0.11888808690312413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1151064596746148,
                                   0,
                                   -0.27146888804420133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27277888844103249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6478888355936625,
                                   0,
                                   0,
                                   0.030595731869031202,
                                   -0.00036448979601277909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31839323983240275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057163113066679205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095441610322235595,
                                   -0.15613825895573041,
                                   0,
                                   -0.46822071497008078,
                                   0,
                                   -0.20438388680335678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0067310369196926512,
                                   0,
                                   0.14417832128623359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3549390194026113,
                                   0,
                                   0.2279215965014173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4487751078287972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0089220646029587423,
                                   0,
                                   0,
                                   0.33577039859628116,
                                   -0.40036623204591432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14828656019901126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28328318958240384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25060750373507024,
                                   0.21742867318771988,
                                   0,
                                   -0.15884501244830082,
                                   0,
                                   -0.29862083972711356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21988417558441836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10891654833778538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50230847000870915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28871466501502302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23913079125354755,
                                   0,
                                   0,
                                   -0.28781071685218396,
                                   0,
                                   0,
                                   0,
                                   0.50391961024832554,
                                   0,
                                   -0.12360854625985376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40963852796936379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16456568302594168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01484534599631647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1496349761657476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1018326001379431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77923905639377833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1621535798650886,
                                   0,
                                   0,
                                   0,
                                   -0.73527301105179887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37044229825674541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17577077274228997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047410074937304036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19814324602742595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71506278382970934,
                                   0.52825551879909227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24460244496751321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038668640947729996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25567217397668474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55806538193721356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61953470578016145,
                                   0.42195485231760055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34911845959020427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19495059631023759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44146434025128112,
                                   0,
                                   -0.10820406207663877,
                                   0,
                                   0,
                                   0,
                                   0.39233171768523745,
                                   0,
                                   0,
                                   -0.19951794580507887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24056971153823747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0813807557784361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3641234785797085,
                                   0,
                                   0.65617851857904275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44008193180714938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41852845711099601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77036200628792295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1848379193209152,
                                   0.020292662785494305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21632407686059166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35339324911830405,
                                   0,
                                   0,
                                   0,
                                   0.16710668766419601,
                                   0,
                                   0,
                                   0,
                                   -0.28847756454945794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024128835322864781,
                                   0,
                                   0,
                                   0,
                                   0.038589434495915967,
                                   0,
                                   0,
                                   0,
                                   -0.027008653888414717,
                                   0,
                                   0,
                                   0,
                                   0.29002483980203358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047153635999340179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03193792418679104,
                                   0,
                                   0.2526808725555601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50028486287015317,
                                   0,
                                   0.27790868985753014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10000998121369595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21939252054331085,
                                   0,
                                   0,
                                   0.1723636509656179,
                                   0.014518808552974813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24790894327478658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26574404286231745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61321140404463848,
                                   -0.040383849211945405,
                                   0,
                                   -0.030630208953127042,
                                   0,
                                   -0.09424983734015388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14968175939563694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68045206038572437,
                                   0.28298245314609649,
                                   0,
                                   0.28942905943111108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24324003944292752,
                                   0,
                                   0,
                                   0,
                                   -0.90583998089560835,
                                   0,
                                   0,
                                   0.011767763581179605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48783482326002992,
                                   -0.45219879350201642,
                                   0,
                                   0,
                                   -0.42779332629507816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26720228313988026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44401011659832024,
                                   0.89080344079326801,
                                   0,
                                   -0.47749704557706785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35585278160181594,
                                   0,
                                   0,
                                   0,
                                   0.86605019387003856,
                                   0,
                                   0,
                                   -0.18140835116546666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71789036781418625,
                                   -0.029689010381249686,
                                   0,
                                   0,
                                   -0.025957795300583328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26316982960983976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36163575897865147,
                                   0.14986247566503999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46567953804900553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1534881946837062,
                                   0,
                                   0,
                                   0,
                                   0.27857655744152321,
                                   0,
                                   0,
                                   0,
                                   0.050749065040049765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15654104711849265,
                                   0,
                                   0,
                                   0,
                                   -0.13176296242709809,
                                   0,
                                   0,
                                   0,
                                   -0.14801796374019796,
                                   0,
                                   0,
                                   0,
                                   0.56821874855259302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26506148622236841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32175752311677097,
                                   -0.52524377182189419,
                                   0,
                                   0,
                                   -0.37371371636541717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28767286698317862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13767139749575691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55058336042308131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44765116668678412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37586974947319163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0221908414930905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29908030235933231,
                                   -0.40499549080462477,
                                   0,
                                   0.023796371571922721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28270312006584591,
                                   0,
                                   0,
                                   0,
                                   0.19007894258656644,
                                   0,
                                   0,
                                   1.0783155712596173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50768154062842707,
                                   0.016080325124528509,
                                   0,
                                   0,
                                   0.37216193139570214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29526753368859693,
                                   0,
                                   0.15311297275574798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070363809734940289,
                                   0,
                                   -0.32456759058434081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27801484921196135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34295955716364779,
                                   0,
                                   0,
                                   0.17611717412077899,
                                   0.38990326991513719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37986367137869315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42051193026198497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19045353071228588,
                                   0.0001077085180972992,
                                   0,
                                   0.1896558436011995,
                                   0,
                                   0.08805902056137381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028419498585610638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26097598495127183,
                                   -0.00538489250004783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062320170785262495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52222754162856599,
                                   0,
                                   0,
                                   0,
                                   -0.43601119105551317,
                                   0,
                                   0,
                                   0,
                                   0.36991818123374742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12445647651121747,
                                   0,
                                   0,
                                   0,
                                   -0.46191250125423233,
                                   0,
                                   0,
                                   0,
                                   -0.050933440460067723,
                                   0,
                                   0,
                                   0,
                                   0.14288807623216479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2750280909463827,
                                   0.35215810134608122,
                                   0,
                                   -0.23507849571675804,
                                   0,
                                   0.26474286269362945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45575155996116123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18142143015405635,
                                   0,
                                   0,
                                   0.8339196793226431,
                                   0,
                                   0.53837510759891449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53425570462256489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20796712492804251,
                                   0,
                                   0,
                                   -0.79586774852734732,
                                   0,
                                   0.019001244868594697,
                                   0,
                                   0,
                                   -0.71302761680399396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093753263627263522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038623496309843866,
                                   0,
                                   0,
                                   -0.22949698648702194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54425361915708625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7468333532897099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077385615446214889,
                                   0,
                                   0,
                                   0,
                                   -0.095734903049177381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043052789274656188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24185151231625951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1336400831637802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.443308275234308,
                                   0.70463169000199655,
                                   0,
                                   0,
                                   0.13471495972858508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12591605396785283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030380611305217471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44581984893858384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09785283039068865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34698547883138209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06383490430911648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21060506764696182,
                                   0.080073200768564667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27417244338673541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015616984742236079,
                                   0,
                                   0,
                                   0,
                                   -0.18695893200965355,
                                   0,
                                   0,
                                   0,
                                   -0.30236413253634931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0039717685303324243,
                                   0,
                                   0,
                                   0,
                                   -0.11678980335757919,
                                   0,
                                   0,
                                   0,
                                   0.8135133790972332,
                                   0,
                                   0,
                                   0,
                                   0.11828204892993269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23219920107825448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0091619248426603635,
                                   0,
                                   0.079690546845657906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09230944152510473,
                                   0,
                                   -0.282430472422322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25210941297923456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32022023739452443,
                                   0,
                                   0,
                                   0.28399174238617025,
                                   -0.13450245079684137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5365960089148436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036684014374865175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21955925727885939,
                                   -0.029704091110828904,
                                   0,
                                   -0.39102659405297463,
                                   0,
                                   -0.38621717223524066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16797736876614883,
                                   0,
                                   -0.15186770840803376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24805395387051218,
                                   0,
                                   -0.48923439510676564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011792736672151138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2535684525691938,
                                   0,
                                   0,
                                   0.46941457997696473,
                                   -0.28242330464185195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41022489668250067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012135683361507381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066559045820295731,
                                   -0.11889012223479434,
                                   0,
                                   0.18328617667538025,
                                   0,
                                   0.25039811238921028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67730932344942185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19600807269786175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0551545412520553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32197382884573456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35305957845882319,
                                   0,
                                   0,
                                   0,
                                   -0.41257268936059988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3223727449461109,
                                   0,
                                   -0.3874920967799369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082171936570850548,
                                   0,
                                   0.0070508577871797665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030191979586775577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15425273228245989,
                                   0,
                                   0,
                                   -0.22651798367850001,
                                   -0.019128191938179637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047857626391534951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61396692494440275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14588928771329604,
                                   -0.47647521388489145,
                                   0,
                                   0.042327292375181805,
                                   0,
                                   -0.18273573833159393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062650031287849323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.888064651207088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20946145642385411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26117977290192101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0004928009432527275,
                                   0,
                                   0,
                                   -0.17223342164152253,
                                   0,
                                   0,
                                   0,
                                   -0.0087091647489466427,
                                   0,
                                   0.0027235935038025863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25170344764570729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047166576128797939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019492381827016902,
                                   0,
                                   0.38355437974391576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29883856751041082,
                                   0,
                                   -0.027417845107877561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070052897613113493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13009273786136114,
                                   0,
                                   0,
                                   -0.14261834113158073,
                                   -0.25636206527315775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028767803059710148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25140388831266464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32657619317445818,
                                   -0.23258165151734952,
                                   0,
                                   0.43062468903082762,
                                   0,
                                   -0.49430908306046134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10710491539711507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2060577294449912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47185013135469622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60904373437823467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060642202931067535,
                                   0,
                                   0,
                                   0,
                                   -0.80390971710317127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58862375630950248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031524479865626238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053526974060508957,
                                   0,
                                   -0.27456608694589535,
                                   0,
                                   0,
                                   0,
                                   0.11060148772784226,
                                   0,
                                   0,
                                   0.22223773766163771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1060341498651565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21174341154934062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0040819304276739216,
                                   0,
                                   -0.52879088651045569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086498350675247332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5412479266231226,
                                   0,
                                   0,
                                   0.48336528100092579,
                                   0,
                                   0.38150059349018017,
                                   0,
                                   -0.49318155784334039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43182955323597644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0250113459356078,
                                   0,
                                   0,
                                   0.40590181030918288,
                                   0,
                                   0.25339464167150799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24293044060314292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10320322846910195,
                                   0,
                                   0,
                                   0.20712443799540489,
                                   0,
                                   -0.29918779504837067,
                                   0,
                                   0,
                                   -0.69842675494782325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15657421350300058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0089287282209572702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27273884269258791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12402631367369742,
                                   -0.3594040112536615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34465247568657742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22091287483467067,
                                   0,
                                   0,
                                   0,
                                   0.27075436186907492,
                                   0,
                                   0,
                                   0,
                                   -0.34513867657675334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33873582798376162,
                                   0,
                                   0,
                                   0,
                                   -0.47825501974690343,
                                   0,
                                   0,
                                   0,
                                   0.073377317782954421,
                                   0,
                                   0,
                                   0,
                                   -0.2352494308271427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12979578402490957,
                                   0.13096989791159883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049280602603328137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060977514275851914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35755420888675049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1178050977632246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19896876969669899,
                                   0,
                                   0,
                                   0.23079920586965064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054521421929009176,
                                   0,
                                   0,
                                   0,
                                   0.57255510263424891,
                                   0,
                                   0,
                                   0.038215638663550211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26889796050473835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61149724436912456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047621125281502537,
                                   -0.4050652981845701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13167280735890657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73037612827730358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23314260138099663,
                                   0,
                                   -0.25148375840352755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29207213162620327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1067049786518971,
                                   0,
                                   0,
                                   0,
                                   0.035439844828749623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0578902710146732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15666907704198499,
                                   0,
                                   0,
                                   -0.26055050946986524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38033519744131722,
                                   0,
                                   0,
                                   -0.49163119397033284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28359196035762341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11644739873611624,
                                   0.29823141005272136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20164060851596588,
                                   0,
                                   -0.24139066601964265,
                                   0,
                                   0,
                                   0,
                                   0.37300751852554392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29780120380586933,
                                   0.10741142357104394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20018197293846904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67347130810194145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23007603761256229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72563260203439317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79886930393004252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9608990350528579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29641102189910107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098936864420094722,
                                   0.38845160169987025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38506397953065125,
                                   0,
                                   0.0070749097968316188,
                                   0,
                                   0,
                                   0,
                                   -0.77661640042664559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65216766012874894,
                                   0,
                                   0,
                                   -0.17964476907045898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52826161879181799,
                                   0,
                                   0,
                                   -0.17809741145098756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13650843302061105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10914429450411926,
                                   0.2116186583072025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078709951176349907,
                                   0,
                                   0.11884889757828448,
                                   0,
                                   0,
                                   0,
                                   0.088052477897089088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35296804870602733,
                                   0.060304138999895056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33728856057840906,
                                   0,
                                   0,
                                   0.26860480783198015,
                                   0,
                                   0,
                                   -0.37334632694349362,
                                   -0.080123290763991287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30996717659324791,
                                   0.12776011461455311,
                                   0,
                                   0,
                                   0.29495958951382345,
                                   0,
                                   0,
                                   0,
                                   -0.069947283049485678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22462836865722829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.145036354045807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079638886098200495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28807292001004725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53249038581156471,
                                   0,
                                   0,
                                   -0.14005986162860801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26194663479828162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28101926066207772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11943470479491024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27498335019468667,
                                   0,
                                   0,
                                   -0.57019119584605693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43156349357835327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15916255549323277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12849265204204163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45119198875275263,
                                   0,
                                   0.075824163935696368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22259044232518294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70137228909724936,
                                   0,
                                   0,
                                   -0.1112193049843441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19351327015508046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19481315502868352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30806529164317759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4875655903129007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19528618333117717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078423599624492066,
                                   0,
                                   0,
                                   0.39335792158392002,
                                   0,
                                   0,
                                   -0.14756120410911627,
                                   0.10228606074545957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15081139687797365,
                                   -0.71385937991559534,
                                   0,
                                   0,
                                   -0.21652369882267242,
                                   0,
                                   0,
                                   0,
                                   -0.36694503347670265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14608334293410885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030516436580020817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13752601945900869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13447208274922207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040623220747021044,
                                   0,
                                   0,
                                   0.17914822574048569,
                                   0,
                                   0,
                                   0,
                                   0.27286968670408773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37622885538581297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59750118817386011,
                                   -0.37911974549684613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35897456015011237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1920552887079022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44276557662860133,
                                   0,
                                   -0.56962726120695428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10559583568446224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19464608742206427,
                                   0,
                                   0,
                                   0,
                                   -0.30996932889626344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39068883222420514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0379670516505388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55737160149743548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13202744046648446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63219096861844004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16765619771567636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76193682907987093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043111026362516638,
                                   0,
                                   0,
                                   -0.011594209480839071,
                                   0,
                                   0,
                                   0.17306111297811122,
                                   -0.41068360389618297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04905848918860696,
                                   -0.39160429687781068,
                                   0,
                                   0,
                                   0.31779081491921962,
                                   0,
                                   0,
                                   0,
                                   -0.023655472556300378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049254438312029497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1139796090252678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095398934874459357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018516854943789393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2058107357699169,
                                   0,
                                   0,
                                   -0.68910475084507861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07492294782093542,
                                   0,
                                   0,
                                   0.0059008971033510937,
                                   0,
                                   0,
                                   0.049183920915442485,
                                   -0.23332262533172998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072580373942741166,
                                   -0.19461654983623719,
                                   0,
                                   0,
                                   0.60196408525355161,
                                   0,
                                   0,
                                   0,
                                   0.055159052701378712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32292889925557677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33262670474242773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12559664382755983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13286043163068759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024600822122798724,
                                   0,
                                   0,
                                   0.52914196789502499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35374526016483943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75753801292159861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025645500668559404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064989467214743579,
                                   0,
                                   0,
                                   0,
                                   -0.61140998642953925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29366105114537056,
                                   0,
                                   0.63253708559203492,
                                   -0.15375951591108078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20800572214661245,
                                   0,
                                   -0.18622109521727692,
                                   0,
                                   0,
                                   -0.51966405949756556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097230314050665484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60100242173241847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29602811444844129,
                                   0,
                                   0,
                                   -0.36639949761353807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24949671228677239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35767891383897321,
                                   0.46620900874251076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30675533828545676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073878348600590824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7383149611839388,
                                   0,
                                   0.48533972944909232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43318009056293022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22193227943539187,
                                   0,
                                   0,
                                   0,
                                   -0.68712483314553685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30096484905906884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07934589339703485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14805135153459983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22003014669827875,
                                   0.065219401827203038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46424462935060773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55625566207377797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78897733050097529,
                                   0,
                                   -0.063195934853427449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02078421781346191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06645377923005949,
                                   0,
                                   0,
                                   0,
                                   0.014946500585352518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69141126203012937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14427200998418638,
                                   0,
                                   0,
                                   0.35161361745765451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083605592408895035,
                                   0,
                                   0,
                                   -0.37022877153473815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085962278912188189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21967313759411314,
                                   -0.44144494626450459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42138725815496791,
                                   0,
                                   -0.19800561800640887,
                                   0,
                                   0,
                                   0,
                                   -0.25075310778072296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11929553913774139,
                                   -0.40876983575515186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28465972064700451,
                                   0,
                                   0,
                                   -0.10158996326164806,
                                   0,
                                   0,
                                   0.13816272658537065,
                                   -0.34706790693670608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2564383628787455,
                                   -0.031166507309242964,
                                   0,
                                   0,
                                   -0.48856520218588401,
                                   0,
                                   0,
                                   0,
                                   -0.1503672078080564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46313149562046529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13930755210284426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25145321217123184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12574387497987141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35708927707431065,
                                   0,
                                   0,
                                   -0.024792025771422234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26189069105856111,
                                   0,
                                   0,
                                   0.1295793696306799,
                                   0,
                                   0,
                                   0.59909038703165907,
                                   -0.10629962504895583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27115327456318417,
                                   0.23581008071289272,
                                   0,
                                   0,
                                   0.10231533191755926,
                                   0,
                                   0,
                                   0,
                                   -0.4309251033164393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33677908420134389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069010244277233485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15966207179457559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083006218906342438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21967488515256733,
                                   0,
                                   0,
                                   0.14246598335565425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070583782633431735,
                                   0,
                                   0,
                                   0.052194018066329825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13230404446788699,
                                   0,
                                   0,
                                   -0.37108994864576805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53490297232279005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3233869964211234,
                                   0.38767584520984688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1406378654193223,
                                   0,
                                   0.36161690742516289,
                                   0,
                                   0,
                                   0,
                                   0.042323106165252894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29441869145261396,
                                   -0.23889180732704232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11583216724540335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50662801883603348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30665050675738958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42666071448530696,
                                   0,
                                   0,
                                   -0.10011394649770253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43333264364762714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21275919137440363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12029404818369857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28275122040812328,
                                   0,
                                   0.34110364181997493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37500184735679187,
                                   0,
                                   0,
                                   -0.34544301434557723,
                                   0,
                                   0,
                                   0.11187314221555758,
                                   -0.011695300962876118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56573521184386122,
                                   0.0091172095462347183,
                                   0,
                                   0,
                                   0.041686932940547414,
                                   0,
                                   0,
                                   0,
                                   0.11050254384640396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39410452373959071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2013218103131576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061349848071482971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2556268854935666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35461890709775273,
                                   0,
                                   0,
                                   -0.050891724711198696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25665329087109329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45788843459185224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22832723408326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70754675906109865,
                                   0,
                                   0,
                                   0,
                                   0.16411847561013165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76898369149448265,
                                   0,
                                   0.28029667271656949,
                                   0.036662821119682346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87278656322771553,
                                   0,
                                   0.63273978462536917,
                                   0,
                                   0,
                                   0.10496605468065581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41604444705729676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11816679746148873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22247138043670578,
                                   0,
                                   0,
                                   -0.12873805852879416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0078507826217735222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36602992853970906,
                                   0.065269400313447995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18346219485826143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12850576260671551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17130434964198293,
                                   0,
                                   0.35920783144270491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05521645262375565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49515434464666169,
                                   0,
                                   0,
                                   0,
                                   0.88014126279030003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022521609248379509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.300538475158384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88974265001511066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2102569082030592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60731008988673696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43807508257924543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093149879605537153,
                                   0,
                                   0,
                                   -0.87069930048590727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25927611918980736,
                                   0,
                                   0,
                                   0,
                                   0.21866070018559855,
                                   0,
                                   0,
                                   0.20655761061285816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041959661007811774,
                                   0,
                                   0,
                                   -0.43843694471421268,
                                   0,
                                   0,
                                   -0.34709046257654264,
                                   -0.47549912370325731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19215049495376715,
                                   0.091021213632987222,
                                   0,
                                   0,
                                   -0.082584466146247384,
                                   0,
                                   0,
                                   0,
                                   -0.42287398981606433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04907607058563257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28303459772784051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22349235079767862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17248974525764407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1579548848632957,
                                   0,
                                   0,
                                   0.20352791994812819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020993136065780571,
                                   0,
                                   0,
                                   -0.012868923038625191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0052960974659248365,
                                   0,
                                   0,
                                   -0.13947520698049681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12006445580493971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37833729405523553,
                                   -0.6164365103257653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17252714508221442,
                                   0,
                                   0.22245685861257922,
                                   0,
                                   0,
                                   0,
                                   0.40059374060951947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042471832510309046,
                                   0.44814269251839883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1417167979637963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42700334122903921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71695845894754207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76887068696695404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77539960293999877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07109126546594409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42324861740800046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12146305789757267,
                                   0,
                                   0,
                                   0.092364994963302749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8003251142017398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10270560711206321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076803693058995759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12965901893291568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35184803896197131,
                                   0,
                                   0.5494072857880391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24591739846909305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21664289189892699,
                                   -0.014606868750828693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21833691116203435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12909040815527448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32830608551611645,
                                   0,
                                   0.21571748461754481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11276636342567348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75210901028320276,
                                   0,
                                   0,
                                   0,
                                   0.080986710879592805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65059516864709332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045621111540834064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7198066585433639,
                                   0,
                                   0,
                                   -0.15327912729541704,
                                   0.37317059856290946,
                                   0,
                                   0,
                                   -0.77086659920779599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5886348268156737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48985379614329272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24637206211367807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34958315981954496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039019406218832091,
                                   0,
                                   0,
                                   -0.84210598039450457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25116033651361996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10577099473553872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14573567814762275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26716008896853394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015626871245385275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50702944745366774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29384785297077831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87565873764791913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39891555253357297,
                                   0,
                                   0,
                                   0,
                                   -0.15845436956342535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11327477454789063,
                                   0,
                                   -0.4070240059111141,
                                   0.91350124642097796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26772320317783566,
                                   0,
                                   -0.21846374026975046,
                                   0,
                                   0,
                                   -0.077077544437212098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54734357529004851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30980801844605815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019849625570115256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29804946954418521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017013317955500082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50882680200292807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40154626879315758,
                                   0,
                                   0,
                                   -0.30906264196983929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29680361323174725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41574015501884254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22836338053129565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21371182273384726,
                                   0,
                                   -0.19094079074557707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24172290555665985,
                                   0,
                                   0,
                                   -0.36851933660904801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35864472213788734,
                                   0,
                                   0,
                                   0.44032184793109558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33741393516062906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10674815642324502,
                                   0.043108952882506907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51130529518539092,
                                   0,
                                   -0.19176569999944218,
                                   0,
                                   0,
                                   0,
                                   -0.11115940361582917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11684878415892776,
                                   0.17870426598194541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044663952923923417,
                                   0,
                                   0,
                                   -0.34129652311200676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15019722096751936,
                                   0,
                                   0,
                                   -0.36668106966398673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048117418096522833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19901149412569208,
                                   -0.10935556168287816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28590186029483994,
                                   0,
                                   -0.041966135030864521,
                                   0,
                                   0,
                                   0,
                                   -0.70249807273726006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095503864331581867,
                                   0.2906932102472819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067099507168703332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010840648849615331,
                                   0,
                                   0,
                                   0.13385917807218761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26779518304358824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78284354779620646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18731657250448053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18032011127151779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47465854639389843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030480080169209715,
                                   0,
                                   0,
                                   0.33022737147613079,
                                   0,
                                   0,
                                   -0.1947689740752977,
                                   -0.34938203811944984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14403959195042537,
                                   0.22434789294827454,
                                   0,
                                   0,
                                   -0.18236102637907717,
                                   0,
                                   0,
                                   0,
                                   0.1546204366098316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094977688291771611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61844820735152384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40929201060887521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03741711889741748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14668455648475515,
                                   0,
                                   0,
                                   -0.16961998379897125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38067142387756964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16898364185190878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74969233878200547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052098265681223443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91709997748339078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37434623366930975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22703350108335446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051232047778172599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19833245729167887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12536875557308547,
                                   0,
                                   0,
                                   0.37332499036073308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056415494852381509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58656626662153522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45684021547219905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37580505022279986,
                                   0,
                                   0.2328761866437529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58027797798221359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13250855224958843,
                                   -0.53328319056626294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40245364903457903,
                                   0,
                                   0.42356259101301097,
                                   0,
                                   0,
                                   0,
                                   0.1412578577713593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48371402146738229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73213657178842739,
                                   0.26233048425403149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086249284522247269,
                                   0,
                                   -0.14314408682492166,
                                   0,
                                   0,
                                   0,
                                   0.36503470251915277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49587491231266606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48389583130733571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0069241527035514248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037822633519828952,
                                   0,
                                   0,
                                   0.5358357097808184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14886202270683394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2821578661163473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14078194600449223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081184148270802531,
                                   0,
                                   -0.32120259485559766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60880336788344702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018640437318743208,
                                   0,
                                   0,
                                   0.72123372026433452,
                                   0.73047251092595666,
                                   0,
                                   0,
                                   0.3347571102118474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40896749477541705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3336481761246517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49523461088115045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086573155408394858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83834151681746261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70692492193728373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57515360204379973,
                                   0,
                                   0,
                                   0,
                                   0.41248922881868566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59043958910257843,
                                   0,
                                   -0.13554089799065608,
                                   0.083499848365017004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35576323935637733,
                                   0,
                                   0.13958868251438628,
                                   0,
                                   0,
                                   0.12607188835916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68303417014765544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34488192497795522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0024328570023254906,
                                   0,
                                   0.11055214741252709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33141602488188188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46917240994258025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61738661009062556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48203640440615897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045494309387771756,
                                   0,
                                   0,
                                   -0.22682940510722588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25160330420967442,
                                   0,
                                   0,
                                   0,
                                   -0.86589778860102029,
                                   0,
                                   0,
                                   0.8191799820690786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12627491859816956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22575538632909428,
                                   0,
                                   0,
                                   -0.79713570985888027,
                                   0.65597654000441352,
                                   0,
                                   0,
                                   0.2228770244694129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82555451622517162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75796353465067334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054546915954255926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1388712292726082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48308945670164849,
                                   0,
                                   0,
                                   0.23911273693786528,
                                   -0.68080888521389182,
                                   0,
                                   0,
                                   -0.052189918600532625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59681041486862585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49397433783331052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14799451011063255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2431118374929524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74321683490275259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67559111977521324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054521652496993991,
                                   0,
                                   0,
                                   0,
                                   0.47140992716140251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28230737681738099,
                                   0,
                                   0.074391271086713145,
                                   0.068550488620664707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12423247118715028,
                                   0,
                                   0.17668847421083586,
                                   0,
                                   0,
                                   -0.62957321571145364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58098640070980423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14254805778836155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35474813993302623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14398554852628767,
                                   0,
                                   0,
                                   -0.39814223171486957,
                                   0,
                                   0,
                                   -0.1284470629611425,
                                   0.4011583587726355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18372323553716746,
                                   -0.042884534054263485,
                                   0,
                                   0,
                                   0.19971548113546833,
                                   0,
                                   0,
                                   0,
                                   -0.45989357341425241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15662640515693532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44811108839711317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19743641443581417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052359951685505404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10832141440398765,
                                   0,
                                   0,
                                   -0.27847972294747159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064176590283670218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4223967763531189,
                                   0,
                                   0,
                                   0.55820460245171177,
                                   -0.4009925440229053,
                                   0,
                                   0,
                                   -0.027006167045757562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40885754806970159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67388379918168195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0307423433283389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0026792922070317804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91694381960245452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40970481642352735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40984838649717836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31267977156422017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86671007442884485,
                                   0,
                                   0,
                                   0.14584711327796057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060418205425427821,
                                   0,
                                   0,
                                   0,
                                   -0.016655195028384678,
                                   0,
                                   0,
                                   -0.13626240689148372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16355265891516291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36463365466252812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12597959443131398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24989189575232162,
                                   0,
                                   0,
                                   -0.15155299321143839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040245555073203182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0029839658528129365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72688013445662358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41808070926436836,
                                   0,
                                   -0.18502129617986565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20304441383916208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082984577298384571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22870019088690965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083062436141150803,
                                   0,
                                   0,
                                   0,
                                   0.51381059979805621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49389114954864616,
                                   0,
                                   1.0502117309089527,
                                   0.0088933653004804603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15305289489043472,
                                   0,
                                   -0.031908045451467054,
                                   0,
                                   0,
                                   0.14709995353706168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58672905316441637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017685454595120345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5322703972661631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63293451206934226,
                                   0,
                                   0,
                                   -0.28162848106073463,
                                   0,
                                   0,
                                   -0.14107831796854881,
                                   0.19085700580535045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24196929761038918,
                                   -0.22102480826418636,
                                   0,
                                   0,
                                   -0.11985665204644237,
                                   0,
                                   0,
                                   0,
                                   0.30623423248457327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014700422796678577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052771325332746262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17526996944799139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20138855225864502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41554498681524138,
                                   0,
                                   0,
                                   0.035330187311674505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012296885630573774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55030551350038526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069198441963503513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86320429890513806,
                                   0,
                                   0,
                                   0,
                                   0.19394113354962375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13627572346955577,
                                   0,
                                   -0.084999057336409334,
                                   -0.31346648483137102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29884668185309166,
                                   0,
                                   0.45433242721969563,
                                   0,
                                   0,
                                   0.24912943046715161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44120003241164424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63659858746571241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33542685835728719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63798088967779021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14940718359742711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13212900243768438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19026860773135656,
                                   0,
                                   0,
                                   0,
                                   -0.29207639955547438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18998818674507797,
                                   0,
                                   -0.045060307571534633,
                                   -0.17526600085317789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70455875276846813,
                                   0,
                                   0.78157321121698109,
                                   0,
                                   0,
                                   0.46302155326619032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094209189695189807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66340845820417593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47830095300290582,
                                   0,
                                   0,
                                   -0.30529866730549859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06913435319432655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0020568383131724446,
                                   -0.45014626320648848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71397824077686811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18795317109668902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21109314647211819,
                                   0,
                                   -0.14595146243987617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020401075301839169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66370878668428746,
                                   0,
                                   0,
                                   0,
                                   -0.20026170791099032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73035089652238838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3301033345089831,
                                   0,
                                   0,
                                   0.035258669817628915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30569109862799487,
                                   0,
                                   0,
                                   -0.23227752711397404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30764972362605625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60638947701502044,
                                   -0.0057214461711062453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020371090911116205,
                                   0,
                                   -0.0744470206932734,
                                   0,
                                   0,
                                   0,
                                   -0.00016483699930681245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30234504949527174,
                                   0.42735177053288581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58087860232766553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47307849613887931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05024174246582995,
                                   -0.11858493499806005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097704422873090668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31006614753067097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94969993575058376,
                                   0,
                                   0.4532858675108134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0465720689915801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24232070573456846,
                                   0,
                                   0,
                                   0,
                                   0.070383492473022238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41537152421368734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35226680937498217,
                                   0,
                                   0,
                                   0.34046046892999166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1226759806541329,
                                   0,
                                   0,
                                   -0.084014535073055396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22921678937936796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18609776235756337,
                                   0.079698286760649092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35096341240480933,
                                   0,
                                   -0.64772525996130448,
                                   0,
                                   0,
                                   0,
                                   0.20106722538427352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19506842352726561,
                                   0.15218195344841162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54248661508975293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49106614309120988,
                                   -0.24369982422376876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63410099779370244,
                                   0,
                                   -0.02842490770579377,
                                   0,
                                   0,
                                   0,
                                   0.047756260848593662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33450798043612495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30906142380676072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41766301032077063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12068538448064325,
                                   0,
                                   0,
                                   0.0013754832839461308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031227555664705281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46595792340946851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.280383580354022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31377405631835775,
                                   0,
                                   0.45652507707233059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20948629137048316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28416760145700026,
                                   -0.1327941317955954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3004250357339403,
                                   0,
                                   -0.86802108983006809,
                                   0,
                                   0,
                                   0,
                                   0.1183814685039461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067055156031257057,
                                   0,
                                   0,
                                   0.13633663938440727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45539578403318925,
                                   0,
                                   0,
                                   0.10456116101352303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36728639601664403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38369509284256387,
                                   -0.086909014638534773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41290302448734773,
                                   0,
                                   0.3180782724704897,
                                   0,
                                   0,
                                   0,
                                   0.11475056551210164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42898104565536171,
                                   -0.0082490994639566537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29930455414019108,
                                   0,
                                   0,
                                   -0.20967933918849496,
                                   0,
                                   0,
                                   0.40276880064856724,
                                   -0.069846615365471307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088276586859469403,
                                   -0.28514978235341393,
                                   0,
                                   0,
                                   -0.17958237521192516,
                                   0,
                                   0,
                                   0,
                                   0.19478590454732239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17916167379454173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065336283139827617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29299251408166416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56088371976391405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3174265629003894,
                                   0,
                                   0,
                                   0.049930465483950109,
                                   0,
                                   0,
                                   -1.1720387928799569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093032949352760103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034695611733787324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42854918042063478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33192637332599878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076580116517322661,
                                   0,
                                   0,
                                   -0.89862550492837079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014774733289026981,
                                   0,
                                   0,
                                   0,
                                   0.32507267949438901,
                                   0,
                                   0,
                                   0.15727586071855304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057118175546429673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33872088521528454,
                                   -0.647204158717541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43586531803696682,
                                   0,
                                   -0.2139763065970357,
                                   0,
                                   0,
                                   0,
                                   -0.47683122551650214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72867455694343275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16788133514958356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21252118572154624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14986498497491985,
                                   0,
                                   0,
                                   0,
                                   -0.2478204703089906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21399024543501843,
                                   0,
                                   0.37925288384760214,
                                   -0.79962983574341773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1786254979847719,
                                   0,
                                   -0.17881601092587002,
                                   0,
                                   0,
                                   -0.66852520576936092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055909323128144658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059416468767042763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48217705770895231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49762898736522704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37766534212525815,
                                   0,
                                   0,
                                   -0.84108368282130408,
                                   -0.56877715285222596,
                                   0,
                                   0,
                                   -0.2304390530378671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20642814244280072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32848552253260943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72376826108597314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28995556014733864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05691663965425893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47533532964864555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021819128257367176,
                                   0,
                                   0,
                                   0,
                                   0.17462136659255445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38869471040302084,
                                   0,
                                   0.65458047740231651,
                                   -0.17367899312220506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64336531317613721,
                                   0,
                                   -0.0066971861305834546,
                                   0,
                                   0,
                                   0.71483687908022175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050571901084098675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36706572787264535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92623639813644387,
                                   0,
                                   0,
                                   0.50227361136605486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58178152113733383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43133866744058785,
                                   0.13169175523261961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08320692559762348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41361065015790588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51644912705732793,
                                   0,
                                   0.17794659452986281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24287452740156754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098260557916655222,
                                   0,
                                   0,
                                   0,
                                   -0.11554779919962772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17920547897843719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45085913347683848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32713005441777199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6737154235569015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36202328044845367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097108840567059415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50263850128718413,
                                   0,
                                   0,
                                   -0.69018198682712872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03577438789967434,
                                   0,
                                   0,
                                   0,
                                   -0.26536622088124001,
                                   0,
                                   0,
                                   -0.46686809621693981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051726328506252896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67617304918159282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10305319838836063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18428420252574831,
                                   0,
                                   0,
                                   0,
                                   0.57530382062288166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57804936436350418,
                                   0,
                                   -0.3935711688182873,
                                   -0.51268327319066787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67784201143172595,
                                   0,
                                   -0.17733579918493353,
                                   0,
                                   0,
                                   -0.247131898756171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28922450999503141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10676670972498609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0025493940433334306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084983062136493412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38108981705297673,
                                   0,
                                   0,
                                   -0.0095064468594884509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24159661449456726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17114795398425986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68514461649630554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21095081355973391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49585695559599008,
                                   -0.39835922709241101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32917791942853714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12332818928909905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89496415785163896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10552540577580745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85432111251835841,
                                   0,
                                   0,
                                   0.37405011770218066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55732615915793171,
                                   0,
                                   0,
                                   0,
                                   0.27622846826491376,
                                   0,
                                   0,
                                   0.29226712258341203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38299657057198544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34129278816229425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61031906925553037,
                                   0.31264461582060066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45268436260540473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16834972021945344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14334504551228544,
                                   0,
                                   -0.19149323217191627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056972904510691161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52218787079622397,
                                   0,
                                   0,
                                   0,
                                   0.26823173585887639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1892259427580861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0069674542573152365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41553552907500829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07018489915314971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47932363982757586,
                                   0,
                                   0,
                                   -0.12841224288711292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12026101987952202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32518768017492899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2640714608669309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49420878010727159,
                                   0,
                                   0.37673479763356876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91934501361787602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75884487830398262,
                                   0,
                                   0,
                                   0.056490415982178632,
                                   -0.19421367075800383,
                                   0,
                                   0,
                                   0.097636502385011162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42728863462629507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20499284160438305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45988541557970458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45755981669297752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36761139856273228,
                                   0,
                                   0,
                                   0.38598868840067818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037533483003642898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20180798215536591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16873536211465184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65384749736066039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091598089393835527,
                                   0,
                                   0.011976699328192123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077323571582869843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43641168739840902,
                                   0.53568033953976169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078626638305995561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20266087290096213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34114314363142706,
                                   0,
                                   -0.76098404148446397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55791384197420613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062234618616309662,
                                   0,
                                   0,
                                   0,
                                   0.18718486543089502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060539423434924744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066402262170653176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10792773351781068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90534113997445054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042695060459509535,
                                   0,
                                   0,
                                   0,
                                   0.24091345310965379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30094937882986161,
                                   0,
                                   0.27989896436056538,
                                   0.34585384205888886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47050710376653715,
                                   0,
                                   0.56495368720689276,
                                   0,
                                   0,
                                   -0.4902762222547693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27324728531918291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51714183234509914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30279808180034112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62326327834961659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16017722578081259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41931517913310984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16232833144560946,
                                   0,
                                   0,
                                   -0.25389167614008806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55361831209829393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080103335775239662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032776084621605715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035949336219588582,
                                   0,
                                   -0.063032102589430844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53180984817949217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28202925106190696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3129074607730113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31880443765493105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45823809918539654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52150240230850664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067427911184052156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021992931198429912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47153791801888817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48046326487169294,
                                   0,
                                   0,
                                   0.19729960944876188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43472975851626056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059988517148522963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1028052421536256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064839654349728659,
                                   0,
                                   0.54358808958762717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4705701232929706,
                                   0,
                                   0,
                                   0.052979516980547738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26641837689262432,
                                   0,
                                   0,
                                   0.16795005449482797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39235846979945715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27174967517677445,
                                   0.082473102639080517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097439761012853149,
                                   0,
                                   -0.32128374813138943,
                                   0,
                                   0,
                                   0,
                                   -0.06051336996296415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57025682507362618,
                                   -0.020090339114556578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066913117505808709,
                                   0,
                                   0,
                                   0.61844837858490143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11711847937398782,
                                   0,
                                   0,
                                   0.062127039290904157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20203531108153178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064357225576805871,
                                   0.32643350728309939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28157995456778034,
                                   0,
                                   0.20030669924515582,
                                   0,
                                   0,
                                   0,
                                   -0.25465833803456334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15017963298930082,
                                   0.48696400334349277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12413895790135632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58079378694460715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20930786030901397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33876775604899928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.175299688226284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073335411044623613,
                                   0,
                                   0,
                                   0.066939226181876754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64042897455571901,
                                   0,
                                   0,
                                   0,
                                   0.1987631758013397,
                                   0,
                                   0,
                                   1.0131029753056002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099298988242064068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1826138757724961,
                                   0,
                                   0,
                                   -0.091488910895671433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01486607287481519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46090209848233815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54832388146253308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27942286085418966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5975229734783043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17095545832750436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21945408973161226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17558175007627114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6228494796477323,
                                   0,
                                   0,
                                   0,
                                   0.22227654742142444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11272951236252647,
                                   0,
                                   -0.16506503475396628,
                                   -0.59334094418349392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0090162997634754688,
                                   0,
                                   -0.21820239018726267,
                                   0,
                                   0,
                                   0.52824093853379372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4820115087396642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95191667775372624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47421237877490108,
                                   0,
                                   0,
                                   -0.47029934243923421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23415058372520123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03792848231677505,
                                   -0.68299119735636205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38449651577618804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5254554817438839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16812748891451948,
                                   0,
                                   0.072170470940958159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54654286637720328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44925159247335567,
                                   0,
                                   0,
                                   0,
                                   0.13813109703995954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027463516914845696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76697258184463879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53788137128468871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64698770031450226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49970319450894063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46119065472210086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28160303942629611,
                                   0,
                                   0,
                                   -0.38703892867298118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44384756092530897,
                                   0,
                                   0,
                                   0,
                                   0.37090151051728232,
                                   0,
                                   0,
                                   0.42482303506092634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1363862704179814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24679776248546459,
                                   0,
                                   0,
                                   0.59714510888722461,
                                   0.28422267575509241,
                                   0,
                                   0,
                                   -0.89679888643217454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64274431937929577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25524400846450007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49332206573441917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18519690759660123,
                                   0,
                                   0,
                                   0.1789437677760396,
                                   0,
                                   0,
                                   0.094635072665676348,
                                   0.24089387470885587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42551576692281007,
                                   0.16769402477422082,
                                   0,
                                   0,
                                   -0.11990047712112392,
                                   0,
                                   0,
                                   0,
                                   -0.29978187429368242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15425204564383166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073371568211540283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31921793710503565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62728187578496275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1107556988040721,
                                   0,
                                   0,
                                   -0.12821380051965778,
                                   0,
                                   0,
                                   0.381077354085675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4628770326258998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65074135089074303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70916973428926322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024643275499483364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057566939612936116,
                                   0,
                                   0,
                                   0.59314377686086084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93650485324821053,
                                   0,
                                   0,
                                   0,
                                   -0.39904902676297871,
                                   0,
                                   0,
                                   0.76163398117210823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92342990155460503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0759994749736235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29914547511033518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34867044057112068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60102335457223965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16701327570926658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18563724619111047,
                                   0,
                                   0,
                                   0.10683791432266648,
                                   0,
                                   0,
                                   0.22353565148529964,
                                   0.14033805060078614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.274465945193758,
                                   0.086325959660371723,
                                   0,
                                   0,
                                   0.10444519985724704,
                                   0,
                                   0,
                                   0,
                                   0.022736490853459489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50509817792065725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33745296264945968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61844165748364832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10180893446632505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16251889122888893,
                                   0,
                                   0,
                                   -0.044786589423811946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47905758120932607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010068344403443692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16984829290910708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65749039151021471,
                                   0,
                                   0,
                                   0,
                                   0.35057606208185327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72167831623468026,
                                   0,
                                   -0.55529147841674109,
                                   -0.2460200118082907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28425343911326573,
                                   0,
                                   0.55726963706203358,
                                   0,
                                   0,
                                   -0.25087260943404049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50299701826449894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46008012584119584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084319280449666315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64665290348678506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42186275882583146,
                                   0,
                                   0,
                                   0.30755544412647445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35670416951380701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21217690977571163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21051540483622039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30246412608983431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034975635533728691,
                                   -0.167777689559198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065754701507825003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22705437574871384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16346794276142751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066938757366791266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24108010791821574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47479456388827956,
                                   0,
                                   0.4372810374572903,
                                   0,
                                   -0.054840087387822638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20751339548343112,
                                   0,
                                   0,
                                   0,
                                   0.5076028175578986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32600098786163684,
                                   0,
                                   0,
                                   -0.26216996960869465,
                                   0,
                                   0,
                                   0,
                                   0.072304068878734584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38918177493865475,
                                   -0.18811803869650884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56431555785507592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60114526876840291,
                                   0.11070277783027123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066261757488757747,
                                   0,
                                   0,
                                   0.20154278257659727,
                                   0,
                                   0,
                                   -0.30086368634441296,
                                   0,
                                   -0.065402312998189327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7460435010994183,
                                   0,
                                   0.29041421270807083,
                                   -0.064573507717268414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16925139701264011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36780611701549332,
                                   0,
                                   0,
                                   0,
                                   0.47276830467713649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54626506634774019,
                                   0,
                                   -0.20328543104818192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28540838095295895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34631986206700138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.267276776056804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088207117456069101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4058557985213011,
                                   0,
                                   0.24122428700222673,
                                   0,
                                   0,
                                   0,
                                   0.12300261159888204,
                                   0.086428952859956082,
                                   0.039063763368326593,
                                   0,
                                   -0.10929591850635406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54254146502558531,
                                   0,
                                   0,
                                   0,
                                   -0.54343687939934981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37890018958866306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062370471097554239,
                                   0,
                                   0,
                                   0,
                                   -0.040974149939547386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56210680187304352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43344488946470655,
                                   0,
                                   0,
                                   -0.15776366619485072,
                                   0,
                                   0,
                                   0,
                                   0.0875242412479698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32104919865476922,
                                   0,
                                   0,
                                   0.39717781370591659,
                                   -0.02633801929251034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16713084709456189,
                                   0,
                                   0,
                                   0.32414629468841133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034882544080757395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2426064216083588,
                                   0,
                                   -0.058719198429804623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11038650030959848,
                                   0,
                                   0,
                                   0,
                                   -0.63534998964145217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16533606755687935,
                                   0.16070963994456569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079515726529081066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28920258802786675,
                                   -0.13224827510693299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25833476138280564,
                                   0,
                                   0,
                                   -0.45268543729658228,
                                   0,
                                   0,
                                   -0.42104854232084316,
                                   0,
                                   -0.27815025962684586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26843075543895722,
                                   0,
                                   0.36370354724386211,
                                   -0.28101983361294325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47481976721304164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18116128689044891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67672438699159554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093526781402077513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29417395946564245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18509304103896709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14141009927308096,
                                   0,
                                   0.030286574892651977,
                                   0,
                                   0.13359459765861631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15410396896178982,
                                   0,
                                   0,
                                   0,
                                   -0.22540260499227718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20226194113776905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9482672060103926,
                                   0,
                                   0.16806789304933745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4271141775916068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69716541306345625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061691642574613292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73238407911869607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095573973268602966,
                                   0,
                                   0,
                                   0,
                                   0.20304621030081543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30825200582800055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31718008302475015,
                                   0,
                                   0,
                                   -0.077835269017867151,
                                   0,
                                   0,
                                   0,
                                   0.19896116049727919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024442056009349206,
                                   0,
                                   0,
                                   -0.0387847929660316,
                                   -0.044151913759798468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2718689967749981,
                                   0,
                                   0,
                                   -0.15827116370615296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42890301555618754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33131071526515754,
                                   0,
                                   0.55824126525636486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43679821835737703,
                                   0,
                                   -1.2772022510971737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46508934299611349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14484714851094008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63011652249206107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26189024094935953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6020510168177956,
                                   0,
                                   0,
                                   0.19192363822714908,
                                   0.086269986104660981,
                                   0,
                                   -0.082638638308056789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35973879427963418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86921081354791829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26877577700393462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40915469374224667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022569969142355983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42701186974572897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1563138377448357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1711147019987343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49467054823072482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61977065578572121,
                                   0,
                                   0,
                                   0,
                                   -0.15622354575784975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38859247267417596,
                                   0,
                                   -0.23491961847276363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31860273090998614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010875603967105511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19738862891141232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18162510843402591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21723459658084257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12144325882074646,
                                   0.46707770252787201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45716709283588375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49490725320537932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8096972834646301,
                                   0,
                                   -1.1395623933062013,
                                   0.20638800725467901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29521588847086322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51271274209068451,
                                   0,
                                   0,
                                   -0.34241468358381733,
                                   0.64215191954084838,
                                   0,
                                   0.11403794512265966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00039599532873810239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54594699843022709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0792989433797691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40900519799211393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42761136459411675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18755240663579215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30112114878253321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29799495660906078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61942156273235982,
                                   0,
                                   0,
                                   -0.0027462475283639431,
                                   0.27900370982557043,
                                   0,
                                   0.30211900264346775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68773005470858584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50861959043937677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40255595140531275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39410263252667255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22500580935013573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37382024782604839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54007821835076086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46306508497119608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11001411091388816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43604370043497354,
                                   0,
                                   0,
                                   0,
                                   -0.71743880737901677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42277373918419819,
                                   0,
                                   0.24079443596502834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086114574433904356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12545606742783538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15221630877629605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68191833111636257,
                                   0,
                                   0,
                                   0.3092665356452004,
                                   -0.32511642347587505,
                                   0,
                                   0.1970915350109978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14423800496151357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43373405582227365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10602208304635816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14893510198769577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30420160391783246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67083593437077627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40695685367471185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22383107678305775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075597759182737118,
                                   0,
                                   -0.021641205423902798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55293272785946912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29729734320702084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20680886984780261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.525179149543773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16172176462207752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27916390385650874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017833894342905741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26031953611021519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052820210139199929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40750506834791123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20672294242725678,
                                   0,
                                   -0.50174778416575816,
                                   0,
                                   0.1987175838941356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45348643989414134,
                                   0,
                                   0,
                                   0,
                                   -0.34131577163578186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053466087473398018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039266449362600403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7014060052039095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19942027102996479,
                                   -0.20883671687912353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078057430375791881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18868695919167094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14090643147341053,
                                   0,
                                   -0.46805153471424665,
                                   -0.85545776466114565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38071258770408811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11761839502458564,
                                   0,
                                   0,
                                   0,
                                   0.27751189086561556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55698971140506381,
                                   0,
                                   -0.56727252827842056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13630748846337679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50846599907796497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26959822375163534,
                                   0,
                                   0,
                                   0.82286795532288137,
                                   0.28621383045324056,
                                   0,
                                   -0.33622905989746527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086897339773820859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016461442962467383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65470244840531899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28957120785159185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0055453130486685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60319500447484276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013261795444833453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090059188407694529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75454434690282379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10432550385799085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39046789146472227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55678248915668005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72228119562274296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16325309518468648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26739166518161561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43531768298791162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00059575418967865168,
                                   0,
                                   0,
                                   0,
                                   -0.15972458403141404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2776491687423609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23543305867697731,
                                   0,
                                   0,
                                   -0.3130657299652525,
                                   0,
                                   0,
                                   0,
                                   0.1623301298643075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27737983147861145,
                                   0,
                                   0,
                                   0.1925646621800591,
                                   -0.020596340798579672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3619615103601353,
                                   0,
                                   0,
                                   -0.20274084126469838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6349938557434468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05816530221381272,
                                   0,
                                   0.15634379352176342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27467252988087409,
                                   0,
                                   0,
                                   0,
                                   -0.26930642607760319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70705653398788226,
                                   0,
                                   -0.28919456105011898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16586878472105132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49087081809920707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33672852996083741,
                                   0,
                                   0.25990242195771174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099982288571146716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64663966398418105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79539481087581421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47822377455740495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19771307547485739,
                                   0,
                                   0,
                                   0.69291420444567142,
                                   0.69811139898384866,
                                   0,
                                   0.12774537556724985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7506957616196156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45357879445087496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.236770702824429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26425378561882684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040796484325883897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74872212925071868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34463612663085558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15454423966055977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59047426972787265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010437910846670145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027033841504796152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1509206585956343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04826146580009457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44423668277970879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84191407552544284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70760582719806064,
                                   0,
                                   0,
                                   -0.12626561476083434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084521231660685286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087667165511165782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017110524971138338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1554827191458247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45424945345229994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15446913204903187,
                                   0,
                                   -0.15762855593623132,
                                   0,
                                   -0.70560160005618511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40674688070277132,
                                   0,
                                   0,
                                   0,
                                   -0.11700339380609386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11270980663383118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012451797542288399,
                                   0,
                                   0,
                                   0,
                                   0.052481582285692358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095948713547872336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088573133222599826,
                                   0,
                                   0,
                                   -0.047543517314148701,
                                   0,
                                   0,
                                   0,
                                   0.037115882764655828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43160952851468848,
                                   0,
                                   0,
                                   0.28944267944755186,
                                   0.2505175939628238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22413528530392612,
                                   0,
                                   0,
                                   -0.22670361005089967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10134556276982111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50132753744447833,
                                   0,
                                   -0.52947805942208481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58190657463414619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97002903546825925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2185161281449251,
                                   0.27842399733774909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82084756840088957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2861196440970542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51233355091093302,
                                   0,
                                   -0.045243242768849876,
                                   -0.30348672986498837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34962208840515846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89661531445025455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32476007498618742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34022679174431658,
                                   0.53981227604630422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048234221030412611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18972653130660033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51031716675052741,
                                   0,
                                   -0.16059015965505552,
                                   -0.41441854321512589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71799490047468795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50731507453915747,
                                   0,
                                   0,
                                   0,
                                   -0.089545734724393811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18987028772471548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18873650950899673,
                                   0,
                                   0,
                                   -0.13771527372647768,
                                   0,
                                   0,
                                   0,
                                   0.0080831265439918198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043702277831752234,
                                   0,
                                   0,
                                   0.040305097277105496,
                                   -0.69315978604427131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12161351685572011,
                                   0,
                                   0,
                                   -0.13274517709886552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14983415804434608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17031567798141148,
                                   0,
                                   -0.27574668312080686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58058912826965625,
                                   0,
                                   0,
                                   0,
                                   0.11751260613734896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12081357504491186,
                                   0.15393807058194894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38224859298985547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40234560141321846,
                                   0.35290404597915348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45972220254195828,
                                   0,
                                   0,
                                   0.48532725068095617,
                                   0,
                                   0,
                                   -0.27081814345818783,
                                   0,
                                   -0.83370568463982742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22467355743602888,
                                   0,
                                   0.12672083412656091,
                                   -0.20766126961862863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043116365423757179,
                                   0,
                                   0,
                                   0,
                                   -0.4236202417391553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4218508635933968,
                                   0.76926326549041357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70135967216924644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46521598523664154,
                                   -0.50875495535368331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15868722131230886,
                                   0,
                                   0,
                                   0.083305860717465458,
                                   0,
                                   0,
                                   -0.26691966294629044,
                                   0,
                                   -0.1436794239261148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48759833804462904,
                                   0,
                                   -0.022300713295077445,
                                   0.015622607580348027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14665471156463233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47997529684883028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26039937715818762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025877120311659129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56968327772309846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32090056517108506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23436748903730001,
                                   0,
                                   0.28897634089103325,
                                   0,
                                   -0.073461050570168898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06207934869004908,
                                   0,
                                   0,
                                   0,
                                   0.058722684875122347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31778651426752474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18376902240371454,
                                   0,
                                   0,
                                   0,
                                   -0.65278088702522918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30275540551498775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045894080452652516,
                                   0,
                                   0,
                                   0.18085634535290496,
                                   0,
                                   0,
                                   0,
                                   0.099541029292476907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065298030769198351,
                                   0,
                                   0,
                                   -0.44696469990158894,
                                   0.13716988303847175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2789664257658005,
                                   0,
                                   0,
                                   -0.25341998819564809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13505283688085684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1391917155788043,
                                   0,
                                   0.034743509220831879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46162123464941318,
                                   0,
                                   0,
                                   0,
                                   -0.27062558754533994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29420617296700285,
                                   0,
                                   0.48452671833913435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61940824303336339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093153864935525521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066353642702573684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38810287389991727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49552272084366311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090393112116546548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081012498001256233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1778201924211642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0785226588214536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44106872981371231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61461667344101545,
                                   0,
                                   0,
                                   0,
                                   -0.72568728740987609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20758164760735923,
                                   0,
                                   -0.14374645179878545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13776113464221429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11354731425252657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3093166796591218,
                                   0,
                                   0,
                                   0.38026269786394717,
                                   0.30202850161664191,
                                   0,
                                   -0.36100386924180683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88550527659770395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17636599387715002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65050479903833969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3961424664618971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087834695460897672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27886020610308815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55430280182650427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53907449690029197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24167148875508518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040569879374133144,
                                   0,
                                   0.40758610877417711,
                                   0,
                                   0,
                                   0,
                                   -0.12625173684688307,
                                   -0.50181043183700758,
                                   0.38146364697104368,
                                   0,
                                   0.37022266061231557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26764753321747992,
                                   0,
                                   0,
                                   0,
                                   0.020681906033623014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.389136292475526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8681300191602338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40727123776592555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020599002698823605,
                                   -0.053082081589528464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25566825054165337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46568588271884265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95344207156891125,
                                   0,
                                   0.21027640085407667,
                                   -0.058221530029394147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36624663806114804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37134919210228906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58534555518159015,
                                   0,
                                   0.0065733570513135421,
                                   0,
                                   0,
                                   0,
                                   0.1560659265187444,
                                   -0.29190142894083376,
                                   0.16201528341993121,
                                   0,
                                   -0.19301430003759795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40079670563779246,
                                   0,
                                   0,
                                   0,
                                   -0.1437020660561841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40629100011418817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30886454547945114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086710432741102114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10629455201251335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46376548618513291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23738962663941371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13788942953040745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2696114508025626,
                                   0,
                                   -0.4452501888662414,
                                   0,
                                   0.11659082487723302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19452225828753031,
                                   0,
                                   0,
                                   0,
                                   0.41985668261821907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31094963801238296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71733198467215575,
                                   0,
                                   0,
                                   0.40438499876833139,
                                   -0.47190018391091793,
                                   0,
                                   -0.60160153099295111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26559629484345382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28460306609653913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1646633737891128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78910237830758967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37890083466100066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66109740375613379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58617328509864652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37295108393640292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65410109956087781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3058381002110719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26227258794149372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038080843589132232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20655441360342908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098625609888582474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21858613699453416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29044092672496902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040230998092891018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12187260925473831,
                                   0,
                                   0.23563138045383603,
                                   0,
                                   0,
                                   0,
                                   0.78468040891897184,
                                   0.31240753505458563,
                                   0.36593975270252233,
                                   0,
                                   -0.10501022593320949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088066014891691594,
                                   0,
                                   0,
                                   0,
                                   0.24001035042653035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066218825887261468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45259991129563193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045324781408048326,
                                   0,
                                   -0.43371210165995389,
                                   0,
                                   0,
                                   0,
                                   0.20667266297408535,
                                   -0.33586351748971055,
                                   -0.14803064153866058,
                                   0,
                                   -0.11290585531142716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025569813167682903,
                                   0,
                                   0,
                                   0,
                                   0.24259752644070973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59607610854597282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16018753742303915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18006334634580562,
                                   0,
                                   -0.17884399869379455,
                                   0,
                                   0,
                                   0,
                                   0.51438560816850032,
                                   -0.34042542660665542,
                                   -0.32934698493781411,
                                   0,
                                   0.45764504838528741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049427423064717715,
                                   0,
                                   0,
                                   0,
                                   -0.39930871377658883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22282503779686516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56786720277741365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048035619973264151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27238922348396494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22882011328851035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35200317625516114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20443584775751719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30276375861167604,
                                   0,
                                   -0.18808230717991931,
                                   0,
                                   -0.14175926003779227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14808358668292501,
                                   0,
                                   0,
                                   0,
                                   0.37075705039915663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27647524173260718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067474055239151426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27639674995130159,
                                   0,
                                   0.44904646454048669,
                                   0,
                                   0,
                                   0,
                                   0.089356846405687376,
                                   -0.17397063882676311,
                                   -0.4644052355041865,
                                   0,
                                   0.13776078933663832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31851301490628153,
                                   0,
                                   0,
                                   0,
                                   0.56883766177791339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13957739083483361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.416789736081701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072148426500169421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02970887207967296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050119603519826368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1753346393269018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19572391617161905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61187166067363563,
                                   0,
                                   -0.39045032180261841,
                                   0,
                                   0.094044695701763686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21666502489300044,
                                   0,
                                   0,
                                   0,
                                   0.28033858404902734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29566873213851957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048970840053776693,
                                   0,
                                   0,
                                   -0.55644449392720563,
                                   -0.17535293947867081,
                                   0,
                                   -0.13140200675361008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30860396118237077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15722068577884388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18186082415820654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61594954456843309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2554294703378503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29176890581475157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0073524892767694592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86486905701393479,
                                   0,
                                   0,
                                   0,
                                   0.23347399346980136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00083096837223213538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16726583396746669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71940247446120231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.198860260432979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20671085205786954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058209622441202619,
                                   0,
                                   0.11015747512893938,
                                   0,
                                   -0.10199486540183614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47560458253342308,
                                   0,
                                   0,
                                   0,
                                   -0.029230595878179111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25439441061288726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23456383586328602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10177798685438644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1847869443536185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0032725454410998485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37677932743441589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41909895065324854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2238340138863916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22353670349916899,
                                   0,
                                   0,
                                   0,
                                   -0.43887868430739257,
                                   0,
                                   0,
                                   0,
                                   0.11366231007538653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33550033705690741,
                                   0.042303022065863866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21324148179947788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048611155456462107,
                                   -0.087773057819483968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42628084444092201,
                                   0,
                                   0,
                                   -0.13181832909904811,
                                   0,
                                   0,
                                   0.21502940222679962,
                                   0,
                                   0.0062855522003542885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036744993218329657,
                                   0,
                                   0.63574221915998352,
                                   0.76570310556034127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017858028658278131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071496181834565978,
                                   0,
                                   -0.26989735511826363,
                                   0,
                                   0,
                                   0,
                                   -0.024701770479044073,
                                   -0.33289856198897561,
                                   0.56550316255428013,
                                   0,
                                   0.016846330826215686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59966543608611267,
                                   0,
                                   0,
                                   0,
                                   0.19489756962835697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30435481079156845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0015192480505989564,
                                   0,
                                   0,
                                   -0.051305487243300224,
                                   0.25235528127430235,
                                   0,
                                   -0.57662543487968509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26890355167691227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098797906738992136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18680498051450062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67976366751188133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2317459057264919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41034209822625534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72932607275665018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18209220575157056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46653003252035991,
                                   0,
                                   0,
                                   0,
                                   0.45152309343866709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24451155345993014,
                                   0,
                                   -0.042515310826454211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71069291521603173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10862206810685415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26735756515043207,
                                   0,
                                   0,
                                   0,
                                   0.074866778180844903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10958825098574608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28606249012957097,
                                   0,
                                   0,
                                   -0.089181237002181057,
                                   0,
                                   0,
                                   0,
                                   -0.25005775363923261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064047052820235539,
                                   0,
                                   0,
                                   -0.22648107382217475,
                                   0.17936916974528438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63689508865687339,
                                   0,
                                   0,
                                   0.19194664134733308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0069421207528614403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41863377292582943,
                                   0,
                                   -0.23074031918137597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68351081497938626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52757949632732071,
                                   0,
                                   0.42510000941288928,
                                   0,
                                   0,
                                   0,
                                   -0.097850230487324663,
                                   -0.034693964650635609,
                                   0.045343192421417426,
                                   0,
                                   0.08167949866395155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035644201544361813,
                                   0,
                                   0,
                                   0,
                                   -0.19011145258233259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12978468692849071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35629555161011339,
                                   0,
                                   -0.043279731683581776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74887382553730286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38136566597281096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86182754832395281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45553905509881298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2751004935940301,
                                   0,
                                   0,
                                   0,
                                   -0.3190031003312348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31203694722201664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11983825107437755,
                                   0,
                                   0,
                                   0.10670360518220452,
                                   0,
                                   0,
                                   0,
                                   -0.61229695569747844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17532884801317997,
                                   0,
                                   0,
                                   0.38579589977456252,
                                   0.31211253236547037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07804557839997267,
                                   0,
                                   0,
                                   -0.012248690460857178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13920998511392085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029938191967369871,
                                   0,
                                   0.14500166939850426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44452858974312809,
                                   0,
                                   0,
                                   0,
                                   -0.23041221255646205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30897937021460742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21579917502115648,
                                   0,
                                   0,
                                   -0.0047927279834498876,
                                   0,
                                   0,
                                   0,
                                   -0.16653479741020599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31932706494821439,
                                   0,
                                   0,
                                   -0.2717069990629149,
                                   -0.24122104981294523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24582270631136902,
                                   0,
                                   0,
                                   0.096845809397432869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07443594615478405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41093442718931883,
                                   0,
                                   -0.3182961061202027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098460506905104495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04686484457053558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26126233240617081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95747541138060266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42888804569492378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39593295259379691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36257319415556749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38859371314258234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26603737824205403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39134869322233462,
                                   0,
                                   0,
                                   0,
                                   0.074137685198426756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47757653253115789,
                                   0,
                                   0.43370040393571407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47619155695327064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31094629239326149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17593333072360853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42958993735888407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41661754266783368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12740993076165419,
                                   -0.56650099103340534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46207414814818215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72422932311194699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36775757263927555,
                                   0,
                                   -0.53885053589309195,
                                   0.60678827901980492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23281027487581629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65822114622163697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15689227288723084,
                                   0,
                                   0,
                                   0,
                                   0.36408412932388978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09277800605400538,
                                   0,
                                   0.47333319594961432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14056240939684667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16827972858218332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35894923508352106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33855813517800437,
                                   0,
                                   0,
                                   0,
                                   -0.35650990054011145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0044147181685920342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47463698509060581,
                                   0,
                                   0,
                                   0.011662967919833067,
                                   0,
                                   0,
                                   0,
                                   0.24808293845495186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32665056367339662,
                                   0,
                                   0,
                                   0.27353265829948109,
                                   0.017226935221105417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23292485271760419,
                                   0,
                                   0,
                                   -0.3473937264039676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12907314987365121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30888006016141883,
                                   0,
                                   0.049774717000429888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42968616328791992,
                                   0,
                                   0,
                                   0,
                                   -0.080218238965131167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21063260869676986,
                                   -0.21461419141820437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14925674466424046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57338537510665666,
                                   0.23690895113191746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49430904956447497,
                                   0,
                                   0,
                                   -0.34747657410060029,
                                   0,
                                   0,
                                   0.33783007936335557,
                                   0,
                                   0.13140263930047208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53421651219859745,
                                   0,
                                   0.37657061081069299,
                                   -0.48921723703728265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53739710944555874,
                                   0,
                                   0,
                                   0,
                                   0.15534244922060397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86918984792940324,
                                   0.18682479404015287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28307277066172576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13562040307848863,
                                   0.34836851917525663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5923239912238486,
                                   0,
                                   0,
                                   0.055980646445183066,
                                   0,
                                   0,
                                   0.13513490906757217,
                                   0,
                                   -0.3607817939993036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047241773474656835,
                                   0,
                                   -0.13088446662592468,
                                   0.0014197524542143474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16722748977825139,
                                   0,
                                   0,
                                   0,
                                   -0.42061233860269931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18541173675532488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29792330113631105,
                                   0,
                                   0,
                                   0.10182789919100663,
                                   0,
                                   0,
                                   0,
                                   0.20779980448859114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2685826551247541,
                                   0,
                                   0,
                                   0.23387740017270214,
                                   -0.19226309374590872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14067649127943041,
                                   0,
                                   0,
                                   0.62508249476678079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17060004139851326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0011679897650566651,
                                   0,
                                   0.12251785601258704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51463901001573231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029440451258149654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53217428681347201,
                                   0.52495929086999715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21646298334525915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.072328981864614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017872658369749231,
                                   0,
                                   0.0573616115118223,
                                   -0.36518926469396673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22619342750242993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15514599061329454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18180813183883551,
                                   0,
                                   0,
                                   0,
                                   -0.073663343989020247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073610240691858952,
                                   0,
                                   -0.63706710559061142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24662245745612627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5442407159314987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4112853979739684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43017760790266019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1265387773603936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61477766588095462,
                                   -0.61499078048418698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65011203378519622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14987172885239369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32484178387122442,
                                   0,
                                   0.26285645000029295,
                                   -0.27721936284661791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65940093691874058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073887893649942027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8369018180097646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46000773143795159,
                                   -0.083481484995641897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71051573381243616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15621981490604919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36756137292269553,
                                   0,
                                   0.2753210912260225,
                                   -0.5034394789167882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46615365370980399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73820670122452603,
                                   0,
                                   0.064554569017528318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82533557763287091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37348217063752814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080337949213836635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53610563993174631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53792345500056638,
                                   0,
                                   0,
                                   0,
                                   -0.16197579459967235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096425353431593808,
                                   -0.52330673320581833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030070042014735697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1923706884203257,
                                   -0.27520141738783549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080924265351146163,
                                   0,
                                   0,
                                   -0.24863583440876391,
                                   0,
                                   0,
                                   0.29600198059614535,
                                   0,
                                   -0.16852937647537791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066834365524995332,
                                   0,
                                   -0.65518555487800434,
                                   -0.041099538940956144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16773639048354902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29183522213465407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18792262524723358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23868879314353841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20926361260696405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3092991940154024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19714494134356117,
                                   0,
                                   -0.021909064260794815,
                                   0,
                                   0.36214707962664838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038964999182091495,
                                   0,
                                   0,
                                   0,
                                   0.34711534546629663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60203673135569113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16537129922824625,
                                   0,
                                   0,
                                   0,
                                   0.0022322339046738082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30775830505064983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04258973526885329,
                                   0,
                                   0,
                                   0.035821184274581572,
                                   0,
                                   0,
                                   0,
                                   0.57487814431361783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41839173400323271,
                                   0,
                                   0,
                                   0.022124023728265135,
                                   0.38162217357626754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11929153168775949,
                                   0,
                                   0,
                                   0.091967937873980304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22978528299122403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22141578563051495,
                                   0,
                                   -0.31410007351946906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080195656396701828,
                                   0,
                                   0,
                                   0,
                                   -0.43881163295868159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19872291586024221,
                                   -0.1745667070574681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65797183728185882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77758456275017052,
                                   -0.28353770515971977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027362199849399346,
                                   0,
                                   0,
                                   0.093058269969294838,
                                   0,
                                   0,
                                   -0.087211658885565618,
                                   0,
                                   -0.0036268170861910934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24972063534712813,
                                   0,
                                   0.060465760390651713,
                                   0.19876694309630399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10932382235449201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23548381715637656,
                                   0,
                                   0,
                                   0,
                                   -0.079128029703054076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050260844483749595,
                                   0,
                                   0.16452169091337027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037237099429304393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60915408816642724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72407567606265055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024376580963077057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63616689284328998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17900164927153986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085969504643444286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51287531574362333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056985374362031271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049321193685823606,
                                   0,
                                   0.15040715591146783,
                                   0,
                                   0.30510010755427669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39937014413796568,
                                   0,
                                   0,
                                   0,
                                   -0.09567032060048615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046759037539437123,
                                   0,
                                   0,
                                   -0.090666843284854359,
                                   0,
                                   0,
                                   0,
                                   0.39998331759092531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69859045826626753,
                                   -0.14972964501363403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16720313960936573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1002433367428088,
                                   0.30376828150208401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18227674116274772,
                                   0,
                                   0,
                                   -0.33428774496831609,
                                   0,
                                   0,
                                   -0.67622284228057405,
                                   0,
                                   -0.34121771340055457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23879525010704478,
                                   0,
                                   -0.42593420880152832,
                                   0.40183100989136139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70989158045247658,
                                   0,
                                   0,
                                   0.56865546598488903,
                                   -0.32221739174931485,
                                   0,
                                   -0.13899417537801267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043960380313159853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18850977577343406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58839679284753932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23527557158667683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68226680383377736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13263695868293451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47534659951460811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60738320326431683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020484618885771199,
                                   0,
                                   0,
                                   0,
                                   -0.54845208856341865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81812678439530651,
                                   -0.17048103033701409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29911443955310152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22958057197285331,
                                   -0.47326751925746657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31225088788008248,
                                   0,
                                   0,
                                   0.93618769016468817,
                                   0,
                                   0,
                                   0.41949775144723572,
                                   0,
                                   -0.60978993075250376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40852951736896576,
                                   0,
                                   -0.17997990934009017,
                                   0.20760991760537767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10478582471507848,
                                   0,
                                   0,
                                   0,
                                   -0.16886941290452556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10865710264704243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18790847971120017,
                                   0,
                                   0,
                                   -0.85895763616799226,
                                   0,
                                   0,
                                   0,
                                   -0.09275326836681258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015608765974522688,
                                   0,
                                   0,
                                   -0.066109496380746591,
                                   0.097604267052733937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18138451817758328,
                                   0,
                                   0,
                                   -0.031111094314810774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33347159726286113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088062103191215088,
                                   0,
                                   0.0029196300537731312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080663996947710884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39422986708629421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1273784490137886,
                                   -0.40697015749846827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047682675044929623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51963502003916917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15530151996191704,
                                   0,
                                   0.087740606642050897,
                                   -0.6281811188259534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42731175542477462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41231068760521755,
                                   0,
                                   0,
                                   0,
                                   0.04113466884598227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17101588048085975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34146211963728118,
                                   0,
                                   0,
                                   0.21942880042121454,
                                   0,
                                   0,
                                   0,
                                   -0.077892984183276198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36876199051259179,
                                   0,
                                   0,
                                   0.33188827740005544,
                                   -0.23385574548587673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17595371230699619,
                                   0,
                                   0,
                                   -0.3582302162808445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35483882269842604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17628185833778065,
                                   0,
                                   -0.10559585938348373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.417730736515045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15554123536889566,
                                   0,
                                   0,
                                   0,
                                   -0.29601471008326102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35668054344259648,
                                   0,
                                   0.021061989933968961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70773809284504663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26820276976473517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11485946204355563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88276870155310738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13744577539024797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014291724747099166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89597892416019276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0071643663145061487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1170664358138932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37067663857165667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.911481092911541,
                                   0,
                                   0,
                                   0,
                                   -0.358831754435048,
                                   0,
                                   0,
                                   0,
                                   -0.0134943272617917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13875431350909909,
                                   0.44703044947856957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41688219731609949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10721966395134444,
                                   -0.21603586135691938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51569821429353624,
                                   0,
                                   0,
                                   0.73227801776442991,
                                   0,
                                   0,
                                   -0.72510797029114538,
                                   0,
                                   0.44101761108754522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3442972405554513,
                                   0,
                                   -0.16789786457219838,
                                   -0.3784058867235417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30286997525041442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28605710441153809,
                                   0,
                                   0.21173181197690427,
                                   0,
                                   0,
                                   0,
                                   0.058097369468259316,
                                   -0.43235024463774829,
                                   -0.15777861616168665,
                                   0,
                                   -0.74470653231948492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014260573637049738,
                                   0,
                                   0,
                                   0,
                                   -0.09994320152365653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040432586345180793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43045435854434588,
                                   0,
                                   0,
                                   0,
                                   -0.17475891625005852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19920138683843605,
                                   -1.0033414229272362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66862983808856102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21875408885286091,
                                   -0.22830659457909394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09950022030698813,
                                   0,
                                   0,
                                   -0.035062784975964517,
                                   0,
                                   0,
                                   -0.20095820058269132,
                                   0,
                                   -0.00012360372510980544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42047946908808964,
                                   0,
                                   0.35289729307952733,
                                   -0.13819529438415618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35487687505681398,
                                   0,
                                   0,
                                   0,
                                   -0.81279905554836729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18382875134287247,
                                   -0.26444614852877696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36157057813503729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076774111085719493,
                                   0.82326412055859555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21832036739629895,
                                   0,
                                   0,
                                   -0.25323165040215784,
                                   0,
                                   0,
                                   -0.12860235711825102,
                                   0,
                                   0.40992833830782238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1189887951967353,
                                   0,
                                   -0.080619886778075481,
                                   0.16189687900903374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17180810623334067,
                                   0,
                                   0,
                                   0.34195043184691359,
                                   -0.18718377368984521,
                                   0,
                                   0.96628939739541519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56214493097271578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0014457409924685076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21336851096769729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029782791310885882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3579240847528844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10936724861311109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57383361321374793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20002842147248026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42466575436805565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88283240416425579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030336429285792665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14481391091523346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2314872803704211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61311136946456324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42750741469356812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32699715307500576,
                                   0,
                                   0,
                                   -0.089265474491842328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37748639663347561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48266717156968775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20964316232141114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0098457070598064189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43758743772263242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22275518640328074,
                                   0,
                                   -0.16264059695146887,
                                   0,
                                   -0.39901525994446729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25360883864567263,
                                   0,
                                   0,
                                   0,
                                   0.18727518340055271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21532228386605137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31972304215725034,
                                   0,
                                   0,
                                   0,
                                   0.21616625002648118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020005167414579826,
                                   0,
                                   0.58080259096851017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21489228313300757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68347551449489485};

const double rot_26_30[9000] = {-0.094105776619519507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17243285756945981,
                                0,
                                0,
                                -0.2497620380482059,
                                0,
                                0,
                                0,
                                0.47763089061146646,
                                0,
                                0,
                                0,
                                0,
                                -0.65834917957703087,
                                0,
                                0,
                                -0.38795545417014887,
                                0,
                                0.27237233175536263,
                                0,
                                0,
                                0,
                                0,
                                0.11304382046357797,
                                0,
                                0,
                                0.072093703427832986,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.88144376857828899,
                                0,
                                0,
                                -0.64150663889169646,
                                0,
                                0,
                                -0.98675838418132233,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41559026609435501,
                                -0.088628263935947818,
                                0,
                                0,
                                0,
                                0,
                                0.49714119718057004,
                                0,
                                0.37417509371557839,
                                0,
                                0,
                                0.29423163368560085,
                                0,
                                0,
                                0,
                                0,
                                0.59788940491553222,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0085270110079323364,
                                0,
                                0,
                                0,
                                -0.41076383071119249,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46323859441648529,
                                0,
                                0,
                                0,
                                0,
                                -0.28927813257014134,
                                0,
                                0.60201412795872289,
                                0,
                                0,
                                0,
                                0,
                                0.97954755015102246,
                                0,
                                0,
                                0,
                                0.10882904769016621,
                                0,
                                0,
                                -0.060529917178593434,
                                0,
                                0,
                                -0.017922711537869479,
                                0,
                                0,
                                0,
                                -0.70176292885200708,
                                0,
                                0,
                                0.10449583176934291,
                                0,
                                0.37481134525853987,
                                0,
                                0,
                                -0.39945434558354059,
                                0,
                                0,
                                0,
                                0,
                                0.33439452533409492,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37507180463279743,
                                0,
                                0,
                                0,
                                0.6607077608132228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0077561039691900827,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58548402320225867,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42094405849426253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.098047567012950559,
                                0,
                                0,
                                0.5709135292666615,
                                0,
                                0,
                                0,
                                -0.021015415249631825,
                                0,
                                0,
                                0,
                                0,
                                -0.23370527967504495,
                                0,
                                0,
                                -0.071147595581059195,
                                0,
                                -0.042696973777152356,
                                0,
                                0,
                                0,
                                0,
                                -0.65215465878019052,
                                0,
                                0,
                                0,
                                -0.63780815130479063,
                                0,
                                0.65512817785600186,
                                0,
                                0,
                                -0.20770121427201721,
                                0,
                                0,
                                0,
                                0,
                                -0.0024542977629364582,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12359465980872028,
                                0,
                                0,
                                0,
                                -0.32494057116252317,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23302135325771231,
                                0,
                                0,
                                0,
                                0,
                                0.80485944798206244,
                                0,
                                -0.97644343905795727,
                                0,
                                0,
                                0,
                                0,
                                0.15983645247382597,
                                0,
                                0,
                                0,
                                -0.12768750714286509,
                                0,
                                0,
                                -1.1499721142994437,
                                0,
                                0,
                                -0.33302953315347023,
                                0,
                                0,
                                0,
                                -0.14870407702916227,
                                0.01578678854536451,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53482940451477112,
                                0,
                                0,
                                -0.25224231596564334,
                                0,
                                0,
                                0,
                                0.55125541577731851,
                                0,
                                0,
                                0,
                                0,
                                0.36556051083186869,
                                0,
                                0,
                                0.1392781358320021,
                                0,
                                -0.327485648015367,
                                0,
                                0,
                                0,
                                0,
                                -0.29312084560761598,
                                0,
                                0,
                                0,
                                0,
                                -0.43404707269782,
                                0,
                                0,
                                0,
                                0,
                                0.17189847420788229,
                                0,
                                0.12839961360215188,
                                0,
                                0,
                                0,
                                0,
                                -0.0073135755810702467,
                                0,
                                0,
                                0,
                                0.88223579810787989,
                                0,
                                0,
                                0.36666788929542043,
                                0,
                                0,
                                -0.66791414235184343,
                                0,
                                0,
                                0,
                                0.50760592423257567,
                                0,
                                -0.48106557560029861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71374285076254074,
                                0,
                                0,
                                0.33713962786198887,
                                0,
                                0,
                                -0.85262947112269849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40901518891697752,
                                0.57603753224862231,
                                0,
                                0,
                                0,
                                0,
                                -0.20035938650194873,
                                0,
                                0.24425264678400443,
                                0,
                                0,
                                0.75248663613107425,
                                0,
                                0,
                                0,
                                0,
                                -0.01085433561472009,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27362341090648989,
                                0,
                                0,
                                0,
                                0.50889393357159707,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62698958006001582,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57074260097572005,
                                0,
                                0,
                                -0.37550502738403041,
                                0,
                                0,
                                0,
                                0.18334594292837689,
                                0,
                                0,
                                0,
                                0,
                                -0.00043012181821816022,
                                0,
                                0,
                                0.1646554714276818,
                                0,
                                -0.28138353290008317,
                                0,
                                0,
                                0,
                                0,
                                -0.01512903451893461,
                                0,
                                0,
                                -0.43922038591009072,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.96431824988760517,
                                0,
                                0,
                                -0.45711750609977475,
                                0,
                                0,
                                -0.28045456489913223,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.9063011423376035,
                                0.25609887628687733,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35112230520036375,
                                0,
                                0,
                                0,
                                0,
                                0.45702387811613143,
                                0,
                                0.75293322143204577,
                                0,
                                0,
                                0,
                                0,
                                -0.92321609833898333,
                                0,
                                0,
                                0,
                                0.16952336142868335,
                                0,
                                0,
                                -0.510782472819867,
                                0,
                                0,
                                0.17568606445427479,
                                0,
                                0,
                                0,
                                0.087091782865799272,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56558909151368075,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.035440734292157938,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.08728091143258862,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51795305748257348,
                                0,
                                0,
                                1.243799413115954,
                                0,
                                0,
                                -0.34113586462257722,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51690070899050744,
                                0.11056545247529607,
                                0,
                                0,
                                -0.4606924306098602,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24150642746990769,
                                0,
                                0,
                                0.22301757959053464,
                                0,
                                0,
                                0,
                                -0.049525077591398819,
                                0,
                                0,
                                0,
                                0,
                                0.3566804332731166,
                                0,
                                0,
                                -0.55350682915824623,
                                0,
                                -0.14304996929862118,
                                0,
                                0,
                                0,
                                0,
                                0.47243361505252446,
                                0,
                                0,
                                0,
                                0,
                                1.2903663700894379,
                                0,
                                0,
                                0,
                                0,
                                -0.23831502612764174,
                                0,
                                0.19664768709143307,
                                0,
                                0,
                                0,
                                0,
                                0.32880138403102915,
                                0,
                                0,
                                0,
                                0.12357718694024326,
                                0,
                                0,
                                -0.023457704707201509,
                                0,
                                0,
                                -0.7525963226508664,
                                0,
                                0,
                                0,
                                0.46501228422275465,
                                0,
                                0,
                                0.20363372607846039,
                                0,
                                -0.0010720017886110544,
                                0,
                                0,
                                -0.37970288210546527,
                                0,
                                0,
                                0,
                                0,
                                0.12482489638889752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87676334100529241,
                                0,
                                0,
                                0,
                                0.17338588998851359,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4339204236687616,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48815784757061986,
                                0,
                                0,
                                -0.12488781881451964,
                                0,
                                0,
                                0,
                                -0.27798306940080075,
                                0,
                                0,
                                0,
                                0,
                                -0.1452344899240689,
                                0,
                                0,
                                0.57252838753006219,
                                0,
                                0.28545944347757152,
                                0,
                                0,
                                0,
                                0,
                                0.22399670121410051,
                                0,
                                0,
                                0,
                                0,
                                0.49661444876712035,
                                0,
                                0,
                                0,
                                0,
                                -0.22914168604923274,
                                0,
                                -0.12610537023680751,
                                0,
                                0,
                                0,
                                0,
                                0.49405033920633956,
                                0,
                                0,
                                0,
                                0.7561817970556608,
                                0,
                                0,
                                -0.31733152090504596,
                                0,
                                0,
                                0.77876195314256735,
                                0,
                                0,
                                0,
                                0.48869258474130345,
                                0.011134152512592393,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21238947707553271,
                                0,
                                0,
                                -0.51279758753905724,
                                0,
                                0,
                                0,
                                -0.59385882704588067,
                                0,
                                0,
                                0,
                                0,
                                -0.17327432331424464,
                                0,
                                0,
                                -0.33639381899100684,
                                0,
                                -0.33954365274607323,
                                0,
                                0,
                                0,
                                0,
                                -0.28401123874542678,
                                0,
                                0,
                                0,
                                0.50350912124988689,
                                0,
                                0.48026661412039684,
                                0,
                                0,
                                -0.017713296926331168,
                                0,
                                0,
                                0,
                                0,
                                -0.71763741957808436,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.019724715274744085,
                                0,
                                0,
                                0,
                                -0.010782064743606795,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35402004852005431,
                                0,
                                0,
                                0,
                                0,
                                0.37894540397199045,
                                0,
                                -0.0099658933056408355,
                                0,
                                0,
                                0,
                                0,
                                0.11342060927510719,
                                0,
                                0,
                                0,
                                0.35068472371286741,
                                0,
                                0,
                                0.5839448812833804,
                                0,
                                0,
                                0.39260477149427159,
                                0,
                                0,
                                0,
                                -0.61993713404222328,
                                0,
                                -1.1266223731846152,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50869075209357451,
                                0,
                                0,
                                0.27793854154258829,
                                0,
                                0,
                                0.15111860984332898,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068818290823471934,
                                -0.73322676258367003,
                                0,
                                0,
                                0,
                                -0.47444583406813329,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0001459538225388,
                                0,
                                0,
                                -0.2093123520579222,
                                0,
                                0,
                                0.5790085051673457,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2936938226418262,
                                0.92602412299140924,
                                0,
                                0,
                                0.14119712170767934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084446711627149118,
                                0,
                                0,
                                0.28062658643712363,
                                0,
                                0,
                                0,
                                0.039155967606842784,
                                0,
                                0,
                                0,
                                0,
                                -0.44719743766530529,
                                0,
                                0,
                                0.22494309485470632,
                                0,
                                -0.72133657842510401,
                                0,
                                0,
                                0,
                                0,
                                0.34890722456117895,
                                0,
                                0,
                                0,
                                0,
                                0.03518242788591909,
                                0,
                                0,
                                0,
                                0,
                                -0.55033852516000603,
                                0,
                                -0.45441259998229466,
                                0,
                                0,
                                0,
                                0,
                                -0.86065671511208086,
                                0,
                                0,
                                0,
                                0.31797833659402291,
                                0,
                                0,
                                -0.27244099212274314,
                                0,
                                0,
                                -0.31305171531887749,
                                0,
                                0,
                                0,
                                -0.31351125054461715,
                                0.39867219165857537,
                                0,
                                0,
                                0,
                                0,
                                -0.24668882591838764,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.075800715053362347,
                                0,
                                0,
                                0.96679687052211127,
                                -0.42129765702711514,
                                -0.71096818612194057,
                                -0.36321796350819718,
                                0,
                                0,
                                -0.22688087305998855,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49257550374029696,
                                0,
                                0.38902903618282958,
                                -0.058849056265403245,
                                0,
                                0.62038037446587779,
                                0,
                                0,
                                0,
                                0,
                                -0.17893879295830756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40883928352758525,
                                0,
                                0,
                                0,
                                0,
                                0.07303304601660042,
                                0,
                                0.11484025637690065,
                                0,
                                0,
                                0,
                                0.31550276496467788,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.83635297518935525,
                                0,
                                0.42333692280445145,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0016385105416650558,
                                0,
                                0.12324461649368162,
                                0,
                                0.081028610814664725,
                                0,
                                0,
                                0,
                                -0.22552371257693965,
                                0,
                                -0.1934188209633281,
                                -0.36396395656998737,
                                0,
                                0.038134623957092877,
                                0,
                                0,
                                0,
                                0,
                                0.72457243777384361,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26168288235084219,
                                0,
                                0,
                                0,
                                0,
                                -0.25799004171346063,
                                0,
                                -0.34316496530962148,
                                0,
                                0,
                                0.10412317914434199,
                                0,
                                -0.43429824000778977,
                                -0.65633433466487201,
                                0,
                                0.17202348678334176,
                                0,
                                0,
                                0,
                                0,
                                -0.50720827097576737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.012792883427762664,
                                0,
                                0,
                                0,
                                0,
                                0.12134256645994781,
                                0,
                                -0.26082303766772658,
                                0,
                                -0.52881126025341951,
                                0,
                                0,
                                0,
                                0,
                                0.27713024342701464,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36733512408772523,
                                0,
                                0,
                                0.11380654800373827,
                                0.77567809286266398,
                                -0.59288249438374818,
                                -0.75480853166020423,
                                0,
                                0,
                                -0.068318131787571984,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17677005074622798,
                                0,
                                -0.36473194212777016,
                                -0.18049793006792297,
                                0,
                                0.053907181994110515,
                                0,
                                0,
                                0,
                                0,
                                0.022304972377726544,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11224129366531868,
                                0,
                                0,
                                0,
                                0,
                                -0.40833002215145775,
                                0,
                                0.78766010800019925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13912667475184887,
                                0,
                                1.1754818260740445,
                                -0.65852831437399373,
                                0,
                                0,
                                0,
                                0,
                                -1.13487224897341,
                                0,
                                0,
                                0,
                                0,
                                0.32077715608789925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3524984899450897,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16163599429921499,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49464433178716166,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1831243313870845,
                                0,
                                -1.0685965269656479,
                                -0.12199824744696239,
                                0,
                                0,
                                0,
                                0,
                                -0.69479821471174286,
                                0,
                                0,
                                0,
                                0,
                                0.076383839446050067,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36240585865958419,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52437311115553875,
                                0,
                                0.14314071652669208,
                                -0.037662792553500232,
                                0,
                                0,
                                0,
                                0,
                                0.457124249279586,
                                0,
                                0,
                                0,
                                0,
                                -0.97014314522810696,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49341386837667711,
                                0,
                                -0.087728910093552021,
                                0,
                                0.27676436079865641,
                                -0.21303104053353814,
                                0,
                                0.35875232851077599,
                                0,
                                0,
                                0,
                                0,
                                0.16764740275858944,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83835192567142069,
                                0,
                                0,
                                0,
                                0,
                                -0.022618170490399367,
                                0,
                                -0.10083890577446131,
                                0,
                                0,
                                0,
                                0.27734109505262372,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10102574967184728,
                                0,
                                0.03969428317056882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51781503434479792,
                                0,
                                -0.54231400502692573,
                                0,
                                0.59081569794647171,
                                0,
                                0,
                                0.30465935071965577,
                                0,
                                0,
                                0,
                                0,
                                0.34010041039606076,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.421886689915281,
                                0,
                                0,
                                0.42672097102133028,
                                0.42254834067338076,
                                0.42030892452186341,
                                0.58492003933529824,
                                0,
                                0,
                                -0.38909559788781412,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.039711912952943872,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24132969528123649,
                                0,
                                0.23387117104126809,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47108742098519107,
                                0,
                                0.77265491096633487,
                                0,
                                0.25800823213609769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71503449755016768,
                                0,
                                0.39084955455243786,
                                0.57224890041036991,
                                0,
                                0,
                                0,
                                0,
                                -0.11652922509975984,
                                0,
                                0,
                                0,
                                0,
                                0.70698682157829851,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.069584745922209756,
                                -0.067996764614750071,
                                0,
                                0,
                                0,
                                0,
                                -0.63067244944954071,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47790105273853623,
                                0,
                                0,
                                0.70761526243718165,
                                0.55873209437552718,
                                0.076138401880285353,
                                -0.25811867074610784,
                                0,
                                0,
                                0.53833156708506269,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19771352760308739,
                                0,
                                0,
                                0,
                                0,
                                0.01293481877666307,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62638459139340541,
                                0,
                                0,
                                0.10360629667092505,
                                -0.13941443852448246,
                                0.32072377243800365,
                                -0.39687061893826642,
                                0,
                                0,
                                1.0003967549078427,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61394962947819109,
                                0,
                                0,
                                0,
                                0,
                                0.42874651151897458,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53551548808731364,
                                0,
                                0,
                                0.65741893786716221,
                                -0.65449885065772206,
                                0.30217553102914846,
                                0.27265900470818255,
                                0,
                                0,
                                0.4274481148305202,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.93447016172355302,
                                0,
                                0,
                                0,
                                0,
                                -0.72510196915934277,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42630617545141908,
                                0,
                                0,
                                0.48519414043778453,
                                -0.56800250728705159,
                                -0.022403433462355335,
                                0.29886771801602063,
                                0,
                                0,
                                0.35862544142802011,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.78725189730971079,
                                0,
                                -0.091839658805572766,
                                0.6071510222988401,
                                0,
                                0,
                                0,
                                0,
                                -0.35381566210793453,
                                0,
                                0,
                                0,
                                0,
                                -0.25816230666049439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.97032719949413471,
                                0,
                                0.55398318821753401,
                                0,
                                0.10074261606155129,
                                -0.25383885035173026,
                                0,
                                0.22810918822577778,
                                0,
                                0,
                                0,
                                0,
                                0.36724822239052751,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15163985924499751,
                                0,
                                0,
                                0,
                                0,
                                0.51674492501148939,
                                0,
                                0.37629027026289746,
                                0,
                                0.031109471899188942,
                                0,
                                0,
                                0,
                                0,
                                0.04573522278265274,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.072282857066772982,
                                0,
                                0,
                                0.24599022855490141,
                                0.061457004950460949,
                                -0.90738310471560657,
                                0.62307331413305933,
                                0,
                                0,
                                0.62720745299413383,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.84391755356525067,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39613305453660075,
                                0,
                                -0.17463882805677516,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21377394109630143,
                                0,
                                -0.071474239141801676,
                                0,
                                0.2226548469496053,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25315658168095001,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25647059342351658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.054657673169139165,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.011535500739025539,
                                0,
                                -0.21780225743174941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6230992358691948,
                                0,
                                0.20437309763682041,
                                0,
                                0.72070842014342018,
                                0,
                                0,
                                0,
                                -0.5111389330073115,
                                0,
                                0.16640350475482749,
                                -0.33748065093943941,
                                0,
                                -0.57119184448669813,
                                0,
                                0,
                                0,
                                0,
                                0.025407422126584672,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.078107392302807166,
                                0,
                                0,
                                0,
                                0,
                                0.48686684931607366,
                                0,
                                0.16464483292350363,
                                0,
                                0,
                                0,
                                -0.32676993101026042,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27388503481720772,
                                0,
                                0.82859999120348116,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2756620968624498,
                                0,
                                -0.21641105128439408,
                                0,
                                0.093846255672226042,
                                0,
                                0,
                                0,
                                0.29759435071055634,
                                0,
                                0.61250592268789661,
                                -0.42071746973308372,
                                0,
                                -0.27235770410351662,
                                0,
                                0,
                                0,
                                0,
                                -0.14695408553107328,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14029034370896543,
                                0,
                                0,
                                0,
                                0,
                                -0.49200981597576304,
                                0,
                                0.041733032067011136,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18121888464466088,
                                0,
                                0.051330768569787556,
                                0.62251853635781318,
                                0,
                                0,
                                0,
                                0,
                                -0.062003023193824003,
                                0,
                                0,
                                0,
                                0,
                                -0.68362431503629473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61349491163159942,
                                -0.38037704846267473,
                                0,
                                0,
                                -0.13625081750254897,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.8067505551457006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2431138112298023,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.84957433896905177,
                                -0.058997113240391141,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12862108846258324,
                                0,
                                0,
                                0.27634966807989081,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34737203634339558,
                                0,
                                0,
                                -0.058111208873579484,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4493092651645782,
                                -0.75253405471162793,
                                -0.079505872541829614,
                                -0.092389010670327301,
                                0,
                                0,
                                0.3939998821730733,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.012842846480334194,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.025600367427091833,
                                0,
                                0,
                                0.28261199572493534,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51605784633149032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90906478342298391,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.90502881858516826,
                                -0.14675742051993779,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23007783555181549,
                                0,
                                0,
                                -0.053684288052380624,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48626919225351289,
                                0,
                                0,
                                -0.25932939134118471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34253243009934353,
                                0.50470419493775631,
                                -0.49987128317653551,
                                0.1361860361921769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.080138485419358016,
                                0,
                                0,
                                0.057797482576548875,
                                0,
                                0,
                                0,
                                0.38564578478219003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.84337135287616061,
                                0.051536510091039822,
                                0,
                                -0.35718811866816752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.99393613592608288,
                                0.589640498603347,
                                0,
                                0,
                                -0.31448082266824195,
                                0,
                                0,
                                0.060901396673491093,
                                0,
                                0,
                                0.77393940421008289,
                                0,
                                0,
                                0,
                                0.6069759637222083,
                                0,
                                -0.71296482318076837,
                                0,
                                0,
                                -0.30973013287776568,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30734459915048284,
                                0.33085235837799215,
                                0,
                                0,
                                0.56249983035676976,
                                0,
                                0,
                                -0.21825954108259576,
                                0,
                                0,
                                0.082721258079516413,
                                0,
                                0,
                                0,
                                -0.078440113153386171,
                                0,
                                -0.23064606201236196,
                                0,
                                0,
                                1.3635512626426187,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50025989579689933,
                                0,
                                0,
                                -0.71398253502971709,
                                0,
                                0,
                                0,
                                0.22736626041319025,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17483628336710372,
                                0.12430319516373664,
                                0,
                                -0.37716647471110137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28490138674541327,
                                0,
                                0,
                                -1.2234531380530598,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28481300694186673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27559192020294054,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20151023356835224,
                                0.59291400752307877,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10010697838960204,
                                0.22956211467296914,
                                0,
                                0,
                                1.0132241944480007,
                                0,
                                0,
                                0.90214944716338574,
                                0,
                                0,
                                -0.45094810911297467,
                                0,
                                0,
                                0,
                                0.23280861188512122,
                                0,
                                -0.34427315957521981,
                                0,
                                0,
                                -0.35563959298030512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72632097493849945,
                                0,
                                0,
                                0.14700680179001818,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.02120199650973327,
                                0,
                                0,
                                -0.51005065254681392,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.063923107458235012,
                                0.07514217973862243,
                                -0.059788143232279906,
                                -0.42064060177100671,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44452260183115844,
                                0,
                                0,
                                -0.20007916398827583,
                                0,
                                0,
                                0,
                                -0.51346590395550529,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.029169153658260866,
                                0.62472517299122676,
                                0,
                                -0.32800665965816606,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80983857544387527,
                                0.69441236870907663,
                                0,
                                0,
                                0.18966806445309833,
                                0,
                                0,
                                0.063398239573818294,
                                0,
                                0,
                                0.18728291310406522,
                                0,
                                0,
                                0,
                                0.58248403807667248,
                                0,
                                0.39899834262368605,
                                0,
                                0,
                                0.3656838823876461,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52609666748285777,
                                0,
                                0,
                                0.57483381488652097,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34609946607060349,
                                0,
                                0,
                                -0.42413125486735292,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.03431493637620768,
                                0.1633367342418045,
                                0.14854840799990118,
                                -0.20782970631297354,
                                0.29281934488552752,
                                0,
                                0,
                                1.0676374658574068,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.052545680903043679,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74838982637096541,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.068838085223754744,
                                1.2926120934566714,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42355385674367396,
                                -0.10143549711763881,
                                0,
                                0,
                                -0.60000200222200251,
                                0,
                                0,
                                0.078709910079925879,
                                0,
                                0,
                                -0.19835526951685767,
                                0,
                                0,
                                0,
                                0.19298584475830854,
                                0,
                                -0.85877792513800189,
                                0,
                                0,
                                0.36770414764567277,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17426899215229591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60476208012775889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46177898812780871,
                                0,
                                0,
                                -0.52992782715066933,
                                0,
                                0,
                                0,
                                0.35438542195842715,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.079087647267067934,
                                0.10559206117716041,
                                0,
                                0.6024475890104406,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.026095290691976206,
                                0,
                                0,
                                0.40190995755151515,
                                0,
                                0,
                                0,
                                0.59830746951987446,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36955772862941733,
                                0.58145045113599114,
                                0,
                                -0.071819578287426467,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42538150599917995,
                                -0.87842948106247842,
                                0,
                                0,
                                0.016772953020918996,
                                0,
                                0,
                                0.60202608291172877,
                                0,
                                0,
                                1.2710348847269246,
                                0,
                                0,
                                0,
                                0.10225255090213999,
                                0,
                                -0.1892360027092212,
                                0,
                                0,
                                -0.28118500356566833,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57601798426835826,
                                0,
                                0,
                                0.067093985202959006,
                                0,
                                0,
                                0,
                                -0.22885327701537839,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33834660468386468,
                                0.49231783587527694,
                                0,
                                0.50445275311599813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45364135305465647,
                                -0.46136031051239285,
                                0,
                                0,
                                0.61570854417184229,
                                0,
                                0,
                                -0.70509858443385587,
                                0,
                                0,
                                -0.035093625563045211,
                                0,
                                0,
                                0,
                                0.13215995553127402,
                                0,
                                -0.36048425581037868,
                                0,
                                0,
                                -0.1568855027604476,
                                0,
                                0,
                                0,
                                0,
                                -1.0852702711941629,
                                0,
                                0,
                                0.45785725863633914,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0071772353915953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49958378527294151,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.04336446421546139,
                                0.31925956058314769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.84406446463780638,
                                0,
                                0,
                                -0.45772611438131472,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74167599639373194,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52753821597519246,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.96293917968395881,
                                0.21311436336294293,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41474989083746583,
                                -0.22648361901128805,
                                0,
                                0,
                                -0.29174649188855178,
                                0,
                                0,
                                0.34928955683618484,
                                0,
                                0,
                                -0.47150257153687958,
                                0,
                                0,
                                0,
                                1.3005699732093132,
                                0,
                                0.50944439641307127,
                                0,
                                0,
                                0.39760675114663435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3021160273336696,
                                0,
                                0,
                                0.43985799119075214,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26326426554420679,
                                0,
                                0,
                                -0.052168879410517004,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.012733219414107272,
                                -0.064394948756467077,
                                -0.26629517726013557,
                                0.75365723136468032,
                                0,
                                0.12484219633120153,
                                0,
                                0,
                                -0.60735204905599738,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37547511081454221,
                                0,
                                0,
                                -0.56375720759382875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23036094581105138,
                                -0.22598445571410231,
                                0.041060993075864166,
                                0.22563914074416414,
                                0,
                                0.13842123325753342,
                                0,
                                0,
                                -0.069330892927485122,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11285614088289986,
                                0,
                                0,
                                -0.21850098065709961,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73001912167156913,
                                -0.30230822917890032,
                                -0.53343755317700103,
                                -0.081730017810875286,
                                0,
                                -0.01344757394842333,
                                0,
                                0,
                                0.039314209109627574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54737047332926414,
                                0,
                                0,
                                -0.34791652020279018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29895287555758027,
                                0.0059149897576198651,
                                0.60084233803260445,
                                0.35664252625535564,
                                0.079014704553770299,
                                0,
                                -0.39470189557232532,
                                0,
                                0,
                                -0.11084586211952401,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72347612837227715,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49642583696680492,
                                0,
                                0,
                                0,
                                0,
                                -0.073273819813769001,
                                0,
                                -0.14233904861387092,
                                0,
                                -0.17376566859923318,
                                0,
                                0,
                                -0.46346535078589762,
                                0,
                                0,
                                0,
                                0,
                                0.62630283000083808,
                                -0.29961429448097332,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43123367723028827,
                                0,
                                0,
                                -0.13572414979957154,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31431254998829072,
                                0.45810827697236473,
                                0,
                                -0.3139586180514411,
                                0,
                                0,
                                0.59814074265446848,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14924493339820907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.05019880998683645,
                                0,
                                0,
                                0,
                                0,
                                0.15159252458172823,
                                0,
                                -0.51747247915068206,
                                0,
                                0.13506448030794913,
                                0,
                                0,
                                0,
                                0,
                                -0.17080547111234906,
                                -0.8628085202415422,
                                0,
                                0,
                                0,
                                0,
                                0.9433844083746884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12720249851954038,
                                0,
                                0,
                                -0.56618452463310087,
                                0,
                                -0.54843352468013828,
                                0,
                                0.64752556359450064,
                                0,
                                0,
                                -0.1366490129481395,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1374905167628297,
                                0.28153463929245182,
                                0,
                                0,
                                0,
                                0,
                                0.37996017505658675,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.92674778853022111,
                                0,
                                0,
                                -0.32322507539947642,
                                0,
                                -0.67216196629849045,
                                0,
                                -1.0736505891986734,
                                0,
                                0,
                                -0.08172289807044425,
                                0,
                                0,
                                0,
                                0,
                                0.31224047768042401,
                                0,
                                -0.16262591652359107,
                                0,
                                0,
                                -0.67932222094996542,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.097253012839187802,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41106538355232225,
                                0,
                                0,
                                0,
                                0,
                                0.36867515373375653,
                                0,
                                -0.2349073092417529,
                                0,
                                0.21223643541871329,
                                0,
                                0,
                                -0.47978260464513639,
                                0,
                                0,
                                0,
                                0,
                                0.063350376667615269,
                                0.023338176395918564,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73345576780161115,
                                0,
                                0,
                                0.33479482843512198,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33941975651129541,
                                0,
                                0.52860724568398132,
                                0,
                                0,
                                0,
                                0,
                                0.22188267650980156,
                                0.085187547386275903,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18299620107187414,
                                0,
                                0,
                                0.65429657814249442,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44999324180462535,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76761768328636626,
                                0,
                                0,
                                -0.65895801758613182,
                                0,
                                -0.063874771464116492,
                                0,
                                0,
                                0.2783713229043715,
                                0,
                                0,
                                0,
                                0,
                                -0.98476834121229073,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48452507847000126,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66406920014438675,
                                0.39272910421900042,
                                0,
                                0,
                                0,
                                0,
                                -0.77599603330878986,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11424240569717087,
                                0,
                                0,
                                -0.45574433007631704,
                                0,
                                -0.81139641532721574,
                                0,
                                -0.14679061453859621,
                                0,
                                0,
                                0.31169834121678913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.05203553209608322,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.059677842689643407,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46811431306318568,
                                0,
                                0,
                                -0.11482387983057057,
                                0,
                                0.25846623413616243,
                                0,
                                0,
                                0.068737645558465621,
                                0,
                                0,
                                0,
                                0,
                                -1.2740036494039393,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41083430462395887,
                                0,
                                0,
                                -0.11035689506249297,
                                0,
                                0.67159863221742466,
                                0,
                                0,
                                0.03249211592343048,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35077876222514737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.074028758857776655,
                                0,
                                0,
                                0,
                                0,
                                -0.20551350409606153,
                                0,
                                -0.56835010081695758,
                                0,
                                0.20478588986537066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64820282489722025,
                                0,
                                0,
                                0.57276940096955731,
                                0,
                                -0.30320151404288709,
                                0,
                                0,
                                0.93693556820692225,
                                0,
                                0,
                                0,
                                0,
                                0.25220634339958353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22540646101801207,
                                0,
                                0,
                                0,
                                -0.45275155245832854,
                                0,
                                0,
                                0,
                                0,
                                -0.014925861101548355,
                                0.56591510144952606,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34793434338296886,
                                0,
                                0,
                                0.45940093857163983,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37739345344412689,
                                0,
                                0,
                                0,
                                0.6866058602125249,
                                0.50844370975639319,
                                0,
                                0,
                                0,
                                0,
                                0.17123819509333477,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11063257595765368,
                                0,
                                0,
                                -0.25681963582431855,
                                0,
                                -0.54404539145823128,
                                0,
                                0.42665592928912394,
                                0,
                                0,
                                -0.3689463577169203,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64349687856126658,
                                0,
                                0,
                                0.7999167339645179,
                                0,
                                -0.43559964864777878,
                                0,
                                0,
                                -0.12568326905954097,
                                0,
                                0,
                                0,
                                0,
                                0.02338393159071335,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3232565724445241,
                                0,
                                0,
                                0,
                                0.13769988739493647,
                                0,
                                0,
                                0,
                                0,
                                0.31349931889304744,
                                0.75749925381093475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12657096182752667,
                                0,
                                0,
                                -0.46788860703471291,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2720511745426798,
                                0,
                                0,
                                0,
                                0.19489476171028813,
                                0.46767148509137108,
                                0,
                                0,
                                0,
                                0,
                                0.90521857688547347,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51874169029722483,
                                0,
                                0,
                                0.49971550756222993,
                                0,
                                -0.025784368397043234,
                                0,
                                0.0055157248132369358,
                                0,
                                0,
                                0.52126012977887248,
                                0,
                                0,
                                0,
                                0,
                                -0.21002424604416123,
                                0,
                                -0.091783508773111089,
                                0,
                                0,
                                -0.34890728575406493,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52559452510059068,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35674472322989892,
                                0,
                                0,
                                0,
                                0,
                                -0.11599519487552702,
                                0,
                                -0.53991559145962364,
                                0,
                                -0.34241667020621325,
                                0,
                                0,
                                0,
                                0,
                                -0.41160937603090808,
                                -0.51974072001027027,
                                0,
                                0,
                                0,
                                0,
                                -0.024121828827508671,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23823880134362241,
                                0,
                                0,
                                1.1029270820215058,
                                0,
                                -0.75757720824548236,
                                0,
                                0.27172981605492191,
                                0,
                                0,
                                -0.77903688826628859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90937509557964336,
                                0,
                                0,
                                0.052851896942128218,
                                0,
                                1.3665855635341611,
                                0,
                                0,
                                0.052570022869366476,
                                0,
                                0,
                                0,
                                0,
                                0.42962689544925542,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37158508794086487,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60992269580784975,
                                0.090758307596070967,
                                0,
                                0,
                                0,
                                0,
                                0.019066353249655221,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76069387683217615,
                                0,
                                0,
                                -0.83575961826148482,
                                0,
                                0.32940131633177061,
                                0,
                                0.14960151766882368,
                                0,
                                0,
                                -1.0532924627707523,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21938358311306941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46290780172133866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.054131738911851662,
                                0,
                                -0.29224026936622155,
                                0,
                                0,
                                -0.13521988692020284,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13505963241809193,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12478597556474016,
                                0,
                                0,
                                0,
                                0,
                                -0.56383151420996791,
                                0,
                                0.026729220488481774,
                                0,
                                0.73549159773150641,
                                0,
                                0,
                                0,
                                0,
                                0.47503589380508926,
                                -1.1372156982677242,
                                0,
                                0,
                                0,
                                0,
                                -0.020967857012443414,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79029523775478139,
                                0,
                                0,
                                -0.1502849613348696,
                                0,
                                -0.091710605212155585,
                                0,
                                -0.5396367182046814,
                                0,
                                0,
                                0.077600834078825426,
                                0,
                                0,
                                0,
                                0,
                                0.35648521880109474,
                                0,
                                0.37377386719775901,
                                0,
                                0,
                                -0.091273677669740663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15341863263937339,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65510300038603853,
                                0,
                                0,
                                0,
                                0,
                                0.38811356881429682,
                                0,
                                0.15872790888615371,
                                0,
                                0.3104135812559467,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34418383232634625,
                                0,
                                0,
                                -0.70439438411964339,
                                0,
                                0.00044944753386069736,
                                0,
                                0,
                                0.43801800361702714,
                                0,
                                0,
                                0,
                                0,
                                0.5143957206198434,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.86210475386638441,
                                0,
                                0,
                                0.70717648613062256,
                                0,
                                0.18604568508695832,
                                0,
                                0,
                                -0.13803924531749845,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.061452152365551502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.067736126327547372,
                                0,
                                0,
                                0,
                                0,
                                -0.55812228097980432,
                                0,
                                0.12783075271236752,
                                0,
                                -0.33170447023113042,
                                0,
                                0,
                                0.22723924280200036,
                                0,
                                0,
                                0,
                                0,
                                0.67527399512926778,
                                -0.091458538490027039,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32482922745804632,
                                0,
                                0,
                                0.10685688977282365,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60586324518596724,
                                0.41650473627292511,
                                0,
                                0.59176581247865845,
                                0,
                                0.065359876612356538,
                                0,
                                0,
                                -0.36223375998698737,
                                0,
                                0,
                                0,
                                0,
                                -0.79302143811158876,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.071572817534488103,
                                0,
                                -0.20102405166201898,
                                0,
                                0,
                                0,
                                0.26380812049127556,
                                0,
                                0,
                                0,
                                0,
                                -0.89252911322612627,
                                0,
                                0,
                                0,
                                0,
                                0.31390555060098257,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48053318026430053,
                                -0.15446732929226939,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55068197646004069,
                                0,
                                0,
                                0,
                                0.10924054117214549,
                                0,
                                -0.95154846664956361,
                                0,
                                0.34162082730267018,
                                0,
                                0.27387676356053914,
                                0,
                                0,
                                -0.62086220221691812,
                                0,
                                0,
                                0,
                                0,
                                -0.035671032680480413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12248109374218161,
                                0,
                                -0.055914451911997232,
                                0,
                                0,
                                0,
                                0.22530063305554907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33248245959577205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4692815696282846,
                                0,
                                0,
                                0,
                                0.41742985737572669,
                                0,
                                0,
                                0,
                                0.031861487567557328,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70078510627099944,
                                0,
                                0.053550136119083248,
                                0,
                                0,
                                -0.39035818480604828,
                                0,
                                0.49615766973292585,
                                0,
                                0.94862675630843818,
                                0,
                                0,
                                0.64205891598000897,
                                0,
                                0,
                                0,
                                0,
                                0.10980544281922183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.011589178578818783,
                                0,
                                0.95162866947620328,
                                0,
                                0,
                                0,
                                -0.0098586765921283084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17497213085793956,
                                0,
                                0,
                                0,
                                0.07589357471000055,
                                0,
                                -0.7707764418165084,
                                0,
                                -0.053191774176255528,
                                0,
                                0,
                                0,
                                -0.45767383225582037,
                                0,
                                0.26906251793152841,
                                0,
                                -0.28984556992250043,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.028788903250240309,
                                0,
                                0.15723440314696113,
                                0,
                                0,
                                0,
                                0,
                                1.0260554345887196,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0094600533919569,
                                0.16171796707903943,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27695413682475062,
                                0,
                                0,
                                0,
                                0.49699705915437675,
                                0,
                                -0.58698402577016695,
                                0,
                                0.0017763008748794828,
                                0,
                                -0.47169324889556763,
                                0,
                                0,
                                0.4111533431175638,
                                0,
                                0,
                                0,
                                0,
                                -0.74959457652597161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22912836854990298,
                                0,
                                -0.05580795626155502,
                                0,
                                0,
                                0,
                                0.26303796664302248,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23519856839466341,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17519619514982374,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28249299939753714,
                                0,
                                0,
                                0,
                                -0.51217264287134678,
                                0,
                                -0.036861017835896237,
                                0,
                                0.53780717422857227,
                                0,
                                0,
                                0,
                                -0.23046046395890488,
                                0,
                                -0.53213776996498008,
                                0,
                                -0.10812782640187954,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13895085240506036,
                                0,
                                0,
                                0,
                                -0.63514230735503308,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55803180386427376,
                                0,
                                0,
                                0,
                                -0.084540782382115737,
                                0,
                                0,
                                0,
                                -0.31145502418929294,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.024629304108140303,
                                0,
                                -0.42477850308640397,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38878243891098108,
                                0,
                                0,
                                0,
                                -0.41229107565286072,
                                0,
                                -0.20973925661650167,
                                0,
                                -0.59261046639360115,
                                0,
                                0,
                                0,
                                0.11875636572280787,
                                0,
                                -0.31014390337073838,
                                0,
                                -0.18845204648016498,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37132206299365261,
                                0.32436565648888049,
                                0,
                                -0.96039119472543799,
                                0,
                                0.2281399014470897,
                                0,
                                0,
                                -0.42571619961003138,
                                0,
                                0,
                                0,
                                0,
                                -0.45607886439653533,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40679291102077048,
                                0,
                                0.46826863158082177,
                                0,
                                0,
                                0,
                                -0.63320772502015821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.087731687655196372,
                                0,
                                0,
                                0,
                                -0.20856734059216481,
                                0,
                                -0.54246575197709568,
                                0,
                                0.14493720844305558,
                                0,
                                0,
                                0,
                                0.61869176349631716,
                                0,
                                0.027995045931677065,
                                0,
                                0.47794403667718194,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1467419706490424,
                                0,
                                0,
                                0,
                                0.49888322665912188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51668853546599813,
                                0,
                                0,
                                0,
                                0.0493744726658722,
                                0,
                                0,
                                0,
                                0.21660887138702806,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60126721327183053,
                                0,
                                -0.27068243387023089,
                                0,
                                0,
                                0,
                                0.52653309359773526,
                                0,
                                0,
                                0,
                                0,
                                -0.43164172675089973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.82656454955129244,
                                0.061173495029736354,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.069323242720369882,
                                0,
                                0,
                                0,
                                0.98299894345892858,
                                0,
                                0,
                                0.62380177596222319,
                                0,
                                0,
                                0,
                                0,
                                0.57585475981508016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72970443887179059,
                                0.5888036825732792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18893360653432067,
                                0,
                                0,
                                0,
                                -0.71011332362604607,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40914597196760538,
                                0,
                                0,
                                0,
                                -0.54222330257630191,
                                0,
                                0.10710668558119582,
                                0,
                                0.12514722733656392,
                                0,
                                0,
                                0,
                                -0.3693535141128314,
                                0,
                                0.49680909560040482,
                                0,
                                0.35338440709269342,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.057775064904073879,
                                0,
                                0,
                                0,
                                -0.17499178026915654,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.046652440169602682,
                                0,
                                0,
                                0,
                                -0.38529763347502483,
                                0,
                                0,
                                0,
                                0.84293060989499247,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25851071284599475,
                                0,
                                -0.20343883245068875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1616312900744715,
                                0,
                                0,
                                0,
                                -0.0014500665546715863,
                                0,
                                -0.0035829468702467115,
                                0,
                                -0.43248692078608364,
                                0,
                                0,
                                0,
                                -0.37479133409127457,
                                0,
                                -0.41496561058167902,
                                0,
                                0.44488677660647252,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52557226253095213,
                                -0.10800985629705524,
                                0,
                                -0.69543898130768389,
                                0,
                                0.26569265154351535,
                                0,
                                0,
                                -0.2275254031521787,
                                0,
                                0,
                                0,
                                0,
                                -0.58752559065213683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45621986011131987,
                                0,
                                0.32830123986578713,
                                0,
                                0,
                                0,
                                1.2517737375322797,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.589124182871682,
                                0,
                                0,
                                0,
                                -0.045093447320810484,
                                0,
                                0.11230951918178211,
                                0,
                                -0.25939264133664469,
                                0,
                                0,
                                0,
                                -0.094233400896147027,
                                0,
                                0.21071437221128464,
                                0,
                                0.37625895968507755,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61331070628345219,
                                -0.37121276947846515,
                                0,
                                -0.10094610366540513,
                                0,
                                0.81630636860390871,
                                0,
                                0,
                                0.32273771031478049,
                                0,
                                0,
                                0,
                                0,
                                -0.4092652906052936,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.067206979495639071,
                                0,
                                -0.66484580130520621,
                                0,
                                0,
                                0,
                                0.27392941834610945,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1619324948596762,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.041386360707102221,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48569282201368824,
                                0,
                                0,
                                0,
                                0,
                                -0.30574460616704363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21673475646214921,
                                0.20813672690734891,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2737355804063981,
                                0,
                                0,
                                0,
                                0.38960943661693892,
                                0,
                                0,
                                0,
                                0,
                                0.34588501180349995,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36590427958256766,
                                0,
                                0,
                                0,
                                -0.135890527963486,
                                0,
                                0,
                                0,
                                -0.23147427584468686,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23257945684458925,
                                0,
                                -0.78761528494481325,
                                0,
                                0,
                                -0.072185102511043112,
                                0,
                                -0.0026419040532223576,
                                0,
                                0.10696271559246091,
                                0,
                                0,
                                0.38630042633288691,
                                0,
                                0,
                                0,
                                0,
                                0.025225211328658972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.9237014666700637,
                                0,
                                0.3559287229439636,
                                0,
                                0,
                                0,
                                -0.85060718647938693,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2947992962593064,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25562840141616894,
                                0,
                                0,
                                0,
                                0.8057585431025962,
                                0,
                                0,
                                0,
                                0.30157728176686205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16078052758326533,
                                0,
                                -0.28583462107273394,
                                0,
                                0,
                                0,
                                -0.29707645210561245,
                                0,
                                0,
                                0,
                                0,
                                -0.42851643746492285,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24089464869787472,
                                1.6278324288444417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.03179388920289962,
                                0,
                                0,
                                0,
                                -0.59490812666916471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43605208603713208,
                                0,
                                0,
                                0,
                                -0.47158610141330293,
                                0,
                                0.20539519606689247,
                                0,
                                -0.25641531096464165,
                                0,
                                0,
                                0,
                                0.23402899149544948,
                                0,
                                0.28990603604129511,
                                0,
                                -0.41949690680291646,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40587731587420345,
                                -0.22756494735222424,
                                0,
                                0,
                                0,
                                -0.092378304555454732,
                                0,
                                0.19368306128327112,
                                0,
                                0,
                                0,
                                0,
                                -0.30571216135589657,
                                0,
                                0,
                                0.77346058976984655,
                                0,
                                0,
                                0,
                                0,
                                -0.53800272635555824,
                                0.67436978351559917,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.93976666656692909,
                                0,
                                0,
                                0,
                                0.4356879252809005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21425857202585022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74100810648873394,
                                -0.11393028943083337,
                                0,
                                -0.073113333213646103,
                                0,
                                0,
                                -0.22349396448859299,
                                0,
                                0,
                                0,
                                0,
                                -0.59066918141000602,
                                0,
                                0,
                                -0.13600706801493487,
                                0,
                                0,
                                0,
                                0,
                                0.026249305253071911,
                                0,
                                0,
                                0,
                                0.12064299883497101,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39614046225462979,
                                0.51450445070457773,
                                0,
                                -0.15106828475076506,
                                0,
                                0,
                                0.34239687770065269,
                                0,
                                0,
                                0,
                                0,
                                0.13210385014110576,
                                0,
                                0,
                                0.32608539577752932,
                                0,
                                0,
                                0,
                                0,
                                0.32087349656392078,
                                0,
                                0,
                                0,
                                -0.45995406563539271,
                                0,
                                0,
                                0,
                                0,
                                -0.033476617588266255,
                                0,
                                0,
                                0,
                                0.38323771806894913,
                                0,
                                -0.61050285791629944,
                                0,
                                0,
                                0,
                                0,
                                0.67597669441496833,
                                0,
                                0,
                                0.60827169734913289,
                                0,
                                0,
                                0,
                                0,
                                -0.32904294763194331,
                                -0.52110816855179731,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12942572535897426,
                                0,
                                0,
                                0,
                                0,
                                0.14519392861761332,
                                0.21187750739193525,
                                0,
                                -0.29522577007218453,
                                0,
                                0,
                                -0.7637769118209109,
                                0,
                                0,
                                0,
                                0,
                                0.4942651919405886,
                                0,
                                0,
                                -0.12627859141714587,
                                0,
                                0,
                                0,
                                0,
                                0.053687253625174548,
                                0,
                                0,
                                0,
                                -0.019660488101342743,
                                0,
                                0,
                                0,
                                0,
                                0.2115830135566768,
                                0,
                                0,
                                0,
                                -0.39321909306751024,
                                0,
                                0.49330014902149433,
                                0,
                                0,
                                0,
                                0,
                                0.45879407477789441,
                                0,
                                0,
                                -0.13598744877065674,
                                0,
                                0,
                                0,
                                0,
                                -0.77642531953831895,
                                -0.26199750628874402,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.050782408133500143,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43816872056254152,
                                0,
                                0.4179903761772118,
                                0.18906933422180983,
                                0,
                                0.31140162690499351,
                                0,
                                0,
                                0,
                                0,
                                -0.4137991235409953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57388528184504495,
                                0,
                                0,
                                0,
                                0.054813982005552632,
                                -0.42335377049298051,
                                0,
                                -0.77337598850991285,
                                0,
                                0,
                                0.19656455410852375,
                                0,
                                0,
                                0,
                                0,
                                0.089549090894755073,
                                0,
                                0,
                                0.18980387906384638,
                                0,
                                0,
                                0,
                                0,
                                -0.35279331050429402,
                                0,
                                0,
                                0,
                                -0.11185390796107239,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35329653080771922,
                                0,
                                -0.41963084548785784,
                                -0.44239445318987025,
                                0,
                                0.5150106152449373,
                                0,
                                0,
                                0,
                                0,
                                -0.3441613998536055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34597060519218958,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72206404307889727,
                                0,
                                0.13910526987974225,
                                0.16640178985845638,
                                0,
                                0.25152217148642037,
                                0,
                                0,
                                0,
                                0,
                                -0.58463287898329985,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16286399227145304,
                                0,
                                1.1239839572134693,
                                0,
                                0,
                                0,
                                0.58884671402648381,
                                0,
                                0.49037481570303526,
                                0,
                                0,
                                0,
                                0,
                                -0.42571296158096705,
                                0,
                                0,
                                0.24393672672305183,
                                0,
                                0,
                                0,
                                0,
                                -0.073992434898156573,
                                -0.077298319395450066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46164653406703343,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.02198900544102067,
                                0,
                                0.20843182805767441,
                                0.42198364684654471,
                                0,
                                0.65674090238705118,
                                0,
                                0,
                                0,
                                0,
                                0.50801458644344721,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29768275996247495,
                                0,
                                0,
                                0,
                                -0.22053738451951319,
                                -0.15175027724036996,
                                0,
                                -0.18368188306239505,
                                0,
                                0,
                                0.016697556703812816,
                                0,
                                0,
                                0,
                                0,
                                -0.18054627087277275,
                                0,
                                0,
                                -0.65353891730885016,
                                0,
                                0,
                                0,
                                0,
                                0.34120635675784811,
                                0,
                                0,
                                0,
                                -0.5640792697540713,
                                0,
                                0,
                                0,
                                0,
                                0.12516026002621849,
                                0,
                                0,
                                0,
                                0.40708981746266543,
                                0,
                                0.34037217330487768,
                                0,
                                0,
                                0,
                                0,
                                0.77351640362528873,
                                0,
                                0,
                                0.24305837819126094,
                                0,
                                0,
                                0,
                                0,
                                0.28138557227194261,
                                0.97676161697728381,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41894608900268626,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.035185937481613971,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53701541448300372,
                                0.123184857876317,
                                1.3368363011037976,
                                0,
                                -0.10563182650773478,
                                0,
                                0,
                                0.56403175514791493,
                                0,
                                0,
                                0.25343011151712724,
                                -0.39186995354573728,
                                0,
                                -0.0055441121343021288,
                                0,
                                0,
                                0.2772865668592458,
                                0,
                                0,
                                0,
                                0,
                                0.43292973514412741,
                                0,
                                0,
                                -0.15423436957808323,
                                0,
                                0,
                                0,
                                0,
                                0.57500020494017978,
                                0,
                                0,
                                0,
                                0.40429062409629413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39497879224579335,
                                0,
                                -0.28557325745507145,
                                -0.34349872821237193,
                                0,
                                0.37720030343405642,
                                0,
                                0,
                                0,
                                0,
                                0.30638690928695134,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63897987834194159,
                                0,
                                0,
                                -0.092616559008974239,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79625600820125608,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19193126234344859,
                                0,
                                0,
                                0,
                                -0.74249176996618704,
                                0,
                                0.78557384436660183,
                                0,
                                0,
                                0,
                                0,
                                0.17218396691973892,
                                0,
                                0,
                                0.65664726139504503,
                                0,
                                0,
                                0,
                                0,
                                0.62399447679669073,
                                -0.2917872973860085,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.033472612947162403,
                                0,
                                0,
                                0.69988806820828686,
                                0,
                                0,
                                0,
                                -0.6362719989286888,
                                0,
                                -1.0864070758322169,
                                0,
                                0,
                                0,
                                0,
                                0.032085601303320423,
                                0,
                                0,
                                -0.5572160756617307,
                                0,
                                0,
                                0,
                                0,
                                0.048059336224022697,
                                0.32834427163511387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30552928448194988,
                                0,
                                0,
                                0,
                                0,
                                0.069400814649324002,
                                -0.56429705998920399,
                                0,
                                0.3651871527715202,
                                0,
                                0,
                                -0.29544835260444274,
                                0,
                                0,
                                0,
                                0,
                                0.066533235036009053,
                                0,
                                0,
                                0.45799790920909722,
                                0,
                                0,
                                0,
                                0,
                                0.13594170007907924,
                                0,
                                0,
                                0,
                                -0.47268601352573392,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1846088939764099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.96194647347909923,
                                0.042922071044423998,
                                -0.6571491656538514,
                                0,
                                0.51601895767522454,
                                0,
                                0,
                                -0.19850357070670677,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.09297884099304729,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48049156619753247,
                                -0.93576535887906587,
                                0.49250450543136287,
                                0,
                                1.06177365215754,
                                0,
                                0,
                                0.21239847721600363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48079762469591303,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53907662283372071,
                                0.49182614374461298,
                                0.76660797426299732,
                                0,
                                0.44285959154750892,
                                0,
                                0,
                                -0.88159227870341716,
                                0,
                                0,
                                0.39014591921954889,
                                -0.056242218832629226,
                                0,
                                0.34559038041643825,
                                0,
                                0,
                                0.21532685247851049,
                                0,
                                0,
                                0,
                                0,
                                0.39609290375339956,
                                0,
                                0,
                                -0.40315648936403609,
                                0,
                                0,
                                0,
                                0,
                                -0.55088889319406142,
                                0,
                                0,
                                0,
                                -0.23647683636610789,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56152522177252406,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28420821037229377,
                                0.51228484088898774,
                                -0.22082948552971082,
                                0,
                                0.73730093509263361,
                                0,
                                0,
                                -0.023183659766094902,
                                0.046933229485923385,
                                0,
                                0,
                                0,
                                -0.14959470845441597,
                                0,
                                -0.18242381019174292,
                                0,
                                0,
                                0,
                                0,
                                -0.52447496671643901,
                                0,
                                0,
                                0.733345757950981,
                                0,
                                0,
                                0,
                                0,
                                -0.51157294866014913,
                                0.2802767702465247,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.93650348461904287,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.072948534242577912,
                                0,
                                -0.71052643195668541,
                                0.66692488668982297,
                                0,
                                -0.03067586050639251,
                                0,
                                0,
                                0,
                                0,
                                -0.12874725161141146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16590670010951461,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.8152459452571722,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29643145982632929,
                                -0.2361652606539138,
                                0.46682663225892862,
                                0,
                                -0.29168341383897434,
                                0,
                                0,
                                -0.89426458508518103,
                                -0.57651684608786125,
                                0,
                                0,
                                0,
                                0,
                                -1.0629345015696845,
                                0,
                                0,
                                0.194029870649812,
                                0,
                                0.47258465546056555,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25742048901087072,
                                0,
                                -0.12158998389972835,
                                0,
                                -0.46599951312204996,
                                0,
                                0.25938801757436281,
                                0,
                                0,
                                0,
                                0.19168089496040425,
                                0,
                                0.52816493388093799,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59813720859175112,
                                -0.39297056319534424,
                                0,
                                0,
                                0,
                                0,
                                0.40728788216426259,
                                0,
                                0.078884943606985503,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16072100414816837,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21787566273710035,
                                0,
                                0,
                                0,
                                0.71741314553560409,
                                0.38478762211819273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39934574337412032,
                                0,
                                -0.26447933015527397,
                                0,
                                0,
                                0,
                                -0.079224202867636484,
                                0.16808630443729972,
                                0,
                                -0.13185553377625131,
                                0,
                                -0.23876953905746945,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42300909784983054,
                                -0.71888446264018258,
                                0,
                                0,
                                0,
                                0,
                                0.36051650837068488,
                                0,
                                -0.31606882974105688,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52332463453332811,
                                0,
                                0,
                                -1.0071794756832975,
                                0,
                                -0.13191082018243017,
                                0,
                                0,
                                0,
                                0,
                                0.34522769748146775,
                                0,
                                0,
                                1.1529527566848121,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67413218709556755,
                                0,
                                0,
                                0,
                                -0.90755029576731283,
                                0,
                                0,
                                0,
                                0,
                                -0.11877299451426498,
                                0,
                                0,
                                -0.18488079479402619,
                                0,
                                -0.45773069574958475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.043367539874118,
                                0,
                                0.019367474878845284,
                                0,
                                -0.23777698238017614,
                                0,
                                -0.47970821547898218,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25146012798189821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1597589397297918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20294870185204367,
                                0,
                                0,
                                -0.53041492371691146,
                                0,
                                0.62628093400134177,
                                0,
                                0,
                                0,
                                0,
                                0.90503154003365238,
                                0,
                                0,
                                -0.65868830470000561,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39100282255229518,
                                0,
                                0,
                                0,
                                0.3490790732629403,
                                0,
                                0,
                                0,
                                0,
                                -0.58704287941599431,
                                0,
                                0,
                                -0.31062052970561604,
                                0,
                                0.048398335926310661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19939769135235857,
                                0,
                                1.3371040959988487,
                                0,
                                0.096776952437929928,
                                0,
                                0.047109076886141132,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.99717692340080988,
                                0,
                                0,
                                -0.95862359018512899,
                                0,
                                -0.55908746238927287,
                                0,
                                0,
                                0,
                                0,
                                -0.20123227834951907,
                                0,
                                0,
                                -0.055371706982214094,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44958949264787795,
                                0,
                                0,
                                0,
                                -0.58415640538840252,
                                0,
                                0,
                                0,
                                0,
                                -0.35577337177824381,
                                0,
                                0,
                                0.016989287973390957,
                                0,
                                0.40173266725144713,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29878620813320517,
                                0,
                                -0.16408463179039423,
                                0,
                                1.0883924135501837,
                                0,
                                -0.10216661422236317,
                                0,
                                0,
                                0,
                                0,
                                -0.059856295946473126,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20692589712989606,
                                0,
                                0,
                                0,
                                0.029664844753907529,
                                0.28381394817826805,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0043884435325584337,
                                0,
                                0.13339415404696323,
                                0,
                                0,
                                0,
                                0.83628302790664533,
                                -0.39368258178702448,
                                0,
                                0.66715053693540938,
                                0,
                                -0.5994288693356975,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20127257202463739,
                                -0.22958692887002985,
                                0,
                                0,
                                0,
                                0,
                                -0.11181488160103541,
                                0,
                                0.29978628682593811,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52957522623921893,
                                0,
                                -0.25228282099832205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53227775510334097,
                                -0.32922371746006579,
                                0,
                                0,
                                0,
                                0,
                                -0.49939014157249173,
                                0,
                                -0.12167612652832788,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62104646298236177,
                                0,
                                0,
                                0.41086952267137627,
                                0,
                                0.65721812596758644,
                                0,
                                0,
                                0,
                                0,
                                -0.30278965402524921,
                                0,
                                0,
                                -0.19172929117648169,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.75565108770336886,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1315448969443076,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67118755889596138,
                                0,
                                0,
                                0,
                                0.44536251881456157,
                                -0.46497374406755043,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.049094254956605979,
                                0,
                                -0.1262300858467188,
                                0,
                                0,
                                0,
                                0.31504849396114676,
                                -0.0074169430587030238,
                                0,
                                0,
                                0.058124611177431604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.099610047209055655,
                                0,
                                0,
                                0,
                                -0.40500603708231875,
                                0.018925996733711967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52839337896496719,
                                0,
                                -0.0078175894302502796,
                                0,
                                0,
                                0,
                                0.34240925048440329,
                                0.65253851395085349,
                                0,
                                0,
                                0,
                                0,
                                -1.1354691055256962,
                                0,
                                0,
                                -0.41406678474764647,
                                0,
                                0.4549364233578278,
                                0,
                                0,
                                0,
                                0,
                                -0.50081829831046099,
                                0,
                                0,
                                -0.73130320522196512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28359215187353781,
                                0,
                                0,
                                0,
                                0,
                                -0.40139299122989147,
                                0,
                                -0.45077760541740403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23353826350127296,
                                0.28152970161169505,
                                0,
                                0,
                                0,
                                0,
                                0.64566024419118351,
                                0,
                                0.29155955259242078,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17794916526141039,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.053143603002372093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2433443242234202,
                                0,
                                -0.19459925263740083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29141860868497421,
                                0.29735816602323872,
                                0,
                                0,
                                0,
                                0,
                                0.15929279976851932,
                                0,
                                -0.83916255296249231,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29340429354581216,
                                0,
                                0,
                                0,
                                0,
                                -0.89022612866622319,
                                0,
                                0,
                                0.00069832376055801472,
                                0,
                                -1.0291014978952135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.090932019167344877,
                                0,
                                -0.50274081538448023,
                                0,
                                0.16712511294903926,
                                0,
                                0.15377700305252315,
                                0,
                                0,
                                0,
                                0,
                                0.54742144355927613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14182031274795642,
                                0,
                                0,
                                0,
                                -0.054005059159624835,
                                -0.14465395806321601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4772787338087443,
                                0,
                                -0.57583422778897686,
                                0,
                                0,
                                0,
                                0.24183460671748158,
                                0.19624327601152489,
                                0.6887365046542504,
                                0,
                                0,
                                0,
                                0,
                                0.21354692680543963,
                                0,
                                0,
                                1.2550468029447941,
                                0,
                                0.2984355839964497,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27671886328477519,
                                0,
                                0.51185940731448587,
                                0,
                                0.17800623328101994,
                                0,
                                -0.63281329745986081,
                                0,
                                0,
                                0,
                                0,
                                -0.13609071527211936,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64389415485904433,
                                0,
                                0,
                                0,
                                0.15821119024639471,
                                -0.70327545154087479,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15936583769018578,
                                0,
                                0.11146540536848039,
                                0,
                                0,
                                0,
                                0.07463272128467513,
                                0.062132464886549742,
                                -0.47270004965808382,
                                0,
                                0,
                                0,
                                0,
                                0.17887030565608197,
                                0,
                                0,
                                0.32304388257300104,
                                0,
                                -0.67766626496344018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.86783290619821218,
                                0,
                                0.46658710300569028,
                                0,
                                -0.68997544186500304,
                                0,
                                -0.19248650252625565,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37258411074810599,
                                0,
                                0,
                                -0.41193383727047672,
                                0,
                                0.71463572935930919,
                                0,
                                0,
                                0,
                                0,
                                -1.0038889742727186,
                                0,
                                0,
                                0.61465548221891819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2298229712587008,
                                0,
                                0,
                                0,
                                0.66442305009196567,
                                0,
                                0,
                                0,
                                0,
                                -0.103538199535153,
                                0,
                                0,
                                -0.78819896916271825,
                                0,
                                0.28149721362497948,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23569247500767199,
                                0,
                                -0.1738894923700203,
                                0,
                                0.11412055487272088,
                                0,
                                -0.76274344172528163,
                                0,
                                0,
                                0,
                                0,
                                0.77023104414895438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1120584996920897,
                                0,
                                0,
                                0,
                                0.09945603818120774,
                                -0.12042772387802814,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.115211511421554,
                                0,
                                0.58893175057415237,
                                0,
                                0,
                                0,
                                -0.019718266290129918,
                                -0.096382476846033321,
                                0,
                                0,
                                -0.19610372587477481,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.045024180607021985,
                                0,
                                0,
                                0,
                                0.29021006477333677,
                                0.15749726238163986,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54076589914283757,
                                0,
                                0.45322327057171308,
                                0,
                                0,
                                0,
                                0.11580908614076765,
                                0.58244145406126446,
                                -0.72601122516803185,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.042647063682284846,
                                0.61699172648413836,
                                0,
                                0,
                                0.050742446381128625,
                                0,
                                -0.69392460441657389,
                                -0.73996019704814708,
                                0.2710513302963154,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.050902575352094914,
                                0,
                                0,
                                0.54480693280496717,
                                0,
                                0,
                                0,
                                -0.31508501692957797,
                                0,
                                0,
                                0,
                                0,
                                -0.28429658557999382,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24776426597989235,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66769685253615818,
                                0.12600028221571988,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52506865388870527,
                                0.61453773462189876,
                                0.12217842073109103,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39305143412524679,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15808332674995745,
                                0.34634847758452764,
                                0,
                                0.006085735489077454,
                                0,
                                -0.17956793358264084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66900564883882541,
                                0.44412872011296523,
                                -0.048684189543360873,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.014179781090990252,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24381056609088181,
                                0.35719482827963744,
                                0,
                                -0.070415626927426533,
                                0,
                                0.40077401024320791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15658834933462551,
                                -0.3403010458338076,
                                -0.66522590067098486,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49403131161988501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.084578321630213782,
                                0.18822911182404489,
                                0,
                                0.025112961107280278,
                                0,
                                0.36037272292622208,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.012976086463587295,
                                0,
                                0,
                                0,
                                0.61814636280509583,
                                0,
                                0,
                                0,
                                0,
                                -0.04171305780218415,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14754416719412439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17650049815184096,
                                0.750376578138508,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63291439496057678,
                                0,
                                0,
                                0.10087147724775644,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0138949662729722,
                                0,
                                -0.050130182816727514,
                                0,
                                0.37893064316843111,
                                0,
                                0,
                                0.70007754737648653,
                                0,
                                0,
                                0.72334030658063098,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65460148112119854,
                                -0.89424338498714939,
                                0,
                                0,
                                -0.76123694763043859,
                                0,
                                -0.7642312173950595,
                                -0.34951375322465883,
                                -0.10496097811877504,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.090786673879509727,
                                0,
                                0.14466919151770652,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71812662169266095,
                                -0.086126770531172625,
                                0,
                                0,
                                0.54424741825031742,
                                0,
                                0.090214249871648611,
                                -0.098511945826734615,
                                0.6058112367260684,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0420654268260758,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30709816025730341,
                                0,
                                0,
                                -0.39793442084046543,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26246943429585701,
                                0,
                                1.2199671520585653,
                                0,
                                -0.91184872680559059,
                                0,
                                0,
                                -0.63731791942924654,
                                0,
                                0,
                                0,
                                -0.3752801961976357,
                                0,
                                0,
                                0,
                                -0.38147320987697519,
                                0,
                                0,
                                0,
                                0,
                                -0.3766473671016195,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71773527707083185,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21160259159644751,
                                0.10890427274061587,
                                0,
                                0,
                                0,
                                0.25202982456427253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7096456137868371,
                                -0.79980051310603217,
                                0,
                                0,
                                1.1156236820038883,
                                0,
                                -0.53599490257878812,
                                -0.37727666901874485,
                                -0.29286687630805408,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34163811145526868,
                                0,
                                0,
                                0,
                                0.18037144854825127,
                                0.015625111779103293,
                                0.030247151449841331,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.04740961536901668,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47589253414936089,
                                -0.36431697691934994,
                                0,
                                -0.7545649591434469,
                                0,
                                0.18838947245618268,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.83881438547139076,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45826394887753191,
                                0.35352516021393587,
                                0,
                                0,
                                -0.059497668160081493,
                                0,
                                -0.50261029418157954,
                                0.22733569473249485,
                                1.0077928162633829,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30423337198813377,
                                0,
                                0.78531086893505386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0143000951999659,
                                0.26184333408107902,
                                0,
                                0,
                                -0.24883782042633754,
                                0,
                                0.57179252842402739,
                                -0.14834190218882859,
                                -0.39174712486987756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47579641786397409,
                                0,
                                -0.48796238423830596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48850616562918003,
                                -0.54236454620755215,
                                0,
                                0,
                                -0.079285832238918025,
                                0,
                                0.72934594552140342,
                                -0.5996009271524696,
                                0.8771145304722312,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71218910461583584,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29194866075483938,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2356183749897578,
                                0,
                                0.74795379862213596,
                                0,
                                0,
                                0,
                                -0.013717661162838873,
                                0,
                                0,
                                0,
                                0,
                                0.025805733597855339,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51960830419439763,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41193232126160678,
                                -0.0054752100107933813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31188244896702,
                                0.027933583632383352,
                                -0.33281462583671473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1502371773660261,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49600079341273501,
                                -0.20924600184206971,
                                0,
                                0.1483504662195273,
                                0,
                                -0.67587257017690616,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32924591647946938,
                                0.18399542101398653,
                                -0.23824974206126906,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54263266692863132,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38393349835711499,
                                -0.15810532817474759,
                                0,
                                0.49856337584425581,
                                0,
                                0.29250982039232137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0168806654089435,
                                0,
                                0,
                                -0.092031105243253031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41839463745151922,
                                0,
                                -0.068745566815790138,
                                0,
                                -1.3860277789985209,
                                0,
                                0,
                                0.58313558021312661,
                                0,
                                0,
                                0,
                                0,
                                0.046197226621479917,
                                -0.52322058419096784,
                                0.45401542846995491,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.030091559509998436,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51990109733310452,
                                0.48409000309044681,
                                0,
                                0.11013146507562765,
                                0,
                                -0.017358098653222187,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50536241047336083,
                                0,
                                0,
                                0.98987645386370704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.066720935559587,
                                0,
                                0.753906794397049,
                                0,
                                0.4659336674143808,
                                0,
                                0,
                                0.26463902657668453,
                                0,
                                0,
                                0,
                                0,
                                0.10896265730478603,
                                -0.025489743292391093,
                                -0.40694393968943621,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53015844123739342,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13498149459190389,
                                0.53025768578983723,
                                0,
                                -0.37723126164830328,
                                0,
                                -0.31481649805643752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6698147063517389,
                                0,
                                0,
                                1.3849757926978095,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71088175025191291,
                                0,
                                0.17298112830585771,
                                0,
                                -0.68858968355506545,
                                0,
                                0,
                                0.46109212231134145,
                                0,
                                0,
                                0,
                                0.051800436492193028,
                                0,
                                0,
                                0,
                                0.5538154453585924,
                                0,
                                0,
                                0,
                                0,
                                0.034647955933389318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29790053053030507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4618252266937467,
                                -0.62239651373553828,
                                0,
                                0,
                                0,
                                0,
                                0.0079769289537361121,
                                0,
                                0,
                                0,
                                0.25728384064678644,
                                0,
                                0,
                                0,
                                0,
                                -0.87960548904317415,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20727311306698395,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30867791172097281,
                                -0.14761904012262608,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43982593519117141,
                                0,
                                0,
                                -0.85882796592874089,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12743771630312059,
                                0,
                                0.60393374934473354,
                                0,
                                0.15012001877899189,
                                0,
                                0,
                                1.2870084611781816,
                                0,
                                0,
                                0.67101250023399428,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30947238772884822,
                                0.73308764230938817,
                                0,
                                0,
                                0.29833281809738288,
                                0,
                                0.56819232841530276,
                                -0.72923857945712112,
                                -0.13105830904238694,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46258425983322754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.022911658743548918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43299300161318793,
                                0.35977921432485976,
                                0,
                                0,
                                0,
                                0.05094270223503769,
                                0.5669865541432153,
                                -0.0076919353803946607,
                                0,
                                0,
                                0,
                                0,
                                0.012866339629717796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11819891119764955,
                                0,
                                0.24097745277522617,
                                0,
                                0,
                                0,
                                0.68863936972107975,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53649599625277389,
                                0.87520542926732547,
                                0,
                                0,
                                0,
                                0,
                                -0.47832522871077404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68697015468044564,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.026277968435022496,
                                0.40675711896552991,
                                0,
                                0.12281616392416031,
                                -0.50964986325646333,
                                0,
                                -0.6616118921566142,
                                -0.084908171092965862,
                                0,
                                0,
                                0,
                                0,
                                -0.050102722554062978,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48707962487677586,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60255770543561871,
                                0.80363879872662869,
                                0,
                                0.52324537506882796,
                                -0.38547546832558949,
                                0,
                                0,
                                0,
                                -0.45780169217063188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6917924733939167,
                                0,
                                0,
                                -0.15687699442131353,
                                0,
                                0,
                                0,
                                0.15682546746032958,
                                0,
                                0,
                                -0.42392108075852875,
                                0,
                                0,
                                0.28797062882686275,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25105096864997878,
                                0,
                                0,
                                0,
                                -0.36008052948890668,
                                0.11367800444086855,
                                0.81600623971190778,
                                0,
                                0,
                                0,
                                0,
                                0.17008474257284528,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12700665765175548,
                                0,
                                -0.23143769953637949,
                                0,
                                0,
                                0,
                                0.17292666645099961,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19297169845302348,
                                0,
                                0,
                                0,
                                -0.024727767150003216,
                                -0.086850461949043264,
                                -0.012377138229757632,
                                0,
                                0,
                                0,
                                0,
                                -0.69430035996666584,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6234564072435953,
                                0,
                                0.16890027257616225,
                                0,
                                0,
                                0,
                                0.23489589433856484,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40725866499358854,
                                0,
                                0,
                                0,
                                -0.21941971157408266,
                                -0.44990114017991623,
                                -0.16320815645538389,
                                0,
                                0,
                                0,
                                0,
                                -0.12287465721032204,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52797530963159978,
                                0,
                                -0.010135799654376221,
                                0,
                                0,
                                0,
                                0.51282412998215177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62256763121913039,
                                0.22179030127371452,
                                0,
                                0,
                                0,
                                0,
                                0.081461754439240586,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1101466407684943,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23241644494376779,
                                -0.26767970558056953,
                                0,
                                -0.3253511560178029,
                                -0.41772694222504636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36291109210223088,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34586876578815201,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27521758846577488,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32327956963649307,
                                0,
                                0,
                                -0.75050748905246834,
                                0,
                                0,
                                0,
                                0.36104334023267781,
                                0,
                                0,
                                -0.2291587882369486,
                                0,
                                0,
                                0.27132648963617417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4216077156480102,
                                0,
                                0,
                                -0.47751667484927229,
                                0.80611634985122993,
                                -0.90445482576308189,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17172690219944273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37650826461886144,
                                0,
                                0,
                                -0.28166271983747121,
                                0,
                                0,
                                0,
                                0.42672075930637665,
                                -0.21779912163408044,
                                -0.11008432509243829,
                                0,
                                0,
                                0,
                                0,
                                0.61312776153958848,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43434743237037726,
                                0,
                                0.080885210784069295,
                                0,
                                0,
                                0,
                                0.32847332998927881,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0092039971249944924,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37575215712471843,
                                0,
                                0,
                                -0.21877716353279053,
                                0,
                                0,
                                0,
                                0.49886910528120665,
                                0,
                                0,
                                0.71438681175906416,
                                0,
                                0,
                                -0.22725152265769155,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0885237637542748,
                                0,
                                0,
                                -0.57751593230590592,
                                -0.70652578764105411,
                                0.00023539521990748654,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23432836866954462,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31026310408249813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.054202784427075046,
                                0,
                                0,
                                -0.56655857703241119,
                                0.68627418560783726,
                                1.072085450211163,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.037896091410723601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40359937491112907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29303334815352339,
                                0,
                                0,
                                0.8568606736123181,
                                -0.15812078167710758,
                                -0.078638984450377272,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.787631755521081,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64974811823129586,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71632015828738438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48969606114532976,
                                0,
                                0,
                                -0.10272891342548132,
                                0,
                                0,
                                0,
                                -0.22034170135468467,
                                0,
                                0,
                                -0.25575821024186213,
                                0,
                                0,
                                -0.35009604598496646,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1502372950162395,
                                0.15767856207017253,
                                0,
                                0,
                                0,
                                0,
                                -0.2624818766500201,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46166324079277338,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.079346432948911888,
                                -0.84244812286401782,
                                0,
                                0.66384440942562528,
                                -0.41149588588113672,
                                -0.18093252280798441,
                                0,
                                0,
                                0,
                                -0.72355070729554938,
                                0.193925007182741,
                                -0.36764388724456515,
                                0,
                                0,
                                0,
                                0,
                                0.2915337509556048,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20401585997404248,
                                0,
                                0.36272281726547051,
                                0,
                                0,
                                0,
                                -0.11307793193698301,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19315921009078171,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.086950936846974122,
                                0,
                                0,
                                0.53224106753682177,
                                0,
                                0,
                                0,
                                0.73882630263168347,
                                0,
                                0,
                                -0.34101380293941941,
                                0,
                                0,
                                -0.098457000310763626,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68128392111172631,
                                0,
                                0,
                                0,
                                0.26106943429838825,
                                0.60539909388505553,
                                -0.15178839431990224,
                                0,
                                0,
                                0,
                                0,
                                -0.11040354608165684,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14881121861578853,
                                0,
                                -0.16449523300331759,
                                0,
                                0,
                                0,
                                -0.12944028093512233,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17884149853561043,
                                0,
                                0,
                                0.21198995896344691,
                                0.25269122945873734,
                                0.23165634116512229,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1770252875068181,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57383638698737682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4051704906208673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16840757793957642,
                                0,
                                0,
                                -0.26538818094957695,
                                0,
                                0,
                                0,
                                0.042051447170436601,
                                0,
                                0,
                                -0.2751835284781553,
                                0,
                                0,
                                -0.81212719205801231,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.061453258007128114,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39992490655066215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16797733401330631,
                                0,
                                0,
                                0,
                                -0.21264265588241504,
                                0.064016336812891317,
                                -0.37008681668960547,
                                0,
                                0,
                                0,
                                0,
                                0.025454734527636802,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22364607100626965,
                                0,
                                -0.8334071518813243,
                                0,
                                0,
                                0,
                                0.2006773118647705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42543284777617069,
                                -0.79253513665728903,
                                0,
                                0,
                                0,
                                0,
                                -0.52561043199344892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35045423606340337,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31615794847163275,
                                0.018911872753899023,
                                0,
                                -0.55712417300032968,
                                -0.7078917852908948,
                                0,
                                -0.5035021594683059,
                                0.2793666499650585,
                                0,
                                0,
                                0,
                                0,
                                -0.3495144901122319,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65023608219477791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15342499873420254,
                                0.044020249445540609,
                                0,
                                -0.85963299069856525,
                                0.37346088639774033,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74203009194520719,
                                0,
                                0,
                                -0.53069184491412236,
                                -0.46279239888429125,
                                -0.33373635410920449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73652869271723043,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39369041707647856,
                                0,
                                0,
                                0,
                                -0.13540761676239915,
                                -0.13246815916468901,
                                0,
                                0,
                                0,
                                0,
                                -0.72988427517281274,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45627981599892853,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.92214128626626668,
                                0.15628110861867955,
                                0,
                                0.11100598600658784,
                                -0.060402118591400045,
                                0,
                                0.15240829478910928,
                                0.31876602983502755,
                                0,
                                0,
                                0,
                                0,
                                0.43188789152463203,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47140620560944746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.86402911333921661,
                                0.022754849326256002,
                                0,
                                -0.10504697790637385,
                                -0.54684864687072932,
                                -0.37398292336730365,
                                0,
                                -0.28371658735846661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76314348332048776,
                                -0.42414556592623026,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.020585291440011227,
                                0,
                                0,
                                0,
                                -0.13011717655338034,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46286715564273323,
                                0,
                                0,
                                0,
                                0.28672844482167681,
                                0,
                                0.3101738421048672,
                                -0.3064332799245631,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1503576095607882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17334331305330319,
                                0.17314087429386638,
                                -0.6563524590504376,
                                0.16595350813995968,
                                0,
                                0.52290113419299555,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21667542498107803,
                                0.060696092655038877,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50821309777015555,
                                0,
                                0,
                                0,
                                -0.62459669291172537,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5910339380721491,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33251210546690851,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16352177367334511,
                                0,
                                0,
                                0,
                                0,
                                -0.73423050548690105,
                                0,
                                0,
                                0,
                                0.47639978120155368,
                                0,
                                -0.77497892529649381,
                                0,
                                0.26200694750147691,
                                0,
                                0.25386927796788394,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.030449196932262147,
                                -0.74665582339177916,
                                0,
                                0,
                                0,
                                0,
                                0.35573298627514877,
                                0,
                                0,
                                0,
                                -0.53875063027701675,
                                0,
                                0.30600027802541768,
                                -0.13431437388294598,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25489958129247647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17764523063251697,
                                0.60268843962322949,
                                -0.1084449164490273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87397960501323702,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53369207848298839,
                                0,
                                0.40508633682519951,
                                0,
                                0.52829068101939136,
                                0,
                                0,
                                0,
                                1.3059675618038298,
                                0,
                                0,
                                0.38421442320225274,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27592420218388186,
                                0,
                                0,
                                0,
                                0.12628551028192972,
                                0,
                                0.31976852019669116,
                                -0.24440051073438115,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48323580784617631,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61774106581730037,
                                -0.28464877574273578,
                                -0.2231333513223322,
                                0,
                                0.24066711813514788,
                                0,
                                0,
                                0,
                                0.20996921317927392,
                                0,
                                -0.66641695897762432,
                                -0.57135876493995741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28253513925963847,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18602140827546726,
                                0.065555607573219016,
                                -0.09328590108454228,
                                0,
                                0,
                                0,
                                0,
                                -0.61968574296894896,
                                0,
                                0,
                                0,
                                0,
                                0.072159132181091046,
                                0,
                                0,
                                0,
                                -0.38764047822770303,
                                0,
                                0.34644089943772122,
                                0,
                                0.26584560287225567,
                                0,
                                -0.76077409107370275,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36459686013381154,
                                -0.97367919299776984,
                                0,
                                0,
                                0,
                                0.69264852413681899,
                                0,
                                -0.04258440230804468,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48485452458270784,
                                0.1336729237783976,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18565182004290892,
                                0,
                                0,
                                0,
                                0.48063045247478797,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11761645548753465,
                                0,
                                -0.60789904467527367,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.070074816321422387,
                                0.69971847576309465,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24852230332896252,
                                0,
                                0,
                                0,
                                -0.24565292675397882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13760874461194389,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3925737914436202,
                                0,
                                -0.42372147476378003,
                                0,
                                -1.1081520018076254,
                                0,
                                0,
                                0,
                                0.052781579125301542,
                                0,
                                0,
                                0.28449133705525909,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.054233885263835074,
                                0,
                                0,
                                0,
                                0,
                                0.25476062538692873,
                                0,
                                0,
                                0,
                                0.086958015240034672,
                                0,
                                0.4654975258904282,
                                0,
                                1.0726085586684064,
                                0,
                                -0.038232463076252096,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.91124717120906318,
                                -0.036141645573821157,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85292075512039844,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30746609926828389,
                                0,
                                0.065087496517376831,
                                0,
                                0.04714292230376585,
                                0,
                                0,
                                0,
                                0.86096895727412637,
                                0,
                                0,
                                -0.46468676544867593,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37535973446370541,
                                0,
                                0,
                                0,
                                0,
                                0.67553541630286595,
                                0,
                                0,
                                0,
                                0.45331708467036275,
                                0,
                                0.76152465135772451,
                                0,
                                0.10990061709567775,
                                0,
                                0.14358862233063596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47831993293478187,
                                -0.41831475111183697,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24545321407715076,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27097960491252382,
                                0,
                                0.40224425987289186,
                                0,
                                -0.20264485452230399,
                                0,
                                0,
                                0,
                                0.1639834536190648,
                                0,
                                0,
                                -0.98339221982602121,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58475735743877466,
                                0,
                                0,
                                0,
                                0,
                                -0.74149448878607749,
                                0,
                                0,
                                0,
                                0.052993287018451907,
                                0,
                                0.16418753575613035,
                                0,
                                -0.51098802103447583,
                                0,
                                -0.79821552402440832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17392036374127762,
                                -0.10570938882065369,
                                0,
                                0,
                                0,
                                0.0496655967371466,
                                0,
                                -0.36782391324178515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3458664296380195,
                                -0.487612400735004,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70209199590405147,
                                0,
                                0,
                                0,
                                0.10916174299911555,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.041982695755417077,
                                0,
                                0,
                                0,
                                0,
                                0.9477859386296098,
                                0,
                                0,
                                0,
                                0.35197624584771581,
                                0,
                                -0.33790367626483508,
                                0,
                                -0.56038230172893833,
                                0,
                                0.16553202141329296,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87152160266929179,
                                -0.61612103968544096,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32435328753982479,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.9715395237637785,
                                0,
                                0.34836932879398652,
                                0,
                                0.30892937916175867,
                                0,
                                0,
                                0,
                                0.083929635030243727,
                                0,
                                0,
                                0.12109533690002927,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67217286913055463,
                                0,
                                0,
                                0,
                                -0.17818307875185688,
                                0,
                                0.012090361520379844,
                                -0.13660935952095693,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19886693501528724,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57014509009549696,
                                0.014294867037730558,
                                0.36442873881581417,
                                0.5801154420251744,
                                0,
                                -0.37340352291830947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10509903440747023,
                                -0.26678881913468905,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39004177825135528,
                                0,
                                0,
                                0,
                                -0.53822041318217484,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10920534052274269,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43189500673399184,
                                0,
                                -1.1047003500516026,
                                0,
                                0.28983528106695006,
                                0,
                                0,
                                0,
                                0.087247534543323929,
                                0,
                                0,
                                -0.73384231439002234,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37286758131238673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1549593001383873,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68578299835756518,
                                0,
                                0,
                                0,
                                0,
                                0.038400203734709142,
                                0,
                                0,
                                0,
                                -0.76906606189856763,
                                0,
                                -0.73825006378902303,
                                0,
                                0.13637618199642676,
                                0,
                                0.75401682104982393,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35973029333256112,
                                -0.64776932436634638,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50538119889951227,
                                0,
                                0,
                                0,
                                0,
                                0.78980750645430231,
                                0,
                                0,
                                0,
                                -0.16129649885765315,
                                0,
                                -0.81086844969761662,
                                0,
                                0.58295061213958765,
                                0,
                                -0.94854081843909044,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43359387170357805,
                                0.1698068978305953,
                                0,
                                0,
                                0,
                                0,
                                0.097670948350362441,
                                0,
                                0,
                                0,
                                -0.38398204507755423,
                                0,
                                0.19434405171466379,
                                -0.21172174908974514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46615536289223519,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14727000931068659,
                                -0.71656334789659137,
                                -0.089275729554972552,
                                0,
                                -0.18042776724868934,
                                0,
                                0,
                                0,
                                -0.48342314570434836,
                                0,
                                -0.47117286503002181,
                                0.33768520885223108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19271163183644735,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16227897270841884,
                                -0.080500087401893017,
                                -0.57250346015086429,
                                0,
                                -0.17675704302650508,
                                0,
                                0,
                                0,
                                -0.39320490640103573,
                                0,
                                -0.062232562066359437,
                                -0.56952289644775889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55234879248735835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38613201723461432,
                                0.036315015255819288,
                                0.17438957633455451};

const double rot_26_2[32]
    = {2.1906370205120904,    -0.91005517316846274, 1.0527697316534987,   -1.8068162381010011, -0.86041479880143901,
       0.50959432297022267,   0.50959432297022245,  0.86041479880143878,  0.54271640003790944, -0.83991601314053499,
       -0.83991601314053499,  -0.54271640003790989, -0.22140904683017937, 0.9751810262621764,  0.97518102626217629,
       0.22140904683017909,   0.098255259637401865, 0.9951612452027998,   0.9951612452027998,  -0.098255259637401893,
       0.87433651819942892,   -0.48532015509650706, 0.48532015509650872,  0.87433651819943048, -0.98056288561167682,
       0.19620506456486203,   0.19620506456486198,  0.9805628856116767,   0.99523952612314348, 0.097459148581243382,
       -0.097459148581243493, 0.99523952612314348};

const double rot_25_50[25000] = {-0.87839241030592807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6042292849158426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25022768305124854,
                                 0.19333245096980728,
                                 0.18946380673977392,
                                 0,
                                 0,
                                 0.43553165962173013,
                                 0,
                                 0.48079035407079307,
                                 0,
                                 0.19728807675139118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014455597641158197,
                                 0,
                                 0,
                                 0,
                                 -0.56308369660744939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41064303290867044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0887513166200569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042900243947222638,
                                 0,
                                 0.89716442175725131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2182816576951796,
                                 0,
                                 -0.072289142185572836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89073818714519293,
                                 0,
                                 -0.59010519734126399,
                                 0,
                                 0,
                                 0,
                                 0.52672504814141075,
                                 0,
                                 0.44257838236955976,
                                 -0.01477175072802794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18942237186405861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32853881111209138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059195942087463954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30938730088380428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53237547616570469,
                                 0,
                                 0,
                                 0,
                                 -0.25005170344158528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18305271632655046,
                                 0,
                                 0,
                                 0,
                                 -0.44123078165156387,
                                 0.60413041892437591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17629044207400335,
                                 0,
                                 0,
                                 0,
                                 -0.18153206647203249,
                                 0.51491076798614599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02577387491932992,
                                 0,
                                 0,
                                 0.081694230982298374,
                                 0,
                                 0,
                                 0,
                                 -0.088341002871604901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028186723909908201,
                                 0,
                                 0.015172197859991278,
                                 -0.38376236309325668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30051846207099941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29407789794393147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70961358721410783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063790550578618599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40900846944014019,
                                 0,
                                 0,
                                 -0.21462297761964227,
                                 0,
                                 0.69829702443204877,
                                 -0.22290078421534709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43621426201241897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052986443657405728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05387938184104283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2454626390427192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40048488485250094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69348152568891019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13820870940170504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2858681640411056,
                                 0,
                                 -0.50842695216500255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36484815646500846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1632451408090147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058749432503488914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33886732031711375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58034696239496086,
                                 -0.26753043906736163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87548165745060702,
                                 0,
                                 0.81949921484245181,
                                 0,
                                 0,
                                 0,
                                 0.65921794196973527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052419855006941102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20294916322508388,
                                 -1.2861805513075326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25542110687541308,
                                 0,
                                 -0.26669130139115033,
                                 0,
                                 0,
                                 0,
                                 -0.08283528289601827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.016575028443909484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94917524619345794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36069013909928793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11031884070160231,
                                 0,
                                 0.18295334787680734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53875211970036352,
                                 0,
                                 -0.14392815969708289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68446394004156397,
                                 0,
                                 -0.21011566660463527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35969412639208814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56626034350530174,
                                 0,
                                 0,
                                 0,
                                 0.089448993164324961,
                                 0.031687181131292277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60807444052877269,
                                 0,
                                 0,
                                 0,
                                 -0.19736048045697446,
                                 0.17208103974338204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29487328494949139,
                                 0,
                                 0,
                                 -0.020935525862101317,
                                 0,
                                 0,
                                 0,
                                 -0.12352343848982551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03265587112551932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11513848535545146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16464938455505654,
                                 0,
                                 -0.5034957565928635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83939819668143312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02167934357091527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52173186666596083,
                                 0,
                                 -0.23704346750263944,
                                 -0.6440831461374612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24026548046682147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.006434075981624432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35443846984543714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2186302431310484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1599013574852966,
                                 0.26109711489525605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19396090455347201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24030031172597208,
                                 -0.30359329443528449,
                                 -1.1279596945113752,
                                 0,
                                 0,
                                 -0.020024207565286362,
                                 0,
                                 -0.21865293145528411,
                                 0,
                                 0.3917467871905807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25946186366125934,
                                 0,
                                 0,
                                 0,
                                 -0.2669407909461996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64068678614659991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30198073698632999,
                                 0,
                                 0,
                                 0,
                                 0.22213493113130958,
                                 -0.18248906095469791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038196139610377204,
                                 0,
                                 0,
                                 0,
                                 0.07353947097721833,
                                 0.14619723566866455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046561690308293921,
                                 0,
                                 0,
                                 -0.42320679201490985,
                                 0,
                                 0,
                                 0,
                                 0.45405867588636184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.514608007888957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24137921063071785,
                                 0,
                                 0,
                                 0,
                                 -0.19085420866566036,
                                 -0.19505278650107935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079305911147001973,
                                 0,
                                 0,
                                 0,
                                 -0.12997325497574569,
                                 -0.47092803876507261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21946438688435468,
                                 0,
                                 0,
                                 0.51928409323952363,
                                 0,
                                 0,
                                 0,
                                 -0.19916695899554948,
                                 0,
                                 0,
                                 0,
                                 0.43293353457207762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42518216364001304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44103501792004912,
                                 0,
                                 0.44646319943234436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70470644113736025,
                                 0,
                                 0.61349469169533566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63131871007104901,
                                 0,
                                 0.56885774681369816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35272751004069924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47217710092839027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44307295751373466,
                                 0,
                                 0.043562912849575294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14709409780835214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65786323985566209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17789925771153298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041131781319796223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1198199639736834,
                                 0,
                                 -0.20918894200825913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30678915907805648,
                                 0,
                                 -0.28838963581873933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47815353955654238,
                                 0,
                                 -0.20549325329222715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2705750094184689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7487967036088774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21014199325154764,
                                 0,
                                 -0.16175836763539039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071354166090155408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53914359598946682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82676459666266156,
                                 -0.76988349396214328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67127662631023066,
                                 0,
                                 -0.46965439170743284,
                                 0,
                                 0,
                                 0,
                                 1.241920264893581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24495763290556866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31523710459148069,
                                 0,
                                 -0.19138043767881088,
                                 -0.51408388301511498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45392684344782558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11071193703592405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084300685116370455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61180195797297166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0013797432166346713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21444838317387716,
                                 -0.55990067417736544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60880660332139014,
                                 0,
                                 0.98068702708892963,
                                 0,
                                 0,
                                 0,
                                 -0.35731126954230119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67500048975027105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48387964129385108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78430181955215461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11958087768306856,
                                 -0.36577060497461861,
                                 -0.60240307770142143,
                                 0,
                                 0,
                                 -0.23459383802165334,
                                 0,
                                 0.26809122799676943,
                                 0,
                                 -0.075096361595826569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39949538283676983,
                                 0,
                                 0,
                                 0,
                                 -1.0255659922867495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45062759417536563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32805838532974096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83131078910266432,
                                 -0.80959569233795603,
                                 0.33345543318719362,
                                 0,
                                 0,
                                 0.52813786032130128,
                                 0,
                                 -0.11906536808129758,
                                 0,
                                 -0.37510623760602341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081057196836179637,
                                 0,
                                 0,
                                 0,
                                 -0.069710578561157102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30111901648234679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010113374040591844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72528919987398843,
                                 0.72695973274920644,
                                 -0.16252379774703637,
                                 0,
                                 0,
                                 -0.038876950913843189,
                                 0,
                                 -0.0099639636512929286,
                                 0,
                                 -0.57932644288071056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19296372601253994,
                                 0,
                                 0,
                                 0,
                                 0.39093830778686572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.123069405610315,
                                 0.32927914273682068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53593577362392064,
                                 0,
                                 0.013432732301640826,
                                 0,
                                 0,
                                 0,
                                 0.24224526981458241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72674382797625203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46449269666611215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15728715315442354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29776407266847083,
                                 0,
                                 0.67800320238423506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35918568329209971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28660276638409166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22745697566691847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35504438127401627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39802338039707785,
                                 0.56952638399602196,
                                 0.033149632029845895,
                                 0,
                                 0,
                                 0.51517508796894695,
                                 0,
                                 -0.4957752095227913,
                                 0,
                                 -0.29747313297644157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48902565625164229,
                                 0,
                                 0,
                                 0,
                                 -0.60447632915171012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061438367149412254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074411472088437722,
                                 0,
                                 0,
                                 0,
                                 0.017960573146921954,
                                 0.20240003804351564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2708457522353922,
                                 0,
                                 0,
                                 0,
                                 0.53934549489708783,
                                 0.057935014185343942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24732210431219098,
                                 0,
                                 0,
                                 0.56289122768410471,
                                 0,
                                 0,
                                 0,
                                 0.45141742827713038,
                                 0,
                                 0,
                                 0.42446934246872542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42556213998904768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30880637180296161,
                                 -0.26318615151619434,
                                 0.23399158282971552,
                                 0,
                                 0,
                                 0.47154058582368308,
                                 0,
                                 0.41514748226118769,
                                 0,
                                 -0.17096686598533556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.98339541492546212,
                                 0,
                                 0,
                                 0,
                                 0.025290896278963259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24867189063891509,
                                 0,
                                 0.23775231473970171,
                                 -0.34262196436184489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44695498961909275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46131737265903883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16202186779348834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56759784041301309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056968781201319318,
                                 0.55302396783189578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14425632929910412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.98316356579100672,
                                 -0.13034188341970759,
                                 0.35176048260165493,
                                 0,
                                 0,
                                 -0.48103533985123698,
                                 0,
                                 -0.19253740099248848,
                                 0,
                                 0.58473062196305703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16475082174679856,
                                 0,
                                 0,
                                 0,
                                 -0.69180410741250176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14245687812300811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5040251965687832,
                                 0,
                                 0,
                                 0,
                                 -0.5985840151313081,
                                 -0.38957786757584645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32282888800855203,
                                 0,
                                 0,
                                 0,
                                 0.27984865149848032,
                                 0.075128949598678593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.097999647483237404,
                                 0,
                                 0,
                                 -0.12470352882560662,
                                 0,
                                 0,
                                 0,
                                 0.047517178672868331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091878689978441397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45965339685810103,
                                 0,
                                 0,
                                 0,
                                 -0.3907900195547499,
                                 -0.29573680142264913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5926935629087704,
                                 0,
                                 0,
                                 0,
                                 0.19913979979747448,
                                 0.14847633412724831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15983405175849139,
                                 0,
                                 0,
                                 -0.1438359610654521,
                                 0,
                                 0,
                                 0,
                                 -0.28438832081409016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32347483718481368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39906705615909221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74968875339943086,
                                 0,
                                 0.015563357153987031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08095705294509882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40899880796369464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5330804919326676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075122658201635037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32780231418363337,
                                 0,
                                 -0.1007515625305081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86362429072161528,
                                 0,
                                 -0.41499576842759078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18303736098449955,
                                 0,
                                 -0.3441518145454322,
                                 0,
                                 0,
                                 0,
                                 0.23340665048352641,
                                 0,
                                 -0.31446693683183885,
                                 0.053644567350772762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092337101323080623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56728835495054508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50339904535266478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30658291237283025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40744109093117309,
                                 0,
                                 0.53032558643217864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11787782689743029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37604811604023058,
                                 0,
                                 -0.62262809415499043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19312085779059179,
                                 0,
                                 0.14345427040098085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1100247865387749,
                                 0,
                                 -0.058575534409312568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30491542454976228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1288040693158832,
                                 0,
                                 0,
                                 0,
                                 0.17043753371232842,
                                 0.34524267650908969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034658911400157158,
                                 0,
                                 0,
                                 0,
                                 0.30785915367265576,
                                 -0.29149931878767305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49252807853524005,
                                 0,
                                 0,
                                 -0.23182260036854047,
                                 0,
                                 0,
                                 0,
                                 -0.51470249595062223,
                                 0,
                                 0,
                                 -0.88312077560745084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44996560365075339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2520829601151533,
                                 0.69748855169319324,
                                 0.08548191467752779,
                                 0,
                                 0,
                                 0.16049977107759528,
                                 0,
                                 -0.94053640648697523,
                                 0,
                                 0.65256287214682529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76979830018708895,
                                 0,
                                 0,
                                 0,
                                 0.21397769802150826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31733732476598137,
                                 0.10972815418108152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79464253404633034,
                                 0,
                                 0.13972789803050772,
                                 0,
                                 0,
                                 0,
                                 0.23960345216133139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.4245587049453212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048582765182724377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088237602295412373,
                                 0,
                                 0,
                                 0,
                                 -0.026830804627277702,
                                 0.22658536339785101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044460879532786213,
                                 0,
                                 0,
                                 0,
                                 0.59051776731135508,
                                 -0.1182735965185257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72098322717750252,
                                 0,
                                 0,
                                 -0.21786912899368971,
                                 0,
                                 0,
                                 0,
                                 -0.0763714821963562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5046833099945689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42799859382174937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23502968563208476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77627548025588899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1495012089840117,
                                 0.079006327259279224,
                                 -0.27562618151472174,
                                 0,
                                 0,
                                 0.6802954321675283,
                                 0,
                                 0.59204663779497513,
                                 0,
                                 0.39117208942890624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20873976820195839,
                                 0,
                                 0,
                                 0,
                                 0.35434230069580513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14976204256639866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95519641139074762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044817757322094975,
                                 0,
                                 0.44679079853021852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15618378209615241,
                                 0,
                                 -0.4443258349808441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2765002594539277,
                                 0,
                                 -0.36355209093103802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070351200152087748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03389046553646835,
                                 0,
                                 0,
                                 0,
                                 -0.41283644295769051,
                                 0.33458053437445578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24367847727367759,
                                 0,
                                 0,
                                 0,
                                 -0.23117064327131359,
                                 -0.57628259052399478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057732527860499497,
                                 0,
                                 0,
                                 -0.29972126162643598,
                                 0,
                                 0,
                                 0,
                                 0.41645829585275812,
                                 0,
                                 0,
                                 0,
                                 0.27916709947906881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025223037057570563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28562071096540398,
                                 0,
                                 -0.19586246878691313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11537790285996034,
                                 0,
                                 0.68376066375615685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31121743656529599,
                                 0,
                                 -0.94647389060051523,
                                 0,
                                 0,
                                 0,
                                 -0.43336850744313915,
                                 0,
                                 -0.26085197067358673,
                                 -0.05857129387372724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45984013882677183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50581078478711294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27865119876146505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041196443429855512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44054085949037591,
                                 -0.26711375227151957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069466849585635329,
                                 0.3068179254417745,
                                 -0.3734487651805995,
                                 0,
                                 0,
                                 0.40118544443488313,
                                 0,
                                 0,
                                 0,
                                 -0.43110057521339318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19728618732230702,
                                 -0.28813004934412745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4450637904647668,
                                 0,
                                 0.15298160401480498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13216006307766562,
                                 0,
                                 0.84961857169455945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012942122217783403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27261074191812729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31205188655596983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29802936989365647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22808669833697626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35096678420746275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33676683334806568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10554632497107982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12724546569670497,
                                 0,
                                 -0.41858380557763386,
                                 0,
                                 0,
                                 0,
                                 -0.70235057740111029,
                                 0,
                                 0,
                                 -0.1246864197044972,
                                 0,
                                 0,
                                 0.17179538326621582,
                                 0,
                                 -0.14726714395958301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85367369945129068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45344842202286567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11898001147166741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016377878334021809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88247542339376728,
                                 -0.094687892628539327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61295948100498387,
                                 0,
                                 0,
                                 0,
                                 0.21705866603371757,
                                 0,
                                 0.0012780440666300963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58401274998715147,
                                 0.072506461535923716,
                                 0,
                                 -0.69274131921178339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33428587335977161,
                                 -0.78574373490937732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35454687298986159,
                                 0,
                                 0,
                                 0,
                                 -0.58548916228484249,
                                 0,
                                 0.13235382517530439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37884589814581765,
                                 -0.89675282323018668,
                                 0,
                                 0.31052069966251516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36186204671729622,
                                 0,
                                 -0.31981745878537443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6030444589249897,
                                 0,
                                 0,
                                 0,
                                 -0.29649761841107947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98529653945061202,
                                 0,
                                 0,
                                 0,
                                 0.77364327761883711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68912076755272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19902191003998032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09392233473033397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16790036486480439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50789178883855779,
                                 0,
                                 0.077394383368498215,
                                 0,
                                 0,
                                 0,
                                 0.34302416034052446,
                                 0,
                                 0,
                                 0.25861433688934177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.4642142904950517,
                                 0,
                                 0.1782272619761282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43009661901896223,
                                 0,
                                 0,
                                 0,
                                 0.76691792281859517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13869631935366789,
                                 0,
                                 0,
                                 0,
                                 0.22178169353931321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46700089483527307,
                                 0,
                                 0.32010774379900608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47660282621714561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65580448690418913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14654245215702577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027142720882993861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41166934962596713,
                                 -0.53090847765752147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87910777341286195,
                                 0.20640929275154651,
                                 0,
                                 0,
                                 0,
                                 0.31085495999801127,
                                 0,
                                 0,
                                 0.31864994502783262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12355289804430591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032248463305757924,
                                 0,
                                 0,
                                 0,
                                 -0.053421747466424807,
                                 0,
                                 0.35773921336071268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58431133261599566,
                                 0.4338949613216796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12221298728962668,
                                 0.17018351588718517,
                                 0,
                                 0,
                                 0,
                                 0.52865621213908409,
                                 0,
                                 0,
                                 -1.0402656030002264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30275421560748755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16931692855511332,
                                 0,
                                 0,
                                 0,
                                 0.44113071467024723,
                                 0,
                                 0.09551584026438073,
                                 0,
                                 0,
                                 -0.08994821609495493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55326970875171499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090805902549501577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014352257010854221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47483576710716902,
                                 0,
                                 0.43404334007914575,
                                 0,
                                 0,
                                 0,
                                 -0.41102257586674984,
                                 0,
                                 0,
                                 -0.3074866890070771,
                                 0,
                                 -0.37646456856190774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13339933842977197,
                                 -0.096729107206998566,
                                 0.13162140672219624,
                                 0,
                                 0,
                                 0.63468432113553463,
                                 0,
                                 0,
                                 0,
                                 0.043813966078633838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059172809920525177,
                                 0.11784867811818953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30989445740606675,
                                 0,
                                 -0.54371883544484545,
                                 0,
                                 0,
                                 0,
                                 -0.055885825014436036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10043096078026233,
                                 0.11344231961993984,
                                 -0.17440031551227911,
                                 0,
                                 0,
                                 -0.21121779553451414,
                                 0,
                                 0,
                                 0,
                                 -0.41304979149220999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28692136027182064,
                                 0.75300315297935871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19929471792834835,
                                 0,
                                 -0.19805726286666031,
                                 0,
                                 0,
                                 0,
                                 0.17346575982432819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077903288833768097,
                                 -0.46858376081745179,
                                 0.24740855733627209,
                                 0,
                                 0,
                                 0.14736536303356862,
                                 0,
                                 0,
                                 0,
                                 -0.26698403545329569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68695965536428116,
                                 0.30427632774061925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075086905545570584,
                                 0,
                                 0.1411603772222641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13351164546906322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57098017641696952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14852461388331201,
                                 0,
                                 -1.111957930996383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53643015427482088,
                                 0,
                                 0,
                                 0,
                                 0.33446429134828082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046553038540237068,
                                 0,
                                 0,
                                 0,
                                 -0.24354705439056762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24955120360847874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29691793100859432,
                                 -0.07085022341858746,
                                 0.31132902644926924,
                                 0,
                                 0,
                                 0.22912264704845198,
                                 0,
                                 0,
                                 0,
                                 0.36156126829253782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2357696587940161,
                                 0.024142852781860916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70748146712346438,
                                 0,
                                 -0.087718004785526757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21212900884422306,
                                 -0.30772706929252214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35263482502273746,
                                 0.15223945624851698,
                                 0,
                                 0,
                                 0,
                                 0.54813925143973663,
                                 0,
                                 0,
                                 -0.009772108397746504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59024247659193896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22597549812964929,
                                 0,
                                 0,
                                 0,
                                 0.12992237766372794,
                                 0,
                                 -0.52781832866344269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43289974271903309,
                                 0.22717892920337687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11196770124709965,
                                 -0.10389168250666531,
                                 0,
                                 0,
                                 0,
                                 0.47269185275690417,
                                 0,
                                 0,
                                 -0.090447523569458815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1610041265008495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84877837415897739,
                                 0,
                                 0,
                                 0,
                                 0.16347264965317043,
                                 0,
                                 -0.17857005092449801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5554856645823717,
                                 0,
                                 0.1450037306613689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3026047614696295,
                                 0,
                                 0,
                                 0,
                                 0.78712543194918083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39739970847239847,
                                 0,
                                 0,
                                 0,
                                 0.007541757115994252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56979861706110713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11078196569978034,
                                 0.28743219780928231,
                                 0.1625879610024748,
                                 0,
                                 0,
                                 0.47721853368552114,
                                 0,
                                 0,
                                 0,
                                 -0.24025688022371419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27233703304359352,
                                 0.10883249204974972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28390825021685906,
                                 0,
                                 0.31926167300318331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56884010020275622,
                                 0,
                                 0.32236102372124348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011822265042831778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.194119990319015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32295030969328953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65603740111637043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59837083068917363,
                                 -0.32646191221145709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044590788275292892,
                                 0.052721862354595916,
                                 0,
                                 0,
                                 0,
                                 -0.44518063786620349,
                                 0,
                                 0,
                                 0.21138829820662411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27360003523406073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40111314551709931,
                                 0,
                                 0,
                                 0,
                                 0.54066291166563096,
                                 0,
                                 -0.45480980838348711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1859020464367664,
                                 -0.45443335631559179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063590719467239251,
                                 0,
                                 0,
                                 0,
                                 -0.10896965349500336,
                                 0,
                                 0.31145348081088459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21502140073250939,
                                 0.37778450519415913,
                                 0,
                                 -0.55357239543132153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.008323369368078315,
                                 0,
                                 0.9016419749706569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11496304047539607,
                                 0,
                                 0,
                                 0,
                                 0.58766731444249154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1636876543452197,
                                 0,
                                 0,
                                 0,
                                 -0.38628088917278619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066905185596536063,
                                 -0.69523357056214263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85906879698129435,
                                 -1.0144737213458332,
                                 0,
                                 0,
                                 0,
                                 0.4107477973682348,
                                 0,
                                 0,
                                 0.18842830659623525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3282830436940517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25247693651270836,
                                 0,
                                 0,
                                 0,
                                 0.81398312554697028,
                                 0,
                                 0.30342847661954919,
                                 0,
                                 0.45676434192744919,
                                 0,
                                 -0.049501510680186128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052039240334125228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24710605734783717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4993932648523684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68974837244571396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020896438463813949,
                                 -0.24598212927011598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80600314426250208,
                                 0,
                                 0,
                                 0,
                                 -0.012424214355674881,
                                 0,
                                 -0.9765356933386975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43614173719534366,
                                 0.56333896527109917,
                                 0,
                                 -0.34136828601013336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0091791397818708764,
                                 0,
                                 -0.18159069139197495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88927439966254485,
                                 0,
                                 0,
                                 0,
                                 -0.327100041528395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17461410577938652,
                                 0,
                                 0,
                                 0,
                                 -1.0419525707788073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24115946687699424,
                                 0.75600948169282289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0034225474210317353,
                                 0,
                                 0,
                                 0,
                                 -0.89113971927421076,
                                 0,
                                 0.24920205304433907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33164686363129908,
                                 0.95361817685500372,
                                 0,
                                 -0.17091805043192054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56015226601186374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16217928639615509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22535709423405986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24275211055913867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3709052424446439,
                                 0,
                                 0.19649999987087247,
                                 0,
                                 0,
                                 0,
                                 -0.18281111507100961,
                                 0,
                                 0,
                                 0.58361807565187462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48551052806687006,
                                 0.75468238784003894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41912029064835649,
                                 0.58861447884933882,
                                 0,
                                 0,
                                 0,
                                 0.47679914346795976,
                                 0,
                                 0,
                                 0.27043703850473322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073482305356683458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015693202247277625,
                                 0,
                                 0,
                                 0,
                                 0.32954338663383598,
                                 0,
                                 0.45841477601274155,
                                 0,
                                 0.45024160689975973,
                                 0,
                                 -0.21823078180532612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20267119650848434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43731500396477102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71645108079475373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0635267150898009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38135895587812663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32922588812696585,
                                 -0.41680703805195912,
                                 -0.056318380946195519,
                                 0,
                                 0,
                                 0.095356538531252852,
                                 0,
                                 0,
                                 0,
                                 0.024616713743245922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36791024604863615,
                                 0.07446160699157954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11016701217648395,
                                 0,
                                 0.63760308318349557,
                                 0,
                                 0,
                                 0,
                                 0.11060322167555614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74681659845455273,
                                 0.14762588656080419,
                                 0.25556735776048822,
                                 0,
                                 0,
                                 -0.25916003283580558,
                                 0,
                                 0,
                                 0,
                                 -0.35150083217123879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0015709065589081805,
                                 -0.30622440428168152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19353532803520707,
                                 0,
                                 -0.14482846589293821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15532531029850027,
                                 -1.0271056036297701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50373898564123665,
                                 0,
                                 0,
                                 0,
                                 -0.30914415548623853,
                                 0,
                                 0.24127082916952719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58531207753892689,
                                 0.44088456938926224,
                                 0,
                                 0.12785330657246533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045099685976224706,
                                 0.20355600063174498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54093044992317241,
                                 0,
                                 0,
                                 0,
                                 -0.17942846633970239,
                                 0,
                                 0.38422038857264246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30811770986014497,
                                 -0.44207136440282668,
                                 0,
                                 -0.72889057853470929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060446546900082242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62988113119353006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052757671558536556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14615189679808277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085826797044374847,
                                 0,
                                 0.59810249040324992,
                                 0,
                                 0,
                                 0,
                                 0.0078641844109789555,
                                 0,
                                 0,
                                 -0.45858211170339058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21118845583912568,
                                 -0.085340668861330085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34589123512850894,
                                 0,
                                 0,
                                 0,
                                 0.30251544235481898,
                                 0,
                                 1.0208353570920514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67533265607478743,
                                 0.03784394557830402,
                                 0,
                                 0.16400173237607071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.156056409539097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1923378613327198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81367266339042033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25980181813224856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11687754481161901,
                                 0,
                                 0.01013343423425403,
                                 0,
                                 0,
                                 0,
                                 -0.35608407335065795,
                                 0,
                                 0,
                                 0.26178892646838714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31652477416428521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32910361946997402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04517592275150676,
                                 0.00089738266201527805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075376032649841704,
                                 -0.40341197431427567,
                                 0,
                                 0,
                                 0,
                                 0.42349008439909069,
                                 0,
                                 0,
                                 0.49098815206394814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70476647993487185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16954385777713046,
                                 0,
                                 0,
                                 0,
                                 -0.34254900480600708,
                                 0,
                                 -0.60312075332254134,
                                 -0.18437930990789295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27657117404553921,
                                 0.58680349064069315,
                                 0.058831992251655724,
                                 0,
                                 0,
                                 0.017503904042454235,
                                 0,
                                 0,
                                 0,
                                 0.44573277536641592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36197742650177112,
                                 0.36057952801323401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11062363302054522,
                                 0,
                                 0.26352643250768237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34318284007954936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22902611337331283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37970298945855857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22100285408363779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58461352720312032,
                                 0,
                                 0.36135731897744938,
                                 0,
                                 0,
                                 0,
                                 -0.23418349254661341,
                                 0,
                                 0,
                                 0.33100144954727706,
                                 0,
                                 -0.41845113654186888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34376509405247224,
                                 0.19123145972200223,
                                 0.74583987243468675,
                                 0,
                                 0,
                                 -0.11444933073435612,
                                 0,
                                 0,
                                 0,
                                 -0.24301354101341366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084831821935105328,
                                 -0.041617668467706551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13252553297745687,
                                 0,
                                 0.1234176011888917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.016950243029954723,
                                 0.41144437307880027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58060967192256385,
                                 -0.71639962069347174,
                                 0,
                                 0,
                                 0,
                                 0.22867614321246804,
                                 0,
                                 0,
                                 0.42291682046774198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4120667118886166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25209543169529069,
                                 0,
                                 0,
                                 0,
                                 0.52402701245648742,
                                 0,
                                 -0.16246866511056623,
                                 0,
                                 0,
                                 0.073796567379209005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13640399996468414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098560782642826639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87397668341067958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0039040916822219787,
                                 0,
                                 -0.3215329666151201,
                                 0,
                                 0,
                                 0,
                                 0.070562095416613832,
                                 0,
                                 0,
                                 -0.3066281861705108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23846472194711854,
                                 -0.083056468341790257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058797427063049898,
                                 0.36327582907794553,
                                 0,
                                 0,
                                 0,
                                 0.12006062342021823,
                                 0,
                                 0,
                                 -0.063163246183787825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4054721867004627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34092597719295381,
                                 0,
                                 0,
                                 0,
                                 0.98893138053695639,
                                 0,
                                 0.097250515287398989,
                                 -0.029725594491238662,
                                 0,
                                 0.91467291751296043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53922853541983828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069035780054283333,
                                 0.80541077218698875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45813566034317305,
                                 0,
                                 0,
                                 0.0026275322876997652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43255866629235173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022300300594432262,
                                 0,
                                 0.49734855368388325,
                                 0,
                                 0,
                                 0.38664425273153469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050907543380398192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51387035283885318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16885470379202472,
                                 0,
                                 0.043387334527704068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25841423986574263,
                                 0,
                                 0,
                                 0,
                                 -0.48426282974893764,
                                 0,
                                 0,
                                 -0.065698079423349445,
                                 0,
                                 0,
                                 0,
                                 1.1383475761863475,
                                 0,
                                 0.32792541087568006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075442910643452876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10360069548384944,
                                 -0.12642336621765105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17751297845019232,
                                 0,
                                 0,
                                 0.1878316395139899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26491036461371292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2115883900788737,
                                 0,
                                 0.22296723420827999,
                                 0,
                                 0,
                                 0.047414188071406946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21367838462511179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3136685005875397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72581337168275517,
                                 0,
                                 0.064366278430880414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033111377509712443,
                                 0,
                                 0,
                                 0,
                                 0.3188567593523437,
                                 0,
                                 0,
                                 0.35427025769634751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50636152062473039,
                                 0,
                                 0,
                                 0.45425599107168946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41633023364801269,
                                 -0.11583314831849011,
                                 -0.59070911311471797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039548286821668069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17986475129686272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24544045186589036,
                                 -0.14039797780771202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40800385764011615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0032199103021180436,
                                 0.21154763950367098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11941647044119269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81376031532172521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18049005929983084,
                                 0,
                                 -0.4753720218790658,
                                 0,
                                 0,
                                 -0.35855285765567291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13291320558482334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57907075909214734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049584792054963273,
                                 0,
                                 0.20622860442121418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26179486803078539,
                                 0,
                                 0,
                                 0,
                                 -0.34363176637363069,
                                 0,
                                 0,
                                 0.16818897302778074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28847475188913319,
                                 0,
                                 0,
                                 -0.31924328835205701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45394003153010321,
                                 0.10397083587468153,
                                 -0.24239752146467675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73432826107567117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15357241549317008,
                                 0.47073907285941313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.5686375789275004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48318247142254306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52768226340871727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2914006005436105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37414074600900576,
                                 -0.15088082947446307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72976365419447509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52319130848481854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62203667894347248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.097431299885546718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12018033163263828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38095932783709086,
                                 0.48715080957303647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38455697552886547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48362358764024937,
                                 0.36263096254314647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11637706056865457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27620660742171449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55808107887824243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31018099120639747,
                                 -0.35161558007037658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13051106141159852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44744754206684423,
                                 -0.42803451682586791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19590079637624527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17281966403289342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4860838498103916,
                                 0,
                                 0,
                                 0.6237381823725936,
                                 0.22682011900970467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4619037053585755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46033709571752912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81772960971282882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69097562841438043,
                                 -0.26174098536732338,
                                 0,
                                 0,
                                 0.53524821951335722,
                                 0,
                                 0.13274583634069714,
                                 0,
                                 0,
                                 0,
                                 0.63294846283837825,
                                 0,
                                 0.33036758612064165,
                                 0,
                                 0,
                                 -0.13376242688997514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14372482845409823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33708681580842792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23069203115271603,
                                 0,
                                 0.48092359793976414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070696514003223854,
                                 0,
                                 0,
                                 0,
                                 -0.21833929905886923,
                                 0,
                                 0,
                                 0.029671534834103327,
                                 0,
                                 0,
                                 0,
                                 -0.22962876172120483,
                                 0,
                                 0.5185134474774431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50195929644844572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43822040924740313,
                                 0.14626017513819739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0266502991673279,
                                 0,
                                 0,
                                 0.27673942550807745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2013903882909136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14294805881562514,
                                 0,
                                 0,
                                 -0.53838451659623665,
                                 -0.57754914563089499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017347409098239692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15195192713612243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66564944949292826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46989954844429604,
                                 0.56919703928721643,
                                 0,
                                 0,
                                 0.041249376198790107,
                                 0,
                                 0.7698218853472506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0062118552118587897,
                                 0,
                                 0,
                                 -0.05243345169001884,
                                 0.42047723267967163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1168927193115161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71074793531054103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2306192866785485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40699167614399118,
                                 1.0221403761081138,
                                 0,
                                 0,
                                 -0.79842252706641648,
                                 0,
                                 -0.043518920310648579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10871845180781189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82148233039274221,
                                 0.0054919982183013532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32206330637116937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43873004941561711,
                                 0.017373950539259678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050203606296911729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11952335014998304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61977672295929176,
                                 -1.1263118989850804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17171862052287262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35620083540078573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35225673847731109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71488202655099353,
                                 0,
                                 0.21486117339515651,
                                 0,
                                 0.62951569821464404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44568329777376103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8953359865074012,
                                 0.16569829109063269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013332854780795671,
                                 0,
                                 0,
                                 -0.42111933235554511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1219637803275548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066659740862658343,
                                 0,
                                 -0.50766838225710553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70086150541971981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1643551401443315,
                                 0.33131428672738195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5384762967172817,
                                 0,
                                 0,
                                 0.69176540132886699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41859465514124405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56149298789757163,
                                 0,
                                 0,
                                 -0.76765503487857267,
                                 -0.1242135406204742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52042231652311566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09613141338847056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30172706124508347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62345436123701914,
                                 0.028690823176258928,
                                 0,
                                 0,
                                 -0.17428393250932306,
                                 0,
                                 -0.84710384523720428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59871384328775912,
                                 0,
                                 0,
                                 0.53664774271956839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4081927860633493,
                                 0.32087403843721957,
                                 0.14117443581137618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25305970367832664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44720130292319882,
                                 0,
                                 0,
                                 0.13009056240271064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56695227239693147,
                                 -0.023694112004635282,
                                 -0.67895441509229759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010585477999772365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18300495568788072,
                                 0,
                                 0,
                                 -0.59089408579183544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35166393305971605,
                                 -0.16116560744347269,
                                 -0.29036139107398651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61919443901397808,
                                 0,
                                 -0.049186224252483091,
                                 0,
                                 0.055921199638055252,
                                 0,
                                 0,
                                 -0.10096899603739032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17303248713176322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26668534873672461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051411369623373435,
                                 0,
                                 0.2648130293984905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19509329560108049,
                                 0,
                                 0,
                                 0,
                                 0.29430056034196495,
                                 0,
                                 0,
                                 -0.82810276929156135,
                                 0,
                                 0,
                                 0,
                                 0.25261737476325852,
                                 0,
                                 0.045331992015542388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080268119020667147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97695629062309275,
                                 -0.34680404886219179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38159205857628736,
                                 0,
                                 0,
                                 -0.066266426304162504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60170045946509743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85367067851351985,
                                 0.11751358351195137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28394803941146651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29715462752181698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052792327584756445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.214974627146981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3049227371753054,
                                 0,
                                 0,
                                 -0.26558365563208519,
                                 0.59472809803650462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25462474149245151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17824161420393744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30611363140975539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62323379738503637,
                                 0.51012566267087456,
                                 0,
                                 0,
                                 -0.1846822491093203,
                                 0,
                                 0.37271799679869122,
                                 0,
                                 0,
                                 -0.30032174055061922,
                                 0,
                                 0.98726893518507819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32714099878021657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23582472067038124,
                                 -1.0019282344038689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11285714781578916,
                                 0,
                                 0,
                                 0.66517044327565278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14509872486251141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53136362018244809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062738245089438413,
                                 -0.045948294755477306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19692755394323899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012027688248176616,
                                 0.41517618368615627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70715488806732707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015522369483640663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40217170705564742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079762622095323782,
                                 0.70405334333092884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.001773167080244064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3541977819068402,
                                 -0.30560633523342917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096845186317910087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32858986111562971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16589455469379341,
                                 0,
                                 0.32274359381220302,
                                 0,
                                 0,
                                 -0.80955090965158583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010333631802661086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0085538393629737697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031536217700678534,
                                 0,
                                 -0.23141487775582631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37127202522539765,
                                 0,
                                 0,
                                 0,
                                 -0.12306698199474077,
                                 0,
                                 0,
                                 -0.072299132072730921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64335887459550589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20771124812746128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069841649268465006,
                                 0,
                                 -0.50043965123704692,
                                 0,
                                 0,
                                 0.13955461980134617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20764706740149402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063025676735250252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3240799193718395,
                                 0,
                                 0.077345729322286325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70802215778569422,
                                 0,
                                 0,
                                 0,
                                 -0.15091617353670908,
                                 0,
                                 0,
                                 -0.20745130446927029,
                                 0,
                                 0,
                                 0,
                                 0.18647707929828988,
                                 0,
                                 -0.44049763168557959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39071287034595414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83118262089609152,
                                 0.072165928374627486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28947375133571707,
                                 0,
                                 0,
                                 0.4315957532422921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67709744248434767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43607708627256919,
                                 0,
                                 0,
                                 0.69788162936399856,
                                 -0.66746932100414236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50911997503440132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038108597545149704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29840607302479283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22300246700916826,
                                 -0.52511647714360099,
                                 0,
                                 0,
                                 -0.64595253410339126,
                                 0,
                                 0.70016256415638811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14366618688144286,
                                 0.65635806087732029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37511489060063724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2270811829120332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29606532287645476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19864004034866903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055783708023890322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098598190724706339,
                                 -0.12826811957891907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65595866926072988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19929344207835623,
                                 -0.47651791845008923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42426213524284684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3060171994611337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68581992096391031,
                                 0,
                                 0.053822003866853957,
                                 0,
                                 0,
                                 0.03694643204254032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20157289075036125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29563071188678125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0025150771717437209,
                                 0,
                                 -0.44929473714993917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17614951014991984,
                                 0,
                                 0,
                                 0,
                                 0.40441540827312283,
                                 0,
                                 0,
                                 -0.030124444449855459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33314711440864186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021562812688410482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37127965004184016,
                                 0,
                                 0,
                                 0.10437907396591864,
                                 0.61539953576643669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04529424900773258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88455469671872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10304961384907832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67033531530196022,
                                 -0.082600451677665776,
                                 0,
                                 0,
                                 -0.35234164473423302,
                                 0,
                                 0.25104972932384062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34679758011673867,
                                 0,
                                 0,
                                 0.069326665231925488,
                                 -0.14792402886625802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28464730170756092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66558653535257672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73617461327680456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19484938705819121,
                                 -0.57570624568006101,
                                 0,
                                 0,
                                 -0.77116183235175273,
                                 0,
                                 -0.42039304015122486,
                                 0,
                                 0,
                                 0,
                                 0.12738350129131734,
                                 0,
                                 -0.084561009567999307,
                                 0,
                                 0,
                                 -0.059660760718707191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87831288504758298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036977244956565555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18946560687469199,
                                 0,
                                 -0.34164786268509556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18435114418795695,
                                 0,
                                 0,
                                 0,
                                 -0.08287493115609422,
                                 0,
                                 0,
                                 0.082392689977073982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42746925722658852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059697086812473626,
                                 -0.32411996516795505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3095569299167677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45616432175913318,
                                 0.38392076947561316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49178570233732932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12447017541622157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10369838957627778,
                                 0,
                                 0,
                                 0.17275977378360985,
                                 -0.099071264915693028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82023342334390548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34853668316806286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69687653975081276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31677694960918668,
                                 0.26127248981188372,
                                 0,
                                 0,
                                 -0.44267610746651959,
                                 0,
                                 -0.17831741974521334,
                                 0,
                                 0,
                                 0,
                                 0.011788441954732717,
                                 0,
                                 0.0055590096287958784,
                                 0,
                                 0,
                                 0.1088036186072931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16792182396055128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15705907488311852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49440527480829927,
                                 0,
                                 -0.52144664744191904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34114144630361215,
                                 0,
                                 0,
                                 0,
                                 -0.45067834249229038,
                                 0,
                                 0,
                                 -0.31511105026069891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2009140210812517,
                                 0,
                                 0,
                                 0.76592877063665232,
                                 -0.66511908959421751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43219782176732746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56956283136028141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075320362679430347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053242369558946845,
                                 0.60805117500251338,
                                 0,
                                 0,
                                 0.076990072812239504,
                                 0,
                                 -0.41536076667168592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.94591457577799498,
                                 -0.67785993993364579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068995697263265515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55410461909663189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48640980901125253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68336396105650254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26161468358290646,
                                 0,
                                 0,
                                 -0.19407483763129058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094254086064255949,
                                 0.91993305980860629,
                                 -0.16458167803434368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10791162457757206,
                                 -0.53887064965676557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18003583510360527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014611086147254961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079059727685559258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44289119644950381,
                                 0.65331289152677496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075297031541881623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20518676260996543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33031737984883086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45695727619640714,
                                 -0.15750646944212982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26896977400401617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35090305582850689,
                                 0,
                                 0,
                                 0,
                                 0.43702232196551555,
                                 -0.27854198719148804,
                                 -0.24524539151449834,
                                 0,
                                 -0.35888717984972179,
                                 0,
                                 0,
                                 0.065383759627153329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16169212700547536,
                                 0,
                                 0,
                                 0.49323450311852918,
                                 0,
                                 0,
                                 0.40766157133929637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94906922399767246,
                                 -0.2639118111095109,
                                 0,
                                 0.98995042628328711,
                                 0.17843790250230701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51383081122556551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083733310038826558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059214251056571937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055629147321625577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45251581648558148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53051177414743589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70723015811781087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32283880724991709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029183315456917658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064447683110004941,
                                 0,
                                 0,
                                 -0.16699402181040074,
                                 0,
                                 0,
                                 -0.76807888021304971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10962778177714369,
                                 -0.57932043624103979,
                                 0,
                                 -0.68930345225842793,
                                 0.73682781915362727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5426894944763444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13140040434818528,
                                 0,
                                 0,
                                 0,
                                 0.05086938033694216,
                                 -0.95342380102111568,
                                 -0.16503954136893206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45157066667594026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68512450842887407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71097047764820676,
                                 0,
                                 -0.06117959376344187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037081169007147877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24237591276336878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2212301799115346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3501799026742356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34087318174167291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0534255304883549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0308723868725984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32209215120945422,
                                 0,
                                 0,
                                 0,
                                 0.46576142434785173,
                                 0,
                                 0,
                                 -0.38971036637934753,
                                 0,
                                 0,
                                 0.43365341948739028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16548081933297712,
                                 0.055495737847564786,
                                 0,
                                 -0.20158272246406878,
                                 0.81379241842146088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19387479127298163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34537840779911688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13641643401406378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027835036222617768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045262756540713871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54415594709733994,
                                 -0.60302805825106942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39603143114367706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2066189181384076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86404247189531291,
                                 0,
                                 0,
                                 0,
                                 0.50197701180605259,
                                 0.42075607841559298,
                                 -0.32674959078893673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1745393913122818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0032118761743415939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62783044296758261,
                                 0,
                                 -0.20837019418244607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0828455874754754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068616979094803743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87617895553346925,
                                 0,
                                 0,
                                 0,
                                 -0.32786103669166577,
                                 -0.61822000505206631,
                                 0.21107743325656916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056386936718182443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14839678078833923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33619699927953633,
                                 0,
                                 -0.23377301694895283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013819534044146927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46609137910004222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24135007962193097,
                                 0,
                                 0,
                                 0,
                                 0.82403348117373565,
                                 -0.022935391700348931,
                                 0.25267908643817144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38940974952978408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42899828095015474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25305461496145626,
                                 0,
                                 0.67931641505610529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16631965962341516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64453907842191382,
                                 0,
                                 0,
                                 0,
                                 -0.47512161677644871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44064536304827029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33923052173802426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13496314610873755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51821393736041865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42220022588220441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20603287510060173,
                                 0,
                                 0,
                                 -0.562761987843028,
                                 0,
                                 0,
                                 -0.027305782007250326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50604730609701321,
                                 -0.24251333082911469,
                                 0,
                                 0.7457758652806562,
                                 -0.24244549567892604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63827761404400674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66289755192774036,
                                 0,
                                 0,
                                 -0.72998201691967812,
                                 0,
                                 0,
                                 -0.37371391773654733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45712091373826358,
                                 0.52852314465603534,
                                 0,
                                 0.82547198498610597,
                                 0.09284157333436488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038112233338466084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24695255639998251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19673109681450685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32864865760748169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36096652145026181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45496815344962965,
                                 0.1409382162747424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32969517356509875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57135455869921825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29066940091888166,
                                 0,
                                 0,
                                 -0.5258470410214694,
                                 0,
                                 0,
                                 -0.25202709541974122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8669014621541894,
                                 -0.2938006776771715,
                                 0,
                                 -0.19555430781123653,
                                 -0.42185418734709079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10346787694686432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63947525173384157,
                                 0,
                                 0,
                                 -0.62200007560252246,
                                 0,
                                 0,
                                 -0.17203729344591065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.016592703593248367,
                                 -0.81788872799909373,
                                 0,
                                 0.2323608783175285,
                                 -0.014514275521634812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57792830203255618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57563658533024387,
                                 0,
                                 0,
                                 0,
                                 -0.12160281842716211,
                                 0.83038167329449197,
                                 0.16017679568781262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21638565673029359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.610141188151751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12730755207008379,
                                 0,
                                 0.075561740269876609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64206019059175801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.004505978454380298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28655286177477879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11964838641349501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81072387816246516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56440424774609421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96713870939063951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26734892139031385,
                                 0,
                                 -0.014029683965401329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20300507983610816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59195113002505495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71772612577712136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048367346223367774,
                                 -0.13136946139719202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26850072775945649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.036948574962421578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73631053576626293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42568981426921454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27120719972764318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23522929329515391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3794663391961105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061270782236665877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0029585318370383166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36785013250713855,
                                 -0.553414410047537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55090615508799101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11791725516066552,
                                 0,
                                 0,
                                 0,
                                 -0.1587697207003903,
                                 0.15099628025950942,
                                 -0.10963339028434575,
                                 0,
                                 -0.013118121457831361,
                                 0,
                                 0,
                                 -0.42521604019348436,
                                 0,
                                 0,
                                 0,
                                 0.066719222770831921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5092586262257156,
                                 0.008466275608265024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12259163463237099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051207012369200056,
                                 0,
                                 0,
                                 0,
                                 0.40764068682833299,
                                 -0.19894098025097681,
                                 0.58954365236548445,
                                 0,
                                 -0.39883685365210603,
                                 0,
                                 0,
                                 -0.078106690178323182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092161925495269137,
                                 0,
                                 0,
                                 0,
                                 0.076684582343420599,
                                 -0.4339298806226175,
                                 0.42760801719606234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31419603143572056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69104726706136843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25600022120633181,
                                 0,
                                 0.37971089278644254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21408735350146979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58417204559389246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2128512754606571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.075863728759179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13194964113059984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10463389807821799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20404457381676158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46292495372691594,
                                 0,
                                 -0.42107917461807171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61777012630167094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087660080065335946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10294460742786755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085737269821422935,
                                 0.070661397146764254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52685426909878463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3644875643500865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2770455057056091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32028425771631713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57128515896787291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13505752506445159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038773352573238856,
                                 0.35109423210444068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51693522236062561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28993785073726625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019383782791550553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085209368382559436,
                                 0.51145722597234133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42244961668124609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39706602986943185,
                                 0,
                                 0,
                                 0,
                                 -0.14797649115957762,
                                 -0.27181816076729987,
                                 0.34345744545101309,
                                 0,
                                 0.36213927487619041,
                                 0,
                                 0,
                                 -0.22306950058759833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4248643307142046,
                                 0,
                                 0,
                                 0,
                                 0.69210406445759975,
                                 -0.36171126565801942,
                                 0.31158304670591047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34504722294309081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08910960221528344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32474942516962535,
                                 0,
                                 -0.66098339154520291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31361926198718382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22437984481535944,
                                 0,
                                 0,
                                 0,
                                 -0.42688272712876962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50821648389534602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57546696836768374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25385610610659781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26041560388653634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30994467528685476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57222336918733641,
                                 0,
                                 0,
                                 0,
                                 -0.73333877393858427,
                                 0.41452150986505371,
                                 0.50945146087051207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44996478951561514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1576522413834005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094833387078580564,
                                 0,
                                 0.32347633431752904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1164789970773869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56809412391732306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22329721244619105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5541461873930309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49765916660662846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21696873180941112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1326179110281798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17035415556013442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65410532148252942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2232704629506415,
                                 0,
                                 0.035334519122217772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61342537240356376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2355761324834944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50207916284880849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13341567187716252,
                                 0.042059071814809279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24579351032269783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48466279777387394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12765430192525948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50068726286761489,
                                 -0.26515359404945482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13232074293183757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0081022750875731648,
                                 0,
                                 0,
                                 0,
                                 -0.20757871786588206,
                                 0.37963241767526512,
                                 0.62811123081529785,
                                 0,
                                 -0.2070570173583168,
                                 0,
                                 0,
                                 0.14328212142028954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61649898829626071,
                                 0,
                                 0,
                                 0,
                                 0.17581080131626572,
                                 -0.033496285537110183,
                                 -0.16352737552756053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26014694691417695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68565815390576212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75307562678974127,
                                 0,
                                 -0.26450148130462348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17817059263716351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27938206774577429,
                                 0,
                                 0,
                                 -0.79738164575113901,
                                 0,
                                 0,
                                 -0.38394635316894948,
                                 0,
                                 0,
                                 0.73613883274844727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31946148966420507,
                                 0.18065681436873304,
                                 0,
                                 -0.69415195951852382,
                                 -0.18481270490825769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22272892213915099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17707483164045246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3844553308114928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69037731635290345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24938122929057346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37540045233008856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37563448529572124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1475865764870965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23584287781178279,
                                 -0.18740899121849997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13546975088116636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12991979097488143,
                                 0,
                                 0,
                                 0,
                                 0.62470209471424964,
                                 0.13841633236348996,
                                 0.11805697700537607,
                                 0,
                                 0.51766767758730203,
                                 0,
                                 0,
                                 -0.40114080009687947,
                                 0,
                                 0,
                                 0,
                                 -0.79021821161978967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00093803995506613891,
                                 -0.013522058724710295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34886235232385809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18912966389695976,
                                 0,
                                 0,
                                 0,
                                 0.17048717500359178,
                                 -0.32770649914959354,
                                 -0.071639350695996931,
                                 0,
                                 -0.084853913210107226,
                                 0,
                                 0,
                                 0.26288147865111711,
                                 0,
                                 0,
                                 0,
                                 -0.42890384498943274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035014125767814763,
                                 0.29092621685708386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2189787118507901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45830117349993055,
                                 0,
                                 0,
                                 0,
                                 0.04029795464949798,
                                 0.38610712060188085,
                                 -0.20855809507944295,
                                 0,
                                 -0.37031998433765062,
                                 0,
                                 0,
                                 -0.37529960520704631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10737909698671862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78168574776916433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76367162566473734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43692680136292295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71020561401302862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44299384372671191,
                                 0,
                                 0,
                                 -0.10138740182884221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25831627179010702,
                                 -0.21243271061686519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33572681124836229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13323145411246767,
                                 0,
                                 0,
                                 0,
                                 -0.35547447942731586,
                                 -0.58386587224753628,
                                 0.053171832116159015,
                                 0,
                                 -0.16048383701221064,
                                 0,
                                 0,
                                 -0.50155633961765567,
                                 0,
                                 0,
                                 -0.52329663619181832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09247078195952535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38864959763912621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25563960580416806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52129864636639289,
                                 -0.2058852888059558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22690530978008228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36821544885680685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10728754941689425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46370639701322941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02217285025833772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77139331373080988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31188953761905414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28399189367959365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17115588247445501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12250542638590292,
                                 -0.41459245810769035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33531379352008589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64974884489537488,
                                 0,
                                 0,
                                 0,
                                 -0.073090051538082151,
                                 -0.15969467748928995,
                                 0.048922340271436326,
                                 0,
                                 0.31601842447070444,
                                 0,
                                 0,
                                 0.34072964484777812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55223360559772794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56705339872143024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1389600913429376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35981352504883696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21499366833003491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20092102985303345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28343608333654702,
                                 0,
                                 0,
                                 0,
                                 -0.19334166441441278,
                                 0.3897289644862702,
                                 0.92076345892040046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98941375092475736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58593564128701769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10891877375436919,
                                 0,
                                 -0.24711688135013585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42236313382469187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017479896079684552,
                                 -0.51740450065223864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40323441285538564,
                                 0.13811657001070257,
                                 0,
                                 0.31162715543309966,
                                 0,
                                 0,
                                 -0.020756889453106053,
                                 0,
                                 0,
                                 0,
                                 -0.5248712586779718,
                                 0.20098033678736338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37039592014222295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4691428010741388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52310446080110706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027587992414844855,
                                 0,
                                 0,
                                 0.60809393061711181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24670862586868281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27360972832380975,
                                 0,
                                 0,
                                 0.10696351516444211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73397687469772988,
                                 0.56958575743423123,
                                 0,
                                 0,
                                 0.042302091913384743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46564658467711229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017155076187428911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19810013703210597,
                                 -1.225337041595731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3733149222371428,
                                 0,
                                 0,
                                 -0.49614524925009984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17102558938473572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9616961592383344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44921093067423951,
                                 0,
                                 0,
                                 0,
                                 0.061234459126473517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16659056634869551,
                                 0,
                                 0,
                                 0,
                                 0.96887479386013076,
                                 0,
                                 0.28655971706717609,
                                 0,
                                 0.17949692865693825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45531043506140323,
                                 0,
                                 0,
                                 -0.40860494455684604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6772771489662448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21213461582847826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.4289640823694523,
                                 0.12318735870398279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23744027141718066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71445262126811759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019895909026613687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13968727440862391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25341946351125333,
                                 0,
                                 -0.16210736987843877,
                                 0,
                                 -0.35435082944972901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3007353496680184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30723550083019824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11122522172362961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16054868531545821,
                                 0,
                                 0,
                                 -0.36442609422278921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11613364399053651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47854654225850202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27494752601249084,
                                 0,
                                 0,
                                 0,
                                 0.019148402989698669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48691409928850637,
                                 0,
                                 0,
                                 0,
                                 0.090483085164919541,
                                 0,
                                 0.055837364057449837,
                                 0,
                                 -0.89075202199909231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057235258559782842,
                                 0,
                                 0,
                                 0.38140460259800801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28700579295199752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2884058892236951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80073651283762448,
                                 0.53728803376469536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.336241003742619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21464158571061479,
                                 -0.25880193094323567,
                                 0,
                                 -0.13844294387016179,
                                 0,
                                 0,
                                 -0.7456914450744534,
                                 0,
                                 0,
                                 0,
                                 -0.22413347596576877,
                                 -0.32578657714088893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20566392189079946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026670858788431728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49329405248902569,
                                 0.17391252351903322,
                                 0,
                                 0.24576058450567972,
                                 0,
                                 0,
                                 -0.32121979328048317,
                                 0,
                                 0,
                                 0,
                                 0.14467977496848439,
                                 0.73548106948810521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016093970350912368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2040652658152407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2431848437136431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077258537112243508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43359202212054049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53820435054151861,
                                 0,
                                 0.42932325200450772,
                                 0,
                                 0.082015401754315542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34568489322442353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18956556920233245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26287929105080193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18038452391191676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21829374590264841,
                                 0.45879564654419275,
                                 0,
                                 -0.61394790675588229,
                                 0,
                                 0,
                                 0.24399932727077769,
                                 0,
                                 0,
                                 0,
                                 -0.40401779036975816,
                                 0.13635442758492219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30170384480341356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56428713800279495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41966927162293549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26517437611798977,
                                 0,
                                 0,
                                 -0.35686690631417234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54354962065177947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11108600117738984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32968360713685219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75324936387704933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24494489411102482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32628906407723623,
                                 0.59223953832178911,
                                 0,
                                 0.44426998871786133,
                                 0,
                                 0,
                                 -0.056294642617247259,
                                 0,
                                 0,
                                 0,
                                 -0.19682380298172994,
                                 -0.48617420672928535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084497907602027411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41054010921512168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022055658224026851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35965189312650958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10342129124595252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050544018236509253,
                                 0,
                                 0.41656862022143903,
                                 0,
                                 -0.69487010946099848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061759983286289982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13393613540948154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10120846256367635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65676977938043712,
                                 0,
                                 0,
                                 0.1055715278728786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32929892109044506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19345194801143734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52934538971524236,
                                 0,
                                 0,
                                 0,
                                 -1.1020902774143337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35940888358082668,
                                 0,
                                 0,
                                 0,
                                 -0.24125009354008353,
                                 0,
                                 -0.35240271844226634,
                                 0,
                                 0.15181406983814061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.6152891053287228,
                                 0,
                                 0,
                                 -0.30114839767259854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60466812143560245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12045254477728418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025550995507628071,
                                 -0.83077099454959902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082187412991873515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38575187803743261,
                                 -0.18025164453683176,
                                 0,
                                 -0.3615573237962057,
                                 0,
                                 0,
                                 0.039458336264645975,
                                 0,
                                 0,
                                 0,
                                 -0.093933984137968191,
                                 -0.074447359522187506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81566132737230979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19531526819617923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47208876107265729,
                                 -0.49044940032476253,
                                 0,
                                 0.34393016803498566,
                                 0,
                                 0,
                                 0.49690792372784853,
                                 0,
                                 0,
                                 0,
                                 -0.28735514837069398,
                                 -0.044289505025137496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2206888005785709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35628121439416943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095967109087466307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60521606806756034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079334818970410517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0033984188479383448,
                                 0,
                                 0.2512565170053348,
                                 0,
                                 -0.37696493680275606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49806152294457273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06725920427035037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18286737360998251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42731800520698071,
                                 0,
                                 0,
                                 0.32606992833792925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73138252982424512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62555368323755678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47701439238993426,
                                 0,
                                 0,
                                 0,
                                 0.33251068061944927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28331672219581694,
                                 0,
                                 0,
                                 0,
                                 -0.62230285137480301,
                                 0,
                                 -0.13593529988246125,
                                 0,
                                 -0.69700163764008127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22870533399240262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45956770870240915,
                                 0.88524621447915786,
                                 0,
                                 0,
                                 -1.0450126266141453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22457261613813823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1349336967065291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24232063753108055,
                                 0.12911907063816694,
                                 0,
                                 0,
                                 0,
                                 0.67302725525940144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64437385879144871,
                                 -0.83760431020419368,
                                 0,
                                 0,
                                 -0.73165268428711472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025533585972963346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40170761701065616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16333158624147306,
                                 0.026044296976716952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17723975973184811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20933249678007088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32549405281530319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022775620549181273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015766993617492203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24003256761930516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39016629170562789,
                                 0,
                                 0.58391483835059654,
                                 0,
                                 0.21610091467912038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23744010315230718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13316006257107033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47082414687591267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.9033801277835507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12112709464580526,
                                 1.0093530821183943,
                                 0,
                                 0,
                                 0.23483829216484869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31868573557485591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22922029268870997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13074559628813359,
                                 0.58402764181538624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20856137707730474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0070002759600644969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37344408043771049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13080272836469867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46932734836718715,
                                 0,
                                 0.16147801405468931,
                                 0,
                                 0.054838423494581387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26493197809291996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63462429817701116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2785602245005574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3207885004558016,
                                 0,
                                 0,
                                 0.35652572365399704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36026684221687982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3830702260899097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54025317973637044,
                                 0,
                                 0,
                                 0,
                                 -0.34375539768858249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09748452430469863,
                                 0,
                                 0,
                                 0,
                                 0.37470999194247073,
                                 0,
                                 -0.92922430854260085,
                                 0,
                                 0.12832518902738435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10809723672878663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44144607477404019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1282886661759475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29388712419963725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28486515394066236,
                                 0,
                                 0.15656190986432192,
                                 0,
                                 -0.018219028731634557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38361697603975631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61539725138060752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24237418379034856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33361913721804259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63363700209057816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25277658008899478,
                                 0,
                                 0,
                                 0.41703242389764383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47186623890921087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16350116641112009,
                                 0,
                                 0,
                                 0.19083349430791102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15089183238848106,
                                 0.74471772249012169,
                                 0,
                                 0,
                                 0.34293792367643183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2667695897794984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37442112743533801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52753634815999562,
                                 -0.051580295234772887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25910026650882922,
                                 0,
                                 0,
                                 -0.80244264644308028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0042316854145993538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060870589407818837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93775783377438837,
                                 0,
                                 0,
                                 0,
                                 -0.18243373933745366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19335947248673646,
                                 0,
                                 0,
                                 0,
                                 -0.67302674194141199,
                                 0,
                                 0.042677991873178875,
                                 0,
                                 0.50241302445590019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49773345997710217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30542233441349148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36575847735295514,
                                 0,
                                 0,
                                 0.30517324522505279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60931209653943641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2465915572654703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22087976694671307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17994377795255728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32194879247669439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60654597265564736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42493984106287563,
                                 0,
                                 0.043856049891064466,
                                 0,
                                 0.20633744544028076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46193428910627432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0054079258740138761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093799932131912747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36752098600066535,
                                 0,
                                 0,
                                 -0.068270020059343198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72781250673172282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03826213200594443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46308798069953194,
                                 -0.65801761661782476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1051618443561992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89857296062730507,
                                 -0.091060571456513612,
                                 0,
                                 0,
                                 -0.68543528661664932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22637768643982437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30927851031945747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56891183628459252,
                                 -0.72259156233859723,
                                 0,
                                 0.69360207102892879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14900655413312466,
                                 -0.2223227881147406,
                                 0,
                                 -0.0020708529931231096,
                                 0,
                                 0,
                                 -0.17073974706422998,
                                 0,
                                 0,
                                 0,
                                 -0.59997962503217039,
                                 0.22377611132163999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089878493884720106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31603695292918921,
                                 0,
                                 0,
                                 -0.90262994004501373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38553826381719075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19413176886797653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86627062761504181,
                                 0,
                                 0,
                                 0,
                                 -0.060925238837344103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35759382473759171,
                                 0,
                                 0,
                                 0,
                                 -0.20877093362307719,
                                 0,
                                 -0.85814681891378242,
                                 0,
                                 0.22393058242782482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030191769039670455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015297157439189813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32937338399850802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49645702402576858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091069591417066262,
                                 0,
                                 -0.28535765039692157,
                                 0,
                                 -0.2053796626662745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095880742909563568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038296816172983431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70805001470070728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054734743386309043,
                                 0,
                                 0,
                                 -0.82598082902377734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34499111526997434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00087707840139515658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50882399115730759,
                                 0.48424512409070042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16359268972571583,
                                 0,
                                 0,
                                 -0.48718212267178068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79380122671643871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35948524326030168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01811962277985385,
                                 -0.63914123552240987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1846385412208153,
                                 0,
                                 0,
                                 -0.024116502818272122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2366781520056784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39975569669248195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20956013397765716,
                                 0,
                                 0,
                                 0,
                                 0.094608840991168106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42834177009037605,
                                 0,
                                 0,
                                 0,
                                 0.078204228160067765,
                                 0,
                                 -0.64027852161911958,
                                 0,
                                 0.068876876308705551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20733985272033589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23536135288739082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72819319614151146,
                                 0,
                                 0,
                                 -0.47290725304245484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066136946483558279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37859546017326751,
                                 0,
                                 0,
                                 0,
                                 0.82047792071059689,
                                 0,
                                 0,
                                 -0.13188136496215205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26312458264563704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60742216229325607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029842647838623507,
                                 0,
                                 0,
                                 0,
                                 -0.407570477775485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12451009220015689,
                                 0,
                                 0,
                                 0,
                                 -0.10322421411123353,
                                 0,
                                 0.71789195938862516,
                                 0,
                                 -0.47175773488770462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62902412228264459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43893770597534953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36013106744059858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0057640309208412156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032168548303360717,
                                 0,
                                 0.27901224415249237,
                                 0,
                                 0.328583615979465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20463500107015409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21568329137060549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081793200541051048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080688000849033659,
                                 0,
                                 0,
                                 -0.26194705679160463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12901320937293254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33766404493942703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20580832622560047,
                                 0,
                                 0,
                                 0,
                                 0.013414422271310747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2550611527362541,
                                 0,
                                 0,
                                 0,
                                 0.5851187345689699,
                                 0,
                                 0.5228467426502621,
                                 0,
                                 -0.22511524862300916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063471847745665888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2187751843272695,
                                 0.13435938594284996,
                                 0,
                                 0,
                                 -0.12681695764980666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.074297006190742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82431719000807413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86541214656354692,
                                 0.20183334119238669,
                                 0,
                                 0,
                                 0,
                                 -0.41386044455644944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23054393094232478,
                                 0.37543933930583578,
                                 0,
                                 0,
                                 0.13297088378155439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096212982876047126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71874824638434487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60666169585123797,
                                 0.09951518081043785,
                                 0,
                                 0,
                                 -0.24383379105437225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0081121104253297216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44830888773380739,
                                 0,
                                 0,
                                 -0.11036195250668276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21306240801585771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82578633248121336,
                                 0.10873110972241809,
                                 0,
                                 0,
                                 0,
                                 -0.17439541629431732,
                                 -0.30974472017118293,
                                 0,
                                 0,
                                 0,
                                 -0.34516584150132112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23144178875440988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65568335955202661,
                                 0,
                                 0,
                                 -0.48769052765845006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14613183909664548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057619968399618658,
                                 -1.0357128765096133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064074188880318544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0042095684027677882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13373591475540886,
                                 0,
                                 0,
                                 -0.43962842446503847,
                                 0,
                                 -0.28459875750809266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045668308832346655,
                                 0,
                                 0,
                                 -0.12305211192427368,
                                 0.2547599510049654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014192430104669307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71471420385390472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25705787751554438,
                                 0,
                                 0,
                                 -0.61977870312214411,
                                 0,
                                 0.31211436585730989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28365337501986493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30992644733255859,
                                 0,
                                 0,
                                 0.34181849476809895,
                                 0,
                                 0,
                                 0,
                                 -1.0093739565178639,
                                 0,
                                 0,
                                 0,
                                 0.012184327634949414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56660162594826002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41196432491148854,
                                 0,
                                 -0.25988439393325796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44965736194867645,
                                 0,
                                 0.10793166992225109,
                                 0,
                                 0,
                                 0.22083221945652207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26525650402442968,
                                 0,
                                 0,
                                 0,
                                 0.28988074310687767,
                                 0.060248078005052719,
                                 0,
                                 0,
                                 0,
                                 0.41503881954394795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045804251025951523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64194984448102499,
                                 0,
                                 0,
                                 0.35782378538212783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35705125064947252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11175852098752982,
                                 0,
                                 0,
                                 0,
                                 0.27063759373157548,
                                 -0.72081670542109066,
                                 0,
                                 0,
                                 0,
                                 -0.35734174171313976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13448932485683404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1423224267143843,
                                 0,
                                 0,
                                 0.37116683312550125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30147572539496931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40381549622335017,
                                 0,
                                 0,
                                 -0.040553989647538008,
                                 0,
                                 0,
                                 0,
                                 0.72375957196896057,
                                 0,
                                 0,
                                 0,
                                 0.15809769957033054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60860936871979898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039310397652035187,
                                 0,
                                 -0.58521749923285982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15683873143467955,
                                 0,
                                 0.72166265423102982,
                                 0,
                                 0,
                                 0.688185885983714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23430479927815828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39409240623601727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43790427372083707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39476251391251566,
                                 0.58323467671963236,
                                 0,
                                 0,
                                 0,
                                 0.1067234341710377,
                                 0,
                                 0,
                                 -0.24153181971931206,
                                 0,
                                 0,
                                 -0.29137202416496177,
                                 0.092708472017336355,
                                 -0.15380866632718981,
                                 0,
                                 -0.27298432281292095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22548202059434183,
                                 0,
                                 0,
                                 -0.24698885190354103,
                                 0,
                                 0,
                                 0,
                                 -0.093827106426144891,
                                 -0.46635764946651803,
                                 0,
                                 0,
                                 0,
                                 0.52229279569786069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44385753028370167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053512205684745962,
                                 0,
                                 0,
                                 -0.44131931137887426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21278618737724619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52054349896503993,
                                 0,
                                 0,
                                 0.34703297353836987,
                                 0,
                                 0,
                                 0,
                                 0.2266270299233307,
                                 0,
                                 0,
                                 0,
                                 0.21148084293931474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75406330082701922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.278577746255603,
                                 0,
                                 -0.0028710299762216979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96665320964975976,
                                 0,
                                 -0.48523606876269898,
                                 0,
                                 0,
                                 0.28527603144346847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68558438828115942,
                                 0,
                                 -0.29554963368729303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16050908927144064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52290150119665046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061423026754135079,
                                 0,
                                 0,
                                 0.37371449619242464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014526730870272508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18633727884762408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46867182939634083,
                                 0,
                                 0.039972525348807991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28732711212871404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61859183313978261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52869523412778086,
                                 0,
                                 0,
                                 -0.18443843841952695,
                                 0,
                                 0,
                                 0,
                                 0.72961178374938895,
                                 0,
                                 0,
                                 -0.10318268217864537,
                                 0,
                                 0,
                                 0,
                                 0.079049018855731124,
                                 0,
                                 0,
                                 0,
                                 -0.13695047144593331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14161760742163901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030879964306002011,
                                 0,
                                 0.47846380770462665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52398209315094946,
                                 0,
                                 -0.57126535631256981,
                                 0,
                                 0,
                                 0.85384627218356912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46878009848195351,
                                 0,
                                 0,
                                 0,
                                 -0.23986566166326728,
                                 0.19191000629569677,
                                 0,
                                 0,
                                 0,
                                 0.14496681927215183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62434797206308756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0026970011597761724,
                                 0,
                                 0,
                                 -0.097702776991818494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51526823863817817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49877495833181729,
                                 -0.13764457505200253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48002587447961353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072808854004014559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36219992173381621,
                                 0,
                                 0,
                                 0.17412819199983112,
                                 0,
                                 0.76855685274997332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42289926311656262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25650434588452342,
                                 0,
                                 0,
                                 0,
                                 1.0645076959877162,
                                 0,
                                 0,
                                 0.94297773877741053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78526315041699957,
                                 0,
                                 0,
                                 -0.60122802040057377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32486770760738526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39733154549654309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32818487731955448,
                                 0.26765637598379471,
                                 0,
                                 0,
                                 0,
                                 -0.14337427809182837,
                                 0,
                                 0,
                                 0.15650641494109188,
                                 0,
                                 0,
                                 -0.30132275171490386,
                                 -0.14006203939021361,
                                 0.52969606395038371,
                                 0,
                                 0.1397113960372022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45521641247306915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034468645762895017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18989862626583953,
                                 -0.49624581883352215,
                                 0,
                                 0,
                                 0,
                                 0.34946602689463468,
                                 0,
                                 0,
                                 -0.33605698751116675,
                                 0,
                                 0,
                                 -0.59871451677687726,
                                 -0.042665677576723515,
                                 0.29554838067910338,
                                 0,
                                 0.14472794381297044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11338100810295593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70700189411492764,
                                 0,
                                 0,
                                 0.04133120514248545,
                                 0,
                                 0,
                                 0,
                                 -0.95433774643285374,
                                 0,
                                 0,
                                 0,
                                 -0.03580276502445072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6512094256064267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45830666338042364,
                                 0,
                                 -0.005172824727012873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.049962367879656022,
                                 0,
                                 0.23153249312857693,
                                 0,
                                 0,
                                 -0.54933190985145919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38297492269435579,
                                 0,
                                 0,
                                 0,
                                 0.66778142290566322,
                                 0,
                                 0,
                                 -0.63633232542292151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31840238706689705,
                                 0,
                                 0,
                                 -0.78634561395053415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50744742190472525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024763948634916065,
                                 0,
                                 0.23107016569393435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79239011363655376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091709660340043936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41374555869027752,
                                 0,
                                 0,
                                 0.37217628087993299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4429312523705381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12087800379426089,
                                 0.43473252058680123,
                                 0,
                                 0,
                                 0,
                                 0.21003992284474804,
                                 0,
                                 0,
                                 -0.30685994139019701,
                                 0,
                                 0,
                                 0.25973988963616079,
                                 -0.053691408073321956,
                                 0.55705438296622345,
                                 0,
                                 0.022512627726108458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28419056113757502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2239730905272079,
                                 0,
                                 0,
                                 0,
                                 0.39750876045806322,
                                 0,
                                 0,
                                 -0.65010368528632734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053502067455975355,
                                 0,
                                 0,
                                 0.13123874473127203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8472127422556518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42046045401070381,
                                 0,
                                 0,
                                 1.1827099274854984,
                                 0,
                                 0,
                                 0,
                                 0.21667967772127841,
                                 0,
                                 0,
                                 0,
                                 -0.0072096776414752317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25519441388292419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65905286968315102,
                                 0,
                                 0.26040859708136399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38662088354208529,
                                 0,
                                 0.0041352643045051429,
                                 0,
                                 0,
                                 -0.42590433342207196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061892955459176766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089796003132057267,
                                 -0.035086504873440096,
                                 0,
                                 0,
                                 0,
                                 -0.081882095578305211,
                                 0,
                                 0,
                                 0.71178582831409087,
                                 0,
                                 0,
                                 -0.20470397180930799,
                                 0.28181975880527904,
                                 0.30359303327684151,
                                 0,
                                 -0.16429055077186908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48274726994774547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31247819769184781,
                                 0,
                                 0,
                                 0.10355532035233608,
                                 0,
                                 0,
                                 0,
                                 0.43309330879075697,
                                 0,
                                 0,
                                 0,
                                 -0.90623911976460469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47146452812285428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11730650235133647,
                                 0,
                                 -0.6946667666836861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75161122712607309,
                                 0,
                                 0.55268777236588951,
                                 0,
                                 0,
                                 -0.47660561780604649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0037610274194371449,
                                 0.12655778806483536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32191844679135034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021455031175983283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64585954112455679,
                                 0,
                                 0,
                                 -0.44073041244203565,
                                 0,
                                 -0.17144530191144064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66120061691193843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13130833944542392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035601658113756228,
                                 -0.30980488393691119,
                                 0,
                                 0,
                                 0,
                                 -0.13697913615130508,
                                 0,
                                 0,
                                 -0.2056950690115496,
                                 0,
                                 0,
                                 0.18939625287041895,
                                 0.037085390236192006,
                                 0.28907825106294344,
                                 0,
                                 -0.82953981904584528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12445488047280716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.093355521559612242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62170711192226824,
                                 0.044000524785870229,
                                 0,
                                 0,
                                 0,
                                 0.43273884369584131,
                                 0,
                                 0,
                                 0.314774758866954,
                                 0,
                                 0,
                                 0.23189710205036984,
                                 -0.092530742375415614,
                                 0.16353684227697166,
                                 0,
                                 -0.030203082155035196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47590774584757395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40951318813474558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073103464474586169,
                                 0.15349150393982341,
                                 0,
                                 0,
                                 0,
                                 -0.035111310514709608,
                                 0,
                                 0,
                                 -0.10096622184111398,
                                 0,
                                 0,
                                 -0.28568167725901028,
                                 0.72772248396551664,
                                 -0.089770127270451694,
                                 0,
                                 -0.091323204762710594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40543257207104499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18294200352321238,
                                 0,
                                 -0.59840254742480792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19006823956347871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47343929281099206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46183740789589989,
                                 0,
                                 0,
                                 0.36726301689971108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48338027423233842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056429148881675703,
                                 0.17289629087133168,
                                 0,
                                 0,
                                 0,
                                 -0.086153491858365988,
                                 0,
                                 0,
                                 0.14610960309131041,
                                 0,
                                 0,
                                 -0.43033282786388377,
                                 -0.58777635448520826,
                                 -0.21386614288510777,
                                 0,
                                 -0.34598854298295362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09155058377932869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11770418536935844,
                                 0,
                                 0,
                                 0,
                                 -0.47349270754214484,
                                 0,
                                 0,
                                 -0.25261750049823373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0185753050827655,
                                 0,
                                 0,
                                 -0.05171129895811255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39909146610417895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73240601569251462,
                                 0,
                                 0,
                                 0,
                                 -0.50009178891301165,
                                 -0.12459439490625369,
                                 0,
                                 0,
                                 0,
                                 0.049673788613454534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10357915928181505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26513931731659879,
                                 0,
                                 0,
                                 -0.022375741528757993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33759474031496428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68316894095872194,
                                 0.13750608312677104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29599409924721654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59049073410342334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40157145465795013,
                                 0,
                                 0,
                                 0.66584898091561029,
                                 0,
                                 -0.22612558419684053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43190889884611655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91656185388400735,
                                 0,
                                 0,
                                 0,
                                 0.29238844223026761,
                                 0,
                                 0,
                                 -0.2379858196124077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28344859145773393,
                                 0,
                                 0,
                                 0.82378455825936048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025930992502401898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019743611723349735,
                                 0,
                                 0,
                                 0,
                                 0.21402987195752385,
                                 0.3329821573990987,
                                 0,
                                 0,
                                 0,
                                 -0.49645033772044905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41434539489650291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0012131441637737404,
                                 0,
                                 0,
                                 -0.30054467799941481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57831709923935193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24391947524962901,
                                 -0.043124964812559646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8712368905496054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13847882934967448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16179947640365611,
                                 0,
                                 0,
                                 -0.17333359350495237,
                                 0,
                                 0.085238864934845102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75886105559367345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.009463254533530174,
                                 0,
                                 0,
                                 -0.69638292934613977,
                                 0,
                                 0,
                                 0,
                                 0.3478101951460541,
                                 0,
                                 0,
                                 0,
                                 0.37172594477146831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29931316760393012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8513686808886981,
                                 0,
                                 -0.27990936122747367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20519704412470738,
                                 0,
                                 -0.42535638045701124,
                                 0,
                                 0,
                                 -0.71856161910139238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67948890914070814,
                                 0.10828810680585708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36580649291019973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2330781236807937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30986764124766686,
                                 0,
                                 0,
                                 -0.75577459702112615,
                                 0,
                                 0.16133795809117149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27933887748552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52445143373438352,
                                 0,
                                 0,
                                 -0.14786440987009408,
                                 0,
                                 0,
                                 0,
                                 -0.040008402188840456,
                                 0,
                                 0,
                                 0,
                                 -0.7442313759262037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53023426907319771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52919080576490796,
                                 0,
                                 1.0248806887813469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23832151233648391,
                                 0,
                                 0.66483151475210078,
                                 0,
                                 0,
                                 0.031399825550564517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0039795258222286,
                                 0,
                                 0,
                                 0,
                                 -0.018188857911500989,
                                 0,
                                 0,
                                 0.65751793842291795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21537281814128104,
                                 0,
                                 0,
                                 0.29806444517058822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1891397744052019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29624299167081958,
                                 0,
                                 0,
                                 0,
                                 -0.67087334232079876,
                                 0.011483313463393402,
                                 0,
                                 0,
                                 0,
                                 -0.19538329901993506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39625578177156484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25407262102225714,
                                 0,
                                 0,
                                 0.44857432530632885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032742659646047563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30094320769491267,
                                 0,
                                 0,
                                 -0.095292776808310664,
                                 0,
                                 0,
                                 0,
                                 0.18973554033534784,
                                 0,
                                 0,
                                 0,
                                 1.1889454614233474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61284304974139014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35864344173051987,
                                 0,
                                 0.81297601251677976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43921227218922382,
                                 0,
                                 0.31066882363740767,
                                 0,
                                 0,
                                 -0.15695770866100794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50991891522728139,
                                 0,
                                 -0.054622026306005961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040757111731730473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24266750021433597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53650398049595593,
                                 0,
                                 0,
                                 0.62338908815495431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14780357242240269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53047654541356926,
                                 -0.018605235979694948,
                                 0,
                                 0,
                                 0,
                                 -0.76185599386795,
                                 0,
                                 0,
                                 -0.1746308391084706,
                                 0,
                                 0,
                                 -0.0056368334485819571,
                                 -0.051613365775193445,
                                 0.2045235350704856,
                                 0,
                                 0.20104568375730464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023176319941030359,
                                 0,
                                 0,
                                 0,
                                 -0.60465816241776948,
                                 -0.38573975303936792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081460534838945414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31862484009717107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86733392974046597,
                                 0,
                                 0,
                                 0.85332933081838436,
                                 0,
                                 0.7451988954788652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22674518792440235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12736731513142852,
                                 0,
                                 0.70469143264868062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47540592430112022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22907470960740817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21069613532049622,
                                 0,
                                 0,
                                 0.4053500646434483,
                                 0.10534769452529501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58934745944310718,
                                 0,
                                 0,
                                 0,
                                 0.19875350576420375,
                                 0,
                                 -0.15623267314901187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36957648979896329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13710605155447367,
                                 0.45251700677735562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36267024328255482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14503072037605463,
                                 -0.25483273586839267,
                                 0,
                                 0,
                                 0,
                                 0.41056109312349898,
                                 0.42769285900344528,
                                 0,
                                 0,
                                 0,
                                 0.07476683800474497,
                                 0,
                                 0,
                                 -0.20163855926550084,
                                 -0.38492982613861532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54680453087643044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35380826807696575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17298486039270006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14964845148449135,
                                 0.37725029774406521,
                                 0,
                                 0,
                                 0,
                                 -0.30352666714896998,
                                 0,
                                 0,
                                 0.65234207454260751,
                                 -0.4315391674594195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23279451404031834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26840729483150211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071743426135027072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0882090677744132,
                                 -1.0176969271933205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37772294344613144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026191203029780397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73241769103007326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055777137043932591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43106136819689173,
                                 -1.3576155806298729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092513637272819721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11232089457946051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65829768423087498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7120328864567983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54667230763669084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32456278416179019,
                                 0,
                                 0,
                                 0,
                                 0.56444146132155004,
                                 0,
                                 0.50560378066978051,
                                 -0.042923282465325036,
                                 0,
                                 -0.44699984524635994,
                                 0,
                                 0,
                                 -0.73571086781801198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82920248079444347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083999701666777241,
                                 0.086855619785214055,
                                 0,
                                 0,
                                 0,
                                 -0.78570624921628673,
                                 0,
                                 0,
                                 -0.15753373402043899,
                                 0.18944072593135908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14958242607351666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28546026966346705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45110831031127291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21974627027995175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054233440694991128,
                                 0,
                                 0,
                                 0,
                                 0.18668359705922558,
                                 0,
                                 -0.35418174953882614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092489285035438948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19931534585840457,
                                 0.037343163958886455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5252262487944217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1705641072383568,
                                 -0.65866889979330245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084978168098530552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042713654733963602,
                                 0,
                                 0.086268810583423866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28879572438662487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076305800417154734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9456671726168302,
                                 0,
                                 -0.10298325890957075,
                                 -0.31727722026213023,
                                 0,
                                 0,
                                 0,
                                 -0.17848788356908327,
                                 0,
                                 0,
                                 -0.21950773381295344,
                                 -0.56959379404944099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26592217566844684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43740960798979989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47139069274728251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44000523697043981,
                                 0.34321354200656518,
                                 0,
                                 0,
                                 0,
                                 -0.26724023661577295,
                                 0,
                                 0,
                                 0.068150960067376962,
                                 0.25689078018978928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45338876217032709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054068875318242976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58142950794597248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59426607030936962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32859899089162353,
                                 0,
                                 0,
                                 0,
                                 0.0073555299725586555,
                                 0,
                                 0.36171277093585991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099903940528871693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084858168405039153,
                                 0.59169246491357674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15068067864527579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098644416949056832,
                                 -0.090902372679820889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7303254163839924,
                                 0,
                                 0,
                                 0,
                                 -0.73712067929326952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28854544394497172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011029110945527359,
                                 0.013195053146552851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64302179067335685,
                                 0,
                                 0.59976680981396169,
                                 -0.80256460630340043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1068491456279313,
                                 0.44875700716660549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061775587227489298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36707223937762457,
                                 0,
                                 0,
                                 0,
                                 -0.2718098837424926,
                                 0,
                                 -0.57830301542828089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43355602712603358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17368545700622223,
                                 0.32187708201550558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19003872698298907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17424327108972526,
                                 0.25477244653708059,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80206949001407091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14622132626459911,
                                 0,
                                 0,
                                 0,
                                 0.059208698284991618,
                                 0,
                                 -0.53687469356156881,
                                 -1.0904995249522369,
                                 0,
                                 -0.63608900445174454,
                                 0,
                                 0,
                                 -0.32427618105542982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070275875978468946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1100163858015006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51239170869954709,
                                 0,
                                 0.28966070234744307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43701105102172166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6603818785539578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11985376501869771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16341669745806503,
                                 0,
                                 0,
                                 0,
                                 0.089051652383776714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 7.5969632345903454e-05,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75849915837293103,
                                 -0.5533433084279874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028774439542240404,
                                 0,
                                 -1.0258856021574831,
                                 -0.80634445726497916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30687815919978884,
                                 -0.39397750227419948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057341710162977455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42215503001421079,
                                 0,
                                 -0.38354562653364055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56227865055214021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55925595457630339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20607112286881801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44532946662303097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0418547940241638,
                                 0,
                                 0,
                                 0,
                                 -0.10521071335012851,
                                 0,
                                 -0.081365573157453103,
                                 -0.19293763267625558,
                                 0,
                                 0.49731898878823888,
                                 0,
                                 0,
                                 -0.47099309887038721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56805662302747995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014265197395541534,
                                 -0.082098745727521433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.324834749485641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21898541413146999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69544678580040886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6126392210409044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60727715906669399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39781267799769671,
                                 0,
                                 0,
                                 0,
                                 -0.82276732408172726,
                                 0,
                                 0.51920453267850142,
                                 -0.28280067248596963,
                                 0,
                                 0.6736752914790145,
                                 0,
                                 0,
                                 -0.096530471123770861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68289919219288808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92311440124569022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5581149153961803,
                                 0,
                                 0,
                                 0,
                                 -0.66944113306122155,
                                 0,
                                 -0.17370648122628241,
                                 0.25635324946616778,
                                 0,
                                 -0.61247209013364712,
                                 0,
                                 0,
                                 -0.54357457639429352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22836457084443798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52755901688978013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33355238983570556,
                                 0,
                                 0,
                                 0,
                                 0.28059327153827085,
                                 0,
                                 0.18479397020758806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14176165275327748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031923690507315985,
                                 0.087184575006605966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081524506209510059,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63824627865806194,
                                 -0.23414033359493294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57498950898975387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04156247540804843,
                                 0,
                                 0,
                                 0,
                                 0.37534257291369993,
                                 0,
                                 -0.99784038584190438,
                                 -0.36484358382876347,
                                 0,
                                 0.38297105214780147,
                                 0,
                                 0,
                                 0.60418397107334987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58329803793842638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084966797802844357,
                                 0,
                                 0,
                                 0,
                                 0.61834915303547455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10361824298702738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50110191300749407,
                                 1.417467487985234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61137112939647775,
                                 0,
                                 -0.108612154549871,
                                 0.071694635728109329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12891337773858783,
                                 0.13677360553038176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70276263558745911,
                                 0.10509880603259338,
                                 0,
                                 0,
                                 0,
                                 0.10389178752082073,
                                 0,
                                 0,
                                 -0.19891054280318146,
                                 -0.46268168891195371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10136387138974473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28811390784607044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3706229996482886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32918291713009079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48277228416612428,
                                 0,
                                 0,
                                 0,
                                 -0.35733042598345938,
                                 0,
                                 -0.92388462935156168,
                                 0.50618247509684267,
                                 0,
                                 -0.83694005479220068,
                                 0,
                                 0,
                                 0.15839440757191203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38366372688967953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19929165922426481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27533935992967423,
                                 0,
                                 0,
                                 0,
                                 -0.27629711976975002,
                                 0,
                                 0.49581893227440327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27117095645055816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36128958066587674,
                                 0.18742020050008604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54928372425949323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099656714724216888,
                                 -0.10705283107344291,
                                 0,
                                 0,
                                 -0.069448279843879912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33865993986552406,
                                 0,
                                 0,
                                 0,
                                 -0.025371478087555736,
                                 0,
                                 -0.05713718350575718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39712774365864806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42363732358354234,
                                 0.28585164809314362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40890170429845935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23868871045197151,
                                 0.48323381111867125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28973099210891218,
                                 0,
                                 0,
                                 0,
                                 0.30505631463418625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81149839574215821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.145812949620578,
                                 -0.23894846382451518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05039482009910505,
                                 0,
                                 0.86947305371722494,
                                 -0.37787677569351297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35206640617052143,
                                 -0.70229444147728437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060362512144159969,
                                 0,
                                 0,
                                 0,
                                 0.40032982129105676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25697324807209321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63680946900659441,
                                 -0.1670602626244003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87586150598761003,
                                 0,
                                 0.77202708355621819,
                                 0.23786846485866653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85852299685446909,
                                 0.1425641204192121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099356255977104235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62887203303263695,
                                 0,
                                 -0.4516475363704332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57730873886561729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14355245937592306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19175535141069905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49187815439769123,
                                 0,
                                 0,
                                 0,
                                 -0.032437873003013401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085464332939397203,
                                 0.22902031960048178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17989772255099251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.285370813867923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24488735216951307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85185812263698146,
                                 0,
                                 0,
                                 -0.2126315356003847,
                                 0.55802840408590915,
                                 0,
                                 0,
                                 0,
                                 0.39371932012814886,
                                 0,
                                 0,
                                 0.019678342532802234,
                                 0.15866098757975544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51037149812070692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44909394183590773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02553911562826236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2359643425337529,
                                 0,
                                 0,
                                 0,
                                 0.42980728660407369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069101216507242505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66596960963476626,
                                 -0.21837750511406112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13691591353041563,
                                 0,
                                 0.26107080227134222,
                                 -0.18073101921332213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43356522769380557,
                                 0.7579698031854315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11442222360238645,
                                 0,
                                 0,
                                 0,
                                 0.43773882660236479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30383074004967792,
                                 0,
                                 0,
                                 0,
                                 0.35999246630507464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23590211657969734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42628982298849849,
                                 0.21213340749358073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1104641913428623,
                                 0,
                                 -0.10292934272376822,
                                 -0.79284639365592491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50605883406989061,
                                 -0.14519837971782026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1143106932546645,
                                 0,
                                 0,
                                 0,
                                 -0.22674354211071082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14248694550298441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25071628112446542,
                                 0.62449042821263379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16298407045207552,
                                 0,
                                 -0.21295476427123447,
                                 -0.35008621323037514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0311858587718239,
                                 -0.49696219191539365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24226293116109587,
                                 0.35540864341079415,
                                 0,
                                 0,
                                 0,
                                 -0.12595037515948981,
                                 0,
                                 0,
                                 -0.64513098831125748,
                                 0.0061294253865357973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27822103328833131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49228453869409172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25129126334794555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10820796575920984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077392673500837644,
                                 0,
                                 0,
                                 0,
                                 -0.7838784179533923,
                                 0,
                                 0.0082471098526106235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052876033329374197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25573622568282656,
                                 -0.18200989350508448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14254319180570477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36900331812275111,
                                 -0.33160445956586454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62217079341914883,
                                 0.1689820588128452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17312672188997466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44901124256273095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8542070917229807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0755806517737105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36869798144285215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23988000076479446,
                                 0,
                                 0,
                                 0,
                                 0.27904828526483627,
                                 0,
                                 -0.75995741118538362,
                                 0.74329077024858614,
                                 0,
                                 0.88814123598004557,
                                 0,
                                 0,
                                 -0.48074162686364691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031197772815149488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69760654818703383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30712683424160192,
                                 0,
                                 0.45641659659106881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22650661131352257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39677609257228053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044334967755311865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23166628104386719,
                                 0,
                                 0,
                                 0,
                                 -0.34978042736759474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.4266014446685922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061146759643309331,
                                 0.098783501324015366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55790678709337826,
                                 0,
                                 -0.455500846804617,
                                 0.32165783875414955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061475474340354393,
                                 0.56365519478196291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0160059083521205,
                                 0,
                                 0,
                                 0,
                                 0.77414753575513195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17867712490165505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33827878155749386,
                                 -0.50261302808960739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43837805582196182,
                                 0,
                                 -0.027597606765235483,
                                 0.29939526454106896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078130639394173418,
                                 -0.60304768518880614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27972759778640011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1045011998624483,
                                 0,
                                 0,
                                 0,
                                 -0.21231431834502471,
                                 0,
                                 -0.27470035886502853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63295955370369061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46288633077143143,
                                 0.3043536225070867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16916552556191305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19026881509171312,
                                 -0.1339493819359705,
                                 0,
                                 0,
                                 0.41331563765429147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29721934455218102,
                                 0,
                                 0,
                                 0,
                                 -0.19092517796454844,
                                 0,
                                 0.16154859663739213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046186082627983592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55984385271615889,
                                 0.29988604912770217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096401775649302371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51298615250725299,
                                 -0.018505164456009852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3949219346443233,
                                 -0.47935375795329621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20154380966307611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40019617285963893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020936909190277311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41671681690692042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69344103743732888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26001631669388381,
                                 0,
                                 0.59096997846741139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15770372555781612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25935959658626118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1007356034617988,
                                 0.31951016668123128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22606374888430641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21317416351036483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40959368493621884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10066952397573498,
                                 0.63611667282016293,
                                 0,
                                 0,
                                 -0.41423068172186717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15522863335316306,
                                 0,
                                 0.1521058698318212,
                                 0,
                                 -0.00051737092793749384,
                                 0,
                                 -0.29915924040473074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45710147975772469,
                                 0,
                                 0,
                                 0.015205128454658323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49008297711218279,
                                 0,
                                 0,
                                 -0.5740533149317093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40489791679938658,
                                 0,
                                 1.1690821799586022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54275093157221233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48749222841692297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85215155442818324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77344765142382454,
                                 0,
                                 0,
                                 -0.23275817284204903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070213956509181483,
                                 0,
                                 0,
                                 0.76071109047803975,
                                 0,
                                 0,
                                 0,
                                 0.15308865527584206,
                                 0.27366805016474949,
                                 0,
                                 0,
                                 -0.12813143701857022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78149240075580717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30703746543099475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37587462600642563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4529873285335263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19186141231410503,
                                 0,
                                 -0.56781072611558137,
                                 0,
                                 -0.44724592598170299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099365149967755098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0055481317617983739,
                                 0,
                                 0.60379674714683007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30790341771400559,
                                 0.71073310564509251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15281855122178967,
                                 0,
                                 0,
                                 0.017097764156713102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043970081921400832,
                                 0,
                                 0.091338703868520235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0043019712520914865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42303437679361527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2181133250187843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14512460097421764,
                                 -0.15048570074186943,
                                 0,
                                 0,
                                 0.13578880351452299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057484712641721926,
                                 0,
                                 0.83244693813825643,
                                 0,
                                 -0.081787136031244143,
                                 0,
                                 0.04657269331472122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54677862320386861,
                                 0,
                                 0,
                                 1.0564753521400125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11774935233352793,
                                 0,
                                 0,
                                 0.041514675739850765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7070155698833912,
                                 0,
                                 0.44079522239691271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12076232572394435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31705513916921191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58460614642451492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55411881496399229,
                                 0,
                                 0,
                                 -0.03133512590402289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78659051701293248,
                                 0,
                                 0,
                                 0.32375199938152122,
                                 0,
                                 0,
                                 0,
                                 0.33576265155839558,
                                 0.13313506867973166,
                                 0,
                                 0,
                                 -0.13212559140201163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75622465976054154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49002309164060726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31982420630055308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61142273255186685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29074601428757829,
                                 0,
                                 0.015088153001906357,
                                 0,
                                 -0.44608428761489549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028836796482575151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48183487443564677,
                                 0,
                                 0,
                                 0.21810375142408492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74321531371408411,
                                 0,
                                 0,
                                 -0.88014226111318483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47741762916384406,
                                 0,
                                 0.070995248196650235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23779778259031925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4581820058469161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058935667065040873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15363821536790173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13784867220535418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16636921246628306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063469641436236318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051398533919611925,
                                 -0.37255388471620676,
                                 0,
                                 0,
                                 -0.30370573343151452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55510314702369412,
                                 0,
                                 -0.15781533126066635,
                                 0,
                                 -0.59913718851959075,
                                 0,
                                 0,
                                 -0.55229561556988638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11585380942855955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13040874492753943,
                                 0,
                                 0,
                                 0.51764709380064544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52788808484304084,
                                 0,
                                 0,
                                 -0.50294696977162734,
                                 0,
                                 0,
                                 0,
                                 0.08418739575998839,
                                 -0.74146263963193237,
                                 0,
                                 0,
                                 0.57294706013982832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037504213004771102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29148429298964396,
                                 1.2296884862331494,
                                 0,
                                 0,
                                 0,
                                 1.0776443706153485,
                                 0.43788894671382461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1375342235422814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41079358846589775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0032701019306565,
                                 0.69889570820472424,
                                 0,
                                 0,
                                 0,
                                 0.089323368465448569,
                                 -0.80352669787334052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031710452125277185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0425547459850819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26570994587680935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069393045724881253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0567349701412753,
                                 0,
                                 0,
                                 -1.2445439484901377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21322688720421468,
                                 0,
                                 0,
                                 -0.52889291893247758,
                                 0,
                                 0,
                                 0,
                                 -0.3736474202622817,
                                 0.33038961681553447,
                                 0,
                                 0,
                                 0.17396348270145037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11419221052355533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56764572909076128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14711303701290834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027236872375181409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78861450601701666,
                                 0,
                                 -0.18095746134254428,
                                 0,
                                 0.027125476089316675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66549667927208522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70004316215430207,
                                 0,
                                 0,
                                 -0.26160604735827214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84644514182505326,
                                 0,
                                 0,
                                 -0.50131163331594297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063390189809520159,
                                 0,
                                 -0.11847990034941314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5989693710281796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34996428398583823,
                                 0.5790722684213151,
                                 0,
                                 0,
                                 0,
                                 -1.1985495003971001,
                                 0.72325896899511333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34932115778760309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47916231729071285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1194030048429688,
                                 -0.24634845628831575,
                                 0,
                                 0,
                                 0,
                                 0.00098747526340392522,
                                 -0.88846881069267458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34937597676261245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3478908508290906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45681884325902999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20988371021862223,
                                 0,
                                 0,
                                 0.31794774328989833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04679095091896307,
                                 0,
                                 0,
                                 -0.70479714568482055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10690124983808449,
                                 0,
                                 -0.54625843987755907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1458728027427449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47162816514942374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27618383655698436,
                                 0,
                                 0.19646072325199335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26785026002904344,
                                 -0.27960299553225015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092053018146616705,
                                 0,
                                 0,
                                 0.44419365246100323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55406605250364804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094735358855667237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7391209211050308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33637812248251625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67749161139016245,
                                 0,
                                 0.085062716730262916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0078921609077095764,
                                 -0.19930730600127289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21550663034914391,
                                 0,
                                 0,
                                 -0.12799535133380402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56392162870099249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34620770115852628,
                                 -0.43783774692971889,
                                 0,
                                 0,
                                 0,
                                 0.53697485883996532,
                                 0.10554023538168171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.5322104647324437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097664619076713255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10702578779043816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16533461825777868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29900557732374206,
                                 0,
                                 0,
                                 -0.44509743229774712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44155178106093401,
                                 0,
                                 0,
                                 -0.4310298111100328,
                                 0,
                                 0,
                                 0,
                                 0.94538816359711508,
                                 -0.23852191382357038,
                                 0,
                                 0,
                                 -0.35851208264189544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052053222509959376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56396509072574286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33650399002324138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50599112876910102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38056643764664871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11136110940280151,
                                 0.021721224324754859,
                                 0,
                                 0,
                                 0.30869937513602913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084091084407401831,
                                 0,
                                 -0.1394216707351201,
                                 0,
                                 0.18213313826622765,
                                 0,
                                 -1.4414620548184258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48187650240972235,
                                 0,
                                 0,
                                 -0.2377995253106828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.276817054997547,
                                 0,
                                 0,
                                 -0.16158155954072093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24911408357598941,
                                 0,
                                 -0.19133830794624274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36552486831289754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60261981433359568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0021307431784617498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18172442481617246,
                                 0,
                                 0,
                                 0.063071254104750535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38388353298311428,
                                 0,
                                 0,
                                 0.45209195422714976,
                                 0,
                                 0,
                                 0,
                                 0.31725416056447309,
                                 0.67444891384154126,
                                 0,
                                 0,
                                 1.0238083947720409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17923115435115441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23910437484616034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017892069446289145,
                                 0,
                                 0,
                                 -0.37316808058198248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51535948264014875,
                                 0,
                                 0,
                                 -0.56014580068522246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1802409155097824,
                                 0,
                                 -0.38342904316623161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16949788092219537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33449244180268894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22042352395105511,
                                 0,
                                 -0.28169288113038232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063566192786610159,
                                 0.28141321072540426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67285668886063998,
                                 0,
                                 0,
                                 0.031628616011704552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47244771991708512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23789225451184526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29868854626045072,
                                 0,
                                 0.11602757824338232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65273281568357977,
                                 0.17176001652979028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17253357934450464,
                                 0,
                                 0,
                                 -0.47424505054920985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36123703124498691,
                                 0,
                                 0,
                                 0,
                                 0.69917999302190137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27273752686101682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082200001954548046,
                                 0,
                                 0,
                                 -0.15811345192300469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45034022806429375,
                                 0,
                                 0,
                                 0.17621210844774149,
                                 0,
                                 0,
                                 0,
                                 0.11141279624628719,
                                 -0.18993429112454324,
                                 0,
                                 0,
                                 0.13411436279908015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75235525741561404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10963902196513219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20538822283214522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87267321179419188,
                                 0,
                                 0,
                                 0.36107419601210161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31722200289892366,
                                 0,
                                 0,
                                 0.17603206909234445,
                                 0,
                                 0,
                                 0,
                                 0.4784091638364425,
                                 0.69229257488922835,
                                 0,
                                 0,
                                 0.15610857941292483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011089923412923752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17366050045722561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44661226976225576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2180493237196181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1223201069822562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18512325131490195,
                                 -0.30712894941970337,
                                 0,
                                 0,
                                 -0.42623174052982421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14718445250550158,
                                 0,
                                 0.18892979437287996,
                                 0,
                                 0.5833024586668093,
                                 -0.64741501028359005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13071308803612791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36643989658959086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16880299183720779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054393476442859107,
                                 0.49078196629497928,
                                 0,
                                 0,
                                 0.032031535436447579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24031790077788318,
                                 0,
                                 0.27531766159918819,
                                 0,
                                 -0.1503034563965488,
                                 0,
                                 0,
                                 -0.29832383143590929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25809654154849104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45559057873162451,
                                 0,
                                 0,
                                 0.041345381176337632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26588450674531605,
                                 0,
                                 0,
                                 -0.77221669525578396,
                                 0,
                                 0,
                                 0,
                                 -0.20297034709179745,
                                 0.69916441742336255,
                                 0,
                                 0,
                                 -0.22358862356170137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5063651713649262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28322823856368085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72241257556684146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30177841470337052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024756268792326477,
                                 0,
                                 -0.39662547651287983,
                                 0,
                                 0.38588467512785851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052053416584651534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22166444530912846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34962679383032352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58639570509793515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53915437374956143,
                                 0.19197098549238772,
                                 0,
                                 0,
                                 -0.071573366673922167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29799250354440915,
                                 0,
                                 -0.18207778955879814,
                                 0,
                                 -0.16565506073092451,
                                 0,
                                 0,
                                 0,
                                 -0.51293086194104565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31118516813944458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12514419068576704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49545065816557243,
                                 0,
                                 0.35385099770641781,
                                 0,
                                 0.50370901350037456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063473882498745637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18429267809374941,
                                 0,
                                 0.43503315424832162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34666106502575567,
                                 -0.44339163259876591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30772387213686792,
                                 0,
                                 0,
                                 -0.59879873826723373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052244477694740277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0082089264974542497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34069393702045414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55990320149719663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10324188597194398,
                                 0,
                                 -0.60174365550012521,
                                 0,
                                 0.44453835132950537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35084976985717153,
                                 0.79071941822084291,
                                 0,
                                 0,
                                 0,
                                 -0.53754794888465263,
                                 -1.0426954961081263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4549723052946234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90789699360598886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66098163852261904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40583190770262351,
                                 0,
                                 -0.29881750902034465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29406905158854962,
                                 0.26144045079325556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1862661815227683,
                                 0,
                                 0,
                                 -0.34330982418727085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041561885827548939,
                                 0,
                                 0,
                                 0,
                                 -0.97966661595422211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78522171907965677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084092515521157471,
                                 0,
                                 0,
                                 0.30160864283981181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30508355992712882,
                                 0,
                                 0,
                                 0.68689610696142156,
                                 0,
                                 0,
                                 0,
                                 0.29526391020512144,
                                 -0.54304724107409308,
                                 0,
                                 0,
                                 -0.2546235492716532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21706049832247706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18164004604381018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63354458611258591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19236813157463994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32950266440699227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55134064691050755,
                                 0.18504960273343135,
                                 0,
                                 0,
                                 0.19841716533771181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089168012688571469,
                                 0,
                                 -0.12634966511176837,
                                 0,
                                 -0.136184576641349,
                                 0,
                                 0.1203065717918603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43094138225889961,
                                 0,
                                 0,
                                 -0.091097531879916538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57503930868881414,
                                 0,
                                 0,
                                 0.50051395036534718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18023580505457312,
                                 0,
                                 0.84228098933535045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77725400730241523,
                                 0,
                                 0,
                                 0,
                                 0.15310019572040018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22606341451964046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25912423205466939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26397523060690598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063820046491678398,
                                 0.1443084673628641,
                                 0,
                                 0,
                                 0.27365399140511498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6786525890982662,
                                 0,
                                 -0.22960155746085018,
                                 0,
                                 0.41899489459562855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2124608691534666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35809512293227314,
                                 0,
                                 -0.46715947961242299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44343899999440306,
                                 0.057576623601202997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55662967305042055,
                                 0,
                                 0,
                                 -0.28928628373285736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12212256728953474,
                                 0,
                                 -0.19865213411919097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3138033071466817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28927407208066624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26500730566267489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56373324959412052,
                                 0.07953078222788787,
                                 0,
                                 0,
                                 -0.56600682434458061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14371153415254725,
                                 0,
                                 -0.16193857475078133,
                                 0,
                                 0.12959667795054364,
                                 -0.055022652516292639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2522492987958117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035368510189730432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30236731571132514,
                                 -0.88061069971118044,
                                 0.25532463531309213,
                                 0,
                                 0.13685940475655148,
                                 -0.11235866003731221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0268722054765402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1095874850414288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35224812270192785,
                                 0,
                                 0,
                                 0.86185628328689912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25287260139567896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69505301148346765,
                                 0.4520128755867231,
                                 0,
                                 0,
                                 0.46534496265545922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012015949461772549,
                                 0.13304911382436188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35067391072110699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64845251048002606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2012792935654546,
                                 0,
                                 0,
                                 -0.093579356550350337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67360701719997795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046575075758857602,
                                 -0.11635904137009948,
                                 0,
                                 0,
                                 -0.11186188776390843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1256085272689364,
                                 0,
                                 0,
                                 0,
                                 0.43717562936527893,
                                 0,
                                 -0.064729641677381766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24827970483985107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57845249157577949,
                                 0.5525411296981716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29476711961224117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02169305871701023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4739739232236021,
                                 0,
                                 0.2854440458872155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85809803922797356,
                                 -0.42814163618576861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37510612721652348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017982095706769563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66428632387259334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18472861675567906,
                                 0.02119108239239182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40230912260311713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037212353176700783,
                                 -0.10238449113074638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19205275610523911,
                                 0.045452682259952047,
                                 0,
                                 0,
                                 0,
                                 -0.54441108198459776,
                                 0,
                                 0,
                                 -0.12286720096016451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84013759875228788,
                                 0,
                                 -0.21040943356478584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13929820024370548,
                                 0.84175603732597171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23248990827339724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57580824266164421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11391145709415933,
                                 0,
                                 0,
                                 0,
                                 0.57225463958756084,
                                 0,
                                 -0.1341282499242995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16904794787444366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22554928687441927,
                                 -0.57896681074906875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44659081683321078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16571905402402809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46025545109273147,
                                 0,
                                 0,
                                 0,
                                 0.70151834007424752,
                                 0,
                                 0.31974845691491771,
                                 0.58364099242181133,
                                 0,
                                 0.076290100419708906,
                                 0,
                                 0,
                                 -0.9317129310818677,
                                 0.57693162756024763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1400491132189674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52615015827978184,
                                 0,
                                 0,
                                 0,
                                 -0.070931425331997061,
                                 0,
                                 -0.39736249503444043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30146963780465946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18304512976210935,
                                 0.27840521798432633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29508120514646285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52083197511601254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27366879714733289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42204981101593086,
                                 -0.0020706776305851118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39382448750231902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18978518314333165,
                                 -0.33310732430827306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26688757193565799,
                                 -0.11758648956483689,
                                 0,
                                 0,
                                 0,
                                 0.10697475117824383,
                                 0,
                                 0,
                                 -0.59025356467109069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032363905725105342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32473944344463268,
                                 0.12904860197842039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43982632668651256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27467916357744415,
                                 0.32569013290192933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49681039273486272,
                                 -0.49131794192348127,
                                 0,
                                 0,
                                 0,
                                 -0.059643992773865367,
                                 0,
                                 0,
                                 0.10050937431786205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19913892825442128,
                                 0,
                                 0,
                                 0,
                                 0.49251362394804998,
                                 0,
                                 0.64966847734031163,
                                 -0.44400889432932478,
                                 0,
                                 -0.19370925012670537,
                                 0,
                                 0,
                                 0.38518139952717362,
                                 1.0561537868396997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50246112530153964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46627098233490383,
                                 -0.26824349894446792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19969480103514328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20294132824570221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060524587478386502,
                                 0,
                                 0,
                                 0.54956933249906248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56312052935382517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3046243644603045,
                                 -0.82239465193243788,
                                 0,
                                 0,
                                 -0.21242480680216511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23426726955429883,
                                 0,
                                 0,
                                 0,
                                 0.68506025172992968,
                                 0,
                                 0.011116667220880949,
                                 0.10132309357072358,
                                 0,
                                 -0.51018676589280565,
                                 0,
                                 0,
                                 0.33008292348580071,
                                 0.18859925885470002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.5390752126470939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29381668388239385,
                                 0,
                                 0,
                                 0,
                                 0.088420050548920076,
                                 0,
                                 0.98168212405961452,
                                 0.0015675697003276132,
                                 0,
                                 0.92592776440663671,
                                 0,
                                 0,
                                 0.46532001832877756,
                                 -0.51166084671447687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04004509010251886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086626275357480242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46310670338791482,
                                 0.20425710537436015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18373996363884162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23341763811939872,
                                 -0.15026274942173512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54721778117777253,
                                 -0.20606984072147624,
                                 0,
                                 0,
                                 0,
                                 0.087525989686511166,
                                 0,
                                 0,
                                 -0.52527246696284369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9452931122795436,
                                 0,
                                 0,
                                 0,
                                 -0.74875492483882744,
                                 0,
                                 0.42315515345155347,
                                 -0.35300661105932102,
                                 0,
                                 -0.88145457283591733,
                                 0,
                                 0,
                                 -0.14459766331033613,
                                 -0.55299795113770756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073624088963488793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2228411417164817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062692384067198167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14271777167804975,
                                 -0.97101507136201892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29623109712537188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35902344197383568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0085107875807225539,
                                 0,
                                 0,
                                 0.21901700764026211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62660040824808794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8008224583519562,
                                 -0.94901656231982778,
                                 0,
                                 0,
                                 0.14723868623874439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78552083063692169,
                                 0,
                                 0,
                                 0,
                                 -0.15085977784133242,
                                 0,
                                 -0.21991207253867556,
                                 0.95083136003176461,
                                 0,
                                 -0.011327104305320634,
                                 0,
                                 0,
                                 0.98433948302344942,
                                 0.5350016389163903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07914189818697516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16161133968539473,
                                 0,
                                 0,
                                 0,
                                 -0.99236084601192209,
                                 0,
                                 0.51070896784989839,
                                 0.87062456770384311,
                                 0,
                                 -0.08611009918491766,
                                 0,
                                 0,
                                 -0.52901759279510174,
                                 0.40097562498099698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22487303788859964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4235313424672143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22122109501020035,
                                 0.50843799825806024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15428269424187838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44529224603647349,
                                 -0.33271179346697394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067657900421675049,
                                 0.077770463109745655,
                                 0,
                                 0,
                                 0,
                                 0.41193268131089616,
                                 0,
                                 0,
                                 -0.0085667385413750463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33393018889780635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33138287378275949,
                                 0.19915137564192134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14964303458759173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41550588591729032,
                                 -0.14333323497838246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37902080925513193,
                                 -0.53407934324000972,
                                 0,
                                 0,
                                 0,
                                 -0.30717821170391696,
                                 0,
                                 0,
                                 -0.013273346771260493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70573267426282826,
                                 0.61018350318852344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16170422554467642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65602527997729365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63001247480324973,
                                 0,
                                 0,
                                 0.27229629055724047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12105472153479152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4849463466152511,
                                 -0.30516546628895258,
                                 0,
                                 0,
                                 -0.73292445856110877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0801602521121699,
                                 0,
                                 0,
                                 0,
                                 -0.41989294952354372,
                                 0,
                                 0.55810524036243836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073361710873300845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3638500958513079,
                                 -0.24505518151339106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43792668989142053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34085499119513502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10044823375740794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67239332847545796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69138052212371048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058791235851982308,
                                 0.18240560503290229,
                                 0.15186218628821313,
                                 0,
                                 0.30584713825981252,
                                 -0.65373831891504697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39750745319634773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11614690215831892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7564063320213904,
                                 0,
                                 0,
                                 -0.97815059171513896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16931914549420113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34789874691586309,
                                 -0.046222476640985805,
                                 0,
                                 0,
                                 -0.49727277668337289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044108478081178383,
                                 0,
                                 -1.4154977886837257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21491838113652606,
                                 -0.45210189676042095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31300856675766503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25935519225099141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17630967167152622,
                                 0,
                                 -0.27679778103024938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1420035625496272,
                                 -0.54167472396656158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3502005402631729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12270926619330004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28937676091203091,
                                 0,
                                 0,
                                 0,
                                 -0.29728319910777434,
                                 0,
                                 -0.15857650792558045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27031848975019385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17422237495300924,
                                 0.13356800741948613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64032484003630263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52101386324916099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64819490330771479,
                                 0,
                                 0,
                                 0,
                                 -0.25084822586781363,
                                 0,
                                 -0.10210203979806483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30824461593941233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32194541449588476,
                                 0.23603124872029752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03375073102445611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50097929396955709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23697109487320839,
                                 0.10866847236457262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42946274977639981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66130079677026499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18200776716921666,
                                 0,
                                 0,
                                 -0.23542807914383193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30672925215391078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71062595314038191,
                                 -0.61960227910270005,
                                 0,
                                 0,
                                 0.62852251900831357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2441788318777518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036971510616949727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058538284485653874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84333911977061893,
                                 -0.15253198966658435,
                                 0.44843750501922269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34347704199824525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14231660223476353,
                                 -0.042091052802161646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25916384277971616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49210653351760558,
                                 -0.26644300938154436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33974342467542712,
                                 0.55626375197936329,
                                 0,
                                 0,
                                 0,
                                 -0.21947986849850754,
                                 0,
                                 0,
                                 -0.081516044964589307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19735230319725922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38565033332893833,
                                 -0.52492486461277976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50849003488853139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27530530454532742,
                                 -0.08853449857009682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14306527139461631,
                                 -0.10938357781907825,
                                 0,
                                 0,
                                 0,
                                 -0.28346855171594099,
                                 0,
                                 0,
                                 -0.2860060013720444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40982686516165917,
                                 0,
                                 0,
                                 0,
                                 0.01696800720196329,
                                 0,
                                 -0.47313280464312119,
                                 -0.63425146522257059,
                                 0,
                                 0.62269363596989369,
                                 0,
                                 0,
                                 0.058847747226528677,
                                 0.3714679593179665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48016721957577385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42900719588939767,
                                 0,
                                 0,
                                 0,
                                 0.13971712341319845,
                                 0,
                                 -0.056626270979593718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76099636546168825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33094067498602875,
                                 -0.15362935295368471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14113184695044143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24711948894509395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37901777276542792,
                                 0,
                                 0.17618909020637566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27327843713650468,
                                 -0.32270153674027646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092652325535960756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.58683814263914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0076731012635065238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064888525938803218,
                                 -0.14216479345619826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047224267254813719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25109679721660277,
                                 -0.733410509802771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22664833669167656,
                                 -0.23813408416319073,
                                 0,
                                 0,
                                 0,
                                 -0.061936595523580218,
                                 0,
                                 0,
                                 0.51032892619397718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3698984502374264,
                                 0.92949702148313396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56189216995064051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25985103395558456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4534498554791605,
                                 0,
                                 0,
                                 -0.34964893116306145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14149791213736393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55100100149567588,
                                 -0.34610382918061516,
                                 0,
                                 0,
                                 -0.035418507247586994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38158232125413344,
                                 -0.0031309768049583298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84191139953075189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36463043665884887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37905485185034338,
                                 0,
                                 0,
                                 -0.18926217072400317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16872695065370574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52969737070792777,
                                 -0.84876111997405623,
                                 0,
                                 0,
                                 0.28865238801167364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1655478174369644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36862131346476157,
                                 0.58776957759548598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28581066999524807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28411724712765229,
                                 0.044059114820133721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10060713741971082,
                                 0.1756656230609929,
                                 0,
                                 0,
                                 0,
                                 -0.53342835474634753,
                                 0,
                                 0,
                                 0.036899856161554362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051485528082475356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35298668679435108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3902444309859461,
                                 -0.045516677728420711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77495003030651322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.589854680014542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.036533284875055153,
                                 0,
                                 0,
                                 0.21012137345201981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0060852188651488309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51870448259334978,
                                 -0.0037577138983066281,
                                 0,
                                 0,
                                 0.56590639116466812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0066562893993314665,
                                 0,
                                 0,
                                 0,
                                 0.35949649919398724,
                                 0,
                                 0.68531992844123513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25751077441805115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4528838771585692,
                                 0.35324366036493293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061180661405040124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033388538609281732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3755093402404461,
                                 0,
                                 -0.30355223206545889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78450030788479952,
                                 0.89166627657284581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5572307843748695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25988460076892222,
                                 0,
                                 0,
                                 0,
                                 0.70387469321972662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24362653875727536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47860612226461474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015867352764498736,
                                 0.17524604642319264,
                                 0.43032517462739928,
                                 0.6539074612109016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30074330881541012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34308938900165831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32681324109252596,
                                 -0.35741638654475211,
                                 -0.36013163927351832,
                                 0.064998511717232366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57713965580033333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41296629674790392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2946829798340711,
                                 0.097618301447280606,
                                 0.62910766768987969,
                                 0.54685361708090086,
                                 -0.19210371092213921,
                                 0,
                                 0,
                                 0.27386179944071964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16780357326113454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37516874399043015,
                                 0.28423991769204066,
                                 0,
                                 0,
                                 0,
                                 -0.052302448187938055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58018057359754649,
                                 0,
                                 0,
                                 0,
                                 0.17386061310255163,
                                 -0.47857258133962588,
                                 0,
                                 0,
                                 -0.16228726591762069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69397972851807255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036694188907485423,
                                 -0.014303840470957063,
                                 0,
                                 0,
                                 0,
                                 -0.093865228462966369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47162909882904486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71927113202832083,
                                 0,
                                 0,
                                 0,
                                 0.086890856816052825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072820630381584817,
                                 0,
                                 0,
                                 0.22351008015861387,
                                 0,
                                 -0.26819523673346418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10917737991907395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55915499429435311,
                                 0,
                                 -0.022115388250809692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11434504099001035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098857704593302329,
                                 0,
                                 0,
                                 0,
                                 -0.45871168720655231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18246719296024111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11399902270664787,
                                 0,
                                 0,
                                 -1.0768769287448974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44290991862335005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043937468429948223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0011701790437264187,
                                 -0.37373710421623507,
                                 0,
                                 0,
                                 0.022414822458563632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11723248701028099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66186434505544822,
                                 0.022426356828532668,
                                 0,
                                 0,
                                 0,
                                 -0.58164831941421247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26304221547680551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27029437713369919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48675192853565208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64411070896698908,
                                 0.58988956072233434,
                                 0,
                                 0,
                                 0,
                                 -0.29621448307907489,
                                 0,
                                 0.06180947015069925,
                                 0.29409801683023007,
                                 0,
                                 0,
                                 0,
                                 -0.06115609878105159,
                                 0,
                                 0.55728371783257979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1896643661660917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14939257379458212,
                                 0,
                                 0,
                                 0,
                                 -0.34940396187213985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038482221552748885,
                                 0,
                                 0,
                                 -0.13412959313698944,
                                 0,
                                 0.0045815122520065782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77662544454999272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010998777935897999,
                                 0,
                                 -0.2057171518018775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42295416595747504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1078345197653196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66873326357750174,
                                 0.072209564337793075,
                                 0,
                                 -0.70276077185218921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1247521336728053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14648453105486112,
                                 0.12918237439591385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24849147479442241,
                                 -0.29509045666237765,
                                 0,
                                 -0.15805143945898117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87815151427431859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020099888049682532,
                                 -0.23375043166663473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65236199269206596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73771597693501645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84744900803889012,
                                 0,
                                 0,
                                 0.024246966176706575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2805229870905992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49107814872330163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017398757045422899,
                                 0.7361871305818336,
                                 0,
                                 0.10890619787396708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14548302909104513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40588446217375024,
                                 -0.50986049434724501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50939211119211114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060435880014381139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31911508419805956,
                                 0.17675749087752782,
                                 0,
                                 0,
                                 0,
                                 -0.081827605676944914,
                                 0,
                                 0.20885020176649893,
                                 -0.70971741605282512,
                                 0,
                                 0,
                                 0,
                                 0.76795660351020656,
                                 0,
                                 0.42143628519212306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29667765330280416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1853505594619545,
                                 -0.31716356895106718,
                                 0,
                                 0,
                                 -0.10897076333884494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19853402129309417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3192242351159803,
                                 -0.1823094055128246,
                                 0,
                                 0,
                                 0,
                                 0.70679343421723861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42315985807668982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.99582050724261229,
                                 -0.54288530424876202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55589146811372103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49322837584324924,
                                 0,
                                 0.18547302243446306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18215514713353109,
                                 0.87837820552850465,
                                 0,
                                 0,
                                 -0.15097574692447169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17168645364559015,
                                 -0.042316899580233727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44510188455102329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22602486932857541,
                                 0,
                                 -0.82951284118760016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55651748035144388,
                                 0.37943685969289931,
                                 0,
                                 0,
                                 -0.74414616520732735,
                                 0,
                                 0,
                                 0,
                                 0.043227325004187939,
                                 0,
                                 0,
                                 0,
                                 0.14432308609111832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66344944954094209,
                                 0,
                                 0,
                                 -0.40132975126460774,
                                 0,
                                 0.25823455866818806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25312304622102516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050176743738401371,
                                 0,
                                 -0.086543346879015728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42682301275887746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23049902235646053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14906994202096585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70580213967420224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2547213998069312,
                                 -0.40145113362340579,
                                 0,
                                 0,
                                 0,
                                 0.50241062834959216,
                                 0,
                                 -0.57342196492578112,
                                 -0.04715844949107658,
                                 0,
                                 0,
                                 0,
                                 0.56501150804778533,
                                 0,
                                 -0.12776280781822488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27284359598753283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45637492299534044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20651745313334324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71237321392300068,
                                 -0.13141595497924871,
                                 0,
                                 0,
                                 0,
                                 0.0080854166900437077,
                                 0,
                                 0.14041377427751714,
                                 -0.37722218773642485,
                                 0,
                                 0,
                                 0,
                                 -0.40834984612552339,
                                 0,
                                 -0.46000185406623473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0133109051954381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2172122475202066,
                                 0,
                                 0,
                                 0,
                                 0.09144257946059775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39464157114591242,
                                 0,
                                 0,
                                 0.38523675852362349,
                                 0,
                                 -0.29662597822689907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14095093160798761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65100374749436707,
                                 0,
                                 0.059177877233497128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078448359321402483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31462927840317118,
                                 0,
                                 0,
                                 0,
                                 -0.70498061941437118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51172458596149295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2258344705482112,
                                 0,
                                 0,
                                 -0.18672068927405167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42640246904937379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67011626711458161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17351000612056602,
                                 0,
                                 0,
                                 0,
                                 -0.037974489069117337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10454665284511672,
                                 0,
                                 0,
                                 0.14996819101579206,
                                 0,
                                 -0.029520215139844604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33158488436001798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28832264845374633,
                                 0,
                                 -0.15564381963107035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26646876935402442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80364869385732274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1621013061938214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34105135177535056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28028684261301046,
                                 0.39439110836423086,
                                 0,
                                 0,
                                 0,
                                 0.20644170548079155,
                                 0,
                                 -0.75520764760936132,
                                 -0.17408290052041744,
                                 0,
                                 0,
                                 0,
                                 -0.44106347353843789,
                                 0,
                                 0.40983547364927742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022086321484394322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49206312252407775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0598212066448678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40439780328121527,
                                 0,
                                 0,
                                 0.21183609882941309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4765339114968663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38847407274850604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.4558654058913434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28583020781538776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23764245718371305,
                                 0.1148450131401792,
                                 0,
                                 0,
                                 0,
                                 0.03553155736175842,
                                 0,
                                 -0.1689799042539199,
                                 -0.24237100349659316,
                                 0,
                                 0,
                                 0,
                                 0.099828756286857834,
                                 0,
                                 -0.27359367425759262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56029624703795455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2907946355094167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20466153128570916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54311044230448413,
                                 -0.10175005435282694,
                                 0,
                                 0,
                                 0,
                                 -0.055364842963852801,
                                 0,
                                 -0.26099336347024871,
                                 -0.8737503946246955,
                                 0,
                                 0,
                                 0,
                                 0.21451744868876663,
                                 0,
                                 -0.20907514419149265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57614931221290444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17506428292824336,
                                 0.52507112225696839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69547658464447482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39856494821027622,
                                 0,
                                 0.45170645975411905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53972770728946917,
                                 0.12781358038094412,
                                 0,
                                 0,
                                 0.53733097030789723,
                                 0,
                                 0,
                                 0,
                                 -0.0013253804758233678,
                                 0,
                                 0,
                                 0,
                                 0.36501096784651571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29465402160061499,
                                 0,
                                 0,
                                 -0.48656611609000039,
                                 0,
                                 -0.5934166471007416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054666074902313476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17049659691708746,
                                 0,
                                 -0.37696028735418807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11018495861543345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068971655315600747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39751592243857109,
                                 0.14684958733121853,
                                 0,
                                 0.17251245210451815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078661726008793315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80946382753610702,
                                 -0.35949462965288131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34946933930157348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41639335802370203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11561886818007794,
                                 0.76647113273471557,
                                 0,
                                 0,
                                 0,
                                 0.89951165961846535,
                                 0,
                                 0.4718474440995184,
                                 -0.078646361045523652,
                                 0,
                                 0,
                                 0,
                                 -0.1206622453485888,
                                 0,
                                 -0.066080411705431136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46792996246953955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43785091449180186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40991105708078895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35617162690916793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60397326152140463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52199262913820088,
                                 -0.10074120781307594,
                                 0,
                                 0,
                                 0,
                                 -0.18777792397071885,
                                 0,
                                 -0.19055398008965962,
                                 0.80195747601125844,
                                 0,
                                 0,
                                 0,
                                 0.45145770587954548,
                                 0,
                                 -0.004650048032652631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43190956359345878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5249478044595457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051699345353696316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39616576071714005,
                                 0,
                                 0,
                                 0.50631832078847416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87609079851377558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1547310503715606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58951922115414634,
                                 0,
                                 0,
                                 0,
                                 0.12693226665969198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26919857302181199,
                                 0,
                                 0,
                                 -0.40404929245911853,
                                 0,
                                 0.43850104312688937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018106562808029469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33657882878436518,
                                 0,
                                 0.2869784797978987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11011034448002707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015947691437267528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.067623478508205534,
                                 -0.77576165971231326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033937793467130828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63774324833211571,
                                 0,
                                 -0.3708882609409484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39563421503035501,
                                 -0.27202171657748797,
                                 0,
                                 0,
                                 0.80507077413427908,
                                 0,
                                 0,
                                 0,
                                 0.053305665132343527,
                                 0,
                                 0,
                                 0,
                                 0.68781662020118539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14022688674209838,
                                 0,
                                 0,
                                 0.37305033846190555,
                                 0,
                                 0.41108788971375593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22142263929130987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028670409610453501,
                                 0,
                                 -0.35802381150397444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13487223321440245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0046763986729493612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1156787586760448,
                                 -0.24393023024899049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55971205633395626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6130976611154233,
                                 0,
                                 0.090012539307365552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77237626386021652,
                                 0.77292301695859333,
                                 0,
                                 0,
                                 -0.039363800472748373,
                                 0,
                                 -0.31368682174185664,
                                 0.50469275093308563,
                                 0,
                                 0,
                                 0.061189950209500743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56734887935190814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22520825565802843,
                                 0.48395612906985663,
                                 0,
                                 0,
                                 0,
                                 -0.084794901272526008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17068794787550301,
                                 0,
                                 0,
                                 0,
                                 0.55945869223223388,
                                 0.38221857512349394,
                                 0,
                                 0,
                                 0.39281573192931224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14345974882940399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42717682916844507,
                                 -0.3725229225885584,
                                 0,
                                 0,
                                 0,
                                 0.14290508806624644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15606023934192534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32521989248732341,
                                 -0.5866457912536438,
                                 0,
                                 0.16823575157503659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22674689973397646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33330223876141069,
                                 -0.59939213385275991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47640130702076894,
                                 -0.0042218805831911455,
                                 0,
                                 0.64126645464749188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36676925674140903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21696545710131365,
                                 0.42450866571985385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060924390424240055,
                                 0,
                                 0,
                                 0,
                                 0.20803088206572812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45197418993132321,
                                 0,
                                 0,
                                 -0.24426226766146919,
                                 0,
                                 -0.038781537217761779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29177193917531302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15725993678587885,
                                 0,
                                 -0.14534144966992302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65922966170416208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34927525433595352,
                                 0.012913330719385635,
                                 -0.25714750389804364,
                                 0,
                                 0,
                                 0.43548396226134706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2646036077397263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.202881534377293,
                                 0.62498789611428185,
                                 0,
                                 0,
                                 0,
                                 0.3219500098541655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37232305916673802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18651420040206118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25500237729709646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02668673124048275,
                                 -0.78685716728663324,
                                 0,
                                 0,
                                 0,
                                 0.29295233275258625,
                                 0,
                                 0.34226107630638219,
                                 0.11795110636660192,
                                 0,
                                 0,
                                 0,
                                 -0.099739700341520021,
                                 0,
                                 0.67288713654466437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075466378385777994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44696958050187036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42538131493727005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27947199084528856,
                                 0,
                                 0,
                                 0.0086038667207870949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38625776759515079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0899130750478665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.203992895570156,
                                 0.09187425689587049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56682816227199773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20925029018361996,
                                 0,
                                 -0.066227885978027576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33916610030371958,
                                 0.021140348953623763,
                                 0,
                                 0,
                                 0.33217891632642238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040479101947582793,
                                 -0.77586322729692303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62318247373665248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16213526886567156,
                                 0,
                                 0.80516719065245945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053546161614855307,
                                 -0.38177548962824764,
                                 0,
                                 0,
                                 -0.60986835005268658,
                                 0,
                                 -0.47413838162113536,
                                 -0.16389522667643924,
                                 0,
                                 0,
                                 0.73388746818223471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15682590321887258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20874316205754323,
                                 -0.34880750495309876,
                                 0,
                                 0,
                                 0,
                                 -0.13898992174625682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024236095118744239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19137024638871822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37303126489899091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58350485617601766,
                                 0.43730369335587777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046028939687768375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0594157092300294,
                                 0,
                                 0.011880067489792243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44911714665636537,
                                 -0.55718661946907622,
                                 0,
                                 0,
                                 -0.41423916852757692,
                                 0,
                                 0,
                                 0,
                                 -0.16458271225919072,
                                 0,
                                 0,
                                 0,
                                 -0.41715768266552178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056089372696856099,
                                 0,
                                 0,
                                 0.035441249056207692,
                                 0,
                                 0.23996474909766691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2314544541876718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09931821138657082,
                                 0,
                                 -0.7404145458589757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26769025295844195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23151625260446157};

const double rot_25_20[4000] = {-0.012896885078217634,
                                0,
                                0,
                                0,
                                0.48965836576108901,
                                0,
                                0,
                                0.2761429212333178,
                                0.60269355397611091,
                                0,
                                0,
                                0,
                                0,
                                0.2087698368208486,
                                0.089022048752971067,
                                -0.12829349739049151,
                                0,
                                0,
                                -0.50259818029989844,
                                0,
                                0,
                                0.2426291205982507,
                                0.39896939847732971,
                                0,
                                0,
                                0.17984730583340833,
                                0,
                                0,
                                0,
                                0.80865124857622339,
                                0,
                                -0.13009252932504708,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28065738452915628,
                                0,
                                0,
                                0,
                                -0.80822865845893554,
                                0.32750448428572204,
                                0,
                                0,
                                0.099064067538706557,
                                0,
                                0,
                                0,
                                0.2177555732577019,
                                0,
                                0.26448417140795977,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33514801555574858,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28230352910448858,
                                0,
                                0,
                                0.34660020371207967,
                                0,
                                0,
                                0,
                                -1.2777182850953319,
                                0,
                                0.46171954938284382,
                                0,
                                0,
                                0,
                                -0.34286053103622549,
                                0,
                                0,
                                0.050576957864560956,
                                0.5040877188503704,
                                0,
                                0,
                                0,
                                0.50470968391261517,
                                0,
                                0,
                                0.0047614882671236092,
                                -0.52127823688104802,
                                0,
                                0,
                                0,
                                0,
                                0.28313700760962907,
                                -0.31250793106343061,
                                0.16267192670447189,
                                0,
                                0,
                                -0.12296384370740933,
                                0,
                                0,
                                -0.47654836525911215,
                                0.040105707465507963,
                                0,
                                0,
                                -0.037430979737827524,
                                0,
                                0,
                                0,
                                -0.1642551342460975,
                                0,
                                -0.67074610647231026,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54130584800042381,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.4730033272592267,
                                0,
                                0,
                                0.59602840758730269,
                                0,
                                0,
                                0,
                                0.27296119966457433,
                                0,
                                -0.012037835200474993,
                                0,
                                0,
                                0,
                                0.024477233925587281,
                                0,
                                0,
                                -0.48995402984302755,
                                -0.11963506980218856,
                                0,
                                0,
                                0,
                                -0.28408353492515925,
                                0,
                                0,
                                -0.28705825232853349,
                                0.030357022918900196,
                                0,
                                0,
                                0,
                                0,
                                -0.17421959402612699,
                                -0.35298702786239317,
                                0.48817501588554452,
                                0,
                                0,
                                -0.65451726583095993,
                                0,
                                -0.41304469645601016,
                                0,
                                0,
                                0,
                                0.13519419158304224,
                                0,
                                0,
                                -0.61601798065379065,
                                -0.24885626359710966,
                                0,
                                0,
                                0,
                                0,
                                0.41572904523959331,
                                0.25465819171331233,
                                -0.30388478759559406,
                                0,
                                0,
                                -0.19920245750729171,
                                0,
                                0,
                                0.0057796550139811113,
                                0.2030632276488929,
                                0,
                                0,
                                0.59680619545782321,
                                0,
                                0,
                                0,
                                -0.33729396711625304,
                                0,
                                0.47289279899561959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51493637144113313,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47786324254710411,
                                0,
                                0,
                                0.43004654631914113,
                                0,
                                0,
                                0,
                                -0.41477671211728645,
                                0,
                                0.61502298114694764,
                                0,
                                0,
                                0,
                                0.99388011271670562,
                                0,
                                0,
                                -0.81790065492900599,
                                0,
                                0.15824546067119855,
                                0.75219513269055904,
                                0,
                                0,
                                -0.55274270454598462,
                                0,
                                0,
                                0,
                                -0.3032122245606817,
                                0,
                                0.088185039768452544,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.062626709499861474,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11138077601014615,
                                0,
                                0,
                                -0.36543539972048494,
                                0,
                                0,
                                0,
                                0.66666615602766266,
                                0,
                                0.58572567807623921,
                                0,
                                0,
                                0,
                                -1.1582433187946191,
                                0,
                                0,
                                -0.32371724099099342,
                                -0.5489702139977789,
                                0,
                                0,
                                0,
                                0.01643627753047272,
                                0,
                                0,
                                0.38616632516402577,
                                -0.19471409759634073,
                                0,
                                0,
                                0,
                                0,
                                0.064424837649732752,
                                -0.63710255095465795,
                                -0.31821054591122111,
                                0,
                                0,
                                0.003920556399805139,
                                0,
                                0.23501671912268013,
                                0,
                                0,
                                0,
                                0.13078539553027579,
                                0,
                                0,
                                -0.19077955863848289,
                                -0.10847946124095627,
                                0,
                                0,
                                0,
                                0,
                                -0.67813475152471103,
                                -0.055282139204267812,
                                -0.59356869325297223,
                                0,
                                0,
                                -0.25347788620085815,
                                0,
                                -0.33198120884929533,
                                0,
                                0,
                                0,
                                0.20177840179875517,
                                0,
                                0,
                                0.40369014800281383,
                                -0.45929709335458674,
                                0,
                                0,
                                0,
                                0,
                                -0.30318317248521953,
                                0.51331205064476915,
                                0.26220745575593102,
                                0,
                                0,
                                -0.22581485936637488,
                                0,
                                0,
                                0,
                                0,
                                -0.45425788590655547,
                                0,
                                0,
                                -1.376423182312061,
                                0,
                                0,
                                0,
                                0.22735696324937749,
                                0,
                                0.77412425724401079,
                                0,
                                0,
                                0,
                                0.74259485699374617,
                                0,
                                0,
                                0.43097052552500142,
                                0,
                                -0.18900838821898308,
                                -0.35344528857167856,
                                0,
                                0,
                                -0.5428978232571624,
                                0,
                                0,
                                0,
                                0.25686775973069031,
                                0,
                                0.48147639294135564,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4968034296611672,
                                0,
                                0,
                                0.30659108550233738,
                                0,
                                0,
                                0,
                                -0.5902816287299758,
                                0,
                                0,
                                0.33668207003642009,
                                -0.20382173019567956,
                                0,
                                0,
                                0,
                                0,
                                0.34223989707123609,
                                0.18032801980664745,
                                -0.3226194624159287,
                                0,
                                0,
                                -0.38592969785461712,
                                0,
                                0,
                                0,
                                0,
                                -0.28986909559573409,
                                0,
                                0,
                                0.77862082407410815,
                                0,
                                0,
                                0,
                                0.44647745057848331,
                                0,
                                0.24251699397277118,
                                0,
                                0,
                                0,
                                0.3755841660553802,
                                0,
                                0,
                                1.3753253740456612,
                                0.0041367848175918043,
                                0,
                                0,
                                0.45092346566718405,
                                0,
                                -0.12444953302308076,
                                0,
                                -0.26716811954863012,
                                0.3426357544948333,
                                0,
                                0,
                                0.40063795000278946,
                                0,
                                0,
                                0,
                                -0.35426540626224184,
                                0.55350737974702879,
                                0,
                                0,
                                0,
                                0,
                                0.93609833473237725,
                                -0.05315645961371418,
                                0,
                                0,
                                0,
                                0.78680226432205569,
                                0,
                                0,
                                -0.38276128315297708,
                                0.63313093483655891,
                                0,
                                0,
                                0,
                                0.1512063689584886,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2244996961999913,
                                -0.61518948392211203,
                                0,
                                0,
                                0,
                                -0.3010080720415797,
                                0,
                                0,
                                -1.1828682595708742,
                                0.14521756795405691,
                                0,
                                0,
                                0,
                                0.4978916861099002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37706001134307443,
                                0,
                                0,
                                -0.23196792058690444,
                                0,
                                -0.49727715059493272,
                                0,
                                0.16939234329228378,
                                0.32599393211935929,
                                0,
                                0,
                                0.21475674397636169,
                                0,
                                0,
                                0,
                                -0.40847974114343283,
                                -0.45693555279503767,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26984969815349935,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29962867601958321,
                                -0.63508200703863538,
                                0,
                                0,
                                0,
                                0.48425486345168423,
                                -0.34874395716751266,
                                -0.27919441400488376,
                                -0.25547138190674146,
                                0,
                                0,
                                0.35631515459604146,
                                0,
                                -0.12486861489405518,
                                0,
                                0.69041893313899905,
                                -0.50686773034293509,
                                0,
                                0,
                                0.087193242335267235,
                                0,
                                0,
                                0,
                                -0.10843075721866423,
                                0.19806216884240643,
                                0,
                                0,
                                0,
                                0,
                                -1.2278797150737313,
                                0.047527857885004063,
                                0,
                                0,
                                0,
                                0.72137346916535805,
                                0,
                                0,
                                -0.4584995605534411,
                                0.12515328491892549,
                                0,
                                0,
                                0,
                                -5.1068958143940524e-05,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61689820179198351,
                                0,
                                0,
                                -0.40586898789699166,
                                0,
                                0.51586434563576533,
                                0,
                                0.047347346771976238,
                                0.1235850754565114,
                                0,
                                0,
                                -0.10233557230922882,
                                0,
                                0,
                                0,
                                -0.16971884306682913,
                                0.36304111752986851,
                                0,
                                0,
                                0,
                                0.041594391875039854,
                                0,
                                0,
                                0.22881708153950284,
                                0,
                                -0.1323799007899859,
                                0,
                                -0.034790067557498375,
                                0.090206931532116785,
                                0,
                                0,
                                -0.84913785909448691,
                                0,
                                0,
                                0,
                                -0.44299434575562946,
                                0.041969967965223454,
                                0,
                                0,
                                0,
                                0,
                                0.33953584414257226,
                                1.0078120875599106,
                                0,
                                0,
                                0,
                                -0.5732638879562808,
                                0,
                                0,
                                -0.56834230444384393,
                                0.06128971681329741,
                                0,
                                0,
                                0,
                                0.50346802180727601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13331413769673683,
                                0.34939497599732294,
                                0,
                                0,
                                0,
                                -0.41454514695285277,
                                0,
                                0,
                                -0.61912107920055781,
                                0.015582194861339049,
                                0,
                                0,
                                0,
                                -1.0746082897643368,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39002223998887686,
                                0,
                                0,
                                0.62832305923743514,
                                0,
                                0.39340423287944182,
                                0,
                                -0.11770043866975095,
                                0.16031720115374104,
                                0,
                                0,
                                0.0079742755584329833,
                                0,
                                0,
                                0,
                                0.15094820081854549,
                                -0.4857179721270849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31624244467216467,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77190073965828754,
                                0.05909630894168913,
                                0,
                                0,
                                0,
                                0.44149216192675511,
                                -0.14578197921404051,
                                0.2906886239017738,
                                0,
                                0,
                                0,
                                0,
                                0.48806047878835601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.093400155657288098,
                                -0.40675716763168085,
                                0,
                                0,
                                0,
                                -0.69559354101513371,
                                -0.15418323392499095,
                                0.2828411968274539,
                                0,
                                -0.96308833098024571,
                                -0.42399246958877762,
                                0,
                                0,
                                0,
                                -0.44168027419641509,
                                0,
                                0,
                                0.46350506579076267,
                                1.0341050418980993,
                                0,
                                0,
                                0,
                                0.31654310690411536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44578805509434205,
                                0,
                                0,
                                -0.050470352049219673,
                                0,
                                0.52157811321354908,
                                0,
                                0.17175589536445623,
                                -0.086973603765667679,
                                0,
                                0,
                                0.21765037302629353,
                                0,
                                0,
                                0,
                                -0.61291611709363514,
                                -0.25803038290048019,
                                0,
                                0,
                                0,
                                -0.24373178972718976,
                                0,
                                0,
                                -0.03839801021195649,
                                0,
                                -0.10575678880672969,
                                0,
                                -0.61354993748798137,
                                -0.68024791494743175,
                                0,
                                0,
                                0.082602453769270279,
                                0,
                                0,
                                0,
                                -0.26904105988368066,
                                -0.097718474484407181,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65153069958250676,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.02329790615957672,
                                -0.30973753926520825,
                                0,
                                0,
                                0,
                                0.040749732775357358,
                                -0.34344147477537879,
                                0.59951232224441564,
                                0,
                                0,
                                0,
                                0,
                                0.10444362543771031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14582777871114588,
                                0.52273911148616592,
                                0,
                                0,
                                0,
                                -0.10469442631539216,
                                -0.82231620263221528,
                                -0.086050853402382443,
                                0,
                                0,
                                0,
                                0,
                                0.39187766234639509,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53278493040784025,
                                0.24193708950486933,
                                0,
                                0,
                                0,
                                0.2722316297858971,
                                0.19798185155376985,
                                0.62508534345767985,
                                0.098472975785433181,
                                0,
                                0,
                                0,
                                -0.36818506021186215,
                                0.72715129511597265,
                                0.36680486834050385,
                                0,
                                0.42602830101651595,
                                0,
                                0.099739178774434972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0077393775991850822,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64580347885005862,
                                0.37405064129629656,
                                0,
                                -0.29628609808408823,
                                0,
                                1.5196875851473211,
                                0.2745468442538645,
                                0,
                                0,
                                0,
                                0,
                                -0.32982807565988642,
                                0.20984282706167393,
                                0,
                                0,
                                0,
                                0.0031745566042221274,
                                0,
                                -0.23831605562797761,
                                0,
                                0,
                                0,
                                0.28926749781403954,
                                0,
                                -0.46215276591130056,
                                0,
                                0,
                                -0.55254524677939698,
                                -0.43336785089342295,
                                0,
                                0,
                                0.055259803568874735,
                                0.83211349026635761,
                                0,
                                0,
                                0,
                                0.36652182570227576,
                                0,
                                -0.042366064550200644,
                                0,
                                0,
                                0,
                                0.065003307276403161,
                                0,
                                0.40018233943579229,
                                0,
                                0,
                                -0.037464127189845042,
                                0.051239298447560998,
                                -0.17595511270731026,
                                0,
                                0,
                                0,
                                0.19398003078344261,
                                0.0084386786929748214,
                                -0.59204078232560053,
                                0,
                                0.74318025830272139,
                                0,
                                -0.16885245157746531,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77965667035579278,
                                0,
                                0,
                                0,
                                -0.42238463863587894,
                                -0.12104785444559191,
                                -0.06546965565304011,
                                0,
                                -0.025009694789895801,
                                0,
                                0.44063857037652021,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52790006185040594,
                                0,
                                0,
                                0,
                                0.5141587201139971,
                                0.023176156466519902,
                                0.56993887382910768,
                                0,
                                0.11652836731777447,
                                0,
                                -0.34353459899866878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37845645015739948,
                                0.23910615352002965,
                                0,
                                0,
                                0,
                                -0.17996532202998738,
                                0,
                                0.51128577126241748,
                                0,
                                0,
                                0,
                                0.52550542313887139,
                                0,
                                -0.38181036092164677,
                                0,
                                0,
                                0.28363436183329627,
                                -0.0584358878283575,
                                -0.00074267730536992094,
                                0,
                                0,
                                0,
                                0.61784921607459475,
                                0.37241045131632233,
                                -0.14610533608178275,
                                0,
                                -0.13118031381615219,
                                0,
                                0.66409126361692716,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18184980643761983,
                                0.24643146720041034,
                                0,
                                0,
                                0,
                                -0.42951927582517724,
                                0,
                                -0.29589388424130336,
                                0,
                                0,
                                0,
                                -0.19624703029332011,
                                0,
                                0.025404818649080563,
                                0,
                                0,
                                0.59156374254482325,
                                -0.49503153195739458,
                                -0.26981349271412552,
                                0,
                                0,
                                0,
                                -0.048019609174016445,
                                0.56329434682855817,
                                -0.40555953407669598,
                                0,
                                -0.48453108305447967,
                                0,
                                -0.45644864879711711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44125184355821889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35210821493089517,
                                1.5572300877099254,
                                0,
                                -0.031505578552849273,
                                0,
                                0.21573596428502448,
                                -0.42872565097208792,
                                0,
                                0,
                                0,
                                -0.077681764379072385,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68199979200904326,
                                -0.68238708276982385,
                                0,
                                0.88907550706813698,
                                0,
                                0.55437814738084279,
                                0.33376879851515562,
                                0,
                                0,
                                0,
                                0,
                                -0.044669509139348001,
                                0.29473388805871653,
                                0,
                                0,
                                0,
                                0.093303755482926742,
                                0,
                                -0.078732972838240628,
                                0,
                                0,
                                0,
                                -0.4947696355232476,
                                0,
                                -0.66480810779268062,
                                0,
                                0,
                                0.12475422445574127,
                                0.44034267274661332,
                                0,
                                1.3186052638190473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85396516775541553,
                                -0.2360020662299932,
                                0,
                                -0.80386290545768491,
                                0,
                                0.17947708872437385,
                                0.34764429114519757,
                                0,
                                0,
                                0,
                                0,
                                -0.052190851559920759,
                                -0.17217547042080569,
                                0,
                                0,
                                0,
                                0.37735980158794169,
                                0,
                                -0.57008885113365571,
                                0,
                                0,
                                0,
                                0.52025828616245495,
                                0,
                                -0.11553202005141347,
                                0,
                                0,
                                0.40828512084339735,
                                0.22252400427252808,
                                0,
                                0.51877515980993705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12770944817235633,
                                -0.29726255040975047,
                                0,
                                0.053040336704607449,
                                0,
                                -0.023223100162168664,
                                -1.1660002081515122,
                                0,
                                0,
                                0,
                                -0.89120005062797647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1716440940625847,
                                -0.075349866855587533,
                                0,
                                -0.19844787369469369,
                                0,
                                0.67453658455240739,
                                -0.52644231679607922,
                                0,
                                0,
                                0,
                                0,
                                -0.69924446676721996,
                                -0.07598917929112875,
                                0,
                                0,
                                0,
                                0.39713992327131858,
                                0,
                                0.51111901050552744,
                                0,
                                0,
                                0,
                                0.0057116143882630088,
                                0,
                                -0.016577552345217642,
                                0,
                                0,
                                0.27242149262257348,
                                -0.10862389859786223,
                                0,
                                0,
                                -0.46711784756206043,
                                0.15285971940194482,
                                0,
                                0,
                                0,
                                -0.58305335839684347,
                                0,
                                -0.0011922577958984049,
                                0,
                                0,
                                0,
                                0.28623720758978932,
                                0,
                                0.15573078231587895,
                                0,
                                0,
                                -0.080126466693643372,
                                0.55306248853319895,
                                -0.26277466759653556,
                                -0.8912458213205412,
                                0,
                                -0.17846260735542951,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.028618263035415675,
                                0,
                                0,
                                0,
                                0.14175630201513437,
                                0.15635812227111384,
                                0,
                                0.017160096330288966,
                                0,
                                0.24315688840278399,
                                0,
                                0.1156754933675915,
                                0.016889503635642324,
                                0,
                                -0.3302513921418635,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.057343667821481446,
                                0,
                                0,
                                0,
                                -0.32964289388064733,
                                -0.48158499740602778,
                                0,
                                -0.54041403191162241,
                                0,
                                0.49126751729653451,
                                0,
                                0,
                                0,
                                0.90896228857725159,
                                0,
                                0.92407161749932443,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14511642491957147,
                                -0.21867761552856776,
                                0,
                                0,
                                -0.64790038410703366,
                                0,
                                0,
                                0,
                                0.7905891516974205,
                                0.37215591945232984,
                                -0.40417020595962988,
                                0,
                                0.483734641364086,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.088968875612982529,
                                0,
                                0,
                                0,
                                -0.4856116225713612,
                                -0.36908060075780375,
                                0,
                                0.18074532149460232,
                                0,
                                -0.22698842057106394,
                                0,
                                0,
                                0,
                                0.51256390806998586,
                                0,
                                -0.24999437759575832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.096444297065907347,
                                -1.3078479489335386,
                                0,
                                0,
                                0.19316560665486049,
                                0,
                                0,
                                0,
                                -0.24152483168283179,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42010013148654413,
                                -0.28716228160978607,
                                -0.65877150618949532,
                                0.35810457537391621,
                                0,
                                0.35537739621891923,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22922003736890462,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61997812425584242,
                                0.097576415007736589,
                                -0.22694968389048459,
                                -0.30333776264183587,
                                0,
                                -0.42829581377673953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52834525389864262,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11555104292321966,
                                -0.53597329825040385,
                                0.31616299852732649,
                                0.54024239260373774,
                                0,
                                -0.5532022343302927,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.039076637136645054,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1973605213146393,
                                -0.63708284174009344,
                                0.063789304337404262,
                                -0.17428253930536947,
                                0,
                                0.39984164574059178,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60071412241069999,
                                0,
                                0,
                                -0.14188119249173736,
                                0.11157223623862778,
                                0,
                                -0.45746592891648041,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38837621492152929,
                                0,
                                0,
                                0,
                                -0.13916077310908584,
                                -0.32184166760535543,
                                0,
                                0.68659690641590898,
                                0,
                                0.1137853734116627,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59904344920910191,
                                0.13034114812609915,
                                -0.58222166104456452,
                                0.27179579051341185,
                                0,
                                -0.34053799546085506,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30876688679654896,
                                0,
                                0,
                                0,
                                0,
                                0.69598013515442658,
                                0,
                                -0.17125253753606881,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11594000868326913,
                                0.31402783119080213,
                                0,
                                0,
                                1.123778129726769,
                                0,
                                0,
                                0,
                                0.42751495369423631,
                                0,
                                0,
                                -0.8338963195942416,
                                0,
                                -0.61445040638254078,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69178108589369169,
                                -0.49694582568517004,
                                0,
                                0,
                                0.30810147581134639,
                                0,
                                0,
                                0,
                                1.3635961273939388,
                                -0.01461271281356713,
                                -0.14562758137524578,
                                0,
                                -0.37017311239913708,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.044215093195504568,
                                0,
                                0,
                                0,
                                0.29674974554587974,
                                -0.40501046368150456,
                                0,
                                -0.2612905698983703,
                                0,
                                -0.72057568614726875,
                                0,
                                -0.0045554878834873636,
                                0.037761131868230213,
                                0,
                                0.28054615336816624,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.86960135056393684,
                                0,
                                0,
                                0,
                                0.25354463494119517,
                                -0.019316278620809299,
                                0,
                                -0.28995091014156826,
                                0,
                                0.12211126302979425,
                                0,
                                0,
                                0,
                                -0.68735021059019497,
                                0,
                                1.1911452761184973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.113045174443777,
                                -0.11777828918634506,
                                0,
                                0,
                                0.8725097821371095,
                                0,
                                0,
                                0,
                                -0.10853631486930343,
                                -0.66029529476260329,
                                0.054451845073643534,
                                0,
                                0.0055632647585410755,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14526063416364546,
                                0,
                                0,
                                0,
                                -0.61600255498954204,
                                0.19573487441651777,
                                0,
                                -0.21064049317392394,
                                0,
                                -0.27887777313546253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16729235497962303,
                                0.44484371264863465,
                                0.26740187740496651,
                                0.61938527334605131,
                                0,
                                0.32923763768577763,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45889872121828534,
                                0,
                                0,
                                -0.56807938970371674,
                                0.063209274570902779,
                                0,
                                0.44726458518587286,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24058058614623987,
                                0,
                                0,
                                0,
                                0.29026178436305694,
                                -0.54873194151282689,
                                0,
                                0.082827003390092246,
                                0,
                                0.15214074872125305,
                                0,
                                0,
                                0,
                                0.081781261724370918,
                                0,
                                -0.51567105759535004,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.94195525566034677,
                                0.24759703833707244,
                                0,
                                0,
                                0.085597132152722882,
                                0,
                                0,
                                0,
                                0.65342553600288134,
                                0.53394157919931262,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60300497950174692,
                                0,
                                -0.62039846940659182,
                                0,
                                0,
                                0,
                                0.11680838934771143,
                                0,
                                0.051414078389320439,
                                0,
                                0,
                                0,
                                0,
                                -0.38196758601791153,
                                0,
                                -0.1410246092826597,
                                0,
                                -0.6957150841553813,
                                0,
                                0,
                                0,
                                -0.009592733018854098,
                                0,
                                -0.19818310694315025,
                                -0.26594752847206377,
                                -0.40356362576899096,
                                0,
                                -0.44175142620268099,
                                0,
                                0.16729616359802557,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27409375627172394,
                                0,
                                -0.12139130428981999,
                                -0.26065869022793248,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1811251002240018,
                                -0.048905031183547984,
                                0.898329453607145,
                                0,
                                0,
                                -0.1870457826744526,
                                0,
                                -0.028230549293788963,
                                0,
                                0,
                                0,
                                -0.64065079864546071,
                                0,
                                -0.23948539800833357,
                                -0.27328247264409711,
                                0.014606706952186252,
                                0,
                                0.52260415386026082,
                                0,
                                0.38525114176539166,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48924783119953075,
                                0,
                                -0.017298082215532522,
                                -0.75147794725170391,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0052490521002209467,
                                0.26484489954687873,
                                -0.35418619036975446,
                                0,
                                0,
                                0,
                                0.56807470587498854,
                                0,
                                -0.19343412308944713,
                                -0.49934247547743105,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35784006604238827,
                                -0.50301855091304892,
                                -0.097233149315695419,
                                0,
                                0.49895259833708239,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32441494161214546,
                                0,
                                0.47525986989569707,
                                0,
                                0,
                                0,
                                0.51444227160778866,
                                0,
                                1.0516739533603485,
                                0,
                                0,
                                0,
                                0,
                                0.4595685341519008,
                                0,
                                0.76753353833745752,
                                0,
                                0.12594529368404614,
                                0,
                                0,
                                0,
                                0.15798249221769467,
                                0,
                                0.012507170903191436,
                                -0.46624228651705923,
                                -0.33568287906987526,
                                0,
                                0.17279317324250487,
                                0,
                                0.099964031522351185,
                                0,
                                0,
                                0,
                                0,
                                0.81610839006807556,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1637293927095006,
                                0,
                                0.52476061312557676,
                                0,
                                0,
                                0,
                                0.80139196992368933,
                                0,
                                -0.38615271634267001,
                                0,
                                0,
                                0,
                                0,
                                0.10192102583722779,
                                0,
                                -0.28852937295641956,
                                0,
                                -0.15470347257849379,
                                0,
                                0,
                                0,
                                0.73295912656979323,
                                0,
                                -0.10816093891016912,
                                -0.021890963976586325,
                                0.001866712301849649,
                                0,
                                0.49725936882818284,
                                0,
                                0.3100648122241535,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32834481939138926,
                                0,
                                -0.11305094668848467,
                                0,
                                0,
                                0,
                                -0.05222599075451434,
                                0,
                                -0.59739776028404412,
                                0.67719977156766931,
                                -0.21076281077450554,
                                0,
                                0.12939807846740581,
                                0,
                                0.0057592708792189931,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18349743317489586,
                                0,
                                -0.57987853121718602,
                                0,
                                0,
                                0,
                                -0.043979462178621281,
                                0,
                                0.029876159668736312,
                                -0.11694741039262622,
                                0.35400503881916412,
                                0,
                                0.363148989849992,
                                0,
                                -0.5969667912920964,
                                0,
                                0,
                                0,
                                0,
                                -0.8949356628991243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28300738667435837,
                                0,
                                -0.30976765886612867,
                                0,
                                0,
                                0,
                                0.51237612110131336,
                                0,
                                0.089185195673791545,
                                0,
                                0,
                                0,
                                0,
                                -0.85405509141520863,
                                0,
                                0.34621875119614365,
                                0,
                                -0.20192420513518378,
                                0,
                                0,
                                0,
                                0.028972884711378266,
                                0,
                                -0.0027499287427341437,
                                0.055137638611300194,
                                0.68881629816733059,
                                0,
                                -0.24693930372588291,
                                0,
                                0.54774549747754175,
                                0,
                                0,
                                0,
                                0,
                                0.11440887438749854,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16961469627890025,
                                0,
                                -0.46063268355721937,
                                0,
                                0,
                                0,
                                0.69379389991411944,
                                0,
                                -0.011819250595259817,
                                0,
                                0,
                                0,
                                0,
                                0.97329518133719761,
                                0,
                                0.10686417148034927,
                                0,
                                -0.29253233018420483,
                                0,
                                0,
                                0,
                                -0.1476001671631261,
                                0,
                                0.73056878609490417,
                                0.40176004231901552,
                                -0.2828924559207398,
                                0,
                                0.21217008258593223,
                                0,
                                0.24704838983989011,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50741859291327918,
                                0,
                                0.026579392762145108,
                                -0.10508892162845503,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23716903860042249,
                                0.81183571509183949,
                                0.12429740475144734,
                                0,
                                0,
                                0,
                                0.14482575211642665,
                                0,
                                -0.78249227133096755,
                                -0.060627406731643393,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59346949144436656,
                                0.093642650358386259,
                                0.045614483915013132,
                                0,
                                0,
                                0,
                                0.29043445745000396,
                                0,
                                0.57840085477702841,
                                -0.32136532216631536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65624800381394688,
                                -0.081188917232927052,
                                0.20142374248489323,
                                0,
                                0.73603828614570543,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.82314001769048384,
                                0,
                                -0.38362845306136029,
                                0,
                                0,
                                0,
                                0.084520325120317874,
                                0,
                                0.30207351742832717,
                                0,
                                0,
                                0,
                                0,
                                0.047068934024399989,
                                0.23834923230369676,
                                0,
                                0.50516797245547862,
                                0,
                                0.88074804961401443,
                                0,
                                0,
                                0,
                                0.33115438727794799,
                                0,
                                0,
                                -0.84600776825359791,
                                -0.16942775501069432,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.035113498483056053,
                                0,
                                0,
                                0,
                                -0.10912813528827807,
                                0.047751389609835763,
                                0,
                                0,
                                0.56794047997126984,
                                0.80465694132518528,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12061805457855204,
                                0,
                                0,
                                0.50803046105005212,
                                0,
                                0.066754594446252924,
                                0,
                                0.6782754912131771,
                                0,
                                0,
                                0,
                                -0.46848364404434634,
                                0,
                                0,
                                0.42127431653768888,
                                0.64347490835610865,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15409484166366672,
                                0,
                                0,
                                0,
                                -0.12291707052551649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19015856500935699,
                                -0.24950295037523762,
                                0.57500059297796147,
                                0.22204541925394844,
                                0,
                                -0.093260240559936688,
                                0.68855417277636355,
                                -0.13577077037183446,
                                0,
                                0.59162632663566905,
                                0,
                                -0.16888390748012494,
                                0,
                                0,
                                0,
                                -0.79690599415792529,
                                0,
                                0,
                                -0.75595870291288969,
                                0.47671118593149059,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33210765444861279,
                                0,
                                0,
                                0,
                                0.44627899122398751,
                                0.39108016227629699,
                                0,
                                0,
                                -0.24860911138514244,
                                0.12561317738684349,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67824089667739462,
                                0,
                                0,
                                0,
                                -0.82692194315527245,
                                0,
                                0,
                                0,
                                -0.21476998840593131,
                                0.27932412146384622,
                                0,
                                0,
                                0.00040847531525517455,
                                0.055260756994482879,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43473908158939184,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2226663931647542,
                                0,
                                0,
                                0,
                                0.52100654115140588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25662052853252154,
                                -0.61631436729824407,
                                0.126183265300359,
                                0.17250806904746024,
                                0,
                                0.41784095485689343,
                                -0.11402654316358971,
                                -0.079958356522255677,
                                0,
                                0.69830827567202614,
                                0,
                                -0.12299404735299016,
                                0,
                                0,
                                0,
                                0.55738472285518814,
                                0,
                                0,
                                0.2393185783361963,
                                0.60799465604522041,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45023561129983053,
                                0,
                                0,
                                0,
                                0.13071135445187534,
                                -0.81307896529485901,
                                0,
                                0,
                                0.20777497173757664,
                                -0.099542951464084803,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25695484868578217,
                                0,
                                0,
                                0,
                                0.015359799598056501,
                                0,
                                0,
                                0,
                                -0.11404179224647774,
                                -0.32162410605807296,
                                0,
                                0,
                                -0.75327518530869608,
                                0.55113926398320245,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11017480417077985,
                                0,
                                0,
                                0.33160296822505891,
                                0,
                                0.81230077572112025,
                                0,
                                -0.54620818940708704,
                                0,
                                0,
                                0,
                                -0.32101907736463958,
                                0,
                                0,
                                0.084074470612286012,
                                -0.9138660998157222,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3669842118850988,
                                0,
                                -0.78281598141640873,
                                0,
                                -0.18839160413288608,
                                0,
                                0,
                                0,
                                0.068903652242778154,
                                0,
                                0,
                                -0.63460336816842844,
                                0.65212591003788623,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5007558144549803,
                                0,
                                0,
                                0,
                                -0.052555553917522153,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17847897589701212,
                                0.13756829893445549,
                                0.63884412773372257,
                                -0.040667451879187716,
                                0,
                                -0.38532828122976992,
                                -0.37074007179598273,
                                0,
                                0,
                                0,
                                -0.021592991402846096,
                                0,
                                0,
                                0,
                                -0.71240964293047038,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37012250017894954,
                                -0.39071668587204617,
                                -0.18806824663471089,
                                0.38003564997044093,
                                0,
                                -0.064007440648978578,
                                -0.13587618086059816,
                                0,
                                0,
                                0,
                                -0.4565992807847184,
                                0,
                                0,
                                0,
                                -0.0087258425257768224,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51100077939430699,
                                0.41838092585535752,
                                -0.14006071814834875,
                                0.048974500766339336,
                                0,
                                0.236610657900167,
                                0.52657046145072117,
                                0,
                                0,
                                0,
                                -0.57930526986020203,
                                0,
                                0,
                                0,
                                -0.31619227142496836,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49383076748577515,
                                -0.27619633346663774,
                                -0.1201010532009576,
                                -0.41567495407555344,
                                0,
                                0.21674289458444274,
                                0.10043504113992061,
                                0,
                                0.041516489290450737,
                                0,
                                0,
                                0,
                                0.84422092819313999,
                                -0.047060357309657873,
                                0,
                                0,
                                0.07101415641834824,
                                0.14153267357839494,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50821080290125475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10433449042461908,
                                0,
                                0,
                                0,
                                -0.25622730221681916,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18862441057407461,
                                0.34553336455838696,
                                0.33707176533872774,
                                0.2585335712419522,
                                0,
                                0.72021870619299921,
                                -0.26328205829693074,
                                0,
                                0,
                                0,
                                -0.34711472072841554,
                                0,
                                0,
                                0,
                                0.19351451889974977,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43424696060158258,
                                0.12489993259494776,
                                -0.24960363371601799,
                                0.72995348097047241,
                                0,
                                -0.20605716844106822,
                                -0.017305220703478629,
                                0.16483274512129137,
                                0.055281367833758713,
                                0.13838509945819644,
                                -0.44532890687637017,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.05754619701997328,
                                0,
                                0,
                                -0.54917221492611512,
                                0,
                                0,
                                0,
                                0,
                                0.20984576895152066,
                                -0.63511332238371321,
                                0,
                                -0.14557457440277513,
                                0.16446014162742156,
                                0.30278962330194648,
                                0.4255136339182668,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4114488001339846,
                                0,
                                0,
                                -0.22335618110284167,
                                0,
                                0,
                                0,
                                0,
                                0.66732465445553191,
                                0.12048735726598636,
                                0,
                                0.34154030175774108,
                                0.69733110940792109,
                                0.24392667658023709,
                                -0.27377896734684726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23983807302794352,
                                0,
                                0,
                                0.45141072175432523,
                                0,
                                0,
                                0,
                                0,
                                -0.025539862578355978,
                                -0.026041775076311627,
                                0,
                                0.20963777501588729,
                                0.4804058760935187,
                                -0.082994202029647107,
                                0.42914659891791496,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69387284586546127,
                                0,
                                0,
                                -0.22230890721566812,
                                0,
                                0,
                                0,
                                0,
                                0.036734696691023916,
                                0.044465066850452463,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4241262400010502,
                                -0.64499590826827302,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19730381729013291,
                                0.33402035504845928,
                                -0.24252540774790127,
                                -0.4413391479945013,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44173443820970981,
                                0.09560737348787221,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68050052147955342,
                                0.26284479947228651,
                                -0.35252822300190989,
                                0.37320961921934559,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50624552535485323,
                                0.49854525043854225,
                                -0.15678551879173927,
                                0,
                                -0.49378319865843362,
                                -0.21571512910852528,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2961625698614203,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.84604308319396604,
                                0.91724258037120221,
                                -0.18484927210735619,
                                0,
                                0.44166595387297025,
                                -0.87407201624516517,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.027470950489816903,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61890347985926142,
                                -0.38012466922141191,
                                0.33979038220181512,
                                0,
                                0.15521609860402302,
                                -0.94600395454113628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31979951541521889,
                                -0.023039942234202696,
                                0.14619098600318536,
                                0.39017726075404519,
                                0.10241469492556107,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25655633238213338,
                                0,
                                0,
                                -0.51742079501723603,
                                0,
                                0,
                                0,
                                0,
                                -0.65582370749755947,
                                0.22742059275613258,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64356744728653204,
                                0.53707037973940785,
                                0.022571390762901267,
                                0,
                                -0.03635768449337777,
                                0.56378982628677055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80471397580592774,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33310345635782301,
                                -0.39107879828002889,
                                0.17613725210062034,
                                0,
                                -1.6906520223383001,
                                0.009190489451974709,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44409888837089623,
                                0.63884797995004028,
                                -0.038421707305251407,
                                -0.59756430332099697,
                                0.1059071370304167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38747062599833382,
                                0,
                                0,
                                -0.23460144427776772,
                                0,
                                0,
                                0,
                                0,
                                0.011618471845719826,
                                0.12958124898004886,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.060443232552933962,
                                0.66152997979740769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25251275682623298,
                                0.50759938196636001,
                                -0.35662052334600941,
                                -0.33185339965653016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1265422808182112,
                                0.065638404447567647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4515564750234709,
                                -0.51868391974727424,
                                -0.32585934021092522,
                                -0.6328965813497367,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7668686090228829,
                                -0.36456698756080685,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15022617717696674,
                                0.30526500857763067,
                                -0.36974770013640734,
                                0.16289707348163696,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13127765210162151,
                                -0.00032515164697821675,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45580302450069976,
                                0.44661633105468085,
                                0.66845299726561558,
                                -0.3587674991871117,
                                0,
                                0,
                                0,
                                0.61791099626737567,
                                -0.47952047918963042,
                                0.55872991916947334,
                                0.1409290282384269,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16778075169007656,
                                0,
                                0,
                                0.15163932915672307,
                                0,
                                0,
                                0,
                                0,
                                0.055835337402024524,
                                0.044085660556084288,
                                0,
                                0.023850686621280426,
                                0.0069590451907720896,
                                0.035766369153552829,
                                -0.56562576259815689,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21050290791115545,
                                0,
                                0,
                                -0.22264860622408994,
                                0,
                                0,
                                0,
                                0,
                                0.27437843789331445,
                                0.71344486590569378,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63514399106088593,
                                -0.10930123740682735,
                                -1.3576224040025335,
                                0,
                                -0.13612588454489422,
                                -0.14886991347897191,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.044914446905413408,
                                -0.0026733788080362531,
                                0,
                                0.30668773994603488,
                                0,
                                0,
                                0,
                                0,
                                0.37232048635881254,
                                0,
                                0,
                                0,
                                0.26990120814069973,
                                0,
                                0,
                                0,
                                -0.15835385368614177,
                                0,
                                0.75487215296220345,
                                0.31515977070275469,
                                0.015254020120118908,
                                0,
                                -0.18318704245495543,
                                0,
                                0,
                                -0.14738844099741827,
                                0,
                                -0.32411981893391895,
                                0,
                                0,
                                0,
                                -0.12454715310989016,
                                0,
                                -0.29755394094361248,
                                0.85768010166515274,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14017106338972735,
                                0,
                                -0.68648117104717188,
                                0,
                                0,
                                0,
                                0,
                                0.3775666534641719,
                                0,
                                0,
                                0,
                                -0.18798949149569671,
                                0,
                                0,
                                0,
                                0.13377616047884358,
                                0,
                                0.14846500933143045,
                                0.069874584841277038,
                                0.53514359787813182,
                                0,
                                0,
                                0,
                                -0.75950751722196297,
                                0,
                                0.25793318456643782,
                                0,
                                0,
                                -0.11930911937743176,
                                1.0010487983779641,
                                0,
                                0,
                                0,
                                0,
                                -0.15883684847496865,
                                0,
                                -0.52568811541711746,
                                0,
                                0,
                                0,
                                0,
                                0.063086228285285997,
                                0,
                                0,
                                -0.46182183372528507,
                                0,
                                -0.34219219752303676,
                                0,
                                0,
                                0,
                                0.80855120421674098,
                                0,
                                0.10019252454744899,
                                -0.043030568601605812,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21294310155292395,
                                0,
                                -0.49903330327449091,
                                0,
                                0,
                                0.20711072924326945,
                                1.3110076346157502,
                                0,
                                0,
                                0,
                                0,
                                1.0278461553739486,
                                0,
                                0.67394563514849226,
                                0,
                                0,
                                0,
                                0,
                                -0.2528525473446826,
                                0,
                                0,
                                -0.43354134290414925,
                                0,
                                0.63607195040637909,
                                0,
                                0,
                                0,
                                0.10837018820612231,
                                0,
                                -0.57164242677438215,
                                -0.070716373069239336,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.025295461526449223,
                                0,
                                0.17840997854059396,
                                0,
                                0,
                                0,
                                0,
                                0.76821716245886562,
                                0,
                                0,
                                0,
                                0.03883323871562222,
                                0,
                                0,
                                0,
                                -0.069934675007502098,
                                0,
                                -0.25295783746545158,
                                -0.53735082795893863,
                                -0.13505536437349397,
                                0,
                                0,
                                0,
                                0.49188851758888757,
                                0,
                                -0.51343003522880526,
                                0,
                                0,
                                -0.58993222331218687,
                                -0.45521878116666564,
                                0,
                                0,
                                0,
                                0,
                                1.2531929230466214,
                                0,
                                -0.39176868806482867,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85665146351171506,
                                0,
                                -0.63947514293110896,
                                0,
                                0,
                                0.95410687563411178,
                                -0.43637457536983215,
                                0,
                                0,
                                0,
                                0,
                                0.11315619622583006,
                                0,
                                -0.29125626949631933,
                                0,
                                0,
                                0,
                                0,
                                0.32599813913956821,
                                0,
                                0,
                                0.067664997595863696,
                                0,
                                0.60482147468639713,
                                0,
                                0,
                                0,
                                0.23896803362249003,
                                0,
                                0.46039871616186923,
                                0.50424690995499732,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52736905161065306,
                                0,
                                0.46721301371767232,
                                0,
                                0,
                                0,
                                0,
                                0.015513687049621361,
                                0,
                                0,
                                0,
                                -0.1868791737048287,
                                0,
                                0,
                                0,
                                0.20351025083350388,
                                0,
                                -0.12881876618922836,
                                0.062530697785871586,
                                0.63758026811001545,
                                0,
                                -0.61803352656448363,
                                0,
                                0,
                                -0.43325721382953708,
                                0,
                                0.041430915990642754,
                                0,
                                0,
                                0,
                                -0.25730089783248122,
                                0,
                                0.60168540115830005,
                                -0.019420399447122538,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6405372728408979,
                                0,
                                0,
                                -0.62028121051088692,
                                0,
                                -0.075748133925342465,
                                0,
                                0,
                                0,
                                -0.44235662762215855,
                                0,
                                0.02560754487855342,
                                -0.053761601906558973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35305138217374099,
                                0,
                                -0.22665759982167855,
                                0,
                                0,
                                -1.3868883543348598,
                                0.20595418018457523,
                                0,
                                0,
                                0,
                                0,
                                -0.6363408443326054,
                                0,
                                0.55274181004673062,
                                0,
                                0,
                                0,
                                0.33411558747503162,
                                0,
                                0.090776893247418111,
                                0,
                                0,
                                0,
                                0,
                                -0.25079589981831668,
                                0,
                                0,
                                0,
                                0.41598910881834883,
                                0,
                                0,
                                0,
                                -0.47628506439940527,
                                0,
                                -0.013681325122579441,
                                -0.37738226646121559,
                                0.52414577320717193,
                                0,
                                0,
                                0,
                                0.38183948390764255,
                                0,
                                -1.53287649265894,
                                0,
                                0,
                                -0.10408906867159017,
                                0.28646472511208265,
                                0,
                                0,
                                0,
                                0,
                                -0.61422752453428231,
                                0,
                                -0.68142638926460997,
                                0,
                                0,
                                0,
                                0.65646291969842618,
                                0,
                                0.39119442441063823,
                                0,
                                0,
                                0,
                                0,
                                -0.0033616479741236391,
                                0,
                                0,
                                0,
                                -0.62900503407263875,
                                0,
                                0,
                                0,
                                0.078496252413978118,
                                0,
                                0.094759778662800859,
                                -0.023301442433334846,
                                0.068415563218369224,
                                -0.14587827565336928,
                                0,
                                -0.050369492930952303,
                                0,
                                0,
                                0,
                                0,
                                0.13318841743293192,
                                0,
                                0,
                                0,
                                -0.33792756014160302,
                                0,
                                0,
                                0,
                                -0.79605138721472224,
                                0,
                                -0.25150772705068525,
                                0.38324944818416407,
                                -0.02035104534370355,
                                0.37111950504253655,
                                0,
                                0.14407464550970539,
                                0,
                                0,
                                0,
                                0,
                                0.21857162639763797,
                                0,
                                0,
                                0,
                                0.41532172528074401,
                                0,
                                0,
                                0,
                                0.20979461301019497,
                                0,
                                -0.50509553606538482,
                                0.55972795986778967,
                                0.0938959471059055,
                                -0.49027825579678153,
                                0,
                                0,
                                0,
                                0,
                                -0.83333844544329583,
                                0,
                                0,
                                0,
                                0,
                                -0.032124892363592353,
                                0,
                                -0.65490366465776551,
                                -0.32805082344556596,
                                0,
                                0,
                                0,
                                0,
                                -0.52733387316623959,
                                0,
                                0,
                                -0.46929423232448841,
                                -0.27322623035106924,
                                0,
                                0,
                                0,
                                0,
                                0.13156359180918981,
                                -0.21339424470504925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43465034345669268,
                                0,
                                0,
                                0.67330776553157312,
                                0,
                                0,
                                0,
                                0.30801713929094526,
                                -0.067885001132414871,
                                0,
                                0,
                                0,
                                0,
                                0.30996983955003499,
                                0.40163967680169183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53381512183304736,
                                0,
                                0,
                                0.59846700227715177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43324572573026821,
                                0.19712524523619018,
                                0,
                                -0.24882397751841989,
                                0,
                                0,
                                -0.60846171682870032,
                                0,
                                -0.27138866608707574,
                                0,
                                0,
                                0,
                                0.19329196770923912,
                                -0.13242559456289382,
                                0,
                                0,
                                -0.46124897315445612,
                                0,
                                0,
                                0,
                                -0.5835987979617594,
                                -0.2960982206588782,
                                0,
                                0.24246598549628004,
                                0,
                                0,
                                0.38556858223325052,
                                0,
                                -0.194614854163766,
                                0,
                                0,
                                0,
                                0.54770285270721752,
                                0.13750247075672373,
                                0,
                                0,
                                0.086747421997329974,
                                -0.97624909951331795,
                                0,
                                0,
                                0,
                                0,
                                -0.27255539613670754,
                                0,
                                0,
                                0,
                                0,
                                0.13729090562878932,
                                0,
                                0.52593935290320015,
                                -0.6227963153488042,
                                0,
                                0,
                                0,
                                0,
                                0.61298457776574344,
                                0,
                                0,
                                0,
                                0,
                                0.31084043183400795,
                                0.25817392840370779,
                                0,
                                0.49574666223842578,
                                0,
                                0,
                                0.2081834716208309,
                                0,
                                0.14111412239089327,
                                0,
                                0,
                                0,
                                0.3159341114773882,
                                -0.26376183514445994,
                                0,
                                0,
                                -0.59859959375301353,
                                0,
                                0.20106559391818887,
                                0.42495511643585077,
                                0,
                                0,
                                0,
                                0,
                                -0.75584256452559684,
                                0.14773317771707903,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17563773572260499,
                                0,
                                0,
                                0.39371828456465841,
                                0,
                                0,
                                0,
                                0.20630722530482565,
                                -0.77568702782111487,
                                0,
                                0,
                                0,
                                0,
                                -0.30506641789919342,
                                0.43941953210472262,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23347051377065503,
                                0,
                                0,
                                -0.12281465031402108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0086600239405079105,
                                0.29862159480030803,
                                0,
                                0.43489768873728163,
                                0,
                                0,
                                -0.44775917166937473,
                                0,
                                0.25381991211315669,
                                0,
                                0,
                                0,
                                0.19497855887447985,
                                0.60295276214358329,
                                0,
                                0,
                                0.23480343276605004,
                                0.10905770494198816,
                                0,
                                0,
                                0,
                                0,
                                0.008897906040418832,
                                0,
                                0,
                                0,
                                0,
                                0.022775850490258043,
                                0,
                                -0.36204357413175403,
                                -1.6667298533423851,
                                0,
                                0,
                                0,
                                0,
                                -0.41317070658084437,
                                0,
                                0,
                                0,
                                0,
                                -0.38888908534798206,
                                0.31089567737450263,
                                0,
                                -0.32802555759359048,
                                0,
                                0,
                                0.35244434911348976,
                                0,
                                0.58868319786485845,
                                0,
                                0,
                                0,
                                -0.16184739415330132,
                                0.26335515103370721,
                                0,
                                0,
                                -0.27963002237214057,
                                0.18083213885437602,
                                0,
                                0,
                                0,
                                0,
                                -0.030141463377521122,
                                0,
                                0,
                                0,
                                0,
                                0.1651273047289924,
                                0,
                                -1.2345718970370114,
                                -0.15333380150253334,
                                0,
                                0,
                                0,
                                0,
                                1.1299788371743518,
                                0,
                                0.50691755226350954,
                                0,
                                0,
                                0,
                                0,
                                -0.13184595882052189,
                                0,
                                0,
                                0,
                                0,
                                -1.2733248050468351,
                                0,
                                -0.13710227878021433,
                                0.17332968779187072,
                                0,
                                0,
                                0,
                                0,
                                0.40505444064691065,
                                0,
                                0,
                                -0.77090644991545987,
                                0.083465069569572309,
                                0,
                                0,
                                0,
                                0,
                                -0.1860280440852532,
                                0.51027084624433916,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30277099238349159,
                                0,
                                0,
                                -0.10992626664499541,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13864893687202057,
                                -0.47972899372778072,
                                0,
                                0.091734435653928831,
                                0,
                                0,
                                -0.32717692000796239,
                                0,
                                0.66489668579550265,
                                0,
                                0,
                                0,
                                0.11060680654722212,
                                -0.41724067557921973,
                                0,
                                0,
                                0.082251877889356936,
                                0,
                                0,
                                0,
                                0.43447318971013094,
                                -0.087614687991440565,
                                0,
                                -0.56922293100515242,
                                0,
                                0,
                                0.004606521413286685,
                                0,
                                0.1149069864770926,
                                0,
                                0,
                                0,
                                0.65679088547290188,
                                0.18668939838917611,
                                0,
                                0,
                                0.0094833747791350509,
                                0,
                                -0.087186963578758866,
                                -0.36262297185393449,
                                0,
                                0,
                                0,
                                0,
                                -0.4331740816518565,
                                -0.56378853555651554,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59084103259368081,
                                0,
                                0,
                                0.079451809478957941,
                                0,
                                0,
                                -0.5743950861232594,
                                0,
                                0,
                                0,
                                0,
                                0.73999976044365801,
                                0,
                                0,
                                0,
                                0,
                                -0.27430575011150249,
                                0,
                                -0.33188716650516409,
                                -0.059966229868901155,
                                0,
                                0,
                                0,
                                0,
                                -0.12061383979944965,
                                0,
                                0,
                                0,
                                0,
                                0.12565274808460469,
                                -0.61900442974156367,
                                0,
                                0.066071196434107693,
                                0,
                                0,
                                -0.077457069599268,
                                0,
                                -0.047920573489105112,
                                0,
                                0,
                                0,
                                -0.23457639960282356,
                                0.50213100380319831,
                                0,
                                0,
                                -0.53030358157890323,
                                -0.53117141605054929,
                                0,
                                0,
                                -0.075708744914893211,
                                -0.26907393235335519,
                                0.056934697188441435,
                                -0.77339069425463092,
                                0,
                                0,
                                0,
                                -0.045443009977374646,
                                0,
                                0,
                                0,
                                0,
                                0.073219641560829996,
                                0,
                                -0.175850569724604,
                                0,
                                0,
                                0,
                                0.54038325788435593,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1217826920826126,
                                0,
                                0.69799343029363681,
                                0,
                                0,
                                1.017585793738923,
                                0,
                                0.072772317234313016,
                                0,
                                0.097143623528129983,
                                0,
                                0,
                                0,
                                0.45904677494625656,
                                0,
                                0,
                                0,
                                0,
                                0.50270736055185128,
                                0.30295371939304611,
                                0,
                                0,
                                0,
                                0.25652299370460691,
                                -0.57784886504575383,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21229002527323959,
                                -0.5619200983433027,
                                0,
                                0,
                                0.73344823374857882,
                                0.1340675291530723,
                                -0.078905152643976545,
                                0.3037545410349371,
                                0,
                                0,
                                0,
                                0.00069901622866134355,
                                0,
                                0,
                                0,
                                0,
                                0.088211119996606066,
                                0,
                                -0.14849530123164134,
                                0,
                                0,
                                -0.3513673103633338,
                                0,
                                0,
                                -0.19496547001321302,
                                0.59529393648262141,
                                0.14907425223006696,
                                -0.09355056294491812,
                                0,
                                0,
                                0,
                                0.23426509047697472,
                                0,
                                0,
                                0,
                                0,
                                -0.0059493533943254934,
                                0,
                                0.63108180133032588,
                                0,
                                0,
                                0.18592603591902621,
                                0,
                                0,
                                0.0032700581570950585,
                                0.54378295710983215,
                                0.24031179569599193,
                                -0.15056197065169555,
                                0,
                                0,
                                0,
                                -0.44941436364590831,
                                0,
                                0,
                                0,
                                0,
                                0.53638980433677186,
                                0,
                                -0.31561836581403241,
                                0,
                                0,
                                -0.089377367618331566,
                                0,
                                0,
                                0.070741930862175131,
                                -0.074576733306255652,
                                0.49774701634739549,
                                0.065711919854381531,
                                0,
                                0,
                                0,
                                -0.64204561683300809,
                                0,
                                0,
                                0,
                                0,
                                -0.53756155197697686,
                                0,
                                0.16787028108875832,
                                0,
                                0,
                                0,
                                0,
                                -0.27853727713168547,
                                0,
                                0,
                                0,
                                0,
                                0.24433913657092174,
                                -0.019718664301980007,
                                0,
                                0,
                                0,
                                0.8499120111076186,
                                0.25910245379151875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26989264102640292,
                                0,
                                0,
                                0.40305138976795818,
                                0,
                                0,
                                0,
                                0,
                                0.14880374969978391,
                                0.50645585300721585,
                                0,
                                0,
                                0,
                                -0.2103549027263372,
                                0.40398548971023568,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5928372704534608,
                                0,
                                0.81492389781293251,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80173635306106661,
                                0,
                                -0.016888701796854311,
                                0,
                                0,
                                1.0437136745305646,
                                0,
                                -0.11681584864317349,
                                0,
                                -0.29907761354202078,
                                0,
                                0.47782194714113352,
                                0,
                                0,
                                0.60948013674340795,
                                0.15869265787160453,
                                0.029499479973690707,
                                -0.50854545099330195,
                                0,
                                0,
                                0,
                                0.19138572948827287,
                                0,
                                0,
                                0,
                                0,
                                -0.23816222175592333,
                                0,
                                0.14899111958423222,
                                0,
                                0,
                                0,
                                0.35364897676147455,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.032506781276998686,
                                0,
                                0.45350697941429297,
                                0,
                                0,
                                0.19353029184248161,
                                0,
                                -1.1743734262127985,
                                0,
                                -0.02615367341892294,
                                0,
                                0,
                                0,
                                0.10721506671313825,
                                0,
                                0,
                                0,
                                0,
                                -0.29804460615807543,
                                0.5087097469779428,
                                0,
                                0,
                                0,
                                0.20904567811213684,
                                0.42298925050068481,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64673698979022165,
                                0,
                                0,
                                0.58383688877766826,
                                0,
                                0,
                                0,
                                0,
                                0.22459837064961202,
                                -0.61950046404597925,
                                0,
                                0,
                                0,
                                0.045329863219165357,
                                0.4278329028815866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19953306734277157,
                                0,
                                0.05100989587744105,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1081050455617104,
                                0,
                                -0.20839570932608897,
                                0,
                                0,
                                0.35640781580789238,
                                0,
                                0.3593967337884369,
                                0,
                                1.5544715092433017,
                                0,
                                0.053441789720627103,
                                0,
                                0,
                                0.10445440779380719,
                                -0.32143006814756869,
                                0.77478302094375295,
                                0.11839633977203168,
                                0,
                                0,
                                0,
                                0.37956097660050736,
                                0,
                                0,
                                0,
                                0,
                                0.34739335517163594,
                                0,
                                0.062135835916753368,
                                0,
                                0,
                                0,
                                -1.188467243279876,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14947781349900394,
                                0,
                                0.067804711005966994,
                                0,
                                0,
                                0.78419418650763228,
                                0,
                                -0.75270307213635967,
                                0,
                                -0.3519825736780422,
                                0,
                                0.070122038786035817,
                                0,
                                0,
                                0.17583647346967196,
                                -0.35424285988043031,
                                -0.24829112785100513,
                                -0.035002465610564332,
                                0,
                                0,
                                0,
                                -0.38492003695430005,
                                0,
                                0,
                                0,
                                0,
                                0.48242352362149238,
                                0,
                                0.62841617001581973,
                                0,
                                0,
                                0,
                                -0.5627478483510322,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64467412191408202,
                                0,
                                1.1631687868938179,
                                0,
                                0,
                                -0.18596842485399667,
                                0,
                                0.60093413256710082,
                                0,
                                -0.18463485783567229,
                                0,
                                0,
                                0,
                                0.44371391418089978,
                                0,
                                0,
                                0,
                                0,
                                -0.72537309345168599,
                                -0.09362828373548325,
                                0,
                                0,
                                0,
                                0.34905794638998128,
                                -0.27164578568590614,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26935608276858958};

const double rot_25_10[1000] = {-0.015700310564962905,
                                0,
                                0,
                                0,
                                -0.9346677614919302,
                                0.32262175182468195,
                                0,
                                0,
                                -0.46497036470173747,
                                0,
                                0,
                                0.0055761454151981374,
                                0.67664215817522955,
                                -0.2243656895092499,
                                0,
                                0,
                                0.19303573443898514,
                                0.51158191022445487,
                                0,
                                -0.43909621737611776,
                                0,
                                0.58135281288615559,
                                -0.56670340097933725,
                                -0.3002769889045972,
                                0,
                                0,
                                0.08141180940559456,
                                0.47983967811473649,
                                0,
                                -0.11762607193240876,
                                0,
                                -0.27037819048360251,
                                -0.34013723831974135,
                                -0.040392762945190105,
                                0,
                                0,
                                0.35709359042682248,
                                -0.34404252191893375,
                                0,
                                -0.75079266692504876,
                                0.86134533148466086,
                                0,
                                0,
                                0,
                                -0.66675066491513069,
                                -0.5041076560012232,
                                0,
                                0,
                                0.061430108117033533,
                                0,
                                -0.0090589977103187475,
                                0,
                                0,
                                0,
                                0.74151218912621764,
                                0.19124199294232458,
                                0,
                                0,
                                -0.13840001568007942,
                                0,
                                0,
                                -0.37798122034745785,
                                -0.24611264419844067,
                                0.67502161307835906,
                                0,
                                0,
                                -0.036006799325028038,
                                0.57843200348607315,
                                0,
                                -0.070883799650154261,
                                0,
                                -0.11420411026012751,
                                -0.054713582963297092,
                                -0.18780075455027728,
                                0,
                                0,
                                -0.90355461780821367,
                                0.020508429685282409,
                                0,
                                -0.36312969938942508,
                                -0.87634655610988943,
                                0,
                                0,
                                0,
                                -0.41901721014191495,
                                -1.3499101378480802,
                                0,
                                0,
                                0.010211999680819601,
                                0,
                                0,
                                0.65801296790170882,
                                0.20431420511459858,
                                0.60575481052527969,
                                0,
                                0,
                                -0.10433625081825285,
                                -0.23381273961107285,
                                0,
                                -0.30460022775403922,
                                0.52144237735074606,
                                -0.33551669350749092,
                                0.37753266724868079,
                                0,
                                0,
                                -0.26137665381810488,
                                -0.46176092374314948,
                                0,
                                0.43755522483844578,
                                0,
                                -0.43994245332306026,
                                0.53507764079146614,
                                0.61985036540553873,
                                0,
                                0,
                                -0.25707433366330334,
                                -0.26247374766300502,
                                0,
                                -0.030796093178384054,
                                0,
                                0.37473561595040844,
                                0.40442986385816826,
                                -0.29233761226593613,
                                0,
                                0,
                                0.18455378307625658,
                                -0.62402485856830725,
                                0,
                                -0.4325289595548823,
                                0,
                                0,
                                0,
                                0,
                                0.25750714772786282,
                                -0.036370920028992032,
                                0,
                                0,
                                -0.38686104275684663,
                                0,
                                -0.71982826592502858,
                                0,
                                0,
                                0,
                                -0.017927245495472283,
                                -0.30023773319586006,
                                0,
                                0,
                                -0.4652025555670678,
                                0,
                                0.35686981769670933,
                                0.45814339784562064,
                                0.046584510916242314,
                                0.23695891687600457,
                                0,
                                0,
                                -0.49051327769857733,
                                0.43183860374495731,
                                0,
                                -0.55199377422496254,
                                0,
                                0.39188690785641334,
                                0.35844574132199181,
                                0.38668835874590352,
                                0,
                                0,
                                0.64381055039651069,
                                0.33196015896245801,
                                0,
                                0.20910247069087312,
                                0,
                                0,
                                0,
                                0,
                                -0.74577480076427216,
                                -0.66486988525289847,
                                0,
                                0,
                                -1.0521328792185867,
                                0,
                                -0.035942428749807631,
                                0.17507421702342527,
                                0.5539887054745114,
                                -0.42675041305746675,
                                0,
                                0,
                                -0.42004717897184085,
                                0.1783121705258503,
                                0,
                                0.52162702669220462,
                                0,
                                0,
                                0,
                                0,
                                0.65733445969158044,
                                -1.0786187127226814,
                                0,
                                0,
                                0.39475567600594752,
                                0,
                                -0.89386341937539826,
                                -0.53475135049573963,
                                -0.67170186005263954,
                                0,
                                0,
                                0.354588899808505,
                                -0.20896727076160518,
                                0.14475669116846371,
                                0,
                                0.2692628763676958,
                                0,
                                -0.19584180171065288,
                                0.21981247052919445,
                                0,
                                0,
                                0.51892206716301392,
                                0.71350873087495859,
                                0.33515913610004694,
                                0,
                                -0.15040611413010432,
                                0,
                                0,
                                0,
                                1.1998971421821745,
                                -0.77900412750931625,
                                0,
                                0,
                                0,
                                -0.29075403186941245,
                                0,
                                -0.22277453032607586,
                                0,
                                0,
                                0.65537175631070022,
                                0.6252384872957385,
                                0,
                                0,
                                0,
                                0.9590553980358395,
                                0,
                                0.26017953309084452,
                                0.32527665835578257,
                                -0.25698528153396211,
                                0,
                                0,
                                -0.40307962497202027,
                                0.35927076319398743,
                                0.47000056800120527,
                                0,
                                0.56187584156001535,
                                0,
                                0.26606828995379606,
                                0.43672581801679228,
                                0,
                                0,
                                0.50813364803355943,
                                -0.42565487090019888,
                                0.21427553661476662,
                                0,
                                0.50317228260519542,
                                0,
                                0.087549528439730379,
                                -0.055943500188297912,
                                0,
                                0,
                                -0.086742303724600928,
                                -0.36137889728639311,
                                0.75107871752606614,
                                0,
                                -0.53569322403469077,
                                0,
                                0,
                                0,
                                -0.069805316892162378,
                                -0.59375546990729744,
                                0,
                                0,
                                0,
                                1.0847344691192458,
                                0,
                                -0.043157396143136857,
                                -0.70101699160979458,
                                0.49050844920432585,
                                0,
                                0,
                                -0.42046329775252622,
                                -0.079910655764217256,
                                0.18915621696636359,
                                0,
                                0.22140791913320856,
                                0,
                                0,
                                0,
                                0.54441096212105677,
                                -0.49743010775033158,
                                0,
                                0,
                                0,
                                -0.21708418559580442,
                                0,
                                0.33654090993282415,
                                0.44023010796453249,
                                0,
                                0,
                                0.001351654422172395,
                                -0.7344801139309286,
                                0,
                                -0.25987212622067435,
                                0.20880837573063238,
                                0,
                                -0.39446182014252573,
                                0,
                                0.40840306293234307,
                                0.6773020131145886,
                                0,
                                0,
                                0.73076874776040557,
                                0,
                                0,
                                -0.39048444810999688,
                                0,
                                0,
                                0.093453812408619885,
                                0.47209680246403174,
                                0,
                                0,
                                0.9619359915451805,
                                0,
                                0,
                                -0.15478494458452513,
                                0,
                                0.5878348863705799,
                                0,
                                0,
                                -0.19385469844160783,
                                -0.090048346160440038,
                                0,
                                0.11402988786360437,
                                -0.66146368585290383,
                                0,
                                0.39777477871695943,
                                0.32410939834239794,
                                0,
                                0,
                                -0.47077408894645806,
                                0.091500168874768306,
                                0,
                                0.52741073498552382,
                                0.60089644850536861,
                                0,
                                0.16035569517265291,
                                0,
                                -0.38845765793612252,
                                -0.54496761180424869,
                                0,
                                0,
                                0.8638973807149376,
                                0,
                                0,
                                0.059430274134214922,
                                0,
                                -0.57249945236310373,
                                0,
                                0,
                                -0.60921217700089336,
                                -0.46968530510674922,
                                0,
                                0.15710892891518813,
                                -0.23620427545857295,
                                0,
                                0.0049939277891929978,
                                -0.10611989081081971,
                                0,
                                0,
                                0.044750010275903723,
                                -0.23395627159237184,
                                0,
                                -0.45758078354278542,
                                0.31930603983710787,
                                0,
                                0.78782228185872827,
                                0,
                                -0.28069743397730429,
                                0.57214654357953765,
                                0,
                                0,
                                -0.41792155632746403,
                                0,
                                0,
                                0.8248065241080883,
                                0,
                                0.12877749077999739,
                                0,
                                0,
                                -0.60634004162122346,
                                0.41075315438718868,
                                0,
                                -0.63815216860627844,
                                0.0062853699088894488,
                                0,
                                -0.19942984175983319,
                                -0.91836994440771369,
                                0,
                                0,
                                0,
                                0,
                                0.1171771435438147,
                                -0.14248909045396324,
                                0.11219658312492609,
                                -0.28022305466506048,
                                -0.17734144386003547,
                                0,
                                -0.083450416290209731,
                                0.37991377758994532,
                                0.12079923921777345,
                                0.31386167487324085,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69263879019857666,
                                0.69725239950136619,
                                0.79785180509928999,
                                -0.73345092596978878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17296586949868498,
                                -0.2579170693781635,
                                -0.26581013332647091,
                                -1.0300650511142717,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48266288037258576,
                                1.1093759922675686,
                                -0.6206523344294782,
                                -0.41428660751014501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13400066880806838,
                                0,
                                0,
                                0,
                                0,
                                0.17296231856369507,
                                -0.54684020055630611,
                                -0.58223975124992067,
                                0.56040253856199673,
                                -0.006286414661894224,
                                -0.065440028394545796,
                                0,
                                0,
                                0,
                                0,
                                0.55212591058337757,
                                0.67260889119939626,
                                -0.47807036665546282,
                                -0.027497701284245595,
                                -0.095731196460248219,
                                0.082095563190412585,
                                0,
                                0,
                                0,
                                0,
                                -0.40554903265937498,
                                0.075652222290465365,
                                -0.19608487246635864,
                                0.0049580364955267818,
                                -0.88577264720692772,
                                -0.047474519811161797,
                                0,
                                0,
                                0,
                                0,
                                0.33768584742609969,
                                0.13704980530604471,
                                0.60784004004789105,
                                0.64656252662346458,
                                -0.27824301278424102,
                                0.35406857686673332,
                                0,
                                0,
                                0,
                                0,
                                0.61074444967401953,
                                -0.45139121143942224,
                                0.10926450397939495,
                                -0.43428127736747479,
                                -0.31198345244805281,
                                -0.006731428376031745,
                                0,
                                -0.36368166111897637,
                                0,
                                0,
                                0,
                                0,
                                1.5092901277163198,
                                0,
                                -0.11144532944342017,
                                0,
                                -0.10823265925172532,
                                0,
                                -0.44018147730260315,
                                0.60602037776565731,
                                0.54509886219101955,
                                -0.32127776825435378,
                                0,
                                0.16405208412980415,
                                0,
                                -0.38989514718084456,
                                0,
                                0.3502096993119313,
                                0,
                                0,
                                0,
                                0,
                                0.69558240719495545,
                                0,
                                0.69799038538603819,
                                0,
                                0.53684827713512728,
                                0,
                                0.017809482438956685,
                                -0.073902429253419374,
                                -0.27097828507617489,
                                -0.4809555255061303,
                                0,
                                0.63345696943442331,
                                0,
                                0,
                                -0.66306668255863632,
                                0,
                                -0.4245874607724941,
                                -0.37924468633255948,
                                -0.30256676643898367,
                                -0.35808985782460445,
                                0,
                                0.12832200159666735,
                                0,
                                0,
                                -0.10768105238542268,
                                0,
                                -0.17882834992105709,
                                -0.18077197194684905,
                                0.22071205153702594,
                                0.65552506026349233,
                                0,
                                0.66732285443627171,
                                0,
                                0,
                                -0.084998638187090178,
                                0,
                                -0.15401651791717905,
                                0.63156038610130472,
                                -0.69645482625019661,
                                0.28383673766507028,
                                0,
                                0.067623988103617833,
                                0,
                                -0.36662505190857086,
                                0,
                                1.2257162684142913,
                                0,
                                0,
                                0,
                                0,
                                -0.33746359898902112,
                                0,
                                -0.51647805596051588,
                                0,
                                0.49153048303491664,
                                0,
                                -0.75494894595786666,
                                -0.22782487449300237,
                                -0.064251199218506361,
                                0.16418779964405061,
                                0,
                                -0.32474582315074657,
                                0,
                                0.38137571262254005,
                                0,
                                0.315292091267798,
                                0,
                                0,
                                0,
                                0,
                                0.17800568221653723,
                                0,
                                -0.92569385087206169,
                                -0.59569477516374825,
                                -1.0671281308761669,
                                0,
                                -0.30665685690422911,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49090722158554589,
                                -0.80371836092823656,
                                0.24183125515303369,
                                0,
                                -0.30517803777035984,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61100286210418275,
                                0,
                                0,
                                -0.59124093742471051,
                                0,
                                0.31539346351318598,
                                0.16686000551968616,
                                -0.53267734064254446,
                                -0.15051397394020377,
                                -0.46553114832306047,
                                0,
                                -0.6124963305449358,
                                0.14934705091273356,
                                0,
                                0.8692823855488121,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64033656023714236,
                                0,
                                0,
                                -0.066825562240266173,
                                0,
                                0.68623115601260953,
                                0.47873903754486535,
                                0.33044007805225184,
                                -0.16788586922303003,
                                0.39755976709362251,
                                0,
                                0,
                                0,
                                -0.37143752412926823,
                                0,
                                -0.62871203261944331,
                                0.48645537706828146,
                                -0.08217702478347054,
                                -0.25633527233200992,
                                0.39705878228017411,
                                0,
                                0,
                                0,
                                0.06439613371561248,
                                0,
                                0.12492837969993509,
                                -0.51913482428485991,
                                -0.31025609190225756,
                                -0.67919600525656543,
                                0.39138090909473355,
                                0,
                                0,
                                0,
                                -0.70918698134170566,
                                0,
                                0.018794924038415144,
                                -0.4865522849073316,
                                0.40295958087076073,
                                0.23956881324925178,
                                0.20049391581813783,
                                0,
                                0,
                                0,
                                -0.030160027703259418,
                                0,
                                -0.13555292142267289,
                                0.0096822970479707015,
                                0.58453047465683416,
                                -0.6039467500403477,
                                -0.52363582637148831,
                                0,
                                0.20615102958507658,
                                -0.62479182280538248,
                                0,
                                0.15601211778906685,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46630275405303045,
                                0.13484543756897324,
                                0,
                                -0.71755470780612463,
                                0.030564723902789383,
                                0,
                                -0.33843561204522765,
                                0,
                                0.2403388601501433,
                                0,
                                0.54193755703599966,
                                0,
                                -0.19096478310222195,
                                0,
                                0,
                                0.11422991416512734,
                                0,
                                -1.0232060202050639,
                                0,
                                0.032845060033352996,
                                0,
                                -0.59214644802084837,
                                0,
                                0.083366667584085785,
                                -0.58767927451120439,
                                0,
                                -0.35855023273423414,
                                0,
                                -0.34622111175047171,
                                0,
                                0.22049563607177192,
                                -0.41835090784328616,
                                0,
                                -0.079009062800935684,
                                -0.30106008601761125,
                                0,
                                0.40042433003702782,
                                0,
                                0.75057446152267238,
                                0,
                                -0.066341873152877248,
                                0,
                                -0.56434897207792578,
                                0,
                                0,
                                0.38520270582733596,
                                0,
                                0.80426230590506231,
                                0,
                                0.078573137214684716,
                                0,
                                -0.23025898129555389,
                                0,
                                -0.54341047798286579,
                                0.069020882359406732,
                                0,
                                -0.22968454152880324,
                                0,
                                -0.10284559028260783,
                                0,
                                -0.76393047307436357,
                                0,
                                0.11701102104256439,
                                0,
                                0,
                                1.4051783735365944,
                                0,
                                -0.45806091335946858,
                                0,
                                0.35599160409614206,
                                0,
                                0.62002221768356303,
                                0,
                                -0.10899844434328113,
                                -0.74715152358867687,
                                0,
                                0.077856115978803986,
                                0,
                                -0.02452086920336239,
                                0,
                                -0.19696076179489924,
                                0,
                                -0.5699570513101101,
                                0,
                                0,
                                0.075628000339840976,
                                0,
                                0.014117848971020835,
                                0,
                                0.88038103008898894,
                                0,
                                -0.1368030009952747,
                                0,
                                -0.40589062515126784,
                                -0.0079000738760691934,
                                0,
                                0.73331225245975207,
                                0,
                                -0.49782292366149777,
                                0,
                                0.17578624870926843,
                                -0.11586420194526655,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39935662182036008,
                                0,
                                -0.61992923342057471,
                                -0.20515553561604613,
                                0,
                                0.29705280596528277,
                                -0.17223818189031956,
                                -0.16173903240008763,
                                0.060139719009826981,
                                0.91426405754410467,
                                0,
                                0.12821299406051742,
                                0,
                                0,
                                0,
                                -0.40225334015634701,
                                -0.49550707339650835,
                                0.63063558917443963,
                                0.23826786353739407,
                                0.17893286067143518,
                                0,
                                -0.32584536331050995,
                                0,
                                0,
                                0,
                                -0.55928431030502512,
                                -0.47657438055324486,
                                -0.63805638281237254,
                                0.080198191894387705,
                                -0.055450392978961732,
                                0,
                                0.20845977150199196,
                                0,
                                0,
                                0,
                                0.17803837932625372,
                                -0.24657880970612781,
                                0.34405355909124374,
                                0.17510523180888987,
                                -0.174604398674301,
                                0,
                                0.85321734412995764,
                                0,
                                0,
                                0,
                                0.54520544979343244,
                                -0.33705652895127158,
                                -0.22433586230992128,
                                0.60835850980769712,
                                -0.27793071521897578,
                                0,
                                -0.30244301243532362,
                                0,
                                0,
                                -0.46704570175678206,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24853733827299263,
                                0,
                                1.3211811555629178,
                                -0.5450119216730267,
                                0,
                                -0.32894725116691081,
                                0.56857312248176539,
                                -0.017996132239889051,
                                0.72966976829064867,
                                0.1459360814701422,
                                0,
                                0.12032929374547505,
                                0,
                                0,
                                1.0612220725916666,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13498376600017553,
                                0,
                                0.36933521278011777,
                                0.53049495595735552,
                                -0.31806496673149193,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0391743177020678,
                                0,
                                -0.07601001461206347,
                                -1.0432166174662814,
                                -0.046574899153632748,
                                0,
                                0,
                                0.18457651778295647,
                                -0.21619291505093297,
                                0.45144391109419135,
                                0.0050143468158021509,
                                0,
                                0,
                                0.8445094213777119,
                                0,
                                0.16720365312561336,
                                -0.46865665655290589,
                                0,
                                0,
                                0,
                                0,
                                -0.057258894344097949,
                                0.83973441134130289,
                                0,
                                0,
                                -0.41832925229784551,
                                -0.98334086863178782,
                                0,
                                0,
                                0,
                                0,
                                -0.30105980551548178,
                                -0.80649852320590643,
                                0,
                                0.37925257392837947,
                                0,
                                0,
                                0.23936228551402389,
                                0.59637481956777172,
                                -0.47819971352573631,
                                -0.26699138934127059,
                                0,
                                0,
                                0.37848499049398299,
                                0.078024184055997647,
                                0,
                                0,
                                0.12381341657690406,
                                0.12609924073565246,
                                -0.1769879294891431,
                                0.96003508772588431,
                                0,
                                0,
                                0.098434491994130263,
                                0.663550300895418,
                                0,
                                0,
                                0.49034455909679669,
                                -0.040431854733718117,
                                0.459329886332073,
                                0.006301140495038441,
                                0,
                                0,
                                -0.32650394763185475,
                                0.2061921893757985,
                                0,
                                0,
                                -0.66080157362527181,
                                0.53245610389273501,
                                0.47867809629424479,
                                0.083110777544375403,
                                0,
                                0,
                                0.035727266145559267,
                                0,
                                0.21604649198187215,
                                -0.46158613782301539,
                                0,
                                0,
                                0,
                                0,
                                -0.24263466980098669,
                                -0.88245141659153981,
                                0,
                                0,
                                0.52658979095773784,
                                0.22227473730600014,
                                0,
                                0,
                                0,
                                0,
                                -0.73306215829775812,
                                -0.25345970571855958,
                                0,
                                -0.60423196693152503,
                                0,
                                0,
                                0.46498487813122197,
                                0.54456628807092,
                                0.30997102700948198,
                                -0.0087165912611348456,
                                0,
                                0,
                                -0.16119036756422034};

const double rot_25_100[100000] = {-0.19734500363261046,
                                   0,
                                   0,
                                   -0.33552353300119037,
                                   0,
                                   -0.31655069383164924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22139673485529743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35904928083318494,
                                   0,
                                   -0.2504533737263594,
                                   -0.11722925088189143,
                                   0,
                                   0,
                                   0,
                                   0.29311030259632326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28889212873321979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15326803559072186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4649093222919729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27434577754560729,
                                   0,
                                   0,
                                   0,
                                   0.049942406955994542,
                                   0.084309825904722094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53238656408614959,
                                   0,
                                   0,
                                   -0.2152140115055608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78149558417462406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64239606322065446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29947768329486635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13673839159756337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34220980630551268,
                                   0.0036229049788686629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10645758135560279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038703543915634381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49378698025062789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23152994673803923,
                                   0,
                                   -0.83546503444813747,
                                   0,
                                   0,
                                   0.39145286879269625,
                                   0,
                                   0,
                                   0,
                                   0.47299718602662011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32635528988261964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47224218341550084,
                                   0,
                                   0,
                                   -0.33192553508391354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57266823911706122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092896361851863063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022089021110468589,
                                   0,
                                   0,
                                   -0.28735880209130349,
                                   0,
                                   -0.064449469615599803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018570698032904377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48157463031351988,
                                   0,
                                   0.25013266347196195,
                                   0.14470134309447777,
                                   0,
                                   0,
                                   0,
                                   -0.26060664384870053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21031020571068249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037107100049564773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29394740023385063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58537659550647914,
                                   0,
                                   0,
                                   0,
                                   -0.21431172845580007,
                                   -0.092173447990155005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51420281055885753,
                                   0,
                                   0,
                                   0.91045760679234355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18334903120589141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24229298795965559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79495774028436095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26177491378765194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27775731551575222,
                                   0.36273161900734258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013469485240816426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12426553715104512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045417432595547237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074378022489963724,
                                   0,
                                   -0.13703628178605592,
                                   0,
                                   0,
                                   0.033380935256777433,
                                   0,
                                   0.32314074364238599,
                                   0,
                                   0,
                                   -0.13273715356921159,
                                   0,
                                   0.33154551609437655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15731585149146707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25159331163313525,
                                   0,
                                   0.21393624210801149,
                                   -0.043177367731438571,
                                   0,
                                   0,
                                   0,
                                   -0.32018307145591685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23268313894126824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29425823059260714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015047451209403845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1447035156451697,
                                   0,
                                   0,
                                   0,
                                   0.018319508134166468,
                                   0.60630876621200713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15350415968981518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2403234165667385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3410434460560885,
                                   0,
                                   0,
                                   0,
                                   0.64966804424890323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91683733338239393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31386824158004989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13044729905716346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025207871643057579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043916736644621181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44908592282064297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35445847672545927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53833271882786549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41356287265200081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43847923784761444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20684830686377118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61044466439904954,
                                   0,
                                   0,
                                   0.022633621680968066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25679866065437174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81343316935603516,
                                   -0.92607710657318154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56092916599665443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13992324968318171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52522362134498646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21071930431036234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32503181199812348,
                                   0,
                                   0,
                                   -0.2385045189530772,
                                   0,
                                   -0.24238227403002136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88309531357905557,
                                   0,
                                   -0.2186400065028942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31858928391901969,
                                   0,
                                   0,
                                   0.21656741686808434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5010615439179934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3894769668913502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34374647913184531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38678535565433103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41291422872535466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0067164256438352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64693928386653909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13171739247152212,
                                   0,
                                   0,
                                   0.3858665232728799,
                                   0.39407840820228046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093084079823002513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041533624111660596,
                                   0,
                                   0,
                                   -0.40324986415999564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72967649139705326,
                                   0,
                                   0.19809912711766706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064505345894294214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12444735711292715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027856161127834234,
                                   0,
                                   -0.40996437329199625,
                                   0,
                                   0.076544148799601183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36373293111014621,
                                   0.22414817094465245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1482935904612647,
                                   -0.16951621719985849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026539122479487011,
                                   0,
                                   0,
                                   0,
                                   -0.62374440504201534,
                                   0,
                                   0,
                                   -0.39518657321102507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0059496100083712977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35253191906328296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33474729138274489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11092181678876331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11097705304226216,
                                   0.53072929211694553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36796429563905253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44490165057424863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71776830848946782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091723564915748249,
                                   0,
                                   0.25647385644211951,
                                   0,
                                   0,
                                   -0.017345027323333047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39889203992788891,
                                   0,
                                   -0.15443456823874732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050206918444140297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14620161825244155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020768334273421063,
                                   0,
                                   0.53690995065357794,
                                   0,
                                   0.22439144228628852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14057567919867112,
                                   -0.54119195298683653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26831394864483238,
                                   -0.1450178852747257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22002614603346804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0089062884262954833,
                                   0.47854397359564071,
                                   0,
                                   0,
                                   -0.24250619775327786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6381094022387811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18064824854709435,
                                   0,
                                   0,
                                   0,
                                   -0.010770666720885086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40788002288091363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3105892650097784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031791842969485118,
                                   0,
                                   0,
                                   0,
                                   -0.091275162769958881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21991068722558313,
                                   -0.12302793373723953,
                                   0,
                                   0,
                                   -0.12287904021156923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16778343998534398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19905762160881607,
                                   0,
                                   0,
                                   0,
                                   0.37898573539286162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45052420978192342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3712606743644315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23923185157372617,
                                   0,
                                   0,
                                   0,
                                   0.55853408205704702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29521402108071937,
                                   0,
                                   0,
                                   0.32646705020189237,
                                   0,
                                   0.29663994156138374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090121408607873349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5119104485006668,
                                   0,
                                   0.0022434652059348803,
                                   -0.23022167010975314,
                                   0,
                                   0,
                                   0,
                                   0.27037756604479163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013005348343208184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1913301479850221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26314334857096205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016608830791986634,
                                   0,
                                   0,
                                   0,
                                   0.34654582762142527,
                                   0.3091873012097594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15953261618577119,
                                   0,
                                   0,
                                   0.12451110638203963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38722800773233551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22721552334603209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0014885894484587339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35748225791162697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46036331978935641,
                                   0.18293161322388626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30773744513274814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43864925433055002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49860827733543028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49904161186777363,
                                   0,
                                   0.20435701745176496,
                                   0,
                                   0,
                                   -0.27283598148530808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28988443529917712,
                                   0.24229981637358808,
                                   0,
                                   0,
                                   0.6220342681680785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22648432133685686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10466742746664653,
                                   0,
                                   0,
                                   0,
                                   0.049864699348045632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055906578420182068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08823501711685186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56803170955873183,
                                   0,
                                   0,
                                   0,
                                   0.26837155053349432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46527612944273355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31765449484671548,
                                   0,
                                   0,
                                   0.77859151517403136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017394198230525071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35298541207401163,
                                   0.30501092099603555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42747560853260891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56321852544180417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23522850908649889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0011426057487547159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68319803435790583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0031302030927582575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51410592067835892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28419855619187545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34507549390146669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11724366564427297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51862535935951271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3430259856052883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24680203654973445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2167459928598757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020869275668624593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023445286212857526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43808228157509183,
                                   0,
                                   0,
                                   -0.09682450751406195,
                                   0.54035862478494523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59206535072776789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65713556046697619,
                                   0,
                                   0,
                                   -0.0036753515491372568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0517902369084771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66327188234164902,
                                   0,
                                   0,
                                   0.19351596847191652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00060256328443641927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72907585225236149,
                                   0.48089243763847528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63137201409385957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045140091321808629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71905844685555942,
                                   0.34895650544898732,
                                   0,
                                   0,
                                   -0.12142665370050215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053581212817463544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052428847256176088,
                                   0,
                                   0,
                                   0,
                                   0.29567350546336313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39793853414664943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19261946356505685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24057588894496174,
                                   0,
                                   0,
                                   0,
                                   0.0079517175798853069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10744879009806897,
                                   0,
                                   0,
                                   0.093640099224611403,
                                   0,
                                   -0.32665600075111229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058393376459117033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098687088814773463,
                                   0,
                                   0.20843336697154818,
                                   0.47564026741909393,
                                   0,
                                   0,
                                   0,
                                   0.38989243961693165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074142778308074669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33620025227924871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45186169386446934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16345653790896456,
                                   0,
                                   0,
                                   0,
                                   -0.13887065787927588,
                                   0.26349406190829239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014806588678684132,
                                   0,
                                   0,
                                   0.011264925424950917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22448941549526974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18507967836690065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047281510050300797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75097750640212824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16015608786250846,
                                   0.433965378383383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13284690392467458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14442110328885088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033019844249740346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71120018720151612,
                                   0,
                                   -0.4818090211456571,
                                   0,
                                   0,
                                   0.89324603522565749,
                                   0,
                                   -0.30470146297793027,
                                   0,
                                   0,
                                   -0.12170080171154803,
                                   0,
                                   0.080554569830265835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44197830822381151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022778685567896695,
                                   0,
                                   -0.069146063685097736,
                                   -0.068740540432239428,
                                   0,
                                   0,
                                   0,
                                   -0.094490061537456593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38205737125670286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071669712571225314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37123639063756247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38963115963257233,
                                   0,
                                   0,
                                   0,
                                   0.40911254245541179,
                                   -0.25189687587811815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36588516642454716,
                                   0,
                                   0,
                                   -0.29351364439975108,
                                   0,
                                   0.10393946033461519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084304298404698844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19853303761279453,
                                   0,
                                   0.25082597316752903,
                                   0.14409850959872439,
                                   0,
                                   0,
                                   0,
                                   -0.20752875601065746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4746836943687795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19204935492541042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10741610616117719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49737444499753614,
                                   0,
                                   0,
                                   0,
                                   -0.22004165635485329,
                                   -0.16235795379564938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39096127317106244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69177269818049414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16263791321568832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54340180364829804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13674837515334609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093181449553853657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098033207283787144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099346844593999506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21938699815405727,
                                   0,
                                   -0.029879479412675897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55105379693634082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17470059371783642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041119645769726265,
                                   0,
                                   0.12608996163486319,
                                   0,
                                   0.38917537204482594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54598202710185517,
                                   0.1562469023419904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078584198484804149,
                                   0.25223592005869183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2354593367421397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23516818336742673,
                                   -0.32456491395610587,
                                   0,
                                   0,
                                   -0.15360574189370391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087053394624507618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38079588506454798,
                                   0,
                                   0,
                                   0,
                                   -0.21610469884311534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37583909629901174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32539482065645903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1957106883786795,
                                   0,
                                   0,
                                   0,
                                   0.57535579304916917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00070892486303945207,
                                   0,
                                   0,
                                   -0.05897991692166267,
                                   0,
                                   0.31504995591348228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43637256076964226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036157151501285817,
                                   0,
                                   -0.087018398563106059,
                                   -0.26146630617456301,
                                   0,
                                   0,
                                   0,
                                   0.38382854708490621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12468326027897471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36478706460048183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014504078719246957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064335605238269672,
                                   0,
                                   0,
                                   0,
                                   -0.5266129757360406,
                                   -0.22801024908672002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67673938444823312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68721022727113135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082191109986929412,
                                   0,
                                   0,
                                   1.163120645345604,
                                   0,
                                   0.082758500245762923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48242788138278714,
                                   0,
                                   -0.17343129673613289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14608533484001135,
                                   0,
                                   0,
                                   -0.10936121097752594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62872480445745971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12025388933020038,
                                   0,
                                   0,
                                   0.33120126983459347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37989734878367243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3875018520148667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086933871936404838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67446106704822639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33666223098756581,
                                   -0.056755503083541499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37261233491174839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40398950931523492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28309398430481808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0075130108991096206,
                                   0,
                                   0.44558948875774917,
                                   0,
                                   0,
                                   0.75628849706627022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058810597912541659,
                                   0.526026522983992,
                                   0,
                                   0,
                                   0.35891226949127758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31333123298333398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34837148044523808,
                                   0,
                                   0,
                                   0,
                                   -0.29606188149706214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015314320807419221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06478883568386555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48411579672747818,
                                   0,
                                   0,
                                   0,
                                   0.21219655883395758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42623199198576722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68370032345172049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31440664972110122,
                                   0,
                                   0,
                                   0.3284293261379938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3241248868514629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19775199313048558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5217863190421268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98891707104443383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76694067581020176,
                                   0,
                                   0,
                                   0,
                                   -0.024914486546692236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98543358361247047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2563058599904634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0030453314765315209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80363986130321896,
                                   0,
                                   0,
                                   -0.18335596402896939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2343486254604967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13960200244582258,
                                   -0.12525222653596346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23465751987651132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25403391968103195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13316119738119653,
                                   0,
                                   0.11185766302523341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3502191810300514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063355090651251805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44516958503616427,
                                   0,
                                   -0.12715557958034596,
                                   0,
                                   -0.470589516838613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16431068857995282,
                                   -0.27592112026395893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17707665469670139,
                                   -0.44961979972437827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26579136425317451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57517940963722292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15384283909898697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35222652826362338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83434545848533692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24046570773407483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67551823183079707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54243585983597575,
                                   0,
                                   0,
                                   0.070306212836623888,
                                   0.015240493659692655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20317896336705857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17479810246091151,
                                   0,
                                   0,
                                   0.11767109901169341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15521697376924992,
                                   0.33653684080418506,
                                   0,
                                   0,
                                   -0.42466297884828885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061388730828493623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64675582357035288,
                                   0,
                                   0,
                                   0,
                                   -0.19346037519418272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015236047679593811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22534993753328419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065333074556562565,
                                   0,
                                   0,
                                   0,
                                   0.40931683295439764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91265795996714316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47361332594680777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24130643733695381,
                                   0,
                                   0,
                                   0.1831589650960691,
                                   0,
                                   -0.29645659510341249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10599665874600822,
                                   0,
                                   0.61963747869777397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35228016175436044,
                                   0,
                                   0,
                                   0.38602796343554602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63082621866993638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28918427529786395,
                                   0,
                                   0,
                                   -0.40123436932615947,
                                   0,
                                   0.12639261696823648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14773213124520643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26366720653001391,
                                   0,
                                   0.46486196329222301,
                                   -0.16596269751394951,
                                   0,
                                   0,
                                   0,
                                   0.10644598708236037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51639735254144681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10133433151951679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15625475698389865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068671874553668855,
                                   0,
                                   0,
                                   0,
                                   0.29313467020246475,
                                   -0.033135644741422547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21692348822290303,
                                   0,
                                   -0.020490823968867946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17529693424733539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0039139836342184861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38474284090603517,
                                   0,
                                   -0.01475791139803433,
                                   0,
                                   -0.10993433755955731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07931343662747152,
                                   -0.20366655385205601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17582258263756639,
                                   0.17552688117533488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80743769471447613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0065309727068196544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52210326608667568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25792400805916682,
                                   0,
                                   0,
                                   0.29530741185528053,
                                   0,
                                   0.25122689771648965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8575353977006368,
                                   0,
                                   0.18589885194406552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1913036281767985,
                                   0,
                                   0,
                                   0.45245647266993128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69792136343239009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05239963107309626,
                                   0,
                                   -0.37533878496901629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55193213681654107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21348170166014355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3727006884753461,
                                   0,
                                   0.098340735512305849,
                                   0,
                                   0.2418518893619365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29954336824777728,
                                   0.1298770337371615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14329535498226206,
                                   -0.32190392905787368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26144319281976069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12800942592621006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49445372161869972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27348518085483486,
                                   0,
                                   0,
                                   0.44848611647447684,
                                   0,
                                   0.23001286704874724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05151332353846455,
                                   0,
                                   -0.3574015056397758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37210943873686286,
                                   0,
                                   0,
                                   0.62754228074212992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57069108650538825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093171825953509285,
                                   0,
                                   0.15218645243533988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047514717347953705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20853606243269143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12750323671658537,
                                   0,
                                   0.33353712418168491,
                                   0,
                                   -0.035445592563470255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13587551242028884,
                                   0.64271654132139622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58939819925123549,
                                   -0.098148923588054951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071293214162136506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27526839758295774,
                                   0.27203874356038216,
                                   0,
                                   0,
                                   -0.28885407938458696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57319777392911131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26471325733029183,
                                   0,
                                   0,
                                   0,
                                   0.4209654209442053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27238455335132505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062932723548196262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3358382007209969,
                                   0,
                                   0,
                                   0,
                                   0.0019235855931687435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33568343773158615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0077414830974729676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29863956582425238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30943025536778623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50585563523037258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70161963402949457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040463460862913261,
                                   0,
                                   0,
                                   -0.12990351869178024,
                                   -0.019168211379555863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44964223197017467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34052950136788929,
                                   0,
                                   0,
                                   0.55020389210599385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40911818271018069,
                                   0,
                                   0,
                                   -0.20843681018758942,
                                   0,
                                   -0.44695653055782109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014462110660417957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33334804516090644,
                                   0,
                                   -0.023666744433319866,
                                   -0.46765706099667753,
                                   0,
                                   0,
                                   0,
                                   -0.062276667879821133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0392166184211157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38598889560521055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18079030955089886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16084716179545866,
                                   0,
                                   0,
                                   0,
                                   0.18921203363269309,
                                   -0.10025498475023327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12397403817072733,
                                   0,
                                   0,
                                   0.28549035682968193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77658542553531429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42416410774769825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10492040173839641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32113552955806951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25935268717215693,
                                   0.072118726149046797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55878498462743698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0031871667781590493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64641544771407811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13750872977753853,
                                   0,
                                   0.41091416446742335,
                                   0,
                                   0,
                                   -0.1227835597640356,
                                   0,
                                   0,
                                   -0.12589922515423915,
                                   0,
                                   0,
                                   0.41014487370230901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40399579780420369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12229003788531626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080300114615621004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098465326963453809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086417718693155732,
                                   -0.55015452670979559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96469452164548941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063988111377703549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064458497529218256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69023432730195056,
                                   0,
                                   0.42314955575047186,
                                   0,
                                   0,
                                   0.5488084374529274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05337380272002052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8157515422971634,
                                   0,
                                   0,
                                   -0.16037808934610429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61920739955297011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65535999677265477,
                                   -0.43314599496365758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40131702103905625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37382820967260511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0400045139896021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28342507448105292,
                                   0,
                                   0,
                                   -0.46227802334155954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69080983767042925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64802349866708164,
                                   0.57438608328458651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28654606222203566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52236033131425685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36662458014048765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072152033619616751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52712149199537239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32760791639031206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40126763895260303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49182961299330707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13300591442824072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2336532206405432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66187994218502666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48148043240016181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11873863179432936,
                                   0,
                                   0,
                                   0,
                                   -0.58847117506940549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18725919076794881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63976668296938177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43693923135722368,
                                   -0.068224440932222435,
                                   0,
                                   0,
                                   0.23082412385046408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23700050795284675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3537164211419751,
                                   0,
                                   0,
                                   0,
                                   0.044483284587040081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33925862416053898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6237276188331744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037002763971234975,
                                   0,
                                   0,
                                   0,
                                   0.24976926660811688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074690043125044972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42932587330936889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36872528253413317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40774576279978153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30137793345818675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037395867957116788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34295673077335453,
                                   0,
                                   0,
                                   0.84614546831832782,
                                   -0.16312242861743884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4290507395860626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13780029020762949,
                                   0,
                                   0,
                                   0.11458302213348273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12112165593856576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086599269456605163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78615275371509852,
                                   0,
                                   0,
                                   0.32527193726458326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49909104764577866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070001798594268555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96113065898351802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38037155780901416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0190700934151731,
                                   0,
                                   0,
                                   0,
                                   0.3088981801566717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61913598515874979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41265066637237996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030631346676362498,
                                   0.037642600002479695,
                                   0,
                                   0,
                                   -0.23441966738476516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12747844407705941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18490136342235861,
                                   0,
                                   0,
                                   0,
                                   -0.644494415403844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37171191804454523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40859943351329087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41246203229455602,
                                   0,
                                   0,
                                   0,
                                   -0.040394062116430596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11533003267403279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16812950105404278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05375562651920697,
                                   0,
                                   0,
                                   -0.68301560779449688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45672354907585455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52956120164238096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27791253464482035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53049483708379497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13263615470120965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52340996405030105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68463139974701936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095415138865930865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030684091999717802,
                                   0,
                                   0,
                                   -0.44224837627171543,
                                   -0.85447452530917622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38867439803473669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084538616912696221,
                                   0,
                                   0,
                                   0.10513871318848333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055996067416683067,
                                   0,
                                   0,
                                   0.060151727410188593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35161509430306992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22388994266536735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16469510321049091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62153912227600916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6187095810179436,
                                   0.079179071316107075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31868653940559993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7396318005527226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25669268521495059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15560733691041781,
                                   0,
                                   0.026330259482873791,
                                   0,
                                   0,
                                   -0.023044634270093914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30054798506440711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3156613423218097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48642595741745304,
                                   0,
                                   0,
                                   0.19595130809953384,
                                   0,
                                   -0.98412727634774977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35079031239985697,
                                   0,
                                   -0.092961954364698285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46605230570585321,
                                   0,
                                   0,
                                   -0.21545938159216857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25468575127758608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23792438847836472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36963010620471221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42064841268155795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38628956763389571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36318974342000732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04573273533482506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32767777618507893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48911129100410261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34199577801870018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78313776777032773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64924208573261633,
                                   0,
                                   0,
                                   -0.24809844983894488,
                                   0,
                                   -0.59058933603288566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45517237551821715,
                                   0,
                                   0.044825742338404813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83022067352113471,
                                   0,
                                   0,
                                   0.33023066594539846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063955397472170439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02454577948201124,
                                   0,
                                   0.069083555280581965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070852273296259566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00072933802756881827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25573273688669945,
                                   0,
                                   -0.44632891538895869,
                                   0,
                                   0.6433437348171811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40849541796805705,
                                   -0.18409891238259302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31123691114571739,
                                   -0.076491236800128287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087316984428869815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16553498328928229,
                                   0,
                                   -0.31662801382568456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03481110989764391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62327994165203759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018747011158557231,
                                   0,
                                   -0.26235969555421773,
                                   0,
                                   -0.26321835298146545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087446786861893444,
                                   -0.0063402949726404575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49580603946860957,
                                   0.17438521585738184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24549182745909087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.884246419768981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61572448561667836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31261742497109896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12125273189615403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037491882540119564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040999071658281566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36130122896000405,
                                   0,
                                   0,
                                   -0.34218372591308321,
                                   0.080932989855564963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26215182335215248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47414405099229828,
                                   0,
                                   0,
                                   -0.32385446356346947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38118624675699192,
                                   0,
                                   0,
                                   -0.2125065896211733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50252802490175585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80413289515375275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45934641118125019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15572989993198422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11667772271916275,
                                   0.29139009422310086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24493380778451981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27965065600926187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0011880825959394744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19896119547466126,
                                   0,
                                   0.40855408878142113,
                                   0,
                                   0,
                                   -0.40099210120903805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12882423414999594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38707189560161404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20859812467735223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38540453489418819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11209971261020094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33760714131187047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68370598852256714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21801611183910746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4536837370474055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11053821813126175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22447652563041659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25844841208711017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10919883767151711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14847937752695417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26190308861193923,
                                   0,
                                   0,
                                   -0.33192915302031667,
                                   -0.29786978838299383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7903619795655068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47842860837105988,
                                   0,
                                   0,
                                   -0.29901720095091261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51857485357752398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24165247174604618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34451684592039611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047268716530814728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059819375128802553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35248873919653456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.093806707311058,
                                   0,
                                   0,
                                   0.15810458385418094,
                                   0.32406749830727877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0086629733031281103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017677914862016239,
                                   0,
                                   0,
                                   0.35086257425642886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070645519557757996,
                                   0,
                                   0,
                                   -0.43041004676165617,
                                   0,
                                   -0.026017183457578887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46020948054072702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17651318829679041,
                                   0,
                                   -0.32207317808502811,
                                   0.4086511862145823,
                                   0,
                                   0,
                                   0,
                                   0.13852696928606942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22646845389902501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055862926519574925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16550563669513513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29409559842270333,
                                   0,
                                   0,
                                   0,
                                   0.23940544168407735,
                                   0.22495613357183805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29125361438593972,
                                   0,
                                   -0.10816161183368724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065250434893522016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092112746898047909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64110977501091637,
                                   0,
                                   0.10731972927417849,
                                   0,
                                   -0.1106962355471945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13100464157720312,
                                   -0.0183875325916254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16958223910169665,
                                   0.63099395588057283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10735581177224143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19622388818471695,
                                   0,
                                   0.4908039008987331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10061348622748673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66494489292451942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071204887211671397,
                                   0,
                                   0.32866417850426133,
                                   0,
                                   0.058300614105700359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25585449400469301,
                                   0.011026519062162597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22248796934071199,
                                   -0.16654798854969943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094981352458626392,
                                   0,
                                   0,
                                   0,
                                   0.31043430763469748,
                                   0,
                                   0,
                                   0.1817791286451888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22113503952598307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20507532273134738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63515221401465749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21463280816374553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56093753220937237,
                                   0.53360082328650538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27621013471430389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43562854684997976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37567222862659444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11663406930885112,
                                   0,
                                   0.0065414575825141208,
                                   0,
                                   0,
                                   -0.33009177288490943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33136681125673495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31772227064766689,
                                   0,
                                   0,
                                   0.412105416066608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096042549850365977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084067195582730986,
                                   -0.049186675245840285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61363474627295456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2183798515932693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17589405758004398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016451472884106297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08928639756503759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24810822250865253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78941564149997012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50237121918825245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53613779564663022,
                                   0,
                                   0,
                                   0.33862185849602983,
                                   -0.52356248215314638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047655292515505376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067769391643745805,
                                   0,
                                   0,
                                   -0.58156316945445019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48100709433068195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19941541424478129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31208689731165379,
                                   0,
                                   0,
                                   -0.35812128178777047,
                                   0,
                                   0.2421301825839669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0065287928268653872,
                                   0,
                                   0.20666438453803571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75221639068041835,
                                   0,
                                   0,
                                   0.78278827353775804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42589221087740137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14507044698060639,
                                   0,
                                   0,
                                   0.3626013093800517,
                                   0,
                                   -0.15198989490882137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28322901450965743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20497395975931235,
                                   0,
                                   0.34830024681103811,
                                   0.26582925862804702,
                                   0,
                                   0,
                                   0,
                                   -0.026585170936011059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013775200882459216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33315337128925399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41712769912152786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030871628536034767,
                                   0,
                                   0,
                                   0,
                                   0.30613747414017634,
                                   -0.36000867769148981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66977570901522987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76535727800430031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71569875939172267,
                                   0,
                                   0,
                                   0,
                                   -0.94900585957427408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74751608654870072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48363501877337733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025798027371302601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42052857170766439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88986595975861782,
                                   0,
                                   0,
                                   0.2625821099079545,
                                   0,
                                   0.55287046058024769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18417134179316461,
                                   0,
                                   -0.05938008092675931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93148858038678561,
                                   0,
                                   0,
                                   0.047223772913426117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11889921904609055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075001348748594751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21885081941844364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0087010373745463332,
                                   0,
                                   0,
                                   0.44199214677881415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33054154861324603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80111711709374156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47942880570627056,
                                   0,
                                   0,
                                   -0.19808470131068162,
                                   0,
                                   0.26558835543642473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13963562791679718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094985928649403556,
                                   0,
                                   0.31264127971325112,
                                   0.060757050547118434,
                                   0,
                                   0,
                                   0,
                                   0.52240370173058448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31746986932518567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33635009387388476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023581429678018725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015713341469122982,
                                   0,
                                   0,
                                   0,
                                   0.12439609074602788,
                                   -0.16527359482519824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15440741031279534,
                                   0,
                                   0,
                                   0.083878231433138578,
                                   0,
                                   -0.4054761915093234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43352294887674386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0015490352029769519,
                                   0,
                                   0.41325049168365374,
                                   -0.32057048578238334,
                                   0,
                                   0,
                                   0,
                                   0.10583489148136453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072082299660168908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42109123803292464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12326784614487979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11190604417739169,
                                   0,
                                   0,
                                   0,
                                   -0.1746719803936202,
                                   0.30213070322018998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49576635975208255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0257323571184249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11586225783955542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13066728667099489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57157623614997832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11499954384137433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073786539010199451,
                                   0,
                                   0,
                                   -0.23473072705317827,
                                   0.66811004208314828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6410840273644145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71819258558024346,
                                   0,
                                   0,
                                   -0.27961920710005295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39384134579218077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10874170688887269,
                                   0,
                                   0,
                                   0.89170489673697562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1481600769577891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15692535751111841,
                                   -0.64870235595817871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58655716413869352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091003042503022394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75222437016524224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39236621483939504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04532710327396814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027458922756037903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33449889196750859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27998923756267036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29312341330494435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034552776241891188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35270636340104994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19595519772340347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1238413863692551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54986365657598446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020045599627568078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44781921016407045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61574345565775823,
                                   0,
                                   0,
                                   0.032879701799034301,
                                   0.060385305630455521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10546359259564243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48738479602714724,
                                   0,
                                   0,
                                   0.33997681965933108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090085749644727778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5417544621514756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3650075596068072,
                                   0,
                                   0,
                                   -0.0583113245610965,
                                   0,
                                   0.085154849808438987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5901241856603574,
                                   0,
                                   -1.1382354972836144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28197513099685911,
                                   0,
                                   0,
                                   -0.22979584997641764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27118316459624336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2747909220964655,
                                   0,
                                   0,
                                   0.041493556003454682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16843312064898897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26467000291039161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090527508394883133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078667327476624721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58680871970579951,
                                   -0.33598214401257143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19792533386965366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12274800370862944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32097155620502338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77322818373633306,
                                   0,
                                   -0.53917711935286416,
                                   0,
                                   0,
                                   -0.35754586334286798,
                                   0,
                                   0,
                                   0,
                                   -0.74900151984541496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58513541058666108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23902772058155344,
                                   0,
                                   0,
                                   -0.11954248372405227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0069394632244201143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15855743998837279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1871814365623837,
                                   0,
                                   0,
                                   -0.42587878559704628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13983404997013396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43670922088668129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56235800887978427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59919603400758337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034510569768596122,
                                   0.24958877573530358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58625694123286265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17743708226760277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63869808088472757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32808148685938232,
                                   0,
                                   0.0096226771465623001,
                                   0,
                                   0,
                                   0.11504997664418609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91830872463091906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39501013085167636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13767385697840365,
                                   0,
                                   0,
                                   0,
                                   0.87520664494404476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64750162289649715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63384825121516164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18103999706293633,
                                   0,
                                   0.63358404814643121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45692041514014425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020293970962323042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11787039898660524,
                                   0,
                                   -0.053611670116764126,
                                   0,
                                   0.01468144099217727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38887564352513665,
                                   -0.22471838484772561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22067298326265694,
                                   0.27970589368212789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10473731145479402,
                                   0,
                                   0,
                                   0,
                                   -0.75645678864426291,
                                   0,
                                   0,
                                   -0.49935962228077918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53514988998858826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26345030800441038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17993858913494082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31688439538463958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65837069600027553,
                                   0.11269561304474363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57042640175119241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75745493037269107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089553636643447926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31579678537220129,
                                   0,
                                   0.52483701890636902,
                                   0,
                                   0,
                                   0.31921460594096018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036627172853970283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27423632405470011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067013408746079306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31175196975222902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4171040762243588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42940176483433856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14778237951286494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66450845249795132,
                                   -0.58196780642459545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083143763815227659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58119636632645411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19411942849689842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37921584492278582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17405238107147758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29474600192028233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13399598511816221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15341509648016724,
                                   0,
                                   0,
                                   -0.019922292650025444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3403508584805624,
                                   0,
                                   0.18379001704593206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40155232053381518,
                                   0,
                                   0,
                                   0,
                                   0.29352628677311332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52292264213224704,
                                   0.85136532769864637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39754807906516421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55059782658825973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60333653823344913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029437895553523559,
                                   0,
                                   -0.098796872758322385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22957552071702736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15091991772191946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37009177978301533,
                                   0.2104373969420012,
                                   0,
                                   0,
                                   0,
                                   -0.4018271785363553,
                                   0,
                                   0,
                                   -0.4164160141649173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08816865225948875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67792940701225946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36205881299587828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8271617558067903,
                                   0,
                                   0,
                                   -0.70696803378196971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39168126364219941,
                                   0,
                                   0.71327719454836969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26713873470754268,
                                   0,
                                   -0.13847138503765793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72639631407173666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26216505659421274,
                                   -0.0058683912639268532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44729312360782181,
                                   0,
                                   0.11401572553169831,
                                   0,
                                   0,
                                   0,
                                   0.072665909870126888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035137771362848721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30571275799933706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2991360511711838,
                                   0,
                                   0,
                                   0.21147142480745221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31401041749400638,
                                   0,
                                   -0.56672633727123334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23470018854063787,
                                   0,
                                   0,
                                   0,
                                   -0.46981657931916354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81364916036464496,
                                   0.17974240123741736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11859071727206413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091974291162764066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75549249579363886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21690599022221932,
                                   0,
                                   0.33575646151438809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20557058191305588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093542610848119462,
                                   0,
                                   -0.57499416515061885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46666213099325282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29313374352882593,
                                   0.12371720998733379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38484366344529625,
                                   0,
                                   -0.18798214492304643,
                                   0,
                                   0,
                                   0,
                                   -0.022162905356214041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10316694379392655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38346846165432391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1739943824237713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23350217129062406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64214066704653483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79769893534338754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53123055563577393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41473218600922679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47981811455950674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2277729327390946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3216612748502673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09802982603422862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59216159028654791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095853179757326976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45980869057767426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18316940931925269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20887151438827678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63261184329825981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81497109368108656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063305866864576746,
                                   0,
                                   0,
                                   -0.10319765967896655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28395369032888179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37578584738789578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29258294979380939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17496329731677088,
                                   0,
                                   0.40821841195077951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082649099803079204,
                                   0,
                                   0,
                                   -0.2972399666201051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13714615838127783,
                                   -0.13769271393704036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55126296153941623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10122620711486592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18860883865301742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3977458013308785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43008171112201399,
                                   -0.0051114083998825277,
                                   0,
                                   0,
                                   0,
                                   -0.12104781069746562,
                                   0,
                                   0,
                                   0,
                                   0.1727919547306237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2046019736754191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29625758654463447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23402419112537179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65461005523436788,
                                   -0.22297388190996986,
                                   0,
                                   0,
                                   0,
                                   -0.057670283680987533,
                                   0,
                                   0,
                                   -0.2616366305464764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56399493331858364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099393556958976337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49622917154666446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6464741069757054,
                                   0,
                                   0,
                                   0.23338519147295844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72537861134812709,
                                   0,
                                   -0.42185902066524084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4908219302964999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1522419578248651,
                                   0.16784291872789933,
                                   0,
                                   0,
                                   0,
                                   0.58759486451463983,
                                   0,
                                   0,
                                   0.10532178845054571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075087582049646356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3613707590029005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10123528093186418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20441299751767342,
                                   0,
                                   0,
                                   0.11586801130939031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73560865185613356,
                                   0,
                                   0.75271434139801308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26748337906722142,
                                   0,
                                   0,
                                   -0.16250833040014545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025466251436452016,
                                   0.064868900566589366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086864704784067784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13289262668951282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11360099359078618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4911163447511574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28745145143302697,
                                   0.3990122297022512,
                                   0,
                                   0,
                                   0,
                                   0.0044112998035257733,
                                   0,
                                   0,
                                   0,
                                   0.21985215821375254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57243203218566552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0029739478566304378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32216354102028971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14262808822950257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33893257647839009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47516759725181396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1298267260970386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4878456872725847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44907332142821849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28052290992148793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034355735275418672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61551923934360886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038194772784295089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1502581119124764,
                                   0,
                                   0,
                                   -0.074919719843653462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27706938582436619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66680907290631275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29258034648810399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24260451173493597,
                                   0,
                                   -0.13910935525012802,
                                   0,
                                   0,
                                   0,
                                   0.61439966298886106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23745251525600292,
                                   -0.21091319511245671,
                                   0,
                                   0,
                                   0,
                                   -0.34087843217831792,
                                   0,
                                   0,
                                   -0.11543140174902773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66426347052575596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54087952853891286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067400640777187201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58036973499398348,
                                   0,
                                   0,
                                   0.44549141987391483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1218547623689709,
                                   0,
                                   0.18458634653891534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16584981947077218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56029279220234285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11298303274105587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69725941393576174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031137023289633581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3434392989940107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69239512800314384,
                                   0,
                                   0.28256661779987235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23599064046430926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049122045196546858,
                                   -0.14668462807183658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36305589738106248,
                                   0,
                                   0.052247669097906665,
                                   0,
                                   0,
                                   0,
                                   0.23373092390642913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089423673653485705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40491729235717222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38818280049884368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071785772868965925,
                                   -0.22610473155011529,
                                   0,
                                   0,
                                   0,
                                   0.53945243804289245,
                                   0,
                                   0,
                                   0.44797283197928434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45046973976950289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088216162972891837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65078782279601377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48981888014619523,
                                   0,
                                   0,
                                   -0.32206901852081526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53534835573499029,
                                   0,
                                   0.52641112447129546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39774587153450192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12414052817832477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38475102626590213,
                                   0,
                                   0,
                                   0,
                                   -0.77812027225149416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25499280417657361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088665159209404265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67249695462778225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33955722028534685,
                                   0,
                                   0,
                                   0,
                                   -0.27914594022016459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19530203010097916,
                                   0.014931767831564149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1087889481965271,
                                   0,
                                   -0.073405358024945508,
                                   0,
                                   0,
                                   0,
                                   0.35489264655711888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0063709794846137785,
                                   0.3096879365111479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20589840088792402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18613681062536583,
                                   -0.097126436218515869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25238943283339477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12936559285256422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14400799387688396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3737245647180879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69052176233350127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52070130821838101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042095887646744656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16848606338860211,
                                   0,
                                   0,
                                   -0.068818781299776491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2650074883438947,
                                   -0.23754662245925534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32631953613004611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17035694911828622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0042130348948628896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0045106354547696272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37204587633213004,
                                   -0.38181368824687723,
                                   0,
                                   0,
                                   0,
                                   -0.51492451461442512,
                                   0,
                                   0,
                                   0,
                                   0.21072682897324474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16664478529268184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28836030673819429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25624550668146007,
                                   0,
                                   0,
                                   0.308622437006843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068343733564647291,
                                   0.44936321887178426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36144614604688263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0046698160969054284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16260531531747263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025405046394380439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54035356354222419,
                                   0.063482256206875573,
                                   0,
                                   0,
                                   0,
                                   -0.31607846769928505,
                                   0,
                                   0,
                                   0,
                                   -0.12279520044367555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14406890194601407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20733826630382887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4831180034190759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36787461932418558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21500675883734288,
                                   0,
                                   0,
                                   0,
                                   -0.16939563121315079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74571380195694925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015918498061098345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29722247419218867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058398457434106876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077629837535335519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15222100070217706,
                                   0,
                                   0,
                                   -0.92347144103201473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19173904514357848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36444080845063898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51724879628758724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20621660702949016,
                                   0,
                                   -0.52941720771908962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10704616343557777,
                                   0,
                                   -0.39721938729976269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18561940307139177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081374213370229764,
                                   -0.54503962227612457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24687789496597806,
                                   0,
                                   0.38442315000441174,
                                   0,
                                   0,
                                   0,
                                   -0.41098384235883578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082109824278209426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32898900710000356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30700091773522697,
                                   0,
                                   -0.030634673038205773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10667019843286993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68545892052478974,
                                   0.03598063549481547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49300722364340749,
                                   0,
                                   0.1700595787686956,
                                   0,
                                   0,
                                   0,
                                   -0.12232824308466678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36312202171318442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059048282120845716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57959041776327958,
                                   0,
                                   0,
                                   0.13026455344904209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14240327975439165,
                                   -0.15240702463458305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046057390784896575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11362563746066169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0507080993943025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25041261488270133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10476844741278152,
                                   -0.1756696732963608,
                                   0,
                                   0,
                                   0,
                                   0.39412755211188366,
                                   0,
                                   0,
                                   0,
                                   -0.50453445924593376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20880415728686699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16722037868693096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34336915361035625,
                                   0,
                                   0,
                                   0.5083866298218378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76126862744322488,
                                   0,
                                   -0.3032793496253014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44911836917282211,
                                   0,
                                   0,
                                   0,
                                   -0.084126536541973426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53494383548905267,
                                   -0.25906685510985761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0049181772677819868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28151241802773569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26124477111968025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10113531791766504,
                                   0,
                                   0.62319696802863767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17241030481949057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046476595305861221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044776376421666181,
                                   -1.1586024667521742,
                                   0,
                                   0,
                                   0,
                                   0.0016694719873558226,
                                   0,
                                   0,
                                   0.060282067422239211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55044057085174236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50457070167599183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38429113794251579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019986758661730213,
                                   0,
                                   0,
                                   0.12953553959318861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11965621005070623,
                                   0,
                                   0.29602569533654488,
                                   0,
                                   0,
                                   0,
                                   0.11049180994354425,
                                   0,
                                   0,
                                   -0.66074191895237233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34105296042931077,
                                   0,
                                   0.53038878064385142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27973993320166873,
                                   0,
                                   0,
                                   0,
                                   -0.20478793957379815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13142356390402896,
                                   0.22634335042926529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64818727361442896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30111509394465535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02177208722771462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31237123387181576,
                                   0,
                                   0.50148621569751595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43595379086426544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14231462774303852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35206633776480056,
                                   0,
                                   0,
                                   0,
                                   0.018909092493734764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19852111035998454,
                                   -0.37692845356327631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081153197277446687,
                                   0,
                                   0.20742188675073386,
                                   0,
                                   0,
                                   0,
                                   0.095446653708849971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20811373531634583,
                                   0.048675298269579045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56714924251679433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4978895232760126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041411363869811348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96058105265539573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62001886820285135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26053068460566869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41418319103884432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22792190655871364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6554828802815591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094213393044444024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62043541998588525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075125704644571689,
                                   0,
                                   0,
                                   -0.20039226245992692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45161191220585095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49923857825452866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01612694600075304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71735805196649982,
                                   0,
                                   0.055609539780701871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75938571184321746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32849895421215991,
                                   -0.28919980575365961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17678641212297555,
                                   0,
                                   0,
                                   0,
                                   0.031945409460438189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93796701075023747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33869805653656571,
                                   0,
                                   -0.45066735383027151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35840337978106507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033656412629352067,
                                   0,
                                   0,
                                   0,
                                   -0.36713143607079002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36430241717401557,
                                   0.092519059615631102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49610498768560674,
                                   0,
                                   -0.0073798256223172251,
                                   0,
                                   0,
                                   0,
                                   0.55290179706846954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0015469471546951524,
                                   0.16441438233411382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091486578618493644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08410380658818159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14171734937186792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0880566406297576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29712659458703039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29635397556515081,
                                   0,
                                   0,
                                   -0.082559375819136527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48568284678470752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39538943160089296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49073221189566396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55847390139471831,
                                   0,
                                   -0.2884866677722111,
                                   0,
                                   -0.22560826135623352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46626362509937364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54168583497629008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28479223306510754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54961015489459886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18519162258460162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084703532443761123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11673489898740771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15185278596994056,
                                   0,
                                   0,
                                   -0.22199675385852824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41159947123854762,
                                   0.40710931294146141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13798471287701974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45315275444056441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39832115886403208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34950613233199124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050754457657457591,
                                   -0.10825468723576044,
                                   0,
                                   0,
                                   0,
                                   0.25744159357108615,
                                   0,
                                   0,
                                   0,
                                   0.071382556730087712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094629480429906515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039348317735604169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65053566341830127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22761556026731511,
                                   0.34498168121172451,
                                   0,
                                   0,
                                   0,
                                   -0.24732391772797402,
                                   0,
                                   0,
                                   0.49584428756879484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063829556079947294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20680505989000011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95381614460672348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10349467978539431,
                                   0,
                                   0,
                                   0.27898295861709921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49193744573673137,
                                   0,
                                   -0.52999152679735118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8633480259290045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41000483194647119,
                                   0.14630848070924324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17896663816715799,
                                   0,
                                   0,
                                   0,
                                   0.62119243470437813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28696160200883369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25221383487947735,
                                   0,
                                   -0.45497763821068254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52498274258350686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0517637916764175,
                                   0.081862508066830375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28648741254691967,
                                   0,
                                   0,
                                   0,
                                   -0.27868783547679843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6395581209392569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37040854099216192,
                                   0,
                                   -0.0096556633911962231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12897861436415636,
                                   0,
                                   0,
                                   0.26078608297540001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39397681693215258,
                                   0,
                                   0.11972984972597919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90223073717766544,
                                   0,
                                   0,
                                   0,
                                   -0.589278898406145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20154794849086466,
                                   0.31667286165450753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55164090723269554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044794022476872412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54169942919841119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45998142521099261,
                                   0,
                                   -0.20949991094958356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21505431699665573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10973787493640655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03924708423020784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052234162124572547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4618384042340612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19723500221251528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038391781055577279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022210724357210096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85412250563879122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012431216929157732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38386274617218402,
                                   0,
                                   0,
                                   0,
                                   0.17175082100084271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058368696909666097,
                                   0.043308032592283066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17658594946133951,
                                   0,
                                   -0.14796932839104629,
                                   0,
                                   0,
                                   0,
                                   0.091961476578532042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59329205254353812,
                                   0.38752303383349557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30495788729649798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4012614044647792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25889773493721652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26788783321299248,
                                   0,
                                   0,
                                   0,
                                   0.033177613357948776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40653302235580069,
                                   -0.37155792933457604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016376031463514823,
                                   0,
                                   0.6078895210171269,
                                   0,
                                   0,
                                   0,
                                   -0.037126630601929653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053156235789586281,
                                   -0.08830878206469861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41196991142715628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072549702497069865,
                                   0,
                                   -0.058818000586989896,
                                   0,
                                   0,
                                   0.21424223210823856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38337281558465064,
                                   0,
                                   0.57915627998276786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042966488060682428,
                                   0,
                                   0,
                                   0,
                                   -0.55620712006189166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19023234358973629,
                                   -0.27822976671048261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20062830326629294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18074101550730068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50248779074760852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92040569561378027,
                                   0,
                                   0.25758102773238079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40974854479088962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11111431332566873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80760805595392848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9772051845234152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12945556215394108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1721095336554808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012924142876772904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33398795152545618,
                                   0,
                                   0,
                                   -0.1922901035222844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25588670488997284,
                                   -0.54497998904668277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14266508571213318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29960895543580951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28905652401512594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25782576042235805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36313342875196569,
                                   0.18733642570159906,
                                   0,
                                   0,
                                   0,
                                   -0.059886809927982135,
                                   0,
                                   0,
                                   0,
                                   -0.031984754596346671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11706194588880296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20874612157778002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9189439112259441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25466376409952912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22333205643280488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061124174517870111,
                                   0,
                                   0,
                                   0.21580830251629105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14908595017310328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22085710218790339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048831044259570938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81399036089238819,
                                   0,
                                   -0.34242525664294765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23591424076992529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66484544755960873,
                                   -0.11289334431721326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3354889853050467,
                                   0,
                                   0,
                                   0,
                                   -0.73349800470979476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016962802095757762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37723142846224467,
                                   0,
                                   0.092289605980386297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48249585678434098,
                                   0,
                                   0,
                                   -0.32201073129874841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18501019513222855,
                                   0,
                                   0.1923119644391805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17870384920802354,
                                   0,
                                   0,
                                   0,
                                   -0.11313868530717611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8942514119689654,
                                   -0.13576817859180967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51047372783870304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35644511330800266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20379396051884907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0011758627184830228,
                                   0,
                                   -0.60102333232101524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23249210452352098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53718614192982084,
                                   0,
                                   0,
                                   -0.17644065027238168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091105862621744665,
                                   0,
                                   0.12815208618871857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050512936666507316,
                                   0,
                                   0,
                                   0,
                                   0.84044489089259122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2233468079948944,
                                   -0.30350576009207803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99375904778429969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05435427375135829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37281452640236679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057738480843032555,
                                   0,
                                   0.18110740004413234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011929567724659092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26551280794246668,
                                   0,
                                   -0.24907928232954377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10314135266543184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38323777505198608,
                                   0.48902779018988529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16792545548180837,
                                   0,
                                   0.42971736058507132,
                                   0,
                                   0,
                                   0,
                                   -0.15802927402990624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38621027254134915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28951227062837803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03259293830517318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37255664657038978,
                                   0.45118218450930692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41485119238152113,
                                   0,
                                   0,
                                   0,
                                   -0.62564752839806315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1449911555730197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55666517481188349,
                                   0,
                                   -1.1935281609974626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21560557922619172,
                                   0,
                                   0.0084593066344603937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01004607301416021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23119247763379827,
                                   0.33181867992005831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06508365737805949,
                                   0,
                                   0.29036824078113849,
                                   0,
                                   0,
                                   0,
                                   -0.28363001430320589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7876142605394606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021362269674734233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27868072468749749,
                                   0,
                                   0,
                                   0.090551810625754445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2419489407478565,
                                   0.29009848443496145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25207437738998489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35450252970793128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43681205333954576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18376009308912578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010628011068305424,
                                   -0.36709011959564719,
                                   0,
                                   0,
                                   0,
                                   -0.25365070788068356,
                                   0,
                                   0,
                                   0,
                                   0.21163842480802203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077498581828021038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32810254562546559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47792416119301456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80005774283757558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24370335660560297,
                                   0,
                                   0,
                                   0,
                                   -0.25846199111306312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045141362422065096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057135232574218708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72853459061674897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20713299986842226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34651159432444933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55224194962221451,
                                   0,
                                   0,
                                   0.17848169888555099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87963662462737791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023629484429145697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37743048871548573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38039234554922036,
                                   0,
                                   0.29863297971253033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30795931640962254,
                                   0,
                                   0.47115929097061537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20833439613962423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048019404604266992,
                                   0.32681199085800849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026082813128984278,
                                   0,
                                   -0.033720779571507632,
                                   0,
                                   0,
                                   0,
                                   -0.53799836962154035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23676698596383236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42817819338815044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06229058326954167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035366957621405348,
                                   0,
                                   0,
                                   0,
                                   0.59500653612458154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34701025870585983,
                                   -0.03329664356835535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23365744223628279,
                                   0,
                                   0.28416038598545196,
                                   0,
                                   0,
                                   0,
                                   0.2728436763260646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37122654614242601,
                                   0.4058370791192818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079807505412675159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02535308930924713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018898523444529719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2185045294611821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12338979048150574,
                                   0,
                                   0,
                                   0,
                                   0.28581353848935626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23960135368908675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89307076346057113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14870396770464508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36053235701730463,
                                   0,
                                   0,
                                   0,
                                   -0.0013044104771258863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27356538115104317,
                                   -0.05059166101899383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1186807717623784,
                                   0,
                                   -0.097940736415792568,
                                   0,
                                   0,
                                   0,
                                   -0.11846903157601907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18299936257629937,
                                   0.40589728787557044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49791013510180976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5353839851856349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018970905159455702,
                                   0,
                                   0,
                                   0.017813819444284465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040414426435992648,
                                   -0.16416529479945502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14165955612396158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30600451239932486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33017076450915411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0015660653187289236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12127540624647046,
                                   -0.51446822020317118,
                                   0,
                                   0,
                                   0,
                                   -0.057854574345661686,
                                   0,
                                   0,
                                   0,
                                   -0.15662435090790455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51262114875747899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42186937549865361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018036011931290053,
                                   0,
                                   0,
                                   0.4916853098788147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18062661219044557,
                                   -0.12680935887829756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22356452462745136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40753703461492263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11762147689024757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075313600638117581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075008798534939206,
                                   0.38664211344355259,
                                   0,
                                   0,
                                   0,
                                   -0.31567626689557354,
                                   0,
                                   0,
                                   0,
                                   -0.11992137463431776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26794308943133371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36427270797556732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22537851759514038,
                                   0,
                                   0,
                                   -0.39490580323424751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38339781661190214,
                                   0,
                                   0.17684224404958826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73980610505673627,
                                   0,
                                   0,
                                   0,
                                   -0.37286861981357516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078263110499837973,
                                   0.074331313869220372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00021162764920970578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24140736059981888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059703394808735835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32500088648525566,
                                   0,
                                   0.1969232886373504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90838445585282157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18288512175644336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34412838077113439,
                                   0,
                                   0,
                                   0,
                                   -0.036796141827327294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43090860768589123,
                                   -0.1331239651760372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29647886535163553,
                                   0,
                                   0.062065491114272821,
                                   0,
                                   0,
                                   0,
                                   0.35919227233351869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3057976986377543,
                                   -0.53598124412333048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19022537656762825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075005091337933982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63975589629568774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48675454313244343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81520087653121853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2730171847644684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1437661814993871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27284209688440308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07028812230953034,
                                   0,
                                   0,
                                   0.22482701352973644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43882580925333292,
                                   0.090118179987730404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44166936521040456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43906172540106364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11810160566279176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15627754480765349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30891275453034395,
                                   0.020852260446007034,
                                   0,
                                   0,
                                   0,
                                   -0.088772739185973212,
                                   0,
                                   0,
                                   0,
                                   -0.27532304785130285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26312072513297813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26235000838031169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2975544393044886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041002019425306416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27547158186707527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60586044115828386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081996947123233174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38279865364798438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4578150272245507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32245281166633377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10644707189974367,
                                   0,
                                   0,
                                   0.30166899949993442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77900683898152401,
                                   0,
                                   0.01810601454624277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84164170232381608,
                                   0,
                                   0,
                                   0,
                                   -0.15039754045451009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038936653363060569,
                                   0.35062603239275703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20953270467555521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20795318080176281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60912645647176156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39530947064238525,
                                   0,
                                   -0.67416058982718818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14034565223732196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49178366024721226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16463701652195495,
                                   0.3661222502675896,
                                   0,
                                   0,
                                   0,
                                   0.79268703476491775,
                                   0,
                                   0,
                                   0.0040948965329563186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4220063442689268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77741183416364712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17401704110381216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58460186829959659,
                                   0,
                                   0,
                                   -0.23444501705907134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12911691322581006,
                                   0,
                                   0.19145427370359575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37134362505135837,
                                   0,
                                   0,
                                   -0.30786774171967707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47997334162172395,
                                   0.087618413406271634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21800133067338104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12962369419585543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24858822079307266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47158990625758829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15048699716878675,
                                   0.24118903404448597,
                                   0,
                                   0,
                                   0,
                                   -0.30581312872986044,
                                   0,
                                   0,
                                   0,
                                   -0.078339976098664277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0039034986427157123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016043687631079866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07430283197257731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23967125217491009,
                                   0,
                                   0,
                                   0,
                                   -0.52881256111695518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30827299741088116,
                                   0.29476636656955185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13548751571948064,
                                   0,
                                   0.41040481818441915,
                                   0,
                                   0,
                                   0,
                                   -0.33813472656852134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12644849170502331,
                                   0.22536271187885817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1477821196511237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29280266492733309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057107474388399818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35140574020837945,
                                   0,
                                   0,
                                   0,
                                   -0.097174224229684789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11906653794597892,
                                   0.1992638810293694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6642949023709378,
                                   0,
                                   0.075246764986890161,
                                   0,
                                   0,
                                   0,
                                   0.46071310798500165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30799621704016455,
                                   -0.085358871301023889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21794462915210719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032755895626853646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16927860682777196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06933597579673173,
                                   1.142770559549136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12808953625731201,
                                   0,
                                   0,
                                   0,
                                   -0.59180354333520491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39485015226113812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44643990283350066,
                                   0,
                                   0.28559884607210828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3087954806183526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38093614391545905,
                                   -0.15961704643260829,
                                   0,
                                   0,
                                   0,
                                   0.33578886464158342,
                                   0,
                                   0,
                                   -0.73392920678049345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08203174118254368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053973627997611545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034861348703629835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27154178025109749,
                                   0,
                                   0,
                                   0.61589987837693727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55583963410603654,
                                   0,
                                   -0.38616829427923205,
                                   0,
                                   0,
                                   0.4079032045879436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79783465767273376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23472860093113124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21146406576306143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036311114929707344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25179265788399657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10789558927411552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14457098492592241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60645499344387699,
                                   0,
                                   0,
                                   -0.88094851520495099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45423364183175968,
                                   0,
                                   -0.52179703040696146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48763802939810852,
                                   0,
                                   0,
                                   0,
                                   -0.61559235798131307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20177364653420288,
                                   -0.17769856216102278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20589816242592851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17819846578217996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35212542170267125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10465595961920535,
                                   0,
                                   0.013004274371131691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45378322058419568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36272912171193256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4543618208374427,
                                   -0.33324237095918352,
                                   0,
                                   0,
                                   0,
                                   0.12804432054538592,
                                   0,
                                   0,
                                   -0.27793662489052934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23602795391835604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24071694771063146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12417921748814889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045631527199390509,
                                   0,
                                   0,
                                   -0.71097135117303634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47260139341247842,
                                   0,
                                   -0.57133436132340443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48064988579700052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064485668728261919,
                                   0,
                                   0,
                                   0,
                                   0.30825502606213001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36181318545777424,
                                   0.57945537343623421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26092943339715935,
                                   0,
                                   -0.10756546320126614,
                                   0,
                                   0,
                                   0,
                                   -0.021639018748357518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090418165758504976,
                                   -0.19923725609875767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064295720974251819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26644173823305628,
                                   0,
                                   0,
                                   0,
                                   0.31525970246051682,
                                   0,
                                   0.14972441004546219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20514904032300688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25724908670872676,
                                   -0.38152700656555055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10280022955889861,
                                   0,
                                   -0.27239166045052443,
                                   0,
                                   0,
                                   0,
                                   -0.5657317490221957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068716112444311861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46349587172133738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55517518324657122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35902742218498068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28948385745128169,
                                   0,
                                   0,
                                   0,
                                   0.33425769852834647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52270608483141823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30680459930746284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52463144105368109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33562151120667771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76792399891183138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3014933073375614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13801718700252158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83448329861070647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77467146722596247,
                                   0,
                                   0,
                                   -0.30165445731294371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094027893277255942,
                                   0,
                                   -0.31885979459868546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33488072182201867,
                                   0,
                                   0,
                                   0,
                                   -0.31081796214445823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74890479212354255,
                                   0.39005983881094852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.167987445970816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22207334541647578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23194229391549984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40342765774352762,
                                   0,
                                   0.24542474460297944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18070489177363463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10564715211485204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013174292202770596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31501817162636303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20904653708980264,
                                   0,
                                   0,
                                   -0.51262326144716075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45138228031441624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90965859594999876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06172334918577603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54217344706664883,
                                   0,
                                   0.56712844183605204,
                                   0,
                                   0,
                                   -0.30033523763339909,
                                   0,
                                   0,
                                   -0.36635136542557528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15990375940605128,
                                   0,
                                   -0.50070568915847358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16875017953368579,
                                   0,
                                   0,
                                   0,
                                   0.19961892015674457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18797214007640439,
                                   0.098097793165687994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25004100224104453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63167613369108988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7113945311954224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29932431518032598,
                                   0,
                                   0.083576324587725043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073247582374083117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13615603039978136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40331051885175506,
                                   0.077295032595991769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087408131618823451,
                                   0,
                                   0,
                                   0,
                                   0.25624686601487129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7045959258641763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79866251775208474,
                                   0,
                                   0.47114778441526056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22594209523117437,
                                   0,
                                   0,
                                   0.52422659026575602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14609021647101933,
                                   -0.21289528104560076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12629005913707958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066169035881609842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093531688396866736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24558528029636134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055533757171570233,
                                   -0.035451264735061529,
                                   0,
                                   0,
                                   0,
                                   0.28447589514738697,
                                   0,
                                   0,
                                   0,
                                   0.61347522469580917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12066114196675853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20470413984280308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16274387603858284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17894665851301531,
                                   0.79851320763800882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83488355936054481,
                                   0,
                                   0,
                                   0,
                                   0.37964471542678574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27035735113498133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19898150922348865,
                                   0,
                                   -0.26916038773450662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15348218450882789,
                                   0,
                                   -0.32422406148950367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23837315790544622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31248889913168326,
                                   0.25131591237623963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41512259957031683,
                                   0,
                                   -0.65416118587448158,
                                   0,
                                   0,
                                   0,
                                   -0.20202107467130065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10606880621878251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037073961793353677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26722102147161231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18033325420035595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80456290698789545,
                                   0,
                                   0,
                                   0,
                                   -0.32498272781450405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21499161141385931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31131367695024303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4408773636068018,
                                   0,
                                   0,
                                   0.030251923720753984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15420995887601613,
                                   0,
                                   -0.14217233168376614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063392040615114609,
                                   0,
                                   0,
                                   0,
                                   -0.01087296743551841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010829916203859147,
                                   -0.60144436409837909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16757092875478061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77824905708500347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13234295044766353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57293945457915718,
                                   0,
                                   0.12201972861153833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56526237203799956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2912141901711508,
                                   0,
                                   0,
                                   -0.10776853957271926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33673179568843359,
                                   0.21023153435573902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13336385418515964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1888721659409992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53116284317455353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04503233119450023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12238678206887474,
                                   0.066999913246192824,
                                   0,
                                   0,
                                   0,
                                   0.21309584772970008,
                                   0,
                                   0,
                                   0,
                                   0.24424386709584545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31647149835623745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42858781895681675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14895065409916858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1830803826188776,
                                   -0.072775628017724192,
                                   0,
                                   0,
                                   0,
                                   -0.18959332361146658,
                                   0,
                                   0,
                                   -0.53812537716777475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30782194080620551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061041845443243412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52424101526128508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29182012728391704,
                                   0,
                                   0,
                                   0.17757741887805689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20189205916627573,
                                   0,
                                   -0.1207143827054922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10962080733329777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1741605437330751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61037143332421151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74065220666054332,
                                   0,
                                   0,
                                   0.76549143825295729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28660399314691343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38002646400372347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8826516559015567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093639193638654264,
                                   0,
                                   -0.22268853360670868,
                                   0,
                                   0,
                                   0,
                                   -0.10789061352137949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049735852977098018,
                                   0.36302775126735537,
                                   0,
                                   0,
                                   0,
                                   0.23138273846765467,
                                   0,
                                   0,
                                   0.42369395817779842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42308817321059017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59137148501151537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23890499303298943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53007839582912353,
                                   0,
                                   0,
                                   0.1328437979457785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1118127148794735,
                                   0,
                                   -0.49576964787162792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1068808503247749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23509479172616649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47454758388029783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10453130264799582,
                                   0,
                                   0,
                                   0.31097110467901806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11375063166600384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72084564485338132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56259766355254326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18025445387058014,
                                   0,
                                   -0.82890843498234912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18058902534871343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32520375971022908,
                                   0,
                                   0,
                                   0,
                                   -0.12976998525216504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   5.8522810345264936e-05,
                                   -0.47482556648083396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14035239797816557,
                                   0,
                                   -0.52938889606115014,
                                   0,
                                   0,
                                   0,
                                   -0.069626637636858113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46689202446814848,
                                   0.047087740235773209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030273416778455194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30562948548400798,
                                   0.41114408679786169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72705496935043257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1972695743960611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50443841849761484,
                                   0,
                                   0,
                                   0,
                                   -0.36697283662324587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66872564191948458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19112431147470146,
                                   -0.023299198834503789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035481506272353296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29847307603026024,
                                   0,
                                   -0.4063089114812376,
                                   0,
                                   0,
                                   -0.29772578088295676,
                                   0,
                                   0,
                                   -0.24120540169761165,
                                   0.14273518259795986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20467826609854622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14769164923524214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10152065095151543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61390587597238766,
                                   -0.29480038317942381,
                                   0.050024306803292014,
                                   0,
                                   -0.26875443681079736,
                                   0.2911520536972525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090042340392313375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44552797097657199,
                                   0,
                                   0.25761801967500031,
                                   0,
                                   0,
                                   -0.010705262299392487,
                                   0,
                                   0,
                                   0.13447558590237835,
                                   0.20305771952364376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45129380628948779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19357927901348371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20826433389774918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45148980472168965,
                                   0.089899250652531071,
                                   0.11900832871880615,
                                   0,
                                   0,
                                   0,
                                   0.1467322223537785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46054248042876611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1371784563963164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017893871246512552,
                                   0,
                                   0,
                                   -0.60777278613610597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081661815108605984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3425401124220141,
                                   0,
                                   -0.20258006294319381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060754016740380834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85954327701526889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48709018482740513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020044331281959621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20707029116137171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49407024999116983,
                                   0.23328242464351029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21360845822545055,
                                   0,
                                   0,
                                   -0.56161384172044837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24474167796936608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25880832765009126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51877643260349149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1052346777878075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2582882711488611,
                                   0,
                                   0,
                                   0,
                                   0.51831343721255152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71009720493253992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10577252428992796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67955500795652113,
                                   0,
                                   0,
                                   0.038333199703084284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13010919688297765,
                                   0,
                                   0,
                                   -0.34646323948502117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55260698087329629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075171645216949842,
                                   0,
                                   0,
                                   0,
                                   0.02832052455723464,
                                   0,
                                   -0.40101835948905407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75781662030167363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95551270138810374,
                                   0.035870100463004151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49823167587328543,
                                   0,
                                   0.20150053361069331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16078460175894171,
                                   0.22363446170625756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34657245201012582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043383516160028071,
                                   -0.40296347894744661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50826184255712015,
                                   0,
                                   0,
                                   0,
                                   -0.020951752793895301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076452742575010557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47780280207784448,
                                   0,
                                   0,
                                   -0.38321294860305166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04332495421162906,
                                   -0.007186886980543955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13211526588554648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77187985937673054,
                                   -0.083596102958554491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14602570915401519,
                                   0,
                                   0,
                                   0,
                                   0.5669648839098741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07825534195873321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13641165165576785,
                                   0,
                                   0,
                                   -0.10161349911984405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13699790351901359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52538323648393148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55040548040668802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66593401819352083,
                                   0,
                                   0,
                                   0.20809680637367423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84215005434928369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46073952210801189,
                                   0,
                                   0.38593719722893866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62926657710399736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25345542504633461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19287068529689855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63359065143829596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16084450511852688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72922670316850913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058171843517856467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018365248269432997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51372161901152724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0074444296000644797,
                                   0,
                                   0,
                                   -0.70136680202351875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2884914045896867,
                                   0,
                                   0,
                                   0.16901503943310842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73130552344903355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069010099153026888,
                                   0,
                                   0,
                                   0,
                                   0.54848785277428558,
                                   0,
                                   0.14057635488608564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45705145829766236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24889670951193796,
                                   0.6342173367130336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23168354439811084,
                                   0,
                                   0.5033607026398571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1498385690642195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51895239742518595,
                                   0,
                                   0,
                                   0.14094462580269668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27818857920370238,
                                   0,
                                   0,
                                   -0.23113229016563511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8027203263096363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058232134515529416,
                                   0,
                                   -0.68935433977688965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00086808569752056235,
                                   0,
                                   0,
                                   -0.10484730898946017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65828048863226152,
                                   0.67873772306713698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22874157392666605,
                                   0.36825417770459801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27633454107789751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35320116830978437,
                                   0,
                                   0.41187409508935213,
                                   0,
                                   0,
                                   0.16952021191228125,
                                   0,
                                   0,
                                   -0.41088246054612421,
                                   -0.086948059167515274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36600660355041703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14154248602095035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20281884031704778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13592486793246533,
                                   0.12478186446004291,
                                   0.083760973269086755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73027158482340637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31394362778038787,
                                   0,
                                   0,
                                   0.014953872445844223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41880455140761907,
                                   0,
                                   0,
                                   -0.080891607606292354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15088553956654488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75305362104456952,
                                   0,
                                   0,
                                   0,
                                   -0.71151537102327234,
                                   0,
                                   -0.6572782516071094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32051752217208784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076631238250899847,
                                   0.35918348959334101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15913225312804019,
                                   0,
                                   -0.26222181406891809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018101916509198561,
                                   0.23555108759835744,
                                   0.58267422015123105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074694834525376924,
                                   0,
                                   0,
                                   0,
                                   0.12174313243252141,
                                   -0.085896077017574374,
                                   0,
                                   0,
                                   0,
                                   -0.079582013770628401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16124614897834377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022489629703647554,
                                   0,
                                   -0.46134433394439434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56654316786063685,
                                   0,
                                   0,
                                   0,
                                   0.10124602630383533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055098448204876103,
                                   0.31674330388909017,
                                   -0.23709016523819396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25904464538045324,
                                   0,
                                   0,
                                   0,
                                   -0.13373417119978565,
                                   0.091227983952717778,
                                   0,
                                   0,
                                   0,
                                   0.34811827905547005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25473735328367464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48249901834883097,
                                   0,
                                   -0.37797856823767678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052963055816606999,
                                   0,
                                   0,
                                   0,
                                   0.42726917825274097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0033615907538047662,
                                   0.11724948802508292,
                                   0.15879344592718506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1647021570500122,
                                   0,
                                   0,
                                   0,
                                   0.40535844557921585,
                                   0.20418926193052611,
                                   0,
                                   0,
                                   0,
                                   -0.33420747660943712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50914604072414349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4286818400797241,
                                   0,
                                   0.16512898984683083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06995725886326111,
                                   0,
                                   0,
                                   0,
                                   -0.37554803233756828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15635567740311354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35186431437459353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13452704261695153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26138071184351874,
                                   0,
                                   0,
                                   0,
                                   0.77528249930145587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67622996120146417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10520090255283296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78131809536799912,
                                   0,
                                   0,
                                   0.22459496695071046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55482634936672037,
                                   0,
                                   0,
                                   0.39579871755413276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33303194304698397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12026003015467907,
                                   0,
                                   0,
                                   0,
                                   0.26991718166481798,
                                   0,
                                   -0.054204480860027146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010534688234525316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82114485399490822,
                                   -0.39054200963705143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25395020282604469,
                                   0,
                                   0.30396788637633382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15861877090993298,
                                   -0.43648651767571878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18210084505691237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10681384682776277,
                                   0.33970187680978042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37802834969157117,
                                   0,
                                   0,
                                   0,
                                   -0.14774477302168784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47923795968395944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37975509148106723,
                                   0,
                                   0,
                                   -0.29280611676685325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30715538155409389,
                                   0.0016147508329644733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47432683118494556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28515477202716166,
                                   0,
                                   0.16000079830143524,
                                   0,
                                   0,
                                   -0.20833021954699391,
                                   0,
                                   0,
                                   0.12450468896804164,
                                   0.20094812696239084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12053115526051821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051616399091685722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65179185140373486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11216892803134307,
                                   0.024925272502987206,
                                   0.13871808464286145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44420953073554381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062782046904998556,
                                   0,
                                   0,
                                   -0.65379051268956601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72192174858841418,
                                   0,
                                   0,
                                   -0.086053921260894312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38702473552215239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54242027179353935,
                                   0,
                                   0,
                                   0,
                                   0.099616651439579831,
                                   0,
                                   0.0059819122598169273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12260024790287849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18401307894621508,
                                   0.37008802527673218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19749433839404984,
                                   0,
                                   -0.33769625571214879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060376632350441488,
                                   0.11791635216127073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.120987324617457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26725474392953202,
                                   0,
                                   0.10919946236568892,
                                   0,
                                   0,
                                   0.06423885273679511,
                                   0,
                                   0,
                                   -0.14612457807515858,
                                   -0.0042943390129241889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52922835562530379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51235528633930538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091924665480377935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23237885030492905,
                                   0.058241720904582031,
                                   0.50053233137992692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52527916830774801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20569948654960415,
                                   0,
                                   0,
                                   0.34080239176888927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39065006026060495,
                                   0,
                                   0,
                                   -0.39044777437016637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39777450743590381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10261796887093656,
                                   0,
                                   -0.34838953494315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06564640875991111,
                                   0,
                                   0,
                                   0.28809827148802797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31444813812924527,
                                   -0.60324778392334844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18411952659147629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25369401061425029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61629124208411212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021494025313343337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58403000285090079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42470156166703205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29593376930223997,
                                   -0.14823832771059772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55704349191262514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28822146700061813,
                                   0,
                                   -0.055985121430011706,
                                   0,
                                   0,
                                   0.019747212289196434,
                                   0,
                                   0,
                                   0.28200422762685673,
                                   -0.43564825345120645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12216092066443232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086445072518925498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2089985457556269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011393968665488172,
                                   -0.38735126395708575,
                                   0.089399148056651279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021231458401562618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22157033024625217,
                                   0,
                                   0,
                                   0.026233440535505859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60062520498665062,
                                   0,
                                   0,
                                   0.20077844341729903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53094008507358559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72868844514695952,
                                   0,
                                   -0.57399178276056417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55852883542995557,
                                   0,
                                   0,
                                   -0.27435721222936565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83859088737438403,
                                   -0.20464176488546867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14270778256713285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16052694386753064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66928533297022275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94585511425020552,
                                   0,
                                   0,
                                   -0.72100761507911393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43672540613289962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38190280374364632,
                                   0,
                                   -0.08519708264709204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23328830608010731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47882288855828981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14124890332695331,
                                   -0.50452397096502122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28182605015683615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19090374648413136,
                                   0,
                                   0.37729938845624339,
                                   0,
                                   0,
                                   -0.30877695953369622,
                                   0,
                                   0,
                                   0.10139435103624717,
                                   0.47947886616865693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00084500992268136932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022356423070219275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21242157087650923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10334403908388698,
                                   -0.020665128470395859,
                                   0.27390659877483031,
                                   0,
                                   -0.28015664693350273,
                                   -0.059903031428642402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18689987982080447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1815267593556672,
                                   0,
                                   0.16715918077647673,
                                   0,
                                   0,
                                   -0.050728142337812476,
                                   0,
                                   0,
                                   0.44363104972875872,
                                   0.071634197033829741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027500769958307258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46561775804193889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34289926272015847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18089240552553007,
                                   0.14283205028850887,
                                   -0.47887962752828572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24763239724883593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22024068552507076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57079747712328321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20704683662805773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6559096893479508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30212011393438465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14312981259366883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47183360354013998,
                                   0,
                                   0,
                                   0.47606721092450865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70987802117630205,
                                   0,
                                   0,
                                   -0.51901762505108806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049794744485995551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045048449460305666,
                                   0,
                                   0,
                                   0,
                                   0.0026882837710290319,
                                   0,
                                   -0.51958980990985359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74850460238151528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12203292196328612,
                                   -0.052480454264029003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018852787017306555,
                                   0,
                                   0.30034448892344046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5309319466622815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073017934566173337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11929199875115168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068920183862724846,
                                   -0.77753242594035887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27640301349927177,
                                   0,
                                   0,
                                   0.060185863888450319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096028324275692301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32512355698655265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1396531773854286,
                                   0,
                                   0,
                                   0.14523453443207351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84854068712351982,
                                   0.548755420216264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41270760900016823,
                                   0,
                                   0,
                                   0.30983434163727303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52171413796984634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71484822819491867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79634466458637587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67682317817804694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47295445344730724,
                                   0,
                                   0,
                                   0,
                                   -0.41156323098784026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39841694494886548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1216253321964719,
                                   -0.029976612845396725,
                                   -0.14093912570401859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39657858222782572,
                                   0,
                                   0,
                                   0,
                                   -0.53692757184248507,
                                   -0.36895365437438882,
                                   0,
                                   0,
                                   0,
                                   -0.26382615818199184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48055904532823918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072959526058250096,
                                   0,
                                   0.017907719439904116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27661824991132422,
                                   0,
                                   0,
                                   0,
                                   0.0070415128662119665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30707281547522713,
                                   0.032866126152409803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46661017770853697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2418742898312195,
                                   -0.17826455376071884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18080341003205266,
                                   0,
                                   0,
                                   0,
                                   -0.40730449958469661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24297772160879519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00047814845215708431,
                                   0,
                                   0,
                                   -0.58223224946106278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3657761378704234,
                                   -0.43445171983351361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23804386898203611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10400669548911254,
                                   -0.70610289708276885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20904574706289733,
                                   0,
                                   0,
                                   0,
                                   -0.023423361744246363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17145522151367804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10985040553626504,
                                   0,
                                   0,
                                   0.16025966348973919,
                                   0,
                                   0,
                                   0,
                                   -0.30612772398054744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052636898188871684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71643645246773069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99668674581243222,
                                   0,
                                   0,
                                   0,
                                   -0.67629470350607002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48983253241751684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1297581823836968,
                                   0.33790782181183482,
                                   -0.52052461063003497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58242721389115282,
                                   0,
                                   0,
                                   0,
                                   0.31921907578390013,
                                   0.18821463188058574,
                                   0,
                                   0,
                                   0,
                                   -0.039298207849206512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23654598948775102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087873987926937694,
                                   0,
                                   -0.14467798390762049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11347166811507642,
                                   0,
                                   0,
                                   0,
                                   -0.14986824807995411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18351357177658797,
                                   -0.25374635188926131,
                                   0.076986374300589897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14679734119597224,
                                   0,
                                   0,
                                   0,
                                   -0.12386847788213846,
                                   0.11635990769409364,
                                   0,
                                   0,
                                   0,
                                   -0.069370860519862854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12541510695221494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052709963319689662,
                                   0,
                                   -0.69987298661124719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41799782639830263,
                                   0,
                                   0,
                                   0,
                                   -0.39712993201091423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23743692778941486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072945130458311844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16170205671248511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54637103149938515,
                                   0.099052071568879976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13236979178284733,
                                   0,
                                   0,
                                   0.69598363579670897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31922963224310374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69052212138678815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68748369318586899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17855954896514714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020814610758346189,
                                   0,
                                   0,
                                   -0.21197936184045074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0626821066676895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13840112240324964,
                                   0,
                                   0.25588661150428771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4027262743470732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12456207042276463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79290395215608889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63926687450147968,
                                   0,
                                   0,
                                   -0.20642876749206887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029387175114651776,
                                   -0.064656222362845739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10732531737874432,
                                   0,
                                   0,
                                   0.90216573556211599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21933967063557977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2882153618611214,
                                   0.074669126514723252,
                                   -0.3406684167769809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43651408355324484,
                                   0,
                                   0,
                                   0,
                                   0.24565451861627202,
                                   -0.36165694774511248,
                                   0,
                                   0,
                                   0,
                                   -0.47454666413590096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02144685554460948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29134120703587785,
                                   0,
                                   -0.28942999155797766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069289225632997456,
                                   0,
                                   0,
                                   0,
                                   0.12045788168387861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044263126913262243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33535415168679178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2123696847450659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44493993352836958,
                                   0,
                                   0,
                                   -0.006022929061858676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24224771739366899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1001091933555458,
                                   0,
                                   0.19415070480138552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25957267677352425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0504604468931769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27956867815426051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26008455960857924,
                                   0,
                                   0,
                                   0.76461018292034955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33723395037522563,
                                   -0.57792611291906049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51148266959585698,
                                   0,
                                   0,
                                   0.15384268797961073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12503312469785696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32537739711213143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098629848642563953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027691493857946552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38250184512008445,
                                   -0.29078413493706018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18669084763880681,
                                   0,
                                   0,
                                   -0.41475945720044677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66775214637807412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058053521275262011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49241877720452243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73571565748704359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34874230497481173,
                                   -0.12533225496060676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0726294182181111,
                                   0,
                                   0,
                                   0.087389265525303156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25026929959535066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086501035478856847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45556213683317026,
                                   0,
                                   0,
                                   0.13585223012841577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11708474542809502,
                                   0,
                                   0,
                                   -0.6771553944218931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68904921296453558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45137105929292831,
                                   0,
                                   0,
                                   0,
                                   0.021830456083479596,
                                   0,
                                   0.47582135680257853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019369461589570369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080133626733746591,
                                   0.045238337995872374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78878083334993943,
                                   0,
                                   0.69236913828921387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59250011897482202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15864112425640137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66909096901618581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17004450968529289,
                                   0,
                                   0,
                                   -0.43448703217813811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46148969113525856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055977407094667697,
                                   0,
                                   0.64898876805029537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55623390261597994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30816843428181517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34127227010014305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051963893614821927,
                                   0,
                                   0,
                                   -0.10283327370737791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1609114940052917,
                                   0,
                                   0,
                                   0.7155176096447291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2936874696318687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28385252671204181,
                                   0,
                                   0.25316892246669942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6577386489226108,
                                   0,
                                   0,
                                   0.25678632292625447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45144018999008867,
                                   0.53468357583720727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50284694329756952,
                                   -0.53521644648176492,
                                   0.012264629278592846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075463369548362719,
                                   0,
                                   0,
                                   0,
                                   0.30186206549501277,
                                   -0.31956888868653521,
                                   0,
                                   0,
                                   0,
                                   0.38851891042134085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.003202582547862892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3044073472647118,
                                   0,
                                   -0.095767264010979208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071107447614560643,
                                   0,
                                   0,
                                   0,
                                   -0.061233269016275287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0173858129633178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10156923156373664,
                                   0,
                                   0,
                                   0.11743356506987065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022876629607322518,
                                   0,
                                   0,
                                   -0.39231446168598993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49896136484930287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26426919743980304,
                                   0,
                                   0,
                                   0,
                                   0.58829635548435499,
                                   0,
                                   0.34503310258062131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18941896115816695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10939193287327825,
                                   -0.08117164574093097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25533122109739015,
                                   0,
                                   -0.83674111713562882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35723870459552126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4709195538812237,
                                   0,
                                   0,
                                   0.31455125400890388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44818047746147288,
                                   0,
                                   0,
                                   -0.0048301154868135437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27468911820237996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48799407282475854,
                                   0,
                                   0.66122176556370704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56957357462016545,
                                   0,
                                   0,
                                   -0.037348866411230773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1601874582574319,
                                   0.264035504059208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12330314868421907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0775677758277338,
                                   0,
                                   0,
                                   -0.062942505152377246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12191291797969722,
                                   0,
                                   0,
                                   0.41095288805270214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11686387540361123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52847853827389013,
                                   0,
                                   0,
                                   0,
                                   -0.31347264208554904,
                                   0,
                                   0.18389092087485875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019401114352091964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22155289033871811,
                                   -0.3979663239667024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87597685868822539,
                                   0,
                                   0.3940927310041793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9895421834793533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10480839691385456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28849711461601235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69118131695160112,
                                   0,
                                   0,
                                   -0.12881842929009893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5574141476789799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69477126420066104,
                                   0,
                                   -0.34647577948302133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34392281490037641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040298095410351537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31804725203739592,
                                   0.40711321568048775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021169223192226298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12428492098311006,
                                   0,
                                   0.26444576389043889,
                                   0,
                                   0,
                                   -0.40322193304225762,
                                   0,
                                   0,
                                   -0.028853458923333672,
                                   0.014756979771496377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28407932198804869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20023420839134973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079020528381719746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12274354476596046,
                                   -0.5798673555790661,
                                   -0.072725143387009944,
                                   0,
                                   0,
                                   0,
                                   0.29453013800080496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76170491494196935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91950149605832554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47053856476553646,
                                   0,
                                   0,
                                   0.05564648336789705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33962112223177882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41862200329542659,
                                   0,
                                   -0.20984363537857004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78510028683457567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1308817647503413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0046264929760794389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97025487707044533,
                                   0,
                                   0,
                                   -0.46722344125299137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84022097262129058,
                                   0,
                                   0,
                                   0.19073112469571796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20101633923019774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65271826288964807,
                                   0,
                                   -0.46491927810683187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19898674836092881,
                                   0,
                                   0,
                                   -0.17129337515587725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037969084379412155,
                                   -0.061482025975409443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57944238192989173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20915886298304179,
                                   0,
                                   0,
                                   -0.019933784091722168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70262466723871908,
                                   0.27555670777019586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052300370313076244,
                                   0,
                                   0,
                                   1.0874195576489221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11000365593536154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34146829308313464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17927599290364155,
                                   0,
                                   0,
                                   0.85272473721260333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42754505993185843,
                                   0.65943803069992879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20713977411786869,
                                   0,
                                   0,
                                   -0.32141200771665257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19691493231403634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20098698662394221,
                                   0.39464167001572004,
                                   0.35578378234515395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32813786601086281,
                                   0,
                                   0,
                                   0,
                                   0.21627703508327301,
                                   -0.24887284320261516,
                                   0,
                                   0,
                                   0,
                                   0.12720087985470516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2611709690575017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17881471661587134,
                                   0,
                                   0.088651313480435534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54309427499654461,
                                   0,
                                   0,
                                   0,
                                   0.20424663499892545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32797347773884888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0037751426658047399,
                                   0,
                                   0,
                                   -0.27157105150790245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26873987192121163,
                                   0,
                                   0,
                                   -0.138575861435143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39252763309903516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98972999851732624,
                                   0,
                                   0,
                                   0,
                                   -0.44598101415988378,
                                   0,
                                   -0.044133560041582441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15339879067224882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46565962498260804,
                                   0.27835586631358367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60359288217447393,
                                   0,
                                   -0.059803302861380137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60811079360157172,
                                   -0.10300693698002308,
                                   -0.19027935657842404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059300473746214374,
                                   0,
                                   0,
                                   0,
                                   0.39150317550752828,
                                   -0.27864767198900869,
                                   0,
                                   0,
                                   0,
                                   0.29524865207718703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34172830538629667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30163712423983252,
                                   0,
                                   -0.020332196149316806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23086960922413682,
                                   0,
                                   0,
                                   0,
                                   0.017310740499490163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44544090897449878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62843623600588638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012940373044352527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17223330405005771,
                                   0,
                                   0,
                                   -0.90985323494056158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26063853188791947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028917453707668211,
                                   0,
                                   0.7181848164422765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29583343197635725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18791743056959309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14619036924695389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53864932390421871,
                                   0,
                                   0,
                                   -0.97355345604727028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053814190268351436,
                                   0,
                                   0,
                                   -0.5656977541150634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071006393585330257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38122401611505208,
                                   0,
                                   -0.60835653201350592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10115388612965326,
                                   0,
                                   0,
                                   0.3129799238536784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1870121628624869,
                                   0.92347177650026679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13912916275251408,
                                   -0.28413564939906188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15908753526240552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33298230425117009,
                                   0.013035224779763516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24722831134224943,
                                   0,
                                   0,
                                   0,
                                   0.27357065069561237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72630708464577487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26644653908289656,
                                   0,
                                   0,
                                   -0.17051555547792083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029638731519696149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54435778951872782,
                                   0,
                                   0,
                                   -0.15347420752223326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16653232918071079,
                                   0,
                                   0,
                                   -0.20891412801264594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34928709426703175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43538049154995495,
                                   0,
                                   0.16409114549140419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27013224574210082,
                                   0,
                                   0,
                                   -0.9615488379844741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27930261343926843,
                                   -0.026683498930408125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090674368708558856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67240597329206997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21600562533735201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59029722164531762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29840969942546058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23556480460733834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19024510372708364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43038112948877344,
                                   0,
                                   0,
                                   -0.27119966358320557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3055951331259274,
                                   -0.97887370157844988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0976114363220206,
                                   0,
                                   0,
                                   -0.37494878451088748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6412990288226369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60907362903522255,
                                   0.14973804768041546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11134721847650314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22205469010620188,
                                   0.20239166096558139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026304904704852666,
                                   0,
                                   0,
                                   0,
                                   -0.070740649149494905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15041203959978391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56767430599825852,
                                   0,
                                   0,
                                   0.39161827306818064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28807102878538149,
                                   0.37068633006464236,
                                   -0.056089860772321476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.264378119053017,
                                   0,
                                   0,
                                   0,
                                   -0.20399128511424666,
                                   -0.017694123579715577,
                                   0,
                                   0,
                                   0,
                                   0.45171531461085629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12383301492280169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30372112225355946,
                                   0,
                                   -0.0053403243525623791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15515372713696063,
                                   0,
                                   0,
                                   0,
                                   -0.57350700004442445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015289536905960854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021995162567725476,
                                   0,
                                   0,
                                   0.071858158629682312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51515662373397098,
                                   0.76546156913208829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45201965234774322,
                                   0,
                                   0,
                                   0.044181086248637258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98765000734734942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29753291823149991,
                                   -0.36334066587799574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18664451260407663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23405662227684376,
                                   0,
                                   0.11614471813633469,
                                   0,
                                   0,
                                   0.26079006173098224,
                                   0,
                                   0,
                                   -0.32338011169854297,
                                   0.049357073304584581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3107688563736547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35678141666665891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01818209439943666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16944436530321325,
                                   -0.49189741901231798,
                                   -0.080323494097082906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22091077524041602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16992329551540619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25013178742761033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081578100814113735,
                                   0.38415434258530734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83955452120357832,
                                   0,
                                   0,
                                   -0.0057403597902964121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025383078588950718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31971155135413626,
                                   -0.23490734888347814,
                                   -0.013683635243600556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069413267451859662,
                                   0,
                                   0,
                                   0,
                                   0.065674122406273516,
                                   0.6202415398003287,
                                   0,
                                   0,
                                   0,
                                   0.035843914948534283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38270820443521281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41754977393978465,
                                   0,
                                   -0.068624775814957267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15821493021177196,
                                   0,
                                   0,
                                   0,
                                   0.31103933200823825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62249883373491244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3732658113245184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48687343737948979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4714490569325982,
                                   0,
                                   0,
                                   0,
                                   -0.47891059231866728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11626036179222671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15353104257839512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7550397557919365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51952210255633913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0052931824389151807,
                                   0.1700105864965617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27571992333305173,
                                   0,
                                   0,
                                   0.10784164057128201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14091507452631272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35085463767748998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19119952352210121,
                                   0,
                                   0,
                                   0.34381158449911386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42731745961180334,
                                   0,
                                   0,
                                   -0.26267759556119463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62131946831327989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16076353350358338,
                                   0,
                                   0,
                                   0,
                                   0.34140724872644129,
                                   0,
                                   -0.044200892863881416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87163513922730684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45911896610155351,
                                   0.73491024721549036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23685621005335578,
                                   0,
                                   -0.067933158559916829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38719698029820804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35726047613409689,
                                   0,
                                   0,
                                   -0.80703532265170452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45381790187159743,
                                   0,
                                   0,
                                   -0.45117821231215111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43374743299738722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.006125881229349834,
                                   0,
                                   0,
                                   0,
                                   -0.74646197315294516,
                                   0,
                                   0.26386275527639536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052033282995610573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16789960574583912,
                                   -0.77884917482814908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51687893772861437,
                                   0,
                                   0.12960819687955499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25721260581881744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0028514634222147478,
                                   0,
                                   0,
                                   0.11641063079786859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67646189574083815,
                                   0,
                                   0,
                                   0.19660844470319122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41379774894139809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0400473479604797,
                                   0,
                                   0.40395474566604489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60017066304220967,
                                   0,
                                   0,
                                   -0.38341357770328455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31092666280848741,
                                   0.20761228863719269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33072910501544134,
                                   -0.026680868013790437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65253208680960761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017492887894001691,
                                   -0.32132039773270737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11771825585301923,
                                   0,
                                   0,
                                   0,
                                   0.20366009063118273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13022599706757432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45005301723654267,
                                   0,
                                   0,
                                   0.29276939393095525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52666783840297382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18227975508701943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37725683287380285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11133450054147498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32083713424167387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65706964867367912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0066862366599734005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23991494314197978,
                                   0,
                                   0,
                                   -1.1337649251206523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33094481777251805,
                                   0,
                                   0,
                                   0.23470583760207131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73712287093459072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2364386616304531,
                                   0,
                                   0.13603573508606814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086974087659078908,
                                   0,
                                   0,
                                   -0.088245378243896139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057333763480855976,
                                   -0.53953366891624732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25768499313827581,
                                   -0.056705246079814434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16817311142263408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2206051488533885,
                                   0,
                                   -0.21996657758959634,
                                   0,
                                   0,
                                   -0.65540995380315392,
                                   0,
                                   0,
                                   -0.26987289740014103,
                                   -0.22693238191679599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2066063645869268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15479659863215783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023046603294713419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27592933288576099,
                                   0.32772245515134746,
                                   0.020943152611482135,
                                   0,
                                   0,
                                   0,
                                   -0.71676821646521349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048807415328992194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70642603327203757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60472408867448002,
                                   0,
                                   0,
                                   -0.47210878359955055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27917041663644232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37397469810740541,
                                   0,
                                   -0.97271115444850109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019892133334508587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071160050381700979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28597256683887651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021265862458508589,
                                   0,
                                   0,
                                   -0.32049644243053038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30751098099094915,
                                   0,
                                   0,
                                   -0.41854053788923784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42203616296733287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030167410461321226,
                                   0,
                                   0,
                                   0,
                                   0.4086406626121496,
                                   0,
                                   -0.60574915976377819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030269442777551059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1699482553502879,
                                   -0.47194432050792146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54857652874402607,
                                   0,
                                   -0.63547984566847038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49281245077988317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3711907266966038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20550008461624569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42191400919631233,
                                   -0.23338718552868168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19861838723412098,
                                   0,
                                   0,
                                   0.072451853263427068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5476709812283217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30064528547403557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2936420227248151,
                                   0,
                                   0,
                                   -0.19010697141558411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4781693432045081,
                                   0,
                                   0,
                                   0.60214480855847996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6827705903404282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10028488911520413,
                                   0,
                                   0,
                                   0,
                                   0.35088872977314917,
                                   0,
                                   -0.62577225457130692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43799655661905962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62981331306174171,
                                   -0.20750933371052235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0080248543125691768,
                                   0,
                                   0.17166803417675128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44338884087088604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1984840451085188,
                                   0,
                                   0,
                                   -0.36549803127833108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1059192503715078,
                                   0,
                                   0,
                                   -0.97575727810889545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35576356396379993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30005711681017166,
                                   0,
                                   0.90082535445754275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61248757974796342,
                                   0,
                                   0,
                                   0.13499176758915693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09434166735674214,
                                   0.083485666539413583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6340542140594877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11199974933434492,
                                   0,
                                   0,
                                   0.11789911293819078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2310478633631588,
                                   0,
                                   0,
                                   -0.61317138363758406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61040117860749643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23676933892502464,
                                   0,
                                   0.40379614739405761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44260486851308828,
                                   0,
                                   0,
                                   0.45123764120943588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1911501093401525,
                                   -0.17325418182341507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24985722136834601,
                                   -0.54780476556822499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018260115211418723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36912696869582062,
                                   0.031806143929709457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42442266634585818,
                                   0,
                                   0,
                                   0,
                                   -0.40873193627421023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28296696707536395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03051750228274417,
                                   0,
                                   0,
                                   0.26773776030485813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7628749840995398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01845464154244833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28199865617754355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25308466727783063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1825449434840139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4906968896905855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49987909685135479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0213475806001633,
                                   0,
                                   0,
                                   0.27536523800814788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16326174807172666,
                                   -0.37467209270668012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028521131851985848,
                                   0,
                                   0,
                                   0.36719319006228313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092971652839892657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39609022604318167,
                                   -0.40697731740951448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30173470084521681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15761779742169851,
                                   0.19870701647448233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49522215988563717,
                                   0,
                                   0,
                                   0,
                                   0.44883554743900983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15083803827895989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0093894484255469084,
                                   0,
                                   0,
                                   -0.22928520661514609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14122851136033793,
                                   -0.31234295775771975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22453903968955283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13260617238296327,
                                   0,
                                   0.12108196680700598,
                                   0,
                                   0,
                                   0.10081068488344029,
                                   0,
                                   0,
                                   -0.47533325840074647,
                                   0.065499623442282495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25901103117549579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43845374623539507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35808575336711579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26589421847634082,
                                   0.15409279208951132,
                                   -0.2782813869410502,
                                   0,
                                   -0.010657861799243662,
                                   -0.2686828752415793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36838240374488002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16940620465567446,
                                   0,
                                   0.45011236508364927,
                                   0,
                                   0,
                                   -0.17359445372256033,
                                   0,
                                   0,
                                   0.025634481835750775,
                                   -0.63559231400951688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0053213932269128364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031244781321129386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13166490001258116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31254289724213508,
                                   0.063031393041777434,
                                   0.076972426955390735,
                                   0,
                                   -0.52799029446618317,
                                   -0.1197518195186266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017434586757117902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34246560241088309,
                                   0,
                                   -0.19718312641549926,
                                   0,
                                   0,
                                   0.19029875642593971,
                                   0,
                                   0,
                                   0.16311016191540423,
                                   -0.056522974970645942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15201842183729949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2148689992413014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33593307319704852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048888880756844999,
                                   0.035059384537036636,
                                   0.54649421147470534,
                                   -0.041324785356947003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28077904309955981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40642556623789527,
                                   0,
                                   0,
                                   0,
                                   0.35760738361676603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40820940156626623,
                                   0.48237389939298969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93631375161847163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037757238556035605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18685115016616682,
                                   0,
                                   0,
                                   0.57383942257555631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37187397457472227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46366411096606575,
                                   0.47561744922654958,
                                   0,
                                   0,
                                   0,
                                   0.34005326592290175,
                                   0,
                                   -0.061007665336311058,
                                   0,
                                   -0.43188878807777287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075634898365027375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17420765246633574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023256500428317894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27931610806515472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048075081578023121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22752559113984866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30792583597530737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48066240256720899,
                                   0.019530689790741393,
                                   0,
                                   0,
                                   0,
                                   0.10992913129862192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35597717522512923,
                                   0,
                                   0,
                                   0,
                                   -0.29262772895723288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12636558049875549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19044948441142692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16802963606260599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5610493764140162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15773147803470194,
                                   -0.35619988484184512,
                                   -0.42477423804399689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46360354037353335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45910485466905043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67701921163092127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.341056618535744,
                                   -0.70178191786414423,
                                   0.54458346384809753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14275148836047927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17418258514400237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30068321376905416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40444196986845837,
                                   -0.020507361082107489,
                                   0.82188003281913558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11310053001752916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3365143634514176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1959727674881534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21335493920225029,
                                   -0.4158898428767509,
                                   -0.94371800332173983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44840668837489411,
                                   0,
                                   0,
                                   0,
                                   -0.43265029511030556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056369704219950925,
                                   0,
                                   0,
                                   0,
                                   0.33857831462733778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033733870204906549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069148573278594,
                                   0,
                                   0,
                                   0.18929119189268637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55464375220800899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54309377816678783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35786644782688992,
                                   -0.67670688148495572,
                                   0.23320235510755399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55384085465196098,
                                   0,
                                   0,
                                   0,
                                   -0.21984616674590082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17976395355191846,
                                   0,
                                   0,
                                   0,
                                   0.50273431120822121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89720206164759619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10086904856387957,
                                   0,
                                   0,
                                   0.092228414311648216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060172039212533647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68164562920703786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38613778127215859,
                                   0.56982644512348846,
                                   -0.3527890792957647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57834127692164394,
                                   0,
                                   0,
                                   0,
                                   -0.61883121441141442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22609123264788203,
                                   0,
                                   0,
                                   0,
                                   1.0218944868392374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19686171595905438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1967339350566813,
                                   0,
                                   0,
                                   0.073468662883108465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64455446602145816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59473196586522159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55805443317649939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063976500851712401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46834468094701831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38732913830987215,
                                   0.31304301477962448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2509231549410974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38668842821267685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068009970549135726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34950059458563421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027659227212239304,
                                   -0.052041869024850147,
                                   0,
                                   0,
                                   0,
                                   0.10308535207640368,
                                   0,
                                   -0.19093820246938426,
                                   0,
                                   0.25017698365124286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56707468633056579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28706129388745083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48468214846717406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35469531137431382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10076079095186193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13757642445968707,
                                   0.59259734433481337,
                                   0,
                                   0,
                                   0,
                                   0.24483482013562194,
                                   0,
                                   0.11109092462800638,
                                   0,
                                   0.62836391506559919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21848917552765695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1530427525228483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23556753584765033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16115277725501106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36610860502030701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036022355118796402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3027580196423359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20505407880657872,
                                   0.22344412205665443,
                                   0,
                                   0,
                                   0,
                                   -0.43412267685913519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16218321484028314,
                                   0,
                                   0,
                                   0,
                                   -0.36746911459282144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34900045388116008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18465562038348252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16231989735967961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38598419908193449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63730911559748349,
                                   -0.45144464560744391,
                                   -0.85983706961947615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2512565375552327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017307111190765001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2716866487915235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23151783248600186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77209432840777359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0894060212749994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29540976614897413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26665551392940284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42884065991478254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19248366547209872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2434237166738325,
                                   -0.15202372041133513,
                                   0,
                                   0,
                                   0,
                                   0.27050452191367019,
                                   0,
                                   -0.26653638692637865,
                                   0,
                                   0.33797059064574775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47483895670534659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2438270833927072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20392882454114097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54372291855956179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13821340210474914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52669800662906308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27881577867386848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81508870356107077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2323450955131191,
                                   0,
                                   0,
                                   0,
                                   0.15475630679621277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73003720578952069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46253577814010982,
                                   0,
                                   0,
                                   0,
                                   0.11815331147371222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15725069120474472,
                                   0.42007432445939463,
                                   0,
                                   0,
                                   0,
                                   -0.029777770971000386,
                                   0,
                                   -0.23131101446597294,
                                   0,
                                   -0.0014797698289771011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50771290443445349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077154712080846136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65828780629312955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18272330835886946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053364699036133091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075298314698958646,
                                   0,
                                   -0.21942700516678673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36339111583337047,
                                   0.5638618429418949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61030865796427514,
                                   0,
                                   0,
                                   0.4946955935542271,
                                   -0.35811692537673517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4542622115306621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12128904458304995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45941289053531414,
                                   0,
                                   0,
                                   0,
                                   0.30673133838419009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0041832069418548841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3644646363045842,
                                   0,
                                   0.56298693631970442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45121731906159029,
                                   0.200747667969954,
                                   0,
                                   0,
                                   0,
                                   -0.17232032541773679,
                                   0,
                                   -0.061767280669852001,
                                   0,
                                   -0.21502887459414191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22690907329117127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50101779628494203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095708647320204093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21848432663754197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27511187804012127,
                                   0,
                                   0,
                                   0,
                                   0.41484258836624549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089112194942498252,
                                   0,
                                   0,
                                   0,
                                   0.22343426591129728,
                                   -0.15965707237668875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48105124573179775,
                                   0,
                                   0,
                                   -0.36633783978343143,
                                   0,
                                   0,
                                   -0.12163232285579362,
                                   0,
                                   0.14376475386295501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065103012694456841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35553940654180261,
                                   -0.22159824610602055,
                                   0,
                                   0,
                                   0,
                                   0.22306467283956288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1956479059483972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2797332119551188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1721332251833394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058186357637430325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62263379446076716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43911886413809809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5551897079878213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19631703001422229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29862432922457494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64186050171912179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55229462814920327,
                                   -0.12303935029171552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040348886055402294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19161992378943846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31903599209616984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14036778526372232,
                                   0.4234693700192973,
                                   0.49146263475500729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93020494605200055,
                                   0,
                                   0,
                                   0,
                                   0.35942573927400456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20137864219073892,
                                   0,
                                   0,
                                   0,
                                   0.21025215166811526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61841994692420588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11885321224271425,
                                   0,
                                   0,
                                   -0.52881350825496787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35093288031968256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13617471554236152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21686017864425067,
                                   0,
                                   0,
                                   0,
                                   -0.071463792248278479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14801734350161586,
                                   0,
                                   0,
                                   0,
                                   0.279210878762713,
                                   -0.49526540277606951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093272356174810889,
                                   0,
                                   0,
                                   0.17332310797311243,
                                   0,
                                   0,
                                   -0.42155201590246899,
                                   0,
                                   -0.30052944115683178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31226432382015784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17701234462103582,
                                   0.010712777676426474,
                                   0,
                                   0,
                                   0,
                                   -0.39603319804756998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10072142966843216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27639377771504459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59536927234693782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46733024946055085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13537324868026115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92312992701781182,
                                   0,
                                   0,
                                   0,
                                   0.48221957171203989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0599646353307866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032241281568874056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33934491795257038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28105398509958579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77909049510013628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034480365758829373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33025014605007108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29768713437951461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35059267736105265,
                                   -0.19716951269732952,
                                   -0.85987016117517578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29113079034385592,
                                   0,
                                   0,
                                   0,
                                   0.1757942310813479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24958312823057768,
                                   0,
                                   0,
                                   0,
                                   0.17223092366001672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010253866472332333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53118674207760364,
                                   0,
                                   0,
                                   -0.99482197386187343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41117660594731453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47774331369875417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085248158642151795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89791438657329692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5610137482211639,
                                   0,
                                   0,
                                   0,
                                   -0.20247009005598979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49831230283983358,
                                   -1.0624670702184058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10555086217394009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39119825042353396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013973652988303796,
                                   0,
                                   0,
                                   0.78238010860055607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4050025861879607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14832469944673968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13850725897527036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16908478606819255,
                                   0.045751733435542619,
                                   0,
                                   0,
                                   0,
                                   0.33743173332580734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39823667293148435,
                                   0,
                                   0,
                                   0,
                                   -0.36167670641951694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28868265433621099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05894286406511285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4273145661744493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30237924042706743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25759524773084708,
                                   0,
                                   0,
                                   0,
                                   -0.21611631051099348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4560014324400003,
                                   0,
                                   0,
                                   0,
                                   0.10614915050010219,
                                   0.12538059301648571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13485878365730436,
                                   0,
                                   0,
                                   -0.22519741477681654,
                                   0,
                                   0,
                                   -0.55794219199435657,
                                   0,
                                   0.25952141098042819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29681520856659399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13974852454666389,
                                   -0.090113049706833953,
                                   0,
                                   0,
                                   0,
                                   0.26883634788542704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12821585586633885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91577929562982652,
                                   0.47362145316571808,
                                   -0.70804053206423312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54983182956590282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20228143654469072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3845928693626568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67331139105122029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024229582321104514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045061243836697719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4308649628846421,
                                   0.063746025117609559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024367060804021672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58332186296626864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11605111330168411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81118743705086094,
                                   0.55654410515552244,
                                   0.079015288487224833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38234148132698353,
                                   0,
                                   0,
                                   0,
                                   0.39067034691787378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77157770150450922,
                                   0,
                                   0,
                                   0,
                                   0.23802347564529661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10599187705254776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66802156327147322,
                                   0,
                                   0,
                                   -0.19423574349188971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045093112571822233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62472979038710008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054867262204692506,
                                   0,
                                   0,
                                   0,
                                   0.3339454345449302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41705959056035025,
                                   0,
                                   0,
                                   0,
                                   -0.22328029173620925,
                                   0.27560485065521745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22003279045151503,
                                   0,
                                   0,
                                   -0.15850130920872327,
                                   0,
                                   0,
                                   0.043100089075203553,
                                   0,
                                   -0.071063314386225512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20057981716589413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16843804929743697,
                                   0.00013985928162342162,
                                   0,
                                   0,
                                   0,
                                   -0.6518372197822061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10853146750988622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21982004899906321,
                                   0,
                                   0,
                                   0,
                                   -0.077242970461931099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073796174386155711,
                                   0,
                                   0,
                                   0,
                                   -0.0063683949062357248,
                                   0.19639852874024463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04229830740848016,
                                   0,
                                   0,
                                   -0.037042997295183192,
                                   0,
                                   0,
                                   -0.10534915725782824,
                                   0,
                                   0.51975290941912344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45300250495690275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2160009495317527,
                                   0.56390562901388308,
                                   0,
                                   0,
                                   0,
                                   -0.12267819270371912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17984386655087209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46728573743358603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086085591990243501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067670888968496518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12518572990540427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46847385795975893,
                                   0,
                                   0,
                                   0,
                                   -0.2695183712873464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41674362013943145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93192272985238833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81784846655570198,
                                   -0.0020577774811964405,
                                   -0.18576997681085464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048748852012923366,
                                   0,
                                   0,
                                   0,
                                   -0.026214512730495423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047375368431181786,
                                   0,
                                   0,
                                   0,
                                   -0.64347861899183267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.995470815620074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062537820788755305,
                                   0,
                                   0,
                                   0.043874801833483169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074809823500460726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095910051878054778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34107938386521869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47986066374634495,
                                   0,
                                   -0.0016765270656913245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20034691954560715,
                                   0.51157535477699057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29283921403743901,
                                   0,
                                   0,
                                   -0.25981525797198196,
                                   -0.26721344134660957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52773582191860169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7904618552834628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036240562466957962,
                                   0,
                                   0,
                                   0,
                                   0.1397888781317711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2918982753296771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17231591720000039,
                                   -0.54303539309328464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10740691271150446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59486034317255965,
                                   0,
                                   0,
                                   0,
                                   -0.63959644738398225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66405138017093746,
                                   0.23817001186470893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12620176388492579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11286421844909372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98187132457926141,
                                   0,
                                   0,
                                   0.26098827266949076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20406625006561133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072906239831974751,
                                   0,
                                   -0.14866174871006774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084443186886778265,
                                   -0.64915013404504629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19701418911116791,
                                   0,
                                   0,
                                   0.53263980471704309,
                                   -0.81467463959094633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023659162580669538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4199066931084422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49016349205892207,
                                   0,
                                   0,
                                   0,
                                   -0.38534939603157853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40491145980895038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24970136035686361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056069952452711014,
                                   0,
                                   0,
                                   0,
                                   -0.35974619148300435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2177794245779518,
                                   0,
                                   0,
                                   0,
                                   0.11534081564111497,
                                   -0.17927423171269719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096273137131737491,
                                   0,
                                   0,
                                   0.002531879915417961,
                                   0,
                                   0,
                                   0.32214464360138806,
                                   0,
                                   0.22972669633474299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42707096906890379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52366794276755202,
                                   0.068888561466444218,
                                   0,
                                   0,
                                   0,
                                   -0.19572860808495368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33025551302030209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19374481654362091,
                                   0.31477904359358733,
                                   -0.8536327083017341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1006927130218403,
                                   0,
                                   0,
                                   0,
                                   1.0052417166662109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45667337319397994,
                                   0,
                                   0,
                                   0,
                                   -0.14621464199483958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012831308447789416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073588393201957272,
                                   0,
                                   0,
                                   0.28947688922562775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54447866335757034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18401638927917971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27917977704326169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3733099861447281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56881062354257372,
                                   0,
                                   0,
                                   0,
                                   0.25069211295210098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60865193767191883,
                                   -0.71827917906463445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61478543128636065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48113360479049283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77676153579337581,
                                   0,
                                   0,
                                   -0.40302517862386433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24589405174325699,
                                   0,
                                   0,
                                   0,
                                   0.17501415783136445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47934195827297288,
                                   0,
                                   0,
                                   0,
                                   0.23875105962127638,
                                   0.37022353720682344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021276944543764942,
                                   0,
                                   0,
                                   0.3677632025896333,
                                   0,
                                   0,
                                   0.00064770489763340405,
                                   0,
                                   -0.37465147584877356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09953395931155494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26069597187693988,
                                   0.052844886613106046,
                                   0,
                                   0,
                                   0,
                                   0.30750032709151487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18380655457746717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26754706180342669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31825799496778034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32659895864563671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40766572351028374,
                                   -0.15156286916013084,
                                   0,
                                   0,
                                   0,
                                   -0.25371013446524282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13729746944616394,
                                   0,
                                   0,
                                   0,
                                   0.42804362333409052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028553923411041175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38193850503835181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34227485740722235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031869986318072099,
                                   0,
                                   0,
                                   0,
                                   -0.3006263273584554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28528206016087831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20061162531115867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039000309712217761,
                                   -0.75334573071218469,
                                   0,
                                   0,
                                   0,
                                   0.17087653900447156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14130459313487073,
                                   0,
                                   0,
                                   0,
                                   0.04575949148230031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083405393000685543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39982561359688812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024077209394807259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016903122006875895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38313098893209319,
                                   0,
                                   0,
                                   0,
                                   -0.11733962266275981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0045101768996200636,
                                   0,
                                   0,
                                   0,
                                   -0.42338737637049323,
                                   -0.21471510706680502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0092582503971698933,
                                   0,
                                   0,
                                   0.45979768382405634,
                                   0,
                                   0,
                                   -0.16500058806435669,
                                   0,
                                   -0.030994854402878171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36478593058651854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11393652930220045,
                                   0.044980924978996015,
                                   0,
                                   0,
                                   0,
                                   0.062371638709993966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47160678091281799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60788267359774861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32201661038429746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2321513317767121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2866866148707205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5282374408512901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3341641929761498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10478496772457067,
                                   0,
                                   0,
                                   0,
                                   -0.11028241979792236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5245477078223898,
                                   0,
                                   0,
                                   0,
                                   -0.14019776891360447,
                                   -0.46152814913911511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064089749788984796,
                                   0,
                                   0,
                                   -0.22348265404797665,
                                   0,
                                   0,
                                   0.42647041705005967,
                                   0,
                                   -0.044647820018825932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26204241461516709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26344641669181995,
                                   0.045361245648356301,
                                   0,
                                   0,
                                   0,
                                   0.26215990738753081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14921734306601173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00037247956382407965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55475748208777331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53333080259456689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49539881984042161,
                                   0.10923391463145811,
                                   0,
                                   0,
                                   0,
                                   0.11131991333563275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022187626342159671,
                                   0,
                                   0,
                                   0,
                                   -0.19564166015570517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060178807890717709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038536147504640322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26517511945215699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15448551035324481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56924209210526255,
                                   0.22992991810358246,
                                   0.0080894314824204415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051593017558619281,
                                   0,
                                   0,
                                   0,
                                   -0.5671618007620306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41424639751388481,
                                   0,
                                   0,
                                   0,
                                   -0.53386255988607467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21475258633408539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075039444026467783,
                                   0,
                                   0,
                                   0.093497400107738826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9005149640221215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15242395344824688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13105988039295985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30716781914897506,
                                   0,
                                   -0.58485376562888303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44589993986182608,
                                   0.30666988895317182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54812712619298731,
                                   0,
                                   0,
                                   0.63844418137772951,
                                   -0.071838442939386904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17468686797890204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10424804798289919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14738340215309745,
                                   0,
                                   0,
                                   0,
                                   0.19307145397276382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38495363871526334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17813288857183585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19112095627898573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3696497210384988,
                                   0,
                                   0.72716573210741586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42832384767746101,
                                   0.18525277252400443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18450344624584369,
                                   0,
                                   0,
                                   0.48923204187183028,
                                   -0.33138599347553838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38420092497882752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074443938910148194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35455485790872027,
                                   0,
                                   0,
                                   0,
                                   -0.45227298614578082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12316198885766648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38859445670827331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21864202148991688,
                                   -0.33441274456605929,
                                   -0.12335870630500054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17613337457132067,
                                   0,
                                   0,
                                   0,
                                   0.35449446679518176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98325254128302142,
                                   0,
                                   0,
                                   0,
                                   0.0630787281462446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6133723208521924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22231413105019196,
                                   0,
                                   0,
                                   0.80843022459559866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09753085720084817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39160481497590927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42325410116739615,
                                   0,
                                   0,
                                   0,
                                   0.32270744734075313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11833759071730074,
                                   0,
                                   0,
                                   0,
                                   0.10978103421390339,
                                   0.0075004450393506769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10268090303914455,
                                   0,
                                   0,
                                   0.44225225499054527,
                                   0,
                                   0,
                                   0.28983894508459723,
                                   0,
                                   0.42536052670776153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096246307683748644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076267031567210375,
                                   -0.32887626149035937,
                                   0,
                                   0,
                                   0,
                                   0.0038442733136868235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31029171666696254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99056135992506322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16413553007435361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28887320026591229,
                                   0,
                                   0,
                                   0,
                                   -0.70755555573897477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28769321211800902,
                                   -0.405963293766049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59479561805747261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20898273383588564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49978294701816672,
                                   0,
                                   0,
                                   -0.58663554962863951,
                                   0,
                                   0,
                                   0,
                                   0.30952398659214103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1516493503737639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17342941754686472,
                                   0,
                                   0,
                                   0,
                                   0.22696978897677902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.321092260555221,
                                   0.73472670670135221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022735164709101613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29204643905501215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3119551926717285,
                                   0,
                                   0,
                                   -0.42576050239607072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32651428557319595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46526683056106982,
                                   0,
                                   0.095214511722386638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20301290690244719,
                                   0.059278641160396606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46820657114654346,
                                   0,
                                   0,
                                   -0.36993099098958004,
                                   0.10673677526606526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88978057963526269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47971958906736806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087025046237185905,
                                   0,
                                   0,
                                   0,
                                   -0.017373804264738557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15362655376101914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16586528337574571,
                                   0,
                                   0,
                                   0.10816785716727483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17412361509022964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099745053325586835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16142274977752574,
                                   -0.061856368933407901,
                                   0,
                                   0,
                                   0,
                                   0.39323721319277449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13719963500414345,
                                   0,
                                   0,
                                   0,
                                   -0.012286791520072345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81095374631902317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24696255145677587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15365211921600713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04787928566974179,
                                   0,
                                   0,
                                   -0.42302861123065483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1660791512275048,
                                   -0.38985466055791917,
                                   0,
                                   0,
                                   0,
                                   0.36130648811356975,
                                   0,
                                   -0.077964647097102283,
                                   0,
                                   0.094255039984100314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18403604469886292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51755216643605872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36713926117103529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24382827627752882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45366049575038636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059829497364843241,
                                   0,
                                   -0.028336079710103258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36030557760803367,
                                   0.43071524831890984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24796502588517891,
                                   0,
                                   0,
                                   0.31187816104804023,
                                   0.064509674166347036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36129308952329542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0017587042822025914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85084893444092791,
                                   0,
                                   0,
                                   0,
                                   0.076609804701540107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28758806894389111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30747870490319001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21706857757780984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084504872974379669,
                                   0,
                                   0.31130256265691614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5939020814671514,
                                   0.34908020054235506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51683025760004275,
                                   0,
                                   0,
                                   -0.22594823416438256,
                                   -0.54437536433043088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53000530359418518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17582223912670703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0024628098288007536,
                                   0,
                                   0,
                                   0,
                                   -0.49554700847867916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11873136436574999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33182693276650477,
                                   0,
                                   0,
                                   0.30507462260899532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083896735616382251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057078733267006819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1258508151519713,
                                   -0.33275205118139134,
                                   0,
                                   0,
                                   0,
                                   -0.26937571763239387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51012447186092102,
                                   0,
                                   0,
                                   0,
                                   -0.63114085253434471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03763604624196145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096992276563606955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081107466456797533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14676188462200107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70836554122062745,
                                   0.54703863272500819,
                                   0.32725928822719974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70668708310093065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033865649348169685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23410956195644983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15927675867617166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28930073391236416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41217466899273203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0095055669314087921,
                                   -0.016042124209668589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45268804352996905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031417866431128316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71748643827335967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18866142679323131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47626403667899225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19300001435764838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27374006427502151,
                                   0.69214978829253226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13514715507928229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0095210414725491466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35772904814270517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87791095725215085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5574614539776912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15374695010147998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36419627684291211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77057123743384193,
                                   0,
                                   0,
                                   0,
                                   0.064963942227428378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029352831847207744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.266322255238368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56326574614709113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74761867808360571,
                                   0,
                                   -0.28464014106924906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064520785597475941,
                                   0.091697613586468538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037850480764024017,
                                   0,
                                   0,
                                   -0.078806148477704147,
                                   0.097701794833517763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29787100724868548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0086409924321592287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27152237076771712,
                                   0,
                                   0,
                                   0,
                                   -0.71747670262273888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1555365068946617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24663920185676075,
                                   0.88800853018188541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050764856611664799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94887578021020613,
                                   0,
                                   0,
                                   0,
                                   -0.37711456573587326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12527800843733047,
                                   0.31003807185924481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33536078024776511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22243483008202153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49088243721419805,
                                   0,
                                   0,
                                   0.24233176000134138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13979835095684753,
                                   0,
                                   0,
                                   0,
                                   -0.24979834310132637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12582383657562204,
                                   0,
                                   0,
                                   0,
                                   0.49339124388507444,
                                   0.20129233515790435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32472919126250666,
                                   0,
                                   0,
                                   0.0429257413463053,
                                   0,
                                   0,
                                   0.24401751736172433,
                                   0,
                                   -0.19278420143582367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20839873220826194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20171243656273632,
                                   0.32179241959337718,
                                   0,
                                   0,
                                   0,
                                   0.027629590563931231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4752245669195253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15963130669168174,
                                   0,
                                   0,
                                   0,
                                   -0.4963091405995087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017447209416251108,
                                   0,
                                   0,
                                   0,
                                   -0.084454142539388918,
                                   0.24604352011538028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49692666352717829,
                                   0,
                                   0,
                                   0.17739380952577055,
                                   0,
                                   0,
                                   -0.051703424584934904,
                                   0,
                                   0.14246398411398828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29787411663534774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11443446102265861,
                                   -0.49714149416511705,
                                   0,
                                   0,
                                   0,
                                   -0.06566403834443385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074573399634314419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21711859457138091,
                                   -0.079291228752381371,
                                   -0.41175400668286433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22174600034272512,
                                   0,
                                   0,
                                   0,
                                   0.23068657828758091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41807701284431176,
                                   0,
                                   0,
                                   0,
                                   -0.079669995402291444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077817671862026136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3683583389712426,
                                   0,
                                   0,
                                   -0.48139192786843077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1397985795227778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13541749158153343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25582740566492412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53076531741827215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16678736355075371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17622968177974982,
                                   -0.072621836858604683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74937506109707763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13107580791878054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099738709394615432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45650331531106147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25519207305819119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36924782787446953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011092787247384869,
                                   -0.31741024350129521,
                                   0,
                                   0,
                                   0,
                                   0.061079974715200741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0042254226989915551,
                                   0,
                                   0,
                                   0,
                                   -0.13596847236847157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0093960013840551394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56750959096847187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36587742640161253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1049176016686498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25536135694574885,
                                   0,
                                   0,
                                   0,
                                   0.2268317429977976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0083148072367462827,
                                   0,
                                   0,
                                   0,
                                   -0.17888678880128397,
                                   -0.15328653811676446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53587526923818629,
                                   0,
                                   0,
                                   0.30778225263066022,
                                   0,
                                   0,
                                   -0.15112085918796819,
                                   0,
                                   0.16391743657889227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086592568683597909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24569071152076832,
                                   0.38777414129255311,
                                   0,
                                   0,
                                   0,
                                   0.2033673406781458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3695722363114966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28833202118508355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31264896006127918,
                                   0,
                                   0.17529578118201355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.337158770193694,
                                   -0.2391257282072419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56074255711096221,
                                   0,
                                   0,
                                   0.29789477931000957,
                                   0.52020420924793631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14327568346692829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013281873851368003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33921302352255284,
                                   0,
                                   0,
                                   0,
                                   0.2863221416050542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75655003991118119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059805638300930677,
                                   0,
                                   -0.014056622026065779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61582552350434916,
                                   -0.080558143995708084,
                                   0,
                                   0,
                                   0,
                                   -0.17413911451195946,
                                   0,
                                   0.5125438746082529,
                                   0,
                                   0.36308248883131811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20562931013982647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28336589263042611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2052292935592272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15658374081224363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22948075941443566,
                                   -1.2238285273471237,
                                   -0.025251061111159823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48601232687680918,
                                   0,
                                   0,
                                   0,
                                   -0.23934198932486678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090829474965610946,
                                   0,
                                   0,
                                   0,
                                   0.13913813147471474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26688412808657613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30666101381129279,
                                   0,
                                   0,
                                   -0.50747934079902413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61111114901913555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036303502129085299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079644083121704734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55805736739387979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65034815938954094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36128240642871773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30550764279439402,
                                   0,
                                   0,
                                   0,
                                   -0.59482626837171726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26189356526545726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46622525355833228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26128021268694945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37373191381664289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56221805319089713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3820061545787955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22246262895031649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52966937263152158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31697483809005822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19343977850440225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57070521262301832,
                                   0,
                                   0,
                                   0,
                                   -0.1326874361526863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87377659310215339,
                                   0.045460236027524699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43426492911926867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25912182478334511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0043071084055505814,
                                   0,
                                   0,
                                   0.70137894870550732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016258178734585987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43777581849895736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10229571230806823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020248785575907868,
                                   -0.63102037415039847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37533996790020285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19229221999890456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47028765273983886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026281535751907698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5731077759058848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19346297893324765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86652949986247774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83837750705342051,
                                   0,
                                   0,
                                   0,
                                   0.87434420275625035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26519057276024377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26155454937017636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01178915587845436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18536581091909071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31581561821504311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014977778157498692,
                                   0.094636556824838791,
                                   0,
                                   0,
                                   0,
                                   -0.085780490268682119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052164585919627873,
                                   0,
                                   0,
                                   0,
                                   -0.034820856285045582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2178660761779587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34251925195701205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59741314211973762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56885952523989591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7632505732903736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57420738574831576,
                                   0,
                                   0.11458077943301234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076344101299227599,
                                   -0.24940259463868733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11640397542776071,
                                   0,
                                   0,
                                   0.31304449286274777,
                                   -0.022715909403209455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4346833629392205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36463045016193579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14005276345395617,
                                   0,
                                   0,
                                   0,
                                   -0.35033792072249542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0067442082251150601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46583663727855368,
                                   0,
                                   0.37680620717385716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0027421318874132627,
                                   -0.14077930059222202,
                                   0,
                                   0,
                                   0,
                                   0.69218346367037675,
                                   0,
                                   -0.016014187941361075,
                                   0,
                                   -0.11226195342097327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11438114091700219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34348349283520663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12496849289637378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44669063593068248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56143134542702389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22776943938920591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10796078644496733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54383215715350175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54633312720940785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16439919221786903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49884103404580232,
                                   0,
                                   0,
                                   0,
                                   0.091178262302768404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015868344100088194,
                                   0,
                                   0,
                                   0,
                                   0.49711013789434633,
                                   -0.2145845437483391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16581385405758592,
                                   0,
                                   0,
                                   0.19571463353998925,
                                   0,
                                   0,
                                   -0.036086022762143649,
                                   0,
                                   0.29174453774013948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14750430396804734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45073399417752025,
                                   -0.061822045252650365,
                                   0,
                                   0,
                                   0,
                                   -0.17103445364329367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19803635057823341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16604351418867958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091466002128394161,
                                   0,
                                   0.042668494650810629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23713605899889578,
                                   -0.38892916711515446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0019200099455963307,
                                   0,
                                   0,
                                   -0.10645141671871308,
                                   -0.7849945622155895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16016682948558572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21274496128331408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80723797528329311,
                                   0,
                                   0,
                                   0,
                                   0.78918969467501754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36924928554344549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6334144995480564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26459862875696349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34965927409685044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34816438612709283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50280341431081155,
                                   0.0035370178115881334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095820102680376357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64672603985260002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079042212089678612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23717166961202521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58513225049056805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014330260111311994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3977540540380694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88380396300795872,
                                   0,
                                   0,
                                   0,
                                   -0.98307632902371112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98248234272440504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06371177108629536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30677833988947845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51825897591853698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11899738647023242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48976791761279581,
                                   0.15248034961238738,
                                   0,
                                   0,
                                   0,
                                   -0.2732119364054611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2195569958709,
                                   0,
                                   0,
                                   0,
                                   0.00077598817278862371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21839318085394668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33024424939553526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14797236330052563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24188454092004349,
                                   0,
                                   -0.36642949791210788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1604821684242852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16506513373139656,
                                   0,
                                   0,
                                   0,
                                   -0.48035304118552613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29584654033484903,
                                   0.24362147139041851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055949663950579598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91640384203358027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2806094740948934,
                                   0,
                                   0,
                                   -0.59334778260361398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27473371079745573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29175808504142581,
                                   0,
                                   -0.67058165268667702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43633674584605847,
                                   -0.087435926667362385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044474162650649671,
                                   0,
                                   0,
                                   0.16737577943310425,
                                   0.41655059325275573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10281536516037472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1611945422041573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10150990128623201,
                                   0,
                                   0,
                                   0,
                                   -0.55487083952154159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19323319697837663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38377587079861719,
                                   0,
                                   0.20076895966592445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26629392197532986,
                                   0.041709892302232959,
                                   0,
                                   0,
                                   0,
                                   0.26467835926858407,
                                   0,
                                   0.74167491688207787,
                                   0,
                                   -0.20557957732633036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031626925855023483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28506965981773003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18009140842943658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33157576698129437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69399036493320909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077744663738823619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48183902467252621,
                                   0,
                                   0,
                                   0,
                                   -0.93431156268623961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25392899969243821,
                                   0.15310672852018833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30956359368220926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55031198432550932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5401949836885086,
                                   0,
                                   0,
                                   0.26395251741032033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47911587986227294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56702497674079744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92314376015714372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24865856800169839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068408454784765219,
                                   0,
                                   0,
                                   0,
                                   -0.56408067133263795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023076356301470115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21755670344164726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36090220520920319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17050181814439117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31548447308568695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055486295162895716,
                                   -0.31250468546576371,
                                   0,
                                   0,
                                   0,
                                   -0.51643060012919972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56487126379519503,
                                   0,
                                   0,
                                   0,
                                   0.082123247141920513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11483696799448567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094135723405206623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1786587562256986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051874225454145835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0011644063260818679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48439943872769081,
                                   0,
                                   0.53327012854258415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37276220842336766,
                                   -0.15388438989669179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060732545410861177,
                                   0,
                                   0,
                                   0.10881502806642233,
                                   0.26946236360406145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72794241965975293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43479461670869096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063461930710800571,
                                   0,
                                   0,
                                   0,
                                   0.2840454949765121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68136367351536309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11445289075010572,
                                   0.026522603902489755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71470911920514035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53991971734179578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0693706128242426,
                                   0,
                                   0,
                                   0,
                                   0.57371973586929625,
                                   0.14497207938621048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18384604803680096,
                                   0,
                                   0,
                                   0,
                                   -0.43168376535242026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074494080810302801,
                                   0,
                                   0,
                                   0.13403988943200551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089011149916207621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21281975557901789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49138888637912481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27110983359869234,
                                   0,
                                   0,
                                   0,
                                   -0.10806873649831963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25780170861975271,
                                   0,
                                   0.022761306308363455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29090690184653273,
                                   0,
                                   0,
                                   0.42947117690484382,
                                   -0.20105700047075542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52147605216423543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55127516648440633,
                                   0.44866361115710268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14120716158805025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61388857013452958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16265779746501857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6070209112288304,
                                   -0.32408119597022694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27078943824399471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21429743109583427,
                                   0,
                                   0,
                                   0.34949910134411027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16249486740257962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10741261664508435,
                                   0,
                                   0,
                                   -0.24710058588055844,
                                   0.4794042824466388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62992379758485373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16082519829859512,
                                   0,
                                   0,
                                   0,
                                   -0.34264111489024929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13631691315084418,
                                   -0.61813492887954113,
                                   0,
                                   -0.41140559769829999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23705382720185197,
                                   0,
                                   0.45125685324509146,
                                   0.69289139074267581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13825619911926718,
                                   0,
                                   0,
                                   0,
                                   0.5057626911863552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20167592776850787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25138289095416005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23103518979134047,
                                   0,
                                   0,
                                   0,
                                   -0.53668237468935531,
                                   0.081477016959586576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1775999711867475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37820754886044827,
                                   -0.035898556288883388,
                                   0,
                                   0,
                                   -0.4411258613970731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34839259968371145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17612417098631225,
                                   0,
                                   0,
                                   -0.15883692561867471,
                                   0,
                                   0.086838174104936161,
                                   0,
                                   0,
                                   0,
                                   0.22995353683223874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54704625981654309,
                                   0,
                                   0,
                                   -0.41599306356041976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25158871414354655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38345873897393457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10311405612156802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18489786124986241,
                                   0,
                                   0,
                                   0,
                                   0.20958068453095002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067990466715179471,
                                   0,
                                   0.13140031301420776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028854847632201065,
                                   0,
                                   0,
                                   -0.1014983218616117,
                                   -0.36764946503004703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31398125903443275,
                                   0,
                                   0,
                                   -0.67062830654003314,
                                   0.72359875580511068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45868990497447382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2611177274206451,
                                   0,
                                   0,
                                   0,
                                   -0.13793000452482784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39177011860662786,
                                   -0.13509343581902591,
                                   0,
                                   -0.12690024204827199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27526858632027762,
                                   0,
                                   -0.20983203948819931,
                                   -0.43007009725291623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099165781702266517,
                                   0,
                                   0,
                                   0,
                                   -0.54164799528142749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27597772313006397,
                                   0,
                                   0,
                                   0.22564586706231826,
                                   0.4276156328973032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74455444416248495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24530361457796648,
                                   0,
                                   0,
                                   0,
                                   0.2002445685335113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16666948481380792,
                                   -0.40667621434147666,
                                   0,
                                   -0.51368805062258904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20231085522902179,
                                   0,
                                   0.040491597771881965,
                                   -0.14225923890020278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027184691173674568,
                                   0,
                                   0,
                                   0,
                                   -0.50389554359060096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24162548809283638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24484255361948254,
                                   0.22310385844655883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89886927063967414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20194277634291649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47922420936200644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10778915492790199,
                                   -0.29536488730911548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81208491049640075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1925745669818609,
                                   0,
                                   0,
                                   0.20585066525822801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08510930260206484,
                                   0,
                                   0,
                                   0,
                                   0.47857819169644045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19961385880457944,
                                   0.00090312277523357798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22349685892255206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3811154162004885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02081150740281297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30925846280976521,
                                   0.40924355068946772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72445820927203874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41094136846385571,
                                   0,
                                   0,
                                   -0.32389147375369043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57710789424983677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097511334123278823,
                                   0,
                                   -0.091200635021512461,
                                   0,
                                   0,
                                   0,
                                   -0.20139028547050061,
                                   0,
                                   -0.15607728572902038,
                                   0,
                                   0.087383513088656939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23920649563470001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031816879488247164,
                                   0,
                                   0,
                                   0.74087431402091219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48550613605437143,
                                   0,
                                   0.25841230742828908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13244626823924521,
                                   0,
                                   0,
                                   0,
                                   0.098316768883513983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2921816983966754,
                                   0,
                                   0,
                                   -0.041789761956680854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016743415498025674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23488068965144099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4676859838127263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092001469844939371,
                                   0,
                                   0,
                                   0,
                                   0.17822009799853702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15930581966858032,
                                   0,
                                   0.53069566751562358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025733490727874592,
                                   0,
                                   0,
                                   -0.29738775926677408,
                                   0.41851070323682427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10868957258213326,
                                   0,
                                   0.0040136085627043849,
                                   0,
                                   0,
                                   0,
                                   -0.3726322368365832,
                                   0,
                                   0.060931338314545946,
                                   0,
                                   0.050751502768514069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15472813615994951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49800880159597294,
                                   0,
                                   0,
                                   -0.55699165749611235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42579114981482968,
                                   0,
                                   0.28202121983787687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54228085682745697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041021499515598012,
                                   -0.71903716052278299,
                                   0,
                                   0,
                                   0,
                                   0.17301609822160535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27059649319873225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28996075304776392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17894421402703686,
                                   0,
                                   0,
                                   0,
                                   0.22900949005154314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31878670408003063,
                                   0,
                                   0,
                                   0.25815977477448659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14923748506881762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0071764599795708667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056303899740345345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18993271700465597,
                                   0,
                                   0,
                                   0,
                                   0.077991438177223371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22230207805048496,
                                   0,
                                   0.31526238854272259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36064166616355353,
                                   0,
                                   0,
                                   0.016526111423934516,
                                   -0.63282503062403861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57749581342262446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95726149522692727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49864604797577705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36042052659709234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17431337534476174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23334492050002939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010283567289715929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09086534005526678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086797410947229342,
                                   0,
                                   -0.30125840312945662,
                                   0,
                                   0,
                                   0,
                                   0.63022730793819082,
                                   0,
                                   -0.038018153035937696,
                                   0,
                                   -0.24768191934877887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63963732926142447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10813906641483927,
                                   0,
                                   0,
                                   -0.11162356785737956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086998579443095109,
                                   0,
                                   0.029544319201566312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69258541585658118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22539501546514507,
                                   1.0664642234950594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17995962785265476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29706419412019969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082643023386626241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048885283560713845,
                                   0.07949611140629731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099015797855253496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64538318506436276,
                                   0,
                                   0,
                                   -0.34020758048656841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22338616782278958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17214327591832057,
                                   0,
                                   -0.20654043135944267,
                                   0,
                                   0,
                                   0,
                                   -0.21286618927791331,
                                   0,
                                   0.54861138898231121,
                                   0,
                                   -0.51282802284631623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0056975136838613716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36128227505815325,
                                   0,
                                   0,
                                   -0.028995209030718359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32784368595021501,
                                   0,
                                   -0.28204457554998313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27115075664970301,
                                   0,
                                   0,
                                   0,
                                   0.31785422321329582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37873585322404579,
                                   0,
                                   0,
                                   0.035484100664176343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21324070011146679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2351574829570108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19706905195389249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086845065518084325,
                                   0,
                                   0,
                                   0,
                                   -0.55411261064843387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17358814431681735,
                                   0,
                                   0.31791448119128823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1819422942522019,
                                   0,
                                   0,
                                   0.12386472746593005,
                                   0.21658338300259511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46623246278146924,
                                   0,
                                   -0.30217069455420875,
                                   0,
                                   0,
                                   0,
                                   -0.32466723121905372,
                                   0,
                                   0.15264686411312239,
                                   0,
                                   0.074417666991453343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36450477691943806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017786881286614726,
                                   0,
                                   0,
                                   0.050068627951915162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61492295853934498,
                                   0,
                                   0.20797855346915922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071640679610250571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76438311210233001,
                                   -0.33538838222381695,
                                   0,
                                   0,
                                   0,
                                   0.18693115743974245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33469409477619994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38876382204007476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11968431164940441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49959059738893241,
                                   -0.018744510920923885,
                                   0,
                                   0,
                                   0,
                                   0.60865654064803321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11978252606008435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59238746258926467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81919479521017236,
                                   0,
                                   0,
                                   0.21509399110714392,
                                   -0.43175070021837508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15602491658925755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18282654932549358,
                                   0,
                                   0,
                                   0,
                                   0.33502877796363589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10963479251868445,
                                   0.031754615900439036,
                                   0,
                                   0.22309937933665466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70100582734777717,
                                   0,
                                   -0.69181287032128458,
                                   -0.0085437500851523011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2046042677204811,
                                   0,
                                   0,
                                   0,
                                   0.0068330703848216382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52430093841460823,
                                   0,
                                   0,
                                   0,
                                   0.21324352163945215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31167756059934759,
                                   0,
                                   0,
                                   0.0035258403167421765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27142283950778456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27249788055346313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21242663640237333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41435787877116742,
                                   0,
                                   0,
                                   0,
                                   -0.17913070826449798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060202453368035203,
                                   0,
                                   -0.34843599948523746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044528964194619304,
                                   0,
                                   0,
                                   -0.23837102597162491,
                                   -0.042591623736980638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40521013038580311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36688429182111471,
                                   0,
                                   -0.063355037930888078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036656597247774335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80277252186913228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064745030646958968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11775188928903463,
                                   0,
                                   0,
                                   0,
                                   -0.18259778586250847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26746930956206277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24385059681021401,
                                   0.22778438156371961,
                                   0,
                                   0,
                                   0,
                                   -0.17454078090902794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74066306334684007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48791912525199554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32903426548824588,
                                   0,
                                   -0.12822932087777444,
                                   0,
                                   0,
                                   0.44071367262552497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81567444083215745,
                                   0,
                                   0,
                                   -0.34716705326878072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72642274597822176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23161180810480442,
                                   0,
                                   0,
                                   0,
                                   -0.83962515729350651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27967556765241264,
                                   0,
                                   0,
                                   0.49570188896953216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13573335563403202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58902711452568757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58788937555875365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59716497964391635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075089068894207966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43530571952467823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46047575114133399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091455689937295914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26011023434158564,
                                   0,
                                   -0.095301392903235554,
                                   0,
                                   0,
                                   0.63270201120826663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92640304272204488,
                                   0,
                                   0,
                                   -0.055131693568281646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40449488199428568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11770025549822855,
                                   0,
                                   0,
                                   0,
                                   -0.31534685616620678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22662414914465634,
                                   0,
                                   0,
                                   0.8992453291086473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10060258012395711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24431652786187821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0689456012065124,
                                   0,
                                   0,
                                   0,
                                   0.13741489680109509,
                                   0.38260111356558307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11292109356841323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26337186218858366,
                                   -0.23612493518127259,
                                   0,
                                   0,
                                   0.65342191067980382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42327087621590426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10259890509310744,
                                   0,
                                   0,
                                   -0.075184663866064871,
                                   0,
                                   0,
                                   0.94261138376804143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19945004320322957,
                                   0.28669320274978993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0536478327871142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10118748977840536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74001157836938236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27819131478058795,
                                   -0.65314868797576231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18682860161388623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74720104858551251,
                                   0,
                                   0,
                                   0.24101972710053046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048319264473155044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53690130057565488,
                                   0,
                                   -0.35711283642741448,
                                   0,
                                   0,
                                   -0.03814747177574309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33851168528579906,
                                   0,
                                   0,
                                   0.18065576829557514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30603602749497094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2562105285541896,
                                   0,
                                   0,
                                   0,
                                   -0.027916932453649457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54337377952241861,
                                   0,
                                   0,
                                   0.17520615707752868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45016917714784666,
                                   0,
                                   0,
                                   -0.14063684884616076,
                                   -0.24901016150697797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16784253000510907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23522336127717614,
                                   0,
                                   0,
                                   0,
                                   -0.32872164075804888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045200862862988432,
                                   0.43500093815629493,
                                   0,
                                   0.078806048374938653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79326906380791795,
                                   0,
                                   -0.37859072675923472,
                                   0.80616600218905243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48145412841081159,
                                   0,
                                   0,
                                   0,
                                   -0.40163550184310798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58954305557704578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24429624369361655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21046180247420343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52866325954621596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69585012002697866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08458023038097405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41012836246272227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58652390844009528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088067813487718027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83033833736751683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36132842264413617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76192208608930478,
                                   0,
                                   0,
                                   0,
                                   0.69638426249464935,
                                   0.51737081198632495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30735794718071879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47617532122871287,
                                   0.4920705289734067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85828401661026021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59471370909452681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13769369123442809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3250876039635392,
                                   -0.34513324560753905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42830413149680679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41761976652068733,
                                   0,
                                   0,
                                   -0.28860115035629502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14020363422858903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61405222282931815,
                                   0,
                                   0,
                                   -0.24562611772935641,
                                   0.094053505131944437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31505059239173228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08683407460678938,
                                   0,
                                   0,
                                   0,
                                   0.0024281177291255451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18443428993186561,
                                   0.79883696969292517,
                                   0,
                                   -0.15905557576617088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3950839670095273,
                                   0,
                                   0.61395837445852952,
                                   -0.684659815510549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58399656531845323,
                                   0,
                                   0,
                                   0,
                                   0.73505526352190542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26956732769985214,
                                   0,
                                   0,
                                   0,
                                   0.18624624667223758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040274863453442049,
                                   0,
                                   0,
                                   0.23631788756189956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46385146325077409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25250022015460855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38246704751770677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33705193116779186,
                                   0,
                                   0,
                                   0,
                                   0.075446327230131879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30517067259715402,
                                   0,
                                   0.036954294321000419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28021253283860253,
                                   0,
                                   0,
                                   -0.3399967343371964,
                                   0.045543873968112193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61676406190454092,
                                   0,
                                   0.3527820151831888,
                                   0,
                                   0,
                                   -0.54440426050975832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18793078516415357,
                                   0,
                                   0,
                                   0.19335778938676584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66186082555284509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42551935360583776,
                                   0,
                                   0,
                                   0,
                                   0.49992793725655771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11020303265348323,
                                   0,
                                   0,
                                   0.32159934399387718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35195260870765632,
                                   0,
                                   -0.1469063240212608,
                                   0,
                                   0,
                                   0,
                                   0.39617448526427035,
                                   0,
                                   0.18419518889289443,
                                   0,
                                   0.38555987315214274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26512455433129245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39381511776526629,
                                   0,
                                   0,
                                   -0.16598409649357995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21940797379040525,
                                   0,
                                   0.46253370847344843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019351840765353463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028044954271811806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42763816936246635,
                                   0,
                                   0,
                                   0,
                                   0.37815044228213418,
                                   0.45712018318542197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31392671790612253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19889884663185414,
                                   -0.23213108471323013,
                                   0,
                                   0,
                                   -0.23553630059043151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3763350583703971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26777666421653312,
                                   0,
                                   0,
                                   0.056591705922463938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25042345540724664,
                                   0,
                                   -0.97203239139861475,
                                   0,
                                   0,
                                   0.38637028850204747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14858130400687322,
                                   0,
                                   0,
                                   0.12114745777650271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42804263336933179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047736248197239546,
                                   0,
                                   0,
                                   0,
                                   0.31046990204151653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52847753242262163,
                                   0,
                                   0,
                                   0.034430430409060714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24552078864096585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0091154342568582347,
                                   0.22370762516308892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11803477418942609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5717562531513436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37449884240081943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1746308690300202,
                                   -0.23591495838533613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38285598572547136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34452604856441738,
                                   0,
                                   0,
                                   -0.23103210088805212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087712509389757373,
                                   0,
                                   0,
                                   0,
                                   -0.43610204269000413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31512477740841166,
                                   0.44126315035079688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30015399234061296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26753107810393106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16294542734681772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55387783449324779,
                                   0.55667301578479378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51556585572870728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37312985948313609,
                                   0,
                                   0,
                                   0.78773150198202457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43027708098444928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54441136933486156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26915647140125376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26213740660294421,
                                   0,
                                   0,
                                   0,
                                   0.03235773854692315,
                                   0.14924663374976896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55235004333240834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26640070694422235,
                                   -0.044510582696825424,
                                   0,
                                   0,
                                   -0.15269281980886285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073978336075309847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31077350374151658,
                                   0,
                                   0,
                                   0.18900871120825125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072873964669431551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020637665026426361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37489649762584043,
                                   0,
                                   0,
                                   0,
                                   -0.42161627031181487,
                                   0.30779014853838793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13352117654945653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52773774610021762,
                                   -0.14381766514957672,
                                   0,
                                   0,
                                   0.26183926547820979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29423718311136826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24988544503483412,
                                   0,
                                   0,
                                   -0.2159268918584763,
                                   0.77496364751240221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1384402527468982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14408606800213869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23794582476968446,
                                   0,
                                   0,
                                   0,
                                   -0.66152060591832362,
                                   -1.0178961543403093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50243913286430097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70895873884528771,
                                   0,
                                   0.059402644276897731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.265355977995055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027277437810974789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16506979062611196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1544161985646639,
                                   0,
                                   0,
                                   0,
                                   -0.34518617933895696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58596917132762272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1383958081572888,
                                   -0.022971891481990553,
                                   0,
                                   0,
                                   0,
                                   0.57881233654712949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4825950872937772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26274946911575986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15434505954230196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37519218357733591,
                                   0,
                                   0.12122092960518351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18321990018216316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29211577428063873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60379162560386546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45618223581454348,
                                   0,
                                   0,
                                   0,
                                   0.35936916586507195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071287836550048306,
                                   0,
                                   0,
                                   -0.70389198541733466,
                                   -0.069145425322120424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15645374503853843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16434723676833457,
                                   0,
                                   0,
                                   0,
                                   0.48222846173086947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017476635126122159,
                                   -0.38387161022677463,
                                   0,
                                   -0.09692495779463324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37691286931935486,
                                   0,
                                   -0.57444151366064866,
                                   -0.059239381614506724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30624670555551359,
                                   0,
                                   0,
                                   0,
                                   0.41559155697194983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31565673370136577,
                                   0,
                                   0,
                                   -0.37470692078436735,
                                   0.13369461136746086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54107136196605587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54013903616787218,
                                   0,
                                   0,
                                   0,
                                   -0.59090652338181759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58660261444920836,
                                   0.4053280535338547,
                                   0,
                                   -0.40695162466550494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19213538177265921,
                                   0,
                                   -0.28813389974694337,
                                   0.063213152027717961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10854323998016176,
                                   0,
                                   0,
                                   0,
                                   0.23330421804467519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48390658546231086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34796660491501052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20279550744070496,
                                   0,
                                   0,
                                   0,
                                   0.0033259681069549712,
                                   0.39723041376314894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4029596910491593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2751771692527239,
                                   0.27463331756290055,
                                   0,
                                   0,
                                   0.037872657501794207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064407677569309763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15874675300674884,
                                   0,
                                   0,
                                   -0.31862032574745897,
                                   0,
                                   0,
                                   0,
                                   -0.23778211912023256,
                                   0,
                                   0,
                                   0.053343281879412785,
                                   0.66164912475819382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32861329676975282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11642694273605986,
                                   0,
                                   0,
                                   0,
                                   0.048419888432469721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74116560804723608,
                                   0.46321761175800946,
                                   0,
                                   0.14860564094061951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.515987934471137,
                                   0,
                                   -0.37783069959847215,
                                   -0.21226084410538892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17255114716811024,
                                   0,
                                   0,
                                   0,
                                   0.44776347806998085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16254147527343726,
                                   0,
                                   0,
                                   0,
                                   -0.053241283587149746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27683034524286448,
                                   0,
                                   0,
                                   -0.35154098189877225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32777408950272446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17856509949926294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36782695431795603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028358280751206746,
                                   0,
                                   0,
                                   0,
                                   -0.21840173456138723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56225810830296408,
                                   0,
                                   0.21724669334101501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012659253927081945,
                                   0,
                                   0,
                                   0.19908100916186106,
                                   0.21043810234706264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6565399998553344,
                                   0,
                                   0.074064409993022079,
                                   0,
                                   0,
                                   -0.26884803804672902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022449164620660128,
                                   0,
                                   0,
                                   0.40086815259208863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37010681045912042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16820234575836499,
                                   0,
                                   0,
                                   0,
                                   -0.20052248103524567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78200964564634001,
                                   0,
                                   0,
                                   -0.6209610218599656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56978840310487733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67394932322292123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54368906512924819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49576891710482413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37907170122148875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13711373750634415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20616486511283474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61810706201250587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16560256677648011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19084586405433213,
                                   -0.45505392134664224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15335232962073758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71715440849278134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30503933969618585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20089091210132073,
                                   -0.10779289625776621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32456439024543143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1401071846014893,
                                   0,
                                   0,
                                   -0.64715084317303062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0107147242323489,
                                   0,
                                   0,
                                   -0.38699003160904283,
                                   0,
                                   0,
                                   0,
                                   -0.096356174706320047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032942842013093471,
                                   0,
                                   0,
                                   -0.23281709296265968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056258120323456624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23454387850607894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23259942674554446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14797942183342316,
                                   0,
                                   0,
                                   0,
                                   -0.43074269810798982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17557298604550681,
                                   0,
                                   -0.1897151636500071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19392089423914402,
                                   0,
                                   0,
                                   -0.55853321229976349,
                                   -0.22263717698257005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0025101046366674956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16060339409538055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40144506300752653,
                                   0,
                                   0,
                                   0,
                                   -0.080176550246319797,
                                   -0.51489592252455219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15533213362441206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24083805232798269,
                                   -0.3108808740927318,
                                   0,
                                   0,
                                   0.25758518043445588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0062632935658092012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41230400963071973,
                                   0,
                                   0,
                                   -0.35543510361162828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21478569735339526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27094679278650086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0049593545391959232,
                                   0,
                                   0,
                                   0,
                                   -0.33901124185219855,
                                   0.0029643626010835977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25648226311107791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20705956526754932,
                                   -0.038289410192661744,
                                   0,
                                   0,
                                   0.21352317486187031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21946220047309173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26695197882086802,
                                   0,
                                   0,
                                   0.70025058266141293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27365789645101807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32098895900677205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055677198114055027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78348940796952382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91499829301773294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69092502074278594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32702188220892148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24310543430497322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14291519678859124,
                                   0,
                                   -0.7718906782867796,
                                   0,
                                   0,
                                   0,
                                   -0.11414951280891372,
                                   0,
                                   -0.41375685770335047,
                                   0,
                                   -0.19249340188748248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38934035222635732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03385896082117,
                                   0,
                                   0,
                                   -0.067378923188256487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0077744733451520914,
                                   0,
                                   0.071754917142567334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14109359795225226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55848811907913243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18331493646245625,
                                   0,
                                   0,
                                   0,
                                   -0.16945273801475394,
                                   -0.11066361148781123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37390637254979314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27312056300492393,
                                   -0.31033368212655732,
                                   0,
                                   0,
                                   0.14675651400683093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25885218636226448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40995880468050361,
                                   0,
                                   0,
                                   0.1621808381133755,
                                   0,
                                   -0.1026581400089803,
                                   0,
                                   0,
                                   0,
                                   0.11189504403913475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20288629536684277,
                                   0,
                                   0,
                                   -0.28215147428680204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3278779393818223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4228815052319887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15843147739590413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068575579123647465,
                                   0,
                                   0,
                                   0,
                                   -0.43831382428466054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53007685626691914,
                                   0,
                                   -0.0085825706692582021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0068292631159913107,
                                   0,
                                   0,
                                   0.2169775264324264,
                                   -0.14047284434131233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35596616888343202,
                                   0,
                                   -0.25903047752415964,
                                   0,
                                   0,
                                   0,
                                   0.11819929355996309,
                                   0,
                                   0.65852640765301884,
                                   0,
                                   0.21465506873233758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18697397247504677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45114479185503625,
                                   0,
                                   0,
                                   0.24625409157618361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099539745431582144,
                                   0,
                                   0.058704932309675328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17410294170482427,
                                   0,
                                   0,
                                   0,
                                   0.40835981176887504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015083319314483047,
                                   0,
                                   0,
                                   0.094725397202289494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14862649450763088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15683714971545182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029514797757538756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22743892299414467,
                                   0,
                                   0,
                                   0,
                                   0.016421394594056025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083433048232590054,
                                   0,
                                   0.1692193521434241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77525538331148514,
                                   0,
                                   0,
                                   0.20835228411471585,
                                   -0.11893359709663215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20454667161153023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13689040534813965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15229256954846165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34456296940890319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16846632787017207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64311574758998657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32018811827863175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80108196491512795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4622416873412476,
                                   0,
                                   0.090328956437153482,
                                   0,
                                   0,
                                   0.44293160359549516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095516273525676362,
                                   0,
                                   0,
                                   0.20987496488347973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10616475589955077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52617445996205359,
                                   0,
                                   0,
                                   0,
                                   -0.21250590511220005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82466206506515372,
                                   0,
                                   0,
                                   -0.74427960130295601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52112863055533731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29296487200791116,
                                   -0.56368023371795939,
                                   0,
                                   0,
                                   0,
                                   -0.44628598736830061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13758544819398721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32674177912310548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22367583333016861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19282750422622102,
                                   0,
                                   0.20153018442663687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6238569717420529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026225748174177305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34940215727438051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42667021518016796,
                                   0,
                                   0,
                                   0,
                                   0.42208720529597277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29123839775012333,
                                   0,
                                   0,
                                   -0.3809585879796224,
                                   -0.33092361534286496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15816731485686197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10482901784128897,
                                   0,
                                   0,
                                   0,
                                   0.03820570631053951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31721879597587327,
                                   0.35918888393498977,
                                   0,
                                   -0.33889986341404221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13899022943369888,
                                   0,
                                   0.3572691675699754,
                                   0.21174359254272634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1827130640610977,
                                   0,
                                   0,
                                   0,
                                   0.2065235737992209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19879804575861262,
                                   0,
                                   0.55494119001464604,
                                   0,
                                   0,
                                   0.10906988262155237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45221797277487213,
                                   0,
                                   0,
                                   -0.62337707735263581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79318449496433885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26926992535599953,
                                   0,
                                   0,
                                   0,
                                   0.11186556755115734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53403613323763655,
                                   0,
                                   0,
                                   -0.42589073485883128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23377358514901891,
                                   0,
                                   0,
                                   0.031458399845279671,
                                   0.1539838709316044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072280296952945466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85079611438142511,
                                   0,
                                   0,
                                   0,
                                   -0.03545693868253335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60495718827904543,
                                   0.45675866148395144,
                                   0,
                                   -0.23797511275873143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093578606196873235,
                                   0,
                                   -0.32509401984157493,
                                   0.63981849540502234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041580201884164517,
                                   0,
                                   0,
                                   0,
                                   0.052663403788105884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035605269664950631,
                                   0,
                                   0,
                                   0.9161233996209085,
                                   0.024352370825921843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23632293119203512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41711667257905849,
                                   0,
                                   0,
                                   0,
                                   0.24620370528770885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24316664725362627,
                                   0.044834613605080176,
                                   0,
                                   -0.83489093041642304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26462973018286823,
                                   0,
                                   -0.24830328369726259,
                                   -0.54605100377642346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27914635881617256,
                                   0,
                                   0,
                                   0,
                                   0.11389609382732362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54227496048758239,
                                   0,
                                   -0.16049765544896979,
                                   0,
                                   0,
                                   0,
                                   0.16792145399289862,
                                   0,
                                   -0.085768386933923912,
                                   0,
                                   0.30064588307689566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09062433916541171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32297248877798107,
                                   0,
                                   0,
                                   0.05166713720505902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1384396857297987,
                                   0,
                                   -0.64797959296231677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18724200118726894,
                                   0,
                                   0,
                                   0,
                                   -0.51246663661818614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13007519159827796,
                                   0,
                                   0,
                                   -0.24514553196831895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27482496748832086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.001291483289251244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1344397006317038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56203217571014319,
                                   0,
                                   0,
                                   0,
                                   0.062771928673897776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036191391888444141,
                                   0,
                                   0.35658459130905296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17515185752223131,
                                   0,
                                   0,
                                   -0.19891649303770609,
                                   -0.11475719880073956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3988343901627609,
                                   0,
                                   -0.23809800140672466,
                                   0,
                                   0,
                                   0,
                                   -0.24602207623305578,
                                   0,
                                   0.0083964876136853883,
                                   0,
                                   0.58115112678109038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33430281612529311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37994733671480585,
                                   0,
                                   0,
                                   -0.1722118564067705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11194284035812052,
                                   0,
                                   -0.29597297385392146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094620561079165874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18410069347696875,
                                   0,
                                   -0.44440520525333932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12739481387482351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18631575960241648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1937651406298869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59507891674274105,
                                   0,
                                   0,
                                   0,
                                   -0.56307286373314147,
                                   0,
                                   0,
                                   0,
                                   0.44071685923190107,
                                   0,
                                   0,
                                   0,
                                   -0.10998975266343267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23085765999433353,
                                   0,
                                   0,
                                   -0.034116451463427407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35962707233185098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36333759131080401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19625233597285385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39406372539574713,
                                   0,
                                   0,
                                   0,
                                   -0.13968082507937463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27773967289958945,
                                   0,
                                   0.34246982529922831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023111158040611427,
                                   0,
                                   0,
                                   -0.11223954451187884,
                                   -0.23874085612281876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20418987396214894,
                                   0,
                                   0,
                                   0,
                                   0.2266054062654313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27688383871272632,
                                   0,
                                   0,
                                   -0.59652749183192721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35619212439368608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36986125969784989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15427892021209785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068084130720348038,
                                   0,
                                   0,
                                   0,
                                   0.33563814528690616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11781746522765045,
                                   0,
                                   -0.14494744503867846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012870148327522557,
                                   0,
                                   0,
                                   0.1858252022084369,
                                   0.0099415082642542035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11617766233768112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99631714883019007,
                                   -0.40424062719709652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074615883565550531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95491842635120305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39094414803362904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20166797477928361,
                                   0.51735639897277375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14528195955761503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32883825720318133,
                                   0,
                                   0,
                                   0.63598153329111384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10459983475118995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044924283124932129,
                                   0,
                                   0,
                                   -0.14952641416235055,
                                   -0.87672170373511649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099361105662795213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3843911286405155,
                                   0,
                                   0,
                                   0,
                                   -0.79900054127825815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072784739600106368,
                                   -0.30650074920779563,
                                   0,
                                   0.20710187322537227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26904964377335072,
                                   0,
                                   -0.31073590937939366,
                                   -0.42184297489205036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1095909085692367,
                                   0,
                                   0,
                                   0,
                                   -0.21252674105142094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62616061924330857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17688085811295476,
                                   0,
                                   -0.024456007310018513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58422564617627359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38769384562978754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20623784588689956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077502123922123523,
                                   0,
                                   0,
                                   0,
                                   0.18939691858820351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35905152596982709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34476410749953212,
                                   0.46761392353460352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3773102155295166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073001518914598301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29361593972734734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073578090427090626,
                                   0.91332885248831808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39365951768914775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76866835251983712,
                                   0,
                                   0,
                                   -0.86386508775873649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32001754427287982,
                                   0,
                                   0.36442768981239987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18153811397995256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36574649326061359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093654747498497642,
                                   0,
                                   0,
                                   0,
                                   -0.79434885492992524,
                                   0.79979427051290186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52494882864493453,
                                   0,
                                   0,
                                   -0.067345987640243049,
                                   -0.57434827989103798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31851070861659225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23483604789390256,
                                   0,
                                   0,
                                   0,
                                   -0.0010999393819795117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59577709255463751,
                                   0.043592382073385338,
                                   0,
                                   -0.60056624811574921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032744802091420042,
                                   0,
                                   0.29191098068448762,
                                   -0.19273537259445958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66802722265069536,
                                   0,
                                   0,
                                   0,
                                   -0.4472331070928528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85810031740847981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14590073527546121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74207715978940791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53052666198248433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53195399388717712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01772491000152171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10841096317981257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08407657924540049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26911257063368932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47016326124058883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090291378061499089,
                                   0,
                                   0,
                                   0,
                                   0.33495195615055284,
                                   -0.23015979105148704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30630116711898625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1694246106288797,
                                   -0.24655004473400705,
                                   0,
                                   0,
                                   -0.069265315062415206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.320315716348614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45790163756098973,
                                   0,
                                   0,
                                   -0.18116367432008179,
                                   1.1308650979402057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12757806079421255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052458022780239671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45158595645473126,
                                   0,
                                   0,
                                   0,
                                   0.98990602257914184,
                                   0.17771096199638192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036081660936790244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20569306928391756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3089002542677852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40813051196743633,
                                   0,
                                   0,
                                   0,
                                   0.71600940881618158,
                                   -0.16003242035453369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16077132172889441,
                                   0,
                                   -0.18009457573048046,
                                   0,
                                   0,
                                   -0.73433626470009628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25866311529825653,
                                   0,
                                   0,
                                   -0.74194109869915259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16165943807253938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26982524581399758,
                                   0,
                                   0,
                                   0,
                                   -0.47863600168067333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22068960942085436,
                                   0,
                                   0,
                                   -0.35350173030891652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32893959944461021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27567963776217946,
                                   0,
                                   -0.07538896587343677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38004209672822226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26956759485558546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61534901822502042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44744815304356711,
                                   0,
                                   0,
                                   0,
                                   0.11896652340327174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5923171897638958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28146895914738856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34259233428790592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26595418187219411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34616931509768101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84973183521643669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92421679328936424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045585927590710437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62324696947853209,
                                   0,
                                   0.040495118869603428,
                                   0,
                                   0,
                                   0.006363210993254903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48645412931464205,
                                   0,
                                   0,
                                   0.73405338264154762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75524093623780231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07236028767020998,
                                   0,
                                   0,
                                   0,
                                   -0.71444607425387996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33035091166971259,
                                   0,
                                   0,
                                   -0.26324283849775398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18883152951830895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13639446936158575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23109419106702278,
                                   0,
                                   0,
                                   0,
                                   -0.041038874885681864,
                                   -0.11869650915490418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21982455664397244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31077826464725,
                                   0.70711024621980145,
                                   0,
                                   0,
                                   0.2874564634247998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3278662073111705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16835937333142073,
                                   0,
                                   0,
                                   -0.11479727289977401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016581930688165734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20890820004014538,
                                   0,
                                   0.85637080583531833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059113503268774001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10538517759061317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1522512973407491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10865118208653601,
                                   0,
                                   0,
                                   0,
                                   -0.41608348634421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10516262339967532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57720002879508581,
                                   0.29669624277218765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020123943628637966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12951490247226879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1822628546051579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17776116746074369,
                                   0.018761533052716661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4256193140395757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2235848981504811,
                                   0,
                                   0,
                                   0.20741013249870058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31430390134871244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48871872077845935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17778116344633282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50225617139855561,
                                   0,
                                   0,
                                   0,
                                   0.32760482173522493,
                                   -0.13704839583488748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0012907118818768146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14857765574134374,
                                   0.1891334986617193,
                                   0,
                                   0,
                                   0.093555052132154981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36923417218195637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23491061311129982,
                                   0,
                                   0,
                                   0.3050598994851087,
                                   1.2390764800476126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55283359199500703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9809730831817951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43783509210385047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23104273679969195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85574719346946293,
                                   0,
                                   0,
                                   0,
                                   0.10990148318674146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05819080079856892,
                                   0.59832103168623085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52893643929536116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38534682883521576,
                                   0,
                                   0.64610363372045054,
                                   0,
                                   0,
                                   0,
                                   0.10491483621511905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22836297853081886,
                                   0,
                                   0.075899794043067015,
                                   0,
                                   0,
                                   -0.49446634841181236,
                                   0,
                                   0.87111374713057477,
                                   0,
                                   0,
                                   -0.38626290830161158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21218304108243699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11529797916723107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46630291938251778,
                                   -0.13491470584500176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087784902021175296,
                                   0.29859653276784248,
                                   0,
                                   0,
                                   0,
                                   0.14868723737067469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20890555356973678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34703356976926741,
                                   0,
                                   0.021360389789627059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048789783472363457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17753325054250796,
                                   0,
                                   0.60698347059240754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14217187814534521,
                                   0,
                                   0,
                                   0,
                                   -0.1329616798392948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51219097414143366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47720884611743974,
                                   0.097548931303899675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26158319106121242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2875136814812152,
                                   0,
                                   0,
                                   0.058967874585399156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20372988162211256,
                                   0,
                                   0,
                                   0,
                                   0.16848827524411986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78600413562995031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19825731116941456,
                                   0.30427553313396427,
                                   0.53877324628055967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66119475265293104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17079506580049583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31773718546541602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080909555832380076,
                                   0,
                                   0,
                                   -0.063095934149373728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13935625546866803,
                                   -0.070458229349828067,
                                   0.36186802585294625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19925400008832744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42533681862268818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25134062399928941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62357195707466917,
                                   0,
                                   0,
                                   0.41477625666662193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12622228197341978,
                                   -0.10417453641876531,
                                   0.42129915483034452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3458292633977253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50921423094950724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2215540751095344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30641778116300755,
                                   0,
                                   0,
                                   0.52330444905464046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056860950895695171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20665117513400588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29068519378969149,
                                   0.33265349093726149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0062792507016147386,
                                   0.021669837584055135,
                                   0,
                                   0,
                                   0,
                                   -0.53822293770077467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45493925967591087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056322419091544548,
                                   0,
                                   0.082937058169210681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31528113956039405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14314996844837205,
                                   0,
                                   0.16895105310172648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32133142759792538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4169560976833428,
                                   0,
                                   0.28963914655788325,
                                   0,
                                   0,
                                   0,
                                   0.020808444238231794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11601511226626973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18981220628786619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33705223234064913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35033678027034765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11847435148441035,
                                   0,
                                   0,
                                   0,
                                   -0.030265886918677026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66411094201014742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21754306118312339,
                                   0,
                                   -0.055042977719144542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42589337232875535,
                                   0,
                                   0,
                                   -0.38894116903623349,
                                   0,
                                   0,
                                   -0.033915322996797892,
                                   0,
                                   0.25690914475842103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27610434899164382,
                                   0.62894644916178644,
                                   0,
                                   0,
                                   0.1312678918793182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85040739362225282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095914951018926026,
                                   0,
                                   0,
                                   0.0039709867189557657,
                                   0.026008869044606725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27166099239863511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37076062426089279,
                                   0,
                                   0.023161646289217516,
                                   0,
                                   0,
                                   0,
                                   0.075377423929127177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48460677605899494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22443471031789278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27356798559113654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1634162663863182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025758367141949269,
                                   0,
                                   0,
                                   0,
                                   -0.37576489477952457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5724479072512858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2091314207881339,
                                   0,
                                   0.52016122657651687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049286515552348989,
                                   0,
                                   0,
                                   -0.37515889917003081,
                                   0,
                                   0,
                                   -0.48992151225926056,
                                   0,
                                   -0.48186802399653256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1885143616819997,
                                   0.085153490803659554,
                                   0,
                                   0,
                                   -0.31025800797853748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25039610818359531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56205770355044204,
                                   0,
                                   0,
                                   -0.30804914332419525,
                                   0.065910415869027378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47346183951365872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37461436384006475,
                                   -0.005694715614795242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013254130804506013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1488793588961202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45409788894432157,
                                   0.029824732789872847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25338698056050285,
                                   0,
                                   -0.34472475402536651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15952013003658372,
                                   0,
                                   0,
                                   0,
                                   0.3974448144090737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44302495421659938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25976186267193691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20025061538146624,
                                   -0.24012150295267845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40199045791133958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25733824710518083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51538093480611857,
                                   -0.0078582770981864281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2216523799938136,
                                   0,
                                   -0.017670849010590257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076846944103418108,
                                   0,
                                   0,
                                   0,
                                   -0.23397658743016858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53574999399954448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10780632582502106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14734163461147723,
                                   0,
                                   0.14959547715998389,
                                   0,
                                   0,
                                   0,
                                   -0.16483207245257339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46674177615117041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088523627428694601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16243001636519194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20418655506208253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36921628382006944,
                                   0,
                                   0,
                                   0,
                                   0.70360600567521137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05999975543080531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081936319507547123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31731425950459435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30923808265549885,
                                   -0.25488676020042417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27696793242304124,
                                   0.50125652643045426,
                                   0,
                                   0,
                                   0,
                                   0.01260051679765295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077578891218843565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44209742715169609,
                                   0,
                                   -0.35634070236616866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15112636791529438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11192787200424094,
                                   0,
                                   -0.19754456507507234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032192167467181454,
                                   0,
                                   0,
                                   -0.17071549639199177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075153733555826788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33319620900187996,
                                   0.20643721915586449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32999251862636259,
                                   0.36735870660756015,
                                   0,
                                   0,
                                   0,
                                   0.5605011343714581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15728679751793301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32360138637497243,
                                   0,
                                   0.070962082778170357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19535462864921846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095548882731278401,
                                   0,
                                   0.15127544168854773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22111807448370652,
                                   0.71215335242408706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78002587956927483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71449010903894583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7251488010781989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25227474986913972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81114152974370524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20944557322157287,
                                   0,
                                   -0.18395500833068912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25593579627973984,
                                   0,
                                   0,
                                   -0.25442584563623599,
                                   0,
                                   0,
                                   0.015648430458324925,
                                   0,
                                   -0.060008681575816958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84959684703733362,
                                   0.28521643606838881,
                                   0,
                                   0,
                                   -0.45317675051024431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25203085560240446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43466276002012827,
                                   0,
                                   0,
                                   0.31022631678575668,
                                   -0.15457803140244017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74660147606708605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15412315773963306,
                                   0,
                                   0.30662077366483959,
                                   0,
                                   0,
                                   0,
                                   0.1189060715933262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.391196659806196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056686622721017953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70456825040255711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35144537721365199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30175076673422169,
                                   0,
                                   0,
                                   0,
                                   0.028778322437953596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0055596760285897872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31606059814211124,
                                   -0.019434569330786529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035479527380383069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67277386559663543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039802694165497657,
                                   -0.10525742066667215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071954031180592612,
                                   0,
                                   0.02080327600691223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54947583687237966,
                                   0,
                                   0,
                                   0,
                                   -0.30938027461595419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16824107452761194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040324657143796336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39352296654165347,
                                   0,
                                   -0.095781889795377079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42612797569454547,
                                   0,
                                   0,
                                   0.16476664211399833,
                                   0,
                                   0,
                                   0.29531973949134188,
                                   0,
                                   -0.032122588006532643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041445723138786,
                                   0.20275936816771947,
                                   0,
                                   0,
                                   -1.0668590493830892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21749175896232759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49009609535041382,
                                   0,
                                   0,
                                   -0.18920003549020969,
                                   -0.46723302986615473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25035023817150526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083550844151224102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47925784192357646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07500514868542342,
                                   0.18524964753635248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20409061369062093,
                                   0.56773096167416859,
                                   0,
                                   0,
                                   0,
                                   -0.25314767346478234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   3.2616949287252173e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26016365876425157,
                                   0,
                                   -0.07864609894536892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0049833358232626171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28679330263686836,
                                   0,
                                   -0.11485135487957129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35495971610625088,
                                   0,
                                   0,
                                   -0.32649499613369531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14588001810237639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0031029069388353453,
                                   0.12427102321214309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26994725174011597,
                                   -0.001112897562694351,
                                   0,
                                   0,
                                   0,
                                   0.27408037193114965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44988908489267315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097852760757967297,
                                   0,
                                   0.18118469735559367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30168117717906728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54038383494629938,
                                   0,
                                   0.065558259478615197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27667121618422352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64048059344738395,
                                   0,
                                   0.14374651664553262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40470763332409937,
                                   0,
                                   0,
                                   -0.47531672386361323,
                                   0,
                                   0,
                                   0.29319374074580229,
                                   0,
                                   0.25129376520620161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39107595294756592,
                                   -0.63885133758977874,
                                   0,
                                   0,
                                   -0.17877841002173406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095321430881583069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1587812884416514,
                                   0,
                                   0,
                                   -0.17902323417330429,
                                   0.30899270219513569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44046101497290546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35914187514290541,
                                   0.6147846263954686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16984892688997616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02996718693825812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19441404914682309,
                                   -0.13666533236193107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3660776824975816,
                                   0,
                                   -0.36311975234128313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28593962238726212,
                                   0,
                                   0,
                                   0,
                                   0.032540522016175077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19786489659352879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13782726922302665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12383435090592187,
                                   0,
                                   0.37741875804506742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55856709719573616,
                                   0,
                                   0,
                                   0.40860449996950982,
                                   0,
                                   0,
                                   -0.68014273874586517,
                                   0,
                                   0.61408870811848504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043864163476952767,
                                   0.09845361247266389,
                                   0,
                                   0,
                                   -0.09439686320716599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22330207581992875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050783959077215279,
                                   0,
                                   0,
                                   0.43989427604904385,
                                   0.42060629454915416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25158951690789899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71742742063276754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27931969137737001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1206114148071432,
                                   0.17057697176574926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17198694516141189,
                                   0.059963999196595057,
                                   0,
                                   0,
                                   0,
                                   0.21422624908060608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14349077704507357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18694212419414363,
                                   0,
                                   0.23719475723821348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17672951643420157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013826750165950689,
                                   0,
                                   0.030896437226285559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37468561296739333,
                                   0,
                                   0,
                                   0,
                                   -0.12795534168627076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3774805203964845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54133844601809322,
                                   0.74477879028294236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57308656349278975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21732458120567655,
                                   0,
                                   0,
                                   -0.9300384943708544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33460769235733195,
                                   0,
                                   0,
                                   0,
                                   0.60369563714780561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13950289181178335,
                                   0,
                                   0,
                                   -0.40322311647142328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52248407573860789,
                                   0.4314756510627511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11140251280517517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13909659029727167,
                                   0,
                                   -0.84201453639358781,
                                   0,
                                   0,
                                   0,
                                   0.38020614086523186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64272825007181056,
                                   0,
                                   0.16867603875133219,
                                   0,
                                   0,
                                   -0.37622710068812826,
                                   0,
                                   0.24501596654603267,
                                   0,
                                   0,
                                   0.41135169433838292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52865367971866717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21615351031480107,
                                   -0.51083908937091127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71410611934420909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1834528469489442,
                                   0,
                                   -0.050249418624541652,
                                   0,
                                   0,
                                   0,
                                   -0.10403471836681832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12215172666756112,
                                   0,
                                   0.62240934409819471,
                                   0,
                                   0,
                                   0.17482058271629689,
                                   0,
                                   0.28472594377634591,
                                   0,
                                   0,
                                   -0.71701853740383359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25202624453916833,
                                   0,
                                   0.03701121786849932,
                                   0,
                                   0,
                                   0,
                                   -0.84383746610325094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17437020431726752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14922693814620203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11551256483151288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094295781297476663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31324882837995122,
                                   0,
                                   0,
                                   0,
                                   -0.2227049702509632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020504783181806128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18478549318317317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25327962820978078,
                                   0,
                                   0,
                                   1.1329004788323016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71868643222721684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35819210946566793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34269259006984387,
                                   0,
                                   0,
                                   0,
                                   -0.065232819768427319,
                                   0,
                                   0.40432828460028403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69682748898056612,
                                   0.5490228354825244,
                                   -0.14348719879957195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27296893820322787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097208800601244649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19516359714148263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17808999145531063,
                                   0,
                                   0,
                                   -0.19659688109564549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43890435157046975,
                                   0.13545927111186423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3780195994336219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15191678267156461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084200480987018822,
                                   0.2835758087704387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43312273122488892,
                                   0,
                                   0.43549467698638089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15445845819604417,
                                   0,
                                   0,
                                   0,
                                   -0.29348242150556442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02362097022416014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2184789647729819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17431278123638905,
                                   -0.1470406737604385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34647135377449717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5209727246356386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095920402465138888,
                                   -0.40432063505335497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.157614315984933,
                                   0,
                                   0.011520930371714011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54932448702717329,
                                   0,
                                   0,
                                   0,
                                   0.013948882556971832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18984503601751163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14455141197966648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5723729045993674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33925969180622018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069259657503140865,
                                   -0.28705367341017463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12811530516104588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11776542249194463,
                                   0,
                                   0,
                                   0.85189813251962176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5821261781157312,
                                   0,
                                   0,
                                   0,
                                   0.73157733340093944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027174514126319549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85081635973826009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29204352332234185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66622013457062834,
                                   0.41371817976335057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046087039047861995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5138774941728198,
                                   0,
                                   0,
                                   -0.50119126812275716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50236972560684356,
                                   0,
                                   0,
                                   0,
                                   0.093455148157892243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18326357375674593,
                                   0,
                                   0.56582101473151214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051015235706884321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76821520149210676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1005720239852477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18167836838566787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12515481743484541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6729795054194817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.679694238093147,
                                   0,
                                   0,
                                   0.087216150533881931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24207738118107086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063800386394441869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12180198393626411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41766027980585224,
                                   0,
                                   0.50435867413446456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51815157347684015,
                                   0,
                                   0,
                                   0.21144373552650991,
                                   0,
                                   0,
                                   0.2935066364627284,
                                   0,
                                   -0.51610721477978139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057684851706772108,
                                   -0.48622701583735362,
                                   0,
                                   0,
                                   -0.36191089008703103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69966753848061625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39767699251535404,
                                   0,
                                   0,
                                   -0.23188018563455812,
                                   0.34506485743029425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055031823791094135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55187474989291707,
                                   0,
                                   -0.061717454766815651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056403500039397925,
                                   0,
                                   0,
                                   -0.20218232192166563,
                                   0,
                                   0,
                                   -0.58998942100796326,
                                   0,
                                   0.21048580953826451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37235924828224504,
                                   0.44218029684441923,
                                   0,
                                   0,
                                   0.24754726766212548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.233900325406246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3630225727663261,
                                   0,
                                   0,
                                   -0.50004744409897617,
                                   0.39070074259231535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1219512580196441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23013451449250871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039237725560853309,
                                   0.79145322998600098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25175958307760754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70888379213754094,
                                   0,
                                   0.021842781923867197,
                                   0,
                                   0,
                                   0,
                                   0.18812053510066037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55346522425449307,
                                   0,
                                   -0.42335053173327875,
                                   0,
                                   0,
                                   1.11047589725553,
                                   0,
                                   0.1529051272078506,
                                   0,
                                   0,
                                   0.18922518262301768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62359430323938692,
                                   0,
                                   0.063006731012533596,
                                   0,
                                   0,
                                   0,
                                   -0.0033358411697158551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22297458049267727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2846237834682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29363989454248801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19604082803558662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2045842458899601,
                                   0,
                                   0,
                                   0,
                                   0.51391471391211319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21401253830330044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10191520702076295,
                                   0,
                                   0.66095998604923711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21174673533697111,
                                   0,
                                   0,
                                   -0.26697000485879563,
                                   0,
                                   0,
                                   -0.008841112005427143,
                                   0,
                                   0.64156930079857211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15147229141542384,
                                   -0.26816409418506659,
                                   0,
                                   0,
                                   0.5202126903937182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0079458059031428663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0084514493498231702,
                                   0,
                                   0,
                                   0.07447024307201569,
                                   -0.65721672873361914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46526294496327608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19675444562651612,
                                   -0.29105078877486884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063633844102092441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067893405532122378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14273554749542566,
                                   0.62865963436596173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38857166668030402,
                                   0,
                                   -0.35443985498166974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03480174505297947,
                                   0,
                                   0,
                                   0,
                                   -0.04724162572632469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34044436367897224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23742604129052486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30346559926396727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31093690301492194,
                                   0,
                                   0,
                                   -0.79615676405272529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36834509457983955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20413686883984694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0033629658301336449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27242833257477561,
                                   0.20657240407492361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04338298556404413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26983882048765867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13687140696991495,
                                   -0.33185721123940953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14309811380195869,
                                   0,
                                   -0.26679253586034191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24372380659918405,
                                   0,
                                   0,
                                   0,
                                   -0.55961762336322096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32540013298541687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3308154018720913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0371656535412508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23532208894031564,
                                   0,
                                   0,
                                   -0.21734829172861633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18886345958582387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57186938986757496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046038210025884846,
                                   0,
                                   0,
                                   0,
                                   -0.45743043188412175,
                                   0,
                                   -0.77686555053780437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53680849856963808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43382274831669876,
                                   0,
                                   0,
                                   -0.097624652645899826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55553707475516445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082979667804932752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44564203056441576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41411821175876079,
                                   0.67812051429641229,
                                   0.14915142927363434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17576553188815652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41390386275243229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10514792282810959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32449442753755203,
                                   0,
                                   0,
                                   0.16688282400064014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57211981579143401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52570975147581622,
                                   0,
                                   0,
                                   -0.92073246635384332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93761616109573276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76778046035395342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82083638384883972,
                                   0,
                                   0,
                                   0,
                                   -0.1226692074801603,
                                   0,
                                   -0.21634648192333206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30551486323764265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43447152968926239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11417353835183304,
                                   -0.39047799912866826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31302526874545117,
                                   -0.13107790916322465,
                                   0,
                                   0,
                                   0,
                                   0.067041503098091607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076850560159730519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33537020750240026,
                                   0,
                                   -0.049454759108499509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20232083559973607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41686554171731566,
                                   0,
                                   0.19413401135837768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24393056523310827,
                                   0,
                                   0,
                                   0,
                                   -0.73026601501696387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41592985564904139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27459914560639076,
                                   -0.15426686716052118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47275707472529926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88548485903433005,
                                   0,
                                   0,
                                   -0.63761305730511009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28130792700354523,
                                   0,
                                   0,
                                   0,
                                   -0.4845858427241857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32571792513428721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33643639599080444,
                                   0,
                                   0.32258413889330328,
                                   0,
                                   0,
                                   0,
                                   -0.42216695505948909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11039104783947518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56621782799106357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20268986010282303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1887674212068963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4349131390257866,
                                   0,
                                   0,
                                   0,
                                   0.0028092213219074666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076567785299473598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21448530066390312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49802145686893651,
                                   0,
                                   0,
                                   0.50837943481916792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62209683138172667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21523874739392368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11911695326573936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46818180819418509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12516639424434794,
                                   -0.73926114737054072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31963843019047466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44657196332731719,
                                   0,
                                   0.079849769425672068,
                                   0,
                                   0,
                                   0,
                                   0.60687692744829969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042213641246530292,
                                   0,
                                   -0.74602634280299018,
                                   0,
                                   0,
                                   -0.11249623248632198,
                                   0,
                                   0.18600654357980453,
                                   0,
                                   0,
                                   -0.31301454833232584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36132913370031355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50386310905059706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30744099651476625,
                                   -0.41748007158971484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022606995440753605,
                                   -0.23409473247804044,
                                   0,
                                   0,
                                   0,
                                   0.10824822395212313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15626141785725697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22424405542549794,
                                   0,
                                   -0.30838670734000301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31457945044083113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0072987443252400183,
                                   0,
                                   0.049620922273916686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091888102357987125,
                                   0,
                                   -0.64501642669309012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12524842705116473,
                                   0.12834101913145132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34867075451702051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13256031834039433,
                                   0,
                                   0.15730321211629644,
                                   0,
                                   0,
                                   0,
                                   0.55488329390742519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65080548972135033,
                                   0,
                                   0.15552387393995409,
                                   0,
                                   0,
                                   0.27147565719076722,
                                   0,
                                   -0.96496937652282511,
                                   0,
                                   0,
                                   -0.56311299125938019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21197913484996653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085672686916515792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53979417134449204,
                                   0.0033065614975739174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17782936647583725,
                                   -0.12071026977622194,
                                   0,
                                   0,
                                   0,
                                   -0.050747778184452627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072716498676719366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27611941812470175,
                                   0,
                                   -0.12305006185154067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39018948010333571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14145237185915827,
                                   0,
                                   0.42410236661037454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39846757122459892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27569569227674745,
                                   -0.028669071994396868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061018965856575666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025838893061102416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23059949926712461,
                                   0.16114140265821228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22064445825079693,
                                   0,
                                   0.14533602038510812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38139645429774544,
                                   0,
                                   0,
                                   0,
                                   -0.40531546836197463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4275098028670643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52661302177149627,
                                   0,
                                   0,
                                   0,
                                   -0.36863426775508668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41477046074741808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25329637750138617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75399515226469216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38889340237741632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72490607150730291,
                                   0,
                                   0,
                                   0,
                                   -0.3655850810146633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82740964247031246,
                                   -0.4099923733743554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58628573915163207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36696056725984677,
                                   0,
                                   0.093482445033963663,
                                   0,
                                   0,
                                   0,
                                   -0.67405205884827823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10047738682062587,
                                   0,
                                   0.33200076109502386,
                                   0,
                                   0,
                                   0.42960002269901698,
                                   0,
                                   0.077128149462376408,
                                   0,
                                   0,
                                   0.56363620154270189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50047891210036,
                                   0,
                                   -0.26021456896511136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35361834702387918,
                                   0,
                                   0,
                                   -0.5123048945908425,
                                   0,
                                   0,
                                   -0.14200322751139796,
                                   0,
                                   0.32187637338600744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35236896609746959,
                                   -0.11436187732124725,
                                   0,
                                   0,
                                   -0.58599106560818481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56348953283583303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29250014031945953,
                                   0,
                                   0,
                                   0.25369039432235246,
                                   0.62523242951100999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24385758297579344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37175460142300515,
                                   -0.01517745607101831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32401050069442322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24009231019867286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26629232254218932,
                                   0.1496712685192523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51514728684421407,
                                   0,
                                   -0.51377007921593687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13997588657137378,
                                   0,
                                   0,
                                   0,
                                   -0.18524081931124886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067171283228416034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13368671143596245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065095123361806284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096751648397945963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06138203915044857,
                                   -0.085342093180311551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0785069425375928,
                                   -0.041813499398468061,
                                   0,
                                   0,
                                   0,
                                   0.28547325345819763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4499695822072356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28793318467402385,
                                   0,
                                   0.25488437827649374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099552635426694458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50406111393732189,
                                   0,
                                   -0.51490183080245455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080545697861829718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24079530226815765,
                                   0,
                                   0.43397113309622626,
                                   0,
                                   0,
                                   0,
                                   0.10015761255886393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46848730211617201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10037619227607691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29197345468699387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44796760609073338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15576687289952112,
                                   0,
                                   0,
                                   0,
                                   -0.19123354489467148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40907497691369132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36726374316125454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24935091629972328,
                                   0,
                                   0,
                                   0.11739761871340965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37002395538637101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78732628561810392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87750496461046112,
                                   0,
                                   0,
                                   0,
                                   0.091510024034166609,
                                   0,
                                   -0.45722983306967147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16429347445817377,
                                   0.077632989453081641,
                                   0.0019479453219701792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42901785886458199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063030425182238697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76096392286679282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40451656214357129,
                                   0,
                                   0,
                                   0.19038928549523088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0066031170771691603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.051633872706075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52288348549369279,
                                   0.60847989590627094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55378376656559947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23197590099641624,
                                   0,
                                   0,
                                   0.35929444396475418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057468389043462714,
                                   0,
                                   0,
                                   0,
                                   0.01429384629650933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057951727485387822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12892407194232403,
                                   0,
                                   -0.52969139705123336,
                                   0,
                                   0,
                                   0,
                                   0.0053037374396064773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045956927728638519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52450653951929649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086255257389850487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37654084410624689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52444351604924189,
                                   0,
                                   0,
                                   0,
                                   -0.021167572674677601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029090967008151728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068887574409308178,
                                   0,
                                   -0.33155541590496257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089619207979125481,
                                   0,
                                   0,
                                   -0.50125965406500472,
                                   0,
                                   0,
                                   -0.60605490231731485,
                                   0,
                                   -0.61202757706280897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37304420235408997,
                                   -0.34149742630514407,
                                   0,
                                   0,
                                   -0.14505012140958448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30445994240249258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14850031070853695,
                                   0,
                                   0,
                                   0.25065023317009599,
                                   -0.16621029614601926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5759933796641582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1929231730345247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21942094813313159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25568115702519378,
                                   -0.43573863675504698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073866027552468794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095027427052207764,
                                   0,
                                   0,
                                   -0.32056122515075269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11715135258835647,
                                   0,
                                   0,
                                   0,
                                   0.31807281467449405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42039572895634003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13570628768509785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048585901286431477,
                                   0,
                                   0,
                                   0.29524485940201212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030758847992386162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93355206556698633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13995756793184214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75413442222717431,
                                   0,
                                   0.11332076424943731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62283406673101072,
                                   0,
                                   0,
                                   0.42725130914310555,
                                   0,
                                   0,
                                   -0.48782480529889743,
                                   0,
                                   0.35675757958676357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26573283855729479,
                                   -0.36293992071116687,
                                   0,
                                   0,
                                   -0.14344383908823991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081413667889994573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30234074422196056,
                                   0,
                                   0,
                                   -0.18689473921534377,
                                   -0.16420579111590194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11579631652275765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13547333723605812,
                                   0,
                                   -0.32971723975854095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050383241955491882,
                                   0,
                                   0,
                                   -0.13575454468908421,
                                   0,
                                   0,
                                   -0.043394695921909955,
                                   0,
                                   0.24312066758602174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74313031751164926,
                                   -0.12203663505526198,
                                   0,
                                   0,
                                   0.10147396122588634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56551881105592439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031440458330312337,
                                   0,
                                   0,
                                   0.46689114812112853,
                                   0.16588754463074629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75441895408900783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36138240278400735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34741328583763248,
                                   0,
                                   0,
                                   -0.51474469246168653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31645098103787878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11646421851285935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50456540401041272,
                                   0,
                                   0,
                                   0,
                                   -0.99640031277354324,
                                   0,
                                   0.99692720549097036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57574839547535284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65795097184412366,
                                   -0.28252296361597401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99428899294237361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62201297227309427,
                                   0,
                                   -0.45599079835179929,
                                   0,
                                   0,
                                   0,
                                   -0.3594812317730316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18691575563449517,
                                   0,
                                   -0.14018184784639462,
                                   0,
                                   0,
                                   0.34876252604577285,
                                   0,
                                   0.27730765069924734,
                                   0,
                                   0,
                                   -0.018895493598481847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21464969983410162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34230922704433075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44334913993862318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73264370930886136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9511220870499385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2620265188663683,
                                   0,
                                   0,
                                   0,
                                   0.25468911356131396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21684171220233922,
                                   -0.21676821380827055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10833146619784802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41197452274633806,
                                   0,
                                   0.07985931550464738,
                                   0,
                                   0,
                                   0,
                                   -0.67162783758557421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0216452355308852,
                                   0,
                                   -0.010088459150537542,
                                   0,
                                   0,
                                   0.5949497120103131,
                                   0,
                                   -0.13357786888060222,
                                   0,
                                   0,
                                   -0.18413337048823297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15166333200730372,
                                   -0.26001680351882189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20113612125473232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069558901710591273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54985940721199933,
                                   -0.014047503519768592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035939701269069514,
                                   0,
                                   -0.26900571704339232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17770619860774986,
                                   0,
                                   0,
                                   0,
                                   -0.29637872745838495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034932495920055179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6060171244800221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055139292919981431,
                                   0,
                                   -0.46997177761585607,
                                   0,
                                   0,
                                   0,
                                   -0.22851602717323827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2586751775534421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4398705325962341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23540865082542883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50984158178183769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35985114177380428,
                                   0,
                                   0,
                                   0,
                                   0.10612753354141258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085767767886842233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035006706651246861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56341233779578404,
                                   0.40963441478373197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14989836982015262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65113512426226172,
                                   0,
                                   -0.15490777604589459,
                                   0,
                                   0,
                                   0,
                                   -0.88510448627316263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09594905356702893,
                                   0,
                                   -0.49362577554580755,
                                   0,
                                   0,
                                   -0.025302813043034417,
                                   0,
                                   0.01670729838320912,
                                   0,
                                   0,
                                   -0.5766677309474102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062406824039345318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07398222949606309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043713056682628218,
                                   -0.55511638652672457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3216996285938698,
                                   0.33100316471283941,
                                   0,
                                   0,
                                   0,
                                   -0.23249080735872249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26429743078187373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28229303604181288,
                                   0,
                                   0.28725704493788684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28788301633717112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30895328464676575,
                                   0,
                                   -0.041201628142814667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037092117630898536,
                                   0,
                                   0.1443897825312902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18034246382038063,
                                   -0.36033609180549486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16699783135976626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83588217674149612,
                                   0,
                                   0.19061613488891838,
                                   0,
                                   0,
                                   0,
                                   0.53162746495888424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1910879011224593,
                                   0,
                                   0.060806994044264907,
                                   0,
                                   0,
                                   0.80768790390427891,
                                   0,
                                   0.44033235445774799,
                                   0,
                                   0,
                                   -0.23310115484286043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099470134337852012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11312471238865593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11098901610260166,
                                   -0.028717967435981359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60913262221471653,
                                   -0.019047122942179376,
                                   0,
                                   0,
                                   0,
                                   -0.13575483919380724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068828682390638884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1534662941428816,
                                   0,
                                   -0.0018810847964509381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52376530732707072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029917850133561852,
                                   0,
                                   -0.14841219387269966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49878482748164171,
                                   0,
                                   0,
                                   0,
                                   0.021626397516301327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02463830667191318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066352338366544666,
                                   -0.0029531536549404491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84169092447692739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87407476190147748,
                                   0,
                                   0,
                                   0.20240857092618175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77925693847451061,
                                   0,
                                   0,
                                   0,
                                   -0.35397732680936334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21131633781478593,
                                   0,
                                   0,
                                   0.77025915427146341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33503765306544314,
                                   -0.50677271847002658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55118304829037679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29611408393377425,
                                   0,
                                   -0.79654819359265838,
                                   0,
                                   0,
                                   0,
                                   0.11120726644614362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35111437855329325,
                                   0,
                                   0.42064773793104004,
                                   0,
                                   0,
                                   -0.013321814448915059,
                                   0,
                                   0.25473628199091508,
                                   0,
                                   0,
                                   -0.45246110537409112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1467954421585454,
                                   0,
                                   -0.47597834566135511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077317661322399187,
                                   0,
                                   0,
                                   0.31179080299268813,
                                   0,
                                   0,
                                   -0.17308985237760899,
                                   0,
                                   0.3704090815308444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1389806113826742,
                                   -0.6486809083670797,
                                   0,
                                   0,
                                   0.24567178322989636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60466439558408769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69296680740031791,
                                   0,
                                   0,
                                   -0.65902361624076988,
                                   -0.22268359634851037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032498103732671466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0038917269917305153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12678989479307315,
                                   0,
                                   0,
                                   0.326626767468636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40724252083284668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47598156354901733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23360376540635902,
                                   0,
                                   0,
                                   0,
                                   -0.89018912874778811,
                                   0,
                                   -0.79552771833085201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31212883542626813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38013110235695063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022507845217633646,
                                   -0.56450674226826036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55735769277502589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32277305981935833,
                                   0,
                                   0,
                                   -0.66217573566886623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11509155878942368,
                                   0,
                                   0,
                                   0,
                                   0.47472364399724548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94432521564547633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47326579219175041,
                                   -0.31240634680700541,
                                   0.06332677081100882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19415716488104615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5842499838538594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29208123412158837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45096149557775522,
                                   0,
                                   0,
                                   0.081784585264393334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32003704550249595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05240082808256219,
                                   0,
                                   0,
                                   0.058120569375567518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33037617505950828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17182795669819123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86762847947017963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052039993267289142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92381478341139944,
                                   0,
                                   0,
                                   0.09159990891062586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0019266784034913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40905162101534753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35489953870475666,
                                   0,
                                   0,
                                   0,
                                   -0.59149064345381008,
                                   0,
                                   0.16342193999098148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13155420801095535,
                                   -0.16340621606059272,
                                   0.59534287904601102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27633778563145794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067317654244873751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27067011092369714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081897517731342642,
                                   0,
                                   0,
                                   -0.66384863077198697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65638846889786395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1388769879149498,
                                   0,
                                   0,
                                   0.33192470469611485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44533785148831212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39382723272661424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15682874332601002,
                                   0,
                                   0,
                                   0,
                                   -0.4424400870820972,
                                   0,
                                   -0.030463365844228006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13237723662743633,
                                   -0.57267573030531194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62456874786866556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15174009918890341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083461136747776277,
                                   -0.41411865776804624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21959066201691102,
                                   0,
                                   -0.067255570721707889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045819782012382695,
                                   0,
                                   0,
                                   0,
                                   0.048499869892299749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048596975800684672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058230971732399606,
                                   0,
                                   0,
                                   0,
                                   0.26555951856715376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49942266182283268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35114250159614407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25636370760479898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1721341727340251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95313418308107745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25688122480340125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020460706581037519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2221420580399705,
                                   -0.39198717037645542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92832955098443148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10344710255054505,
                                   0,
                                   0,
                                   -0.18671045228122346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72438224430485509,
                                   0,
                                   0,
                                   0,
                                   0.24243863174674779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41534443120465914,
                                   0,
                                   0,
                                   0,
                                   0.027322073751734344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17624384184224551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23302967176103448,
                                   -0.20411531122595439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22743868671722273,
                                   -0.0042013826577831925,
                                   0,
                                   0,
                                   0,
                                   -0.12659893774797187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42774624832243913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1971612493964422,
                                   0,
                                   0.71077476155162866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23597844129746867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087250134410884597,
                                   0,
                                   0.11753496596526988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017302416514377722,
                                   -0.28176077847804215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53785009620306545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030013585000024656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33704708716582876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74997419839253487,
                                   0,
                                   -0.016547972575221892,
                                   -0.2622640342576269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17643825930719773,
                                   0,
                                   -0.54099858083591135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38450785413158395,
                                   0,
                                   0.31398985400875201,
                                   0,
                                   -0.3708333551395151,
                                   0,
                                   -0.29027249795888882,
                                   0.60980957290064497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57172759082259161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12393606350742209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35281598049647866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52751412760165495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50247368725653774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050371983842919632,
                                   0,
                                   0,
                                   0,
                                   0.25425798034349623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2016366596899162,
                                   0.1166990950448851,
                                   0,
                                   0,
                                   0,
                                   0.0075282423374502389,
                                   0.13563387866306748,
                                   0.052216587403501075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60316857619926267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16152084436497771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21819379394980939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076216257436503759,
                                   0,
                                   -0.27125337005341044,
                                   0,
                                   0,
                                   0,
                                   -0.078681019835100618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4482259254249471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3686498673231321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19661784205989222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72129555498284303,
                                   0,
                                   0,
                                   0,
                                   -0.49934018035112726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16429539764420339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37802899858761985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95803435859489217,
                                   0,
                                   0,
                                   0,
                                   -0.087234859964851003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62070852023078582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11325802981425044,
                                   0.36488220459020226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63736443122100406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40245194740221624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54986221939153501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29906138823077483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75032771757742245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95078447113989739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81983245666142601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62858915916327185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26475775772794913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069859221064475285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66163990724264965,
                                   0,
                                   0.092317871321844186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042566329400527653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43021492736600025,
                                   0,
                                   0,
                                   -0.16931728766431217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2462387466578714,
                                   0.068861040826388276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29878998122618666,
                                   0,
                                   0.26809288249726554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37610436272603781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7886367783235555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15390957162133131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043041466903364335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3730724091357292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35272003558782944,
                                   -0.28814229666150193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20484648261126071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23295866798446296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041439713631373214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044375774870874081,
                                   0,
                                   0,
                                   -0.10805658449190873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19707219281223204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19502894732519077,
                                   -0.54825009758661603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54992854790115131,
                                   0,
                                   0.033087300493698443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26506559357326431,
                                   -0.14429900009427152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13114825413110154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1087992610554175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22510032632682331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021813010833968822,
                                   0,
                                   0,
                                   0.36103080349593275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5423771798705066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021701049708627979,
                                   -0.53787986948094457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1536534280298654,
                                   0,
                                   -0.30136955675664123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8688994051458907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040855430311702773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57145683198131214,
                                   0,
                                   0,
                                   -0.41799309545495328,
                                   0,
                                   0,
                                   0.59772893640351832,
                                   0,
                                   -0.48568093057652273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20956093454549438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42764659670616106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57953188213524509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42728165477678259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10616594041935357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73426150479384988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52829706218208994,
                                   0,
                                   0.76539611123572748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097638062665146158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65572018352533878,
                                   0,
                                   0,
                                   -0.50089555325409585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015048413914745234,
                                   -0.48683696472461946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05469347170191495,
                                   -0.04170997884585656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40001280524644472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55713598793505126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40565314499296451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13533984250886655,
                                   0,
                                   -0.74413837729763432,
                                   -0.097547166870830121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022709293906811132,
                                   0,
                                   -0.69626391561584278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74587065074164294,
                                   0,
                                   0.13995801896285159,
                                   0,
                                   -0.060313211937191302,
                                   0,
                                   0.35628072606683053,
                                   0.019715154371027964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37097341448210791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72966075350170512,
                                   0,
                                   -0.25761539647297521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46521770012325703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14093188651309704,
                                   -0.15719920830075262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033840589066060633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038237891469690151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60761860543191248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098443903560714169,
                                   0,
                                   0,
                                   0,
                                   -0.23103327318036157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63037862526718125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29383529161193134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080483660085365366,
                                   0,
                                   0,
                                   0,
                                   0.52946741177650958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21106660521812465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57141315923864888,
                                   0.23593410275690199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20524214862329682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5303187333252416,
                                   0.32116494241875876,
                                   0,
                                   0,
                                   0,
                                   0.20673450872458429,
                                   -0.30065022282254572,
                                   -0.033194238951615107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21446858140764158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22585128509316557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017934329172695662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2434725578472938,
                                   0,
                                   0.3713098993800259,
                                   0,
                                   0,
                                   0,
                                   0.28268019919766368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14496459857152733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20942597017008691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10550806110220584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08331444204149592,
                                   -0.054928166451365508,
                                   0,
                                   0,
                                   0,
                                   0.099416103232919661,
                                   0.32465338159195811,
                                   -0.43389012631727925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34752620683619412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4483733290765553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11933432354478765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094130017186844966,
                                   0,
                                   0.3382586798337362,
                                   0,
                                   0,
                                   0,
                                   -0.35530827643283391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14676588699725449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26124365809730998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11636700656484435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1616597119080451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6517732117016849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50684361417746793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044751783985405844,
                                   0,
                                   -0.50184717608568952,
                                   0.5228003280247655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28149134131515646,
                                   0,
                                   0.30869892345760314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054738962138727747,
                                   0,
                                   -0.34368755558041431,
                                   0,
                                   -0.89329642478336235,
                                   0,
                                   0.090292084554282587,
                                   -0.025538706582112321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.000486861234769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02598256474210698,
                                   0,
                                   0,
                                   0,
                                   0.14938332274727908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14216145620993761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37497714588108427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7100045888600971,
                                   0,
                                   0,
                                   0,
                                   -0.17884605727314778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56881034432428712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23801304750854083,
                                   -0.60433178452776093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083651341086293143,
                                   -0.097669739442953665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39767723114301656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55952609165546985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32306408356870797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38027221596903749,
                                   0,
                                   0,
                                   -0.096241335754456855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11671914603563399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11615012325542493,
                                   -0.096917660497300717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10442308598691333,
                                   0,
                                   0.45452752248247558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095821278642924806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15523771406440723,
                                   0.19052680387951382,
                                   0,
                                   0,
                                   0,
                                   0.69440587964508815,
                                   -0.034423947448436486,
                                   -0.027295016802487432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049425212873807703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094778597351175831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40378544160288432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15929754124071077,
                                   0,
                                   -0.31306428795158925,
                                   0,
                                   0,
                                   0,
                                   -0.34019751703049417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10287080603773423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17610351274505115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21193215650782418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059557456121285317,
                                   0.45996354083149876,
                                   0,
                                   0,
                                   0,
                                   -0.26431864238540659,
                                   -0.065631979570701007,
                                   0.10855232446107935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23560113585713419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20451959468277628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065771079060698276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23709141084697477,
                                   0,
                                   -0.054044971115865904,
                                   0,
                                   0,
                                   0,
                                   -0.44402518982301498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54400128494179578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011168933705492181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037246051866036634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48499925580782827,
                                   0.1410158421669376,
                                   0,
                                   0,
                                   0,
                                   0.15339004924782107,
                                   0.043135075159662209,
                                   0.51876924874555008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15936980178631607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51345842342161763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20529374501460673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26596516379741392,
                                   0,
                                   0.024109333981873194,
                                   0,
                                   0,
                                   0,
                                   0.20060704908487445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078597324077827102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0083094225538569155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32523669493141927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47037306940256374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82864820185329624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43607258680458022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20985494138910343,
                                   0,
                                   0.33090095869588765,
                                   0.55825200249823359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032050656798025295,
                                   0,
                                   0.030260464877134428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10240711388281601,
                                   0,
                                   -0.27353202191089199,
                                   0,
                                   0.18835993485703739,
                                   0,
                                   0.30290092088989784,
                                   0.0077820856499183216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24201392633849605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35558949333511836,
                                   0,
                                   -0.66313528217392059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38990229215842953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098328444102770196,
                                   -0.0070087466571627233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44177540628096701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13538853994901712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34545801690433298,
                                   0,
                                   0.557031176625986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077969652206664519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09297654320971932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5566162724110606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20731852340423618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32034390313127259,
                                   0,
                                   0,
                                   0.12938271268765625,
                                   0,
                                   0,
                                   -0.25226435459224783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14089382703938402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23552189094475232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036734155025994315,
                                   0,
                                   0.26036849241774285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48320335391300739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14139552592945756,
                                   0.7723740208010984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044519574056962663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15286102324703504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0014222120561095172,
                                   0,
                                   0.0041811256415124481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1460192855991852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25287633766272882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54023283740534944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060439925909148491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64137060004367896,
                                   0,
                                   0,
                                   -0.16158524660059143,
                                   0,
                                   0,
                                   0.065048329017289838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42132006206966255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069477810061344417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081006164423328697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64704094733711015,
                                   0,
                                   0,
                                   0.72071748469742747,
                                   0,
                                   0,
                                   0.37653501262871081,
                                   0,
                                   -0.53308296422503065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87206533643763817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88378270133801551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18814886926391353,
                                   0.52102476344612603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071773349668113592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077969437723407559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077206302422623344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41337531651938969,
                                   0,
                                   0,
                                   0.25784426207727207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14532642397454645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5453732554548254,
                                   -0.29483430032192953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072572513816305417,
                                   0,
                                   0.16683264465660674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25063296269423263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49279700412568017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4952916488842049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39307714453977322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15265672410534584,
                                   0,
                                   -0.097282822201169669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44081318936501013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51355255109075659,
                                   0,
                                   0,
                                   0.13767875118602341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15603841306960201,
                                   -0.56427918897680429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8844137984226037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79235900363882417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096659617478822457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64594297250576138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37500383156879569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5964900975086953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57586792144032661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27413124104377967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19446612258091811,
                                   0,
                                   -0.11231872628759369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27651180847135032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.479650889360696,
                                   -0.30237387667417903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6692202194005028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16914512803873444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67555385149564773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17777969670833918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27055138588251232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24857163865259965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087632783548870982,
                                   0,
                                   -0.37384527144513396,
                                   0.11662341507888477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0835057988061647,
                                   0,
                                   -0.31314415443485161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6601522490922751,
                                   0,
                                   -0.64259537470686068,
                                   0,
                                   0.032163469534830694,
                                   0,
                                   -0.23792443910039748,
                                   0.46539245975597998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27724543626896103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57203869250375128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18285685971099988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040869175137284476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58041430169549624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47320082429576427,
                                   0,
                                   -0.22519724087663648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.802256151157555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71920884674440522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61328757496117869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24898193482236367,
                                   0,
                                   0.36358035890659507,
                                   0.26946085691641708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.007261576689946151,
                                   0,
                                   0.07742958357338528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19270290348971994,
                                   0,
                                   0.40304393027023511,
                                   0,
                                   -0.5555614185208444,
                                   0,
                                   -0.23888739775535051,
                                   -0.40719205873632963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50649330140556548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46284947525811299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31507170751761204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50944933110811486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52931742959032002,
                                   0,
                                   0.26809395032432931,
                                   -0.050238265247352643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29656794729948216,
                                   0,
                                   -0.0096623261515382045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44340942857977711,
                                   0,
                                   0.34548693618535403,
                                   0,
                                   -0.31648939845114898,
                                   0,
                                   0.55581916870507597,
                                   0.61579371584332998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16824478826807251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45204876800762628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0062323824436437969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59032271004393155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28484116440440405,
                                   0,
                                   0.31927622765949187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77808931331991193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59096359991022829,
                                   0,
                                   0,
                                   0.064106194511954984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41996703129324686,
                                   0.6633075680170365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58689014670740891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26605131041943048,
                                   -0.24468482788697787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32863891081263974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30218421477352275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11784516176359094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17380768571959174,
                                   0,
                                   0,
                                   -0.086100920732437344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46182756505238548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10823874839693508,
                                   -0.20370619651699709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45451082257939884,
                                   0,
                                   -0.38136676665957769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035471621246992463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4023559393599852,
                                   -0.36208464576848581,
                                   0,
                                   0,
                                   0,
                                   -0.046862206284640877,
                                   -0.10195172855411405,
                                   0.180398652370516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24232537024566536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37392762093975529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089320250373628701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30415896035434836,
                                   0,
                                   -0.47767090976288379,
                                   0,
                                   0,
                                   0,
                                   0.18822087277717753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098295004198172609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29718604012704808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24154200143346605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1815808229761359,
                                   0,
                                   0,
                                   0,
                                   0.75263379432981359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069950618163959477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.750247796265753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41038601185831258,
                                   0,
                                   0,
                                   0,
                                   0.47118095876567939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15209396147356694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028326497274632503,
                                   -0.0040826754825703249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68976036307843103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27644285955929215,
                                   0,
                                   0.24037707902675731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10712594282470758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14113921610748778,
                                   -0.4117655142980487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19247111449628423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38991875073284199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12345968710909641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14135158822265165,
                                   0,
                                   -0.25481950241039258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2384828859076368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54967753269509412,
                                   0.043006847006103271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12649051983793982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72317047647031196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31560710210812359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3295763753056008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34029563033693089,
                                   0,
                                   0,
                                   -0.12939131000040885,
                                   0,
                                   0,
                                   0.95271753723969976,
                                   0,
                                   0.65684204630938903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18068214218914133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23698290377984116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29905108329533897,
                                   0.42176007225105527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030966586470126928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041454545348903284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19938984869669171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31374206697893664,
                                   0,
                                   0,
                                   0.40383463917694462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43815033012616633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44598665440317542,
                                   -0.19441459543755851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -7.375033092699157e-05,
                                   0,
                                   -0.0077344695116978585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25093479889010778,
                                   0,
                                   0.50382119394185598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022534129551846784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01548376413937508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41519622945216561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2043028865690954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56485677982432536,
                                   0,
                                   0,
                                   0.10088749899566198,
                                   0,
                                   0,
                                   0.22228311596840733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29944877036132711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47291783594026748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.077949259446388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36215572416267816,
                                   0,
                                   0,
                                   0.16780527125398817,
                                   0,
                                   0,
                                   -0.40009322146945081,
                                   0,
                                   0.21201293195969853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28985514457893208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16688448429828112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0066284113928512271,
                                   0.46543701245304575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16690539539440732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22167443137521597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26573331921282217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38546556874340271,
                                   0,
                                   0,
                                   -0.59450908067685171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10840598187360224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03869324912413126,
                                   -0.28557650728469591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079065346082339019,
                                   0,
                                   -0.18064950465561916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55138420513004349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16872897242631635,
                                   0.049597372813637554,
                                   0,
                                   0,
                                   0,
                                   -0.098439299099375946,
                                   0.26896582986937878,
                                   -0.13604224370392312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0043095284198483973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052548484444292581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37644458039077111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32685864391940445,
                                   0,
                                   -0.012509428157424694,
                                   0,
                                   0,
                                   0,
                                   0.024196794136709169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38596295750085263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40431337082196961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41641357821772912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52457994843559563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0046116550176412,
                                   0,
                                   0,
                                   -0.031271749689279149,
                                   0,
                                   0,
                                   -0.86144887228784273,
                                   0,
                                   0.029899851519024915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056421540657962586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20488274333579837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40321261459476676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19135765157609491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78675267515882852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34868221603734462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53516957231268958,
                                   0,
                                   -0.28336351672207327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11214558788974598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076329024569685044,
                                   0,
                                   0,
                                   -0.70202807005341628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82188488991147302,
                                   0.064893672248612172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48885184888604277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41186006486408638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65133667283519592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40425012765838259,
                                   0,
                                   0,
                                   -0.82249218998520468,
                                   0,
                                   0,
                                   0.6308346714731542,
                                   0,
                                   -0.35169576229321781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085913270873043887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31854786194824436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39985165502953479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41314756489872334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50606429550962628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63691020287291622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3029896554760228,
                                   0,
                                   -0.54118451724056238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43905500948214188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27919813851248998,
                                   0,
                                   0,
                                   0.46707346935203647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25658420112853003,
                                   -0.28608765695262522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35344880283029062,
                                   0,
                                   0,
                                   0.19792301002657084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18645209119755296,
                                   -0.39580624549126586,
                                   0,
                                   0,
                                   0,
                                   -0.18956227552231628,
                                   -0.30825832006803111,
                                   0.21335759132629306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084866543887622395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2101761915782161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030922776247567296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39492793599471782,
                                   0,
                                   0.095764758891045507,
                                   0,
                                   0,
                                   0,
                                   -0.55697529262958567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16146304073547393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19788297598527885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61091710536648292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23757207999240249,
                                   0,
                                   0,
                                   0,
                                   0.18582608935367012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76241733668542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72934538786425773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05998168067409345,
                                   0,
                                   0,
                                   0,
                                   -0.71569455575451468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26393176587594769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4380680399355753,
                                   -0.11409314941427107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071168476575660541,
                                   0.047912695120648684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66476464627979759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39713473060407778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.205259589238248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13542726832379157,
                                   0,
                                   0,
                                   -0.087651779892893564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12179613387410702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066864537811108113,
                                   -0.051515306704282858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54887960544040848,
                                   0,
                                   -0.040357169843525595,
                                   0,
                                   0,
                                   0,
                                   0.96080622617869005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13296629856845427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15108927846385803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074103173951398538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055400187675778673,
                                   0,
                                   0.57224942811794388,
                                   0.22461090229573269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35930703006229769,
                                   0,
                                   -0.60398094818940629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28100651867458443,
                                   0,
                                   -0.013345601408864136,
                                   0,
                                   -0.29175366924827334,
                                   0,
                                   0.025546336624646518,
                                   0.12016575929986927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16195553468586515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37075761320736483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45606967709049873,
                                   0,
                                   0,
                                   0.41567936247856047,
                                   0,
                                   0,
                                   0.09503658736564613,
                                   0,
                                   -0.41898254382673705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64281798276137081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.473714810750758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73913880779023233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23779790730903594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10841492601725293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13127351125915843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6477878958969866,
                                   0,
                                   0.11570353612212152,
                                   -0.75455503497873244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44042111569428538,
                                   0,
                                   0.21764338480148121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028871890953348633,
                                   0,
                                   0.16952186192219484,
                                   0,
                                   -0.15003973724018865,
                                   0,
                                   0.79240205396012731,
                                   -0.24875691273028522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098744092462328639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16072857490032372,
                                   -0.18224716345385361,
                                   0,
                                   0,
                                   0,
                                   0.44093015476127156,
                                   0.32854440968524773,
                                   0.44944911717328517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07874669121336049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19200414856396841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46556097115965334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031093347931450844,
                                   0,
                                   0.29443928103262518,
                                   0,
                                   0,
                                   0,
                                   -0.096559525253391065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25649851087993703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065164365836915233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35934074787168374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51529356232616541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16539012508328799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9113199900152269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60482909180938105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18706244846219186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30901433553009772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2573383479720302,
                                   -0.15833043223495424,
                                   0,
                                   0,
                                   0,
                                   -0.21885702052570929,
                                   0.59254685524950967,
                                   0.20086747069199126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2580244245512977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051551704851833247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45695849070329281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13624719470004565,
                                   0,
                                   0.10733747016301977,
                                   0,
                                   0,
                                   0,
                                   0.034027577183757797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18281948643215346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17649351854843348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15666445408842641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54818278051042357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61556129612921495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35150097257778323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0032442643495850382,
                                   0,
                                   0.54567310295152116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34182287241527359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68805020618557089,
                                   0,
                                   0,
                                   -0.20678060297084427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69810227486164345,
                                   0.27523041798451692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71819992548289036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053508126739912037,
                                   0,
                                   -0.018923532928967007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14878668549332733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72498897155432696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14346999396981833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18847853454938915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14078064228007175,
                                   0,
                                   0,
                                   0.5245400984605596,
                                   0,
                                   0,
                                   0.053164489766529828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30844210049417259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43472075964434825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45043028570282134,
                                   0,
                                   0,
                                   0,
                                   -0.080573297505108513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10834024059214692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32081367122540783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83172123461709591,
                                   0,
                                   0,
                                   0,
                                   0.065107314564234076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23180277024774443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65435102124905475,
                                   -0.92428671600643753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24209784572491996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22929239243985131,
                                   -0.21821034674568543,
                                   0,
                                   0,
                                   0,
                                   0.035106275506635254,
                                   -0.3148934606080821,
                                   0.20047739024874123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017230993433408719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31335660535656801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36010533370382264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22012832579000749,
                                   0,
                                   0.23396204246549912,
                                   0,
                                   0,
                                   0,
                                   -0.17953163380919793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022909327476429084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58008625888954235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30870392679864406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035754364997135329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4192488833583019,
                                   0,
                                   0,
                                   0.055006611664579819,
                                   0,
                                   0,
                                   0.15932547211795298,
                                   0,
                                   -0.21066843192487195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1776050419206781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62418018153218369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0035031136962944548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16331763862870471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20573802618822681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11289370424745304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12233650343365549,
                                   0,
                                   -0.95253412485585365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12731303498483465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26217181115286575,
                                   0,
                                   0,
                                   -0.86840638193001041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31209137593237751,
                                   0.50498933986851668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46802688311295876,
                                   0,
                                   0,
                                   0,
                                   -0.019416156544270369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46191796107423921,
                                   0,
                                   0,
                                   0,
                                   0.50739005909052348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68927812748620887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37626366296646185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095219932171933711,
                                   0,
                                   0,
                                   0,
                                   -0.49338737222790308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076897538808958721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81711446069132165,
                                   0.32451924835532142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8372448225266963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32831005613933534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84719122892755561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47541356294592296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4744408654564059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49022743505890642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18768502816548155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7577748748666282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.227813082699169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099341186998578287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5594189591840758,
                                   0,
                                   0.030304217841717093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65255596073698574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19589963090490614,
                                   0,
                                   0,
                                   0.090088021949051841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15002873474693132,
                                   -0.12552700927690427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11628364399379866,
                                   0,
                                   0,
                                   -0.4935570801934549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056538615783923288,
                                   0.10984918271500282,
                                   0,
                                   0,
                                   0,
                                   0.0018125522331181622,
                                   0.20141040483478151,
                                   0.040093322676521659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16930863147057043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.248942274295511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14350015196687721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56493029291859309,
                                   0,
                                   -0.41505915897148471,
                                   0,
                                   0,
                                   0,
                                   -0.18950040907179069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079076354164158119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23269564061793907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27355922335793931,
                                   0,
                                   -0.52878388292845513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01622892177475984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29183659804756407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088225863049249204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017083288218799595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21921944866599463,
                                   0,
                                   0,
                                   0.55379867112618741,
                                   0,
                                   0,
                                   -0.2683877100248207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3539254713281989,
                                   0,
                                   0,
                                   -0.36381144315210445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5914649571393128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082212015168871291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045444183728436574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11078469552609647,
                                   0,
                                   0.20455015255586395,
                                   -0.20745688119906247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23178149677082968,
                                   0,
                                   -0.56580443741674835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37590686629898012,
                                   0,
                                   -0.75912832727575541,
                                   0,
                                   0.15583483948538313,
                                   0,
                                   0.60265413838619808,
                                   -0.6181239798050534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2772682702327699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27635553542751778,
                                   0,
                                   -0.041756851157738646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31649025898647687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57652158572460488,
                                   -0.10219815143386743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38906693109970597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50064511170139758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017486269096639862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11990371239821314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13500347413422908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68440799961923648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031749470816931552,
                                   0,
                                   -0.067512487594181714,
                                   -1.1207887932868164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19998329037440477,
                                   0,
                                   0.3179292045383551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33817283041272539,
                                   0,
                                   -0.37172187685434294,
                                   0,
                                   -0.091213269248710774,
                                   0,
                                   -0.43283143345802155,
                                   -0.12492328642740762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067557265102238806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28219289097002864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89823104537889675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21866501567603769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0119977997941862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81938239018948544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25238628884509035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57899879067533899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083193641625310538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12035669116753672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21481583049878503,
                                   0,
                                   -0.18072703397242362,
                                   0.14283216308443147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73329558896820013,
                                   0,
                                   -0.5097853128997073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0097900693729986964,
                                   0,
                                   0.10976926837375904,
                                   0,
                                   -0.29872917175039904,
                                   0,
                                   -0.026896440852042486,
                                   -1.0997334661272102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088379939921257228,
                                   0,
                                   -0.019757191728552725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012609117385688706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13485139822527528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28068233825895794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17035122040030262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17762078211599266,
                                   0,
                                   0,
                                   0.25157518242130805,
                                   0,
                                   0,
                                   0.84859898436815617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22515147329540969,
                                   0,
                                   0,
                                   -0.013098453623335227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17620966756149264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059687584506087292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28618775600655577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30793468385268608,
                                   0,
                                   0.66323948659456189,
                                   -0.096359965702773248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56340199698732218,
                                   0,
                                   -0.33139719538610057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69294629699430998,
                                   0,
                                   -0.52070507344597161,
                                   0,
                                   -0.44552035066759071,
                                   0,
                                   -0.058940584717732197,
                                   0.02420386819252332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10863033602987787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39933811203601666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058431297515734684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87771381403433812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65362972464644997,
                                   0,
                                   0.017386426778922902,
                                   -0.21172738941273503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087081814009229541,
                                   0,
                                   0.14376628394852356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38360019391533379,
                                   0,
                                   -0.3116140554474367,
                                   0,
                                   -0.34822788280563244,
                                   0,
                                   0.28224317028477036,
                                   0.32778140179476101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54672290600156259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28497878474403449,
                                   0,
                                   0,
                                   0,
                                   -0.27712668404845858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46074092036100178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50698053004597765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50904420217017854,
                                   0,
                                   0,
                                   0,
                                   0.11075889621754408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83007815518222305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039708405553348203,
                                   0.62828561065293054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59406694597966803,
                                   0.31520363439490173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15449381124742384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37012893246276563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35327268841501702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06290416093513447,
                                   0,
                                   0,
                                   0.025605741868479012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36365117248729983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22872511598085599,
                                   0.10544850087813666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035981087975716336,
                                   0,
                                   -0.24593049704761211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1187587763702187,
                                   0.17375070784969976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28095923663650391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10083023181940165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70975906724950677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17416260910175876,
                                   0,
                                   0,
                                   0.15645718376687578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11515277327913828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23918585486629917,
                                   0.35293910863248812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18050251571811088,
                                   0,
                                   -0.28357646412830051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3244998309433747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35946003671625726,
                                   0,
                                   0.53760664371704459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39126499214024901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25684478376482156,
                                   -0.32465798506342514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3865663617137694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050730090254129417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29932732051017141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1460729928302544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043155118073359033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53607242560319712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0047965923868940608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44765645810924831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26975416503204047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4514044334501105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18569171676991039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24513846619635782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63143020523406534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47977947282210631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13248998345251278,
                                   0,
                                   -0.042709629557253909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30505724379428822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48620875789249746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3004598451037534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22607049476617291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19447128696277771,
                                   0,
                                   0,
                                   -0.27919261288703323,
                                   0,
                                   0,
                                   -0.11786539341211144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61653838400675975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5448628064009271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79940132904660011,
                                   0,
                                   0,
                                   0,
                                   0.69325273605851756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51600488396383792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49987624835796463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70818910010819103,
                                   0,
                                   0,
                                   0,
                                   0.20472609890408117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055529712393391689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095292613790185637,
                                   -0.62645162270019972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16489935216140947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0681886852878483,
                                   0,
                                   0,
                                   0,
                                   -0.64045834131991675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29615458512830412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52605631947208342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40735877426813799,
                                   0,
                                   0,
                                   0,
                                   1.0407501529096526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11305158224262582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18190702561791749,
                                   0.13664462202390859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11410252784317854,
                                   0,
                                   0.0075120977473794176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9099857711869499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0033522044866137884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098804440630849755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27290019555623735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15970853355691095,
                                   0,
                                   0,
                                   -0.15592991957781829,
                                   0,
                                   0,
                                   -0.069925423544350496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14103717913477359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049740147309000761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21341800928503885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46481247705989759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77056780460734231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042295215932856345,
                                   0,
                                   0.16906325390654375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59039429185664671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16827275981704376,
                                   0,
                                   0,
                                   0.51611896385690759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14966699889982599,
                                   -0.097965936100497142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67598182663205919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14718479511920107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43570083931451814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27436922093665034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091772838827410233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0023586473909715522,
                                   0,
                                   0.57918137816526338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070451540689450171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72181060718646028,
                                   0,
                                   0,
                                   0.40693675885688424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49084962466816973,
                                   0.83670801745517942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.220795378679955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71418816851189637,
                                   0,
                                   0.014474541188394335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049373288698425097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19772974344598399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097799767898842468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62413827408595279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056430980250536042,
                                   0,
                                   0,
                                   0.044334823658331843,
                                   0,
                                   0,
                                   -0.067255016730796396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19850522753450298,
                                   0,
                                   0,
                                   0,
                                   0.46199766497662514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55075674372576622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39019530230575511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070440046994585837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015319794487776366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57076816355812066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1370600647987307,
                                   -0.15894255281864669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058964361417883936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11538003595938462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067573358589846047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54115656507627408,
                                   0,
                                   0,
                                   0.28713553413160353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1748460188325166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54902140562355184,
                                   0.12033269438480301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13158398358471787,
                                   0,
                                   -0.44216412907400804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27332371826892876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18799153943924657,
                                   0.4519645794577295,
                                   0,
                                   0,
                                   0,
                                   -0.28346865480743794,
                                   0.043848200561995378,
                                   0.38149342640819883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46731627298013251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17280305204746818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042942234653048965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17685048070731146,
                                   0,
                                   0.099474759345589622,
                                   0,
                                   0,
                                   0,
                                   -0.098303784087619583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39134286186610606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061590166619730158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46022046999546878,
                                   0.06050451347388032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30417811343432061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39291253172163848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19433528617668633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24364205490942267,
                                   0,
                                   0,
                                   -0.37819768650183139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15596917486474265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15176502582261941,
                                   0.010972834950670987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30415108170183314,
                                   0,
                                   -0.39684166356708583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4376550672226332,
                                   0,
                                   0.39167855827136688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16112020872297714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15066326660120233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095841796856438372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57589918407439056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032007883140310396,
                                   0,
                                   0,
                                   0.44454296456192122,
                                   0,
                                   0,
                                   -0.25384623577456095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049602661009018591,
                                   0,
                                   0,
                                   0,
                                   -0.48803645798090622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094117700149859401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18276350023991866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79455379404914994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099237412017211868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.279992824190609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89109214484881327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37763184594984284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14253171076160054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42967744504491423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11664579213596657,
                                   0,
                                   -0.41976516219946935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31575026195763756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14966779255698731,
                                   0,
                                   0,
                                   0.44990386720821185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40508709855767711,
                                   0.83029403685723979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13367232635233151,
                                   0.03100064019437088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25089719993519222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38328844071537266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43455460785530886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83228848974294611,
                                   0,
                                   0.17980653238982769,
                                   0,
                                   0,
                                   0,
                                   0.2052569480749464,
                                   0,
                                   0.25306115375483701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34272586919862535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89310998379172724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2910428005440201,
                                   0,
                                   0.013722870258178185,
                                   0,
                                   0,
                                   0.21121220413553127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25162182471144312,
                                   0,
                                   0,
                                   0,
                                   -0.37641555402637999,
                                   0,
                                   0,
                                   -0.57998083824385516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2068226848850544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81292206669651768,
                                   0,
                                   0,
                                   -0.54390879314114582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31484289901649432,
                                   0,
                                   0,
                                   0,
                                   0.21566879306343995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35788424456458945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10241146649909739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4725274850488646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38239129688642415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041766795132495094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12105286520436635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038059117895961309,
                                   0,
                                   0,
                                   0,
                                   -0.14271648368684181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78356635898231586,
                                   -0.057699945972200628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25445427120328357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10690926575236394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1626523076554032,
                                   0,
                                   0,
                                   0.47143309842729048,
                                   0,
                                   0.0687623270839475,
                                   0,
                                   -0.12855968301927612,
                                   0,
                                   0,
                                   -0.0093184505770119528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32705827352405603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023458234281069801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2526544893120366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.467642097468559,
                                   0.13471128027814658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08012323813683217,
                                   0,
                                   -0.276482229399588,
                                   0,
                                   0,
                                   0,
                                   -0.11227601244953149,
                                   0.10513063413922824,
                                   0,
                                   0,
                                   0,
                                   0.20895814021509285,
                                   -0.24292917359725605,
                                   0,
                                   0,
                                   0.0098530812692919217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60577221351478416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12472525943891863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29600521670244906,
                                   0,
                                   0,
                                   0.23023703550944152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37994186568832833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11666265827381284,
                                   0,
                                   0,
                                   0.17449701771480622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42724892212470322,
                                   0,
                                   0,
                                   0,
                                   -0.26838242839481569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64549308260391669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098329313336832411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97060461548637655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38414192621328902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12656503221847479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24311978864216996,
                                   -0.018697351355883768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26397706548764283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19588905433714773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12433838872709717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41666360872581854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2956132801043897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23651193345090299,
                                   0,
                                   0,
                                   0,
                                   0.64250397179282748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29543477648087213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19826950400752624,
                                   -0.014672415915158447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067955070742779067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048662156075954019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35887424164999943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31995832903690902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21329579632486587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68563982801585976,
                                   0,
                                   0,
                                   0,
                                   0.08092469596057944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44741266898743881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55962944521488778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45726170186122905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40558251768169157,
                                   0,
                                   -0.51778567234861617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1100881948095237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0290882457399944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18279776665816475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30004738732868441,
                                   0,
                                   0,
                                   0,
                                   -0.45860887041359388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08052715707914436,
                                   0.33762189186258851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38379552470818057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30975121173046277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10701777344387495,
                                   0,
                                   0,
                                   0.045119146236804408,
                                   0,
                                   0.1349697433051984,
                                   0,
                                   -0.11306377837113865,
                                   0,
                                   0,
                                   -0.50796424304855692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43374162200016753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059069353919064448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13152261692517239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51928040404015585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10674929282243242,
                                   0,
                                   -0.012158759516950855,
                                   0,
                                   0,
                                   0,
                                   -0.17184931414277016,
                                   0,
                                   0.39847462079785223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73382933682401397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45380854696811712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63921027893141558,
                                   0,
                                   0.58707293524879156,
                                   0,
                                   0,
                                   -0.45285138163299332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46541532370516558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26107368794343816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20005430590596696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53884330954050386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67418353859785729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32935132874228007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37730451137379883,
                                   0,
                                   0,
                                   0,
                                   0.22422481891818191,
                                   0,
                                   0,
                                   0,
                                   -0.6843787081864372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13563728476142711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51024019929284758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0017277793698777799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49479758840341304,
                                   0,
                                   0,
                                   0,
                                   -0.23967969143313317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27615638647738894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49813428233983448,
                                   0,
                                   0,
                                   0,
                                   1.2901025660854122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39898250235659521,
                                   0,
                                   0.39464437284189119,
                                   0,
                                   0,
                                   0,
                                   -0.2935720537463441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14840158634157274,
                                   0,
                                   0,
                                   0,
                                   -0.13699868340661436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027944277328159163,
                                   -0.0061254478752217345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033904032981275499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3167349725160275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54607611779322163,
                                   0,
                                   0,
                                   0.13009373530064997,
                                   0,
                                   0.51976629513904382,
                                   0,
                                   -0.079984884644216436,
                                   0,
                                   0,
                                   0.42315098893707059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35311881159757508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39124665454479657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17402932100800325,
                                   0,
                                   0,
                                   0.24778201352010762,
                                   0,
                                   0.32262841803969455,
                                   0.30797941439462978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2622861635286648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60234257861502161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097960263549477067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35784969119924137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70382903470170355,
                                   0,
                                   -0.65891407363188037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2910388742342835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13258781193679031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14692613845332947,
                                   0.11779551280597615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1271564306012728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54739919130200831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0049731391505802788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32927439942624415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19757084985665604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3714121602979461,
                                   0,
                                   0,
                                   0,
                                   0.59157404205025776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.115476627644505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17314016337149085,
                                   -0.53320672182451834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33302083489075363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34332697226691206,
                                   0,
                                   0,
                                   0,
                                   -0.61966618797950179,
                                   -0.27009369623613322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53660507450105221,
                                   -0.34636814753806083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12720221899329096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59741303355961539,
                                   0,
                                   0,
                                   0,
                                   0.23413299223745826,
                                   0.40519514453284089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88595895806670955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60995192590235892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56058030467750231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40523729250707458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073860481409503381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21140005638823312,
                                   0,
                                   0,
                                   0,
                                   0.06588249231786153,
                                   0,
                                   0,
                                   0,
                                   0.17558052186969564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19508397266158589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052195597233155491,
                                   0,
                                   0.047526476011315037,
                                   0,
                                   0,
                                   0.1226790601288347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37215496510178225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28528675908308626,
                                   0,
                                   0,
                                   0.065564740477514177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93712494448653794,
                                   0,
                                   0,
                                   0,
                                   -0.2907286599558862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32938470683635168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095915622770891662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68577071431086833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21991241782005891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75267445351453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84961871881738982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16668308015963079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63929686488552429,
                                   0,
                                   0.11764683648236626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93208667816566393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28932362336963768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37766742780864543,
                                   0.029640153524314983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46590532956811265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18784130707935517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3873921279044783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15646470089892123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084175038807530189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00015596952852686696,
                                   0,
                                   0,
                                   0,
                                   0.044924061323760006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64844363390035098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52723262576781138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68732795113532674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3764744909249419,
                                   0,
                                   -0.59890920636304523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47388964883050044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79084572176967682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25844693350101761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5929295949785065,
                                   0,
                                   0,
                                   0,
                                   0.030189136422434544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0403624270244052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52018282743029221,
                                   0,
                                   0,
                                   0,
                                   -0.38616767889695652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17042041872350758,
                                   0,
                                   0.95696055294617521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50751296377171906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030716855049985791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43924750598393092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11040129583377406,
                                   0.21903136758860128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29207126800739464,
                                   0,
                                   0.27689080341946065,
                                   0,
                                   0,
                                   0,
                                   -0.072178598026943486,
                                   -0.079432192182521427,
                                   0,
                                   0,
                                   0,
                                   -0.0088336018851687126,
                                   0.2207375862378643,
                                   0,
                                   0,
                                   0.38269857893274728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34480301845608163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027234255288869774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22163132795233831,
                                   0,
                                   0,
                                   0.35813325245471783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26177303806905294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10848618548833211,
                                   0,
                                   0,
                                   -0.48689160167164547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38615879377660511,
                                   0,
                                   0,
                                   0,
                                   0.98180821786615824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49741254514968625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018113097623389252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27348312869038466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1648164845370001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28511011832183242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39706233427695065,
                                   -0.25953285400160064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14589878829232925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50220379811396065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11490940948428036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60884499763315292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12225150921961314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26550334156029343,
                                   0,
                                   0,
                                   0,
                                   0.17457136787272406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0409886231656304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052292651414741709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14598481112120523,
                                   0,
                                   0,
                                   0,
                                   -0.5692490515334474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46654878882826256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35524153500434102,
                                   0,
                                   0,
                                   0,
                                   -0.10627189499114981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95041453830345679,
                                   0,
                                   -0.064488566911777317,
                                   0,
                                   0,
                                   0.0082544260585682705,
                                   0,
                                   0,
                                   0.30050609977342807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25728216468164866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16217964708610988,
                                   0,
                                   0,
                                   0.034927001199322037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038192043261709496,
                                   0,
                                   0,
                                   0,
                                   -0.81503225371938914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11083076445190858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47500089747239554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086278285630489615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086361119908152165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73874759438684867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18381821437455506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57044071608451297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28766331936306355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0377010294923992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11958825441147609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3998432598220712,
                                   0,
                                   0,
                                   0,
                                   0.23198656878423787,
                                   0,
                                   0,
                                   0,
                                   0.14853859813692977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65766575034217722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25233331340515053,
                                   0.26563798817988404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27014179785432646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88807515857702835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51586151668980873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19752749176111148,
                                   0,
                                   0.58386146784801618,
                                   0,
                                   0,
                                   0,
                                   -0.37142450493219192,
                                   0,
                                   -0.073876921109837929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18451450838430447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16844610693289533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22757519434425308,
                                   0,
                                   0.44180391745535125,
                                   0,
                                   0,
                                   -0.23451318294076676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54913493116348799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074605557813545581,
                                   -0.22380382742032368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052409976085087663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062907390162325716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085287303789694097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11185624513662752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86932388775649561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16862308951089361,
                                   0,
                                   0,
                                   0,
                                   -0.3351131165415201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14627849966023618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026224071305285531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28244488502217774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26042061263465682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02489124426063374,
                                   0.17413815642197461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15958345487441711,
                                   0,
                                   0.31742074120884856,
                                   0,
                                   0,
                                   0,
                                   0.0088331296878628712,
                                   -0.38827955068257641,
                                   0,
                                   0,
                                   0,
                                   0.47603519147572465,
                                   0.36740320260311393,
                                   0,
                                   0,
                                   -0.0025055199471909415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21416601896991877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36911353289405202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66892066122967309,
                                   0,
                                   0,
                                   0.30024209554417913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051795937820019095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26544561773193803,
                                   0,
                                   0,
                                   -0.48465737332027786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20712096487470386,
                                   0,
                                   0,
                                   0,
                                   0.056091441392298956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2801386547911382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037530548846330003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63237200498869572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84228135660240544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19732663094981689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24051762003839669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40699574501859193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4737639198672261,
                                   0,
                                   0,
                                   0.31169796409386802,
                                   0,
                                   -0.52636819305691773,
                                   -0.046066566288033496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40998657417579615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087311346362463904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18418992012340626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11791795902292704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051534975442534506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3240655290958035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0067330271976587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77380751623561039,
                                   0,
                                   0,
                                   0,
                                   0.25903174218853031,
                                   0,
                                   0,
                                   0,
                                   -0.0096008755289065939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15776779504616018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28633924591427373,
                                   0.013796634347083989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46567405078226326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078337108199467292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18721504686439269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069980479185498629,
                                   0,
                                   -0.30773841731495755,
                                   0,
                                   0,
                                   0,
                                   0.051103063322348513,
                                   0,
                                   -1.0389155298336079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19088538731764582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090778366089922902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29209708541430646,
                                   0,
                                   -0.35378995944145875,
                                   0,
                                   0,
                                   -0.5543990893147146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27441484952921369,
                                   0,
                                   0,
                                   0,
                                   0.058312461965825277,
                                   0,
                                   0,
                                   -0.49658440521875852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36824506826116005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18101553802440742,
                                   0,
                                   0,
                                   -0.65089318841206611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65950114391211589,
                                   0,
                                   0,
                                   0,
                                   -0.051806639529507731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20379821393479058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74533900526606656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017294965044260049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27167855054577905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43303232711115969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027342021548617382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44535403334105711,
                                   0,
                                   0,
                                   0,
                                   -0.41041546953394437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27503335702346082,
                                   -0.042384264112572435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046525701358157395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023247479104267187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28577871565301849,
                                   0,
                                   0,
                                   0.31608140186068406,
                                   0,
                                   -0.034866046081129913,
                                   0,
                                   0.44950152397165682,
                                   0,
                                   0,
                                   0.40924600618150619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12545264605469458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23906947187096,
                                   0,
                                   0,
                                   0,
                                   -0.50540071984082546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019572149707229175,
                                   0.12591207789795986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14983090914695793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6007777934338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30538775802445001,
                                   0,
                                   0,
                                   -0.011253277728565582,
                                   0,
                                   -0.2998428241238521,
                                   0,
                                   -0.20433513732572872,
                                   0,
                                   0,
                                   0.2168189757436475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091365300662626395,
                                   0.35205506932840303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51916594088619794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42755448117632833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10021056314375354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30046359168459241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18617063034425352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30498327869581038,
                                   0,
                                   0,
                                   0,
                                   0.067590056120299391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42756315905141995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29645022038674018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35714120623687823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28316994132587464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14580626848112779,
                                   0.1784808315693715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18037471051611642,
                                   0,
                                   -0.3348490629058824,
                                   0,
                                   0,
                                   0,
                                   0.4762014247546113,
                                   -0.12748369793632733,
                                   0,
                                   0,
                                   0,
                                   -0.20720814432129769,
                                   -0.034371649448731584,
                                   0,
                                   0,
                                   -0.084381780934462997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14598422227175673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43708146842243112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074413892991806077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20579931803154872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017798903808369425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17004630596326098,
                                   -0.32441625434998844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13962330155253891,
                                   0,
                                   -0.39250484267756763,
                                   0,
                                   0,
                                   0,
                                   -0.062052033208220982,
                                   -0.23788097979754874,
                                   0,
                                   0,
                                   0,
                                   0.14023350608376936,
                                   -0.11639642418451618,
                                   0,
                                   0,
                                   0.73916407721147159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0028093150693689339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063665042790564688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50649162626316968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41090638409674818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042089874149168413,
                                   0,
                                   0,
                                   0.13497885799882903,
                                   0,
                                   -0.24880879273436587,
                                   -0.012013114632767639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084622078409072723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69672110632725914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78379216937940277,
                                   0,
                                   0,
                                   -0.11673632513969756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94298865913836349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43872250642636618,
                                   0,
                                   0,
                                   0.45137476183139097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14383442055743653,
                                   0,
                                   0,
                                   0,
                                   0.36905095744790661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29833108146387544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06933213966190456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15349848129394336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0021038505765707816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29901789440505788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1414793001379011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55168644081561358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31166160696336281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28952518446881204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081781285287007455,
                                   0,
                                   0.30586907520393813,
                                   0,
                                   0,
                                   0,
                                   0.47990203050591645,
                                   0,
                                   -0.44719817332301487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10263816317359391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083080206422194977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060381431858371554,
                                   0,
                                   0.015935990572129001,
                                   0,
                                   0,
                                   0.42533993627102834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26442860686330555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32202207602392768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00031157968949701437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14285081315423043,
                                   0,
                                   0,
                                   0.30895095732194816,
                                   0,
                                   0.50205735324556178,
                                   0.47085759436655977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52417458822063145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17865379247441779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13859276546173935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4786113199036251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5155067168617038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14856219200165038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24633777493223755,
                                   0,
                                   0.2985550030427403,
                                   0,
                                   0,
                                   0,
                                   0.58306600903960137,
                                   0,
                                   -0.12553154804905695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2143636383427355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23506199796948798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047479009105915404,
                                   0,
                                   -0.033817328960906314,
                                   0,
                                   0,
                                   -0.99207003478095523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60910644698277161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13277677344968097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0013070189523213677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2580027610529177,
                                   0,
                                   0,
                                   0.19409038195122594,
                                   0,
                                   0.35642029836853012,
                                   -0.74781840728236948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41530785693834094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13922537003965701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15695288456370707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21769285627269536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80072756319537641,
                                   0,
                                   0,
                                   0.16443835861511252,
                                   0,
                                   -0.40746820495369207,
                                   0.18454342398216156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20284085555633705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13616160267879951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53192830635219746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.368067179484943,
                                   0,
                                   0,
                                   0,
                                   -0.14598115046392457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079049887237883365,
                                   0.19166707602286698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27135525832181828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17697602953874347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022685505241636622,
                                   0,
                                   0,
                                   -0.43113344163114742,
                                   0,
                                   -0.37598659432915094,
                                   0,
                                   -0.26230485077584192,
                                   0,
                                   0,
                                   0.12557291724841785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33175536083695367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56509011403674914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44683549697251346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19999576926629023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23801458316557186,
                                   0,
                                   0.13440558025608709,
                                   0,
                                   0,
                                   0,
                                   -0.26655474495158205,
                                   0,
                                   -0.033345424064831514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22728693871711589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072946134907266244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46423251537319699,
                                   0,
                                   0.045070679228581337,
                                   0,
                                   0,
                                   0.35997521525680232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1255846850487055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27148453714041021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61941726596694691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75657543856495102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26270453869604615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2540984917240468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69778256709475484,
                                   0,
                                   0,
                                   0,
                                   0.14877214932425714,
                                   0,
                                   0,
                                   0,
                                   0.084523819360102392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82393663156466412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53241186546285624,
                                   0.1468300683937134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60643991462316005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51562661044449132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38281816623730203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42182204515552052,
                                   0,
                                   -0.30535710498188573,
                                   0,
                                   0,
                                   0,
                                   0.23859800103962442,
                                   0,
                                   0.15443693896081845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11111708069137874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41000974234894272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79874397690002019,
                                   0,
                                   0.19651004513082765,
                                   0,
                                   0,
                                   -0.75032766220252567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49511818289863235,
                                   0,
                                   0,
                                   0,
                                   0.63323439682408345,
                                   0,
                                   0,
                                   -0.43136590085624166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28711478365910209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24589453862860508,
                                   0,
                                   0,
                                   0.29811127477740446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15503546133273102,
                                   0,
                                   0,
                                   0,
                                   0.44688017497953259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0029867795162624331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18476197766139624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54811401602236531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81203696426035077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41166568027770506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0630855597375934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19277363943422954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1171732496094346,
                                   0,
                                   0.52247754511635414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021231337888474311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1570424835997449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027922597414600916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05474026125005016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34279374667235851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27016622008079522,
                                   0.0071339845601706628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19022176722204834,
                                   0,
                                   0.069171244201906346,
                                   0,
                                   0,
                                   0,
                                   -0.25148253182803848,
                                   -0.15960757833282818,
                                   0,
                                   0,
                                   0,
                                   0.1893969147468218,
                                   -0.61656430669789386,
                                   0,
                                   0,
                                   -0.03440083980807053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41821293146113703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28962107197173514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42519358131101093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6038919138306742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052298637366010613,
                                   0,
                                   0,
                                   -0.61723482636765337,
                                   0,
                                   0.10025299979602953,
                                   -0.094382912542802427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13837268982367268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18084578245895144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1634881214520483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17484321693080315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096902128364895215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18917876772070133,
                                   -0.15372276854788064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76040064464266321,
                                   0,
                                   0.1514480817336763,
                                   0,
                                   0,
                                   0,
                                   -0.14339965282002617,
                                   0.28061167498693657,
                                   0,
                                   0,
                                   0,
                                   0.0093883893081947948,
                                   -0.013248168264074071,
                                   0,
                                   0,
                                   0.13250201045059798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37288662422675084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12874493353479874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23964458838421426,
                                   0.60097168600417017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39787479889594712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41942379777351668,
                                   0,
                                   0,
                                   0,
                                   -0.20197034497083238,
                                   0.45430254885547094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061992522410250696,
                                   0,
                                   0,
                                   0.45716296735903295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40207846417081483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57046949646592282,
                                   0,
                                   0,
                                   0.22645963038218209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24694315960178442,
                                   0,
                                   0,
                                   0,
                                   -0.052503393823231097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072135914408506807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87617242172804499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048568716482389383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15797263699544162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21947491245927131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51556617203134103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1104161922543094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26102239040279596,
                                   0,
                                   -0.49962249522583513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19349004489399604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022770534217413249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0079120734307036242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36649697272520299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14858994841950507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1679567966374188,
                                   -0.04219144366735187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36651452649167143,
                                   0,
                                   -0.45859317596715055,
                                   0,
                                   0,
                                   0,
                                   -0.18562651476448588,
                                   -0.45436926403571726,
                                   0,
                                   0,
                                   0,
                                   0.27228211723419332,
                                   0.22331097249582516,
                                   0,
                                   0,
                                   -0.31020378261213322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041041340239498694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077996419375668133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27930506854611359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010597129289905919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13001014444762957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33942261412327551,
                                   -0.069135572852419808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14126186254418682,
                                   0,
                                   0.36639299100359313,
                                   0,
                                   0,
                                   0,
                                   0.14990033496266467,
                                   -0.54412235714929047,
                                   0,
                                   0,
                                   0,
                                   -0.14847892775903182,
                                   -0.18494120563254099,
                                   0,
                                   0,
                                   0.045560967951239581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22661452288738404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45007680512664372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32767205688873102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13598858775276751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37064639408316996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46275628099220006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73905998720360899,
                                   0,
                                   -0.86784617493267913,
                                   0,
                                   0,
                                   0,
                                   -0.74375996284515533,
                                   0,
                                   -0.39357487880835262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0061121219276067396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21669706176288631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49637864389075881,
                                   0,
                                   -0.18658406739105265,
                                   0,
                                   0,
                                   0.26962257698082992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068521917923242998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10343994641914039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53202867007751431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31226513728543442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027372473667870628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52076248102184342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48824157109772331,
                                   0,
                                   0,
                                   0,
                                   -0.025193857474466112,
                                   0,
                                   0,
                                   0,
                                   1.0445613346117921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10768026862342062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41325622704831905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87096205246579816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083427917492826242,
                                   0,
                                   0,
                                   0,
                                   -0.15252363986199205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57371416277243048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1724416220783098,
                                   0,
                                   0,
                                   0,
                                   -0.40458467737045339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1960808456198552,
                                   0,
                                   -0.17519733478632912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26000129598400246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4916590431331343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065954001471005996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40254997189102598,
                                   0.43952024260394162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060051825880538159,
                                   0,
                                   -0.10415213127255295,
                                   0,
                                   0,
                                   0,
                                   0.025203733432738837,
                                   -0.090089220253361829,
                                   0,
                                   0,
                                   0,
                                   0.069619653208899041,
                                   -0.32581631612226608,
                                   0,
                                   0,
                                   -0.18199228360120862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031261088342602841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40347175691707382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47347043769663266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12296036081853265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42405692739007844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26352401562153938,
                                   0.38482606667999286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19439964320371972,
                                   0,
                                   0.13553783599434976,
                                   0,
                                   0,
                                   0,
                                   -0.49083194875245689,
                                   0.00089518500557319441,
                                   0,
                                   0,
                                   0,
                                   -0.031020054358505814,
                                   -0.17225265888491248,
                                   0,
                                   0,
                                   0.091993200157841293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044316032473676381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15876963440978506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32520675600926757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10846462987465796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6324044112541285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26508259632802272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11765340327651315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55532738531451087,
                                   0,
                                   0,
                                   0,
                                   -0.78373954288282932,
                                   0,
                                   0,
                                   0,
                                   -0.0022570142437823293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073034932470994157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76808291488973102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48391417968153316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31679493952731924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11233177954052252,
                                   0,
                                   0,
                                   -0.5311201236892934,
                                   0,
                                   -0.041995199915336373,
                                   0.28103128455434501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49842256401560164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20394554782215607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025098343302974446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1295842858047356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47972890142703467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14936890443822315,
                                   0.4602321364181215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075675423676990039,
                                   0,
                                   -0.22707576821666578,
                                   0,
                                   0,
                                   0,
                                   -0.20292317090203421,
                                   -0.15484502543413373,
                                   0,
                                   0,
                                   0,
                                   -0.52910515503373445,
                                   0.22071360396884077,
                                   0,
                                   0,
                                   0.22743049184183722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12306757166246551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018206944868685432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4153883877756484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39892099931993913,
                                   0,
                                   0,
                                   0,
                                   0.036355996217327401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17041175024159061,
                                   0.67026372014305458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055715773144976541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060203627905781244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34170591193288025,
                                   0,
                                   0,
                                   0.21930434563428461,
                                   0,
                                   0.05738487084652083,
                                   0,
                                   0.10414981981256535,
                                   0,
                                   0,
                                   -0.054524188743893739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9895954463052874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51593817028019273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63755675574498027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10268545101193589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14084291816986408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24845697761782953,
                                   0,
                                   0,
                                   0,
                                   -0.16179073466389693,
                                   0,
                                   0,
                                   0,
                                   -0.36781314093051998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10505437588993144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23802624115003798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43694385638348743,
                                   -0.6296589614021334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52305072377376627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30349697742025233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10557137188907287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16145387758827651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021362546786287073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090475442161687236,
                                   0,
                                   0,
                                   0,
                                   -0.010679767828431677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030794368315851944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087304780328456594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78043314712077649,
                                   0,
                                   0,
                                   0,
                                   0.94310659824163512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37476471051650179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58430134956885027,
                                   0,
                                   0,
                                   0,
                                   -0.2777270137936918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21181151669277587,
                                   0,
                                   0.32317422960508263,
                                   0,
                                   -0.22203157603596135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20050258928587783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18369835532946471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78035509473751352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21515698337648706,
                                   0,
                                   -0.063484285116610029,
                                   0,
                                   0,
                                   0,
                                   0.54691408399691954,
                                   0,
                                   -0.042689339546361033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55474639502760525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31618323639046791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11550892060526864,
                                   0,
                                   0.27396948026254059,
                                   0,
                                   0,
                                   0.15606506144433116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1017921139126723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35700362827737786,
                                   0.2678850380494161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46339684065677911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24056405199227945,
                                   0,
                                   0,
                                   0,
                                   0.33351284989181634,
                                   -0.64571472005945851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31086792388878037,
                                   -0.33807183905673344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33837539757017282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036355061508789671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62740078214984207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28924983315214203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085943470212356113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36820092815946764,
                                   0,
                                   0,
                                   0,
                                   -0.05082082084303477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2245234921655837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049618551695526369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41494311700101433,
                                   0,
                                   0,
                                   0,
                                   1.4815346789008561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11505799557806877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59235921056878149,
                                   0,
                                   0,
                                   0,
                                   0.16388648989963864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30307640632851252,
                                   0,
                                   0.075403811552330002,
                                   0,
                                   0,
                                   0.4646517456362147,
                                   0,
                                   0,
                                   -0.18163417365154461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51698734652757472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52876279237387758,
                                   0,
                                   0,
                                   0.36582858061499995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1031176996429342,
                                   0,
                                   0,
                                   0,
                                   -0.11264065073752083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56939226040705049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13761490566247292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76830813165291956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16155965416935397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0019575713569802144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44434369221904751,
                                   -0.14467312826169684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59541467462846986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53971089196690003,
                                   0,
                                   0,
                                   0,
                                   -0.1291543819775629,
                                   0.34516812293355992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54749889651715833,
                                   0.37664309782836269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38125725792664911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012207591479184654,
                                   0,
                                   0,
                                   0,
                                   -0.62649170923986186,
                                   -0.14278288207272033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25234879579854946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46480144291300718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018850410937352152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44598338927368897,
                                   -0.041311095206323825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010757296331401406,
                                   0,
                                   -0.15253608948628486,
                                   0,
                                   0,
                                   0,
                                   -0.43257717715405286,
                                   0.19383160164908753,
                                   0,
                                   0,
                                   0,
                                   0.13231932927831414,
                                   0.30533045875605919,
                                   0,
                                   0,
                                   -0.12678089930852579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22949804127456702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30292251897402567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49737842765986295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057463298104655398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61842764705588094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23707134164458718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35515312122783405,
                                   0,
                                   -0.26692007294954712,
                                   0,
                                   0,
                                   0,
                                   0.5042089653555808,
                                   0,
                                   -0.2786664110984316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66982241585547331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22879891176964803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39887332811335102,
                                   0,
                                   0.32118239029818502,
                                   0,
                                   0,
                                   0.32217924630304012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057734598879024449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05394352893207463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55504866660290686,
                                   0,
                                   0,
                                   0,
                                   0.46540000717375551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13215169358243853,
                                   0.26385149495498378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045373059420087791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40188630146619497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29955401526133718,
                                   0,
                                   0,
                                   0.31455305176539,
                                   0,
                                   0.085960070240935341,
                                   0,
                                   -0.15919528579585415,
                                   0,
                                   0,
                                   -0.018772539726864393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19214510553462547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016072064163879018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44403147109631552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32750042826325892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48644301646018995,
                                   0,
                                   0.78603515541331048,
                                   0,
                                   0,
                                   0,
                                   -0.37846869510013903,
                                   0,
                                   -0.226502309416755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52069653697687923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22752110253319777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30886633655652296,
                                   0,
                                   0.10395504257722689,
                                   0,
                                   0,
                                   -0.20835745390226967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44897463398752585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52747615254653324,
                                   0.48221323537836869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10399604693426237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30319681218961797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51995628791987469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088882117913378716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088467048182230862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017743007587326186,
                                   0,
                                   0,
                                   0,
                                   -0.28039370353687798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14655847049249227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49416723787914368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041972418066320773,
                                   0,
                                   0,
                                   0,
                                   0.067577070077769946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0083938034977869263,
                                   0.30591714849484974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083145709129272077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11664123352301237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35313130719464125,
                                   0,
                                   0,
                                   -0.13318115715637074,
                                   0,
                                   0.21741167444833748,
                                   0,
                                   -0.50355492615395048,
                                   0,
                                   0,
                                   0.43820304900886081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14356854382657042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29307961321871723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12253346914781045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35901636352720756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049171431147889605,
                                   0,
                                   -0.26071447366167666,
                                   0,
                                   0,
                                   0,
                                   -0.081311876060250629,
                                   0,
                                   -0.48690335847253952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33857861715972282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45220738559206242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42819248880423616,
                                   0,
                                   0.90881273469508361,
                                   0,
                                   0,
                                   0.14107791553358434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36941073546152958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094378556293690297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093568974412608932,
                                   0,
                                   0,
                                   0,
                                   0.12109828317429897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46892943420316008,
                                   0.30709186656997389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20069681298510694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15779535230939157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087715284845259797,
                                   0,
                                   0,
                                   -0.45406034935863687,
                                   0,
                                   0.15840136925153278,
                                   0,
                                   0.55205418872644596,
                                   0,
                                   0,
                                   0.21112634865603672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088187052740944863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74503737251464019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82304344515478489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69420086146840454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.009931728049422741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17468224910006419,
                                   0,
                                   0,
                                   0,
                                   -0.94735442970827943,
                                   0,
                                   0,
                                   0,
                                   0.35586154583337781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53838110405013562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25935715667749709,
                                   0,
                                   0,
                                   -0.1105654106818704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013402394434103022,
                                   0,
                                   0,
                                   0,
                                   0.22962446827318178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16716586314000303,
                                   -0.11345426562968813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71362045083501824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2468235789381808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085495268859129586,
                                   0,
                                   0,
                                   0.1971332113585417,
                                   0,
                                   -0.41703721766119511,
                                   0,
                                   -0.11645178838446234,
                                   0,
                                   0,
                                   0.30037300518745297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46449883331291864,
                                   0,
                                   0,
                                   -0.49341114611927372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44699105808179446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48595661666545797,
                                   0,
                                   0,
                                   0.53686715932414286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40986325514801036,
                                   0,
                                   0,
                                   0,
                                   0.17988584551688924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69189846502033692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1897059904216922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08648606391959611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0016892332495304294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077769711983530734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28229219681455875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30190820149073044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11982435011594285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11588099701205462,
                                   -0.4259365213733397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12188869609551603,
                                   0,
                                   0.060229930076691862,
                                   0,
                                   0,
                                   0,
                                   -0.37536885305517709,
                                   -0.28746306516043518,
                                   0,
                                   0,
                                   0,
                                   -0.48128538508658325,
                                   -0.019471797705409247,
                                   0,
                                   0,
                                   -0.271164644696817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096038357072044667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25132580676611094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35429120228085764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13273550784208391,
                                   0,
                                   0,
                                   0,
                                   -0.12442769913341355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045486519769803849,
                                   -0.3295822438268613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35629676920955211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36734878481712957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37715492402322914,
                                   0,
                                   0,
                                   -0.25114346525508269,
                                   0,
                                   0.46631491696143479,
                                   0,
                                   -0.208807018710328,
                                   0,
                                   0,
                                   -0.049213113612159951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60136685305748272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2547462166290766,
                                   0,
                                   0,
                                   0,
                                   0.19163181005199936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064433229257868679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36873767261432266,
                                   0,
                                   0,
                                   0,
                                   0.58008580152236744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22362427747812486,
                                   0,
                                   0.89843570275270046,
                                   0,
                                   -0.46535203062040675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081224982222971961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18535620794276317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03290492479953968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60153894444722134,
                                   0,
                                   0.81852277503707949,
                                   0,
                                   0,
                                   0,
                                   0.011127545080769963,
                                   0,
                                   -0.41819063737665174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19352333505069091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67938520059136953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043861220071396728,
                                   0,
                                   -0.15286908441027131,
                                   0,
                                   0,
                                   0.27887577835106547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27445640269382832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96373265832289745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57224825077547592,
                                   0,
                                   0,
                                   0,
                                   0.21713576299810561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16741613045118048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20572044303931419,
                                   0,
                                   0,
                                   0,
                                   0.63667221170944666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65256715372461338,
                                   0,
                                   -0.50615342659442986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022417412362565281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28365745795228114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34487454594093309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18001952293714263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40011880915944553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18560106773178542,
                                   0,
                                   0,
                                   0,
                                   1.1315542540152284,
                                   0,
                                   0,
                                   0,
                                   0.42220637335215377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93778110936241688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58779673521500575,
                                   -0.38273872085991095,
                                   0,
                                   0,
                                   -0.28574290344006431,
                                   0,
                                   0,
                                   0.23707612884377716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43538265293116329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13399887031265956,
                                   0,
                                   0,
                                   0,
                                   -0.018207271819465069,
                                   0,
                                   0,
                                   0,
                                   0.022759578506452799,
                                   0,
                                   -0.48927054685066806,
                                   0,
                                   0,
                                   0,
                                   0.16126247667474672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17298333814497413,
                                   0,
                                   0,
                                   0,
                                   -0.10464325615555424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40778092789645237,
                                   0,
                                   0.10451895467481195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.154335741697819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1039397944347889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53208296714304582,
                                   0,
                                   -0.58477418651549506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15530482014877217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071324529760276409,
                                   0.1078332408838498,
                                   0,
                                   0,
                                   0,
                                   -0.44415399056356375,
                                   0,
                                   -0.10720285388545492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33301303326613446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00096035325824199436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0055401921451378455,
                                   0,
                                   -0.059950703920339188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28784753613151459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079723243094541776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089844396813291927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.617577346806504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39784635724076844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069890762688765984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49084997324943697,
                                   0,
                                   0.24866063059873234,
                                   0,
                                   0,
                                   0,
                                   0.23173949618482928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040972714170694313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34522638404962647,
                                   0,
                                   0,
                                   0.32645733297308016,
                                   0,
                                   0,
                                   0.044843544258522244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25443254563323076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16136569670440926,
                                   0,
                                   0,
                                   0,
                                   0.082576050260091294,
                                   0,
                                   0,
                                   0,
                                   -0.52276034891630996,
                                   0,
                                   -0.34351179506748175,
                                   0,
                                   0,
                                   0,
                                   0.014091280454354704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15470553407579093,
                                   0,
                                   0,
                                   0,
                                   0.1260199537927881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10096426673355506,
                                   0,
                                   -0.48234115216200985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022380715527747765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57512177176685997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37416166502708964,
                                   0,
                                   -0.19593883715989346,
                                   0,
                                   -0.044625014716792678,
                                   0,
                                   -0.2293637395722033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0069888950191085153,
                                   0,
                                   0,
                                   0,
                                   -0.83420359288650681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30346185611815468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50703600728672027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38161132262520064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13542081320279553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8204528764250284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38995120945672734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37790562457911536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68135048701192558,
                                   0,
                                   -0.43778763543481208,
                                   0,
                                   0.72549608417819966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45186236767101651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16128682476524514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47952017058114998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4296917273779654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079175226724932241,
                                   0,
                                   0,
                                   -0.035287536054141463,
                                   0,
                                   0,
                                   -0.090480342573712985,
                                   0,
                                   0,
                                   -0.03887423962030901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051927291183282501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086551185330085489,
                                   0,
                                   0,
                                   0,
                                   0.52964051475254437,
                                   0,
                                   0,
                                   0,
                                   0.27118784354860515,
                                   0,
                                   0.17936149662272197,
                                   0,
                                   0,
                                   0,
                                   0.035646547812030943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18296426518503364,
                                   0,
                                   0,
                                   0,
                                   0.19061624874954941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40377490660175924,
                                   0,
                                   -0.41456005758165343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43204340324356716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52741978684572666,
                                   0,
                                   0,
                                   0,
                                   -0.12126096934571376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43372893279467617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17634669894907329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99694914986971339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31873900908346464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31851348838093418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30235276662864219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30793625333813829,
                                   -0.67815481372403819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19922543222566094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47273596170060483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0072818356087438613,
                                   0,
                                   0,
                                   0,
                                   0.54208421429497233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17428400362259977,
                                   0,
                                   0,
                                   0.60701997714139611,
                                   -0.66524759369664399,
                                   0,
                                   0.0093995298836313732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29968374658673402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033132897349213292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31212831283608988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6325937528649711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73671938999429309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061169797989461011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63765376720097722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31088481344158519,
                                   0,
                                   0,
                                   -0.24425929616412592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33138089994030417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3056324441389075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10354723232554233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52163559840489282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12066464551784666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64467657607865669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21208615412626888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10160612792724956,
                                   0,
                                   -0.35486947237571875,
                                   0,
                                   0,
                                   0,
                                   0.010146881641122804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11070498717772059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.4225617195248019,
                                   0,
                                   0,
                                   0,
                                   0.11384508661138559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39406238620792772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27424425120931101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18252402559103276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039053668685430656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17802887402114961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14593406064015188,
                                   0,
                                   0.025785782198861656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11386969409251935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28164040800612922,
                                   -0.13945698454408886,
                                   0,
                                   0,
                                   0,
                                   0.10068035304153221,
                                   0,
                                   -0.086804583341906202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68564497353165699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17884465814027217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25078927333499645,
                                   0,
                                   0.50194314013776009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088450968905306335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68672657642977775,
                                   0,
                                   0.28780877969340424,
                                   0,
                                   0.63338179625628044,
                                   0,
                                   0.35174723446475226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0142412557001136,
                                   0,
                                   0,
                                   0,
                                   -0.22022286113214962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27027893477699377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37415324062159122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091183224623667708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082602107128565513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25058492053800968,
                                   0,
                                   0.17761549965166748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59472649652570087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31533156213296742,
                                   0.15289447952693538,
                                   0,
                                   0,
                                   0,
                                   -0.088521353171306286,
                                   0,
                                   -0.61031490696864865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026138170392479065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064643504839773783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19272816564248518,
                                   0,
                                   0.00023243670373949976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72865464726278073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57568548511560425,
                                   0,
                                   0.84946263445880865,
                                   0,
                                   -0.23943907096560516,
                                   0,
                                   -0.42582121998169553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20625069752937975,
                                   0,
                                   0,
                                   0,
                                   0.54937187086951988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67349880059920508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36519159929860373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28161546005965582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35605333816271428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0028882384252282567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12906629591112198,
                                   -0.60262131304572941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091391056116681926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42259176762977085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29864530281044177,
                                   0,
                                   0,
                                   0,
                                   -0.16719704465725485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03621862010763216,
                                   0,
                                   0,
                                   0.23127116329443306,
                                   0.15880250613157668,
                                   0,
                                   0.4035188619517539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92061466083956289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22824488763036116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6075638862394076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15837276322911872,
                                   0,
                                   0.031703612074397217,
                                   0,
                                   0.069787079083232464,
                                   0,
                                   0.58899527566032539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091165709491848754,
                                   0,
                                   0,
                                   0,
                                   0.52443080454053459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58953453056962535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41091640705955534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16198578662183744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056720383338718178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38163899737165413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16764859658029085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86622546238947606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33165013166456292,
                                   0,
                                   0.49325074453610068,
                                   0,
                                   -0.18738334729887027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35380587855803636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45575466961741251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42135831659520717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18677023024418765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41304675812506586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020361044204130849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45921159212954915,
                                   0,
                                   -0.10054419912487429,
                                   0,
                                   -0.13061145830695561,
                                   0,
                                   0.44882591215862505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36574291112991686,
                                   0,
                                   0,
                                   0,
                                   0.34544441393717423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74844830227036607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37466216314057804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030562968929857433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20015018611919905,
                                   0,
                                   0,
                                   -0.15526411454976646,
                                   0,
                                   0,
                                   0.045050787535551404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32188494126796713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20876487583849443,
                                   0,
                                   0,
                                   0,
                                   0.57062133606879117,
                                   0,
                                   0,
                                   0,
                                   -0.4285859233238492,
                                   0,
                                   0.31479195696774986,
                                   0,
                                   0,
                                   0,
                                   -0.03034114234748668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27004153004261122,
                                   0,
                                   0,
                                   0,
                                   0.14853984799944656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12294320858709874,
                                   0,
                                   0.17952409901184802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18700556804283572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046104242878237618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40243714375406087,
                                   0,
                                   -0.58945101821204915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41383135938088889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0021584540250723788,
                                   0.30808800088405819,
                                   0,
                                   0,
                                   0,
                                   0.15341963948001558,
                                   0,
                                   -0.3228531146807061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18999561519099653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2381949217970053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023289848181201923,
                                   0,
                                   -0.033729527090206241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51854312065020325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050913078920745231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083304686563717617,
                                   0.18028291805609559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27581580032351782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018257727826173593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66410032713080003,
                                   0,
                                   0,
                                   0,
                                   -0.60385646093625878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58524430935591443,
                                   0,
                                   0,
                                   0.36278421158193108,
                                   -0.46487242267711443,
                                   0,
                                   -0.15566478147968427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13349974706862153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2776380650041364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015719980386160369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73573802581368419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66036891614503146,
                                   0.13334057087233714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12597159750978934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24781685884616733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29695557425539748,
                                   0,
                                   0,
                                   0,
                                   -0.40935802137649363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44191529306306226,
                                   0,
                                   0,
                                   0.63907476811573161,
                                   -0.42253693398505787,
                                   0,
                                   -0.24947588853159558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32357482484745109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12103233105854685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21888908245024447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18737068872779353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24031236442218462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35634618301388504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024887426502684259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22103176677050351,
                                   0,
                                   0,
                                   0,
                                   -0.82294344873441094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074409772291779808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48018058419914567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37758407645683867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069113685364624228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03964516125873066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11321720097014364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19803183469892743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55930362848707793,
                                   0,
                                   0.093523378280029157,
                                   0,
                                   0,
                                   0,
                                   0.2229862297033377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44405366740713303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49305115334523925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071482612505779794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91491757754916059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34559563947011296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93525040488236844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77297982444274405,
                                   0,
                                   0,
                                   -0.34627874025362393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11852342357502729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18258182586787544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085246209498906045,
                                   0,
                                   0.26478891446068226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052167513697606804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24991544917214809,
                                   0.58992304563656128,
                                   0,
                                   0,
                                   0,
                                   -0.035531331282631771,
                                   0,
                                   0.33709534766518012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2065470026966103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54280880042156976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086114022703418669,
                                   0,
                                   -0.12837826315107104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48883507809815907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35298979744713055,
                                   0,
                                   0.05522290212290501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040554030523866483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34840487158396183,
                                   0.1430380747529621,
                                   0,
                                   0,
                                   0,
                                   0.40113420378482534,
                                   0,
                                   -0.34757018491371844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079446927400463982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13946830087024073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35013519435723583,
                                   0,
                                   -0.24459531312004823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50329486903074028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29670633942470248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20092303439692499,
                                   0.28640381143140681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26277896881388579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36720594360209019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37919149056021767,
                                   0,
                                   0,
                                   0,
                                   -0.11347435890099614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027445614453552925,
                                   0,
                                   0,
                                   -0.55218482017476433,
                                   -0.2850032205756774,
                                   0,
                                   0.56297743255081667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011993975238096879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33535488940245317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34973517201971804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30437875730923597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52609329673409932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045180254731177719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32339795732843502,
                                   0,
                                   0.74198686937003855,
                                   0,
                                   0.39282691337304809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23299831203382432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21702734045742048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01353075046100162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.748145972454487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42561417775608362,
                                   0,
                                   0,
                                   -0.012981983289551143,
                                   0,
                                   0,
                                   0.063606144615356908,
                                   0,
                                   0,
                                   0.48686336323793006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34568102051405714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20510887810921835,
                                   0,
                                   0,
                                   0,
                                   0.055438384965857637,
                                   0,
                                   0,
                                   0,
                                   -0.064253061160403316,
                                   0,
                                   -0.11751799554858373,
                                   0,
                                   0,
                                   0,
                                   -0.052294534224886828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16382913568835397,
                                   0,
                                   0,
                                   0,
                                   0.64545229218313038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046913738858039261,
                                   0,
                                   0.35618281221560349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030363833928912346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24221040360272608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0018129906265156211,
                                   0,
                                   -0.2551074267039507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3258900058311619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31478908785084125,
                                   -0.029289523157259828,
                                   0,
                                   0,
                                   0,
                                   0.51993737224753811,
                                   0,
                                   0.14747661242656757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080178670852623493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048678913633119887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47800319518466727,
                                   0,
                                   0.37513618810142213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26884085319591522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54961119802965874,
                                   0,
                                   0,
                                   0,
                                   -0.082769980360316908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35452777129502056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57122797706890172,
                                   0,
                                   0,
                                   0.40842369495268616,
                                   0,
                                   -0.53160056781361731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13484933072921126,
                                   0,
                                   0.21214775859048635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082760527478228624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27203497883336458,
                                   0.60886897349603053,
                                   0,
                                   0,
                                   0,
                                   0.065891732759397664,
                                   0,
                                   -0.14940256798683196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02275048144286216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30629289846710483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087748998707700449,
                                   0,
                                   0.27191984614062137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034019816045515718,
                                   0,
                                   0,
                                   0.028837841724876408,
                                   0,
                                   0,
                                   -0.3948646685645365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10687951971333827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2034816242728337,
                                   0,
                                   0,
                                   0,
                                   0.046008605484932998,
                                   0,
                                   0,
                                   0,
                                   0.24476349671895417,
                                   0,
                                   -0.52468915520836945,
                                   0,
                                   0,
                                   0,
                                   -0.05389077032616002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48244188797967014,
                                   0,
                                   0,
                                   0,
                                   0.42970676171166194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083406319285082089,
                                   0,
                                   0.029288880264469679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15434865274149515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86388212323922464,
                                   0,
                                   0,
                                   0,
                                   0.38781431896508967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50994016860910163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20701844355065896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18810510601622435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99250326531246968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37857932352167784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20296637486617367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22413890335955608,
                                   -0.38671939762951385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60650195181796385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50662004198325428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20191787419291377,
                                   0,
                                   0,
                                   0,
                                   0.023120047934224092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042673830158506204,
                                   0,
                                   0,
                                   0.23066459840028142,
                                   -0.23673726086289745,
                                   0,
                                   0.18873455006143647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099134233744858052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69893085215592698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80890087080927586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14361195683104583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022558439427139705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24526882828508856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2195578879314512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51432693847547384,
                                   0,
                                   0,
                                   -0.58920634136663752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53435592150019839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46198995671199222,
                                   0,
                                   0,
                                   0.19395254929002367,
                                   0,
                                   0,
                                   -0.36771767725962623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026517528586620376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19303833151118993,
                                   0,
                                   0,
                                   0,
                                   0.21653343239600234,
                                   0,
                                   0,
                                   0,
                                   0.11037310866780378,
                                   0,
                                   -0.07595515470631628,
                                   0,
                                   0,
                                   0,
                                   0.18199943443809394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45993475909241238,
                                   0,
                                   0,
                                   0,
                                   -0.010941998932999613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51047019972166807,
                                   0,
                                   0.048034212346123997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057058488859229664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78440171012079574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15508884545305776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071752985902441169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036277912944859339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12259321670404312,
                                   0,
                                   0.011513422730183159,
                                   0,
                                   -0.024723428684340808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51889854396544455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18222188933961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98645327636309155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50712305978408345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18933767789349398,
                                   0,
                                   0,
                                   0.27274163367900855,
                                   0,
                                   0,
                                   -0.2993702135245726,
                                   0,
                                   0,
                                   -0.062696328220176983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19283260440791816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14822626867867056,
                                   0,
                                   0,
                                   0,
                                   0.27859017443165535,
                                   0,
                                   0,
                                   0,
                                   0.23596794420685235,
                                   0,
                                   -0.19032576952736424,
                                   0,
                                   0,
                                   0,
                                   -0.38630206552763025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23326515249963517,
                                   0,
                                   0,
                                   0,
                                   0.0024323422895010938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035548416697573484,
                                   0,
                                   -0.13684572641389323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61623670460596258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60840412028005286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14262368127807495,
                                   0,
                                   -0.35379420894872238,
                                   0,
                                   0.15540577000633152,
                                   0,
                                   -0.46281220106811838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33853644044234865,
                                   0,
                                   0,
                                   0,
                                   0.27986319823765515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6809368669682192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80926898802082636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13258891344030405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028844575262431345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14959319069964744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33445757638160878,
                                   0.11911089161985741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58162205182917392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4165490346699014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27441893557130953,
                                   0,
                                   0,
                                   0,
                                   -0.26243848421629384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46776527396663686,
                                   0,
                                   0,
                                   -0.061007952045993831,
                                   -0.36149359060246489,
                                   0,
                                   0.22635417581506273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3173931421354253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66089743204905071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19079177017837862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11703921863510264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18391712741196267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23135944660010638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58835608489665037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63516226630885764,
                                   0,
                                   0,
                                   0,
                                   0.24398306023343241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23114042828661377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26106794373645081,
                                   0,
                                   0,
                                   0.0126641585691004,
                                   0,
                                   0,
                                   0.082580869127879403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57068316643628747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.009935544901648094,
                                   0,
                                   0,
                                   0,
                                   -0.014139023739642556,
                                   0,
                                   0,
                                   0,
                                   0.23842674295990821,
                                   0,
                                   0.076499163356299804,
                                   0,
                                   0,
                                   0,
                                   -0.46538381884929692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28459043901620174,
                                   0,
                                   0,
                                   0,
                                   -0.010818595113766184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20955902603536872,
                                   0,
                                   0.2887529058738052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33346982738161424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57803211660950993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18520067804829263,
                                   0,
                                   0.55071065031507238,
                                   0,
                                   -0.79481246460072119,
                                   0,
                                   0.44864541794434792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30022820149815499,
                                   0,
                                   0,
                                   0,
                                   -0.32645867169424281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36883807927205531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10331283508049735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64384429073715421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15959153824874736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14841295817734959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079635334095564947,
                                   -0.52698818164017391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20508411531237275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23192789676284714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66178323786201576,
                                   0,
                                   0,
                                   0,
                                   -0.70855349487031016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3206853718423528,
                                   0,
                                   0,
                                   -0.4469884128182573,
                                   -0.11414462048549852,
                                   0,
                                   0.38850572382485005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49647683264061238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14090202611980734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47531219913597289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6822094538825304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27346842934229687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23438748265348319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83482771586327575,
                                   0,
                                   0.56288388792925159,
                                   0,
                                   -0.072307148332217491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02052661621474583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3778501171685878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12208386961453033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72199192247189359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30698188811922944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46772010183019863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19655722916561374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22567712380948551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49503377206640348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18347691784528319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18615358816376293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14429805327722114,
                                   0,
                                   0.3677126738107564,
                                   0,
                                   0,
                                   0,
                                   -0.22800258613772617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4126474361910949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29363687998560872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71712844735517245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.005852766735307692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098235827660793959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17822010258292859,
                                   0,
                                   -0.51272261300212407,
                                   0,
                                   0.26170362225710658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48946688740174671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1230042790802175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17149377447653538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40702978423025488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31359000416452559,
                                   0,
                                   0,
                                   -0.21180278014837514,
                                   0,
                                   0,
                                   0.2416709785822091,
                                   0,
                                   0,
                                   -0.15630436339531065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30232714989418863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046856838317155092,
                                   0,
                                   0,
                                   0,
                                   0.18884953981104638,
                                   0,
                                   0,
                                   0,
                                   -0.31650515322400397,
                                   0,
                                   -0.23829442853188221,
                                   0,
                                   0,
                                   0,
                                   -0.557348531448426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01548188385258622,
                                   0,
                                   0,
                                   0,
                                   -0.33318372606941415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26961706548732756,
                                   0,
                                   0.22456953289245848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20265536144892424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75172839676881931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10284318203228812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41130886296610464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55870336220473071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054248502758216938,
                                   0,
                                   -0.0057598221887936452,
                                   0,
                                   0.22855910163099427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4667154235546736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21251009451667235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63099551279395905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21897152370567097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76522741989840115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05423656205994333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062376960334943277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56115536393029364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65619679788352103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2842091269715703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38725195554638397,
                                   0,
                                   0,
                                   0,
                                   -0.013378742959196777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1294605516879781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45917993899419901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10467311378276464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061525452910055962,
                                   0.50615296448802205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32387350986558328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10326940032042886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63466351589222425,
                                   0,
                                   0,
                                   0,
                                   -0.37627505737469302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18289569258532207,
                                   0,
                                   0,
                                   0.031056798246572426,
                                   -0.25260530379568358,
                                   0,
                                   0.68842564402281936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21421616032539098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093450463644663528,
                                   0,
                                   0.17028467861952012,
                                   0,
                                   0,
                                   -0.22174744500585805,
                                   0,
                                   0,
                                   -0.23747764285260173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057021801242628983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85924528787764398,
                                   0,
                                   0,
                                   0,
                                   0.053803774281246192,
                                   0,
                                   0,
                                   0,
                                   0.016119459017603928,
                                   0,
                                   0.09350413924017896,
                                   0,
                                   0,
                                   0,
                                   -0.070687702881335149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2933507551896351,
                                   0,
                                   0,
                                   0,
                                   -0.0056549559720318887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0012448779281964018,
                                   0,
                                   0.099881193619993605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10451178073358086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094836992639500656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20925970628150231,
                                   0,
                                   0.14221826306060786,
                                   0,
                                   0.38620451448584792,
                                   0,
                                   -0.12167706281713125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9644129993757472,
                                   0,
                                   0,
                                   0,
                                   0.22331118868835281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21773816708294141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077629064693689007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21855205027482133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26704536494434378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18832049325148215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10877983135360351,
                                   -0.44654054242287017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074853725368525803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19033042949227785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15544720548613844,
                                   0,
                                   0,
                                   0,
                                   -0.22723981578238392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41411295814351651,
                                   0,
                                   0,
                                   -1.0704780512100955,
                                   -0.6932216791746928,
                                   0,
                                   -0.43060705465812632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42664599639285888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13372252519914976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23717575256659637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51403198777163839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5990259104957234,
                                   0.3407705148084052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010037005305863786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55318135562198512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14196604367666948,
                                   0,
                                   0,
                                   0,
                                   0.17385583999378484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15165981673177578,
                                   0,
                                   0,
                                   0.089819143867099452,
                                   -0.21088544827878378,
                                   0,
                                   -0.046913532548556743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3585808403056524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19748920932244335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071614157123874478,
                                   0,
                                   0,
                                   0,
                                   -0.41650326277018346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13719065889820464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2125123220959297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96292123494553672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11317468449931238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17088797961125313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2667891854307598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34249894948296872,
                                   0.12433686903852401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38109559075000032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042409188734809526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54106608465253003,
                                   0,
                                   0,
                                   0,
                                   -0.27243693979111439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74509814607476565,
                                   0,
                                   0,
                                   0.18293252949526173,
                                   0.56690028117095914,
                                   0,
                                   -0.22545522841568552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56605172778449886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021856150141436437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35851356234841092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26137954624022502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33484459659887705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17452245158756749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53466313069258131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49715680672219148,
                                   0,
                                   0,
                                   0,
                                   -0.22494094081289556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27738382756375107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47199940689602554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30332900165269883,
                                   0,
                                   0,
                                   0,
                                   0.18343202815014922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25072657104527973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59673472382937043,
                                   0,
                                   0,
                                   -0.4822910155114451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56132266061129799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46551384453426525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4260281980531273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091453315324682094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2821777683078347,
                                   0,
                                   -0.24360037873949533,
                                   0,
                                   -0.011729338581271493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67560350627640031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4103515537765704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53390490430715609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30099828041242327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59932279976116587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083234694585222091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087630990070182518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39139896314777606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27144810961746413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025474928082872921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78787926732550928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25385976027204066,
                                   0,
                                   -0.18395106440295048,
                                   0,
                                   0,
                                   0,
                                   -0.178678028796461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083091809653051185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01850007004924805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03327413049513625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44013186017791928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37920742826484144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083808866722526923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0067698608410438,
                                   0,
                                   0,
                                   0.26049638419776461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81447569675456177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51551065746558067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30949440710350939,
                                   0,
                                   0,
                                   0,
                                   0.54966864914054003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3563706376540236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32009873892455831,
                                   0,
                                   0,
                                   0.32689924459997943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1186396789320539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38746238838407432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23953030434028322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4208206187195232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094068445631220118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0047028756439441433,
                                   0,
                                   0,
                                   0,
                                   -0.36835862042946665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6758503544323109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30218327876229217,
                                   0,
                                   0,
                                   0,
                                   0.85133534331868832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67732947092693518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85188911108218679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050112926363339881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28990423878606691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31094340089245737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58656733217163515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28892326383826933,
                                   0.16578350897102326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90243208102796713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71469217282817243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33369530394757335,
                                   0,
                                   0,
                                   0,
                                   0.11956056385414125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00066179135923092117,
                                   0,
                                   0,
                                   -0.05790366045207776,
                                   -0.6118839780112646,
                                   0,
                                   -0.45962375657251964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050534847261423342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056998766578016127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69606095139833735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20884000240432943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13835588934685225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14017279782689887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10528381434782612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63674904492340656,
                                   0,
                                   0,
                                   0.19463309296125963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88056459225874684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32096627180115062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28778375701056552,
                                   0,
                                   -0.1067446475335202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1853748303486123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14338679409070618,
                                   0.01967228477711272,
                                   0,
                                   0,
                                   0,
                                   0.28381050802107299,
                                   0,
                                   0.17192717537516217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42444986332091306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10912646827161787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16334077092660315,
                                   0,
                                   -0.6469948256841177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039521905250079009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45037438023464316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54160762193858192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41704865841780314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4070564525045326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19597544575088452,
                                   0,
                                   0,
                                   0,
                                   0.13116365480091646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32715027403326796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36865336156019446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18998995268593666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23309837062930258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24702596716257075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34501744044306892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4053800911396413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22682682490258854,
                                   0,
                                   -0.37012368988828315,
                                   0,
                                   0,
                                   0,
                                   -0.47888790119116631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10722037737610621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43249203892586191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45027898832090063,
                                   0,
                                   0.89490815982944649,
                                   0,
                                   -0.18430497887599101,
                                   0,
                                   0.50322344750795667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12072082691297936,
                                   0,
                                   0,
                                   0,
                                   -0.57453294035284963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073948168175458129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5172736562371627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92161519791989055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025602330793285416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24741505856117152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96472732922352633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54909915422478706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46671842655515283,
                                   0,
                                   -0.39431197118720568,
                                   0,
                                   -0.021575782985573076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67914766075304667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12468770471866851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093237856233094524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52605057092533691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33417988707532109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82317711426631945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37900711112055435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094182544155234152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055603303105791785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2176018329769879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011326327458329715,
                                   0,
                                   0,
                                   0,
                                   -0.17274881716757151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29908188191023294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14549635984457254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46451933715945071,
                                   0,
                                   -0.022123236441938053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035296167555885438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018133912924285178,
                                   -0.15293843295610737,
                                   0,
                                   0,
                                   0,
                                   0.4435810602496893,
                                   0,
                                   -0.06473228253063365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2406213285572566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39159795947414328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56953207047505694,
                                   0,
                                   -0.032086511724829514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24753649878452635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47561377154441808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35467287157911165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0067065455483691014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44999663075833929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023407111627257754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18402836229748237,
                                   0,
                                   -0.091845794060708585,
                                   0,
                                   0,
                                   0,
                                   -0.56269833039318762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15717200414521257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23759476138560362,
                                   0,
                                   0,
                                   0.24221464661205755,
                                   0,
                                   0,
                                   -0.31510375769255533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18521798210882473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0042281465202483326,
                                   0,
                                   0,
                                   0,
                                   -0.35752084420703234,
                                   0,
                                   0,
                                   0,
                                   -0.049914934754399072,
                                   0,
                                   0.32801354653863402,
                                   0,
                                   0,
                                   0,
                                   -0.27281368045120347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15222325524027219,
                                   0,
                                   0,
                                   0,
                                   0.42219846526574029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37105741533044617,
                                   0,
                                   -0.089459901444077269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30302450303938755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40265588900378285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43053754301003017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53357309073836368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35973707465775884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087002092010612569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054527585266449609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25829835252407762,
                                   0,
                                   0.36767765603015357,
                                   0,
                                   0,
                                   0,
                                   0.032694940273797907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15772816716383281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12554801461901632,
                                   0,
                                   0,
                                   0.61753383599144518,
                                   0,
                                   0,
                                   0.38151251357719751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11996385955994364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12281346753136706,
                                   0,
                                   0,
                                   0,
                                   0.19875382575927375,
                                   0,
                                   0,
                                   0,
                                   0.41948921264370909,
                                   0,
                                   0.032728115359909028,
                                   0,
                                   0,
                                   0,
                                   -0.074122953827854499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31420723032371439,
                                   0,
                                   0,
                                   0,
                                   -0.15084161006071423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0021717566905313963,
                                   0,
                                   -0.10532868450621855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27063912538548918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27474386618685193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88795919131442991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16517916928391468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72414351892813023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9209583232096672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024980367639135942,
                                   0,
                                   0,
                                   -0.65470857388645542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39735884230638768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55286237799834803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59616566059214049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17288682822449236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20971334052863569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71194845521765238,
                                   0,
                                   0.43546786176290248,
                                   0,
                                   0.51273609589062397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51516264303145798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76161219253196188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33506757298838852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090180220509144413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26748884815491841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078857573775754933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40622911660305527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19873801285041579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24689546079858626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060324568482579582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29178404859211315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4352438797455791,
                                   0,
                                   -0.0040299966603256909,
                                   0,
                                   0,
                                   0,
                                   0.26237097566106615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6174433029789772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066554003858000393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38931083180611442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60172596615822893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93303419951942435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35532426365512676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052071492637359107,
                                   0,
                                   0,
                                   -0.61413781957395008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2482050514635134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33487693204030555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065191988961472047,
                                   0,
                                   0.08346561928124327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18428802624910939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51852006440169562,
                                   -0.16741455086905871,
                                   0,
                                   0,
                                   0,
                                   -0.21507565520905675,
                                   0,
                                   -0.15219009085060406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11213430470411097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57349295535924483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36346445801972166,
                                   0,
                                   -0.052859475153022528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3015867621447243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61836341973762154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34903334647033224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065776718645429763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25433021151100144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33470600221795616,
                                   0,
                                   0,
                                   0,
                                   -0.17240880913995285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44055021335643796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31410433271421973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13393455812303071,
                                   0,
                                   0.27617910835082565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50096576974193818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41165797029784168,
                                   -0.2424368266222304,
                                   0,
                                   0,
                                   0,
                                   0.028271328919966386,
                                   0,
                                   -0.41089446567568266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27506664177833601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051658180895291256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22368921338792036,
                                   0,
                                   -0.17297364346923844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51379789651057661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037134007680118222,
                                   0,
                                   0,
                                   0,
                                   0.41047793992247261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61624643433337789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22009833465776518,
                                   0,
                                   0,
                                   -0.37139965415196491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046762725558998394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27290045510894978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91015916646179251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72988008802298909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60938567194791027,
                                   0,
                                   -0.16486357864563433,
                                   0,
                                   -0.64138424984676679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52945281977123171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045396445093333015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031029494703676899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48223437182051965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6816418596228786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20286410027997692,
                                   0,
                                   0,
                                   0,
                                   -1.5140873364898484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51903991550337092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43178534974019023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38559274862795062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64703860075137998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28559182340577566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38170440340479206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25674187073016608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34318443227525786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42912936497302084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2561754020155228,
                                   0,
                                   0,
                                   -0.77729315476308014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10602908945473552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13505870640284465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73603867458039163,
                                   0,
                                   0.6045732121984132,
                                   0,
                                   0.34675663585762784,
                                   0,
                                   -0.39875076923421643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4458615987699357,
                                   0,
                                   0,
                                   0,
                                   -0.45881451683730834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12374122306537594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26043665235113544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26856763761006064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43548659471572704,
                                   0,
                                   0,
                                   0.31561422743129969,
                                   0,
                                   0,
                                   -0.27139190127304424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039547156797871685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080774488804233713,
                                   0,
                                   0,
                                   0,
                                   0.22571961387570874,
                                   0,
                                   0,
                                   0,
                                   0.036452696081583864,
                                   0,
                                   -0.014275366247563606,
                                   0,
                                   0,
                                   0,
                                   0.41409518533854628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15816972497037551,
                                   0,
                                   0,
                                   0,
                                   -0.034968014500406173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34651475741910853,
                                   0,
                                   0.49060433204254827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13429356697749334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04403637633543344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42585113914952866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081237526016289835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1796916132406127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21502809785427385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050191024715151022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095828613821635433,
                                   0,
                                   -0.59481764111785385,
                                   0,
                                   0,
                                   0,
                                   0.44349684314564192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41156551388702556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013591615982443211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64531854776683917,
                                   0,
                                   0,
                                   0,
                                   0.60719025297290363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39497432773969487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17267223659354733,
                                   0,
                                   0,
                                   -0.16993768185467695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21912149700147157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35855896587643621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35289168978621521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052153008116987545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54746146040614918,
                                   0,
                                   0.066220474503627474,
                                   0,
                                   1.0465458821508147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42741173689073481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12697928911586748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098081177266982733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14202864518517583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0090958410935839118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69589349671802569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39474522515378996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044092689704765944,
                                   -0.25098202570247952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46993983645598025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14620069772901209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51732278538904963,
                                   0,
                                   0,
                                   0,
                                   0.71709540508309511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070132366830890608,
                                   0,
                                   0,
                                   -0.28773368244127556,
                                   0.26405134006653502,
                                   0,
                                   0.80819107240471022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17135820998849083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40805958297375261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41835022062667748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30383761635146261,
                                   0,
                                   0,
                                   0,
                                   0.34669014275515786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38559282561855579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36997849494210244,
                                   0,
                                   0,
                                   0.57175678992011614,
                                   0.1136402086422576,
                                   0.023346520654556752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2409474096898567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71798225669506843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17321606455100158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16012376825716812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.4469782864581151,
                                   -0.62880585976463632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15968876981376803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31747739126512708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32436371977860395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59627835420125519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064031964007451189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17564450916473801,
                                   0,
                                   0.38703691152629777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018143663336374689,
                                   0.03083437257480541,
                                   0.53046976019203784,
                                   0.3356825599339141,
                                   0,
                                   0,
                                   0,
                                   0.61935163620079015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52227083998837531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40545368655576591,
                                   0,
                                   0,
                                   0,
                                   0.11825009139657636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075773741484722004,
                                   0,
                                   0,
                                   -0.15643623195725642,
                                   0,
                                   0,
                                   0,
                                   -0.28267395562997927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19161911208767018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057306126241648998,
                                   0,
                                   0,
                                   0.29107586988476097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18543743629189502,
                                   0,
                                   0,
                                   -0.21575824640658844,
                                   0,
                                   0.3372169314038081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21287782474132616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095587188633025566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71149845872280659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34631647894676876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48080672113128409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56149921161307526,
                                   0.17053122025828094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01588475965624947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54942009988296003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34978259454318356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018960114509817688,
                                   0,
                                   0,
                                   0,
                                   0.26235886503868511,
                                   0,
                                   0,
                                   0.21674148549980796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012479642027460006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16104184908954952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15669332856986326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24452712853643099,
                                   0,
                                   -0.02775349186243771,
                                   0.31290339161588632,
                                   0,
                                   0,
                                   0,
                                   0.4084582707025235,
                                   0,
                                   -0.3395878217696241,
                                   0,
                                   0,
                                   0,
                                   -0.23155414962712484,
                                   -0.52976395247565189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24143514259082638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069744133454494123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37329373081070583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33767296245468814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.058493271249842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45825411792536686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14768362660623321,
                                   0,
                                   -0.93272126393180499,
                                   0,
                                   0,
                                   0,
                                   0.51497751811909476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17828754699779142,
                                   0,
                                   0,
                                   0.0063866846498503924,
                                   0,
                                   0,
                                   0,
                                   -0.63810872367412763,
                                   0,
                                   -0.0042144168737515142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024127981638549706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36900193310360146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37248728954470606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53430411686751644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15466224236120343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40763166831584857,
                                   0,
                                   0,
                                   -0.49469507207676455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28745568532832833,
                                   0,
                                   0,
                                   0.271886981598922,
                                   0,
                                   -0.13764637343263114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18072622613469005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30713981592316775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49159140951049735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1450311148835923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27426953488156552,
                                   0,
                                   0,
                                   0,
                                   0.36717919193144827,
                                   0,
                                   0,
                                   0.053427892214652099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096546537138590183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19119263580691429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14218655717731854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12712108982084486,
                                   0,
                                   -0.58568935173699344,
                                   0.48245987382252103,
                                   0,
                                   0,
                                   0,
                                   -0.24972318120597131,
                                   0,
                                   0.065956498672618172,
                                   0,
                                   0,
                                   0,
                                   -0.068841898869123008,
                                   0.19831317137150772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13516539027220095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13062599895870777,
                                   0,
                                   0,
                                   0.14085482629153831,
                                   0,
                                   0,
                                   0,
                                   0.24578172480542962,
                                   0,
                                   0.64159473383738708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21093968413498715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021623359670670306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3421353999563852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5736066209873194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35708566281857762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44131407549256285,
                                   0,
                                   0,
                                   0.34073923758856783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13974836181411421,
                                   0,
                                   0,
                                   0.55769290221370194,
                                   0,
                                   -0.30753322126947702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30647923952461187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18262498735263313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030126428538088841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091169162516044136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17377977215435852,
                                   0,
                                   0,
                                   0,
                                   -0.23776722973142592,
                                   0,
                                   0,
                                   -0.03913912583394575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051765304912914326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020556076328435507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66389010078492594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14163778017428832,
                                   0,
                                   -0.36187774265333478,
                                   -0.23929226121381789,
                                   0,
                                   0,
                                   0,
                                   0.4550935532324426,
                                   0,
                                   -0.092112594629515918,
                                   0,
                                   0,
                                   0,
                                   0.17813299186997564,
                                   -0.087334385763728012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068206461629553336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92467802371763019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073983587087740679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58687050477423908,
                                   0,
                                   0,
                                   0,
                                   -0.41401580703773022,
                                   -0.26151201663082557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049161739775386709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37739119481465871,
                                   0,
                                   0,
                                   0,
                                   0.40881078198752513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50591781432708249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68415453070820664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43595977059818369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014980720549394692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0091636153307160101,
                                   0,
                                   0,
                                   0.35635691000942654,
                                   0,
                                   0,
                                   0,
                                   -0.52520565839994537,
                                   0,
                                   0.09199615741560474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18535436039882525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73728949073293693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087066090087670717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055578486312611974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58966592362609216,
                                   0,
                                   0,
                                   0.43128861034540256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53838663815816057,
                                   0.94513618505985753,
                                   0,
                                   0,
                                   -0.67132178656715624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38695943723647069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40862663985878867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32162885500722782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4060184720037483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4828461243451041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37999601517937881,
                                   0,
                                   0,
                                   -0.10670375383765811,
                                   0,
                                   0,
                                   0,
                                   -0.055625155530009074,
                                   0,
                                   0.15243915206715225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76111334838817124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17136124901884975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36504713705007497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27562268652207389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21708699526029476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66665494426586169,
                                   0,
                                   0.04060516981590355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27917928003239939,
                                   0.0087546078287030482,
                                   -0.12474982027546462,
                                   -0.015749282811422356,
                                   0,
                                   0,
                                   0,
                                   -0.27839591875052716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26016347049809996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2764645267364213,
                                   0,
                                   0,
                                   0,
                                   0.14681236820806051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30923264687452962,
                                   0,
                                   0,
                                   0.79716263043766356,
                                   0,
                                   0,
                                   0,
                                   -0.61233045010635356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29006544231369308,
                                   0,
                                   0,
                                   0.69357787182579911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67170028573378693,
                                   -0.20047658083839764,
                                   0,
                                   0,
                                   -0.11363552483136376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51995180246007855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70757230477310562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64815233985427501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26942688045193613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90473658475543661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52371899745306549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26717279653174564,
                                   0,
                                   -0.19608115802307693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1983587515695534,
                                   -0.031931988484808355,
                                   -0.32453522617357511,
                                   -0.049638828171436208,
                                   0,
                                   0,
                                   0,
                                   0.29345849376731609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14724493827506641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95594985190819304,
                                   0,
                                   0,
                                   0,
                                   -0.40044532157133689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45965829285377119,
                                   0,
                                   0,
                                   -0.24256700224163585,
                                   0,
                                   0,
                                   0,
                                   0.078002936834430769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36837572659814266,
                                   0,
                                   0,
                                   0,
                                   -0.18694837654268429,
                                   0,
                                   0,
                                   -0.10319748474296404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17310045137835744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49550546175427812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085984477766069253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0088257684031083188,
                                   0,
                                   -0.025948804957329388,
                                   0.09227526480050488,
                                   0,
                                   0,
                                   0,
                                   0.24259744628149757,
                                   0,
                                   0.28106842367868107,
                                   0,
                                   0,
                                   0,
                                   -0.60184695906418439,
                                   0.10217956576909104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12664037154061342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061130681976933714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0059987978199785158,
                                   -0.62451735528289098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3778638361196941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26394272409130082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62750162298466239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34306990978233531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036751996847927862,
                                   -0.40186483672538598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77381434900590407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27310731569911856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21466422179184919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4140285901381674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35216995199660728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0018521173400224689,
                                   0,
                                   0,
                                   0,
                                   -0.46790679737158364,
                                   -0.026752063430547507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30760374105388877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4514856582904897,
                                   0,
                                   0,
                                   0,
                                   0.86116788807027944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43078373511981027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09491889748663572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28034848923274125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36206502118938438,
                                   0,
                                   0.59451601523598208,
                                   -1.5845869861565591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014453911841506668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76002878756639991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25727195870962144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014364434597598258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3308383159068361,
                                   0,
                                   0,
                                   0.030089027871192997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19238212085571821,
                                   0.64909083360210684,
                                   0,
                                   0,
                                   0.18791351999849432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65848970591863598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38705074595352379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34923645300186074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0941344683919096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62307699888177537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1288932901403661,
                                   0,
                                   0,
                                   0.088833298725446999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21915822206903363,
                                   0.034736166734373235,
                                   0,
                                   0,
                                   -0.83602157109420783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38075828016505986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4511499789869291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0058942512713564543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14657581745821052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1225668574837549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50406547075102992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18976590392465126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59412913925959365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48512405758392818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21036339030196283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76625530087762528,
                                   0,
                                   0.12819949836812089,
                                   0,
                                   0,
                                   0,
                                   0.035681351229219255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0027565601651013873,
                                   0,
                                   0,
                                   0,
                                   -0.0071047934703206174,
                                   0,
                                   0,
                                   0.3704459578313174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58846454784372204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0150852229197324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17965145901574561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49824889606770595,
                                   0,
                                   -0.0098639939300670335,
                                   0.025687706609906893,
                                   0,
                                   0,
                                   0,
                                   -0.14690724745889963,
                                   0,
                                   0.32147508356333215,
                                   0,
                                   0,
                                   0,
                                   -0.070159509277774715,
                                   0.18315139877722561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26742307578503299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21508147235509728,
                                   0,
                                   0,
                                   1.0790043122814779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03142118922349673,
                                   -0.42322846551226806,
                                   0,
                                   0,
                                   0.18431602618006518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10611964622089075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032639553344051934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4906672139097667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19053906800391646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095688615793932952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33030551988890261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29540318471243127,
                                   0,
                                   0,
                                   0.20247316599573126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029897499301783814,
                                   0,
                                   0,
                                   -0.013864515081068673,
                                   0,
                                   -0.47062555603281947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26371997726784435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48738087333713498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16447944500519335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45378795695343133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34511943295356362,
                                   0.4070216595172787,
                                   0,
                                   0.19277643616309498,
                                   0,
                                   -0.0037921083233581621,
                                   0.11083778844650252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075205799442255875,
                                   0,
                                   0.40788054168790383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4167585834028209,
                                   0.00060132626959435997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13322207379733816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093858403428995679,
                                   0,
                                   0.54175247860710707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036546713853591498,
                                   0.5799874790297268,
                                   0,
                                   -0.29913299776945462,
                                   0,
                                   0.47047693707441413,
                                   -0.13848342764579979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15169059028194062,
                                   0,
                                   0.16945491648507061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10753131316689615,
                                   -0.34962741634290184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11007562266657572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23133670352575086,
                                   0,
                                   -0.28480075999652865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028042635836752431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42268083434421538,
                                   0,
                                   0,
                                   -0.39240519159878245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24520478319511363,
                                   0,
                                   0,
                                   -0.52759585080851168,
                                   0,
                                   -0.3552757377754483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048315853484344203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24552187545212736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12606353609931176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35122876157627742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18474414101766728,
                                   0.086746599369335625,
                                   0,
                                   -0.11736513091256595,
                                   0,
                                   0.48509491505212932,
                                   0.51685896011227861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24192939458657323,
                                   0,
                                   -0.11377612679898173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31687353912836513,
                                   0.16197958327393241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048340492666055598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43776585466120072,
                                   0,
                                   0.2236358283357448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069729321981993234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55662826938187382,
                                   0,
                                   0,
                                   -0.3305905423362262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26276421476753226,
                                   0,
                                   0,
                                   0.23432591564387478,
                                   0,
                                   -0.3615213433301524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094119486802929836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46197326067238675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29647383202021649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1057678177219315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0049295987776584588,
                                   -0.044375474029624898,
                                   0,
                                   -0.30692608236291302,
                                   0,
                                   -0.25999735137196994,
                                   0.1913670606069344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58116608097371758,
                                   0,
                                   -0.18706681200497627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070115890020325561,
                                   -0.21943736338370887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52080736789238335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24745755416521659,
                                   0,
                                   0.20320030965896785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62581851950900069,
                                   0.16553954262444498,
                                   0,
                                   -0.064255345979785244,
                                   0,
                                   -0.44454682572005377,
                                   0.26873432813226877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09385284758037199,
                                   0,
                                   0.29004692916180974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066717660420533814,
                                   -0.35400098732124513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28861231484497446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019696619542796508,
                                   0,
                                   0.024300682143771853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47793734744453509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05719114346381491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25954908690545625,
                                   0,
                                   0,
                                   0,
                                   -0.14315211067948108,
                                   0.39154021622942664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86430783660022747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11810092832517924,
                                   0,
                                   0,
                                   0,
                                   0.26095578166029915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53233260171640695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28393187140336718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15879561686504229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98836665395682355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024991228768381592,
                                   0,
                                   0,
                                   0,
                                   -0.32781033414658889,
                                   0,
                                   0,
                                   0.60673286059706466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012676551138951005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095464088936347974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068031402879801681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17628511850448073,
                                   0,
                                   0.16894438585813179,
                                   0.11777324462347616,
                                   0,
                                   0,
                                   0,
                                   0.071697087468660825,
                                   0,
                                   -0.38153284254157932,
                                   0,
                                   0,
                                   0,
                                   -0.2519910507411936,
                                   0.33239593715748006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3342232540233766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82847109446969125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49182952337292341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1180102922588695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73785125929826612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13694564913405333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25820724842401205,
                                   0,
                                   0.022213512337841003,
                                   0,
                                   0,
                                   0,
                                   0.35362700807835606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00037853244581442791,
                                   0,
                                   0,
                                   0.48532985020152608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51553341737588143,
                                   -0.17643346959608613,
                                   0,
                                   0,
                                   -0.31194657080329635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17526902250572016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78982987381700565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63588752822814376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.288020359353516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92126152665945416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31602101565740925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45005961828165314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060026916983077563,
                                   0,
                                   0,
                                   0,
                                   0.39266615302614688,
                                   -0.30440681826006488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081384478864806403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54027445791647999,
                                   0,
                                   0,
                                   0,
                                   -0.33707368786709985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35068772464311104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47144794046065208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23745509604631332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28937859236568642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018205272953015744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82067109852533937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19097008253587566,
                                   0,
                                   0,
                                   0,
                                   -0.106423614357679,
                                   -0.22506874319399695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50297985711036697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70962008664147125,
                                   0,
                                   0,
                                   0,
                                   -0.13059941662226648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16153872656880111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14862694062072671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74989108830910112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20270808995352313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077776192576907016,
                                   0,
                                   0,
                                   -0.36074024481090522,
                                   0,
                                   0,
                                   0,
                                   -0.12320622491631639,
                                   0,
                                   -0.52063395174336358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44139093377013161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0098328514268757536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57087597629160902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23823482614306815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40183208222776301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063379334733884601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32110572809581084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73841880394383286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47210678060520395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28739973671014574,
                                   0,
                                   0.30040412573663311,
                                   0,
                                   0,
                                   0,
                                   -1.0155511956222687,
                                   0,
                                   0,
                                   0,
                                   -0.16450566683690965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071530144835254911,
                                   0,
                                   0,
                                   -0.33343784594029807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3315078818472299,
                                   0,
                                   0,
                                   0.41041001188772541,
                                   0,
                                   0.29507711495212208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28106982802668568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26708184765751358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29686344137394483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50276764524043704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63282600785681931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11045725035173531,
                                   0,
                                   -0.43189399658745969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066163063456852467,
                                   -0.31918085712887889,
                                   0.19693952029869657,
                                   0.25166700648292484,
                                   0,
                                   0,
                                   0,
                                   0.24846405611722927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70721817733094972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0018407692810623235,
                                   0,
                                   0,
                                   0,
                                   0.2494480620347953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097416630593812309,
                                   0,
                                   0,
                                   0.25219079368310732,
                                   0,
                                   0,
                                   0,
                                   -0.404273594068633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07979500866019669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14017837547723785,
                                   0,
                                   -0.26623949792480334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69998076829865297,
                                   0.13359725140694667,
                                   0.73169500678622301,
                                   -0.3105909419375647,
                                   0,
                                   0,
                                   0,
                                   0.079367891815976491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39018309596098222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33210652557916065,
                                   0,
                                   0,
                                   0,
                                   0.096165838825988947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31785405125735267,
                                   0,
                                   0,
                                   -0.23874990017220657,
                                   0,
                                   0,
                                   0,
                                   0.12615400235315705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41773656404880261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53450250053836346,
                                   0,
                                   -0.44906458142365535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3091185840622373,
                                   -0.45841255317088153,
                                   -0.063710186582947692,
                                   0.058622454573151149,
                                   0,
                                   0,
                                   0,
                                   -0.11820944321216743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11118907306329841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81754794400096198,
                                   0,
                                   0,
                                   0,
                                   0.65071648149638672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28587282989719226,
                                   0,
                                   0,
                                   -0.67325162215739309,
                                   0,
                                   0,
                                   0,
                                   -0.34856367623435774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028231659061405557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37887437556894266,
                                   0,
                                   0.64561007596204045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17135295488656066,
                                   -0.22440459015569353,
                                   -0.095723623901363866,
                                   -0.87020057111489724,
                                   0,
                                   0,
                                   0,
                                   -0.16683460373758757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21834552734769597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028760276018781328,
                                   0,
                                   0,
                                   0,
                                   -0.10934598218609463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06932634692237867,
                                   0,
                                   0,
                                   -0.21572266906598511,
                                   0,
                                   0,
                                   0,
                                   -0.362723338397961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52667443371567069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30166088863734586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63244098905686619,
                                   0,
                                   0,
                                   0,
                                   -0.63874959608264414,
                                   -0.69736661662355504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019271136473841849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66225886972548875,
                                   0,
                                   0,
                                   0,
                                   0.17120315492486476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10638467674288427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34846602341809929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047308411754680202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1982423399084508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22588868604760329,
                                   0,
                                   0,
                                   0.66651664756053441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80280012035800818,
                                   -0.061707961498621705,
                                   0,
                                   0,
                                   0.026335113093107931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3878035294590253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027516047422389098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68443306011990057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0093588040152532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29416103182651854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048854443795301211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77087637078428584,
                                   -0.099053622324776602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15301682532628774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56281080595624777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23104348521043339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27819633145807127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47221174629845813,
                                   0,
                                   0.35362383575234008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5509211675868424,
                                   -0.28886410166394894,
                                   0.013191386244182488,
                                   0.32976858428693689,
                                   0,
                                   0,
                                   0,
                                   0.24219982183874969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47467737295465401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59525410714531213,
                                   0,
                                   0,
                                   0,
                                   0.1318966264386463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71521867816114149,
                                   0,
                                   0,
                                   0.51784832669714387,
                                   0,
                                   0,
                                   0,
                                   0.44728651502594058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15215977998269981,
                                   -0.4859064494852004,
                                   0,
                                   -0.34146946282396301,
                                   0,
                                   0.16787043867418303,
                                   -0.31851034105719489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35670018304271156,
                                   0,
                                   0.42861339923144032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00016738517559114919,
                                   -0.1684400775966467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34449616009891115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051274917290527439,
                                   0,
                                   0.18408783858241162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42352959357393205,
                                   0,
                                   0,
                                   0,
                                   0.51735045504537069,
                                   0,
                                   0,
                                   -0.061858413305858811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014840057004073134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026069472908091952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14995343231135186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23314306384241934,
                                   0,
                                   0.51278289824773882,
                                   -0.059209749227846692,
                                   0,
                                   0,
                                   0,
                                   0.12759083319750605,
                                   0,
                                   -0.0039763544674249612,
                                   0,
                                   0,
                                   0,
                                   0.048033536037095897,
                                   0.097916495959811445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4204295112503571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16383240595438928,
                                   0.16188283406774714,
                                   0,
                                   0.31682660453396877,
                                   0,
                                   0.012545121187039224,
                                   -0.22915814199345436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39442197829967002,
                                   0,
                                   -0.58259924790231055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10067177417526205,
                                   -0.4388674908987158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26576499220083599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059900929297325559,
                                   0,
                                   0.14816796424900583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36197282761982752,
                                   0,
                                   0,
                                   0,
                                   0.11291586915157108,
                                   0,
                                   0,
                                   0.46486931749023019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27993082792678681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27137881683935966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054496349123358732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071701376297531594,
                                   0,
                                   -0.029133647211356868,
                                   -0.35403968004548819,
                                   0,
                                   0,
                                   0,
                                   -0.41665582223854003,
                                   0,
                                   -0.1467828226338285,
                                   0,
                                   0,
                                   0,
                                   0.12279849824600826,
                                   -0.27454049775462575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26117318847877274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29784692271301394,
                                   0,
                                   0,
                                   0,
                                   -0.31000265033222613,
                                   0,
                                   0,
                                   -0.22591044558624451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042084496070421945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56958387788049847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20180616465027493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024182651266792195,
                                   0,
                                   0.21962502139129392,
                                   -0.028040547940760524,
                                   0,
                                   0,
                                   0,
                                   -0.34329281101347042,
                                   0,
                                   0.049803247450085505,
                                   0,
                                   0,
                                   0,
                                   -0.36610135488489604,
                                   -0.30379475728796679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031135414307699158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51007823494304394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080459127803368655,
                                   -0.60814529429016595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0061518265222835489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18921275749579231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57242162035908128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19871000728993365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44598174934378004,
                                   0,
                                   0.094629059705864493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20832779658501499,
                                   -1.0735916114730191,
                                   0.60582873729426323,
                                   -0.046907544041177709,
                                   0,
                                   0,
                                   0,
                                   -0.58257324586415304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15849704803499431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28849644607275854,
                                   0,
                                   0,
                                   0,
                                   -0.60810087216689024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40626543612203542,
                                   0,
                                   0,
                                   0.36019637972061097,
                                   0,
                                   0,
                                   0,
                                   -0.076826197948001357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43717469236641671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24564346640401485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31680880383617593,
                                   0,
                                   0,
                                   0,
                                   0.12862047778512148,
                                   0.36237231439216189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58071834970689329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31083331965850147,
                                   0,
                                   0,
                                   0,
                                   0.2286794121958452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39866331339214028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29265772615719787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0070391222656930041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69688226522306018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34189547117672997,
                                   0,
                                   0,
                                   0,
                                   -0.28215169996647699,
                                   0,
                                   0,
                                   0.21678518593055887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23926015596999498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010640046575529496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27709471004755287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21625585609372822,
                                   0,
                                   -0.0050694898927513407,
                                   0.2278558285205827,
                                   0,
                                   0,
                                   0,
                                   0.16551886440783001,
                                   0,
                                   0.37066070005678942,
                                   0,
                                   0,
                                   0,
                                   0.40019603455606512,
                                   -0.3529038725296777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2723371899281869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0026737228396374671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11899114006765989,
                                   0,
                                   0,
                                   0.28328585490069491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48224267785420594,
                                   0,
                                   0,
                                   -0.088924128992743615,
                                   0,
                                   -0.32468942366048731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57649946446453693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28992774864208032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076625607569567517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37069279141992639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16560623341696248,
                                   0,
                                   0,
                                   0,
                                   -0.27862045348745063,
                                   0,
                                   0,
                                   -0.036397197452531019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36471440381759157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21538359560340092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0081580067468149595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61236898600138234,
                                   0,
                                   -0.017898455603738154,
                                   0.29516139384712692,
                                   0,
                                   0,
                                   0,
                                   -0.29945194706893596,
                                   0,
                                   -0.010385153486379362,
                                   0,
                                   0,
                                   0,
                                   0.07933012524074888,
                                   -0.18354694971237653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34921164070726618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67149968501297275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24412673564255627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49940042582180066,
                                   0,
                                   0,
                                   0,
                                   -0.030159322115050957,
                                   -0.096273610860718534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29545274343306482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26479762721743089,
                                   0,
                                   0,
                                   0,
                                   -0.10386584239425456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72143682386064567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19624303251108663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34081156650263844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44855651334513791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52609610173395482,
                                   -0.12315244893556429,
                                   0,
                                   0.15328500036910259,
                                   0,
                                   -0.11968618426180211,
                                   0.059145617824093784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080817930880179217,
                                   0,
                                   0.16560170452721301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46563471762404451,
                                   -0.55308564186325426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23304992006937436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22580791218595386,
                                   0,
                                   -0.068998039654060539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14041154042684068,
                                   0.35785236241573348,
                                   0,
                                   -0.37101686792086719,
                                   0,
                                   -0.44861146543884528,
                                   -0.14443069284527077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36336837921428189,
                                   0,
                                   -0.084284995241788438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44420188530526306,
                                   0.30269699404994377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10119941493201651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16982020498342554,
                                   0,
                                   0.15905580666275279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27082339027081237,
                                   0,
                                   0,
                                   0,
                                   0.081276412746966245,
                                   0,
                                   0,
                                   0.032546607566817681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0035225508894879132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27382897866291894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57000555386287377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35370649451981201,
                                   0,
                                   0.34518805759292565,
                                   0.43197615319567212,
                                   0,
                                   0,
                                   0,
                                   -0.064542037474150771,
                                   0,
                                   0.14002982964803928,
                                   0,
                                   0,
                                   0,
                                   0.039119996279202124,
                                   -0.2067709573768837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14199788018917703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054998564796344553,
                                   0,
                                   0,
                                   0,
                                   -0.0071010886173353913,
                                   0,
                                   0,
                                   -0.25274047146844225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58337976735422425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40104398508827482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012204798399128618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095369366239445585,
                                   0,
                                   -0.17909481496103621,
                                   -0.030258456185254565,
                                   0,
                                   0,
                                   0,
                                   -0.22152048048333381,
                                   0,
                                   -0.45614388615403639,
                                   0,
                                   0,
                                   0,
                                   -0.1479018486652354,
                                   -0.20595939364054727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26117266071466722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54782038973276159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11599405309418817,
                                   0,
                                   0,
                                   -0.23654236413221985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26596405757947389,
                                   0,
                                   0,
                                   -0.20776857898262582,
                                   0,
                                   0.077600853873743866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46217938082918131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43590512867282827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13195399449913375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29920634588998724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057528420339933162,
                                   0,
                                   0,
                                   -0.082312263521896911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39446444037082651,
                                   -0.71725355497310406,
                                   0,
                                   0,
                                   -0.40368177810476252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31338920502389472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25962031635999511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87905190833613034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5018081750484813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11270929363989535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44121865129051829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03316920942345241,
                                   0,
                                   -0.036525329280396222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2119095820251754,
                                   -0.4200228017630373,
                                   -0.38735598045401637,
                                   0.24934025383799413,
                                   0,
                                   0,
                                   0,
                                   0.81070350256157264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12551467880535008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35598112637722296,
                                   0,
                                   0,
                                   0,
                                   -0.94500491151106569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2000306628438891,
                                   0,
                                   0,
                                   0.062326257018557873,
                                   0,
                                   0,
                                   0,
                                   -0.41238643985878365,
                                   0,
                                   0,
                                   0,
                                   -0.11951295149176537,
                                   0.17097871298721026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14406099007661188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81074537142821923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86323598854527372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21071187518391801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62034217267311353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28741588374665294,
                                   0.19937279104339342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48448524769454526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44869445667982244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23825515330429448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039129261540933616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39616822715431227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051653090652272499,
                                   0,
                                   0,
                                   0,
                                   0.10311663845980737,
                                   -0.430225243370569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55418950182956561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3505324647805676,
                                   0,
                                   0,
                                   0,
                                   0.45946857324267715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42499004486771808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68597900252435506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51211226434628121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15053840889069248,
                                   0,
                                   0,
                                   0,
                                   0.11198408354167248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30427479696414339,
                                   0,
                                   -0.8054364735369689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75951533335675203,
                                   0.18064182491326408,
                                   0.31915062912587611,
                                   -0.66346418820603237,
                                   0,
                                   0,
                                   0,
                                   0.42173134862251915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30126148637686906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20238061546763547,
                                   0,
                                   0,
                                   0,
                                   -0.38465384754825782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12021009161179416,
                                   0,
                                   0,
                                   0.21911640931503795,
                                   0,
                                   0,
                                   0,
                                   0.11856585944422957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22170166570252858,
                                   -0.026194209995903481,
                                   0,
                                   0.57793552636719292,
                                   0,
                                   0.029796716246088747,
                                   0.13206738750194197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10824689147957574,
                                   0,
                                   0.25731132759446795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46638960233788884,
                                   0.092597422238981722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39763855228248557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36101179162909186,
                                   0,
                                   0.073192475400665258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55693799041516601,
                                   -0.09048526249262262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32455268851175245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58889547452475821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88857795003562301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36563619055781094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41996802883975548,
                                   0,
                                   0,
                                   -0.040311774511987489,
                                   0,
                                   0,
                                   0,
                                   0.4595065548178961,
                                   0,
                                   -0.19516182454924547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25166311690585319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38665972729779563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49243518276507708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34268779604253902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60821442700736772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1652485543965781,
                                   0,
                                   0,
                                   0.052887700420801577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56585859261881932,
                                   0,
                                   0,
                                   -0.12463776661448986,
                                   0,
                                   -0.30957869955369105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34984103809918626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080819813521192163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094587252704566527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17474033220602997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59614495338536466,
                                   0,
                                   0,
                                   -0.12974897830955456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30047602925059569,
                                   -0.5698525284641891,
                                   0,
                                   0,
                                   0.1314842247936219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0051444838652537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78497091188725798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0073996968791479323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01323287188019355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14598451404183097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21124861528839337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3086041653418452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48036846478269468,
                                   0,
                                   0,
                                   0,
                                   -0.27949500557420681,
                                   -0.75853932083594655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18630103493311223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18352267725525345,
                                   0,
                                   0,
                                   0,
                                   0.042985893620165777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086132114346689104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08471728641844839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45154203356570588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51345655679332769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23205395488304004,
                                   -0.10536783294710181,
                                   0,
                                   -0.11114530642201102,
                                   0,
                                   -0.082982961060735314,
                                   0.60427959171525469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35356821358444329,
                                   0,
                                   -0.031537343496064546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24994770547949124,
                                   -0.078515591884420421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33564401607717714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28242355962951293,
                                   0,
                                   -0.40446470053125394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50582369419885465,
                                   0,
                                   0,
                                   -0.63210560422632767,
                                   0,
                                   0,
                                   0,
                                   -0.15886917030613784,
                                   0,
                                   0.49704431645625341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0088173977443365657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097626670191730477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048070007370003755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24570915907472596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065318951135076367,
                                   -0.20910741747482064,
                                   0,
                                   -0.19172037202974007,
                                   0,
                                   0.16251332871440499,
                                   0.17787160796037368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090233830831151857,
                                   0,
                                   -0.21906468616970176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026721150074178201,
                                   -0.21168031262348147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29770036003720518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6231162442403696,
                                   0,
                                   0.5278716859530298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37159382187389134,
                                   0,
                                   0,
                                   0,
                                   -0.23865429595865706,
                                   0,
                                   0,
                                   -0.22002033882708902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021665922288074454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033881599139272502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045814156426453062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09236668629096878,
                                   0,
                                   0.17978698369940999,
                                   0.36445078074742798,
                                   0,
                                   0,
                                   0,
                                   -0.0088254774173036205,
                                   0,
                                   -0.39334202356452286,
                                   0,
                                   0,
                                   0,
                                   0.37148100601591838,
                                   0.31187670949439783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43485227957262323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090043549909112175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23362205415833126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52922473181402707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090186170092629497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3256527193284344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39666713110673119,
                                   0,
                                   -0.018490159964890118,
                                   0,
                                   0,
                                   0,
                                   -0.16694862525429219,
                                   0,
                                   0,
                                   0.0494430763573704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83854849073508664,
                                   0,
                                   0.032004170509560004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26334781898205861,
                                   0.53524878878490745,
                                   -0.25910697996779802,
                                   0.30408203383874127,
                                   0,
                                   0,
                                   0,
                                   -0.14558917872052612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043462659581036761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37519307730618184,
                                   0,
                                   0,
                                   0,
                                   -0.48334468601432801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09304281209602841,
                                   0,
                                   0,
                                   0.0070383738886231062,
                                   0,
                                   0,
                                   0,
                                   -0.072230821451969601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087448864937070964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13404105529778632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7294777929686791,
                                   0,
                                   0,
                                   0,
                                   0.088500205581207997,
                                   0.089078060125448832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29715393788900107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74208064507993809,
                                   0,
                                   0,
                                   0,
                                   0.17980090761511547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38162480405820925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14478664019452986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7798367823851331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29102271600383373,
                                   0,
                                   0.62138337422542211,
                                   0.17018421606395148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91630822075150209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12171742086402132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072697954369261797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1289102457779476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55890606438496215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29554313050067355,
                                   0,
                                   0.1809097298102022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042423735347377596,
                                   0.016887532614144857,
                                   -0.009812850901758402,
                                   -0.36077208071126377,
                                   0,
                                   0,
                                   0,
                                   0.37585968177751128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23883864817316414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42140045659829173,
                                   0,
                                   0,
                                   0,
                                   0.35664095452407574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43959126451561592,
                                   0,
                                   0,
                                   0.45837171891958084,
                                   0,
                                   0,
                                   0,
                                   0.12690244840731776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60508810726179352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1252811342038487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4196081387981685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094296384958950569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22105736076260468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30045781467797456,
                                   0,
                                   -0.26438070790710178,
                                   0,
                                   0,
                                   0,
                                   -0.30347894978840595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60695103969853159,
                                   0,
                                   0,
                                   -0.55715987964872493,
                                   0,
                                   0,
                                   0,
                                   -0.043680635607582036,
                                   0,
                                   -0.020893686835793915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28815706622838622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3623204885980244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1807046091619896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26809321661386099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0933145108623579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077531101447056355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58610724503157274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25277306257446575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4600720182800207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1933607590645701,
                                   0,
                                   -0.30806973796849868,
                                   0,
                                   0,
                                   0,
                                   -0.05645544845755425,
                                   0,
                                   0,
                                   -0.32971829793589608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57311981612826912,
                                   0,
                                   -0.16860902357481597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36767748217250357,
                                   0.46919872127393503,
                                   0.29269440521207757,
                                   0.42707512338667963,
                                   0,
                                   0,
                                   0,
                                   -0.15437191423971752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23596297703941632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31930357095412942,
                                   0,
                                   0,
                                   0,
                                   -0.1889924556155784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070580086755675189,
                                   0,
                                   0,
                                   -0.2577888379211391,
                                   0,
                                   0,
                                   0,
                                   -0.61773484413168356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68938300755980453,
                                   0,
                                   0,
                                   0.45719020042717295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10903527214492596,
                                   0.22277751295659165,
                                   0,
                                   0,
                                   0.67186420150124582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024136235715024334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52533876857608908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094287394660756238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082245944564054291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72146122008722358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31563378515259222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28169916296067388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23673312554089662,
                                   0,
                                   0,
                                   0,
                                   0.91848553091416385,
                                   -0.52039823621898262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19686934330643899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1596651964282742,
                                   0,
                                   0,
                                   0,
                                   0.45690904434608376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080207409791282269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24501970193452474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38033528453696874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037133137261095059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044665530249936761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.004121084331304925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44255937113419913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31696027823792972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094536138307213802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11443059348050408,
                                   0,
                                   1.0531291410280261,
                                   0,
                                   0,
                                   0,
                                   0.94731822713952818};

const double rot_25_30[9000] = {0.25611020813559027,
                                0,
                                0,
                                -0.42631769532296199,
                                0,
                                0,
                                0,
                                0,
                                0.65754434373554793,
                                0,
                                0,
                                0,
                                0.45142640595305378,
                                -0.26827379469038165,
                                0,
                                0,
                                0.13305280613241754,
                                0.14119819748112566,
                                0,
                                0,
                                0,
                                0.08306389627119834,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26257629070642874,
                                0.33822788516026975,
                                0,
                                0,
                                0,
                                0,
                                0.098098037407994998,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31476744339649554,
                                0,
                                0,
                                0,
                                0,
                                -0.14332189917339061,
                                0,
                                -0.82910352436261259,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16359277352881207,
                                0.70821603906741126,
                                0,
                                0,
                                0,
                                0,
                                0.055018325985410649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33853851075455166,
                                0,
                                0,
                                0,
                                0,
                                -0.39926561390851573,
                                0,
                                0.44115652159854013,
                                0,
                                0,
                                0,
                                0,
                                -0.38776525389270705,
                                0,
                                0,
                                0.066280578772036206,
                                0,
                                0,
                                0,
                                0,
                                0.5738502889994429,
                                0,
                                0,
                                0,
                                -0.39335628148054308,
                                -0.13529249986644643,
                                0,
                                0,
                                -0.43577738981585046,
                                -0.14368102707290514,
                                0,
                                0,
                                0,
                                -0.36381512180044251,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48635844263754474,
                                0,
                                0.73296254055135568,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41354115424141602,
                                0,
                                0.48676650791800663,
                                0,
                                0,
                                0,
                                -0.12923061424377025,
                                0,
                                0,
                                -1.0588778044275966,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25605332660586899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.091383984651097622,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0908733764220182,
                                0,
                                0.6694646385374885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.84863375878851832,
                                0,
                                -0.023386570730583575,
                                0,
                                0,
                                0,
                                0.85226446883559226,
                                0,
                                0,
                                0.43513619949885801,
                                0,
                                -0.30295954813474057,
                                -0.51583970059804085,
                                0,
                                0,
                                0,
                                0,
                                -0.10415878859474197,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7822036538581858,
                                0,
                                0,
                                0,
                                0,
                                -0.13938355544247508,
                                0,
                                0.0023517233063869852,
                                0,
                                0,
                                0,
                                0,
                                -0.45159621279814249,
                                0,
                                0,
                                -0.053622524870796037,
                                0,
                                0,
                                0,
                                0,
                                -0.20334066866372225,
                                0,
                                0,
                                0,
                                0.6571060360737303,
                                -0.08131744231412609,
                                0,
                                0,
                                -0.45224362651040639,
                                -0.30256303291198927,
                                0,
                                0,
                                0,
                                0.1317896134261663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.93243981029005307,
                                0.024326883666480684,
                                -0.004105081250869419,
                                0,
                                0,
                                1.2437140257559374,
                                0.18989150852460501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50579372613270479,
                                0,
                                0,
                                0.082296025659066185,
                                -0.061327539401888967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.78466369016523996,
                                -0.12243622809889809,
                                0.77889952416417796,
                                0,
                                0,
                                0.20820910414633367,
                                0.13717416871354246,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18985635114554278,
                                0,
                                0,
                                0.58843099764856133,
                                -0.28223229433750674,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41229891966597787,
                                0.076932699298715324,
                                0.37795263035843041,
                                0,
                                0,
                                0.024338975587944595,
                                0.18224108063848066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15406663604357324,
                                0,
                                0,
                                0.11668558354702832,
                                1.1968559132909136,
                                0,
                                -0.024011134993854127,
                                0,
                                0,
                                -0.0657520991485539,
                                0,
                                0,
                                0,
                                0,
                                -0.35001569170921848,
                                0,
                                0,
                                0,
                                0.086928812104338365,
                                -0.56503689008929747,
                                0,
                                0,
                                -0.077711183517072902,
                                0.5086209543583099,
                                0,
                                0,
                                0,
                                -0.53012407379739424,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21327469626266957,
                                0,
                                0,
                                0.019560828137010267,
                                0,
                                0,
                                0,
                                0,
                                0.049436846861315532,
                                0,
                                0,
                                0,
                                0.010052542194002728,
                                0.38208729186778978,
                                0,
                                0,
                                -0.62993214041317125,
                                0.60086357725511697,
                                0,
                                0,
                                0,
                                0.21850396769924302,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10453359731980437,
                                -0.05893369874947546,
                                0.7182723254097868,
                                0,
                                0,
                                -0.054338157356327424,
                                -1.1089897133916302,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57042565793373323,
                                0,
                                0,
                                0.13857257704322323,
                                0.56271824066460796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56998453547714634,
                                -0.01912193992627069,
                                -0.32576741086970185,
                                0,
                                0,
                                0.062695172550040951,
                                0.30080701307153734,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35134829379756533,
                                0,
                                0,
                                1.0073128657383861,
                                0.33832675206343277,
                                0,
                                0.39093832324228339,
                                0,
                                0,
                                -0.13905254678920215,
                                0,
                                0,
                                0,
                                0,
                                -0.16003512762949376,
                                0,
                                0,
                                0,
                                -0.32742379376920477,
                                -0.55413589697193144,
                                0,
                                0,
                                -0.36145062263694339,
                                -0.29278506314245595,
                                0,
                                0,
                                0,
                                0.41421950187489792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61734294524027267,
                                0,
                                0,
                                -0.24427739547425034,
                                0,
                                0,
                                0,
                                0,
                                -0.0060949293282140868,
                                0,
                                0,
                                0,
                                -0.25070331977587923,
                                -0.16891462581445826,
                                0,
                                0,
                                0.21759777463415614,
                                0.37492616768312981,
                                0,
                                0,
                                0,
                                0.52903342593723368,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.081770110816992453,
                                0.25325398743661587,
                                0,
                                0,
                                0,
                                0,
                                0.23704830544796146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3223465666924385,
                                0,
                                0,
                                0,
                                0,
                                0.87359841338558653,
                                0,
                                0.07682884081158553,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.092195000543255842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26754387462229989,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39826621269828533,
                                0,
                                -1.1954003950044969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0319619337597272,
                                0,
                                -0.21909795365831686,
                                0,
                                0,
                                0,
                                0.24079242023030284,
                                0,
                                0,
                                -0.19171994677613488,
                                0.0099405463428745844,
                                0,
                                0,
                                0.85280226964434669,
                                0,
                                0,
                                0,
                                0,
                                0.21536127273690092,
                                0,
                                0,
                                0,
                                0.1788309982421353,
                                -0.3197756326586304,
                                0,
                                0,
                                0.083796455096707939,
                                0.14781544068665725,
                                0,
                                0,
                                0,
                                0.25127826222402655,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27975077680432792,
                                0,
                                -0.60210572085883041,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50819868880848107,
                                0,
                                1.3131720716648778,
                                0,
                                0,
                                0,
                                -0.069952567874496024,
                                0,
                                0,
                                0.47866522433368175,
                                0,
                                -0.61907791931925926,
                                -0.059980917336781736,
                                0,
                                0,
                                0,
                                0,
                                0.71652727119183235,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20852493855395376,
                                0,
                                0,
                                0,
                                0,
                                -0.14128973768666775,
                                0,
                                -0.19049422309013597,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15412997959876046,
                                1.1942507625970822,
                                0.20884890911850335,
                                0,
                                0,
                                -0.36090915988830985,
                                -0.19979913790007967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37957344613218885,
                                0,
                                0,
                                -0.099136939990350337,
                                -0.36328397054275957,
                                0,
                                0,
                                0.6500482958906374,
                                -0.2240670667400172,
                                0,
                                0,
                                0,
                                0,
                                0.63788515905579035,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16456189761695422,
                                0,
                                0,
                                0,
                                0,
                                -0.13221591959513795,
                                0,
                                0.27526717735117628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59182628813215032,
                                0,
                                -0.79083231953439737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49559397175882913,
                                0,
                                0.38344750805570893,
                                0,
                                0,
                                0,
                                -0.05486253160050733,
                                0,
                                0,
                                -0.61176110202174216,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45182276445792618,
                                -0.081396649083255501,
                                -0.69278189469014462,
                                0,
                                0,
                                0.81024048585828123,
                                -0.18857158103711469,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2914878845462176,
                                0,
                                0,
                                0.25155174871311592,
                                0.27966857989291016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2141794167306596,
                                0.22986843973203047,
                                0.40541075396816961,
                                0,
                                0,
                                0.5185044913786967,
                                0.40376840194405389,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.82531585175649669,
                                0,
                                0,
                                -0.30721676389307717,
                                0.11410024647900022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.94517006089354394,
                                0,
                                -0.25474302373173596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27846178853892534,
                                0,
                                -0.28280256050862512,
                                0,
                                0,
                                0,
                                -1.0135914302819005,
                                0,
                                0,
                                -0.13471926070967849,
                                -0.091470125632944904,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.026328744116706,
                                0,
                                0,
                                0,
                                -0.0030841235280339718,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.6265523029104099,
                                0,
                                0.11346678882419448,
                                0,
                                -0.28166438866967736,
                                0,
                                0,
                                0,
                                -0.51388873672770607,
                                0,
                                0,
                                0,
                                0.39668978701360469,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21087269629050762,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21502486498190557,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6976912065913663,
                                0,
                                -0.032856852972761662,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26941137908731738,
                                0,
                                0,
                                0,
                                0.37354621147826844,
                                0,
                                0,
                                0,
                                -0.082428254555196812,
                                0,
                                0,
                                0,
                                0.53694497749696335,
                                0,
                                0,
                                0,
                                0.3337036343783118,
                                0,
                                0.34007972627706168,
                                -0.23242721371445385,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4601539581523047,
                                0,
                                0,
                                0,
                                -0.21609970586271318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27357967194794658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19156531901173945,
                                0,
                                0,
                                -1.292506382835285,
                                -0.30297527871179109,
                                -0.19424409475220566,
                                0,
                                0,
                                0,
                                0.38847401635231305,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55755029724626182,
                                0,
                                0,
                                -0.21486270707996682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65316105722649076,
                                0,
                                0,
                                -0.11626622169823553,
                                0,
                                0,
                                0,
                                -0.58100968331956282,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25353290147196228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75682486866331233,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.069126663954703294,
                                0,
                                -0.08407499007064359,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.072030100799276631,
                                0,
                                0,
                                0,
                                -0.21627338512241209,
                                0,
                                0,
                                0,
                                0.4317435576063009,
                                0,
                                0,
                                0,
                                -0.23289669726635628,
                                0,
                                0,
                                0,
                                0.40409453963862546,
                                0,
                                0.67515920647657435,
                                0.027086287949664722,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29585148011070483,
                                0,
                                0,
                                0,
                                0,
                                0.39889492303447716,
                                0,
                                0,
                                0.084256041285229011,
                                0.50630691455117494,
                                -0.56531575973252091,
                                0,
                                0,
                                0,
                                0.39964789929687167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47738978548600436,
                                0,
                                0,
                                -0.55645560923970794,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0893460058679085,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.087221202061038505,
                                0,
                                0,
                                0.063721425490695524,
                                0.81761279087301242,
                                -0.49667110869258796,
                                0,
                                0,
                                0,
                                0.53858509496503792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.88170185712673244,
                                0,
                                0,
                                0.38739107056187161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16149267629601297,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18808695701967904,
                                0,
                                0,
                                -0.22367404096009458,
                                0.31579047671835098,
                                0.99989486515506076,
                                0,
                                0,
                                0,
                                0.73972377943826051,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23325622240011229,
                                0,
                                0,
                                -0.0060394318200461643,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0059617408377401482,
                                0,
                                0,
                                0,
                                0.38708955298223691,
                                0,
                                0,
                                0,
                                0.42254948602221443,
                                0,
                                0,
                                0,
                                -0.1283557536460706,
                                0,
                                0,
                                0,
                                0.020538328734487125,
                                0,
                                0,
                                0,
                                0.62212697014083473,
                                0,
                                -0.23013676109607245,
                                0.39260212185609328,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24612042890179833,
                                0,
                                0.42119091238148992,
                                0,
                                0,
                                0,
                                0.0061501704305930438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75990113468108378,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12157421507530253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13619953158663708,
                                0,
                                0.4601956693252679,
                                0,
                                0,
                                0,
                                0.044367960821604657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.4419812137461048,
                                0,
                                0,
                                0,
                                0.88385254491133591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18732075318020419,
                                0,
                                -0.38164983638541761,
                                0,
                                -0.45901070173697761,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.9214998051231964,
                                0,
                                0,
                                -0.40537974740074634,
                                -0.31520790924919329,
                                -0.10475366131109509,
                                0,
                                0,
                                0,
                                0.065957155413318022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0024334516530369055,
                                0,
                                0,
                                0.87849064901453755,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34609333919771318,
                                0,
                                0,
                                0,
                                0.77283721153511853,
                                0,
                                0,
                                0,
                                0.14644745827722261,
                                0,
                                0,
                                0,
                                -0.19080303090089282,
                                0,
                                0,
                                0,
                                -0.020582760845859388,
                                0,
                                0,
                                0,
                                -0.28735677364209866,
                                0,
                                0.46338212583636973,
                                -0.19787530994249436,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.089413598508786302,
                                0,
                                0,
                                0,
                                0.23310257475300739,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26862140189129108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28564182406673821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55816082462181182,
                                0,
                                0,
                                0,
                                -0.53605353825474678,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8685181419929392,
                                0,
                                0.51994682093609779,
                                0,
                                1.0990490032813818,
                                0,
                                0,
                                0,
                                -0.46933366551522721,
                                0,
                                0,
                                0,
                                -0.22219621473524892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2292426054359043,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.08325781662579923,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.086049202649684187,
                                0,
                                0.81453437687944397,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.01320312157346451,
                                0,
                                0,
                                0,
                                -0.033923303675213429,
                                0,
                                0,
                                0,
                                -0.2372324103520998,
                                0,
                                0,
                                0,
                                -0.70197576109850424,
                                0,
                                0,
                                0,
                                0.35484420571235681,
                                0,
                                -0.10536509598386186,
                                -0.33451271802963412,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44800751004228523,
                                0,
                                0,
                                0,
                                0,
                                -0.53475103942452318,
                                0,
                                0,
                                0.70065553298394589,
                                -0.37662244004705131,
                                -0.52180313220248986,
                                0,
                                0,
                                0,
                                1.3118421042539343,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54899174851012222,
                                0,
                                0,
                                -0.030615610200755466,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44589497737135003,
                                0,
                                0,
                                0,
                                0.17940034436934293,
                                0,
                                0,
                                0,
                                -0.24037884290632885,
                                0,
                                0,
                                0,
                                0.03338026233809039,
                                0,
                                0,
                                0,
                                0.28004354567447681,
                                0,
                                0,
                                0,
                                0.26208972484127302,
                                0,
                                -0.27589125048964785,
                                -0.73637134166025509,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37874152155902246,
                                0,
                                0,
                                0.32157219601794196,
                                0,
                                0,
                                0,
                                -0.0039469401209497636,
                                0,
                                0,
                                0,
                                0.78579226819033088,
                                0,
                                0,
                                0,
                                0.061083231794710438,
                                0,
                                0,
                                0,
                                0.028692754319855483,
                                0,
                                -0.26959635575364654,
                                0.018815604638863438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44890488780325916,
                                0,
                                0,
                                0,
                                0,
                                -0.24295208644756949,
                                0,
                                0,
                                0.80503408721338521,
                                -0.61372251834050784,
                                0.30421515015031875,
                                0,
                                0,
                                0,
                                -0.41575583840204766,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.92244335404626165,
                                0,
                                0,
                                0.030444747330422572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4757432833291349,
                                0,
                                -0.69943748469595479,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28702152666312575,
                                0,
                                0,
                                0,
                                -0.40098031712860904,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22558551567200247,
                                0,
                                0.56550749146388457,
                                0,
                                -0.47732409559196776,
                                0,
                                0,
                                0,
                                0.46668339800554764,
                                0,
                                0,
                                0,
                                0.42851640795491547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38725733763669046,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57347567992498405,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.056475956201214254,
                                0,
                                0.34139150471517266,
                                0,
                                0,
                                0,
                                1.1081033433611709,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30669261154411886,
                                0,
                                0,
                                0,
                                0.040974411306992031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29184166219701047,
                                0,
                                0.84310062564720611,
                                0,
                                -0.34167350451475098,
                                0,
                                0,
                                0,
                                0.32700346133291069,
                                0,
                                0,
                                0,
                                -0.52156463304409495,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33359199876538487,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17433851079545945,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69231797121385563,
                                0,
                                0.0075735448463498667,
                                0,
                                0,
                                0,
                                -0.1877016924923689,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29216423552086995,
                                0,
                                0,
                                0,
                                -0.84264241312573729,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.065807961350028352,
                                0,
                                -0.90521679073041561,
                                0,
                                -0.40187765435428013,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7601429700231761,
                                0,
                                0,
                                -0.35368039072830326,
                                0.2391989850392951,
                                -0.30253194078771845,
                                0,
                                0,
                                0,
                                0.30005231553456507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18198516203454435,
                                0,
                                0,
                                0.52634905793524933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.81689321288320949,
                                0,
                                0,
                                0,
                                0.1983582935115808,
                                0,
                                0,
                                0,
                                -0.74481257214072638,
                                0,
                                0,
                                0,
                                -0.28117457217623548,
                                0,
                                0,
                                0,
                                0.28579403195609454,
                                0,
                                0,
                                0,
                                0.24557055352153856,
                                0,
                                0.030330211814967395,
                                0.31218155076697757,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29408963241023683,
                                -0.30478940731506265,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62702674949040316,
                                0,
                                0,
                                0.15012056414952651,
                                0,
                                0,
                                0,
                                0,
                                -0.70012831026442668,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3311714673513857,
                                0,
                                0,
                                0.43606782788037984,
                                0,
                                0,
                                0,
                                0.41424263521052246,
                                0,
                                0,
                                0.21040226592996145,
                                0,
                                0,
                                0,
                                0,
                                -0.54848762610890511,
                                0,
                                0,
                                -0.81708154415328016,
                                0.48000384543627972,
                                0,
                                0,
                                0,
                                0,
                                0.40857076006972337,
                                0,
                                0,
                                0,
                                0.8486753441501006,
                                0,
                                0,
                                0,
                                0.054069312615429022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24378832396648015,
                                0,
                                0,
                                0.43605377998063199,
                                0,
                                0,
                                0,
                                0,
                                -0.46909795039189128,
                                0,
                                0,
                                0,
                                -0.020097890896599187,
                                0.34195531651948552,
                                0,
                                0.091859899869960085,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6233756754916091,
                                0.12648568807249538,
                                0,
                                0,
                                0,
                                -0.12514419537747243,
                                0,
                                0,
                                -0.95354010800128441,
                                0.08013013322958451,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.045770877384239045,
                                -0.040550250131796861,
                                0,
                                0,
                                0,
                                0,
                                -0.25483339369588115,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.88955760639981452,
                                0,
                                0,
                                0.20447919736328657,
                                0,
                                0,
                                0,
                                0,
                                0.38619082102243174,
                                0,
                                0,
                                0.24680624528530004,
                                -0.96902193907494805,
                                0,
                                0,
                                0,
                                0,
                                -0.055532819615004808,
                                0,
                                0,
                                0,
                                -0.030593570328655173,
                                0,
                                0,
                                0,
                                -0.34223074531115499,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22551692293586242,
                                0,
                                0,
                                -0.58402063097360923,
                                0,
                                0,
                                0,
                                0,
                                -0.04269292192739535,
                                0,
                                0,
                                0,
                                -0.6610096436845383,
                                -0.16848622678790609,
                                0,
                                -0.027947280669719646,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37197471089141287,
                                -0.042092051307346431,
                                0,
                                0,
                                0,
                                0.28133437536723849,
                                0,
                                0,
                                -0.059288458036059713,
                                0.055793207197238459,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.93589276551998668,
                                0.17163499478917518,
                                0,
                                0,
                                0,
                                0,
                                -0.094176037409468033,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55924647699273455,
                                0,
                                0,
                                -0.062959521631047816,
                                -0.49084278274295245,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26933141525499421,
                                0.56116832152755969,
                                0,
                                0,
                                0,
                                0,
                                -0.23431505053462087,
                                0,
                                0,
                                0,
                                0,
                                0.96409448524572872,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.9898356222562934,
                                0,
                                0,
                                -0.047310674386280969,
                                0,
                                0,
                                0,
                                0,
                                -0.080089357672067291,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18272339997207479,
                                0,
                                0,
                                0.58644778094101191,
                                0,
                                0,
                                0,
                                -0.20954373996346426,
                                0,
                                0,
                                0.55604770536702253,
                                0,
                                0,
                                0,
                                0,
                                -0.033635412571433383,
                                0,
                                0,
                                -0.5703224089286687,
                                -0.46086394344978887,
                                0,
                                0,
                                0,
                                0,
                                -0.54959426134501754,
                                0,
                                0,
                                0,
                                -0.85127350505171473,
                                0,
                                0,
                                0,
                                0.41939426237301475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44929361935728929,
                                0,
                                0,
                                -0.28802148008300232,
                                0,
                                0,
                                0,
                                0,
                                0.29896645386527765,
                                0,
                                0,
                                0,
                                0.54368347958166607,
                                0.14483892882530866,
                                0,
                                -0.0094487091354396452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28685042625924517,
                                -0.4762934428019287,
                                -0.44212642231726063,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.96731005940427861,
                                0,
                                0,
                                -1.0050781509806506,
                                0,
                                0,
                                0,
                                0,
                                0.20298761049884617,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14311923931470638,
                                0,
                                0,
                                -0.19536741553902218,
                                0,
                                0,
                                0,
                                0.24749310670820077,
                                0,
                                0,
                                0.582383855702583,
                                0,
                                0,
                                0,
                                0,
                                0.31393644657104702,
                                0,
                                0,
                                0.60582401008982845,
                                0.81263297989894023,
                                0,
                                0,
                                0,
                                0,
                                -0.98364271360685218,
                                0,
                                0,
                                0,
                                -0.41439623508692702,
                                0,
                                0,
                                0,
                                0.32171216580558593,
                                0,
                                0,
                                0,
                                0,
                                0.64826956688797099,
                                0,
                                0,
                                -0.63975794003478248,
                                0,
                                0,
                                0,
                                0,
                                -0.062710662898395664,
                                0,
                                0,
                                -0.8037381379026558,
                                0.40427842843172268,
                                0,
                                0,
                                0,
                                0,
                                0.17771849702508982,
                                0,
                                0,
                                0,
                                -0.77401020883982907,
                                0,
                                0,
                                0,
                                0.60182020181948925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75482810645023468,
                                0,
                                0,
                                -0.073924055961055224,
                                0,
                                0,
                                0,
                                0,
                                -0.048780976875650986,
                                0,
                                0,
                                0,
                                0.080078357304352532,
                                -0.10284451289558939,
                                0,
                                0.28413470634971771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40802574683264847,
                                -0.39772239236180984,
                                0,
                                0,
                                -0.2907250165778178,
                                0,
                                0,
                                -0.27892540463206605,
                                0,
                                0,
                                0,
                                0,
                                -0.2374695667902324,
                                0,
                                0,
                                0,
                                0.10199898440921369,
                                0.40881170390225008,
                                0,
                                -0.7766148299071387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.020737772314251196,
                                0.01401202822231476,
                                0.20399165278173276,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59134835113852358,
                                0,
                                0,
                                -0.89662182679340963,
                                0,
                                0,
                                0,
                                0,
                                0.54724618116378709,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80763234633922021,
                                0,
                                0,
                                0.95282196856358703,
                                0,
                                0,
                                0,
                                0,
                                -0.09534870165786663,
                                0,
                                0,
                                -0.2145792426429127,
                                0,
                                0,
                                0,
                                0,
                                0.16659226020846538,
                                0,
                                0,
                                0,
                                0.39462804432104265,
                                -0.33305891202235166,
                                0,
                                -0.038906415987220867,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36856541920132463,
                                0.71630837135929581,
                                0,
                                -0.01352815883880612,
                                0,
                                0,
                                0.92255941177462952,
                                0,
                                0,
                                0,
                                0,
                                -0.30147951361991215,
                                0,
                                0,
                                0.28243346636483529,
                                0.3844128870806634,
                                0,
                                0,
                                0,
                                0,
                                0.79645693282859753,
                                0,
                                0,
                                0,
                                -0.43617856723747739,
                                0,
                                0,
                                0,
                                -0.19144368439916021,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35297182358578422,
                                0,
                                0,
                                -0.0080056491176485611,
                                -0.85342846597861588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20934481209409572,
                                -0.31694452573435533,
                                0,
                                0,
                                0,
                                0,
                                -0.052226162509128767,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30846440759466026,
                                0,
                                0,
                                -0.28692416625150036,
                                -0.14424687170920952,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0041697538016210456,
                                -0.091877846106745875,
                                0,
                                0,
                                0,
                                0,
                                0.89065040651104055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.045373862435057359,
                                0,
                                0.31433584612415355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46107103473506517,
                                0,
                                0,
                                -0.35191720879037575,
                                0,
                                0,
                                0,
                                0,
                                -1.032302555691734,
                                0,
                                0,
                                0.00098953845954584396,
                                -0.60596052959986668,
                                0,
                                0,
                                0,
                                0,
                                -0.15055835903262871,
                                0,
                                0,
                                0,
                                -0.45630346682646056,
                                0,
                                0,
                                0,
                                -0.43700892929177615,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39564878868768882,
                                0,
                                -0.13194877761444321,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49485819036357293,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.113510523812929,
                                0,
                                0,
                                0.551608751679172,
                                0,
                                0,
                                0,
                                0,
                                0.26956803448553429,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65601129570159666,
                                0,
                                0,
                                -0.69321498661535719,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61048659164068952,
                                0,
                                0,
                                -0.02987762064962185,
                                -0.019807470002605406,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.07501806309210815,
                                0.73830335885306642,
                                0,
                                0,
                                0,
                                0,
                                0.27441128595510805,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1087519894728417,
                                0,
                                0,
                                0.25372698679148364,
                                0,
                                0,
                                0,
                                0,
                                -0.9539880437222914,
                                0,
                                0,
                                0.56498000100044443,
                                -0.37635817075761124,
                                0,
                                0,
                                0,
                                0,
                                0.46875955383085116,
                                0,
                                0,
                                0,
                                -0.12776782308863577,
                                0,
                                0,
                                0,
                                0.96579167133669608,
                                0,
                                0,
                                0,
                                -1.0477755092962198,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39066297163920749,
                                0,
                                0,
                                0.52792327322642429,
                                0,
                                0,
                                0,
                                0,
                                1.0437165803031887,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17744613094886952,
                                0,
                                0,
                                0.60269772103571984,
                                0,
                                0,
                                0,
                                0,
                                -0.099639769012302981,
                                0,
                                0,
                                -0.37986120594005485,
                                0,
                                0,
                                0,
                                0,
                                0.071653345641733202,
                                0,
                                0,
                                0,
                                -0.0035434065613748275,
                                0.68735845886677249,
                                0,
                                0.51424642263423859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15195975455424196,
                                0.28395038617551971,
                                0,
                                0,
                                -0.12057632497259611,
                                0,
                                0,
                                0.33498909836329271,
                                0,
                                0,
                                0,
                                0,
                                0.77271270525283009,
                                0,
                                0,
                                0,
                                -0.30742546176875957,
                                0.26945638728774157,
                                0,
                                -0.20215145909319115,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25476874632377383,
                                0.057177296752423772,
                                0.38407158469207631,
                                0,
                                0,
                                0,
                                0,
                                0.080287288587166453,
                                0,
                                0,
                                0,
                                0,
                                -0.89559083279517748,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1385113745924772,
                                0,
                                0,
                                0,
                                0,
                                0.10943512451593077,
                                0,
                                0,
                                -0.11313081793819191,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34311438807304467,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30719386747246485,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47874403913973418,
                                0,
                                0,
                                0,
                                0.16754272706710047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.5745323019584077,
                                0,
                                -0.016267794362308893,
                                0,
                                0,
                                -0.6994528574245471,
                                0.035209407142186289,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6539661051258514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.86301569006847889,
                                0,
                                0,
                                0.33247717258949566,
                                0,
                                -0.38100579654431854,
                                0.65305067254968341,
                                0,
                                0,
                                0.15849776318008058,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43105647773422179,
                                -0.36104800211816579,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.092482741460175183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12022969065140252,
                                0,
                                0,
                                -0.33744150537815426,
                                0,
                                -0.038658589951121425,
                                -0.062114078688302349,
                                0,
                                0,
                                1.0026781429398268,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46658040860887889,
                                0,
                                -0.20773172805723306,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.075357307771588389,
                                0,
                                0,
                                0,
                                0,
                                0.78520988888943211,
                                0,
                                0,
                                0,
                                0,
                                0.044300010453202879,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43975502459570642,
                                0,
                                0,
                                0,
                                0,
                                -0.070112476465905488,
                                0,
                                0,
                                0.42131220563396571,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14370362782305668,
                                0,
                                -0.17298880360879301,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.9394998336060979,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29810161489559939,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2308928174509519,
                                0,
                                0,
                                0,
                                0.52112924484788969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49084017283735798,
                                0,
                                -0.36011959543064453,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28195463021439932,
                                0.36118352502446072,
                                0,
                                0,
                                -0.065971174117372133,
                                -0.14587308132540527,
                                0.32768468114119398,
                                0,
                                0,
                                0,
                                0.0097790059500151919,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61840900333882931,
                                0,
                                0,
                                -0.52394114312513351,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28173562682521919,
                                0.010327096874401226,
                                0,
                                0,
                                0.060545754400347901,
                                -0.46840905982806702,
                                -0.18655425972505563,
                                0,
                                0,
                                0,
                                0.46675114600377215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33937204281555255,
                                0,
                                0,
                                0.57411936422701093,
                                0,
                                -0.28894829395074118,
                                0,
                                0,
                                0,
                                0,
                                -0.037402941124333525,
                                0,
                                0,
                                0,
                                0,
                                -0.30161488840458572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59917399786489811,
                                0,
                                0,
                                0,
                                0,
                                0.035628093740450062,
                                0,
                                0,
                                0.68107233223051511,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.9219353245295937,
                                -0.088080010503864159,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36157874639621435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29840192721666497,
                                0,
                                0,
                                -0.39076104299738967,
                                0,
                                -0.33209513669311835,
                                -0.6430781349875323,
                                0,
                                0,
                                -0.37955764118253899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3598651297797692,
                                -0.1739826509859238,
                                0,
                                0,
                                -0.53981607131189735,
                                -0.36442844707014338,
                                -0.54317160306867218,
                                0,
                                0,
                                0,
                                -0.13789711583790112,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20400806241320896,
                                0,
                                0,
                                -0.245656970545794,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18444033252141512,
                                0.74293412116690183,
                                0,
                                0,
                                -0.071803860373561748,
                                -0.43637799905267005,
                                0.063047877845518407,
                                0,
                                0,
                                0,
                                -0.020339438367234404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46108153381826944,
                                0,
                                0,
                                0.038264793759644998,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41797972094608549,
                                0.058182282824838782,
                                0,
                                0,
                                -0.39795616796592292,
                                0.13849333361741545,
                                0.50165633809003962,
                                0,
                                0,
                                0,
                                -0.20423648016254389,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31128525730844214,
                                0,
                                0,
                                0.50407154945688071,
                                0,
                                0,
                                -0.049826960096532522,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7606129381081439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1807350520285366,
                                0,
                                0,
                                0,
                                -1.254657573344574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.058706469395060974,
                                0,
                                0.81593516942064415,
                                -0.83642131190572344,
                                0,
                                0,
                                0,
                                0,
                                0.0058337168193014453,
                                0,
                                0,
                                0,
                                0,
                                -0.31908269214793172,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16467767909851186,
                                0,
                                0,
                                0,
                                0,
                                -0.23844288075683984,
                                0,
                                0,
                                -0.33849349614537066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72190720943654518,
                                -0.40359300041306889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49565673667772875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16216068370871073,
                                0,
                                0,
                                -0.026401681435441905,
                                0,
                                0.44014857127685769,
                                -0.16021480289451601,
                                0,
                                0,
                                -0.38255180177791603,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47841452089083075,
                                -0.35897004853646552,
                                0,
                                0,
                                0.49358631490465066,
                                -0.49375226518409299,
                                0.34715538113945865,
                                0,
                                0,
                                0,
                                0.061948149096263956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.033925861715697447,
                                0,
                                0,
                                -0.1712772748944309,
                                0,
                                0,
                                -0.69773179669637786,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52349943580193992,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87303316831806055,
                                0,
                                0,
                                0,
                                -0.74041451054226282,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22793248301283936,
                                0,
                                -0.51677414246624986,
                                0,
                                0,
                                -0.25581060037112291,
                                0.76720608704752957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38441277765796888,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47423150651111423,
                                0,
                                0,
                                -0.90248929350227391,
                                0,
                                0.1865737000508132,
                                0.47417768878839556,
                                0,
                                0,
                                -0.42588191030973466,
                                0,
                                0,
                                0,
                                0.14858683708996084,
                                0,
                                0,
                                0,
                                0,
                                0.54244132776797271,
                                0,
                                0,
                                0,
                                0,
                                0.02439126099081048,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60963718304732473,
                                0,
                                0,
                                0,
                                0,
                                -0.37523379834606718,
                                0,
                                0,
                                -0.4130696379366362,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50150812227115737,
                                -0.14031909721426652,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20909801779179132,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34727606962009894,
                                0,
                                0,
                                0.13322187651888573,
                                0,
                                1.1158004260543286,
                                0.32347424628677351,
                                0,
                                0,
                                0.48294285649993351,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4210004856549624,
                                -1.0097678873919274,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35818787647206901,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1737111063555247,
                                0,
                                0,
                                -0.40681104711137012,
                                0,
                                0.050540994429690025,
                                0.69846675001147596,
                                0,
                                0,
                                -0.025595365019165345,
                                0,
                                0,
                                0,
                                0.20406008491128719,
                                0,
                                0,
                                0,
                                0,
                                -0.28517323744385148,
                                0,
                                0,
                                0,
                                0,
                                -0.050737859027384688,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17217550576890278,
                                0,
                                0,
                                0,
                                0,
                                -0.88554131597435037,
                                0,
                                0,
                                0.24623880475819704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5170281179754771,
                                -0.36652712045495017,
                                0,
                                0,
                                -0.33121075473204847,
                                -0.40318018011074241,
                                0.33696763346545916,
                                0,
                                0,
                                0,
                                -0.348516688823925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30036441631739375,
                                0,
                                0,
                                0.029242478137843024,
                                0,
                                0,
                                0,
                                -0.52846542231248639,
                                -0.23270195881153405,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0805244666965581,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79661819208918883,
                                0,
                                0,
                                0.042205329359496724,
                                0,
                                0.2835091278812526,
                                -0.19821982267298299,
                                0,
                                0,
                                0.57362983471311546,
                                0,
                                0,
                                0,
                                0,
                                0.11356799963311115,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23684023355704553,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52587400584596755,
                                0,
                                0,
                                0,
                                -0.84173347237414042,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15165286686590915,
                                0,
                                -0.88420654482833438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.081852913738041821,
                                0.1436382166171164,
                                0,
                                0,
                                0.42863469839137264,
                                -0.10273356442483764,
                                -0.27034553156934682,
                                0,
                                0,
                                0,
                                -0.77175412926842102,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24477171545431806,
                                0,
                                0,
                                0.22311866382338033,
                                0,
                                0,
                                0.92385538262267475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2689418687749894,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.021840346578422945,
                                0,
                                0,
                                0,
                                -0.21935695553564208,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.013268162255698268,
                                0,
                                0.44955324925480167,
                                -0.0063108263287873917,
                                0,
                                0,
                                0.31198990685905043,
                                0,
                                0.21538855461632345,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32448183241178841,
                                0,
                                0,
                                0.029001050380593363,
                                -0.73217076556434091,
                                0.41995844868385873,
                                0,
                                0,
                                0,
                                0,
                                -0.19406595006054947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.4480477190706549,
                                0,
                                0,
                                0,
                                0,
                                -0.58728336280111981,
                                -0.29218060393603357,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11234360850091429,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.06265621203937416,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50014108169126426,
                                0,
                                0,
                                0,
                                0,
                                0.59722220866398612,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32591117417963128,
                                0.14541599220465404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3607759418603495,
                                0.45463093555784695,
                                0.54863562499032836,
                                0,
                                0,
                                0,
                                -0.3861508496732512,
                                -1.1586594719474652,
                                -0.32854773973944984,
                                0,
                                0,
                                -0.44385325178863005,
                                0,
                                -0.1293645575880959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19660372403640977,
                                0,
                                0,
                                -0.35967546391157401,
                                -0.4552964086464244,
                                -0.54888660701268521,
                                0,
                                0,
                                0,
                                0,
                                -0.041529436542935415,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23827813006454493,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46521443093001918,
                                -0.36347738847581057,
                                0.072260486953472591,
                                -0.19593731468511841,
                                0,
                                0,
                                0,
                                -0.74234105692292063,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61029058384772483,
                                0,
                                0,
                                0.61357390081820695,
                                0,
                                -0.074429155261003063,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32521954325176655,
                                0,
                                0,
                                0.1857845713365526,
                                -0.088990590780300804,
                                -0.28698808817488658,
                                0,
                                0,
                                0,
                                0,
                                0.12234224980507889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.087739973912614955,
                                0,
                                0,
                                0,
                                0,
                                0.56605789695238584,
                                0.96298921504078117,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0042514043452348965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1569385094085283,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.450586598092489,
                                0,
                                0,
                                0,
                                0.060613873011396979,
                                0,
                                0,
                                0,
                                0,
                                0.10831427376367841,
                                -0.83753883023656417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0075808059510689,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26044025836157358,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43297410975300099,
                                0,
                                0,
                                0,
                                0,
                                0.33399132068551135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31582316291661172,
                                -0.28494752674897927,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49089638314113981,
                                -0.31951633816094982,
                                0.80240705853039729,
                                0,
                                0,
                                0,
                                0.96341492263893547,
                                0.24177089694300169,
                                0,
                                0,
                                -0.2018797687498409,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.073758791743908106,
                                -0.87726220492234686,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32707823478444442,
                                0.19985386660470641,
                                -0.66237170966661452,
                                0,
                                0,
                                0,
                                0.34826235580704645,
                                0.12789617024382052,
                                0,
                                0,
                                0,
                                0,
                                -0.37621223159939227,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38035374063754246,
                                0.4861124341181246,
                                0.075987521162509661,
                                -0.62141000109896694,
                                0,
                                0,
                                0,
                                0.29251597791496192,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.83495828849198972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25089073244596649,
                                -0.1610791798628175,
                                0.19259357189671067,
                                -0.4096823182181541,
                                0,
                                0,
                                0,
                                0.094974253718785512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.096724276891039976,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72049949717471784,
                                0.039646105535931266,
                                -0.44096591869140084,
                                0.46976028361422945,
                                0,
                                0,
                                0,
                                0.23415253498103689,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0063310062756847807,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22558045183053299,
                                -0.23581217916115021,
                                -0.84276696955966668,
                                -0.42801966161885324,
                                0,
                                0,
                                0,
                                0.0029997595967361512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67168263372581871,
                                0,
                                0,
                                0,
                                0,
                                0.081789939258114619,
                                -0.8779009781660756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0500017115782967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69290668429059421,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50445125024859672,
                                0,
                                0,
                                0.10773263324565607,
                                0,
                                0,
                                -0.07550769809175549,
                                0,
                                -0.50988969030084119,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.052276690013240736,
                                0,
                                0,
                                0.1498447296546089,
                                -0.25163345632827921,
                                0.18744742999929564,
                                0,
                                0,
                                0,
                                0,
                                0.77399130505884461,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0045117590814959642,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.040244304499310934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30844266667554021,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.077164369582894882,
                                0.74057625519076953,
                                -0.21726695167179824,
                                0.061180246762553049,
                                0,
                                0,
                                0,
                                -0.54727291254536792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29750665917814051,
                                0,
                                0,
                                -0.2625893562333077,
                                0,
                                -0.4444091683052791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48107932252311297,
                                0,
                                0,
                                -0.14510154720298535,
                                -0.072822911745728386,
                                0.50576419163125552,
                                0,
                                0,
                                0,
                                0,
                                -0.36255308755037235,
                                0,
                                0,
                                0,
                                0,
                                -0.52598201106453146,
                                0,
                                0,
                                -0.32623245896792463,
                                0,
                                0.57497476245128942,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.026772623593224479,
                                0,
                                0,
                                -0.041843809625221939,
                                0.13577238071047915,
                                0.33810637324032883,
                                0,
                                0,
                                0,
                                0,
                                0.38871788295472021,
                                0,
                                0,
                                0,
                                0,
                                -0.33126949123985011,
                                0,
                                0,
                                0.21008894359726568,
                                0,
                                -0.36652769036114724,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68279288964378504,
                                0,
                                0,
                                -0.21403339414345293,
                                0.40197849393960411,
                                0.17303512950627123,
                                0,
                                0,
                                0,
                                0,
                                -0.090754187564636185,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27596069008500079,
                                0,
                                0,
                                0,
                                0,
                                1.0940515299907092,
                                -0.35755896038963053,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24151372228387882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83556072860794239,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19436562333342827,
                                0,
                                0,
                                0,
                                0,
                                -0.37211265067214871,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.95718706606542991,
                                0.58985450356952041,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44858385066954998,
                                0.64896330048499751,
                                0.22287118925441596,
                                0,
                                0,
                                0,
                                -0.16701924862462969,
                                0.028824465352900341,
                                0,
                                0,
                                -0.64454259295266947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.076686334849585536,
                                0.19407949874642527,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36438264683876648,
                                -0.85519855321826177,
                                -0.42945609286585124,
                                0,
                                0,
                                0,
                                0.39929862651261327,
                                -0.74668134649173479,
                                0,
                                0,
                                -0.79779225188060132,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18980017172297026,
                                -0.4032878600926737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.035019226036817286,
                                -0.37671496954645045,
                                0.29498817203135597,
                                0,
                                0,
                                0,
                                -1.1749654488010248,
                                0.27592291380169065,
                                -0.1817934958648702,
                                0,
                                0,
                                -0.32243463391090049,
                                0,
                                -0.094378769970737769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22180553288095214,
                                0,
                                0,
                                0.86267461569912207,
                                -0.0082706291527377337,
                                -0.069319543046198279,
                                0,
                                0,
                                0,
                                0,
                                -0.23622212036944384,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61813418578927826,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19960817405086381,
                                0,
                                0,
                                0,
                                0,
                                -0.67805335596163518,
                                0,
                                0,
                                0,
                                0,
                                1.0469801062588333,
                                -0.46337362338858351,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2199640496979457,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.85213912541289005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0079981043042797236,
                                0,
                                0,
                                0,
                                0,
                                0.65618921946864739,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.75456331942073684,
                                -0.56797574494785619,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79700909876634762,
                                -0.65508201803070232,
                                -0.22952337087268723,
                                0,
                                0,
                                0,
                                0.14019600209816768,
                                -0.52709951011535294,
                                0,
                                0,
                                -0.84297332452844387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45795835464182466,
                                0.073321375598355429,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28705473310649582,
                                0.41626651019874789,
                                0.46480994488000132,
                                0,
                                0,
                                0,
                                0.4639387649083786,
                                -0.60450002976753769,
                                -0.32709757340879492,
                                -0.080301875164427383,
                                0,
                                0.44330632408776638,
                                0,
                                0,
                                -0.80353900380917631,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21047712202843832,
                                0,
                                -0.007920845847017563,
                                0,
                                0,
                                0,
                                0,
                                0.19590233566996076,
                                0.47088387525766856,
                                0,
                                -0.56456632411981689,
                                0,
                                0,
                                -0.40667381713845013,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1389288931230046,
                                0,
                                0.48628251632242719,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26002387780945113,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10698865012218496,
                                0,
                                0.52197119907510914,
                                -0.53960105121118151,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12568895610661179,
                                0,
                                0,
                                0.24898928839440818,
                                0,
                                0,
                                0.18210470961818215,
                                0,
                                0,
                                -0.49634894972631033,
                                0,
                                0,
                                0.033002914966645369,
                                0.43772400539888007,
                                0,
                                -0.18525042110828521,
                                0,
                                0,
                                -0.25043761347586457,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3760158086842228,
                                0,
                                -0.75424392444124744,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57108689186500816,
                                0,
                                0,
                                -0.13348669365514051,
                                0,
                                0,
                                0.34583756561086032,
                                0,
                                0,
                                -0.83046407300876257,
                                0,
                                -0.20247221326202708,
                                0.49858998464498872,
                                0.7657279338509998,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71959982856687077,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50470607051733818,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68799929844126118,
                                0,
                                0,
                                0,
                                0,
                                0.43583058746390735,
                                0,
                                0,
                                0.61163929362939207,
                                0,
                                0,
                                0,
                                -0.46398405500365403,
                                0,
                                -0.57156726963127191,
                                0,
                                0.67692135057937164,
                                -0.4411116251302668,
                                0,
                                0.067929285627959968,
                                0,
                                0,
                                -0.32047309534384572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47900590369162832,
                                0,
                                0.10214681026886656,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19574887326009288,
                                0,
                                0,
                                0.92872885693660501,
                                0,
                                0,
                                -0.059839563871241404,
                                0,
                                0,
                                0.033431658635894583,
                                0,
                                0.43540071321126572,
                                -0.28819167530264933,
                                -0.021736609289996232,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37448594719474682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34278536805400378,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28881514968987976,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.083374537195366721,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4552160617343507,
                                0,
                                -0.18551295558665779,
                                0.20120860689699804,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62237850150990048,
                                0,
                                0,
                                0.3399407070583334,
                                0,
                                0,
                                -0.0019859662370575182,
                                0,
                                0,
                                -0.45607941850918049,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.90320037934567066,
                                0,
                                0,
                                0.047150909974115002,
                                0,
                                0,
                                0.18631834189688085,
                                0,
                                0,
                                -0.24422358011313805,
                                0,
                                -0.37096083083315701,
                                -0.31772946155669834,
                                0.73095452235861746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47077257289623259,
                                0,
                                0,
                                -0.42687660351336654,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.015469068811546645,
                                0,
                                -0.68310881017526737,
                                -0.4590448877504883,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.093797773736796888,
                                0,
                                0,
                                -0.28525603881274786,
                                0,
                                0,
                                -0.14390421262166975,
                                0,
                                0,
                                -0.17117174219677883,
                                0,
                                0,
                                0,
                                0,
                                0.23448203998314465,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79458692278754972,
                                0,
                                0.17951244550208134,
                                -0.18471837677556369,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35516026396485906,
                                0,
                                0,
                                -0.16307912781047623,
                                0,
                                0,
                                -0.30738664987074649,
                                0,
                                0,
                                -0.0091668263790140141,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2561830329284347,
                                0,
                                0,
                                -0.12863962679543695,
                                0,
                                0,
                                0.4132995161157621,
                                0,
                                0,
                                -0.37885925931107078,
                                0,
                                0.79504694912633911,
                                -0.43945251178499101,
                                0.13663774277938173,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27812193465367679,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57747895848266995,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.053238981190487061,
                                0,
                                0,
                                0,
                                0,
                                0.30021725135491056,
                                0,
                                0,
                                -0.40999045565356218,
                                0,
                                0,
                                0,
                                -0.79271822280217119,
                                0,
                                0.052288592060587169,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47612617866698881,
                                0,
                                0,
                                -0.67491596220792749,
                                0,
                                0,
                                0.15020109592705363,
                                0,
                                0,
                                0.6679812718918765,
                                0,
                                0.32284470463983261,
                                -0.14832016333427853,
                                -0.33851265338173647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36563073897562015,
                                0,
                                0,
                                0,
                                0,
                                0.41947015931400611,
                                0,
                                0,
                                0.3244980868433282,
                                0,
                                0,
                                0.62411285729669952,
                                0,
                                0,
                                0.48768127497054892,
                                0,
                                -0.099909195453738095,
                                0.38342881768044929,
                                0.55151247635756018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.020777807298444889,
                                0,
                                0,
                                0,
                                0,
                                0.12308989319891418,
                                0,
                                0,
                                0.056932606758411913,
                                0,
                                0,
                                0.35253595948579747,
                                0,
                                0,
                                -0.21123598774859376,
                                0,
                                -0.55418161905766772,
                                -0.83140139471253538,
                                -0.0434496585822267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39879105417511929,
                                0,
                                0,
                                0.24999079035381386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.069196221324105814,
                                0,
                                -0.21681995187172409,
                                0.27341847874728625,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37673445709845299,
                                0,
                                0,
                                -0.22247025982161656,
                                0,
                                0,
                                0.64539218414372057,
                                0,
                                0,
                                -0.45054965610733538,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13956689926588473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53215456639792624,
                                0,
                                0,
                                0,
                                0,
                                -0.9629313776542332,
                                0,
                                0,
                                0.18689845897619919,
                                0,
                                0,
                                0,
                                -0.70951675900386146,
                                0,
                                0.13729173022392052,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14291604691477761,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17756493451895008,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21580423465280293,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17534608117606398,
                                0,
                                -0.25612910628555458,
                                0.034173862589260515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41511745584799942,
                                0,
                                0,
                                0.73795193106746426,
                                0,
                                0,
                                0.19721965974943184,
                                0,
                                0,
                                0.31641928393131918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37087136391553632,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22320858539914376,
                                0,
                                0,
                                0,
                                0,
                                -0.029910684836142898,
                                0,
                                0,
                                0.84302622803641758,
                                0,
                                0,
                                0,
                                -0.30227283839686336,
                                0,
                                1.0189508213623959,
                                0,
                                -0.28568456793542052,
                                -0.6206480136350635,
                                0,
                                -0.66614653218446718,
                                0,
                                0,
                                -0.15332801499052892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12854401779716015,
                                0,
                                -0.22225238757016211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62641329937593537,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31758120738434559,
                                0,
                                -0.2586856078460526,
                                -0.14376483982863697,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13988982722892343,
                                0,
                                0,
                                0.34659247722310321,
                                0,
                                0,
                                -0.42046675160747971,
                                0,
                                0,
                                -0.32042812605397264,
                                0,
                                0,
                                -0.56009112894794866,
                                0.020838841396382257,
                                0,
                                -0.045398898505538798,
                                0,
                                0,
                                0.0031610991301546376,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74097235784806625,
                                0,
                                0.36708661421375843,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.99067113853545996,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37382476427412875,
                                0,
                                0,
                                0,
                                0,
                                -0.085704396319743775,
                                0,
                                0,
                                0.61239169041301889,
                                0,
                                0,
                                0,
                                0.80338518290180705,
                                0,
                                -0.68054042305916096,
                                0,
                                0,
                                0,
                                -0.43216932240011913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11546387927044727,
                                0,
                                0.12139765934075084,
                                0.57175944922510591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35789654180563585,
                                0,
                                0,
                                -0.016924124911406796,
                                0,
                                0,
                                -0.46842288692070683,
                                0,
                                0,
                                -0.33234793252984762,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.082209602120541028,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47821014909210119,
                                0,
                                0,
                                0,
                                0,
                                -0.33596879155413117,
                                0,
                                0,
                                0.74331870931736499,
                                0,
                                0,
                                0,
                                -0.75515511136797697,
                                0,
                                -1.2377920529112327,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15377281027747094,
                                0,
                                0,
                                -0.31173348467074447,
                                0,
                                0,
                                -0.4772698016911423,
                                0,
                                0,
                                0.065524889862335081,
                                0,
                                -0.10041145202180721,
                                -0.14068522111779028,
                                1.2243753874417709,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48052035544386706,
                                0.15773193268889857,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.045938841977814199,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30695325292894471,
                                0,
                                0.7973131351703846,
                                0,
                                0,
                                0,
                                0.022587830494925625,
                                -0.39717129544366925,
                                0,
                                0,
                                -0.13461271086065885,
                                0,
                                -0.25827484444472687,
                                0,
                                0,
                                0.24691840181008956,
                                0,
                                -0.29700579808900335,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29972800342552464,
                                0,
                                0,
                                0.018882593730413733,
                                0.29005406403392198,
                                0.51976795133008402,
                                -0.15348584905678855,
                                0,
                                0,
                                -0.26765045339089827,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52653621112806193,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.85002096711481467,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46378319422480213,
                                0,
                                0.048235463752404673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0039368692293011362,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19598410703303409,
                                0,
                                0,
                                0,
                                0,
                                -0.13217778415548664,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.96385929811781224,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.041444603784010131,
                                0,
                                0.1155913598669637,
                                0,
                                0,
                                -0.15746448250538708,
                                0,
                                0,
                                -0.37391094895439925,
                                1.1259247097591574,
                                -0.93807080863754577,
                                -0.41824212229144597,
                                0,
                                0,
                                0.28169634507063601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.071211813109877536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19338613377991659,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29987974023463537,
                                0,
                                0,
                                0.0053036742637221634,
                                0.60187577748936816,
                                0.42713604974155089,
                                0.58565613941461336,
                                0,
                                0,
                                0.2233395969341091,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56495705496727777,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34137244014253565,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34202336230494379,
                                0,
                                0,
                                -0.14373417050899087,
                                -0.015600644644468226,
                                -0.24255175022487135,
                                0.6881083870558814,
                                0,
                                0,
                                0.77661850190721438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79919642300597771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.035840759815011711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55018614863549575,
                                0,
                                0,
                                -0.74100904065310202,
                                -0.069978978103902467,
                                -0.45933936328426939,
                                0.86304763639640691,
                                0,
                                0,
                                -0.77411280872622912,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30698776425155067,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10663691977617856,
                                0,
                                0,
                                0,
                                0,
                                0.57307608224488593,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1765163867036639,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36761361536169179,
                                0,
                                -0.30670078178284732,
                                0,
                                0,
                                0,
                                0.43089938206474632,
                                0.017950123240411422,
                                0,
                                0,
                                -0.47026135895674093,
                                0,
                                0.063862346672088413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50303264833327965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47082079228750229,
                                0,
                                0,
                                0,
                                0,
                                -0.1185927299202089,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13950908958907682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54458072105810695,
                                0,
                                0.44180397558703111,
                                0,
                                0,
                                0.81733413844160507,
                                0,
                                0,
                                -0.71614600591848465,
                                0.34077883152614918,
                                0.00026522675461535493,
                                -0.075470820604312594,
                                0,
                                0,
                                -0.21488193562940683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35261380612672233,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7783915609955907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34006840290423918,
                                -1.2043172654378227,
                                0.34740808704658094,
                                0,
                                0,
                                0,
                                0,
                                0.79100987981507664,
                                -0.069027551346375726,
                                0,
                                0,
                                0,
                                -0.094012740580966564,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.88518993584045003,
                                0.82097793122731955,
                                0.58169677893369864,
                                0,
                                0,
                                0,
                                0,
                                -0.041333164991558397,
                                -0.023820673778660345,
                                0,
                                0,
                                0,
                                -0.44002045080861069,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.85257197880426172,
                                -0.73542273204107889,
                                -0.59192284719112909,
                                0,
                                0,
                                0,
                                0,
                                -0.32018414596480527,
                                -0.22268267282879073,
                                0,
                                0,
                                0,
                                0.51122827286385986,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4582257785529309,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42502555544370013,
                                0,
                                0,
                                0,
                                0,
                                0.47469706461389705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.032936516178114716,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6096643913819445,
                                0,
                                -0.10615849339182387,
                                0.11626263151679839,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26645960679966596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36701919890154572,
                                0,
                                0.21651208766188268,
                                0,
                                0,
                                0,
                                -0.57403095249066061,
                                0.59363978766754544,
                                0,
                                0,
                                -0.087323747100688326,
                                0,
                                0.21060990780090913,
                                0,
                                0,
                                0,
                                0.25926507128096743,
                                0,
                                0,
                                0.95203020011141848,
                                0.11766438934695675,
                                -0.56813183861477368,
                                0.23179286138809141,
                                0,
                                0,
                                -0.34859162496946233,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44407749591891388,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30258195456067627,
                                0,
                                0,
                                0,
                                0,
                                0.030347380549265987,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58323714318329101,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40223352439689619,
                                0,
                                0.11038106228209098,
                                0,
                                0,
                                0,
                                -0.14469602256545419,
                                -0.4085595146532921,
                                0,
                                0,
                                -0.21041827136540464,
                                0,
                                0.50279620062359298,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18919808665069718,
                                0.81596611255806872,
                                -0.67786218911097351,
                                0,
                                0,
                                0,
                                0,
                                0.98090942049114671,
                                -0.16623292934498088,
                                0,
                                0,
                                0,
                                0.17508988334364978,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27946073561418266,
                                0.14135179289813135,
                                -0.52018143091588964,
                                0,
                                0,
                                0,
                                0,
                                0.015910236940534363,
                                1.2191104880702033,
                                0,
                                0,
                                0,
                                -0.67073122799149942,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64734043400865371,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69757336280276583,
                                0,
                                0,
                                0,
                                0,
                                -0.15548924185821142,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.093525856643807387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15898980740472751,
                                0,
                                0.19010527860201018,
                                -0.20479364115358639,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11938475547268354,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.057464267513373357,
                                0,
                                0.40262712193223604,
                                0,
                                0,
                                0,
                                0.67070278721940835,
                                0.42495331705936501,
                                0,
                                0,
                                0.16566229159100737,
                                0,
                                0.34716647019646785,
                                0,
                                -0.017554228285355543,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46138773499787628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40786212742394773,
                                0,
                                -0.068992073750523145,
                                0,
                                0,
                                0,
                                -0.065625166043511124,
                                -0.29874794986084868,
                                0,
                                0,
                                0.19230838315104029,
                                0,
                                0.69653590836451684,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50434982187350008,
                                -0.21558447272249751,
                                0.42414975587951265,
                                0,
                                0,
                                0,
                                0,
                                -0.25603485889379707,
                                0.58782339299387232,
                                0,
                                0,
                                0,
                                1.147605555071372,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.81573982422130231,
                                0,
                                0,
                                -0.38929923309736381,
                                0.8942034569751055,
                                0.081206376673732178,
                                0.064453884845998899,
                                0,
                                0,
                                -0.099265014794202341,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21636121754014692,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67144796059799694,
                                0,
                                0,
                                0,
                                0,
                                -0.19988275022471796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57287317553446715,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48325153645481272,
                                0,
                                -0.19171894471619289,
                                0,
                                0,
                                0,
                                0.089787265844628678,
                                -0.22550798584577539,
                                0,
                                0,
                                0.52605109260634697,
                                0,
                                -0.16102686995103313,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22072952271622315,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16241774421833588,
                                0,
                                0,
                                0,
                                0,
                                -0.52859004496590445,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19625542936176277,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54976310565132225,
                                0,
                                0.55202885127326462,
                                0.74166352084394038,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.01581972457699625,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26638191622629204,
                                0,
                                0.086834743077929488,
                                0,
                                0,
                                0,
                                -0.034005805036484454,
                                0.043751225462981443,
                                0,
                                0,
                                0.60636303111016898,
                                0,
                                0.020944456619192565,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2630601298942789,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21513523289102598,
                                0,
                                0,
                                0,
                                0,
                                -0.66298050850841006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.05625276740735078,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.050062778148261683,
                                0,
                                -0.66279890567950539,
                                -0.59915823811067992,
                                -0.16737831391234256,
                                0,
                                0,
                                0,
                                0,
                                -0.49300956408687729,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87852355564072393,
                                0,
                                0,
                                0,
                                0,
                                -1.0482652792178451,
                                0,
                                0,
                                0,
                                0,
                                -0.34235225870902464,
                                0,
                                0,
                                0,
                                0.66176843067911639,
                                -0.91761284623107386,
                                0,
                                0,
                                0,
                                0,
                                -0.54320933056021437,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4586819395854827,
                                0,
                                0,
                                0,
                                0,
                                -0.12808396931386717,
                                0,
                                0,
                                0,
                                0,
                                -0.065204330840599622,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20118147434905814,
                                0,
                                0,
                                0,
                                0,
                                0.3918638481140943,
                                -0.059234470621229114,
                                -0.53513774003802406,
                                0,
                                0.10834373116883383,
                                0,
                                0,
                                0.040976601108840063,
                                0.55286635676654339,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44385691526757287,
                                0,
                                0,
                                0,
                                0.0063162307282787974,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6237240179316047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.09714744075979817,
                                -0.4296965245757815,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.89018745984017755,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.040400840497690972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0078369742278209219,
                                -0.1086089857545897,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16410482832878964,
                                0.73028306734913173,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40272994899707493,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45560014323225972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25308196163631697,
                                0.077089981347730208,
                                0,
                                -0.066258051412501934,
                                -0.31672557161881254,
                                0,
                                0,
                                0,
                                0,
                                0.47610132101698283,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10093071154530857,
                                0,
                                0,
                                0,
                                0,
                                0.59155714458012143,
                                0,
                                0,
                                0,
                                0,
                                -1.1298282373119106,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.071825771772031435,
                                0,
                                0,
                                0,
                                0,
                                -0.31207588542258335,
                                0.26900985698973195,
                                0.59057253351549799,
                                0,
                                -0.027480631864414101,
                                0,
                                0,
                                -0.074487844495854702,
                                0.66131274809622076,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18074652098071453,
                                0,
                                0,
                                -0.20882593930838844,
                                0,
                                0,
                                0,
                                0,
                                0.69534258441007435,
                                -0.15891133725240988,
                                0.45979632846855578,
                                0,
                                -0.27531685167845044,
                                0,
                                0,
                                -0.37828146325916634,
                                -0.11301424098198568,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.067501760488261564,
                                0,
                                0,
                                -0.50630543271498629,
                                0,
                                0,
                                0,
                                0,
                                -0.15411155890510156,
                                -0.52731229067930385,
                                0.227459693646475,
                                0,
                                -0.03083999680172099,
                                0,
                                0,
                                0.58299588832190863,
                                -0.10535835009068105,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19537804109754664,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20824636099733113,
                                0,
                                0,
                                -0.60011412475851711,
                                0,
                                0,
                                0,
                                0,
                                -0.23644478198854113,
                                0,
                                -0.2607946204441286,
                                0,
                                -0.63736951254559648,
                                -0.39148980525734978,
                                0.25604598530141998,
                                -1.1141338950338158,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.093940304568651434,
                                0,
                                0,
                                0,
                                0,
                                0.30647732096255709,
                                -0.18166285901451468,
                                0.20324546341410094,
                                0,
                                0.71955841063419934,
                                0,
                                0,
                                0.15827811507828121,
                                0.22578463278503708,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47868757007091034,
                                0,
                                0,
                                0,
                                0,
                                -0.12039776298252991,
                                -0.41224100029731325,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1606164096146942,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37953441354807305,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7713127185806733,
                                0.22537618417563599,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59874735885756791,
                                0,
                                0,
                                -0.012586307022629317,
                                0,
                                0,
                                0,
                                0,
                                -0.38652378629889167,
                                0,
                                -0.17360528586654622,
                                0,
                                0.10962515280163501,
                                -0.92403662681825294,
                                0.69544326902800402,
                                0.40566503494299827,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51326927501010822,
                                0,
                                0,
                                0,
                                0,
                                0.34149597495222955,
                                0.30759236206932988,
                                0.20046042068087888,
                                0,
                                -0.083553928237312614,
                                0,
                                0,
                                0.60750876566027612,
                                -0.10762973327886241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31225853102107504,
                                0,
                                0,
                                0.14735145164050559,
                                0,
                                0,
                                0,
                                0,
                                -0.14719040692616589,
                                -0.13250335647568395,
                                0.14206564534724528,
                                0,
                                0.56074238208689675,
                                0,
                                0,
                                -0.3252522153986504,
                                -0.31279521041063879,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63310416235960321,
                                -0.96194562727054922,
                                -0.9531489767202963,
                                0,
                                0,
                                0,
                                0,
                                0.66118496353346423,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.010494458566704105,
                                0,
                                0,
                                0,
                                0,
                                -0.42220792131811252,
                                0,
                                0,
                                0,
                                0,
                                0.51186998387294136,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72567785899434256,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31207316291382503,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64917808859846193,
                                0,
                                0,
                                -0.077654940587114238,
                                0,
                                0,
                                0,
                                0,
                                0.15089742865786751,
                                0,
                                -0.39732046452430092,
                                0,
                                0.21532644993077205,
                                0.17435194305449558,
                                -0.96775837427076516,
                                -0.011070936014764873,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.95937575022898414,
                                -0.25161487725763132,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0023559330477501556,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.070136349685448227,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.047599044970372123,
                                0.095382369258596708,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23720040963961972,
                                0,
                                0,
                                0.068674793206380466,
                                0,
                                0,
                                0,
                                0,
                                1.219234733310584,
                                0,
                                -0.14921556263458441,
                                0,
                                0.21223094196849621,
                                -0.52147877992874192,
                                0.16516901808472645,
                                -0.12041393089463927,
                                0,
                                0,
                                0,
                                0,
                                0.68132844253890923,
                                -0.11350745715407989,
                                0,
                                0,
                                0,
                                0,
                                0.85297752372645363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48247198012938863,
                                0,
                                0,
                                0,
                                0,
                                -0.4127702744933528,
                                0,
                                0,
                                0,
                                0,
                                0.18625743979063036,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.84093849220662586,
                                0,
                                0,
                                -0.13354004161513558,
                                0,
                                0,
                                0,
                                0,
                                0.44840979792535851,
                                0,
                                -0.24777612084468778,
                                0,
                                0.40027614451645904,
                                0.93254350591505508,
                                0.53398782681141843,
                                -0.037162308410784203,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2058016886070389,
                                0,
                                0,
                                -0.78260905637995681,
                                0,
                                0,
                                0,
                                0,
                                0.29702125915417799,
                                0,
                                0.95347106028529649,
                                0,
                                0.64474548386515984,
                                0.053276545260265387,
                                -0.242101668303009,
                                -0.025950134607893027,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27625511932401942,
                                0,
                                0,
                                -0.074473339619704593,
                                0,
                                0,
                                0,
                                0,
                                -0.59105691498936941,
                                0,
                                -0.10025020754289526,
                                0,
                                0.9674200767582336,
                                -0.032064229657495572,
                                0.21381501236407066,
                                -0.52866833393295143,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12154438077911114,
                                0,
                                0,
                                1.1532770237747039,
                                0,
                                0,
                                0,
                                0,
                                -0.19371714468622803,
                                0,
                                0.41793078626754809,
                                0,
                                -0.091855190837569073,
                                -0.29683218545774959,
                                0.29897444171970239,
                                -0.85731493600563091,
                                0,
                                0,
                                0,
                                0,
                                0.055883438591831203,
                                -0.75475525095785145,
                                0,
                                0,
                                0,
                                0,
                                0.25831119403969027,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1562762370091961,
                                0,
                                0,
                                0,
                                0,
                                0.4949138696317768,
                                0,
                                0,
                                0,
                                0,
                                0.33815823256977906,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16454804462830935,
                                0.20421340306974242,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.052245843202149138,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70405593037050274,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58185234138292097,
                                -0.30699234293563404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.04072431243588831,
                                0.084212442868087323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12977698152662206,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38227745142693276,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.01212338360682582,
                                0.91001357331036681,
                                0,
                                0,
                                0,
                                -0.60035908335839627,
                                0,
                                0,
                                0,
                                0,
                                0.097912302253765987,
                                0.68966826394850456,
                                -0.0050358406719612225,
                                0,
                                0.26754138420269258,
                                0,
                                0,
                                0.099416006003285512,
                                -0.26968117587099066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.011162749549643802,
                                0.2002608534672457,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58063336512416397,
                                0,
                                -0.084473868175974853,
                                0,
                                0.24671508934137659,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2740607926886287,
                                0.51048528843678842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13692348407597196,
                                0,
                                0,
                                0,
                                0.51804035491978007,
                                0,
                                0,
                                0.1864414649763082,
                                0,
                                -0.2959789920525196,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.052107159445912585,
                                0,
                                -0.43049528265254045,
                                0,
                                0,
                                0,
                                0,
                                0.12817402965983168,
                                0.70738323443309847,
                                -0.3809217174184899,
                                0,
                                0,
                                0.16635412502287839,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74077233070187254,
                                0,
                                -0.012460702061077494,
                                0.91892057758349999,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21747981906446789,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62254590477084371,
                                0,
                                0,
                                0,
                                0.11392919432547516,
                                0,
                                -0.75107988817889015,
                                0,
                                -0.043813832919066563,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44251737313257611,
                                0,
                                0.043022267555602123,
                                0,
                                0,
                                0,
                                0,
                                0.015269543482148915,
                                0.2663067417547757,
                                0.29845772976792934,
                                0,
                                0,
                                0.27578497505832217,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.083103219383123372,
                                0,
                                1.0531338067924598,
                                0.87291777764136891,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11555088925957516,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69593210264513428,
                                0,
                                0,
                                0,
                                -0.56806525492163606,
                                0,
                                0,
                                -0.711532611832151,
                                0,
                                -0.95314297597831421,
                                0.26655739974915238,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58455282085280047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26054498924765701,
                                0,
                                0,
                                0,
                                -0.68353182853038008,
                                0.26474568476984256,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10988742157217972,
                                0,
                                0.51122275457505273,
                                0,
                                0.78987337637919053,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0052584900036457827,
                                -0.57211278323452808,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76695017046656544,
                                0,
                                0,
                                0,
                                0.20486988531569975,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51769591707745732,
                                0,
                                0.58629449997077643,
                                0,
                                0,
                                0.16119572130415205,
                                0.015393679587264512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39853445873861021,
                                0.45077594878749849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44315353883579411,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.96744065364564913,
                                0,
                                0.60718787695574283,
                                0,
                                -0.33917609946694233,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13807860599038921,
                                0.52416030280741877,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32103198718055814,
                                0,
                                0,
                                0,
                                0.0036933590969210929,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12103496727745175,
                                0,
                                -0.5565814868041804,
                                0,
                                0,
                                0.23424882135187519,
                                -0.61328922196569569,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48579771593542437,
                                0.092585011480736265,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80363174490981726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.018093682400897121,
                                0,
                                -0.18775607473525319,
                                0,
                                0.41978573309676293,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43767134930027762,
                                0.30397509997871697,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12574270554284664,
                                0,
                                0,
                                0,
                                1.0073760641315719,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47976643910176636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32743618723846307,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67322970838902196,
                                0,
                                0.25394657231698087,
                                0,
                                0,
                                0.60447043515558696,
                                0.11075581699527838,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31814887311599416,
                                -0.058333821325505547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23169888387661902,
                                0,
                                -0.44732324553414721,
                                0,
                                0,
                                0.10431755955103822,
                                0.77147939915850572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36725847766661934,
                                -0.072637010128926455,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.089941519785843457,
                                0,
                                0.043366686669503024,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.094977415443971716,
                                0,
                                0.87044607963743403,
                                0,
                                0,
                                0,
                                0,
                                0.060920717007292194,
                                0.33627134908283018,
                                -0.24953791788316132,
                                0,
                                0,
                                0.21041349783032925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.99223373705328655,
                                0,
                                -0.13817884872318509,
                                0.030678939718566112,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55704046304521371,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64000098451882981,
                                0,
                                0,
                                0,
                                1.0792767288591896,
                                0,
                                0.084012224398835128,
                                0,
                                -0.016584180206503318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17970801981933415,
                                0,
                                -0.068741761386813677,
                                0,
                                0,
                                0,
                                0,
                                -0.66445160521731395,
                                -0.27025825988727287,
                                -0.31346799430978267,
                                0,
                                0,
                                0.58553297328393916,
                                0,
                                0,
                                0,
                                -0.43071177460408844,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.4461629981520046,
                                0,
                                0.47373000983451952,
                                0,
                                -0.011967768190475098,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.018115457858131602,
                                0.20915310871872186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.092240394963025829,
                                0,
                                0,
                                0,
                                -0.19436800324301548,
                                0,
                                -0.75801599327122704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25913149288772064,
                                0,
                                -0.20273352225359231,
                                0,
                                -0.48318119539299431,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12130616060551888,
                                -0.8165251593544941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11792308854026071,
                                0,
                                0,
                                0,
                                0.594776528579261,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12328355695026127,
                                0,
                                -0.28607152900112326,
                                0,
                                0,
                                0.26539796628572604,
                                0.11538880022924038,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43102294768375726,
                                0.79588492115613885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44183710310014707,
                                0,
                                0.0072069798860695811,
                                0,
                                0,
                                0.68734321005740873,
                                -0.05364210386321723,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42812683643620497,
                                -0.38225290315342686,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53108181456756554,
                                0,
                                -0.1199622722621792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43464828371587827,
                                0,
                                0.0012439661807524191,
                                0,
                                0,
                                0,
                                0,
                                -0.42193315200628201,
                                0.09683022656139513,
                                -0.37746110707825153,
                                0,
                                0,
                                -0.42983708144560351,
                                0,
                                0,
                                0,
                                0,
                                -0.12404290653333835,
                                0,
                                -0.11663886722797216,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53360453203328473,
                                0,
                                0.069215854845137786,
                                0,
                                0,
                                0,
                                0,
                                0.35007491669940111,
                                -0.35262406898360465,
                                -0.61548388530989062,
                                0,
                                0,
                                -0.23615144805257451,
                                0,
                                0,
                                0,
                                0,
                                0.27203077927692954,
                                0,
                                0.19229093086581303,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53243373547727535,
                                0,
                                0.096883460349807382,
                                0,
                                0,
                                0,
                                0,
                                -0.47347253704270231,
                                0.30583717690647405,
                                0.13266708896708415,
                                0,
                                0,
                                -0.51072319984736458,
                                0,
                                0,
                                0,
                                0.4142910940338983,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.026892369741150945,
                                0,
                                -0.22749619396974793,
                                0,
                                -0.74571465145092108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.04795581365582538,
                                0.15306845458463725,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1997341250607338,
                                0,
                                0,
                                0,
                                0.57807233420671877,
                                0,
                                0,
                                0,
                                0.98624660924207252,
                                0,
                                -0.17498303239462015,
                                0.2072686552065785,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45391783459217144,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0501579225541462,
                                0,
                                0,
                                0,
                                0.46240812492965289,
                                0,
                                0.12056437940459866,
                                0,
                                -0.91834073499705515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.054853685023104094,
                                0,
                                0.19037411034694118,
                                0,
                                0,
                                0,
                                0,
                                -0.11564909998939632,
                                -0.12375591342248193,
                                0.25766725809609997,
                                0,
                                0,
                                -0.088207935485965089,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.099802050550445304,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12496425205784041,
                                0,
                                0,
                                -0.45168152970081032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24266519624025537,
                                0,
                                -0.51196175569259961,
                                0,
                                0.26360425943380195,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21557670402232532,
                                0.2065884584513682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66772201100274753,
                                0,
                                0,
                                0,
                                -0.94115173846588496,
                                0,
                                0,
                                0,
                                0.32728068695263252,
                                0,
                                -0.57163806689612207,
                                0.33781370256274912,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3012962496871492,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.031222616875515839,
                                0,
                                0,
                                0,
                                -0.90676573062136412,
                                -0.08966163265601991,
                                0,
                                0,
                                0,
                                0,
                                0.19288403633720341,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2286324760770313,
                                0,
                                0,
                                0,
                                0,
                                -0.83132938354360741,
                                0,
                                0,
                                0.20005063874465245,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41395039441154458,
                                0,
                                0,
                                0,
                                -0.042774082314638195,
                                0,
                                0.40212214110863698,
                                0.49289063420325868,
                                0,
                                -0.41896435174073177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58029560168938599,
                                -0.013767384484621115,
                                0,
                                0,
                                0,
                                -0.21011783748765228,
                                0,
                                0,
                                0,
                                0.19212970710289196,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74318064906631931,
                                0,
                                0,
                                0,
                                0,
                                -0.30017067028102362,
                                -0.49005491642907717,
                                -0.6890773587926482,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0020219439914355708,
                                0,
                                0,
                                0,
                                -0.58420757508797294,
                                0,
                                0,
                                -0.61046549768771063,
                                0,
                                0,
                                0,
                                0.52604142088836747,
                                0,
                                -0.74381380368682548,
                                0,
                                -0.26377881822817684,
                                -0.18299550396470238,
                                0,
                                0.049694740240644117,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21349060401586875,
                                0.34816793395444273,
                                0,
                                0,
                                0,
                                -0.40566589445318335,
                                0,
                                0,
                                0,
                                -0.09920117267721909,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00018221603639885509,
                                0,
                                -0.533761852042416,
                                0.099651319532158014,
                                0,
                                0.24917324331857013,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25240848327544929,
                                -0.61356638306471545,
                                0,
                                0,
                                0,
                                -0.16343546184939037,
                                0,
                                0,
                                0,
                                0.41975667044696108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51525801503210933,
                                0,
                                0,
                                0,
                                0,
                                0.34026987001582271,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41410739901830645,
                                0,
                                0,
                                0,
                                0,
                                -0.09845560649042967,
                                0,
                                0,
                                0.26998262531671091,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60386797494202038,
                                0,
                                0,
                                0,
                                0.24713987358590661,
                                0,
                                -0.32619941633040428,
                                -0.46731141513364494,
                                0,
                                -0.31988155815663016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55838040915591858,
                                0.20337146839462308,
                                0,
                                0,
                                0,
                                0.39831589017674723,
                                0,
                                0,
                                0,
                                0.002733103238522494,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18189291385474698,
                                0,
                                0,
                                0,
                                0,
                                0.77291358076042505,
                                -0.11946136014534908,
                                0.74661556260237805,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54491897207602191,
                                0,
                                0,
                                0,
                                -0.23239050025002761,
                                0,
                                0,
                                -0.54802242045681315,
                                0,
                                0,
                                0,
                                0.047313666959146961,
                                0,
                                0,
                                -0.60187228721575514,
                                0,
                                0,
                                0,
                                0,
                                -0.5077050393673489,
                                -1.0253582645511081,
                                0.4403196291999556,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30588815374592548,
                                0,
                                0,
                                0,
                                -0.27901447357399339,
                                0,
                                0,
                                -0.090111801927450386,
                                0,
                                0,
                                0,
                                -0.22380265164946733,
                                0,
                                0,
                                0.91436847622310613,
                                0,
                                0,
                                0,
                                0,
                                -0.037954755874402557,
                                -0.55167841336259571,
                                -0.16314531188988857,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85309996839984825,
                                0,
                                0,
                                0,
                                -0.46782780088692111,
                                0,
                                0,
                                -0.086383009527427751,
                                0,
                                0,
                                0,
                                -0.040316494200802633,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4742964369651565,
                                -0.098565767500413848,
                                0,
                                -0.26776562698107037,
                                0,
                                0,
                                -0.63160561632055601,
                                0,
                                0,
                                0,
                                0,
                                -1.0016999685334933,
                                0,
                                0,
                                0.5633754722840929,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.149436178793783,
                                0.46030746093598529,
                                0,
                                -0.24314525882717242,
                                0,
                                0,
                                0.63196545807456039,
                                0,
                                0,
                                0,
                                0,
                                -0.83607735308768605,
                                0,
                                0,
                                -0.056081468091508935,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54781228547251903,
                                0,
                                0,
                                0,
                                0,
                                0.72416524042425579,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.094833123998365437,
                                0,
                                0,
                                0,
                                0,
                                -0.0050078058784958634,
                                0,
                                0,
                                -0.31189853453220279,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2630348058267446,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61542419650556601,
                                -1.2941721488384583,
                                0,
                                -0.0070760858962310436,
                                0,
                                0,
                                -0.30126827558611358,
                                0,
                                0,
                                0,
                                0,
                                -0.060699307118186996,
                                0,
                                0,
                                0.21542454131955677,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.042531289389085153,
                                0,
                                -0.089254315650474259,
                                -0.31371939919798764,
                                0,
                                -0.72299068315122161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37036062977323592,
                                -0.25303240891030554,
                                0,
                                0,
                                0,
                                -0.40038163335513077,
                                0,
                                0,
                                0,
                                0.087129322452020819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57380764104939663,
                                0,
                                0.034033388675055433,
                                -0.16884175265513748,
                                0,
                                0.28689650431376756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1042106460236164,
                                0.36463588461959684,
                                0,
                                0,
                                0,
                                -0.62905518065710164,
                                0,
                                0,
                                0,
                                0.13870749977195268,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13733381210618875,
                                0.071290957752845663,
                                0,
                                1.1010464626380749,
                                0,
                                0,
                                -0.39046801857655344,
                                0,
                                0,
                                0,
                                0,
                                -0.59744824192376944,
                                0,
                                0,
                                -0.80386228866925158,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.014107540992651733,
                                0,
                                0,
                                0,
                                0,
                                -0.22821617612161349,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66493659064335686,
                                0,
                                0,
                                0,
                                0,
                                -0.037429142965078488,
                                0,
                                0,
                                -0.71004276233103514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0040024474226628692,
                                0,
                                0,
                                0,
                                0,
                                0.29840060448626693,
                                0,
                                0,
                                0,
                                0,
                                0.40853107548778278,
                                0.11413227891427409,
                                -0.28543468564269248,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23681625953288685,
                                0,
                                0,
                                0,
                                0.95319092760849222,
                                0,
                                0,
                                -0.76495643815498049,
                                0,
                                0,
                                0,
                                -0.54268396730451129,
                                0,
                                0.21376982311431264,
                                0,
                                -0.33530929209773047,
                                0.31341711950917617,
                                0,
                                -0.083084344646905159,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11886798607040788,
                                -0.14874674202986143,
                                0,
                                0,
                                0,
                                -0.19135146271878928,
                                0,
                                0,
                                0,
                                -0.81477988964517523,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31313402077294572,
                                0,
                                0,
                                0,
                                0,
                                0.15581264042406404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56050157794927224,
                                0,
                                0,
                                0,
                                0,
                                0.49732387210893192,
                                0,
                                0,
                                0.4566700514553147,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32806846475911805,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15246518149978322,
                                0.58318034334754443,
                                0,
                                1.3004471302907388,
                                0,
                                0,
                                -0.47046690405749919,
                                0,
                                0,
                                0,
                                0,
                                0.45817761983029981,
                                0,
                                0,
                                0.54337828695551571,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.019658582606417167,
                                0,
                                0,
                                0,
                                0,
                                -0.73704954238160469,
                                0.60626134871268889,
                                0.49065597484730544,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31694228307682831,
                                0,
                                0,
                                0,
                                -0.17437387168068449,
                                0,
                                0,
                                -0.38282442116493465,
                                0,
                                0,
                                0,
                                0.1389843323210895,
                                0,
                                -0.084092783461124573,
                                0,
                                0.50581994721469969,
                                -0.51971476250965676,
                                0,
                                0.2136811828213665,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28288442861923135,
                                -0.49158475030301646,
                                0,
                                0,
                                0,
                                -0.11527238596260497,
                                0,
                                0,
                                0,
                                -0.29384453858435344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39465464495379599,
                                -0.37135426830108142,
                                0,
                                0.32303113915283332,
                                0,
                                0,
                                1.1909868794913514,
                                0,
                                0,
                                0,
                                0,
                                -0.14011654427503673,
                                0,
                                0,
                                0.91691962537576122,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32442824972069229,
                                0,
                                0,
                                0,
                                0,
                                -0.0420821647417573,
                                0.1986678019747799,
                                0.42564656204579887,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12595768394368137,
                                0,
                                0,
                                0,
                                0.64388233969869024,
                                0,
                                0,
                                0.099241081669122572,
                                0,
                                0,
                                0,
                                1.176024302537596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40732511445331399,
                                0,
                                -0.19821731361060979,
                                0,
                                -0.57281736337310152,
                                0,
                                0,
                                0,
                                0,
                                -0.49622239639850313,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10462429495033272,
                                0,
                                0,
                                0,
                                0,
                                -0.22459050953984908,
                                0,
                                0,
                                0.27766916985277817,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53586966099496713,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.053983895909236856,
                                0,
                                -0.25683692284096005,
                                0,
                                0,
                                0,
                                0.83123507154389054,
                                0,
                                0,
                                0,
                                0,
                                -0.80605318934401327,
                                -0.64703276911077034,
                                -0.1271781848025953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58851486547015708,
                                0,
                                0,
                                0,
                                0.24612125077448316,
                                0,
                                0,
                                -0.58865039758472681,
                                0,
                                0,
                                0,
                                -0.23532867374284949};

const double rot_25_2[32]
    = {2.1323005447221077,   -1.2736903162691897,  -1.9416313740604236,  -0.24713351145510043,  0.49069991339904684,
       -0.87132863776543468, -0.87132863776543457, -0.49069991339904706, 0.29255572305394922,   0.9562484765521887,
       -0.95624847655218803, 0.292555723053949,    -0.8385817060054146,  0.54477584597066042,   0.54477584597066042,
       0.83858170600541415,  -0.80407177344252601, 0.59453223895175888,  -0.59453223895175888,  -0.80407177344252567,
       0.54484204737996678,  0.83853869523523217,  0.8385386952352325,   -0.54484204737996678,  -0.65038250869539715,
       0.75960686699310576,  0.75960686699310576,  0.65038250869539704,  -0.089321152318146357, -0.99600287737965842,
       -0.99600287737965831, 0.089321152318146274};

const double rot_24_50[25000] = {-0.35237182597907957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021602219150900881,
                                 0.49860054360034139,
                                 -0.18760525027714217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76797621911343139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042210605895404735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2316580447724448,
                                 -0.28243480458740078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18826367335905239,
                                 -0.35572146664242554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41613842777380239,
                                 0,
                                 0,
                                 0,
                                 0.7781542608631834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29624578172312316,
                                 0,
                                 0,
                                 -0.506996168580646,
                                 0,
                                 0,
                                 -0.32462121897123897,
                                 0.24113596114779889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29628821159080665,
                                 0.11891538818821958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68991408346023875,
                                 0,
                                 0,
                                 0,
                                 -0.54020406110102659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5600277919949932,
                                 0,
                                 0,
                                 -0.44161888352630718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082546646254906597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12631053069458323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35781189240093692,
                                 0,
                                 -0.37883761301332547,
                                 0.44700157920016187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27327611537757823,
                                 0,
                                 0,
                                 -0.39216124823107579,
                                 0,
                                 0,
                                 -0.18281549162488037,
                                 0,
                                 0,
                                 -0.29230514203703856,
                                 0,
                                 0,
                                 0,
                                 0.41467311393450179,
                                 0,
                                 0,
                                 0,
                                 0.049077588892115172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083341584904804214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0089295814492377779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19060657705235615,
                                 -0.12759345486695475,
                                 -0.64618662541507987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37473875422793201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019364162727717016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47907053549811363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3992987203440741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55461804644258106,
                                 0,
                                 0.16628642237086549,
                                 0.19020577626922422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17650854233487018,
                                 0,
                                 0,
                                 -0.11919683653330067,
                                 0,
                                 0,
                                 0.44944887176168669,
                                 0,
                                 0,
                                 0.46630000383323789,
                                 0,
                                 0,
                                 0,
                                 0.0121143529515878,
                                 0,
                                 0,
                                 0,
                                 -0.37410691931407514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15382955854962674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26105526222971437,
                                 0,
                                 0.2705684357172396,
                                 0.42798586453229498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26025471344939105,
                                 0,
                                 0,
                                 0.076044520997564397,
                                 0,
                                 0,
                                 0.54750726722026799,
                                 0,
                                 0,
                                 0.030820516110035182,
                                 0,
                                 0,
                                 0,
                                 0.20507756628965618,
                                 0,
                                 0,
                                 0,
                                 0.35768800031770409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36227622159205142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045592711206577881,
                                 0,
                                 0,
                                 -0.90922434610203551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38630901497572567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77603106618318407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12063745411490728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26570575529133578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21231637880285253,
                                 -0.1743685123584453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71115560344103956,
                                 -0.051111255608316419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0183220161651209,
                                 0,
                                 0,
                                 0,
                                 0.46251585315781424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5285729257309425,
                                 0,
                                 0,
                                 0.91200436447012101,
                                 0,
                                 0,
                                 0.986301939871155,
                                 0.65419080156587328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48258327241384208,
                                 0.32078915124326213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40222712958778217,
                                 0,
                                 0,
                                 0,
                                 -0.51879643023013355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81855873168943527,
                                 0,
                                 0,
                                 0.49490480318614699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45585385108919341,
                                 0,
                                 0,
                                 0.023337239517110669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0409880029540115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32791185209210016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50191180810582803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36255611237075169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053369477394966419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12026027224747136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19116001456913609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20892858665381514,
                                 0.50770906410719929,
                                 -0.12236444443664857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24532597457541871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64491612122436914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40478344407771344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084343758832464463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48204415497439818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63297425495376425,
                                 -0.39563523738096795,
                                 -0.0070050221359617172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22381551704315825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075256305089628245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28012190237919526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27599916034391503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012190036238281715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43350219968464426,
                                 0.35676802024034188,
                                 0.37804696792757664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26750251404219916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24334931015180122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63453844769127099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091152576984614653,
                                 -0.031091708588038513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27005889388766158,
                                 0.27182284858047862,
                                 0.65653660071312392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058291312761898653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64635567086504264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065130100734905036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064177316886770058,
                                 -0.098244134664429578,
                                 0.69067076126932547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24116540466604713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66843143186075205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44055821218333641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79964330195682454,
                                 0.27578297487763187,
                                 -0.2069784891813515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0070072756006924752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21802202912986199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13391141078999108,
                                 0,
                                 0,
                                 0.80161310659287544,
                                 0,
                                 0,
                                 0,
                                 -0.13853905167218553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048481521875643252,
                                 0,
                                 -0.70098972170645346,
                                 0,
                                 0.49675408955593292,
                                 0.61615053175098244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16162700082005327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6304900682178457,
                                 0.58553359456290199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32320762902507288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33543643885276941,
                                 -0.2351221193976594,
                                 -0.47085609445048032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15789308058398679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43156399204125662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00040532731949416423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54300412788986563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10279678897923687,
                                 0,
                                 0.34218838772035676,
                                 0.50045857421267437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64712348598655922,
                                 0,
                                 0,
                                 0.18368167769128693,
                                 0,
                                 0,
                                 -0.30135337240140442,
                                 0,
                                 0,
                                 -0.16292833656704733,
                                 0,
                                 0,
                                 0,
                                 0.18955682457899414,
                                 0,
                                 0,
                                 0,
                                 -0.0059518933982553798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12667543350355176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58198637713385226,
                                 0,
                                 0,
                                 0.79244497073368569,
                                 0,
                                 0,
                                 0,
                                 -0.79578326485770601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15425955357354765,
                                 0,
                                 0.16519807623609056,
                                 0,
                                 -0.40244977024715212,
                                 -0.2298190564229588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40678653028470574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.074597053044914596,
                                 0.00062965739801130668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70846021139353532,
                                 0,
                                 0,
                                 -0.58537376981866496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65582742638894476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2933437718649417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42999543789184197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10943451340618311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02973745409634624,
                                 0,
                                 0.22946304263170897,
                                 -0.50495834165467757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078833686936627081,
                                 0,
                                 0,
                                 -0.08409566264616547,
                                 0,
                                 0,
                                 0.0024193690158368641,
                                 0,
                                 0,
                                 0.054067038535761044,
                                 0,
                                 0,
                                 0,
                                 0.81508066917522859,
                                 0,
                                 0,
                                 0,
                                 -0.070011018610014866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077495163843339598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53595233390369801,
                                 0.66653437968835982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33736980663374838,
                                 0.55213900661001514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41795838112284645,
                                 0,
                                 0,
                                 0,
                                 0.33336263816513495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7915731237649668,
                                 0,
                                 0,
                                 -0.035165333792532449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.663308998553231,
                                 0,
                                 0,
                                 -0.59223377742209626,
                                 0,
                                 0,
                                 0,
                                 -0.31381550404620018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28035370486563355,
                                 0,
                                 0.80927045997318436,
                                 0,
                                 0.0013625562154882948,
                                 0.42550034601826597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02511917535447409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24797577139802099,
                                 0.29659452705512429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075568644559245363,
                                 0,
                                 -0.10146666168825177,
                                 -0.19119543764551969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34035950714403235,
                                 0,
                                 0,
                                 -0.2862194148846533,
                                 0,
                                 0,
                                 0.52694317723241191,
                                 0,
                                 0,
                                 -0.42645424766151985,
                                 0,
                                 0,
                                 0,
                                 -0.060853448293442275,
                                 0,
                                 0,
                                 0,
                                 0.28361446540325935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45387157771015507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0021245008176556,
                                 0,
                                 0,
                                 -0.41164776935467684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28518671664263401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3006254043029648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23250603571428788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4617750889777526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10738684321824965,
                                 0.2351397732489216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059660960900595451,
                                 -1.3585887950179738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17701730854993825,
                                 0,
                                 0,
                                 0,
                                 0.095776696753584079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029879452192034139,
                                 0,
                                 0,
                                 0.83208214417143478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064958897310441036,
                                 0,
                                 -0.61628844277502659,
                                 0.0045468098703158044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50815541357582972,
                                 0,
                                 0,
                                 -0.029959190026317126,
                                 0,
                                 0,
                                 0.13770866679099891,
                                 0,
                                 0,
                                 0.11822681366406852,
                                 0,
                                 0,
                                 0,
                                 0.056602213835463155,
                                 0,
                                 0,
                                 0,
                                 -0.036360100079317663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56512089166949797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29105580597725628,
                                 0,
                                 0,
                                 0.26261017669737213,
                                 0,
                                 0,
                                 0,
                                 0.52451490242686982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82131822740591753,
                                 0,
                                 0.23299082394531737,
                                 0,
                                 0.023656409246645839,
                                 0.38770783856107216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25172738760756153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039879287252879335,
                                 -0.95636589673361494,
                                 0,
                                 0,
                                 -0.75039713962638532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51776880865728947,
                                 -0.37614986855983867,
                                 -0.11771730496716216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11510870174197997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014949678896587472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044629135852642304,
                                 0,
                                 0,
                                 0.070124293454726788,
                                 0,
                                 0,
                                 0,
                                 0.41935136784388893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51327208639294719,
                                 0,
                                 0.034556088970613255,
                                 0,
                                 0.48730347146372499,
                                 -0.59475131471055886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62593914259425454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05286733315970682,
                                 0.10021269422774332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13664129772459466,
                                 0,
                                 0.017092819062260858,
                                 0.040924025334365691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12271506862712661,
                                 0,
                                 0,
                                 0.17611414859669861,
                                 0,
                                 0,
                                 0.23964630228115918,
                                 0,
                                 0,
                                 -0.55307986480138982,
                                 0,
                                 0,
                                 0,
                                 0.0052361381609103835,
                                 0,
                                 0,
                                 0,
                                 -0.7434434900100122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13123912150003955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047548463121117712,
                                 0,
                                 0,
                                 0.55847217982079633,
                                 0,
                                 0,
                                 0,
                                 0.19900847808488145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.079218260949916228,
                                 0,
                                 0.20413565815267623,
                                 0,
                                 -0.51130147643062807,
                                 -0.69831431937135025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17656823658705303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93736683326001602,
                                 0.3095133093583623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38085835467042217,
                                 0,
                                 0,
                                 0.32870480132887514,
                                 0,
                                 0,
                                 0,
                                 0.0027846288921015427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2201576547667972,
                                 0,
                                 0.69702593067893093,
                                 0,
                                 0.53332946540186055,
                                 0.04740708446951173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18644239365919354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21471481051181376,
                                 -0.19583432168155526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093061992323323989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18149761905440984,
                                 0.20216927031846393,
                                 -0.1316467787468632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78730617901227939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19118829616087751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1678437725376829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46434822662240238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39197320702462596,
                                 0,
                                 -0.42948105499665801,
                                 0.1482988779576245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11100238938685476,
                                 0,
                                 0,
                                 0.39058690677290075,
                                 0,
                                 0,
                                 0.10605056436514193,
                                 0,
                                 0,
                                 0.32538593422163337,
                                 0,
                                 0,
                                 0,
                                 0.26722504702490002,
                                 0,
                                 0,
                                 0,
                                 -0.11702357512695472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52230674674359479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065242877649932196,
                                 0,
                                 0,
                                 0.98580770255869443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40664734022724619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24473030527052603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58053236343166859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1370729986290331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33680568048931353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12234729410303308,
                                 0.67105361489611581,
                                 -0.0063563077042024796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57909824917446806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29306131492591148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63195357121587514,
                                 0,
                                 0,
                                 0.56052667659777078,
                                 0,
                                 0,
                                 0,
                                 -0.71459798816365527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71343007189438146,
                                 0,
                                 0.16652885978474513,
                                 0,
                                 0.42673623690267504,
                                 -0.26961237212757999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55593456866076718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090562298919884418,
                                 0.3659498167144869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75587603412517868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30684664190337796,
                                 0.15587281668804165,
                                 0.013327609780873023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18062775265903547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10568146754989384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29448653482275011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42368068449837654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55002182559324997,
                                 0,
                                 -0.10499695459275084,
                                 -0.1231017360063494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0013379444755916483,
                                 0,
                                 0,
                                 0.72042656084771017,
                                 0,
                                 0,
                                 0.093168826817981554,
                                 0,
                                 0,
                                 -0.24308243618631453,
                                 0,
                                 0,
                                 0,
                                 0.084916194856883731,
                                 0,
                                 0,
                                 0,
                                 0.27675940457233578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026558324083682732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84084135407230431,
                                 0,
                                 0,
                                 -0.47167891300842013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18937815042314476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087467042771334436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.081313290652224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56293357925757959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3611077936764302,
                                 -0.17361929838052306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7532196176897441,
                                 -0.48855314546993811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60084117575342832,
                                 0,
                                 0,
                                 0,
                                 0.088081845574190437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089982780861765782,
                                 0,
                                 0,
                                 -0.45268646757157982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48007786515353723,
                                 0,
                                 0,
                                 0.39082775935030523,
                                 0,
                                 0,
                                 0,
                                 0.58554792844354808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24415528877985909,
                                 0,
                                 0.12883159147620316,
                                 0,
                                 -0.56877439933621488,
                                 0.12177600467208888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47473274170517382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63302929079259385,
                                 0.70656978604942267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76738173315624469,
                                 0,
                                 0,
                                 0.22949282791949205,
                                 0,
                                 0,
                                 0,
                                 -0.10016296532117046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17158842506458469,
                                 0,
                                 0.43924418771939988,
                                 0,
                                 -0.21351112210995127,
                                 0.49306148679337086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43353782651530665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054079645950814138,
                                 0.52328413420609998,
                                 0,
                                 0,
                                 0,
                                 -0.027292154957364638,
                                 0.94627462111311023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045793130392104905,
                                 0.084989680425895844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42291530028852292,
                                 0,
                                 0,
                                 0,
                                 0.59481889883029759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42240016000947644,
                                 0,
                                 0,
                                 0.044955158287446194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21538491645561506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30302402877906959,
                                 -0.56717686421555291,
                                 0.43045005094664085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018094810091682741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53371978713617518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10315254803115434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2428667383284448,
                                 0.33847466087351713,
                                 0,
                                 0,
                                 0.14243655836330638,
                                 0,
                                 0,
                                 0,
                                 -0.21933716236470313,
                                 0,
                                 0,
                                 -0.94501289856707116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12212148733298704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44923011545281422,
                                 -0.31693130476030706,
                                 -0.26165030958573976,
                                 0,
                                 0,
                                 0,
                                 -0.33187764296135408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84647229191329287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19895457049828252,
                                 0,
                                 0,
                                 0.11458027639862316,
                                 0,
                                 0.21156222308338535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91738988523651366,
                                 0,
                                 -0.089255005122591158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034364608904128208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18130483921442042,
                                 0,
                                 0,
                                 -0.1375021322048266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077842717144147686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29288266261236912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28057427653962469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06263331768837449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060048536378733003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7000654348067511,
                                 -0.77960565960948303,
                                 -0.56831819754479906,
                                 0,
                                 0.5410739298223588,
                                 0,
                                 0,
                                 0.25776382717266655,
                                 0,
                                 0,
                                 0,
                                 0.4143090524120937,
                                 0,
                                 0,
                                 -0.68723232184725913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58884074506003559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31415377674487677,
                                 0.0077820581796875926,
                                 -0.50711113422599874,
                                 0,
                                 0,
                                 0,
                                 0.69890314101353346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094485514795407149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38761714264205072,
                                 0,
                                 0,
                                 0.24315793559396215,
                                 0,
                                 0.031513385904901839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061898948271985242,
                                 0,
                                 0.43715562047113388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43176802625507915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51034150021142544,
                                 0,
                                 0,
                                 0.38448079790227691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5698234517087879,
                                 0,
                                 0,
                                 -0.30627106187067343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073385983965806353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1538132363245002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18320491426906851,
                                 -0.30886448889252111,
                                 0,
                                 0,
                                 -0.039520947707895118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62643399620927798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066107851986212968,
                                 0.15856304144468314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13928668537899774,
                                 0,
                                 0,
                                 -0.49514989735301512,
                                 0,
                                 0.1522062269739497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16669956311005288,
                                 0,
                                 -0.20128000754279235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21864617045175302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11705764468549809,
                                 0,
                                 0,
                                 0.76318283332877934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28360530463277567,
                                 0,
                                 0,
                                 0.3930643219916865,
                                 0,
                                 0,
                                 0,
                                 0.95550127843112276,
                                 0,
                                 0,
                                 -0.20329272979263119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38584811199112223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088420021199008492,
                                 -0.091053620507013183,
                                 -0.050869622074482881,
                                 0,
                                 0,
                                 0,
                                 -0.37825454785152995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16215017541192003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095323368677721565,
                                 0,
                                 0,
                                 -0.088933279793870418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58474574537308621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23522386416079974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28649296938869107,
                                 -0.07294993269289396,
                                 0,
                                 0,
                                 0.12889323182639778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037943464184808984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68688065052626124,
                                 0.092132297186964141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59554696173061883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2289651086569584,
                                 0,
                                 0,
                                 0.46990461733418898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32950928516001016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3775986729932691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34775180681947149,
                                 -0.89236978130593492,
                                 0,
                                 0,
                                 0.21745007829281623,
                                 0,
                                 0,
                                 0,
                                 0.044629448935423151,
                                 0,
                                 0,
                                 0.27865544909900913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51262547632463906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28751485843896996,
                                 -0.90110935958569693,
                                 -0.48144683383559089,
                                 0,
                                 0,
                                 0,
                                 -0.26084520863358684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078181981827039934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17032226718727242,
                                 0,
                                 0,
                                 -0.082312787286121541,
                                 0,
                                 -0.88567143967943296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2551389276731521,
                                 0,
                                 -0.23947523568041643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22645733249949193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073138680817695395,
                                 0,
                                 0,
                                 0.026918029136655308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25819208803520977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80529304853879935,
                                 0.25523681764702921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2409699139159126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6729551325549461,
                                 0,
                                 -0.31453173315468497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65974021594079379,
                                 0,
                                 0,
                                 0.05417037825337595,
                                 0,
                                 0.25897301324858041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056761391226686636,
                                 0,
                                 -0.62799528931399784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023342928802189827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17545365216436701,
                                 0,
                                 0,
                                 -0.25653962789749829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16145083772613328,
                                 0,
                                 0,
                                 0.0067960313503462044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21654705856452994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36901261375128674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28799248684955536,
                                 -0.56785089560164315,
                                 0,
                                 0,
                                 0.17975812238747757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26404494499219372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047915774849693213,
                                 -0.53019011131657567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1177675636971533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13797593475309819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76217545840791245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62825400065789128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0801962117783122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4813411292872643,
                                 -0.049684423660239861,
                                 -0.37321375275897606,
                                 0,
                                 -0.60335053539833794,
                                 0,
                                 0,
                                 0.28174096617299876,
                                 0,
                                 0,
                                 0,
                                 0.23377068648180305,
                                 0,
                                 0,
                                 0.063752087183526818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30367241882093987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14341239670909223,
                                 0.010627961639886826,
                                 0.32762482793760817,
                                 0,
                                 0,
                                 0,
                                 0.83219141590912749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61589219038064558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35917348212878403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32937470272769154,
                                 0.3179951145810434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58749777681328885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54057950090939089,
                                 0,
                                 0.58789735502411811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56377655162967133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11702643491670756,
                                 -0.75127763216745125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76865983960167839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010494095661739589,
                                 0,
                                 0.019465909469804962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019379665536014067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40041466333306264,
                                 0,
                                 0,
                                 -0.60201585736359586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17622124262971145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64345436236134146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17827504210784845,
                                 0,
                                 0,
                                 -0.41527195313077203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75481147875667221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38899027567267158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.829278312660096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3657951785171083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82681784989882634,
                                 0.58918066823547022,
                                 -0.016433683462657153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22365531019586607,
                                 0,
                                 0,
                                 -0.10304426630617612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34290624380052159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35258803168545483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54033912607713541,
                                 -0.06163859923774867,
                                 0,
                                 0,
                                 -0.36377392267415837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080828904134014987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0072412217134067997,
                                 0.51261512593607572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076753199590858995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50334576808830156,
                                 0,
                                 0,
                                 0.46766965131401395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65313608368702936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25872829259326752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1688490691053226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17843058178801724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01487411370925544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61229560988447185,
                                 0,
                                 0,
                                 0.20428288156353291,
                                 0,
                                 0,
                                 0,
                                 0.032821275105394274,
                                 0,
                                 0,
                                 0.37783067095049105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34688402657418627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46097402646531438,
                                 -0.78748779261072954,
                                 -0.28056356001419602,
                                 0,
                                 0,
                                 0,
                                 0.27650376507887808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16810962904545279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32757785733160361,
                                 0,
                                 0,
                                 -0.96215187789438594,
                                 0,
                                 0,
                                 0,
                                 0.51927482194266872,
                                 0,
                                 0,
                                 -0.31786066749005237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15969541117075511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015889913421264529,
                                 -0.72135660582421102,
                                 0.45724017992775295,
                                 0,
                                 0,
                                 0,
                                 0.32703948911276787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49410444806666709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59703717212607954,
                                 0,
                                 0,
                                 0.5773530784852775,
                                 0,
                                 0,
                                 0,
                                 0.28695944746092705,
                                 0,
                                 0,
                                 0.37899883354202857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38614424380127216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27335546901085378,
                                 -0.11377411523376772,
                                 0.87997517265445524,
                                 0,
                                 0,
                                 0,
                                 -0.071030837935161822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31242455901229116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47870614819639534,
                                 0,
                                 0,
                                 0.33949089375539365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28105797092335699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52691270597321826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25022214241905494,
                                 -0.044928082477053682,
                                 0,
                                 0,
                                 -0.0060707342429693681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33936314393085165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32395023026800718,
                                 -0.11907212891830607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39545612433366067,
                                 0,
                                 0,
                                 0.135642210475063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2066299563052526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41405523043324644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1541811422838128,
                                 0.12752622208980804,
                                 0,
                                 0,
                                 0.20419659146748431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52627659320298081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21082541266568591,
                                 0.45599622221047753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41888068097185177,
                                 0,
                                 0,
                                 0.58821084784769706,
                                 0,
                                 -0.023637643559239474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16959782217265518,
                                 0,
                                 -0.51182027559897925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078479777278215895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12562060074638123,
                                 0,
                                 0,
                                 0.40660202756058056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55111832964280993,
                                 0,
                                 0,
                                 0.0022359790489666631,
                                 0,
                                 0,
                                 0,
                                 0.12137073071751334,
                                 0,
                                 0,
                                 -0.117282922975465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55407340402789196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1258011013568416,
                                 -0.26182082624490005,
                                 -0.084268984668409555,
                                 0,
                                 0,
                                 0,
                                 -0.027560779509042049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17454896758975061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19991701934288741,
                                 0,
                                 0,
                                 -0.32768649636733554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13678718934524994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13824392646044809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14656108887282474,
                                 0.47199009174911466,
                                 0,
                                 0,
                                 -0.48089613878889287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084464991762896846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40141259526941253,
                                 -0.4135823072206477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024966610785284164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31122458637413836,
                                 0,
                                 0,
                                 -0.32462459369094465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3632245864029402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2282628000349271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7830062530438443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89023469592323168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19841070295689783,
                                 0.15357323418658853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4637925502371823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16688566020168477,
                                 0,
                                 0.63427036365296596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35621125948381932,
                                 0,
                                 0,
                                 0.52157548522874941,
                                 0,
                                 -0.16035771158692638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10340265317563435,
                                 0,
                                 0.2131168126205763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67898143394429566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.213928187981232,
                                 0,
                                 0,
                                 0.11165130720529065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73143261441289475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5527727034638823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56947286323279511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47560859933959632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36647961002952323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20925771837312312,
                                 -0.030297517344837908,
                                 -0.46703966285713699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24537621907607599,
                                 0,
                                 0,
                                 -0.61840912649939317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21655061115096474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3820728888509734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2833399061034621,
                                 0.26186946015596524,
                                 0,
                                 0,
                                 0.33475677057932995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031383444857560339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31424130046105292,
                                 -0.061927992547984284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15541858119311119,
                                 0,
                                 0,
                                 -0.23415666683047848,
                                 0,
                                 -0.23092713619205074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1378488897663217,
                                 0,
                                 -0.036188725787216797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4955669666704009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77155593486518281,
                                 0,
                                 0,
                                 -0.080568346168980481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30472557204954204,
                                 0,
                                 0,
                                 -0.45248411537324562,
                                 0,
                                 0,
                                 0,
                                 0.36734827236158907,
                                 0,
                                 0,
                                 0.47493412478229985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12059946099702992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32110323332611795,
                                 0.22449507822019035,
                                 -0.51093369717799886,
                                 0,
                                 0,
                                 0,
                                 -0.09019996711862896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77811767321967107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3359980267365954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0827623621813265,
                                 0.69818915927710068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38567793325037447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11359246897765693,
                                 0,
                                 -0.99223315921767563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25262270914864088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4819191535927847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13260600972989856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23275945710086315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063942971587816824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86038034000595365,
                                 0.70766042256737516,
                                 -0.93064269719700177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018752674760613083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16450739199866674,
                                 -0.96544052705613903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24329723749210874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88168506420048776,
                                 0,
                                 0.031739153081821153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79759342447451753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25589416007097232,
                                 0,
                                 0,
                                 0.27301581854820811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27327670920049851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29470283730135871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24959036198160961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075479648286638515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.004125623511066441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10713900184245699,
                                 0,
                                 0,
                                 -0.1031841967684433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0026132269556132935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015327796176006927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52810565960276479,
                                 -0.38417112369191764,
                                 0,
                                 0,
                                 -0.63722094234581639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32889846045352428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1892978926976899,
                                 0.033030693528334827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30483836153688576,
                                 0,
                                 0,
                                 -0.50350417996043884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54855112509126691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21475065160872997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20594054036886131,
                                 -0.34030559090866153,
                                 0,
                                 0,
                                 0.16147246577529994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14649180336863582,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27635466707570544,
                                 0.15622556080621633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91064293249126416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64861776611500899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41792891727782944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37762664070488838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97709159417021407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66223399591229226,
                                 -0.031507952458998248,
                                 0.14108721169857308,
                                 0,
                                 0,
                                 0,
                                 -0.52736512510973821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7497219033752035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2623003560188941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58202300516614625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12905287119932751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21445214425096787,
                                 0.022587374673108732,
                                 0.029881851478450103,
                                 0,
                                 0,
                                 0,
                                 -0.78571037357889062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76012299213915857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28759291203237441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39004645361755186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21365571329783667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49972060481838892,
                                 1.0494125076116776,
                                 0.34791101843930849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047734566831756503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60954372265736023,
                                 0,
                                 0,
                                 0.1346584246308169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47662427641309735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48733123040740706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37865887151581784,
                                 0.22085272882304671,
                                 0,
                                 0,
                                 0.26304740121726594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20269423519762858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19510985345221932,
                                 0,
                                 0.069609185664134654,
                                 0,
                                 0,
                                 -0.083824469868768056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17522590717950656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50738473456025912,
                                 0,
                                 0,
                                 0,
                                 0.60348821177364076,
                                 0,
                                 0,
                                 0.37237607247075305,
                                 0,
                                 -0.44774920774250171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82085423747055763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69575908509715023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6504294726342148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47426529461255157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55413473510997469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16287743967906451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72140862156942043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21844957286273531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013621548728641464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056135329748720042,
                                 -0.39129958359077321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38255429517499373,
                                 0,
                                 0,
                                 -0.32018814746032942,
                                 0,
                                 0,
                                 0.31479804793377869,
                                 0,
                                 0,
                                 0.31017031281186824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33310328732146433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40518111322061473,
                                 0,
                                 0.46440222152293781,
                                 0,
                                 0,
                                 -0.20316162603318946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24020046637527137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15797954241022699,
                                 0,
                                 0,
                                 0,
                                 -0.019555264917463275,
                                 0,
                                 0,
                                 -0.43541561022922015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.009077769190854075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029410971854449949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17723423274535433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63251670024739726,
                                 0,
                                 0,
                                 0,
                                 0.67960619664596411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074295577840358645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17224344641751749,
                                 0,
                                 -0.82389636695571777,
                                 0,
                                 -0.10790222722675225,
                                 0,
                                 0,
                                 0,
                                 -0.85846971991555499,
                                 0,
                                 -0.23110242748910811,
                                 -0.55990705269142038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.4145782710361137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094028851581412679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18422452152444363,
                                 0,
                                 0.47221429254067637,
                                 0,
                                 0,
                                 0.19973677135227239,
                                 0,
                                 0,
                                 0,
                                 -0.18260417015649627,
                                 0,
                                 0,
                                 -0.31950941321803256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086095592635121024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58645692766781454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34922558003919996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083990055721011342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28756336745362171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26152626531387047,
                                 -0.16484333730836609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53985476074174021,
                                 0,
                                 0,
                                 -0.23947916501425531,
                                 0,
                                 0,
                                 0.47204870409500799,
                                 0,
                                 0,
                                 -0.14738357799153254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17209312122665932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0086473864839958451,
                                 0,
                                 -0.27288283439898459,
                                 0,
                                 0,
                                 -0.091194810185841496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25429963823459806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59088869567476054,
                                 0,
                                 0,
                                 0,
                                 0.47147432145928736,
                                 0,
                                 0,
                                 -0.082885191932467156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66649770855169865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3477044564099302,
                                 0.28151349626175193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083677500739679944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57231168070149752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14522390613491387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3266475793548303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44445832744001368,
                                 0,
                                 0,
                                 0,
                                 0.44012499720665316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17196868054874312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52954397434908873,
                                 0,
                                 -0.012440646928193933,
                                 0,
                                 0.56153239867102189,
                                 0,
                                 0,
                                 0,
                                 0.095405213253410087,
                                 0,
                                 -0.43681639957594987,
                                 0.31522667430340401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0033141191787294799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61886686782492761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027268030579716621,
                                 0,
                                 0.080953952725514422,
                                 0,
                                 0,
                                 0.048405569172522672,
                                 0,
                                 0,
                                 0,
                                 0.42175704470437159,
                                 0,
                                 0,
                                 -0.96913043713416469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91315205095175644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060812506337319633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78181860845745854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67991992626184472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80371690569249377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33589756928829034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96119745925280953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16232022363208756,
                                 0,
                                 0,
                                 -0.52904130429343188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25235837431607594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15418232653007738,
                                 0,
                                 0.65488820628168343,
                                 0,
                                 0,
                                 0.2120136787098231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18045440891683823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0015140375620851495,
                                 0,
                                 0,
                                 0,
                                 0.13786903016647059,
                                 0,
                                 0,
                                 0.28444364341048572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013399490273639916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46434170168486499,
                                 0,
                                 0,
                                 0,
                                 0.051577970606918086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42731697018581905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35705767943057876,
                                 0,
                                 -0.2591419466503822,
                                 0,
                                 0.26165256808517778,
                                 0,
                                 0,
                                 0,
                                 0.7081855284145806,
                                 0,
                                 0.41826369694619897,
                                 -0.60629923033279354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21230765087326034,
                                 0,
                                 0,
                                 0.41165976167177587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36873203792924292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12975548830675535,
                                 0,
                                 0.20217166412015924,
                                 0,
                                 0,
                                 0.72152684907839637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18114268578235462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0085353989195889705,
                                 0,
                                 0,
                                 0,
                                 -0.097726269464366355,
                                 0,
                                 0,
                                 -0.16956289203461067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34680101720911122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87351537961814785,
                                 -0.025235361795858932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24117146403036216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018268058898899563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23992856334717377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52737690280588856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19129052680745506,
                                 0.33200191565588572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31463320518739302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60516985454778249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33140859687331647,
                                 0,
                                 -0.46797969882606899,
                                 0,
                                 0,
                                 0.47077281536083926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28002338585711595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18985413842196638,
                                 0,
                                 0.12958880177677251,
                                 0,
                                 0,
                                 0.065738906706778788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048560053837318005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.474448567588593,
                                 0,
                                 0,
                                 0,
                                 0.29830310478359229,
                                 0,
                                 0,
                                 0.32764484043096953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.222270133420989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12906071201561736,
                                 0,
                                 0,
                                 0,
                                 1.0444201188674906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84167996609747331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13395900250397652,
                                 0,
                                 0.70693697296237212,
                                 0,
                                 -0.61757627660121517,
                                 0,
                                 0,
                                 0,
                                 0.29660701959913693,
                                 0,
                                 0.013065025430763518,
                                 0.25016008036212611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27461899696325498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058729245989287554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62823509613681305,
                                 0,
                                 0.67003187152327737,
                                 0,
                                 0,
                                 -0.47766292786840858,
                                 0,
                                 0,
                                 0,
                                 0.10671219042682764,
                                 0,
                                 0,
                                 -0.5840578129159324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69743295437613118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43717573938209581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17680427588220532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1361000148907174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40483524559291867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82978358434375443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14243549162689073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16572147652466723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77094880051508319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019002693764242518,
                                 0,
                                 0.15754671400368564,
                                 0,
                                 0,
                                 -0.72561072677432681,
                                 0,
                                 0,
                                 0,
                                 0.39532019743031754,
                                 0,
                                 0,
                                 0.14046407202337374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24924490287310497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42743096448616291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32053826016441972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076775046228321361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56600528065214917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53620034485307877,
                                 -0.21187180031470562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17585941522371201,
                                 0,
                                 0,
                                 -0.15803355785318352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028957757773569681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15432936500626465,
                                 0.718052070302028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42175261117214469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51123939583322864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14319264930161402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10680596929798429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62425086354051573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51575128061708952,
                                 0,
                                 0.71171435914118686,
                                 0,
                                 0,
                                 0.57094540711850172,
                                 0,
                                 0,
                                 0,
                                 -0.15011951509744265,
                                 0,
                                 0,
                                 -0.43284330263133552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20619372797514626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43780815407276896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56105780262013771,
                                 0,
                                 0,
                                 0,
                                 0.0098261197954584573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66650228594438354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38063621260839831,
                                 0,
                                 0.38374605303623893,
                                 0,
                                 1.1583845708148046,
                                 0,
                                 0,
                                 0,
                                 0.13872661700692918,
                                 0,
                                 0.048476926685626497,
                                 0.39669703589209332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15786411644625392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31879381971429643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65052887021673689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015665060158269163,
                                 0,
                                 0,
                                 0,
                                 0.0098181591611610775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37063048830996104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11173261670848095,
                                 0,
                                 0.74972212209994471,
                                 0,
                                 0.41130619917986699,
                                 0,
                                 0,
                                 0,
                                 -0.54244596471383044,
                                 0,
                                 0.56267222464267008,
                                 0.13616273918591354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034061118870729046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45982217712010309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23928958243659273,
                                 0,
                                 1.0530258634951872,
                                 0,
                                 0,
                                 -0.042323028107776189,
                                 0,
                                 0,
                                 0,
                                 0.45381538753434802,
                                 0,
                                 0,
                                 0.48668008315197642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7424242938950083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12747192373873956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48231746549287907,
                                 0,
                                 0,
                                 0,
                                 0.31328074478654577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5787669089653078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38192015934933854,
                                 0,
                                 0.23104595469034223,
                                 0,
                                 0.31993763070481318,
                                 0,
                                 0,
                                 0,
                                 0.91683164910595616,
                                 0,
                                 -0.018943682590322478,
                                 -0.0015996694374337678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0062977314108772081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71849120368394481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44205285851287307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2424316991182762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14208930635415343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54342362530520394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33227781803403272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11697559583786742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5965205043495202,
                                 0,
                                 0.13334680788198611,
                                 0,
                                 0,
                                 -0.037286048249190074,
                                 0,
                                 0,
                                 0,
                                 -0.69895059871921916,
                                 0,
                                 0,
                                 -0.25182891834393367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52014216962439752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061487357563975886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10434470925269426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37350684742700258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11004434632480561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39517492993485148,
                                 0.34241773336000575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46360130263190602,
                                 0,
                                 0,
                                 -0.58768619696861957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11887386461213599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45212152379633153,
                                 0,
                                 0,
                                 0,
                                 -0.30893308671903119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16264350465296334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97165329761226582,
                                 0,
                                 0.31259540604841018,
                                 0,
                                 -0.02245944001071809,
                                 0,
                                 0,
                                 0,
                                 0.021434247155426911,
                                 0,
                                 -0.59057291998363415,
                                 -0.1849223638002544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33838005381326153,
                                 0,
                                 0,
                                 0.051751703741050543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.079253733904735571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083251949749292023,
                                 0,
                                 0.10010282331702319,
                                 0,
                                 0,
                                 -0.1499695772951834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60508251173832062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29102884535780493,
                                 0,
                                 0,
                                 0,
                                 0.36419480757455286,
                                 0,
                                 0,
                                 -0.50362358643145377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0085469822110387991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17300538939771096,
                                 0,
                                 0,
                                 0,
                                 0.19593022771216573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10643330080382955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44832613321025294,
                                 0,
                                 -0.48352035285283307,
                                 0,
                                 -0.051739634947118529,
                                 0,
                                 0,
                                 0,
                                 0.0062200196145426453,
                                 0,
                                 0.44054615896031241,
                                 0.93458087379371568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77201752779071053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30453505732652625,
                                 0,
                                 0,
                                 0,
                                 0.32102320556795422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46872466654564116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072735634900095159,
                                 0,
                                 -0.022697031852838542,
                                 0,
                                 0.11791253358484224,
                                 0,
                                 0,
                                 0,
                                 -0.46059335779090654,
                                 0,
                                 0.046206538168406412,
                                 -0.55665771498227901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57468839133793681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41118734620362496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35318332284154913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52511501300772156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21701612142383903,
                                 0.20837321398041886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022736763807412075,
                                 0,
                                 0,
                                 0.095611866800766318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27850550105277944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20828562195252043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62913048225985635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51884132482951917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39674900702386329,
                                 -0.20253389721738843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12469763487189803,
                                 0,
                                 0,
                                 0.0084289544245224612,
                                 0,
                                 0,
                                 0,
                                 0.10614627615267443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3939516522993452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83725593507611829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8107707107061386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73092284594135082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06053606900792001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13630281262730565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4515908417037009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9204597911377328,
                                 0,
                                 0.47289856588140583,
                                 0,
                                 0,
                                 -0.91139776955857299,
                                 0,
                                 0,
                                 0,
                                 -0.45928982644125138,
                                 0,
                                 0,
                                 -0.34048449983914864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23485086423095206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2986142907597803,
                                 0,
                                 0,
                                 -0.047996954131414769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.604430741876953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45764506000758742,
                                 0,
                                 0.3523861503854317,
                                 0,
                                 0,
                                 -0.24443650256807253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20899630721597071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22631817071158958,
                                 0,
                                 0,
                                 0,
                                 -0.15361755176118563,
                                 0,
                                 0,
                                 0.17699533685507232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028021615958974233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22206994519840734,
                                 0.54120954385204234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81013258160692825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022914298843431921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012332609192547098,
                                 0,
                                 0,
                                 0,
                                 -0.16190280225842957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092503855196760826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050919959126796449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19333972339864103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38624208912838592,
                                 -0.6652729372656313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46574030186795323,
                                 0,
                                 0,
                                 0.3414269574256163,
                                 0,
                                 0,
                                 0,
                                 -0.90232150270428746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64595008626004813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5749939236374515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28977233986608758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10853791761713381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10891898595185638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22850973114356177,
                                 0,
                                 0,
                                 -0.21185924935736566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25198738440383101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68516069608357832,
                                 0,
                                 -0.25429702609336491,
                                 0,
                                 0,
                                 0.5259390055275126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017720543316483775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013694980914423432,
                                 0,
                                 0,
                                 0,
                                 0.16721067165040671,
                                 0,
                                 0,
                                 -0.014708704611772705,
                                 0,
                                 0,
                                 -0.094956350276699103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15153746459849338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52601066184865397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048246050035024163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36206363983266576,
                                 -0.36130913253624669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28874877916224029,
                                 0,
                                 0,
                                 -0.58651049831361934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39466403262611072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079673166457119221,
                                 -0.037168668482671266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040623665384747557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20977197229348418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88930108255417484,
                                 0,
                                 -0.28806359944663823,
                                 0,
                                 0,
                                 -0.30337555934229998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32429111173066461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18766271686755803,
                                 0,
                                 0.14004050435779325,
                                 0,
                                 0,
                                 0.12107024969326294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60751826817341226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084687072689658596,
                                 0,
                                 0,
                                 0,
                                 0.33375571865606046,
                                 0,
                                 0,
                                 -0.40334605218795083,
                                 -0.43255822465819721,
                                 0,
                                 0,
                                 0,
                                 -0.11930216730729455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50672328355192697,
                                 0,
                                 0,
                                 -0.76971381450865439,
                                 0.75441220996320935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.079293703942679081,
                                 0,
                                 0,
                                 0,
                                 -0.33229099055424571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044688083598904776,
                                 0,
                                 0.096649963991247645,
                                 0,
                                 0,
                                 0,
                                 -0.58777029290037508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33061680743410821,
                                 0.18904509691480589,
                                 -0.28452339697093987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35014165402457631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011066337697418188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32769800621453438,
                                 0,
                                 0,
                                 0.59400235667384294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27993747283014414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060037421423424796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33028019795441027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37905988762908222,
                                 -0.43086957231946743,
                                 -0.4416018257710963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13218464302075519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10841613464168451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015689558296852528,
                                 0,
                                 0,
                                 0.02341221026221213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20845805722328317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32452648104606202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54484815340053616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28481272383951967,
                                 -0.11290757184446733,
                                 0.094432467126728037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47817751814156234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4449565097195527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096316431831690294,
                                 0,
                                 0,
                                 -0.072372334029472671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37595471068106623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41052525047945249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38234608900270622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034085990590243864,
                                 0,
                                 0,
                                 0,
                                 0.012732784060499616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13174021806309041,
                                 0,
                                 0,
                                 0.827079410675987,
                                 0.57673906745148595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79338725887137374,
                                 0,
                                 0,
                                 0,
                                 -0.47833167491696893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21748525192952486,
                                 0,
                                 -0.17569911789461695,
                                 0,
                                 0,
                                 0,
                                 0.098386100232760842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31327951306660123,
                                 0,
                                 0,
                                 0,
                                 -0.56009570683000509,
                                 -0.0013437910005688336,
                                 0,
                                 -0.42075132279666039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32769732541033902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52333185275572847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15293813987822585,
                                 0,
                                 0,
                                 0.080395426827109123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75854330563434835,
                                 -0.29205388003890126,
                                 0,
                                 0,
                                 0,
                                 -0.084591876776107022,
                                 0,
                                 0,
                                 -1.0542666755869563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27930381201072951,
                                 0,
                                 0,
                                 0,
                                 0.11311779020620244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46738056618219437,
                                 0,
                                 0,
                                 0.25786497183577611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18849447706912123,
                                 -0.56404734931565392,
                                 0,
                                 0,
                                 0,
                                 -0.3741775578465526,
                                 0,
                                 0,
                                 -0.16262220362330654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1031973625759282,
                                 0,
                                 0,
                                 0,
                                 -0.30173031157455482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4546027129418716,
                                 0,
                                 0,
                                 -0.47674493806119245,
                                 0,
                                 0,
                                 -0.27823939131280384,
                                 0.24400968905788362,
                                 -0.13589552331112287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10731108598669445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4962420168788062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20916745095939387,
                                 0,
                                 0,
                                 0.47251042687681749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30129492135291802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4400819855099834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18797553396261563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49729879276943634,
                                 0,
                                 0,
                                 0,
                                 -0.40461601222204185,
                                 -0.021591847065126547,
                                 0,
                                 -0.32385875805975317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27742989295309212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19340594566983449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20303132793391199,
                                 0,
                                 0,
                                 -0.57274266899270698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030709499287765327,
                                 0,
                                 0,
                                 0,
                                 -0.33863366358973401,
                                 0.038169547487093142,
                                 0,
                                 0.71190870672020712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47915844191310736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10461015517827697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16113636761322744,
                                 0,
                                 0,
                                 -0.33107736480659228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34289315919101149,
                                 -0.88166476395249038,
                                 0,
                                 0,
                                 0,
                                 -0.97684870717612871,
                                 0,
                                 0,
                                 0.75526693771046072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12010175258765643,
                                 0,
                                 0,
                                 0,
                                 0.326642066077871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54018949867851984,
                                 0,
                                 0,
                                 0.026655682401732293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52096672514284026,
                                 0,
                                 0,
                                 0,
                                 -0.25520638009121371,
                                 0.0049144232771881069,
                                 0,
                                 -0.23570332477708555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057120184586927102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72632193554955293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27693940147226953,
                                 0,
                                 0,
                                 -0.019531112412005891,
                                 0,
                                 0,
                                 0,
                                 0.40442880184363517,
                                 0.54305252671171123,
                                 -0.18487375415871277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52231209766023601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19024102832745221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18314979444754037,
                                 0,
                                 0,
                                 -0.12257956574728113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11608209449943695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35832561003022323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088935502817572093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1350121931142505,
                                 -0.6044959394335766,
                                 0,
                                 0,
                                 0,
                                 0.15863843124522459,
                                 0,
                                 0,
                                 -0.88444848577032764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22565166671605177,
                                 0,
                                 0,
                                 0,
                                 0.81353269315529486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.049573862661951115,
                                 0,
                                 0,
                                 -0.22042723917595489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20997264029402113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75331372839263322,
                                 0,
                                 0,
                                 0,
                                 0.042206351597759789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026697293572961626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18581518372964498,
                                 0,
                                 0,
                                 0.59279719368376771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1768618070863312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47212614220922533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71697134978220833,
                                 0,
                                 0.78927146381531765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9149217032045851,
                                 0.52907731627275068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34361456448000099,
                                 0,
                                 0,
                                 0,
                                 0.4637264531033885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58903237481038295,
                                 0,
                                 0,
                                 -0.067900052941557112,
                                 0.10737091729640333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55432419467642213,
                                 0,
                                 0,
                                 0,
                                 -0.80823424013250189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46315983832265561,
                                 0,
                                 0.35776557595415687,
                                 0,
                                 0,
                                 0,
                                 -0.57328120089111434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047190351396640712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015869864827860097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45731052918712567,
                                 -0.31286818944122319,
                                 0.49778548865966549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36919407185925229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094593735106310389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073677715931657478,
                                 0,
                                 0,
                                 0.3985477675280924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32134296282598845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026105027303453598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17811918694517659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073341143131603836,
                                 0,
                                 0,
                                 0,
                                 -0.086335755784208865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73332111748935191,
                                 0,
                                 0,
                                 0.29497302093321087,
                                 -0.46809766402449909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24058270029496362,
                                 0,
                                 0,
                                 0,
                                 -0.16549012078629474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1206518577799236,
                                 0,
                                 0.22323794008497735,
                                 0,
                                 0,
                                 0,
                                 0.4469514771022165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10804492094850583,
                                 0,
                                 0,
                                 0,
                                 0.019695630060877045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19364766257027627,
                                 0,
                                 0,
                                 -0.0015583235089756536,
                                 0.70464387831252107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53962644041158592,
                                 0,
                                 0,
                                 0,
                                 -0.011807283018898843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54559448573862168,
                                 0,
                                 0.21455172226218266,
                                 0,
                                 0,
                                 0,
                                 1.0913956668199307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027485167296891835,
                                 -0.15548600431315679,
                                 0.20977685013002542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28397921138212967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56807295438357319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6053679394855298,
                                 0,
                                 0,
                                 -0.19302281182586775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29162710953271304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1647910032179799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10853881054030587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73888131476247731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49773925765001747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57727020259940998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53966550531827651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35727685295031786,
                                 0,
                                 -0.67105711274534907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66495198745492601,
                                 -1.0625886870879824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24598095446686111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076761018626465005,
                                 0,
                                 0,
                                 0,
                                 0.55699187746045087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33686962743372473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67066577376809611,
                                 0,
                                 0,
                                 -0.24512739241216536,
                                 -0.79489177147068768,
                                 0,
                                 0,
                                 0,
                                 0.50160258066368013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0092656992346301179,
                                 0,
                                 0,
                                 0.17002515274497199,
                                 -0.41868560133276805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1078786518629721,
                                 0,
                                 0,
                                 0,
                                 -0.72243777349250227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61751910528053411,
                                 0,
                                 0.10833223760820382,
                                 0,
                                 0,
                                 0,
                                 0.098936948285634499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21191053068040538,
                                 -0.20648783621799774,
                                 0.30287627777716747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030165438667367123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17544270906474302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39245454225949833,
                                 0,
                                 0,
                                 0.31963436896801589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62311352635921913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31223560583049637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21698922816762758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02214895276896689,
                                 0,
                                 0,
                                 0,
                                 -0.025882695670069275,
                                 -0.61001722414421078,
                                 0,
                                 0.045711157854615922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034887998593892106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24612550437216452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6841429525287499,
                                 0,
                                 0,
                                 -0.30786761831666487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62563308669769635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26666992714933158,
                                 0,
                                 0,
                                 0,
                                 0.22416570838572147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67146122320699275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15130329637480311,
                                 0,
                                 0,
                                 -0.11604854244107699,
                                 -0.27488893426410943,
                                 0,
                                 0,
                                 0,
                                 0.82549698955754169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42726849206925788,
                                 0,
                                 0,
                                 0.20274284401428433,
                                 0.25354356622354007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33997003283638799,
                                 0,
                                 0,
                                 0,
                                 0.41913216754691218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22090194469563071,
                                 0,
                                 0.58240918672220687,
                                 0,
                                 0,
                                 0,
                                 0.22346764392224344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59262637319040823,
                                 -0.21428198344978094,
                                 0,
                                 0,
                                 0,
                                 0.038348895909645103,
                                 0,
                                 0,
                                 -0.59934649573081777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0248568779110354,
                                 0,
                                 0,
                                 0,
                                 -0.97182217919729141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43237276901216593,
                                 0,
                                 0,
                                 0.2178695115151677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.4547839472473427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15524862153928748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38632993328285725,
                                 0,
                                 -0.62348214867239526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035832886620120852,
                                 0.52943853660560658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37556354258190761,
                                 -0.35898606385236048,
                                 -0.43743646587758744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34355992397383917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0078047833918716419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20022968228862734,
                                 0,
                                 0,
                                 0.2214575451579025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23594428463518979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51941966751299617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077679903004874665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020785721076833297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70311235322188104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65918731335126812,
                                 0,
                                 0.15045869510318075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2800596188988316,
                                 -0.12657066513861073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040452869901417443,
                                 0.46831636623346129,
                                 0,
                                 0,
                                 0,
                                 -0.34928540096499644,
                                 0,
                                 0,
                                 -0.86815929626310895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55543629359442293,
                                 0,
                                 0,
                                 0,
                                 -0.0075492861941871547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0175411093501612,
                                 0,
                                 0,
                                 -0.10452390736919046,
                                 0,
                                 0.23490863951283095,
                                 0,
                                 0,
                                 0,
                                 -0.77791393845925016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18560364287176984,
                                 0,
                                 0,
                                 -0.18662639855723168,
                                 -0.52895625066029806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6048812304516894,
                                 0,
                                 0,
                                 0,
                                 -0.14348551435074852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096783645103292321,
                                 0,
                                 1.049999234574464,
                                 0,
                                 0,
                                 0,
                                 0.2225390108899736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28936532826451355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3627612954614417,
                                 0,
                                 0,
                                 0,
                                 0.47000445763949883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23367668924976148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58986237736951141,
                                 0,
                                 0,
                                 -0.40152875336364996,
                                 -0.58605337889176201,
                                 0,
                                 0,
                                 0,
                                 -0.77176519341895622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72868129650996116,
                                 0,
                                 0,
                                 -0.0084174533288145642,
                                 -0.16727593945663075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031906611522525663,
                                 0,
                                 0,
                                 0,
                                 -0.29578995053566365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4269437941009902,
                                 0,
                                 -0.14480610962119078,
                                 0,
                                 0,
                                 0,
                                 0.82116220274919738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5984463170703278,
                                 0,
                                 0,
                                 0,
                                 -0.24012428967187233,
                                 0.22256274554350847,
                                 0,
                                 -0.076354218131136686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37771555131729029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14512957047918662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40842835721860571,
                                 0,
                                 0,
                                 0.44530083746785382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48774028381088225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0303347074612581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4740911967938185,
                                 0,
                                 0.4991453534667219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65402126387978976,
                                 -0.23499180203552783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33077069556202698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42479388713877841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69149894680421031,
                                 0,
                                 -1.013219048927501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16092850945821241,
                                 0.48538312015980584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37019957932797354,
                                 0,
                                 0,
                                 0,
                                 -0.5046392448273016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14586199607551584,
                                 0,
                                 0,
                                 0.37573188444023337,
                                 0.23928944663171733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41603612576606946,
                                 0,
                                 0,
                                 0,
                                 0.26734737020931021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053508220509548073,
                                 0,
                                 0.47602646124078307,
                                 0,
                                 0,
                                 0,
                                 -0.69302233219850251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17048643311521988,
                                 -0.34328974064497919,
                                 -0.29595515552381801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10515168390648538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.381042621200399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48967835188445324,
                                 0,
                                 0,
                                 -0.2361689172559415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018351565285367032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073159287406161455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55497478604569617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074519713938532336,
                                 0,
                                 0,
                                 0,
                                 -0.35655810285912864,
                                 -0.61458496822535735,
                                 0,
                                 0.21348424535703206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29044813979306155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14563928972615064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2819608523186331,
                                 0,
                                 0,
                                 0.50887137714196085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45736152336034641,
                                 0.38965437263349545,
                                 0,
                                 0,
                                 0,
                                 -1.1585403769415969,
                                 0,
                                 0,
                                 0.0022094106618616993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18451674534562956,
                                 0,
                                 0,
                                 0,
                                 -0.4008485474805642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2685206675506201,
                                 0,
                                 0,
                                 0.34264337013550134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60405849364208064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2774883216147927,
                                 0,
                                 0,
                                 0,
                                 0.41260273719669283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58572892182465119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21098043192356614,
                                 0,
                                 0,
                                 0.016776065317570601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13423374039700892,
                                 0,
                                 0,
                                 0,
                                 0.3966262196937968,
                                 -0.4457365228804,
                                 0,
                                 -0.31971669581577511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59543703059941055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21766927803913486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34403578226295367,
                                 0,
                                 0,
                                 -0.059019826238027082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11298628093667834,
                                 -0.50838148874518785,
                                 0,
                                 0,
                                 0,
                                 0.39121998021484283,
                                 0,
                                 0,
                                 0.11769717492476445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61618347211819724,
                                 0,
                                 0,
                                 0,
                                 0.0038129674535051783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17510028930964444,
                                 0,
                                 0,
                                 1.1587992773894202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23530649003772647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38329857353155933,
                                 0,
                                 0,
                                 0,
                                 -0.49657144356941496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19303566871776237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31676029266151917,
                                 0,
                                 0,
                                 -0.64306298937340256,
                                 0.17259143119544332,
                                 0,
                                 0,
                                 -0.41010696657946077,
                                 0,
                                 0,
                                 0.018516566470952546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15938169661255969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020007340288660448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38008549656832658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21776194074573813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76419470306170101,
                                 0,
                                 -0.17873101089664045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68621900611564257,
                                 0.21652253241051439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10107473122822852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40726671088169525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94776564657656293,
                                 -0.24886134976431901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82964520256565222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23597865112201238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80691636362547459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28395571122168189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23703021617035006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3905608434593717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062033189271607045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066670479750310957,
                                 0,
                                 0,
                                 0.59824476575230123,
                                 0,
                                 0,
                                 0.042505752104554012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24922135439633453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54641697316668347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42828444663315746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23131638267334714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1955348568545594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10780046489291747,
                                 -0.22417322140593121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33497567558249891,
                                 0,
                                 -0.29934266458617503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77385994131660074,
                                 0,
                                 -0.0018764634227156733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1028201245431353,
                                 0,
                                 0,
                                 -0.060250490735092116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1280345357766223,
                                 0,
                                 0,
                                 -0.24631971345258064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40288169896528603,
                                 0.13051025283571466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54476380075661923,
                                 0,
                                 -0.25211579099039899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18895040575431263,
                                 0,
                                 0.49785222934405005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20769733266988821,
                                 0,
                                 0,
                                 -0.57713262006957167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19586516862890496,
                                 0,
                                 0,
                                 0.75377649908750888,
                                 0,
                                 0,
                                 0,
                                 0.67865460264358901,
                                 0,
                                 0,
                                 0.18729271205067899,
                                 0,
                                 0,
                                 -0.16666269502804515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051466207087682042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13845251206448417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28545052090806156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50622977721851603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34205914782535934,
                                 0,
                                 0.493493663326104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37144692792211648,
                                 -0.67085754285991728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11290344728691713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16683926759026751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42166037947617779,
                                 -1.0976290721290805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27581093444064836,
                                 0,
                                 0,
                                 0,
                                 -0.62400373098217277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20292119801145753,
                                 0.30535602925057831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38202157084910127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070025029748719603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89332536068670099,
                                 -0.0077672101801702365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0851582113179419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66186697616631318,
                                 0.3667133659070263,
                                 0,
                                 0,
                                 0.21466176475766369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23364836595415103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28069991303475611,
                                 0.016973815679878945,
                                 0,
                                 -0.12321257557380566,
                                 -0.34927035727137362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05345934874842994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32813504255202336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12803828164935699,
                                 -0.026832093700814828,
                                 0,
                                 0,
                                 -0.51540618871348598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13235956365046295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44175219327481419,
                                 0.094819247522290678,
                                 0,
                                 0.10048853131201874,
                                 -0.45329921968277276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4944647558319053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18845273017932523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62517180506793379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42718253311013754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41438136783744461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37871215152740878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077851408611846945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3247762984047774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080469665395518308,
                                 -0.44695012245494681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26787655169398106,
                                 0,
                                 -0.44755081686089809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069222226376080095,
                                 0,
                                 -1.1978024017215501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084109453647852772,
                                 0,
                                 0,
                                 0.11838615523955229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57811682121181596,
                                 0,
                                 0,
                                 0.13529940005514363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14341519817932075,
                                 0.47283008518181435,
                                 0,
                                 0,
                                 0.06441172689539422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083920022764963853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10835204999612746,
                                 0.082224353740043971,
                                 0,
                                 -0.13449190786586337,
                                 0.60927327672391995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57662888645832444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066094386295847102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91158778303704158,
                                 -0.1717224392647187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15442448486996213,
                                 0,
                                 0.34354990049082618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58439707543849551,
                                 0,
                                 0.17917617642799982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77716862813470466,
                                 0,
                                 0,
                                 0.16926492044375407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11803199451087605,
                                 0,
                                 0,
                                 -0.47078986645615134,
                                 0,
                                 0,
                                 0,
                                 -0.14030121160097225,
                                 0,
                                 0,
                                 0.23038129366359789,
                                 0,
                                 0,
                                 0.24495984176782121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53416454308120009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45512981456561319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35470193102830755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49515490060651102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061383734105543028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25290960305433652,
                                 0,
                                 0,
                                 -0.46083295826884224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10740632683365131,
                                 0,
                                 0,
                                 -0.46867015946097745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2218965514334541,
                                 0,
                                 0,
                                 0.84506918243695495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69381867629506233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12519052106888479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66957965196565827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21528420088568617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048144927119444847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077076886119571697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55791535506115619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86575368702566347,
                                 -0.036916049309584323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45572482212481585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6688739261389286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72021633414802644,
                                 0.38405445580801106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34761944887073198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89140481706153496,
                                 0,
                                 0,
                                 0.20132713141791456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1615836686597008,
                                 0,
                                 0,
                                 0.13620503416835913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64308797072314772,
                                 0,
                                 0,
                                 0.57322128097837988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0091072515885179586,
                                 -0.49009150977146976,
                                 0,
                                 0,
                                 0.14819376152580502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020471889539343213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73822764830727039,
                                 0.035691412480934187,
                                 0,
                                 0.0242477295568704,
                                 0.34999013853252253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14243457383819641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21845888828022922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20319990910886823,
                                 0,
                                 0,
                                 -0.5380337130267453,
                                 0,
                                 0,
                                 0.52530697536742144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10307858338136144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45325258922968387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14623961440843983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10546713803226082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38040722415950162,
                                 0,
                                 0,
                                 0.17743656911513975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22531359828257519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33983922842133474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69266130868756082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55246408805649738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13138907127588167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23097350886751972,
                                 -0.9584506366551323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085034727015441458,
                                 0,
                                 -0.49119207063455517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39895874521395897,
                                 0,
                                 0.34840034278047505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38152502632565749,
                                 0,
                                 0,
                                 -0.28050990164178807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70014660758202441,
                                 0,
                                 0,
                                 -0.37878238715562418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1338327093603133,
                                 0,
                                 0,
                                 -0.33975378608776102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43385763805868438,
                                 0,
                                 0,
                                 -1.2647214538713818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042682276827155197,
                                 0,
                                 0,
                                 0.073783181075981974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83081757709509485,
                                 -0.16263629798540699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20123291535647364,
                                 0,
                                 0.8831874739629858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1785754023763434,
                                 0,
                                 -0.34845142151845676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19863106275736264,
                                 0,
                                 0,
                                 -0.58844369794133311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046009051570033849,
                                 0,
                                 0,
                                 0.20476442419526331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95736266050942165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020948049419778333,
                                 0.43117511575413303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33207237465341577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35432524924520781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10065730027841099,
                                 -0.52701742155838249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0850771816626352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8728394800479109,
                                 0,
                                 0,
                                 -0.45307459350849166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87303538064049424,
                                 0,
                                 0,
                                 0.41092126057889361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52306868533740281,
                                 0,
                                 0,
                                 0.76460965450459806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17117300350793035,
                                 0,
                                 0,
                                 0.20141088366742008,
                                 0,
                                 0,
                                 0.64869301554794956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46668141166683708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36455122989833133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026534238465866056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37997552035982513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11643122128656685,
                                 0,
                                 0,
                                 0.18129388669620256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25493281028327086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42871946787432413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31548426683413983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69923122883134725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36039807541154184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082568700431451036,
                                 -0.3876538441639944,
                                 0,
                                 0,
                                 0.16952076862621379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6200295961464749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069910741804166399,
                                 -0.42333853098378033,
                                 0,
                                 -0.1015761285659639,
                                 -0.031930500782507296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35099027786430742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33331434135918436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52142691955419374,
                                 -0.35766144480233653,
                                 0,
                                 0,
                                 -0.30535116519225791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34391492516312011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24580192181258725,
                                 0.10269299488597686,
                                 0,
                                 -0.48187324893956279,
                                 0.21204374204049556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20113516670241646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0095540985958448288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3767326463623259,
                                 -0.50835450951004291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77683821961645716,
                                 0,
                                 -0.59255311002811162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028257738652603309,
                                 0,
                                 0.10132525960651187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27958795703281875,
                                 0,
                                 0,
                                 0.15285137309265079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41415567453889668,
                                 0,
                                 0,
                                 0.15090037877586115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35290896231113661,
                                 -0.17158810679949468,
                                 0,
                                 0,
                                 0.57692909010937576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20541296624089186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048802934927440603,
                                 0.27150024081587998,
                                 0,
                                 -0.44130068510843956,
                                 -0.35425885345406249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24679015206792251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11715804669352281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28348397468140374,
                                 -0.10470729654968838,
                                 0,
                                 0,
                                 -0.33694610242720524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18467132183690055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15296989884872694,
                                 -0.31993038977565497,
                                 0,
                                 -0.12993921696190977,
                                 -0.080954839248567306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066375746126760768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77938320168329489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59028612747225706,
                                 0.55421218784768389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099673597041541287,
                                 0,
                                 -0.60209303962394523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42916192589727831,
                                 0,
                                 0.35179105778352576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20014048344310412,
                                 0,
                                 0,
                                 0.21530878736181083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39724313281507867,
                                 0,
                                 0,
                                 0.11220458174209162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88935086667502738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5267047673923877,
                                 -0.43495193810903549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6249842378478464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9920302120725808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41529783176547524,
                                 -0.21149552474421501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14678705077109189,
                                 0,
                                 0,
                                 0,
                                 0.034440078382448294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62206261880852198,
                                 0.70889763445768816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28599524979076524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1108856648997811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73122590028183432,
                                 0.45807183430845017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026879499451633593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62116149879808635,
                                 0,
                                 0,
                                 0.57776866137235006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59182431080289233,
                                 0,
                                 0,
                                 0.15770166186034451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17244477178969436,
                                 0,
                                 0,
                                 0.16208753429373465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20028489667671637,
                                 0.25135513837608042,
                                 0,
                                 0,
                                 -0.23102057375656834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16093082941885095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25465167587572451,
                                 -0.12643474365509444,
                                 0,
                                 -0.70844011127967921,
                                 -0.011465674795867575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40625245245964209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26371232184234122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51406198612174492,
                                 0,
                                 0,
                                 0.021990543239380669,
                                 0,
                                 0,
                                 0.062065288989824427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41515030351686266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17458119211188883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66295135835671126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037622942477189641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29606795476414161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73097842417181336,
                                 0,
                                 0,
                                 1.0194988648908265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16147614728747062,
                                 0,
                                 0,
                                 0.11995799553150815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33747985707446376,
                                 0,
                                 0,
                                 0.35772913322813915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087970025429896098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18700653363874895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0054076259905279644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41801493344627305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2119966314850911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8588256704583952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2093993976738488,
                                 -0.22187576491630712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021827530502493878,
                                 0,
                                 0.18517348455621122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2839882114550587,
                                 0,
                                 0.40732105255403461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048358325616483726,
                                 0,
                                 0,
                                 0.49180515496138366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63606265415972363,
                                 0,
                                 0,
                                 1.0970554696721848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24766020772584321,
                                 0,
                                 0,
                                 0,
                                 -0.0087792980350290539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034086376284714455,
                                 0.13878276075433374,
                                 0,
                                 0,
                                 0.20109585857527587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56170884540053878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1157896457871701,
                                 -0.77515903924636709,
                                 0,
                                 0.002695669735812891,
                                 -0.025620768937907157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076527892615134999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053123497160593808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27960720550248058,
                                 -0.63892578984438664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0586368794223882,
                                 0,
                                 0.51653997857433942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47183562378456423,
                                 0,
                                 -0.1537169216748745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47766961121863727,
                                 0,
                                 0,
                                 0.62940788511040946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46848905464721713,
                                 0,
                                 0,
                                 0.047422745584439492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094428484579077182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.074492686471022501,
                                 -0.44144211202779371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1246819039791993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13142709904495392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11185534413432727,
                                 0.59322810910999357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12852389674299153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21050428477575164,
                                 0,
                                 0,
                                 0,
                                 -0.15724093555975105,
                                 0,
                                 -0.38815025386379798,
                                 0,
                                 0,
                                 -0.23501313016629849,
                                 0,
                                 0,
                                 -0.45767507352211573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47301073231293495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32542564444652045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056722077962110068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49061727064396832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10525223428654068,
                                 -0.55473707983869547,
                                 -0.60063741674734572,
                                 0.49238345830155683,
                                 0,
                                 0,
                                 0,
                                 -0.63750719405309331,
                                 1.2575414776509617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13301354960122369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14574576556624214,
                                 -0.70429874956751626,
                                 -0.58470746222114489,
                                 0,
                                 0,
                                 0,
                                 -0.30363092660342139,
                                 -0.16669029373543481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.93582457964642762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1329273005071803,
                                 -0.25630528262301333,
                                 0.27191400912855496,
                                 0,
                                 0,
                                 0,
                                 -0.99250959976480502,
                                 -0.89764880336279518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13662137562149654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31966092162170434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28285735159640246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050125452779486601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60674369049234078,
                                 0,
                                 -0.45191205809549817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25147775866415045,
                                 0,
                                 0.24493633691408026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22910863528755507,
                                 0.35864855315446559,
                                 -0.14579035407668925,
                                 0,
                                 0.28671793229587528,
                                 0,
                                 0,
                                 0,
                                 0.1315621566055325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23013125888988115,
                                 0,
                                 0,
                                 0,
                                 -0.49873915628945392,
                                 -0.94819069433687941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50983720508306229,
                                 0,
                                 0.085847046491543122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014045460731627601,
                                 0,
                                 0,
                                 0,
                                 0.29790767911242411,
                                 0,
                                 0,
                                 0,
                                 0.32153860817662105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17819731976332542,
                                 -0.69293274735561428,
                                 -0.20852350104810319,
                                 0,
                                 0,
                                 0,
                                 -0.44649827664001673,
                                 0.64834823055767976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93937868537932923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62207687968048042,
                                 0.26310212623837592,
                                 -0.80728897975233227,
                                 0,
                                 0,
                                 0,
                                 0.50274295445018269,
                                 0.36222530471254077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0092414411184165712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24805993012157565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59599412009423403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41129257144126607,
                                 0.15350385364719982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13668764339357739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60979402720703924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025848629030673524,
                                 0,
                                 0,
                                 0,
                                 0.70422387332032976,
                                 -0.27932879648227282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095492847991789725,
                                 0,
                                 0.22527492919909817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66145744021429187,
                                 0,
                                 0,
                                 0,
                                 0.3913893141997834,
                                 0,
                                 0,
                                 0,
                                 -0.15795768251896963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11013113326982736,
                                 0,
                                 0,
                                 0,
                                 0.18269587754045208,
                                 -0.38263976257277987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39867678052742905,
                                 0,
                                 -0.8580154291483465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17006228027352921,
                                 0,
                                 0,
                                 0,
                                 0.14921772829658597,
                                 0,
                                 0,
                                 0,
                                 -0.69637619636954762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14777591828774417,
                                 -0.17955204502604044,
                                 0,
                                 -0.43438408095350889,
                                 0,
                                 0,
                                 0.24648667473034874,
                                 -0.054755994573691173,
                                 0.74018698835446417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35230983160294033,
                                 0,
                                 0,
                                 0.94518365086093048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18604460438731968,
                                 0,
                                 0,
                                 0.44284812115154842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.272346214528495,
                                 0.078774906259650737,
                                 0,
                                 0.37416527256384702,
                                 0,
                                 0,
                                 0.1667859966578826,
                                 0.44429768914174567,
                                 -0.13926941051252656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0277696957837485,
                                 0,
                                 0,
                                 0.51747927803380767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12171639412372556,
                                 0,
                                 0,
                                 0.11543277853365871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14076989403695517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36469244129197237,
                                 0,
                                 -0.20979086959916651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25647979455259912,
                                 0,
                                 0.38351122751090178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017252764538357189,
                                 0.44371886012385869,
                                 0.2113816142969292,
                                 0,
                                 -0.36161398108938292,
                                 0,
                                 0,
                                 0,
                                 0.4665590656000263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18076434387180751,
                                 0.058768861101044206,
                                 0,
                                 -0.00061179123261508039,
                                 0,
                                 0,
                                 -0.77971429824120264,
                                 -0.35461237850029442,
                                 0.8900609707931223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030864612091839601,
                                 0,
                                 0,
                                 -0.013508483492164519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25160395716135553,
                                 0,
                                 0,
                                 0.49929116844893989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42100588987829185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24211912313666406,
                                 0,
                                 0.10488856580230191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028680342296719077,
                                 0,
                                 0.5527156606353093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14748866848890019,
                                 -0.49652574330829591,
                                 -0.30215331748060348,
                                 0,
                                 -0.29420904188144054,
                                 0,
                                 0,
                                 0,
                                 0.02583190716260593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18491323061727208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21790334731393232,
                                 -0.20950491917516501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25449930074260163,
                                 0.23356243644434674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68310321145588848,
                                 -0.43756614891922857,
                                 -0.31147629000588378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52147702341072111,
                                 -0.69668906931075658,
                                 0,
                                 -0.021048959502137421,
                                 0,
                                 0,
                                 -0.74434233462335708,
                                 0.36009556538424931,
                                 0.74899462738422784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32767268932441135,
                                 0,
                                 0,
                                 0.31212645895445368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0015022371246563304,
                                 0,
                                 0,
                                 -0.56586870595380745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30085358525514905,
                                 -0.11106235772746842,
                                 0,
                                 0.24474980490655629,
                                 0,
                                 0,
                                 0.12346856706061968,
                                 0.50249114063963196,
                                 0.45496608049114751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56666114491265984,
                                 0,
                                 0,
                                 0.49627686611927313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84450616471895035,
                                 0,
                                 0,
                                 -0.23071584091703878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31916146640576032,
                                 0.20604894276872385,
                                 0,
                                 0.56237495933158876,
                                 0,
                                 0,
                                 0.61706853965617436,
                                 -0.69031361265738256,
                                 0.1261609980221278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23441738580928667,
                                 0,
                                 0,
                                 -0.097370269507734156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34942651852097811,
                                 0,
                                 0,
                                 -0.31921530571264634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16384594175523384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22385501952477993,
                                 0,
                                 0.59756955737944473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18681451077908942,
                                 0,
                                 0.42240983381004621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27626658583825869,
                                 0.19310927814821655,
                                 0.090032146629817233,
                                 0,
                                 0.47597201574548814,
                                 0,
                                 0,
                                 0,
                                 -0.065990647844386741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37952215039943171,
                                 0.60633866269040793,
                                 -0.59316901682822587,
                                 0,
                                 0,
                                 0,
                                 -1.1200880212111515,
                                 0.2153073461328453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65426189884634778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55079411326741967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44643037937673957,
                                 0,
                                 0.39990042101875467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21153942462722777,
                                 0,
                                 0.11724674782911916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036081421474348396,
                                 -0.11459497416445373,
                                 0.24756720192510073,
                                 0,
                                 -0.040678158651048534,
                                 0,
                                 0,
                                 0,
                                 0.44892268514831279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48488306573790935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2020917645489419,
                                 0.37036441845101975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59417786390485383,
                                 0.43728597042570738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18668746126260569,
                                 0.080055982346497273,
                                 0.036742433502812061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040119437258456639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65458049732263868,
                                 0.20640783147810418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43477985674540603,
                                 -0.094415575465744611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31299353866103119,
                                 -0.056766458394519367,
                                 0.47767708718246382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.089573955518203893,
                                 0,
                                 0,
                                 0,
                                 0.66460252746003656,
                                 -0.0026812086546021616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049367510609737403,
                                 0,
                                 0.69336371931897001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86616566044534915,
                                 0,
                                 0,
                                 0,
                                 -0.51559423179381358,
                                 0,
                                 0,
                                 0,
                                 0.059624031744053944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26303963252487117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12565095071304405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46585380047403796,
                                 -0.64644612082123643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17347033960387487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50001768073026798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79912243877218281,
                                 0,
                                 0,
                                 0,
                                 0.6013143427358959,
                                 0.20824681601255926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4861145330953866,
                                 0,
                                 -0.27041956533243988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36530448678416372,
                                 0,
                                 0,
                                 0,
                                 -0.20534380613904535,
                                 0,
                                 0,
                                 0,
                                 0.58869088239496303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065694864259737279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53470285079462143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18876281824640745,
                                 0.75889466353658008,
                                 0,
                                 0.37658369009577208,
                                 0,
                                 0,
                                 0.021631796256523173,
                                 0.40139498225467324,
                                 0.41638408949183542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33979319788131535,
                                 0,
                                 0,
                                 -0.064524312763129976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33608323769328974,
                                 0,
                                 0,
                                 -0.53519981616034396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44609175357721242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23728963389524643,
                                 0.010625940331587744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18512733842391504,
                                 0.77653434655169473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27234788855760955,
                                 -0.11345379676658603,
                                 -0.142337652149407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10862469314382937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44597316746005661,
                                 -0.2615262628559385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.055608413537482249,
                                 0.3099054837195156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16557259288822185,
                                 0.15544129870079257,
                                 0.75511763217962236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17549106312831231,
                                 -0.56726856722665087,
                                 0,
                                 0.52325633226270962,
                                 0,
                                 0,
                                 0.2716403218890503,
                                 0.06428869203983574,
                                 0.50367641607776148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40860759845745126,
                                 0,
                                 0,
                                 -0.48697844497692511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38775656278787368,
                                 0,
                                 0,
                                 0.24281799505253085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44314130638445159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72855840613372191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22798535672001449,
                                 -0.11303157427049462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13306328837551817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43631311354765351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8068385920750456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28057789529865546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34609974393021625,
                                 -0.18707969721104212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1953052320014389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27813585080651226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57910066052930298,
                                 0,
                                 0,
                                 0,
                                 -0.31674858426332037,
                                 -0.030401924433474448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77801662767879431,
                                 0,
                                 0.090827076563933101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66733602495165001,
                                 0,
                                 0,
                                 0,
                                 -0.32627209365450427,
                                 0,
                                 0,
                                 0,
                                 -0.41940863161943193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069915780026364394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0014742364321280316,
                                 0,
                                 -0.12996183963156716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66495194246312317,
                                 0,
                                 -0.047495045884802828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6687024473768437,
                                 -0.23468651537268015,
                                 -0.0665745788094389,
                                 0,
                                 0.15480248837056254,
                                 0,
                                 0,
                                 0,
                                 -0.056266835932201976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22517875139775259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18841061208715665,
                                 0,
                                 -0.20877557745828412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25881349757378791,
                                 0,
                                 -0.1654243626741424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0036110901547128649,
                                 -0.47215118751130447,
                                 0.22728880972145143,
                                 0,
                                 0.37126422508569457,
                                 0,
                                 0,
                                 0,
                                 0.60284489833025401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34702082167650128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11702663133871608,
                                 0,
                                 0.36626084600806241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12280219482222886,
                                 0,
                                 -0.45205432558594993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030727244141961318,
                                 0.29021352046102927,
                                 -0.51761270413297755,
                                 0,
                                 -0.021626894058744572,
                                 0,
                                 0,
                                 0,
                                 0.39842456275986193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54713893955294601,
                                 0,
                                 0,
                                 0,
                                 0.40633927153188787,
                                 0.11327851995337221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19138233672962535,
                                 0,
                                 -0.28467819251427645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090668588369367697,
                                 0,
                                 0,
                                 0,
                                 -0.6839077049628024,
                                 0,
                                 0,
                                 0,
                                 0.87519534576836189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34857594850745749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26717072227231026,
                                 0,
                                 -0.17066793966578006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28290275332710424,
                                 0,
                                 0.24191208718625637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41455014397003181,
                                 -0.013721132591488126,
                                 -0.50304470659504752,
                                 0,
                                 0.45676272097038506,
                                 0,
                                 0,
                                 0,
                                 0.075534034972684336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10892980791303122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04733079748688486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16679594719274207,
                                 0.51808440539911071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81436933890766172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16267861963610958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50592989708010672,
                                 -0.14026281311369254,
                                 0,
                                 0.80536099502443559,
                                 0,
                                 0,
                                 -0.44741981389858332,
                                 -0.0046024767649501773,
                                 -0.43562586730250996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27715486520992516,
                                 0,
                                 0,
                                 0.31213794204431705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0014315515074150853,
                                 0,
                                 0,
                                 0.23657204759036432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016986840917379627,
                                 0,
                                 0,
                                 0,
                                 -0.094423939309258964,
                                 0.56654699800512465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6221274777232042,
                                 0,
                                 0.037681220837043734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36194736334769906,
                                 0,
                                 0,
                                 0,
                                 0.60355578058428849,
                                 0,
                                 0,
                                 0,
                                 0.23670581440486196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4155518497515166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26505194721933073,
                                 0,
                                 0.00027286488350112756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43156232578265591,
                                 0,
                                 0.052519422951958557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47734849334157581,
                                 -0.12291099221784646,
                                 -0.44305957359444059,
                                 0,
                                 -0.31837757810924666,
                                 0,
                                 0,
                                 0,
                                 0.16560481897005325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74284068945173132,
                                 0.027586981432594346,
                                 0,
                                 0.22691751212158007,
                                 0,
                                 0,
                                 -0.0086994642659035393,
                                 -0.453067478922622,
                                 -0.29132986396867055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12227327467946081,
                                 0,
                                 0,
                                 0.39350206628584805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1445564183925061,
                                 0,
                                 0,
                                 -0.68127250399810113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10023965608245958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13130626995284941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64361122864186338,
                                 0.49229826201424132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48184762830990735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28972494800331772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48985988762010541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37389568611592977,
                                 0.42663786958733485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53730980999052569,
                                 0.14653339016205794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35310752706047394,
                                 -0.011964202592431639,
                                 0.056723015468327184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31136022872942959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18270545583155318,
                                 -0.46412173833815745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24262505013778063,
                                 0.1562888150453296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05280091529613104,
                                 0.72257345527702965,
                                 -0.21464177782337662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42588832145710143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23414465255587069,
                                 -0.55713188470592434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090642562744782718,
                                 0.019236400545549641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4141163131561359,
                                 -0.48950502801776774,
                                 0.18359160058775306,
                                 -0.45461701426001866,
                                 0,
                                 0,
                                 0,
                                 0.040738098058206829,
                                 0,
                                 -0.44446421789695789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27696035902903948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29784239092198478,
                                 0,
                                 0,
                                 -0.2157444486751896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87527071420465186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32827121956535921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32999535354898601,
                                 0.28358696963610153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79817119393671254,
                                 0,
                                 0.25667290671299303,
                                 0,
                                 0,
                                 0,
                                 -0.73941210865788132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20610631915283403,
                                 0,
                                 0,
                                 -0.46494280263995319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30205893546690477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.6779983302933621e-05,
                                 0,
                                 0,
                                 0.8153807580844894,
                                 0,
                                 0,
                                 0.44493814316883706,
                                 0.82799126013204616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24719558784033838,
                                 0,
                                 0.44678071498071992,
                                 0,
                                 0,
                                 0,
                                 -0.39341106922116431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22813976067215805,
                                 0,
                                 0,
                                 0.32388335570519378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62644485501330238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29148713046986374,
                                 0,
                                 0,
                                 0.32130938909220319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17325276596613812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070644440947400342,
                                 0,
                                 0.41998513514329572,
                                 0,
                                 -0.16758415184802278,
                                 0,
                                 0,
                                 -0.095912689125862496,
                                 0,
                                 0,
                                 0.55433059460983025,
                                 0,
                                 0,
                                 -0.20224711091764577,
                                 0,
                                 0,
                                 -0.11860194547589316,
                                 0.4425865883590353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43952932184328564,
                                 0,
                                 0,
                                 0,
                                 0.32593601995595994,
                                 0,
                                 0,
                                 0,
                                 0.026162260062423073,
                                 0,
                                 -0.90013953845729078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6390113889962763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98867032211599837,
                                 0,
                                 0,
                                 0.46795635374119754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45708691199072643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19864501727525508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4317050347480425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19924109040721527,
                                 0,
                                 0,
                                 0,
                                 0.20368540517551517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18551808308212117,
                                 0,
                                 0,
                                 -0.18792986242441981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16009374508964733,
                                 0,
                                 -0.40247017673268265,
                                 0,
                                 0.68927437488102639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.001185562932136,
                                 0,
                                 0,
                                 0,
                                 -0.07095880403539899,
                                 0,
                                 -0.44769838059937733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48955142767572157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12066564004861347,
                                 0,
                                 0,
                                 -0.053673541935978328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13947185417940056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068628966371019423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12909128586247787,
                                 0,
                                 0,
                                 0.3272124228024621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50081225047704359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59657042746907907,
                                 0.091735992535883215,
                                 0,
                                 0,
                                 0.51102132322736749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44440637814806461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98322491184181027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0970839915153419,
                                 0,
                                 0,
                                 -0.42173924637449112,
                                 0,
                                 0,
                                 -0.14403120184251098,
                                 0,
                                 -0.74299209451006076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090591119401682907,
                                 0.44839232303293991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057808334951729975,
                                 0,
                                 0.055063390180255009,
                                 0,
                                 0,
                                 0,
                                 -0.48809942419448848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15050340361463138,
                                 0,
                                 0,
                                 0.35218646132819653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0058995086858695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05531095122218864,
                                 0,
                                 0,
                                 -0.63750705746207359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6301225237079473,
                                 0,
                                 0,
                                 -0.30558477555538927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01510830150729997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57541079686842944,
                                 0.24246661005875952,
                                 0,
                                 0,
                                 -0.34561198929450698,
                                 0,
                                 0,
                                 0,
                                 -0.6918291561454325,
                                 0.24468119171778574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052556867588376813,
                                 0,
                                 -0.25942982020856209,
                                 0,
                                 0,
                                 0,
                                 0.78377395357411594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30253449297748369,
                                 0,
                                 0,
                                 0.23909231407976583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4320299265266469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86278249242007354,
                                 0,
                                 0,
                                 0.70437155433602383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40109388482714792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22576171328232869,
                                 0,
                                 0.0079463230856951922,
                                 0,
                                 -0.040209475486810968,
                                 0,
                                 0,
                                 -0.19712204393514549,
                                 0,
                                 0,
                                 0.057142261121521855,
                                 0,
                                 0,
                                 0.31905879022943195,
                                 0,
                                 0,
                                 0.592563869864976,
                                 0.36733996023185284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39558053834102425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099516197347907481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22256353288847314,
                                 0,
                                 0,
                                 0,
                                 0.13772846542069453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063204201256492148,
                                 0,
                                 0,
                                 -0.72002603732010162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56420176343118877,
                                 0,
                                 0.27943737428171123,
                                 0,
                                 -0.052456921629033905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10094045727086842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1692973028855988,
                                 0,
                                 0.59816085047235368,
                                 0,
                                 -0.12708327826091226,
                                 0,
                                 0,
                                 0.4790918222868521,
                                 0,
                                 0,
                                 -0.34464455782141673,
                                 0,
                                 0,
                                 0.085190355480330396,
                                 0,
                                 0,
                                 0.32210822208657491,
                                 -0.26260348746904716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2427392514997494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34988908403563901,
                                 0.82896013854600759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18179567512380923,
                                 0,
                                 -1.0350037482897254,
                                 0,
                                 0,
                                 0,
                                 0.48379617781661455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076518564325637306,
                                 0,
                                 0,
                                 0.21219267793146673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032848427769436972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16631896971966256,
                                 0,
                                 0,
                                 -0.062688912915409484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34370116412304108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17019326384409358,
                                 0,
                                 0.11595089938299455,
                                 0,
                                 0.013579971871620286,
                                 0,
                                 0,
                                 -0.21543215113359351,
                                 0,
                                 0,
                                 0.52854382698981217,
                                 0,
                                 0,
                                 -0.05788718917740026,
                                 0,
                                 0,
                                 0.49857063361141962,
                                 -0.51027408986782752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034668387137506196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22247081694937934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30751429206899389,
                                 0,
                                 0,
                                 0,
                                 0.44074374311194542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12887182426743152,
                                 0,
                                 0,
                                 0.63440264634101207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4069606488271878,
                                 0,
                                 0.26042794585896367,
                                 0,
                                 0.095772121382963565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33038215135948418,
                                 0,
                                 0,
                                 0,
                                 -0.040376029290654487,
                                 0,
                                 0.14642494217413635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049163557713076109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0084017372721639,
                                 0,
                                 0,
                                 0.4384445835209857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25041376116223657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71957415926606327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37347065730268336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075615606034833985,
                                 0,
                                 -0.33544912632266566,
                                 0,
                                 -0.43180153880475991,
                                 0,
                                 0,
                                 0.56889805412185857,
                                 0,
                                 0,
                                 0.38913604789520623,
                                 0,
                                 0,
                                 -0.045124821618324984,
                                 0,
                                 0,
                                 -0.069521200411343784,
                                 -0.20158555943464962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18233271410432705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75575208553704964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14398608054509995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79114219943988495,
                                 0,
                                 0,
                                 0.70809762717159086,
                                 0,
                                 0,
                                 -0.54077959873456372,
                                 0,
                                 -0.42091807360395367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65505330594465172,
                                 0.36376114245292562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031141089203584216,
                                 0,
                                 0.80115019505474205,
                                 0,
                                 0,
                                 0,
                                 0.43861049668547591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62705483651511484,
                                 0,
                                 0,
                                 -0.6456193769040236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12659764986633262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20943244381420384,
                                 0,
                                 0,
                                 -0.12294882109199985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28097312373287098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43996809949703636,
                                 0,
                                 0.37758991150285492,
                                 0,
                                 0.0058893987556805361,
                                 0,
                                 0,
                                 0.081599394445971168,
                                 0,
                                 0,
                                 0.23361593735583031,
                                 0,
                                 0,
                                 0.22909034707293002,
                                 0,
                                 0,
                                 -0.42056137781135494,
                                 -0.064311516506749655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53865411047699097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70749344346440257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17116353209598217,
                                 0,
                                 0,
                                 0,
                                 -0.14782415862652459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21500420347979204,
                                 0,
                                 0,
                                 0.051078294587487312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10894115674242905,
                                 0,
                                 0.25536537824746186,
                                 0,
                                 0.56779277833543818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85015722039491437,
                                 -0.073521769579562912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44833543710062229,
                                 0,
                                 -0.33961074859580487,
                                 0,
                                 0,
                                 0,
                                 -0.20903378824322061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21555055941064727,
                                 0,
                                 0,
                                 0.11581662940299413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32860610249320266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7610698490994956,
                                 0,
                                 0,
                                 0.53500378992926811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36572710871033209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12272762618877639,
                                 0,
                                 0.040111554255353531,
                                 0,
                                 -0.83692937629358144,
                                 0,
                                 0,
                                 -0.19724228431216448,
                                 0,
                                 0,
                                 -0.24517159038166803,
                                 0,
                                 0,
                                 -0.072068478764393956,
                                 0,
                                 0,
                                 0.050734930632429953,
                                 0.16914667552226487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11717410092517024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24446009134919597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37515267099099731,
                                 0,
                                 0,
                                 0,
                                 0.58939768900406286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37706480975672046,
                                 0,
                                 0,
                                 -0.12657657545296078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42285010204721357,
                                 0,
                                 0.047597943764737957,
                                 0,
                                 -0.33592086586023773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29359598787992308,
                                 0,
                                 0,
                                 0,
                                 0.79649290356864455,
                                 0,
                                 0.05869809738017398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2480757184982576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6744069164736044,
                                 0,
                                 0,
                                 -0.87008208486134031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32875284847597697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81105960852228709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082442997066622781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57076396821389586,
                                 0,
                                 -0.36091793778698666,
                                 0,
                                 -0.19431275200621731,
                                 0,
                                 0,
                                 -0.15492845543718414,
                                 0,
                                 0,
                                 0.0656357368055554,
                                 0,
                                 0,
                                 0.44280143054918708,
                                 0,
                                 0,
                                 -0.021457812125753012,
                                 -0.19292504881723146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48718368825919994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53778914777768239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14608786413770336,
                                 0,
                                 -0.15440052542749388,
                                 0,
                                 0.15568190876015089,
                                 0,
                                 0,
                                 0.51303145939480821,
                                 0,
                                 0,
                                 0.13800330744708952,
                                 0,
                                 0,
                                 0.29427973282203856,
                                 0,
                                 0,
                                 0.20721020695460737,
                                 0.46866860380679581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099657950568216525,
                                 0,
                                 0,
                                 0,
                                 0.039465056224180603,
                                 0,
                                 0,
                                 0,
                                 0.32353839067782852,
                                 0,
                                 0.31088260066380513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22075755035562877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60169085328378513,
                                 0,
                                 0,
                                 0.84980238553516185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1555219038703326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48667873127256522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34505592352879955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65962826322358836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64854697825314922,
                                 0,
                                 0,
                                 -0.5800085706074336,
                                 0,
                                 0,
                                 0.79872758226786755,
                                 0,
                                 -0.39961990797501795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021783882262489979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32272154883668641,
                                 0,
                                 0.54395476631737194,
                                 -0.00049904434112019863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1016427917352352,
                                 0,
                                 0.068997611955293803,
                                 0,
                                 0,
                                 0,
                                 0.82620935547735552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72113109958904031,
                                 0,
                                 0,
                                 0.51448483652363541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6483730683871356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13083022354169474,
                                 0,
                                 0,
                                 0.30790853755590641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71306510255193245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0873295651328689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24387922195571377,
                                 0,
                                 0,
                                 -0.13114005437599649,
                                 0,
                                 0,
                                 -0.19996230129021075,
                                 0,
                                 0.61405311975392096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31202352792429627,
                                 0,
                                 0,
                                 0,
                                 0.33564234340024729,
                                 0,
                                 -0.39385640310677389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0389391772509911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40259185480606091,
                                 0,
                                 0,
                                 0.074635400503311855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33753425756378547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27400445937173623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69985776858317461,
                                 0,
                                 0,
                                 -0.21321198709200584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031799803266498589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40910252931597579,
                                 -0.16035586020862386,
                                 0,
                                 0,
                                 -0.52023998638156832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19326061764173277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56914784432453236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27670040443665223,
                                 0,
                                 0,
                                 1.1138958259488176,
                                 0,
                                 0,
                                 0.92106805481882348,
                                 0,
                                 0.38313877658691198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29598551295433456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31397686722592216,
                                 0,
                                 0,
                                 0,
                                 0.2867723215612597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24276935016879658,
                                 0,
                                 0,
                                 0.056273438634672733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50790649853534475,
                                 0,
                                 -0.63203620209328903,
                                 0,
                                 -0.10968276649696448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.028821700620715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30131397085742084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27055997932168468,
                                 0,
                                 0,
                                 -0.63415830428126219,
                                 0,
                                 0,
                                 -0.13612333561207854,
                                 0,
                                 0.50448988876174983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30286152670907995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10496465285147652,
                                 0,
                                 0,
                                 0,
                                 -0.396209243107572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80253981959852783,
                                 0,
                                 0,
                                 0.13502881758289675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18666850347345065,
                                 0,
                                 0.12528667852890102,
                                 0,
                                 -0.16562224289763913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28653630096115179,
                                 0,
                                 0,
                                 0,
                                 0.77769124209168772,
                                 0,
                                 0.2017094269084557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19011744554182636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59076758552855813,
                                 0,
                                 0,
                                 0.12599439202017565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76691841167944652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58117049345359784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12080475155187104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73250794475033765,
                                 0,
                                 0,
                                 0,
                                 -0.36990043528568511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23144875244766103,
                                 0,
                                 0,
                                 0.061221332889775548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083335870747792404,
                                 0,
                                 -0.4576748217671287,
                                 0,
                                 -0.1956637534454003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27988299103948511,
                                 0,
                                 0,
                                 -0.59222283977838874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24177898542656492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0072633973124656762,
                                 0.56858227695243846,
                                 0,
                                 0,
                                 0.43490456306271985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12014725879135733,
                                 0,
                                 0,
                                 -0.63107477623701869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55325730714440946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15388228142710839,
                                 -0.48211879067420144,
                                 0,
                                 0,
                                 0.1584213692507081,
                                 0,
                                 0,
                                 0,
                                 -0.3988997209267518,
                                 -0.022898567666777642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86934139403595312,
                                 0,
                                 0.25241412391168805,
                                 0,
                                 0,
                                 0,
                                 0.22219168013050256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27182183483445987,
                                 0,
                                 0,
                                 0.67486564600944321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54891496097610804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4185000497395735,
                                 0,
                                 0,
                                 -0.17878634177967448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18053018335188414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57004280349482794,
                                 0,
                                 -0.20371021974780493,
                                 0,
                                 0.070935447686047981,
                                 0,
                                 0,
                                 0.13996995900587683,
                                 0,
                                 0,
                                 -0.042994930953669734,
                                 0,
                                 0,
                                 -0.71014301435651628,
                                 0,
                                 0,
                                 0.23409323923944092,
                                 0.097900896710204799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076176631122162275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0609122016987904,
                                 0,
                                 0,
                                 0.071465787024290586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61919050041753276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34915433112899918,
                                 0.592752996442235,
                                 0,
                                 0,
                                 -0.36677051057098797,
                                 0,
                                 0,
                                 0,
                                 -0.056096628644579288,
                                 0.30470294518645624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054797383496730204,
                                 0,
                                 0.18807621273670214,
                                 0,
                                 0,
                                 0,
                                 0.35487949911538169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1016420301299021,
                                 0,
                                 0,
                                 -0.63516551814738464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.004219157971198248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81167266762534074,
                                 0,
                                 0,
                                 -0.01006191903838132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10471132377745762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36260053615984161,
                                 1.6645692764268509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45573934257931759,
                                 0.17115483701291134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15037098874258342,
                                 0,
                                 0.13073259178232197,
                                 0,
                                 0.43452240334304992,
                                 0,
                                 0,
                                 0,
                                 -0.035913537375321797,
                                 -0.26962113166529783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063019698325572929,
                                 -0.0092719074899188514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73637213867214035,
                                 0,
                                 0,
                                 0,
                                 0.31051357916014838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073441411198067574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26206524472363385,
                                 0,
                                 0.5349420105587277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033205459086366643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087013129477516785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31121522889631426,
                                 0,
                                 -0.43547378923592289,
                                 0,
                                 0,
                                 0.55410379191928183,
                                 0,
                                 0,
                                 -0.13653956077111007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090697472042409064,
                                 0,
                                 -0.12793564358153825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15542036581329802,
                                 0,
                                 0.21799297041048066,
                                 0,
                                 0,
                                 0,
                                 -0.53290930375039125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054937186094681678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4171789967789985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14182022762988794,
                                 0,
                                 0,
                                 0,
                                 0.54580320598854759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12598045891966086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4974873721133618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060503428315389934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48775408488121635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37029195629378953,
                                 0,
                                 -0.11168383310758252,
                                 0,
                                 0,
                                 0,
                                 -0.7599611185888635,
                                 0,
                                 0,
                                 0.82181759120460507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68445928906578768,
                                 0.10776501857859062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26277127478323281,
                                 0,
                                 0,
                                 -0.49901373402897037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09683141576739912,
                                 0,
                                 0,
                                 0,
                                 0.042682307358702376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31499746756078462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46301471580036868,
                                 0,
                                 -0.46998125754034847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67402780617895075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81190859304176111,
                                 0,
                                 -0.57625920173862832,
                                 0,
                                 0,
                                 0,
                                 0.21915735232156458,
                                 0,
                                 0,
                                 -0.1339949159317175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057352608139913552,
                                 0.34514017092503096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38881769165725205,
                                 0,
                                 0,
                                 -0.81181933047589316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41206134833252461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49412797390054902,
                                 0,
                                 -0.30030075017156038,
                                 0,
                                 0,
                                 0.032907567496909762,
                                 0,
                                 0,
                                 0.05635740436030956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18981430348261411,
                                 0,
                                 0.093989611590515651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43461887624560325,
                                 0,
                                 0.0090423970874330475,
                                 0,
                                 0,
                                 0,
                                 0.50770516602977722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2677431727280194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66515647428923819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087375604531161513,
                                 0,
                                 0,
                                 0,
                                 -0.18978452576915278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052653715687012215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48118772991837944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4081792122648622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20323257897104943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04088097497862539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15048325009650251,
                                 0,
                                 0.35822065336951059,
                                 0,
                                 0,
                                 0.033716813102174358,
                                 0,
                                 0,
                                 0.16295688574304268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75710092686563013,
                                 0,
                                 0.22894829883218515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36406746541374213,
                                 0,
                                 0.2405697682858495,
                                 0,
                                 0,
                                 0,
                                 0.060263263627467839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25435008603345144,
                                 0,
                                 -1.0781290495706095,
                                 0,
                                 0,
                                 0,
                                 -0.33221235578429775,
                                 0,
                                 0,
                                 0.73559840521810493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2072583994875192,
                                 -0.55847354666381199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20978296511406974,
                                 0,
                                 0,
                                 -0.074017134975112392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33316384552925793,
                                 0,
                                 0,
                                 0,
                                 0.075809928976821372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78371254203760854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25815882067149498,
                                 0,
                                 0.42418077041435498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14991349330137782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21562627409520596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036127691384211763,
                                 0,
                                 -0.20523565721884268,
                                 0,
                                 0,
                                 -0.13328688831496871,
                                 0,
                                 0,
                                 0.31923370556702779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15218010290544356,
                                 0,
                                 -0.81618409020395255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082683917723659961,
                                 0,
                                 0.21078543683268644,
                                 0,
                                 0,
                                 0,
                                 0.22320503583259266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14482459081398147,
                                 0,
                                 -0.3434692799685401,
                                 0,
                                 0,
                                 0,
                                 -0.58578740076306479,
                                 0,
                                 0,
                                 0.04696570121718923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31417213639466063,
                                 0.7950790222105304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052167064589766748,
                                 0,
                                 0,
                                 0.49059488050081962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5331751589640179,
                                 0,
                                 0,
                                 0,
                                 0.23179798355371392,
                                 0,
                                 0,
                                 0.14947945349975655,
                                 0.16397893923444473,
                                 -0.1546772539204673,
                                 -0.39730558565100688,
                                 0.40662216145015129,
                                 0.22850413991468008,
                                 0,
                                 0,
                                 0,
                                 0.91232951276028773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22197019360630543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15587393625905377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022720387650418956,
                                 0,
                                 -0.16448544770826504,
                                 0,
                                 0,
                                 -0.17260955749419718,
                                 0,
                                 0,
                                 0.7764513928644472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076858164723788619,
                                 0,
                                 0.13882140243308447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10604375899077181,
                                 0,
                                 -0.32541150570924882,
                                 0,
                                 0,
                                 0,
                                 -0.41610614814707692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9248832231566958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057913479924074918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031947678281059128,
                                 0,
                                 0,
                                 0,
                                 -0.10510832142319337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021440723540380888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076334134481268023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33941744608721891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087623236445046826,
                                 0,
                                 0,
                                 0,
                                 -0.087739404879895663,
                                 0,
                                 0,
                                 0,
                                 -0.44606389813084768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29629122517358952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65986682195622759,
                                 0,
                                 0.047881677909515918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51751659654809601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32905674261472373,
                                 0,
                                 0,
                                 0,
                                 0.54957752411556804,
                                 0,
                                 0,
                                 -0.28580486531255822,
                                 -0.28810522246103459,
                                 0.74802237427305751,
                                 0.0075493770623280554,
                                 -0.5544849976263182,
                                 0.14686169233539453,
                                 0,
                                 0,
                                 0,
                                 -0.18687951507951209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0032672260805426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55430430439378309,
                                 0,
                                 0,
                                 0,
                                 0.6014539529369709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2719918296754919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45213846085019388,
                                 0,
                                 0.22865861821330072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017503535459901069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17776549126341246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24052888991647975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51137396594873985,
                                 0,
                                 0,
                                 0,
                                 0.0083610457557843978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67233537186504533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016090853440422825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38357596160365348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22259325450163231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15119209744825798,
                                 0,
                                 0,
                                 0,
                                 0.075108859003908915,
                                 0,
                                 0,
                                 0.18505011001347788,
                                 0.051155153420150937,
                                 -0.96280304904891012,
                                 0.80423271795659412,
                                 -0.2129459796627492,
                                 0.36609419872364934,
                                 0,
                                 0,
                                 0,
                                 0.24157333984693569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027848851403490194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44891175480707257,
                                 0,
                                 0,
                                 0,
                                 0.073272486748954993,
                                 0,
                                 0,
                                 0.41368807754305731,
                                 -0.91032258924895626,
                                 0.52235906486357109,
                                 0.35705396717977306,
                                 0.49084323306966843,
                                 0.10536227379030359,
                                 0,
                                 0,
                                 0,
                                 0.24013896695143264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34882294879539455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042829267212065425,
                                 0,
                                 0,
                                 0,
                                 0.25417196185266117,
                                 0,
                                 0,
                                 -0.58376409082093916,
                                 -0.59271775205418908,
                                 -0.48915386114932374,
                                 -0.63933081853153173,
                                 -0.43357343426260686,
                                 0.29314876168898257,
                                 0,
                                 0,
                                 0,
                                 0.023476383948321383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47383230449512725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4000414356419823,
                                 0,
                                 0,
                                 0,
                                 0.99604223867057384,
                                 0,
                                 0,
                                 0.70146451978333846,
                                 0.014068683701708912,
                                 -0.4943324651637141,
                                 -0.55615479098205201,
                                 0.031494038890613897,
                                 -0.35713488507197561,
                                 0,
                                 0,
                                 0,
                                 -0.44827682404341673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11288100480815377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54225384181527325,
                                 0,
                                 0,
                                 0,
                                 -0.39571249056775382,
                                 0,
                                 0,
                                 -0.087990501324979431,
                                 -0.22921065401791538,
                                 -0.24221931340764982,
                                 -0.076001633834327953,
                                 0.015420813435912534,
                                 0.11315257787728132,
                                 0,
                                 0,
                                 0,
                                 -0.65913342483680237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77138195175003266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96607015650032391,
                                 0,
                                 0,
                                 0,
                                 -0.57328019523838569,
                                 0,
                                 0,
                                 0.60424410024396047,
                                 -0.50203702485288382,
                                 -0.42663597312135965,
                                 -0.13049363100642986,
                                 0.15914903088899282,
                                 -0.33100290841940916,
                                 0,
                                 0,
                                 0,
                                 0.65117726331337733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18040328871421313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14838158584864913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021018243098700803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01302007198252729,
                                 0,
                                 0,
                                 0,
                                 -0.49776158389570979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26613514756382267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68943475174005686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42730170034645487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02949720269155431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2742570493179089,
                                 0,
                                 -0.30829836427131629,
                                 0,
                                 0,
                                 0,
                                 -0.30271756062760868,
                                 0,
                                 0,
                                 0.37608178400929482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.028310220934914,
                                 -0.23687510358065159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80085828669608139,
                                 0,
                                 0,
                                 -0.25823083411784908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1633686202856794,
                                 0,
                                 -0.53485896360375396,
                                 0,
                                 0,
                                 0,
                                 0.35703408813831006,
                                 0,
                                 0,
                                 -0.24071671299959368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54866229654397636,
                                 0.12169952424217793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51228071281079313,
                                 0,
                                 0,
                                 -0.36523460995002832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13132762587827146,
                                 0,
                                 0,
                                 0,
                                 -0.1701911130392299,
                                 0,
                                 0,
                                 0.93601408227536065,
                                 0.090633112872099353,
                                 0.049978667469134611,
                                 -0.35694686387619912,
                                 -0.47008525523423139,
                                 0.63650951127326516,
                                 0,
                                 0,
                                 0,
                                 -0.075799316144045822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041584498161176819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32103064447092028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30473041465984912,
                                 0,
                                 -0.03673195339559842,
                                 0,
                                 0,
                                 0.0033207399327349618,
                                 0,
                                 0,
                                 -0.091790740829712364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33164385031947641,
                                 0,
                                 0.07521687804093552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73258422494889108,
                                 0,
                                 0.30219942531581778,
                                 0,
                                 0,
                                 0,
                                 -0.22504118372792042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050793820091785249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2957285552443995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39609234391444847,
                                 0,
                                 0,
                                 0,
                                 0.13032638377303596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63305001304837805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15429562528568463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053813281688195547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55554943069869311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21677945498248155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22502803223917597,
                                 0,
                                 0.35478422579694685,
                                 0,
                                 0,
                                 0.35517427077646146,
                                 0,
                                 0,
                                 -0.093123031524363992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19517029694431121,
                                 0,
                                 -0.3067882560924407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21586649809281602,
                                 0,
                                 -0.67945495486601049,
                                 0,
                                 0,
                                 0,
                                 -0.034766140588848748,
                                 0,
                                 0,
                                 0,
                                 0.55889315967820064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92209175754640904,
                                 -0.25856536410328423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43401330423800311,
                                 0,
                                 -0.45457809596098026,
                                 0,
                                 0.39040466319067041,
                                 0,
                                 0,
                                 0.065478457461062387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33838928409629015,
                                 -0.55574596646534524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1556658915367502,
                                 0,
                                 0.77064551291714167,
                                 0,
                                 0.32819505046123876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45366982244087556,
                                 0,
                                 0,
                                 0,
                                 0.64250287397256922,
                                 0,
                                 0,
                                 -0.26626642266597911,
                                 -0.10545980523917314,
                                 -0.050745607358909539,
                                 -0.34369838551012066,
                                 0.67401699101546864,
                                 0.59725938489716968,
                                 0,
                                 0,
                                 0,
                                 -0.42456865674804961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28431987716582813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082473462033316833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4750296391383288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74271237919192223,
                                 0,
                                 0,
                                 0,
                                 0.029627870380826399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12201075763606889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12416642724456912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23859160310382999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35751307862350307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02016727942991673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59227726448801132,
                                 0,
                                 -0.38123767611361653,
                                 0,
                                 0,
                                 0.46774228648200988,
                                 0,
                                 0,
                                 0.075893340577227714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18394883323366809,
                                 0,
                                 0.16720897668335766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1541378544325718,
                                 0,
                                 -0.24499962234929568,
                                 0,
                                 0,
                                 0,
                                 0.36515312289941437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17782095417600555,
                                 0,
                                 -0.30823321595625092,
                                 0,
                                 0,
                                 0,
                                 0.97974873670092633,
                                 0,
                                 0,
                                 0.71744700342110979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67512134351421782,
                                 0.33078926283230964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29289803921975238,
                                 0,
                                 0,
                                 0.22611355465167515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53927971521001583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27086127642492447,
                                 0,
                                 0.10506505210534084,
                                 0,
                                 0,
                                 0.36852130432695651,
                                 0,
                                 0,
                                 0.41983410335464566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38261265062184369,
                                 0,
                                 0.25088298320347274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049912837131167356,
                                 0,
                                 0.23337304163003245,
                                 0,
                                 0,
                                 0,
                                 0.21544207317293024,
                                 0,
                                 0,
                                 0,
                                 0.42365311650097409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40905474003404296,
                                 -0.20288332956529195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21470089179345916,
                                 0,
                                 0.091234042279956518,
                                 0,
                                 -1.4356279946221016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34565490936781845,
                                 0,
                                 0.23236690504073507,
                                 0,
                                 0,
                                 0,
                                 0.37576618207781615,
                                 0,
                                 0,
                                 0.51311304877752451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38102744379273462,
                                 0.42679797166040029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56037506710190321,
                                 0,
                                 0,
                                 -0.34889225507232158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35756315634342589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58143833294828229,
                                 -0.8873207080501635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1477353252309208,
                                 0,
                                 0.17955990538056804,
                                 0,
                                 0.25243633422998601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55577710920846624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25857216022701973,
                                 0,
                                 -0.48895904756491004,
                                 0,
                                 0,
                                 -0.40303748475763534,
                                 0,
                                 0,
                                 -0.21845138559873833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15864432597717174,
                                 0,
                                 0.21511746474359555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16369530456086762,
                                 0,
                                 -0.27700003285303187,
                                 0,
                                 0,
                                 0,
                                 0.0065079883018671625,
                                 0,
                                 0,
                                 0,
                                 0.37837357568910501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29767470890161052,
                                 0.57847987433675674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0495705300538805,
                                 0,
                                 0.58636721926344082,
                                 0,
                                 -0.055217024005140836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14976694328823592,
                                 0,
                                 0,
                                 0,
                                 -0.57904450066037727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34555688457819778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10217530656256614,
                                 0,
                                 0.50837773175879419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50396434105431653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082987791647050266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.093648963296032534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032375827142023174,
                                 0,
                                 0,
                                 0,
                                 0.62396606989454395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20590068610765111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018279742023295839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57007524006196209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47565326311148759,
                                 0.078601886824519962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47237863762875582,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1079769620015692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27952452791354554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.675898405100203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21671504579683298,
                                 0,
                                 0.18675010761440922,
                                 0,
                                 0.033512336086439234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13085088863270877,
                                 0,
                                 -0.32759637270227304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10824911564107501,
                                 -0.52275901208378261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056266447246326672,
                                 0,
                                 -0.7308168705875101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37415521540992214,
                                 -0.5941075710890511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44085455457706102,
                                 0,
                                 0,
                                 -0.3335631059110461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28903465088367741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31366392232182888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6055137505023227,
                                 0,
                                 0,
                                 0,
                                 0.064372674828122214,
                                 -0.36945323106233419,
                                 -0.071905474419978035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61037944088703755,
                                 0,
                                 0.39520231685928647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52310204785460634,
                                 0,
                                 0.18102100132161272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50414910212311592,
                                 0.46476906358278219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41746712407870601,
                                 0,
                                 -0.60368798079102826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19005971926959042,
                                 -0.49942411540468834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39758878159973166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25541211695457866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20683136176261446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26249155780926747,
                                 0,
                                 -0.051089355648997178,
                                 -0.072648127031001167,
                                 0,
                                 0,
                                 0,
                                 0.65163048212252939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45767768766505273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14991682799572065,
                                 -0.023509618742090156,
                                 0,
                                 0,
                                 0,
                                 -0.39351344625433121,
                                 0,
                                 0,
                                 0.061395761884536035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73096674460787592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19107247829765095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30888114911800513,
                                 0,
                                 0,
                                 0,
                                 -0.1873589411217057,
                                 0.3219999253730419,
                                 -0.19068761185578642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23302774356154887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40484199013865557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30601643863252936,
                                 0,
                                 0,
                                 -0.25815624888050098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71263078877426356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33714638229227156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25215447634530064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79160444071393476,
                                 0.61421380056611719,
                                 0,
                                 0,
                                 -0.41940715394145411,
                                 0,
                                 0,
                                 0,
                                 0.094974436560774783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016026086432057513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79909983660490846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20611612974182941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057521505499555398,
                                 0,
                                 -0.70208548333554255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65813684819512031,
                                 0,
                                 -0.53488149516489192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16574596814127177,
                                 0.62012950603444772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65028260421003969,
                                 0,
                                 -0.27783439220914952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088694958377850727,
                                 0.19058890786073904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056144354222227549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11950703975036854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017318647354128705,
                                 0,
                                 -0.62681725986469705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47384903848008003,
                                 0,
                                 -0.2113298584205178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60431649419779532,
                                 0.54024484713194032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48291872753574827,
                                 0,
                                 -0.2106980834037529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0048472251092701313,
                                 0.34477074744367692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10635074939521544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.350064499308824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18092997717363749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32033026043765639,
                                 0,
                                 -0.37092863821251831,
                                 -0.074788564527066753,
                                 0,
                                 0,
                                 0,
                                 0.47211639140804795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.452398649515238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36365498424896769,
                                 -0.16677072679559962,
                                 0,
                                 -0.98117288489179177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98010124861426351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51513726724705089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53296673194895838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017067483656303367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71227184191594739,
                                 0,
                                 0,
                                 -0.33792963633448936,
                                 0,
                                 0,
                                 -0.15901838201790464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42417796739346519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39346210992003366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055822590063040495,
                                 0,
                                 0,
                                 0,
                                 0.10891605276343913,
                                 0.56234544813997878,
                                 -0.44109643384163111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32512829357407846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075997755128964645,
                                 0.20239102024268918,
                                 0,
                                 0,
                                 -0.56651603745704149,
                                 0,
                                 0,
                                 0,
                                 1.255143622122151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16123343773328577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062746774224831256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16145400029750095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27162000185255109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10524530353758212,
                                 0.10705421575528498,
                                 0,
                                 0,
                                 -0.34843650709312662,
                                 0,
                                 0,
                                 0,
                                 -0.095260999240063052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037492847345065951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59462911420048803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0050946394499456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19470269072178237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12845495269585488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70077111217324828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40950002612887915,
                                 0,
                                 -0.15455423542522304,
                                 -0.04594535249495315,
                                 0,
                                 0,
                                 0,
                                 -0.12310176912551321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41657641585539218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16963762989100295,
                                 0.20821838513916974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46865895378845951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48727351260201973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20408813193501707,
                                 0,
                                 0,
                                 -0.061080996532492229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5645918769267404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42281966336088117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1657234237955903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40631311976305406,
                                 1.1302530486137004,
                                 0,
                                 0,
                                 0.57957172950356262,
                                 0,
                                 0,
                                 0,
                                 0.14448575325385329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034299969271497227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23531532628446203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17078686720539926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24148839904834377,
                                 0,
                                 -0.6878827647639888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90585162332925284,
                                 0,
                                 -0.59155961555292114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55498211181833979,
                                 0.077495925381703523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83794524549729732,
                                 0,
                                 -0.13419507091148303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1315417556455552,
                                 -0.14155559639704279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42250244797102621,
                                 0,
                                 -0.36020290241788533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084578892604900757,
                                 0,
                                 0.63363617280411466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49565741228468774,
                                 -0.13514471911992554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26796859919593607,
                                 0,
                                 -0.08312228754093838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65278746809413046,
                                 -0.080417595700948127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7029416817863241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1605417726485612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2878807788194151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62905644449164855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47976640899048262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23849759894951456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17559644316115347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022548630731007976,
                                 0.21778204884532271,
                                 0,
                                 0,
                                 0.1644755243530473,
                                 0,
                                 0,
                                 0,
                                 -0.44496813082109149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.005392903554873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84766573509574916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62083967766744652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29065117255068207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6249330872102381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072860567278170002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.067425475494374845,
                                 0,
                                 0.0578008406284308,
                                 -0.15653288515639618,
                                 0,
                                 0,
                                 0,
                                 0.13785687571571867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17124191468278419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66214842251499961,
                                 0.022657208938677051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34557853903897917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4942660837371412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096465679036818311,
                                 0,
                                 0,
                                 0.78856837981733463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05441821853161162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046577381151258188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082012841068211328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24947685725852292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22523914179911272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51548481595303142,
                                 0,
                                 -0.067680488001640005,
                                 0.55935136490166548,
                                 0,
                                 0,
                                 0,
                                 0.084367855787130727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13371668025869393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19663492405813315,
                                 -0.48317693261726918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60504114149895716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19420233180382845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16527751153381054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11364300176182672,
                                 0,
                                 -0.0071906291861732058,
                                 -0.25647133182997728,
                                 0,
                                 0,
                                 0,
                                 -0.09449218084194233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57702702286368335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27514493041545712,
                                 -0.26936284907181829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090891391656185622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15161321203097669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84130207311188565,
                                 0,
                                 0,
                                 0.11301400579207588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3506281233555788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35390784710863643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15202387368028214,
                                 0,
                                 0,
                                 -0.039678535502862669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12367583772944962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45562556788134917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55102114281436176,
                                 0,
                                 0,
                                 0,
                                 -0.55300641452786092,
                                 0.23520437553849688,
                                 -0.29607852353125014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71333819250131625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2231723042671954,
                                 0.20381450074588769,
                                 0,
                                 0,
                                 -0.026807483066659171,
                                 0,
                                 0,
                                 0,
                                 -0.15176991020540648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39177103074734537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037740434752666835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39609140700835122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14327488912671268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32093446431567174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22003785724727493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42352591451521465,
                                 0,
                                 0.06428533931049138,
                                 -0.59203601837287267,
                                 0,
                                 0,
                                 0,
                                 0.24378003011559507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11844749354978701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43099783649163592,
                                 0.18661623214311066,
                                 0,
                                 0.91332857726960648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78197265806039495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43498723264713068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4462043821413566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22986465796473432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.99278473689808511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41610636647346771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56564958012135336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3101589050046667,
                                 0,
                                 0,
                                 0.47211843989345059,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018277229477686854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43297531053200372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16655642926103165,
                                 0,
                                 0.0074766586090267637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057785545322393661,
                                 0,
                                 0.55635245689001722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1941569674934138,
                                 -0.24832113454675953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39554969808359214,
                                 0,
                                 -0.91764354762968126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52936312397271168,
                                 0.84004078424542028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2546576949109966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39780589105885034,
                                 0.56420161712590966,
                                 0,
                                 0,
                                 -0.79983558308752178,
                                 0,
                                 0,
                                 0,
                                 -0.24167769889161339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43527207062811563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20850042463392759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49594009771415709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17735436240493047,
                                 0,
                                 -0.47138910223704605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028081387502296815,
                                 0,
                                 0.34066303224923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58423258740398898,
                                 0.014307348314982024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26576049959488857,
                                 0,
                                 0.079617383019168431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68117273250025878,
                                 -0.79346760130184069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38106903551912458,
                                 0,
                                 0,
                                 0.54484278061628855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13540744629763948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43245648560865702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26123931723046084,
                                 0,
                                 0,
                                 0,
                                 0.53150619170129154,
                                 0.018039031912814085,
                                 -0.038842332123544709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48760762811439806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40433080496642831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19387296670401855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30378792060114462,
                                 0,
                                 0.45438214824724182,
                                 -0.28650272515429087,
                                 0,
                                 0,
                                 0,
                                 -0.30006616206341558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094907652302905765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14597198632423714,
                                 -0.24490741148216111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23865008133510163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52430854470669708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90955363123224009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53018290731381801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19104596711485367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22920269924853426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27603051353982549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83528851271339377,
                                 0,
                                 0,
                                 0.42779492487683024,
                                 0,
                                 0,
                                 0.49992432438445766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34066191428603038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48475034634131597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34048675995733191,
                                 0,
                                 0,
                                 0,
                                 0.094898896538886557,
                                 0.29892446740152306,
                                 -0.041723644777270308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41483122639606468,
                                 0,
                                 0,
                                 -0.29527282187556353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18860884568572409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20241725187184206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06529603062558427,
                                 0,
                                 0,
                                 0,
                                 0.47379018861133287,
                                 -0.15220757193160861,
                                 -0.6420865318233927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11480277901109441,
                                 0,
                                 0,
                                 0.47343527304062233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13024943369170516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19931108283933746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2067952758010283,
                                 0,
                                 0,
                                 0,
                                 -0.35649994341264912,
                                 -0.52480326596182458,
                                 -0.51060217169694588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1869824427493871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0080955376732718687,
                                 -0.60182132903655972,
                                 0,
                                 0,
                                 -0.083214733774396046,
                                 0,
                                 0,
                                 0,
                                 -0.2665770034667263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69060578120840699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57245263743149777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035248236738464223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67566290874499302,
                                 0,
                                 -0.15309129738792107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40557505277103834,
                                 0,
                                 0.23428198231736136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91634245867725339,
                                 -0.10315440930265955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20809432794154628,
                                 0,
                                 0.48580804296151298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38970805150555821,
                                 0.45558710490749066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55356887226013507,
                                 0,
                                 0.2854115612529623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021101218548873646,
                                 0,
                                 0.51657952864813972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28677339973499089,
                                 0.9289789871056926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018817946907222778,
                                 0,
                                 -0.86054579922224916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13420571438710388,
                                 -0.2144247943682758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65209399308938176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10687615192547487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22673469492306103,
                                 0,
                                 0,
                                 0.26854494332646495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21715867674564948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62663227891033535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095554721715638863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16367870653492356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50367745667175479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26947071618333585,
                                 0,
                                 -0.34687633907777349,
                                 0.18810881886225489,
                                 0,
                                 0,
                                 0,
                                 -0.17659481125035931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09503530313047534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20582927511270541,
                                 0.63204578940484324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26077758774770748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10932136701149367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10174784623576227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18257914723365318,
                                 0,
                                 -0.70499828688846766,
                                 -0.34042403107037994,
                                 0,
                                 0,
                                 0,
                                 -0.3487469348956494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0098780974835690483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11941467984480574,
                                 -0.35701981262630034,
                                 0,
                                 -0.53148545684068749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47939472840401037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3034448915538478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94396464252414192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14982428547324972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22886469571856985,
                                 0.38697471955453377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30674949349964076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19512905914159062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10040122421217232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33592950389817844,
                                 0,
                                 0,
                                 0.3866822733766998,
                                 0,
                                 0,
                                 -0.16877506641083967,
                                 -0.14125585893750101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60573329398995912,
                                 0,
                                 0.17400196209091578,
                                 0,
                                 -0.11529127573256649,
                                 -0.034772412242070519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14953855545766057,
                                 0.2463494052373176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36096517360768121,
                                 0,
                                 0,
                                 0.88671778803858392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35741706412095231,
                                 0.23249128637307767,
                                 0,
                                 0,
                                 0.61923170626754431,
                                 0,
                                 -0.52789148710761102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54430471254580481,
                                 0.49076822632710598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51512605718770166,
                                 0.33431978436885224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4885805152496126,
                                 0,
                                 0,
                                 -0.52563540230566197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30361028636969117,
                                 0.56869313664333854,
                                 0,
                                 0,
                                 0.70616661608647002,
                                 0,
                                 -0.0094190800337425745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51284578971512707,
                                 -0.12351666856954426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23574896685340824,
                                 0.54989527903288293,
                                 0.42517811196801747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42777798959877233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11626697313041812,
                                 -0.81352711254019638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36470567701864759,
                                 0.29708018223363891,
                                 0.04256271813139656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31871174691365955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.348906408305437,
                                 -0.34311578082077437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13181707191324751,
                                 0,
                                 0.35137994484253177,
                                 -0.29334391241264873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36194171132500802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36128759472611532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31202696153111931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022972025102597958,
                                 -0.60145605365050647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67680606381007824,
                                 0,
                                 -0.99329232030520254,
                                 0.50664531082113229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046966415583986926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57350335737935931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48964998272275906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.130213398302573,
                                 1.0723705804649037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2701818594790264,
                                 -0.53452670137669711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28354843808274549,
                                 0,
                                 0,
                                 0.44129948319867768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23432386485388984,
                                 0.18613627238000807,
                                 0,
                                 0,
                                 0.030810069489081798,
                                 0,
                                 -0.16748516203633862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35413474451585336,
                                 -0.52041268128360962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0858852216364094,
                                 -0.075740258035019048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037360501330839638,
                                 0,
                                 0,
                                 0.37776519840198308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26838757796110513,
                                 -0.5739259488265247,
                                 0,
                                 0,
                                 -0.46080990672936439,
                                 0,
                                 0.30315970456161423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67706466638585128,
                                 -0.3100433072789695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32511221189852463,
                                 -0.35895902725221129,
                                 -0.40510781590707851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21632084749956004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29843684590974084,
                                 0.14062084883697293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27107732348787711,
                                 -0.36974673073424391,
                                 0.71822348020572335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40635046223547233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24298774618031752,
                                 -0.070074909396645652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69072902637437483,
                                 -0.28515721121106841,
                                 -0.158898231920929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59361316628751981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30341916268596641,
                                 0.75796260945010352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18293540058387983,
                                 0,
                                 -0.47951035005634046,
                                 -0.41115320896002605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30606939457244231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011031445794250132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82704532786211382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14101731257982694,
                                 -0.4214008663758857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29411846244303685,
                                 -0.1800266099049897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43618049051169216,
                                 0,
                                 0,
                                 -0.039166484564989119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66017415542629976,
                                 0.36938251704740993,
                                 0,
                                 0,
                                 -0.87408272374187101,
                                 0,
                                 -0.44004749969730328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10745140305773254,
                                 0.47143257984414672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1454330349443873,
                                 0,
                                 -0.71680341826278782,
                                 0.12244482847205093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15616836644113585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24666239510743676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19339492889875032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40261158610277387,
                                 -0.63727057560891009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094963695274902019,
                                 0,
                                 -0.35557468676176479,
                                 -1.4509531699658662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21122995273707246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070549756743942107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34582556927312585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64521993700599778,
                                 -0.094629991575557251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28858420599655166,
                                 0.76522747027805993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09125582538958113,
                                 0,
                                 0,
                                 0.14442792372873764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55049850303861592,
                                 -0.26421057026081546,
                                 0,
                                 0,
                                 -0.34113264717862385,
                                 0,
                                 -0.85898638783644332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33870185311267625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36491072958289883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26244491152549793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36116183065856272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2655948974020983,
                                 0,
                                 0,
                                 -0.05711837990824617,
                                 0,
                                 0,
                                 -0.34603602646276532,
                                 -0.31367990066151763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49200147950589657,
                                 0,
                                 -0.13711815433603194,
                                 0,
                                 0,
                                 0,
                                 0.34197518721689363,
                                 0.44956167686362175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39385878213761705,
                                 0.51232771170529767,
                                 -0.33497168536035621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38876318702041707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35667896062755716,
                                 0,
                                 0,
                                 0,
                                 -0.23054414002921711,
                                 0.42691566515206714,
                                 0.44028288706582774,
                                 0,
                                 0,
                                 0.37257988499065348,
                                 0,
                                 0,
                                 0,
                                 -0.39431181573719942,
                                 0,
                                 0,
                                 0,
                                 -0.03001387305088098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38512997993333792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41188583694608688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14246711872074336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18498796644518656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49501881663735259,
                                 -1.1628288360022163,
                                 0,
                                 0,
                                 0.20711581192643946,
                                 0,
                                 -0.69457758137163694,
                                 0,
                                 0,
                                 0,
                                 0.18857521835170366,
                                 0,
                                 -0.05982721894508921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088255732149981336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 5.719009686651344e-05,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48433781443893592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47331261298103694,
                                 0,
                                 0,
                                 -0.016427004770335468,
                                 0,
                                 0,
                                 -0.43317717329543098,
                                 -0.23661587875432805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11461587288983317,
                                 0,
                                 -0.52248205318069252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082125041679008387,
                                 0,
                                 0,
                                 0,
                                 0.011658098259721639,
                                 -0.29467436383017592,
                                 0.51529014946555995,
                                 0,
                                 0,
                                 0.34738775914855113,
                                 0,
                                 0,
                                 0,
                                 -0.051485334003859323,
                                 0,
                                 0,
                                 0,
                                 0.097361691499683892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71270916483781055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40266665258786949,
                                 0,
                                 0,
                                 0,
                                 -0.045322398128008007,
                                 -0.050760533709908476,
                                 0.046547806133211828,
                                 0,
                                 0,
                                 -0.68503529324750312,
                                 0,
                                 0,
                                 0,
                                 -0.47096064873765986,
                                 0,
                                 0,
                                 0,
                                 -0.28793365284240224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23891220770403507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20293102390387785,
                                 0,
                                 0,
                                 0,
                                 -0.27004190469658679,
                                 0.0851662719186915,
                                 0.55124977825071797,
                                 0,
                                 0,
                                 -0.28809996893220235,
                                 0,
                                 0,
                                 0,
                                 0.5372586449718838,
                                 0,
                                 0,
                                 0,
                                 -0.44030952360169395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09615527588778422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29202950490202628,
                                 0.26183869413006283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11535391883636732,
                                 0,
                                 -0.16727984967442205,
                                 -0.25842173301291793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0874635416877276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28946373930485075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82026690594942397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09568875681994915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71622353735874489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032816801554420023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45167643745595631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16121258775752584,
                                 0,
                                 0,
                                 0.047830376945693587,
                                 0,
                                 0,
                                 -0.32681993493314088,
                                 -0.27098997450699808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0085730441656338696,
                                 0,
                                 0.25334044897113406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56624304139675641,
                                 0,
                                 0,
                                 0,
                                 -0.13754175551834974,
                                 -0.13070261026393595,
                                 0.10102811493411966,
                                 0,
                                 0,
                                 -0.23599932058224565,
                                 0,
                                 0,
                                 0,
                                 0.42010874267332132,
                                 0,
                                 0,
                                 0,
                                 0.61986663857302238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12938139982268609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67475933307220115,
                                 0.29835635815711681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15886759602472356,
                                 0.33851484824495248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51040225974267706,
                                 0,
                                 0,
                                 0.24325767904559809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63346975665788485,
                                 0.46932804189611693,
                                 0,
                                 0,
                                 -0.86363497102974962,
                                 0,
                                 -0.068062666836495089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029963176022840016,
                                 0.58286088123529201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18804400394179463,
                                 0.95880990209206551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00505434155373332,
                                 0,
                                 0,
                                 0.74399032968197809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22299038020374673,
                                 -0.3797760142928025,
                                 0,
                                 0,
                                 -0.23008012800371758,
                                 0,
                                 0.33987407061504049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0167034972352369,
                                 0.74145849073823933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29644482409666817,
                                 0,
                                 0.0541094789343535,
                                 -0.061606849813936465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53926271027245609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12718387671125758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82678758763131821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56539173005547727,
                                 0,
                                 0,
                                 0,
                                 0.23186062018256365,
                                 -0.23364512223003051,
                                 -0.22223460357820668,
                                 0,
                                 0,
                                 0.3305794552713463,
                                 0,
                                 0,
                                 0,
                                 0.29589411608523347,
                                 0,
                                 0,
                                 0,
                                 -0.56678306834444769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.067196960352942953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54197698717346499,
                                 0.39380914729433308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54387782211254065,
                                 -0.24768799519107626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50329446121576016,
                                 0,
                                 0,
                                 -0.21115344156759963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6064521099340876,
                                 -1.0270269929684481,
                                 0,
                                 0,
                                 0.041473890929643265,
                                 0,
                                 -0.42189154453136063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46341823263127035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41566874239092216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38897168114447522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23019329143784495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23503521413525852,
                                 0,
                                 0,
                                 -0.24743909909600265,
                                 0,
                                 0,
                                 0.10021371696632818,
                                 -0.51112274839651717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073917135960265834,
                                 0,
                                 0.1222884396763613,
                                 0,
                                 -0.8405815001877488,
                                 -0.27461633407615094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095618887133905123,
                                 -0.015047650232010185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88242241804677646,
                                 0,
                                 0,
                                 0.41559773030238178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69282177893800168,
                                 -0.51813957805373811,
                                 0,
                                 0,
                                 0.10306061786289758,
                                 0,
                                 -0.46105938825088366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09940638287200812,
                                 0,
                                 0,
                                 0,
                                 -0.70472296949188462,
                                 0.34356845355711335,
                                 -0.41703502730098219,
                                 0,
                                 0,
                                 0.12512945141666423,
                                 0,
                                 0,
                                 0,
                                 0.1389848255833519,
                                 0,
                                 0,
                                 0,
                                 -0.069377304273365983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40216792430125126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26043962853357044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064627655580811003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14973339219194445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57577936216271874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1845171150464785,
                                 0,
                                 0,
                                 0.01769441215714232,
                                 0,
                                 0,
                                 0.04236855003315057,
                                 0.39785928249908215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15242738180131826,
                                 0,
                                 -0.59696870604877272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19647547923345443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031942791522958286,
                                 -0.43338142181940897,
                                 0,
                                 0,
                                 -0.90439415420227454,
                                 0,
                                 -0.1307750231757131,
                                 0,
                                 0,
                                 0,
                                 1.4038183512836908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26388775920604701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80805446061848041,
                                 0.62593962374358203,
                                 0,
                                 0,
                                 -0.11071098674741968,
                                 0,
                                 -0.59082287407975709,
                                 0,
                                 0,
                                 0,
                                 0.04314217517253828,
                                 0,
                                 0.59317302415654827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070159015595868471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52424552925977796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18497551185291364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42538390832385037,
                                 0,
                                 0,
                                 -0.13858051949940875,
                                 0,
                                 0,
                                 0.22495814346679613,
                                 0.14967119332848808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24395845405207711,
                                 0,
                                 -0.038662274066603913,
                                 0.23836190326887929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11566626441241215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28702077848918639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024734429615689418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038461103211846523,
                                 0,
                                 0,
                                 -0.82465996034915001,
                                 0,
                                 0,
                                 0.060264368031631835,
                                 -0.11000701182837143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37895740453801718,
                                 0,
                                 -0.076985980741819879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93477473122017352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53342050266740437,
                                 -0.40230295209306605,
                                 0,
                                 0,
                                 -0.73574840549643494,
                                 0,
                                 0.70836517685808087,
                                 0,
                                 0,
                                 0,
                                 -0.64924173860821743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11195331037892473,
                                 0,
                                 0,
                                 0,
                                 0.54993198920134501,
                                 0.72894966269467942,
                                 0.032724790493206868,
                                 0,
                                 0,
                                 -0.0871504092133491,
                                 0,
                                 0,
                                 0,
                                 0.21921496926365863,
                                 0,
                                 0,
                                 0,
                                 0.050504424690146529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30724851082492866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96329447859137707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93600783533040122,
                                 -0.034777545996178355,
                                 0,
                                 0,
                                 -0.53987424895212444,
                                 0,
                                 -0.6343657112763692,
                                 0,
                                 0,
                                 0,
                                 -0.37769947288966499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026380562232802475,
                                 0.037695489272584384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34986476775939324,
                                 0,
                                 -0.029963921868957424,
                                 0.38804512348346343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13461259257729841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.6111856551923902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015957767617027524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17797138841722562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28498089900678353,
                                 0,
                                 0,
                                 0,
                                 0.17758138352871528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21234108238455629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33139024063494821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032780636987935881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46086001795163156,
                                 0,
                                 0,
                                 0.23864518645852667,
                                 0,
                                 0,
                                 0.20547117037781723,
                                 -0.42652811790235973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29481411727414708,
                                 0,
                                 -0.48174534048422518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79528446675214026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8246740348123458,
                                 0.17826983354424966,
                                 0,
                                 0,
                                 -0.03013200344709209,
                                 0,
                                 0.72404820937008674,
                                 0,
                                 0,
                                 0,
                                 0.39783193284158808,
                                 0,
                                 0.0022242024466683739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10785514925823746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50121604290641342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021768696175276832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28720304860859563,
                                 0,
                                 0,
                                 -0.16400421670723073,
                                 0,
                                 0,
                                 -0.67009407301596569,
                                 0.34097117935482224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24305096193666989,
                                 0,
                                 0.05409959088676488};

const double rot_24_20[4000] = {-0.83386446191608909,
                                0,
                                0,
                                0,
                                0,
                                0.26209357764740226,
                                -0.25357431453130858,
                                -0.30655148713321312,
                                0,
                                0,
                                1.2825006114368929,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50726901146560333,
                                0,
                                0,
                                0,
                                -0.22004002609077561,
                                0.13130935525041071,
                                -0.17544357015041914,
                                0,
                                0,
                                0,
                                0,
                                0.021081384869062608,
                                -0.69882780982692805,
                                0,
                                0,
                                0,
                                -0.64401479894414537,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67552584982563268,
                                0.17586661436795101,
                                0.21678970258823554,
                                0,
                                0,
                                0,
                                0,
                                -0.23631635184537528,
                                0.5236514996481163,
                                0,
                                0,
                                0,
                                -0.36834993387618098,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54929971982624348,
                                0.75142411072060522,
                                0.070866105868757454,
                                0,
                                0,
                                0,
                                0,
                                -0.21254620420817083,
                                0.16348443803737892,
                                0,
                                0,
                                0,
                                -0.23813140964991841,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.85469101313046869,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.091993019888381586,
                                -0.0018458694470098874,
                                0,
                                0.13178131213470451,
                                -0.31559591728263109,
                                -0.16994282826799245,
                                0,
                                0.051856116954278691,
                                -0.33541083785874254,
                                -0.98417934015127895,
                                0,
                                0,
                                0,
                                0,
                                -0.16584890740972225,
                                -0.46998848454136416,
                                -0.53768650239086657,
                                0,
                                0,
                                -0.86693199138607091,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.074416109065931574,
                                0,
                                0,
                                -0.3043486809847652,
                                0,
                                0,
                                0,
                                0,
                                -0.99421425191128354,
                                1.1557185993204731,
                                -0.4930637634940922,
                                0,
                                0,
                                0.52578393489783315,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17248299793526756,
                                0,
                                0,
                                -0.95062820706127971,
                                0,
                                0,
                                0,
                                0,
                                -0.087872182528550058,
                                -0.16894145726510806,
                                1.4358410799720156,
                                0,
                                0,
                                -0.19025942314164646,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.099498800947607879,
                                0,
                                0,
                                0,
                                -0.39318590455192692,
                                0.5326341498203413,
                                -0.56189361140800431,
                                0,
                                0,
                                0,
                                0,
                                0.077528492356644441,
                                -0.078345267231489976,
                                0,
                                0,
                                0,
                                0.4835624347910501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18639300997770478,
                                -0.31716477685054539,
                                -0.75686937443962321,
                                0,
                                0,
                                0,
                                0,
                                -0.34649646893435515,
                                0.31232227854783357,
                                0,
                                0,
                                0,
                                -0.27241125441302949,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7321430407330739,
                                0,
                                0,
                                0,
                                0,
                                0.27318653280370803,
                                0.060333892048050675,
                                0.13074721565427538,
                                0,
                                0,
                                -0.36571114310443215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2548637891471546,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10837611300619014,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.033213861856769639,
                                0.23854427551383656,
                                0,
                                0.14467739671905841,
                                -0.50160949869125671,
                                -0.047107752367156863,
                                0,
                                -0.087979044698895725,
                                0.80482606517923694,
                                0,
                                0,
                                0,
                                0,
                                0.16521654096583013,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46722816205455953,
                                -0.11912879714768067,
                                0,
                                -0.40716949037007022,
                                0.049487549042937812,
                                0.31117597146119413,
                                0,
                                -0.68467756334573027,
                                0.079748394981884435,
                                0,
                                0.06464921675683151,
                                0.0538327017038044,
                                -0.16918656293518394,
                                0,
                                0,
                                0,
                                0,
                                0.87889919673880856,
                                0.32713674674896387,
                                0,
                                0,
                                0,
                                -0.29123216996162815,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16604864752963636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.074297571540414664,
                                -0.11196440424551468,
                                0,
                                0.69743659909264144,
                                0.012505653071570866,
                                -0.25390833155262804,
                                0,
                                -0.61771814063493014,
                                -0.1474867671513338,
                                0,
                                0,
                                0,
                                0,
                                -0.21787800720007655,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.82234623324393141,
                                0.19319836306502086,
                                0,
                                0.10035641217493128,
                                -0.018757134400624403,
                                -0.42470134954479716,
                                0,
                                0.21804512860105854,
                                -0.024740355487855442,
                                0,
                                0,
                                0,
                                0,
                                0.13090481485346059,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28663035547159232,
                                -0.49051734927015095,
                                0,
                                0.47816194239784349,
                                0.17530612332751966,
                                0.51035693842574326,
                                0,
                                0.2990562830794023,
                                0.22545454919567998,
                                -0.69472784284426681,
                                0,
                                0,
                                0,
                                0,
                                0.88863086471978692,
                                0.3596931794842686,
                                -0.186633167844864,
                                0,
                                0,
                                -0.22421399964973129,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14974571778195628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24743972301407952,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.090544305294530378,
                                0.42390593734432547,
                                0,
                                0.17147632736576099,
                                -0.48066469476351359,
                                0.58599618673996312,
                                0,
                                0.013295486814959609,
                                -0.38323372510166687,
                                0,
                                0,
                                0,
                                0,
                                0.27758947809664419,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0018110464288814444,
                                0.67730082099157907,
                                0,
                                0.20342799595769931,
                                0.61972502223895176,
                                0.15288360593041245,
                                0,
                                -0.045348156348470871,
                                0.11546642226236975,
                                0.0018909298502309962,
                                0,
                                0.28012966856242133,
                                0,
                                0,
                                0,
                                0,
                                0.032899456445555725,
                                0,
                                0.15420820229127827,
                                0,
                                -0.36092085068000995,
                                0,
                                0,
                                0,
                                -0.47795412519748953,
                                0.70750578836994782,
                                0.19337218636925932,
                                0,
                                0,
                                0,
                                0.32854527439204911,
                                0,
                                -0.44871486099141494,
                                -0.39176192697218365,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.063161248942198933,
                                0,
                                0.48861102407651441,
                                0,
                                0,
                                0,
                                0,
                                0.54268360262506443,
                                -0.81833228554118609,
                                0,
                                -0.12969496586148133,
                                0,
                                0,
                                0,
                                0,
                                -0.11591868238820441,
                                0,
                                -0.018781272941529446,
                                0,
                                0.47927592987348966,
                                0,
                                0,
                                0,
                                -0.20084635706736662,
                                0.1475184834620521,
                                0.088967578729173685,
                                0,
                                0,
                                0,
                                0.20215054253933856,
                                0,
                                -0.28436906049996485,
                                0.32410966731383534,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.86300099780432438,
                                0,
                                -0.091094872191343199,
                                0,
                                0,
                                0,
                                0,
                                -0.14196239355658219,
                                0,
                                -0.40868823930472886,
                                0,
                                -0.037833374612173398,
                                0.29800590105961994,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.057500275494188492,
                                0,
                                -0.38334282475282055,
                                0,
                                0,
                                0,
                                0,
                                0.76972530085850943,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.94847463581176239,
                                0.35575703544599047,
                                0,
                                -0.78821084391090968,
                                0,
                                -0.53932645578734606,
                                0,
                                0,
                                -0.75789862180052858,
                                0,
                                0,
                                0,
                                0,
                                -0.44790591754941012,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74152811917558525,
                                0.036522409857715044,
                                0,
                                -0.32469631344702743,
                                0,
                                -0.50172898878798999,
                                0,
                                0,
                                1.0074859320165539,
                                0,
                                0,
                                0,
                                0,
                                0.37512558418752906,
                                0,
                                -0.25876639101729537,
                                0,
                                0.16697816473306748,
                                0,
                                0,
                                0,
                                0,
                                0.036247701863977119,
                                0,
                                -0.54882271119111259,
                                0,
                                -0.24161897497876811,
                                0,
                                0,
                                0,
                                0.59712621783813669,
                                0.38626905708834064,
                                -0.19620078901292146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.026635389987702707,
                                0.59542725961814646,
                                0,
                                1.19924739639372,
                                0,
                                -0.74359059913828163,
                                0,
                                0,
                                -0.011034378994976057,
                                0,
                                0,
                                0,
                                0,
                                0.13709007999117084,
                                0,
                                0.29096387225356474,
                                0,
                                -0.78333154743116484,
                                0,
                                0,
                                0,
                                0,
                                -0.024559249873878239,
                                0,
                                -0.21022328640106586,
                                0,
                                0.13632726807416973,
                                0,
                                0,
                                0,
                                -0.13166774823526295,
                                0.40306785929515959,
                                -0.24197005145261594,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.88781308099315914,
                                -0.15226321310936752,
                                0,
                                -0.57964048169488369,
                                0,
                                -1.0608764689623607,
                                0,
                                0,
                                0.21100831588006888,
                                0,
                                0,
                                0,
                                0,
                                0.68664492064316685,
                                0,
                                -0.22834273038528163,
                                0,
                                -0.061484547211221124,
                                0,
                                0,
                                0,
                                0,
                                -0.55799959595762338,
                                0,
                                0.032072994739182764,
                                0,
                                -0.47624626384638064,
                                0,
                                0,
                                0,
                                -0.24848176881648501,
                                -0.21833345977661392,
                                -0.54356584599676971,
                                0,
                                0,
                                0,
                                -0.35155290819464241,
                                0,
                                -0.45478757010737503,
                                -0.63134145491374771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.086150651046530677,
                                0,
                                -0.47052658882169529,
                                0,
                                0,
                                0,
                                0,
                                -0.20535233297722488,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46800989794627912,
                                -0.95944572583602916,
                                0,
                                0.41449327699526167,
                                0,
                                -0.50236886793790592,
                                0,
                                0,
                                -0.30770376268273203,
                                0,
                                0,
                                0,
                                0,
                                -0.68590934461220487,
                                0,
                                0,
                                0.30845070464977131,
                                0,
                                0.66569358278464008,
                                -0.4774286136587767,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33457970388583957,
                                0,
                                -0.26905919267020378,
                                0,
                                0,
                                0,
                                0,
                                0.22234142233867904,
                                -0.20564269330834575,
                                0,
                                -0.23130131904176843,
                                0,
                                0,
                                0,
                                0,
                                0.25395651365797695,
                                0,
                                0.75565117822650874,
                                0,
                                -0.16284424572741468,
                                0,
                                0,
                                0,
                                0.40933062495210121,
                                0.16796163203800424,
                                -0.21546983498143027,
                                0,
                                0,
                                0.28770952153975049,
                                0,
                                0.31328410541478191,
                                0,
                                0,
                                0,
                                0,
                                -0.60076015125631577,
                                0,
                                0.23671382049606993,
                                0,
                                0.47750898350308896,
                                0,
                                0,
                                0,
                                0.23392886608890795,
                                0.30000761766517242,
                                -0.17142926817070264,
                                0,
                                0,
                                -0.038763205914722987,
                                0,
                                -0.32831232611798,
                                0,
                                0,
                                0,
                                0,
                                -0.49678286296780194,
                                0,
                                0.048949797832719313,
                                0,
                                -0.28587110378218095,
                                0,
                                0,
                                0,
                                0.27075268190169172,
                                -0.011008753214958103,
                                0.697401347401849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47662721801056407,
                                0.8361076421443957,
                                0,
                                -0.37902892771770036,
                                0,
                                -0.29311911932017432,
                                0,
                                0,
                                1.0792166203958211,
                                0,
                                0,
                                0,
                                0,
                                -1.0352489337710293,
                                0,
                                0,
                                0.68222855365387181,
                                0,
                                -0.2576396061098859,
                                0.16167215353811479,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35856399681342477,
                                0,
                                -0.55876752784440542,
                                0,
                                0,
                                0,
                                0,
                                0.035480399223635051,
                                -0.35674255355272549,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33665097898508367,
                                0,
                                0.060708061833046258,
                                0.32296569149048193,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79101316160901647,
                                0,
                                -0.16033321659258162,
                                0,
                                0,
                                0,
                                -0.40659228052784624,
                                -0.36296509455308207,
                                0,
                                0.37183130091176936,
                                0.11994585306278008,
                                0,
                                0,
                                0,
                                0,
                                -0.35461683907594826,
                                0,
                                0,
                                -0.068163391470057358,
                                0,
                                0,
                                -0.10569838911939101,
                                0,
                                0,
                                -0.63931372079065618,
                                0,
                                0.55273981256752691,
                                0.064663322162730907,
                                0,
                                -0.45137354037141852,
                                0.16465390053818563,
                                0,
                                0,
                                0,
                                0,
                                -0.17640239811997258,
                                0,
                                0,
                                0.11310006563114099,
                                0,
                                0,
                                -0.45229925123153042,
                                0,
                                0,
                                -0.45930853561303298,
                                0,
                                0,
                                0,
                                -1.1969028659241117,
                                0,
                                0,
                                0,
                                -0.13742281944115009,
                                0,
                                0,
                                0,
                                -0.13605638002170717,
                                0.34680040087460978,
                                0,
                                -0.43979887608522927,
                                0,
                                0,
                                0,
                                -0.63661861676547116,
                                0,
                                0,
                                -0.062182514434753824,
                                0.26672878214365553,
                                0,
                                -0.10686924432025059,
                                0.11436883810796589,
                                0,
                                0,
                                0,
                                0,
                                0.60351216353981041,
                                0,
                                0,
                                -0.51674149276123771,
                                0,
                                0,
                                0.22206561264766522,
                                0,
                                0,
                                -0.46896267118053303,
                                0,
                                -0.46323356358498263,
                                0.74072588785430082,
                                0,
                                -0.0056994279324591446,
                                0.11277494374130535,
                                0,
                                0,
                                0,
                                0,
                                -0.043027428184775895,
                                0,
                                0,
                                0.41863662213298825,
                                0,
                                0,
                                -0.19365755215522837,
                                0,
                                0,
                                -0.096839685781868814,
                                0.010586283040437572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.091250101788112964,
                                0,
                                0.34908802311550546,
                                -0.04513332893888574,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22560913624810006,
                                0,
                                -0.90374908127899978,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38937748585927556,
                                0,
                                0,
                                0,
                                0.50105884333370698,
                                0,
                                0,
                                0,
                                0.7053962842433783,
                                0.15461731543723267,
                                0,
                                0.80386921215436102,
                                0,
                                0,
                                0,
                                -0.27770665087067165,
                                0,
                                0.48527580492121081,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58380567355305746,
                                0,
                                0.18531712627276375,
                                0.58760590999337292,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20078840129955589,
                                0,
                                -0.061149029753259199,
                                0,
                                0,
                                -0.68765134367610292,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19874781582435461,
                                0,
                                0.38388896807792217,
                                0.398937369823121,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37842128713189382,
                                0,
                                0.19470618849337434,
                                0,
                                0,
                                0,
                                -0.10070190346572164,
                                -0.32367782195553818,
                                0,
                                -0.34522649410095285,
                                0.10458270242240152,
                                0,
                                0,
                                0,
                                0,
                                0.24185465629192471,
                                0,
                                0,
                                0.63337441218267587,
                                0,
                                0,
                                0.49805698590599456,
                                0,
                                0,
                                -0.2173829302168892,
                                0,
                                0,
                                0,
                                0.032978314233731945,
                                0,
                                0,
                                0,
                                -0.071845764596622425,
                                0,
                                0,
                                0,
                                -0.060150998126534891,
                                1.4092489965300634,
                                0,
                                -0.10509738283064715,
                                0,
                                0,
                                0,
                                0.57345924449135144,
                                0,
                                0,
                                0,
                                0,
                                0.70613122774297854,
                                0,
                                0,
                                0,
                                -0.78127644414269715,
                                0,
                                0,
                                0,
                                0.5415679985462627,
                                0.16956718530176884,
                                0,
                                0.28466192105315014,
                                0,
                                0,
                                0,
                                -0.65683053352584597,
                                0,
                                0,
                                0.45874716280806155,
                                0.24471769955982453,
                                0,
                                0.52958713087616938,
                                -0.48167214270108449,
                                0,
                                0,
                                0,
                                0,
                                0.025889844842683585,
                                0,
                                0,
                                0.26018751104375049,
                                0,
                                0,
                                0.24735260514653118,
                                0,
                                0,
                                -0.29604487776669464,
                                0,
                                0,
                                0,
                                -0.66827203443320893,
                                0,
                                0,
                                0,
                                -0.25193356209039308,
                                0,
                                0,
                                0,
                                0.89924981452334196,
                                -0.16787049717758423,
                                0,
                                -0.69101105192601242,
                                0,
                                0,
                                0,
                                0.34625437964163941,
                                0,
                                0.13748908412126698,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46778008566448598,
                                0,
                                -0.4830260973116895,
                                0.62180412262716855,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36940610299211651,
                                0,
                                -0.076570860482917918,
                                0,
                                0,
                                0,
                                -0.29352508094081475,
                                -0.047805325066305061,
                                0,
                                -0.43772250980961414,
                                -0.8228849359038366,
                                0,
                                0,
                                0,
                                0,
                                -0.080971599447336479,
                                0,
                                0,
                                -0.10698504788876222,
                                0,
                                0,
                                -0.099103149898287918,
                                0,
                                0,
                                -0.12244766112066288,
                                -0.38126428568918502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52838581544178431,
                                0,
                                -0.67780874556152937,
                                -0.050833525574141405,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.058473705405776809,
                                0,
                                -0.33168970046108387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10105196870427124,
                                0,
                                0,
                                0,
                                -0.92553414693919467,
                                0,
                                0,
                                0,
                                0.09565372851453191,
                                -0.3991296705927887,
                                0,
                                1.0693277194225039,
                                0,
                                0,
                                0,
                                0.97681992520151284,
                                0,
                                0,
                                0.062949277974664264,
                                0.27805840525533804,
                                0,
                                -0.23517022524456621,
                                0.11233189158424683,
                                0,
                                0,
                                0,
                                0,
                                -0.64135048258458704,
                                0,
                                0,
                                -0.24490252775920476,
                                0,
                                0,
                                0.61511896999143456,
                                0,
                                0,
                                -0.033442280173563779,
                                0.20650788328099856,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79620776970378127,
                                0,
                                0,
                                -0.28394500668081835,
                                0,
                                0,
                                0,
                                -0.12328432642461357,
                                -0.74392560861855428,
                                0,
                                0,
                                1.0666437035415608,
                                0,
                                0,
                                -0.49181061027281964,
                                -0.29284926418095142,
                                -0.7655836393783102,
                                0,
                                0,
                                0.22701784557706289,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17164732838161079,
                                0.072411433192674207,
                                0,
                                0,
                                0,
                                0.40450578753285005,
                                0.30244730883524767,
                                -0.4668979117216796,
                                0,
                                0,
                                0.11650937825071267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66934897805656046,
                                0.25554753689861237,
                                0,
                                0,
                                0,
                                0.26973319426699494,
                                0.34024463047303993,
                                -0.087069860160216062,
                                0,
                                0,
                                0.050728717985476957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62935108242337456,
                                0.63658483096956464,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45086352541879759,
                                0.73576688965228509,
                                0,
                                0,
                                -0.30328860413395109,
                                -0.035674131701115247,
                                0,
                                0.34419894387895389,
                                -0.026389216419905777,
                                -0.15897373644557197,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13293077852054197,
                                0,
                                0,
                                0,
                                0,
                                -0.60347862175577871,
                                -0.17093832674639597,
                                0,
                                0,
                                0.20757244817545162,
                                0.36390671566549782,
                                0,
                                -0.012022163888916748,
                                -0.49069062402233676,
                                0.15841059697928517,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40628005663772548,
                                0,
                                0.21383198665453007,
                                0.44983561047617293,
                                -0.17821587576051581,
                                0,
                                0,
                                0.4440150773877124,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27941876471289001,
                                -0.66703723407057958,
                                0,
                                0,
                                0.36815620024058582,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11693362478999539,
                                0,
                                0,
                                1.224617255316655,
                                0,
                                0,
                                0,
                                -0.39982482390079804,
                                0.80167775600620272,
                                0,
                                0,
                                0.42016007846323594,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36360268227150061,
                                -0.37189123275756564,
                                0,
                                0,
                                -0.45181189926256471,
                                -0.53517473550132544,
                                0,
                                0.0091570544891209082,
                                0.29034006923183819,
                                -0.061052851821781245,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38837527270004724,
                                0,
                                0,
                                0,
                                0,
                                -0.038598899760065808,
                                -0.091197620292498088,
                                0,
                                0,
                                -0.52612533713557075,
                                0.46699675410843478,
                                0,
                                -0.52812628198776279,
                                -0.032290361108997176,
                                -0.44671341985773344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12564379665824693,
                                1.1894151981442485,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69227986059278068,
                                0,
                                0,
                                -0.039967546762029113,
                                0,
                                0,
                                0,
                                0.19049081519996544,
                                -0.31872396051709884,
                                0,
                                0,
                                0.11577692454333721,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.051950115330781796,
                                -0.42431298619180008,
                                0,
                                0,
                                -0.065990882017878685,
                                0.32761863258470103,
                                0,
                                0.74868940179952326,
                                0.073201026457584153,
                                -0.35673269767362481,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11143824347625954,
                                0,
                                0,
                                0,
                                0,
                                0.05731311731753045,
                                -0.12192128752991518,
                                0,
                                0,
                                0.043445947739586599,
                                -0.49866250889912112,
                                0,
                                -0.015433534586168196,
                                -0.70845025034313325,
                                -0.41691247472979959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.235250069686369,
                                0,
                                0,
                                0,
                                0,
                                -0.53771133863369036,
                                -0.19579440483854219,
                                0,
                                0,
                                0.41438072783283469,
                                -0.073786260230970263,
                                0,
                                -0.18294210068053057,
                                0.33643732030479817,
                                -0.12442038006212827,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57726679609211951,
                                -0.21957330276697717,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.086939844794144849,
                                0,
                                0,
                                0.046513987541455561,
                                0,
                                0,
                                0,
                                0.80996893635909861,
                                0.77147606718019501,
                                0,
                                0,
                                0.43677209197329681,
                                0,
                                0.38091644841511918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33483604222081248,
                                0,
                                0,
                                -1.3030027100654114,
                                0,
                                0,
                                0,
                                -0.78411762136461405,
                                0.62375980176770718,
                                0,
                                0,
                                0.18043113513637149,
                                0,
                                0,
                                -0.34359773491611689,
                                0.55902760024098974,
                                -0.21332959113268213,
                                0,
                                0,
                                -0.70962119940040569,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.01611579524498586,
                                -0.14176480092614274,
                                0,
                                0,
                                0,
                                0.59829580763190848,
                                -0.43833159936010169,
                                -0.33322133450898672,
                                0,
                                0,
                                -0.48125193418275414,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21929840481992632,
                                -0.24326089552029417,
                                0,
                                0,
                                -0.53566619042357289,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.94273373489222168,
                                0,
                                0,
                                -0.098576173113196719,
                                0,
                                0,
                                0,
                                -0.071905730456208988,
                                -0.041802590403985568,
                                0,
                                0,
                                0.72973367920350485,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.06100620721033434,
                                -0.22263269755711165,
                                0,
                                0,
                                -0.45390979741122961,
                                0.018937115859897144,
                                0,
                                0.090219214565115613,
                                -0.22964337471751683,
                                0.65559014905579893,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49964605107001303,
                                0.39425577242744947,
                                0,
                                0.1036274942095316,
                                0,
                                0.73872871473728374,
                                0,
                                0,
                                0,
                                0,
                                -0.083257898309765863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47862987217856579,
                                0,
                                0,
                                0,
                                -0.2282217829249861,
                                0,
                                -0.24330113894594721,
                                0,
                                -0.71463086941333165,
                                0,
                                0,
                                0,
                                0,
                                0.24071007165355252,
                                0,
                                -0.36235435939648086,
                                0.304558028363561,
                                0,
                                0,
                                0,
                                0,
                                -0.022398706982754417,
                                -0.077743792086661712,
                                0.37624973618176,
                                0,
                                -0.65605832221146665,
                                0,
                                -0.34156790600765496,
                                0,
                                -0.030391674004544345,
                                0,
                                0,
                                0,
                                0,
                                -0.20937729818948253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63825209977409303,
                                0,
                                0,
                                0,
                                0.028117498655761075,
                                0,
                                0.23841389029780768,
                                0,
                                0.23378263184598277,
                                0,
                                0,
                                0,
                                0,
                                -0.028520615924581744,
                                0,
                                -0.65125536655344152,
                                -0.11375615317173599,
                                0,
                                0,
                                0,
                                0,
                                -0.62617116305022158,
                                0.22439117204228279,
                                0.090417553894406699,
                                0,
                                0.057522587030493247,
                                0,
                                -0.75913576408987371,
                                0,
                                0.40212584286774034,
                                0,
                                0,
                                0,
                                0,
                                0.15899892118795123,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2927568486409709,
                                0,
                                0,
                                0,
                                0.3843326954525057,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34346726730234683,
                                0.36000509290182758,
                                -0.29768295512434761,
                                0,
                                0,
                                0,
                                0,
                                -1.5111338365245683,
                                -0.39538311164817691,
                                -0.24130651439272408,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71929973122437918,
                                -0.86141567077033254,
                                0.3343634102236116,
                                0,
                                0,
                                0,
                                0,
                                0.020061384419494815,
                                -0.63407723894527457,
                                0.52341592790441749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39321479711081841,
                                -0.20401839952342876,
                                -0.61741278929198151,
                                0,
                                0,
                                0,
                                0,
                                0.45422373993976728,
                                -0.99054198709541619,
                                0.9225778565444458,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.085539829728421793,
                                0,
                                0.44218344465685766,
                                0,
                                0,
                                0,
                                0,
                                -0.060129736772937342,
                                0,
                                -0.22237709916530593,
                                0.25223113950723308,
                                0,
                                0,
                                0,
                                0,
                                0.075739643379382188,
                                -0.78329797101324905,
                                0.24733949667217162,
                                0,
                                -0.19975273893370979,
                                0,
                                -0.28714089797225861,
                                0,
                                0.093483061489969599,
                                0,
                                0,
                                0,
                                0,
                                -0.081105049269822524,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3431332275817337,
                                0,
                                0,
                                0,
                                -0.86289711108967682,
                                0,
                                0.74759348312550378,
                                0,
                                -0.2597183560536056,
                                0,
                                0,
                                0,
                                0,
                                0.31229000911751326,
                                0,
                                -0.0041593657103461109,
                                0.12490035910352258,
                                0,
                                0,
                                0,
                                0,
                                -0.020342332802379744,
                                -0.33438763838286478,
                                -0.38507013190853812,
                                0,
                                0,
                                0.017543804837825763,
                                0,
                                -0.30465170314205359,
                                0,
                                0,
                                0,
                                0,
                                -0.25538218618016795,
                                0,
                                0.37973294785569417,
                                -0.4790361931726953,
                                0,
                                0,
                                0,
                                0,
                                -0.50871368030868813,
                                -0.39018494020578559,
                                0.23864788185343377,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12302982232758869,
                                0.66688289420731595,
                                0.084183002223389397,
                                0,
                                0,
                                0,
                                0,
                                0.039626905972865709,
                                0.91762841255889582,
                                0.73939557267170131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.071677760055073134,
                                -0.8963855841035151,
                                -0.4088636908032145,
                                0,
                                0,
                                0,
                                0,
                                -0.66072383711119453,
                                0.32684238130865739,
                                -0.1888434333953953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.95336767631432795,
                                -0.061067693016645649,
                                0.98542590805037267,
                                0,
                                0,
                                0,
                                0,
                                0.03141560865933761,
                                -0.27194900345855327,
                                0.26909550906936924,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4808928240940229,
                                0,
                                -0.40265484360036702,
                                0,
                                -0.4826395368935229,
                                0,
                                0,
                                0,
                                0,
                                0.40460693142106841,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39853408363428078,
                                0,
                                0,
                                0,
                                -0.22612841775207382,
                                0,
                                0.18874790093682067,
                                0,
                                -0.02600066934517542,
                                0,
                                0,
                                0,
                                0,
                                0.12753885263343809,
                                0,
                                -0.31635839619267836,
                                -0.69542899500773103,
                                0,
                                0,
                                0,
                                0,
                                0.53632721932225158,
                                -0.041224807875411905,
                                0.27272979896799748,
                                0,
                                0,
                                -0.28547606989290647,
                                0,
                                -0.2476778455865582,
                                0,
                                0,
                                0,
                                0,
                                -0.47207611138889755,
                                0,
                                -0.38807665949946135,
                                -0.15175302311025174,
                                0,
                                0,
                                0,
                                0,
                                0.085348055865096001,
                                -0.20533406646003308,
                                -0.64126780694161911,
                                0,
                                0,
                                0.44757139379236127,
                                0,
                                -0.1297519483505713,
                                0,
                                0,
                                0,
                                0,
                                -0.73195800831710678,
                                0,
                                -0.014616806367313412,
                                0.28099316013670489,
                                0,
                                0,
                                0,
                                0,
                                0.21802954627218399,
                                0.14875432567815849,
                                0.31344252087238833,
                                0,
                                -0.37374048585801556,
                                0,
                                0.22743082760684374,
                                0,
                                0.22354201688581965,
                                0,
                                0,
                                0,
                                0,
                                0.86813813098028769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.035655328875561866,
                                0,
                                0,
                                0,
                                -0.060721640558606842,
                                0.18254618226775571,
                                0,
                                0,
                                0,
                                0.70418476666228003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.048548565333214416,
                                0,
                                -0.85222684768128065,
                                0,
                                -0.088501087921624436,
                                0,
                                -0.3812855356381567,
                                0,
                                0,
                                0,
                                -0.20447137558654824,
                                -0.19910304912913251,
                                0,
                                0,
                                -0.60059206049959524,
                                0.46209830887014941,
                                0,
                                0.37625743738179318,
                                0,
                                -0.4064571422509301,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15256912617526655,
                                -0.11937066751774619,
                                0,
                                -0.053407303967852024,
                                -0.36173398206250057,
                                0,
                                0,
                                0.34557030190757226,
                                0.24995201682271004,
                                0,
                                -0.1809249848819787,
                                0,
                                -0.12572709838899107,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59032410797153445,
                                0.53607614753280519,
                                0,
                                0,
                                0,
                                0.8645516906063283,
                                0,
                                0,
                                0,
                                -0.15984973854833082,
                                0,
                                0.38275845840434236,
                                0,
                                0,
                                -0.032396466835714822,
                                0,
                                -0.27757693151474949,
                                0,
                                -0.048948073538388322,
                                0,
                                0,
                                0,
                                -0.89482343777770379,
                                0,
                                0,
                                0,
                                0.51644218565942346,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.82178895927872264,
                                0,
                                0.18083506123557141,
                                0,
                                0.56856075451667165,
                                0,
                                -0.28814761365900377,
                                0,
                                0,
                                0,
                                0.018401322649552659,
                                -0.45837539500660895,
                                0,
                                0,
                                0.31215552081580455,
                                0.31353088404821294,
                                0,
                                -0.22527723853633247,
                                0,
                                0.12346493888892514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.02199536630036604,
                                -0.72617730801323832,
                                0,
                                0.46301385025637454,
                                0.048681992189730322,
                                0,
                                0,
                                -0.22077280223298346,
                                0.54533434046619356,
                                0,
                                0.026634248833715984,
                                0,
                                0.61840209292599113,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.086065284798672537,
                                0.21582469741909188,
                                0,
                                0,
                                0,
                                -0.036591894955348633,
                                0,
                                0,
                                0,
                                0.38732071604763763,
                                0,
                                -0.20720324963594153,
                                0,
                                0,
                                0.28861152744537738,
                                0,
                                -0.54079317521219128,
                                0,
                                -0.65571078788882953,
                                0,
                                0,
                                0,
                                0,
                                -0.12904659689350184,
                                -0.32134103176207085,
                                0,
                                0,
                                -0.085600117767672984,
                                -0.42210409194692838,
                                0,
                                0.52858612908970437,
                                0,
                                0.52139531042807863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36924021665132001,
                                -0.083623975873983972,
                                0,
                                0,
                                0,
                                -0.07337966524263477,
                                0,
                                0,
                                0,
                                0.27399391792460037,
                                0,
                                0.53226567446114192,
                                0,
                                0,
                                0.75007507398988582,
                                0,
                                0.23667648773180136,
                                0,
                                0.13269375642296657,
                                0,
                                0,
                                0,
                                0,
                                0.2990520212132301,
                                -0.08237474915727698,
                                0,
                                0,
                                -0.55583299932619468,
                                -0.31773068061350279,
                                0,
                                -0.58413393769943889,
                                0,
                                -0.014901881042702819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36932155423402813,
                                -0.1266737822668185,
                                0.53560294815492848,
                                0,
                                0,
                                0,
                                -0.52203607903028959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32107865366045213,
                                0,
                                -0.2687933436023594,
                                0,
                                0.73173748930023541,
                                0,
                                -0.66429487361446438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19101601251506803,
                                0,
                                0,
                                0,
                                -0.59828544975409637,
                                0,
                                0.30069953149138756,
                                0,
                                0,
                                0.01539214352111834,
                                0,
                                0.27901809497570174,
                                0,
                                -0.66110451513372492,
                                0,
                                0,
                                0,
                                -0.8130818526544018,
                                0,
                                0,
                                0,
                                -0.16741952811839114,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61590137839223069,
                                0,
                                0.028452561261713728,
                                0,
                                0.025165594754599566,
                                0,
                                -1.3474787146729172,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17506498560851874,
                                0,
                                0,
                                0,
                                -0.61461693419589825,
                                0,
                                -0.16379397390655628,
                                0,
                                0,
                                0.43223245702765201,
                                0,
                                -0.52425098320172092,
                                0,
                                0.32110094803549005,
                                0,
                                0,
                                0,
                                0.19095400763022469,
                                0,
                                0,
                                0,
                                0.075247630424305934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65149806486484685,
                                0,
                                0.60623260958326664,
                                0,
                                -0.87200209155479325,
                                0,
                                -0.27573092962358403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42271972511219225,
                                0,
                                0,
                                0,
                                -0.11687002078752501,
                                0,
                                -0.64031816585461732,
                                0,
                                0,
                                0.40740572351274085,
                                0,
                                0.47094356156324091,
                                0,
                                -0.099372113744073842,
                                0,
                                0,
                                0,
                                -0.19737309273033238,
                                0,
                                0,
                                0,
                                -0.85361481262574068,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57590912058097421,
                                0,
                                -0.3412337560495538,
                                0,
                                -0.93174217431046924,
                                0,
                                0.40845978678866013,
                                0,
                                0,
                                0,
                                -0.78620086017772173,
                                0.22577603364925519,
                                0,
                                0,
                                -0.15800369912320775,
                                0.16408036773644172,
                                0,
                                -0.35815423685262349,
                                0,
                                0.38512229706593704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.045732837029340126,
                                0.018458619035601413,
                                0,
                                0.12814739224206745,
                                0.67528370895101242,
                                0,
                                0,
                                0.18012709869522395,
                                0.14916758080718601,
                                0,
                                0.15920760921851737,
                                0,
                                -0.030434011918498205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58781020704157472,
                                -0.31792969037493585,
                                -0.17385632621167296,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31551895293300236,
                                0,
                                0,
                                0.59599244567011178,
                                0,
                                0,
                                0,
                                -0.7226404393740764,
                                0,
                                -0.49492640352259282,
                                0,
                                0,
                                0.71249831981510936,
                                0,
                                -0.50645228884974069,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4466726832165534,
                                0.079814405418530854,
                                0,
                                0.18625347265052378,
                                0.53960538126650792,
                                0,
                                0,
                                0,
                                0,
                                -0.46016837169509961,
                                0,
                                0,
                                0,
                                0,
                                -0.052715271156704241,
                                -0.26047771091505734,
                                0.36507759333215134,
                                0.23408274111336599,
                                0.26817828301479552,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67101153405734049,
                                0,
                                0.32187780866010329,
                                0,
                                0,
                                -0.33987452013413477,
                                0,
                                0,
                                0,
                                -0.091352432655658011,
                                0.21804223245111667,
                                0.16033817412395862,
                                0.10843374189650963,
                                -0.50422833510440412,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55302448753539746,
                                0,
                                -0.29261143507893772,
                                0,
                                0,
                                0.51082517731376398,
                                0,
                                0,
                                0,
                                -0.31804475833316059,
                                0.36755528828165152,
                                0.46062969883979826,
                                -0.2966476750068206,
                                -0.44774083100939399,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16835893110882022,
                                0,
                                0.19372294436435858,
                                0,
                                0,
                                -0.44410124814338559,
                                0,
                                0,
                                0,
                                0.70409223361662332,
                                -0.33892655656219295,
                                0.0208934085280221,
                                -0.25463580591165491,
                                -0.40465122913972595,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10519989317355802,
                                0,
                                -0.21712752209578182,
                                0,
                                0,
                                -0.31961381701356983,
                                0,
                                0,
                                0,
                                0.049715145872878383,
                                -0.45744746157572719,
                                0.28966240220628781,
                                0.33824926543108347,
                                -0.34866799104015322,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35639423583328605,
                                0,
                                0.46726410782779915,
                                0,
                                0,
                                0.35075830079543102,
                                0,
                                1.0016260319384231,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20006943489880102,
                                0,
                                0,
                                0.0011856931626378492,
                                0,
                                0,
                                0,
                                -0.47312485665273685,
                                0,
                                -0.014847467793507693,
                                0,
                                0,
                                -0.50027371323861791,
                                0,
                                0.16392413905702991,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23378341706123729,
                                0.21038946344348269,
                                0,
                                -0.12683287948023159,
                                0.58530385888380954,
                                0,
                                0,
                                0,
                                0,
                                0.71801342443719052,
                                0,
                                0,
                                0,
                                -0.2874414686371376,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16820700499620905,
                                0.84862179869846766,
                                0,
                                0.29986376086273542,
                                -0.24999434828353198,
                                0,
                                0,
                                0,
                                0,
                                0.12848890652214323,
                                0,
                                0,
                                -0.78929579471571265,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20170259194504875,
                                0,
                                0,
                                0.40901956692577524,
                                0,
                                0,
                                0,
                                -0.99843209700120428,
                                0,
                                0.64891399639792202,
                                0,
                                0,
                                -0.4936218748765635,
                                0,
                                -0.66009213444372883,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5779648389304648,
                                -0.18950279303146303,
                                0,
                                -0.35812507611468392,
                                0.17280488155918255,
                                0,
                                0,
                                0,
                                0,
                                0.19028560956111842,
                                0,
                                0,
                                0,
                                0.29944176452057475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14553863486504839,
                                0.43917895275514102,
                                0,
                                -0.68311859105967698,
                                0.20163892766996624,
                                0,
                                0,
                                0,
                                0,
                                -0.43470187056886239,
                                0,
                                0,
                                0,
                                0,
                                0.1407458907244287,
                                -0.02040360159649366,
                                0.20222843710287158,
                                -0.74891894450444996,
                                0.25100629853927314,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11789798682300852,
                                0,
                                0.32989708928536471,
                                0,
                                0,
                                0.43847710812890572,
                                0,
                                -0.012272149602343907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90926423375333831,
                                0,
                                0,
                                -0.33672395331966642,
                                0,
                                0,
                                0,
                                0.39855179366648008,
                                0,
                                0.47774607814465442,
                                0,
                                0,
                                1.1947744084100791,
                                0,
                                0,
                                0.50771101134075591,
                                0.60807685843166104,
                                -0.20564364941602664,
                                0.2465763268127677,
                                -0.048448809402534085,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.078031149870703864,
                                0,
                                0.51081564948359803,
                                0,
                                0,
                                0.0037539943514085516,
                                0,
                                0.25764579030216861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59083622259780544,
                                0,
                                0,
                                0.97935803847009639,
                                0,
                                0,
                                0,
                                0.5892077404913626,
                                0,
                                -0.20740865277271495,
                                0,
                                0,
                                -0.15082033833112279,
                                0,
                                0.32958361847537687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60192223930271993,
                                -0.02043320884243971,
                                0,
                                0.5141986094264781,
                                0.4829373322364553,
                                0,
                                0,
                                0,
                                0,
                                -0.17611945786337574,
                                0,
                                0,
                                0,
                                0,
                                0.33455346205157521,
                                0.23496572830301932,
                                0.67919349836560683,
                                0.21098843865278363,
                                0.35028403986610257,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23977081381631724,
                                0,
                                -0.37148327093982175,
                                0,
                                0,
                                0.094108372389915179,
                                0,
                                -0.11533436749248027,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7970906335723873,
                                0,
                                0,
                                0.39511147493058379,
                                0,
                                0,
                                0,
                                0.37934784538399063,
                                0,
                                1.2098625217783898,
                                0,
                                0,
                                0.68819749728320678,
                                0.1206529745164901,
                                0,
                                0,
                                0.12094899624084518,
                                0,
                                -0.13797439414297727,
                                0,
                                0,
                                0,
                                0,
                                -0.14567249215920899,
                                0,
                                0.32852268882379415,
                                0.90671766905978579,
                                0,
                                -0.014173506398610078,
                                0,
                                0,
                                0,
                                -0.017082590459321811,
                                0,
                                -0.11290632686721969,
                                0,
                                0,
                                0,
                                0,
                                -0.25882182904713674,
                                0,
                                0,
                                0,
                                0,
                                0.29675217061393372,
                                0,
                                0,
                                -0.04546027621911336,
                                0,
                                0.29851537511750664,
                                -0.86082722163190195,
                                0,
                                0,
                                0,
                                0,
                                0.82448595148026738,
                                0,
                                -0.82942062356332702,
                                0,
                                0,
                                -0.75207911372788605,
                                -0.45319669248365524,
                                -0.15862732572976032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47977487665527091,
                                0,
                                -0.094631057990997802,
                                0,
                                0,
                                0.17373414800730622,
                                0,
                                -0.20070689441070849,
                                0,
                                0,
                                0,
                                0,
                                -0.68502254965862786,
                                0,
                                0.42075448102177571,
                                -0.30126486034996569,
                                0,
                                0.38284020256250356,
                                0,
                                0,
                                0,
                                -0.1922518858040014,
                                0,
                                0,
                                -0.10202641746818378,
                                0,
                                1.2055314107356296,
                                0,
                                0,
                                -0.43346879317819442,
                                0.39428271023457984,
                                -0.002820032579529716,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1004534607321383,
                                0,
                                -0.31928279223069161,
                                0,
                                0,
                                -0.19621789783674612,
                                0,
                                0.53577147651930768,
                                0,
                                0,
                                0,
                                0,
                                -0.10058503190664037,
                                0,
                                0.17052395815032939,
                                0.054724176334038761,
                                0,
                                -0.35314093233390648,
                                0,
                                0,
                                0,
                                -0.63687277975291667,
                                0,
                                0.20151784203639103,
                                0,
                                0,
                                0,
                                0,
                                -0.43458890816779039,
                                0,
                                0,
                                0,
                                0,
                                -0.30154025900965187,
                                0,
                                0,
                                -0.79260043415449843,
                                0,
                                -0.22387787810963675,
                                -0.035493096598397583,
                                0,
                                0,
                                0,
                                0,
                                -0.24388826571467653,
                                0,
                                -0.030118857658721798,
                                0,
                                0,
                                -1.3084310717907259,
                                0.76637768480066981,
                                0.10877256760746459,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71631945961255394,
                                0,
                                0,
                                0,
                                -0.77684846915647787,
                                0,
                                -0.10235001511688321,
                                0,
                                0,
                                -0.27197282118565325,
                                -0.4837968465652604,
                                -0.78763955913556372,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45941550264908509,
                                0,
                                0,
                                0,
                                0.35112401431126,
                                0,
                                0.77442549413666495,
                                0,
                                0,
                                0.35925287828985775,
                                0.55424129239089981,
                                -0.76535611729315256,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.093895110464336268,
                                0,
                                -0.38975055466762809,
                                0,
                                0,
                                -0.51481787402930479,
                                0,
                                -0.53392160245183717,
                                0,
                                0,
                                0,
                                0,
                                -0.23570629409331648,
                                0,
                                -0.44160927258037092,
                                0.15821488491432373,
                                0,
                                -0.028295619186045035,
                                0,
                                0,
                                0,
                                -0.14688766310940266,
                                0,
                                -0.16025491655307861,
                                0,
                                0,
                                0,
                                0,
                                0.031302596689648673,
                                0,
                                0,
                                0,
                                0,
                                0.77918617381300548,
                                0,
                                0,
                                -0.19950989909695632,
                                0,
                                -0.56329328107161702,
                                0.095414335199669964,
                                0,
                                0,
                                0.36254311510950599,
                                0,
                                0,
                                -0.061493380204728346,
                                0,
                                0.34861662670182497,
                                0,
                                0,
                                0,
                                0,
                                -0.65898450631810035,
                                0,
                                -0.38046468900529351,
                                0.046119004518574869,
                                0,
                                -0.27830263201553163,
                                0,
                                0,
                                0,
                                0.29095399078371459,
                                0.23846630257689921,
                                0,
                                0,
                                -0.74875289752552399,
                                0,
                                0.26847977030161141,
                                0,
                                0,
                                0,
                                0,
                                0.061106398858801446,
                                0,
                                0.24508959987751786,
                                0.039958716653868673,
                                0,
                                0.47711462849001007,
                                0,
                                0,
                                0,
                                0.13184673760026017,
                                0,
                                -0.61818836948856115,
                                0,
                                0,
                                0,
                                0,
                                0.60686247629162271,
                                0,
                                0,
                                0,
                                0,
                                -0.27564352348764343,
                                0,
                                0,
                                -0.3527594210517514,
                                0,
                                -0.081660312180351163,
                                -0.20609247179708579,
                                0,
                                0,
                                -0.48864469686089118,
                                0,
                                0,
                                0.26625884400994443,
                                0,
                                0.41533628338357609,
                                0,
                                0,
                                0,
                                0,
                                -0.030720311511291593,
                                0,
                                -0.36118669122553637,
                                0.22985071118696709,
                                0,
                                0.56323373447839931,
                                0,
                                0,
                                0,
                                0.12792657024986415,
                                0,
                                -0.10588616983930195,
                                0,
                                0,
                                0,
                                0,
                                0.046471264376968927,
                                0,
                                0,
                                0,
                                0,
                                0.35196611080472284,
                                0,
                                0,
                                -0.41093919042727833,
                                0,
                                0.73235065090316764,
                                0.39691296698602235,
                                0,
                                0,
                                0,
                                -0.72635551989418412,
                                0,
                                0,
                                0,
                                0,
                                -0.61050982432972678,
                                0,
                                0,
                                0,
                                0,
                                -0.11841044200269515,
                                0,
                                0,
                                0.19132038013947464,
                                0,
                                -0.021495663457254292,
                                0.2204514208089409,
                                0,
                                0,
                                0,
                                0,
                                0.30154553532992001,
                                0,
                                -0.89358704116427234,
                                0,
                                0,
                                0.23244654067838524,
                                1.0403594120603477,
                                0.10263678085654537,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61375450251791308,
                                0,
                                0.54365751974676368,
                                0,
                                0,
                                0.1278388434615996,
                                0,
                                -0.049368904296352774,
                                0,
                                0,
                                0,
                                0,
                                0.070075078881868036,
                                0,
                                -0.39454178768464332,
                                0.050208128840360272,
                                0,
                                0.32465422760695845,
                                0,
                                0,
                                0,
                                -0.64588039140336195,
                                -0.48490289248480423,
                                -0.20285708150953596,
                                0,
                                0.15348881541542972,
                                0,
                                0,
                                0,
                                0.18981488738640762,
                                0,
                                0.22661994127323709,
                                0,
                                0,
                                0,
                                0,
                                0.053266336185986765,
                                0.26744824770956088,
                                0,
                                -0.73376237015390677,
                                0,
                                0,
                                0.4039080353712991,
                                0.59248033603699479,
                                0,
                                0.11236399002661937,
                                0,
                                0,
                                0,
                                -0.052587458518170975,
                                0,
                                -0.33791167117565024,
                                0,
                                0,
                                0,
                                0,
                                -0.23557080780850753,
                                -0.016166945361526242,
                                0,
                                -0.54817421518463338,
                                0,
                                0,
                                0,
                                0,
                                -0.72757423349110195,
                                0,
                                -0.6743234315773714,
                                -0.96580370091781409,
                                0,
                                0,
                                -0.3533739769411518,
                                0,
                                0,
                                0.064936701126501239,
                                0,
                                -0.24995494314994388,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11007150854930248,
                                -0.087381583812041502,
                                0,
                                0.054218759263235744,
                                0,
                                0,
                                0,
                                -0.26970461879195401,
                                0,
                                -0.0084202699285734085,
                                0,
                                0,
                                0,
                                0,
                                0.71852171341619808,
                                -0.56471734675968632,
                                0,
                                -0.26328393653032428,
                                0,
                                0,
                                0,
                                0,
                                0.97233160080982928,
                                0,
                                -0.56316449237165456,
                                0.050514091980376319,
                                0,
                                0,
                                0.1339867704827587,
                                0,
                                0,
                                -0.7901662929333565,
                                0,
                                -1.2442114750283948,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68280398788987673,
                                0,
                                -0.60083814898955634,
                                0.48652066230145996,
                                0,
                                0,
                                -0.68986667635609522,
                                0,
                                0,
                                -1.0432458655404957,
                                0,
                                0.1295456302204121,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.010615762568783505,
                                0,
                                0,
                                0,
                                0.35152766743866082,
                                0,
                                0.068296609609067638,
                                0,
                                0,
                                0,
                                -0.45014292521906729,
                                0,
                                0.81786588133407356,
                                -0.010859316322143174,
                                0.52350554259562543,
                                -0.35477400864940029,
                                0,
                                0.48671978084989054,
                                0,
                                0,
                                0,
                                0.37283793520788183,
                                0,
                                0.34441075886670219,
                                0,
                                0,
                                0,
                                0,
                                -0.21835793021560507,
                                -0.23628267778605772,
                                0,
                                -0.045217455975779933,
                                0,
                                0,
                                0,
                                0,
                                0.11634229433792176,
                                0,
                                -0.16519289249363731,
                                -0.93149410775552655,
                                0,
                                0,
                                1.0749708704191767,
                                0,
                                0,
                                -0.66557351280331578,
                                0,
                                0.66765107833507831,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30664018276980315,
                                0.1459536616419434,
                                0,
                                -0.66529914329405326,
                                0,
                                0,
                                0,
                                0.51391907225837907,
                                0,
                                0.29495764113437883,
                                0,
                                0,
                                0,
                                0,
                                0.26388065920330206,
                                0.10599311835909909,
                                0,
                                -0.10032950992048192,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68108188381672918,
                                0,
                                0,
                                0,
                                -0.30016633524823522,
                                0,
                                0.33596053525092945,
                                0,
                                0,
                                0,
                                0.45199564278425297,
                                0,
                                0.35827753475200919,
                                -0.022255436870130277,
                                0,
                                0,
                                -0.94524246688022073,
                                0,
                                0.66420694110948475,
                                0.73604661572818675,
                                0,
                                0,
                                1.0727179499358721,
                                0,
                                0,
                                -0.096460301029325887,
                                0,
                                -0.50896491485503481,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30102952849138231,
                                0,
                                0,
                                0,
                                0.12602891934502089,
                                0,
                                0.55457819213572868,
                                0,
                                0,
                                0,
                                -0.5029736055636036,
                                0,
                                -0.3791771999930551,
                                -0.43495191272625,
                                0,
                                0,
                                -0.35529348868210936,
                                0,
                                -1.0326710419458349,
                                0.66076712084433098,
                                0,
                                0,
                                0.64512774101615311,
                                0,
                                0,
                                -0.1434441828269285,
                                0,
                                0.039283795297915897,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22493874440511871,
                                0.26626767728645301,
                                0,
                                -0.21672721352803703,
                                0,
                                0,
                                0,
                                -0.25508841412597782,
                                0,
                                0.586520359351696,
                                0,
                                0,
                                0,
                                0,
                                -0.41766551481138131,
                                -0.49369476190881983,
                                0,
                                -0.065407714071720607,
                                0,
                                0,
                                -0.1961642425316501,
                                0.61793653718300967,
                                0,
                                0.48160021398137109,
                                0,
                                0,
                                0,
                                0.26142587873902945,
                                0,
                                0.2845244977601043,
                                0,
                                0,
                                0,
                                0,
                                0.34075301346040399,
                                0.089799057303529717,
                                0,
                                0.2725088862483015,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10008054454268363,
                                0,
                                0,
                                0,
                                0.80094678550311804,
                                0,
                                0.25203940948599657,
                                0,
                                0,
                                0,
                                0.34576720220628765,
                                0,
                                -0.16878481270819518,
                                0.37000134640256016,
                                0.36393356980092206,
                                -0.016413597665192015,
                                0,
                                0.049470163762865185,
                                0,
                                0,
                                0,
                                -0.59323667998413754,
                                0,
                                0.45145221353820697,
                                0,
                                0,
                                0,
                                0,
                                0.13238335564792708,
                                0.53892666417001311,
                                0,
                                -0.033607911088689185,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21601607070759532,
                                0,
                                0,
                                0,
                                0.35849544370906794,
                                0,
                                -0.51574196225134317,
                                0,
                                0,
                                0,
                                0.24673861847021616,
                                0,
                                0.018221579614169224,
                                -0.7054192587396515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62347168171303968,
                                0,
                                0,
                                0,
                                -0.020259450376690025,
                                0,
                                0.49537408603636857,
                                0,
                                0,
                                0,
                                0.39956718323639251,
                                0,
                                0.17359988560627573,
                                -0.41914946910858092,
                                -0.22769946713806624,
                                0,
                                0,
                                0.58855987788310604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13978934023647779,
                                0,
                                0,
                                0.28903044425049806,
                                0,
                                0.15432900788218679,
                                0,
                                0,
                                -0.36612342307197576,
                                0.53100706821670185,
                                -0.24256598148119579,
                                0,
                                -0.074567090500258643,
                                0,
                                0,
                                0,
                                0,
                                0.64431270704250854,
                                0,
                                0,
                                0,
                                0.35325334268501835,
                                0,
                                0,
                                0.40632184276971128,
                                0,
                                -0.40164317511719605,
                                -0.35790820109316479,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24113718219499586,
                                0,
                                0.0086907845526656979,
                                0.12382688569713651,
                                0,
                                -0.12293756488203822,
                                1.1689246905091482,
                                0,
                                0,
                                0.90188784296645985,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28470568226071513,
                                0,
                                0,
                                0.50857194663579286,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43174877405590312,
                                0,
                                0,
                                0.042836469054815786,
                                0,
                                -0.22238623266089638,
                                0,
                                0,
                                0.33160586918230506,
                                -0.45231605169106692,
                                -0.32870561758665989,
                                0,
                                0,
                                -0.60600436636070343,
                                0,
                                -1.4139846965203662,
                                -0.25163455577340188,
                                0,
                                0.45025593738967995,
                                0.28338766318035202,
                                0,
                                0,
                                0.17003063009319191,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62907984957381491,
                                0,
                                0.53680485066939487,
                                0.3097027852706159,
                                0,
                                0.49889423623883988,
                                -0.71069729399567749,
                                0,
                                0,
                                0.71598734338287706,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39190522863857696,
                                0,
                                0,
                                0,
                                0,
                                0.12955601135319089,
                                0,
                                0,
                                0,
                                -0.15321637788654408,
                                0,
                                0,
                                -0.10053191141452171,
                                0,
                                0.61777371079220911,
                                -0.64373849525773319,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.024547365428213491,
                                0,
                                -0.27071229978648614,
                                1.1764314657241401,
                                0,
                                -0.53217865745598281,
                                0.38693880218910537,
                                0,
                                0,
                                0.39440102110601405,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46517463400480202,
                                0,
                                -0.62772497835970498,
                                -0.76567037676548522,
                                0,
                                -0.58427016976273216,
                                -0.59633397693881995,
                                0,
                                0,
                                0.60401948858611298,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56265923438702126,
                                0,
                                0,
                                -0.37190935802954711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21778758665292292,
                                0,
                                0,
                                0.51018895976188694,
                                0,
                                -0.37035648296693652,
                                0,
                                0,
                                -0.23244502548290025,
                                -0.21485482688565072,
                                0.0040739198069158072,
                                0,
                                -0.4027697307677176,
                                0,
                                0,
                                0,
                                0,
                                -0.49735405262631205,
                                0,
                                0,
                                0,
                                -0.4037375753194915,
                                0,
                                0,
                                0.43246776556471039,
                                0,
                                -0.42875882687133149,
                                -0.23780025381821687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.95112313163712592,
                                0,
                                -0.023957433881620888,
                                -0.0059980521602474579,
                                0,
                                -1.4644143246869628,
                                0.12477260176118077,
                                0,
                                0,
                                -0.37742558864854098,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47784214538959091,
                                0,
                                0,
                                0.2536345625246752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25926608523332262,
                                0,
                                0,
                                -0.16552735499757601,
                                0,
                                0.10744054173505577,
                                0,
                                0,
                                0.39671689110612629,
                                0.080221438093770581,
                                0.6613281664579379,
                                0,
                                -0.15533071056919825,
                                0,
                                0,
                                0,
                                0,
                                0.44975257070713809,
                                0,
                                0,
                                0,
                                -0.60611077001600777,
                                0,
                                0,
                                -0.51984939187635293,
                                0,
                                -0.36357209129020324,
                                0.061617158062056754,
                                0,
                                0,
                                0,
                                0.51238579334058609,
                                0,
                                0,
                                0.38100776867311476,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13346335852331076,
                                0,
                                0,
                                0.45382629481473485,
                                0,
                                -0.15164905772172116,
                                0,
                                0,
                                -0.15937937706568819,
                                -0.34609650436137634,
                                0.44759478570128985,
                                0,
                                0.40874403516879554,
                                0,
                                0,
                                0,
                                0,
                                0.27530873358148783,
                                0,
                                0,
                                0,
                                -0.55998560655566298,
                                0,
                                0,
                                0.5680467604545818,
                                0,
                                0.31294266548519689,
                                0.15145725943067373,
                                0,
                                0,
                                0,
                                0,
                                -0.69815991636971675,
                                0,
                                0,
                                0,
                                0,
                                0.20650193257707772,
                                0,
                                0,
                                0,
                                0.088196613457749387,
                                0,
                                0,
                                0.21177113666851891,
                                0,
                                0.20757286207404158,
                                0.6117332204447139,
                                0,
                                0,
                                0,
                                -0.059839799632952884,
                                0,
                                0,
                                0.2032455057238953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53751934945330349,
                                0,
                                0,
                                -0.56120263117812164,
                                0,
                                -0.097133120942451218,
                                0,
                                0,
                                -0.38326816902729693,
                                -0.40415638107202501,
                                -0.17766064721874425,
                                0.059855531512782056,
                                0,
                                0,
                                -0.05865099429507914,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46171171784915171,
                                0,
                                0,
                                0.32561492089239585,
                                0,
                                0.57431013859979252,
                                0,
                                0,
                                0.40656170137115721,
                                -0.25028754670431624,
                                -0.34059680085543492,
                                -0.22907293535451514,
                                0,
                                0,
                                -0.048879329232729148,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39935494375419822,
                                0,
                                0,
                                -0.0016073224901435035,
                                0,
                                0.64479074991396468,
                                0,
                                0,
                                -0.45495880340538231,
                                -0.33922644412390168,
                                0.21870583556846801};

const double rot_24_10[1000] = {0.40899499949282003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39403750100096907,
                                0,
                                0.80770309235621685,
                                -0.75174823379488664,
                                0,
                                -0.5435078365988103,
                                -0.31298019129638532,
                                0.31666572333019238,
                                -0.00071287441784773347,
                                0.51956501532862076,
                                0,
                                0.48622745473302892,
                                0,
                                0,
                                0,
                                0.05427087773249252,
                                -0.39739568064158426,
                                -0.0044443190864034768,
                                0.32995430402501008,
                                0.48133046702446652,
                                0,
                                -0.70608974757802256,
                                0,
                                0,
                                0,
                                -0.4676439192399639,
                                0.059736286790129101,
                                -0.4256368039865559,
                                -0.69502747356060213,
                                0.10488354944429948,
                                0,
                                -0.32017230358426535,
                                0,
                                0,
                                0,
                                -0.083896499760963639,
                                -0.77261812102325267,
                                0.13782943937927267,
                                -0.16043488791830213,
                                -0.59057826113811285,
                                0,
                                -0.050036249304654917,
                                0,
                                0,
                                0,
                                -0.21711601387195031,
                                0.33816605837470992,
                                0.80051373096442735,
                                -0.15893302138127785,
                                -0.14871257638546317,
                                0,
                                -0.3876944471623181,
                                0,
                                0,
                                0.28682245647074073,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6609991590980272,
                                0,
                                0.20125028199199912,
                                -0.41951366598832462,
                                0,
                                0.65481683090153198,
                                -0.17104562237552051,
                                0.24231630354877642,
                                -0.59755117062445962,
                                0.34128361301478338,
                                0,
                                0.098484597991850775,
                                0,
                                0,
                                -0.50386651761302159,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34183756044414237,
                                0,
                                -0.25571637301499661,
                                0.010135772863433173,
                                0.51000756341279885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.022362876918304526,
                                0,
                                -1.1467930802973596,
                                -0.45453416968719862,
                                -0.37643881492936682,
                                0,
                                0,
                                -0.055638988421565186,
                                0,
                                0.25605964058928116,
                                -0.98148146771839984,
                                0,
                                0,
                                0,
                                0,
                                0.084661464520945542,
                                -0.38048965537228518,
                                0,
                                -0.13199904347030883,
                                0,
                                0,
                                0.15537508650931595,
                                -0.75045760268091788,
                                0.49326289154304309,
                                0,
                                -0.36770365671466071,
                                -0.18338285120580533,
                                0,
                                -0.79230327146723822,
                                0,
                                0,
                                0.059738594166459047,
                                0.36905161763513172,
                                0.25229443242472654,
                                -0.024614919120365723,
                                0,
                                0,
                                0.69378915400133845,
                                0,
                                -0.68659687812675219,
                                -0.57165350001495485,
                                0,
                                0,
                                0,
                                0,
                                -0.090742484462900938,
                                0.69720628996905343,
                                0,
                                0.13444830852770215,
                                0,
                                0,
                                0.0010134581198204158,
                                0.069519573871821339,
                                0.69480849507360543,
                                -0.14007839684631718,
                                0,
                                0,
                                -0.38399114784949628,
                                0,
                                -1.2701779417811296,
                                -0.050429762203793388,
                                0,
                                0,
                                0,
                                -1.1642800816345296,
                                0,
                                0,
                                -0.38534114991653323,
                                0,
                                0.48286539810299262,
                                0.37020384701364145,
                                0,
                                0,
                                0,
                                0,
                                0.50718177635134254,
                                -0.43848172123211865,
                                0,
                                0.25811320617409494,
                                0,
                                0,
                                0.18426430554955558,
                                0.53671766212427086,
                                0.40231680992116314,
                                0,
                                0.72340490836017324,
                                0.37181436127250034,
                                0,
                                -0.50031355670863875,
                                0,
                                0,
                                0.22486533865827957,
                                -0.0863807770493909,
                                -0.17349266587359047,
                                0,
                                -0.26238186498849675,
                                0.070637116042054401,
                                0,
                                0.1407812084454311,
                                0,
                                0,
                                0.94221605851965495,
                                0.015932089259831306,
                                -0.13535831600077602,
                                0.57455126995411532,
                                -0.16379172315108631,
                                -0.36031834501263382,
                                0,
                                0,
                                -0.68655928840069236,
                                0,
                                0.02966601518385396,
                                -0.20246004771933174,
                                0,
                                0.037189045617369382,
                                -0.35324133491719778,
                                -0.64581867533270465,
                                0,
                                0,
                                0.52883694087238842,
                                0,
                                -0.29869850095407796,
                                -0.2964227863711168,
                                0,
                                -0.52900229696637024,
                                0.16970369461099319,
                                -0.2147854175273636,
                                0,
                                0,
                                -0.17008673818193351,
                                0,
                                0.4985220184151824,
                                -0.60644105146927707,
                                0,
                                0,
                                0,
                                0,
                                -0.17919981613494607,
                                -0.62611524035960553,
                                0,
                                1.1147696390325983,
                                0,
                                0,
                                0.51815462897323861,
                                0,
                                0,
                                0,
                                0.43485911027779911,
                                -0.037556059548715229,
                                0,
                                -0.4353461545065504,
                                0,
                                0,
                                0.99277873151300644,
                                0.61688498896483024,
                                0.19442688929198271,
                                0.21878875174122461,
                                0,
                                0,
                                0.4624307926211022,
                                0,
                                0.48363565117885043,
                                -0.29332046666785766,
                                0,
                                0,
                                0,
                                0,
                                -0.30960753415818826,
                                -0.38375012748413745,
                                0,
                                0.40055530151723168,
                                0,
                                0,
                                0.52919301600963364,
                                0.08867434150580164,
                                0.88153515033139451,
                                -0.29200099043228667,
                                0,
                                0,
                                0.0090251728062332726,
                                0,
                                -0.35924488712758185,
                                -0.025094198608255347,
                                0,
                                -0.015942221704038036,
                                0.06846495613773193,
                                -0.52328104968032629,
                                0,
                                0,
                                0.078196184470444657,
                                0,
                                0.5462733731453977,
                                0.64552776618846297,
                                0,
                                0,
                                0,
                                0,
                                0.26449869065952536,
                                0.74363001011905183,
                                0,
                                -0.072497731370228857,
                                0,
                                0,
                                0.96825628378797535,
                                0.26064948806274135,
                                -0.88834407556394768,
                                0,
                                0,
                                0.096832844453267924,
                                0.23133961875900289,
                                0,
                                0,
                                0.21794984278982196,
                                -0.18030500502894045,
                                -0.17107870016701832,
                                0.12918972593241973,
                                0,
                                0,
                                -0.34275321803563091,
                                0.2484184029297917,
                                0,
                                0,
                                0.83930146241283898,
                                0.26537459725145307,
                                0,
                                0,
                                0.16596056402002679,
                                0.6183933274940786,
                                0,
                                0,
                                -0.09850621381884983,
                                -0.35830372691340101,
                                0,
                                0,
                                0,
                                0,
                                -0.37574794019700875,
                                -0.51158704039940639,
                                0,
                                0,
                                0.97961780924402064,
                                1.1089189861037219,
                                0,
                                0,
                                -0.4262875442304398,
                                -0.41695506580099267,
                                0,
                                0,
                                -0.27298883798999451,
                                -0.22806530779169715,
                                0,
                                0,
                                -0.27673672134264199,
                                0.66430979182317162,
                                0.61267460530478179,
                                0.13999416647467797,
                                0,
                                0,
                                0.16192638550890545,
                                0.40699964332200256,
                                0,
                                0,
                                -0.14872331063425598,
                                0.62533508957474992,
                                0,
                                0,
                                -0.68971855045342023,
                                0.65792559383950022,
                                0,
                                0,
                                0.20010155919486627,
                                -0.43262250100617894,
                                0,
                                0,
                                0,
                                0,
                                0.3125090030983273,
                                0.76224733985391824,
                                0,
                                0,
                                1.1756381891177379,
                                -0.67616985847355315,
                                0,
                                0,
                                0.22879815975459095,
                                -0.02548384520911497,
                                0,
                                0,
                                0.46159686603965111,
                                -0.73124342205537751,
                                0,
                                0,
                                0.38307923549232503,
                                0.22904948378898465,
                                -0.54162171528043257,
                                0.0074497122930587811,
                                0,
                                0,
                                0.74788294875105599,
                                0.36385552255893139,
                                0,
                                0,
                                0.051179922710851089,
                                0.1106855388275122,
                                -0.11938892866217807,
                                0,
                                0.3345539957125,
                                0,
                                0.64471637675739668,
                                0,
                                0,
                                0.40838685959065907,
                                0.50450619014474996,
                                0.19197494166119997,
                                0,
                                0.033823940997381181,
                                0,
                                0.16207148808674357,
                                0,
                                0.42912505643384591,
                                -1.1587331227149422,
                                0,
                                0,
                                0,
                                -0.89002936617157058,
                                0,
                                -0.20933658139398334,
                                0,
                                0.056664247475409213,
                                0,
                                0,
                                -0.36693580935906689,
                                0.10645561819290764,
                                0.12182117741070514,
                                0,
                                -0.469684905653936,
                                0,
                                -0.90665569137261826,
                                0,
                                -0.023921683742918053,
                                0.6951699664143226,
                                0,
                                0,
                                0,
                                0.060425453553944831,
                                0,
                                0.57920287997681075,
                                0,
                                0.23538063992634101,
                                0,
                                0,
                                -0.60271223114911965,
                                0.0045607894691528199,
                                -0.49212387501512567,
                                0,
                                -0.29327168538401349,
                                0,
                                0.60649082797458742,
                                0,
                                -0.12193860949338287,
                                0.81636977472860706,
                                0,
                                0,
                                0,
                                0,
                                -1.2174306536799659,
                                0,
                                0.077232682994604479,
                                0,
                                0.6219926429205801,
                                -0.13787399133056466,
                                0,
                                0,
                                0,
                                -0.25988954865752856,
                                0,
                                0.69664401661028208,
                                0,
                                -0.58085150292651477,
                                0,
                                0,
                                0.21224119530796198,
                                -0.048048480032850172,
                                0.24980209516428981,
                                0.3424120312303956,
                                0,
                                0.030531961755476067,
                                0,
                                -0.019421253167385077,
                                0,
                                0,
                                -0.53803206079461396,
                                0.2433928697754488,
                                0.72988083109848612,
                                -0.071792750296883118,
                                0,
                                0.15010248799438353,
                                0,
                                0.43354383563850091,
                                0,
                                0,
                                0.028132325148914492,
                                -0.82010435870638909,
                                0.33315491861153745,
                                -0.55254334423847073,
                                0,
                                0,
                                0.5267189809796331,
                                -0.030197489496264683,
                                0,
                                0.36378317418940964,
                                0.31481335540477912,
                                0,
                                0.43000631725258109,
                                0,
                                -1.0650197893004774,
                                0.12600212620852774,
                                0,
                                0,
                                -0.014582664928216166,
                                0,
                                0,
                                0.75455498570391055,
                                0,
                                0,
                                -0.14526194126927136,
                                -0.67085995984461577,
                                0,
                                0,
                                -0.41741173680732452,
                                0,
                                0,
                                -0.33164524128472772,
                                0,
                                0.43899141304330624,
                                0,
                                0,
                                -0.092398269271378564,
                                0.32010998950615921,
                                0,
                                -0.19204304147596438,
                                0.74889137442173181,
                                0,
                                0.31394246808239795,
                                0.44654024485978261,
                                0,
                                0,
                                -0.0058412836558526526,
                                -0.80160203388410944,
                                0,
                                0.23670410741559117,
                                0.0070283808258256864,
                                0,
                                0.31925481326713301,
                                0,
                                -0.80815370460654512,
                                -0.88231223717015583,
                                0,
                                0,
                                0.48581053740914193,
                                0,
                                0,
                                0.47870972933507738,
                                0,
                                0.5434214457522637,
                                0,
                                0,
                                0.65136908544180838,
                                0.31299414655585944,
                                0,
                                0.31811987025637289,
                                -0.20925926086776603,
                                0,
                                -0.19353661394713501,
                                -0.066056205548284952,
                                0,
                                0,
                                0.48681665048971551,
                                -0.38218921932047711,
                                0,
                                -0.57809111236338184,
                                0.29678335510341625,
                                0,
                                -0.43624286021639075,
                                0,
                                0.66269030866203649,
                                -0.16412308486545477,
                                0,
                                0,
                                -1.2232263024198327,
                                0,
                                0,
                                0.62535674741635849,
                                0,
                                0.053980660774530717,
                                0,
                                0,
                                0.229615804450301,
                                0.10008971164071997,
                                0,
                                -0.58254858328251347,
                                -0.45621822005824864,
                                0,
                                0.62197009898794464,
                                0.37278985681242804,
                                -1.2969798893587334,
                                0,
                                0,
                                0,
                                0,
                                0.84572444323242868,
                                0,
                                0.34356623165940547,
                                0,
                                0.12598093343861874,
                                0.11110022471633652,
                                0,
                                0,
                                0,
                                0,
                                -0.24748482355245482,
                                0,
                                0.54695677209614746,
                                0,
                                0,
                                0,
                                0.58919408094243542,
                                -0.34011704895412365,
                                0.25123011614337626,
                                -0.33211207376579249,
                                0,
                                -0.44132600479310385,
                                0,
                                0.41108038713620915,
                                0,
                                0,
                                0.48000031556274192,
                                0.093896031811297645,
                                0.015596404400279047,
                                0.05990158366127471,
                                0,
                                0.81525900867313283,
                                0,
                                0.30381661161255069,
                                0,
                                0,
                                -0.61837555999450078,
                                -0.14953928262000785,
                                0.33026941301629831,
                                -0.0019840554589408144,
                                0,
                                0.11910915008518859,
                                0,
                                0.68700863056498074,
                                0,
                                0,
                                -0.19141274098200298,
                                -0.052060851880480707,
                                -0.2676718917534211,
                                -0.91004502672518117,
                                0,
                                0.22678828640824597,
                                0,
                                -0.096890201450663543,
                                0.92559588333898779,
                                0.4852658707421873,
                                0,
                                0,
                                0,
                                0,
                                -0.098989012821051117,
                                0,
                                0.74859612694928757,
                                0,
                                0,
                                0,
                                0.058461293880616549,
                                0.91037654223216635,
                                -0.0093070654595583512,
                                -0.15253577668727047,
                                0,
                                -0.23823771410357159,
                                0,
                                0.29611794172737199,
                                -0.18659717673447362,
                                -0.32409473456268273,
                                0,
                                0,
                                0,
                                0,
                                -1.1545143495170149,
                                0,
                                0.36903874323107844,
                                0,
                                0,
                                0,
                                -0.0022668372493983291,
                                0.14712630706031726,
                                0.86938336344555989,
                                -0.18617282406669233,
                                0,
                                0.13493324780556543,
                                0,
                                -0.41189073405387155,
                                0.37864906628326844,
                                0,
                                0.61029378423127589,
                                -0.31211667139279309,
                                0,
                                0.040400724111070083,
                                0,
                                0.62054716612793681,
                                -0.0062097561988983738,
                                0,
                                0,
                                0.89292974024672322,
                                0,
                                0,
                                -0.78422368974513534,
                                0,
                                0.84176063886519392,
                                0,
                                0,
                                0.28610735441126733,
                                0.55488441320972481,
                                0,
                                0.38242387893481128,
                                0.19350207967795918,
                                0,
                                -0.39406876239962874,
                                0,
                                -0.59219858353506016,
                                -0.04922253668340569,
                                0,
                                -0.024881085992541602,
                                0,
                                -0.058389183197625094,
                                0.73529307391751986,
                                0,
                                -0.39341620925737325,
                                0,
                                0.46514694839496201,
                                -0.29013399143617197,
                                0,
                                0,
                                -0.37840495680140807,
                                0,
                                0,
                                -0.69160379746531686,
                                0,
                                -0.55555968477791717,
                                0,
                                0,
                                -0.3898020369769935,
                                -0.64533910078570944,
                                0,
                                0.37880834325861112,
                                -0.21354445517885268,
                                0,
                                -0.6002336784626493,
                                0,
                                -0.045307667497829808,
                                0.17918481029994834,
                                0,
                                0,
                                0.36028743741818525,
                                0,
                                0,
                                0.097726809209476129,
                                0,
                                -0.0919667099891643,
                                0,
                                0,
                                -1.1960397542116024,
                                -0.004349101363439356,
                                0,
                                0.17891084953420697,
                                0.43844613234407437,
                                0,
                                0.21323969643821516,
                                0,
                                0.041882585438502429,
                                0.85352894688389158,
                                0,
                                -0.36280522936413551,
                                0,
                                0.54989028363051673,
                                0.29436028730588271,
                                0,
                                0.53155398727487713,
                                0,
                                -0.20988909683783435,
                                -0.3908221953942263,
                                0,
                                0,
                                -0.085669775686261662,
                                0,
                                0,
                                -0.092613780364256271,
                                0,
                                0.54180727332893241,
                                0,
                                0,
                                -1.014418214528537,
                                0.11495573835419275,
                                0,
                                -0.79725474336249724,
                                0,
                                0,
                                0,
                                -0.34260538415562197,
                                -0.11172821204554298,
                                0.13256002619764687,
                                0.45137152019218668,
                                0,
                                -0.89402772963682431,
                                0,
                                0.55584048365401217,
                                0.5576533969605082,
                                -1.0163178402945152,
                                0,
                                0,
                                0,
                                0,
                                0.17823588915385313,
                                0,
                                -0.17052461893810156,
                                0,
                                0,
                                0,
                                0.73907949229958636,
                                -0.32779477979135641,
                                0.53377239992514836,
                                -0.023503906811912612,
                                0,
                                0.78073834272342124,
                                0,
                                0.1852143093738815,
                                0.009927668747254037,
                                -0.95778509602752737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38552903296272562,
                                0,
                                -0.72644744484792945,
                                0.34414806935521192,
                                0.038679064475389539,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2153707349638232,
                                0,
                                -0.044792683112043832,
                                0.13971872565957388,
                                -0.11919473501934703,
                                0,
                                0,
                                0,
                                0,
                                0.45180947711737951,
                                0,
                                0.37961366647008166,
                                0,
                                0,
                                0,
                                -0.43643706356280731,
                                0.13760170927757825,
                                0.66202624546186184,
                                0.063807288676828708,
                                -0.38623509489952007,
                                0,
                                0.40760162593506105,
                                0,
                                0,
                                0,
                                0.053554661615527327,
                                -0.27836702764542448,
                                0.048250914570263995,
                                0.77588588812098047,
                                -0.61372605079845011,
                                0,
                                -0.063982965374914103,
                                0,
                                0,
                                0,
                                -0.33708774971031674,
                                -0.4354117049106192,
                                0.36501941311190594,
                                -0.42754630040111202,
                                -0.47439237816726704,
                                0,
                                -0.14479912785677507,
                                0,
                                0,
                                0,
                                0.17149195774997444,
                                0.77075391904628687,
                                0.35166573922813604,
                                0.082735703681796363,
                                0.41569380066160289,
                                0,
                                0.072524305516888904,
                                -0.73867924340220514,
                                0.39882594209992456,
                                0,
                                -0.2962386066459351,
                                0,
                                0,
                                -0.17167533430325616,
                                0,
                                0.32366753671241083,
                                0,
                                0,
                                0,
                                -1.0581641709581142,
                                0,
                                -0.47753223492077362,
                                0.097318326309276532,
                                0,
                                0.24269230166553746,
                                0,
                                -0.30138783092701987,
                                0.40695741344448005,
                                0.63191929642235567,
                                0,
                                0.34102365367188586,
                                0,
                                0,
                                -0.41113544747360714,
                                -0.40536423053772014,
                                0,
                                0.62829083273891095,
                                -0.082783033188346386,
                                0.004111226848348172,
                                0,
                                0.16637942723538521,
                                0,
                                0,
                                -0.63747817493587333,
                                0.11267118361044544,
                                0,
                                0.65071317706786247,
                                0.24922101601776459,
                                0.45818350340984271,
                                0,
                                -0.00024170572177609206,
                                0,
                                0,
                                0.54021687268223262,
                                0,
                                -0.18301957263536017,
                                0,
                                0,
                                0,
                                0.72884716071672662,
                                0,
                                0.53408885369026138,
                                0.83547269482149156,
                                0,
                                0.68271839882290419,
                                0,
                                0.27024975276196012,
                                0.36638555516797738,
                                -0.40991461836366433,
                                0,
                                -0.27356889535346013,
                                0,
                                0,
                                -0.28939998125759803,
                                0,
                                -0.014506064440313451,
                                0,
                                0,
                                0,
                                0.51635421145578642,
                                0,
                                -0.66145217881873064,
                                -0.34582241748462178,
                                0,
                                0,
                                0.42591284577384758,
                                0,
                                0,
                                0,
                                -0.46100738894529847,
                                0,
                                0.58190979908305063,
                                -0.92038363752836139,
                                0,
                                -0.35380749525252941,
                                0,
                                -0.11266615417681229,
                                0.29246558526566385,
                                0.25226345630281011,
                                0,
                                -0.83272050703402822,
                                0,
                                0,
                                -0.13975042475964006};

const double rot_24_100[100000] = {0.47312444355132938,
                                   0.26711191580970683,
                                   0,
                                   -0.34603461114942424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27415909775984981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30866045097949046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24545845444185693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19577388443373456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074807022950294122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31190139283518414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089444487791710686,
                                   0,
                                   -0.029507967999882465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0035810634982896324,
                                   0,
                                   -0.16455323169539546,
                                   0,
                                   0,
                                   0,
                                   0.42096625218961514,
                                   0.064405361558745405,
                                   -0.078745985272306307,
                                   0,
                                   -0.037073513227363131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11056547234403591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45640458670689732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031968052822453463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14188627220693428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37503532046816501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15234990783571842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52192591815998512,
                                   0,
                                   -0.01133332000665976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1273638582035955,
                                   0,
                                   -0.24276509503644916,
                                   0,
                                   0,
                                   0,
                                   -0.48480871979460038,
                                   0,
                                   0,
                                   -0.2866972592793523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67115354015019535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16813038382362561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44437889188907859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34959163026874984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34554720891707508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074967898793627002,
                                   -0.12133341863322886,
                                   0,
                                   0.27911428058189214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19149025865134195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15284929878447465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59027873820525967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0062243859191490804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035677932988168203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39175039435121373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021078607887149242,
                                   0,
                                   0.53601581613057059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084336232167202846,
                                   0,
                                   0.074956060513283157,
                                   0,
                                   0,
                                   0,
                                   -0.194998755639406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0520001102957237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59745936257573984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078187216038689666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33985475498117595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60843227198801619,
                                   0,
                                   0,
                                   0,
                                   0.80210987697722991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54775387300913392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23522602155157829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.204834204305341,
                                   0,
                                   0,
                                   0,
                                   -0.18263319854949747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034576944343495009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43417436429158612,
                                   0.45620366504271853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13325722180384553,
                                   0,
                                   0.82960565537235287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093229207162877442,
                                   0,
                                   0,
                                   0,
                                   0.24330465391355727,
                                   0,
                                   0,
                                   -0.26374264718804585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86498469659901567,
                                   0.25875107440949996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54375395649978953,
                                   0,
                                   0.53290454366479589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43841001605755248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33905526263940233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084627610631508143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070296709718648709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29317851448347826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12298563979578292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14159052298814018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20628216678460504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6897010487407591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49123227506362116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12547069707419242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45239386704952811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49428526468449552,
                                   0,
                                   0.45056165631717515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11869773962309642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36253541980569221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2252155977639049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54291774783451763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20384903457579689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14184150196553064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40352702935650026,
                                   0,
                                   0,
                                   0,
                                   0.096972215551243787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11634645503857956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.200700727681389,
                                   -0.17345084374425801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48142080511045326,
                                   0,
                                   0.25144692401420821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36368437026666123,
                                   0,
                                   0,
                                   0,
                                   -0.94178893581425194,
                                   0,
                                   0,
                                   -0.22601938716946168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63258070905984909,
                                   -0.47627332531851913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2534326744462605,
                                   0,
                                   0,
                                   0,
                                   0.79760523891740542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73266736838654167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25694238262112418,
                                   0,
                                   0,
                                   0,
                                   -0.1938984015848251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72859496096474052,
                                   0,
                                   -0.071495840315376299,
                                   0,
                                   0,
                                   0.3405275433780241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28279433006803878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31752342443237075,
                                   0,
                                   -0.21490219103443151,
                                   0.23670300295503416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23292343977945301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11470709785285588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33924865342777488,
                                   -0.80593323519871252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24532195595684991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34530394124349428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22504736892712451,
                                   0,
                                   0,
                                   -1.5945982555465223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0667330182457959,
                                   -0.0082390926105459783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1224504330711922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55054130421736125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75356152268062893,
                                   0,
                                   0,
                                   0.27729515138004668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5794408225075055,
                                   0,
                                   0,
                                   0,
                                   0.55400747172766662,
                                   -0.1468913352654968,
                                   0,
                                   0.53086150493397111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28357227201659768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38428087561149837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19589024599550711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36009003627177666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11805190912183799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6895821867776778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31342867758633897,
                                   0,
                                   0,
                                   0,
                                   0.10733260838962966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18772369633977426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27354237552349597,
                                   0,
                                   0,
                                   0,
                                   -0.21733102708637581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33893976852026797,
                                   0,
                                   0.19923629417169464,
                                   0,
                                   0,
                                   0.65646327219681355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0031067721226288939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070381828858643747,
                                   0,
                                   0.59167466696902926,
                                   -0.43111797357692455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17929276595379451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71224781983218133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086364690835568747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016315863826810571,
                                   0,
                                   0,
                                   0,
                                   0.40622437279018464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54155275725116558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36802500289079121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15710487420629168,
                                   -0.032921959881683671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23257928516957582,
                                   0,
                                   0,
                                   0.094340683860314328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55657507545121632,
                                   0,
                                   0.11816978497247163,
                                   -0.53178996827242642,
                                   0,
                                   0.14503070812716218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34003747358490927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35647144977630146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28198389190442935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15262411357276007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20951343693540656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19365301371161756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071839181616213374,
                                   0,
                                   0.25620950521369906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37506797908959322,
                                   0,
                                   -0.0091209653357804,
                                   0,
                                   0,
                                   0,
                                   0.20912743119738678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22998248329651283,
                                   0,
                                   0,
                                   0,
                                   -0.26715387544864716,
                                   -0.31429667788582544,
                                   0,
                                   0.55241780696493914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53801120859212337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37624260611970983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53044307509834498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35405396983561188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50792250352522683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020206539154465776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76088297241308678,
                                   0,
                                   0,
                                   0,
                                   0.4769082638342042,
                                   -0.32303989314155074,
                                   0,
                                   -0.68613130454809979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86506512525205259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13992532419739886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28094220989815949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19922832015129249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47238279844836512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16503325133862445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36715254410841669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27852651729446809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19237114972980338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18317270285949827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48951667136548016,
                                   0,
                                   0,
                                   0,
                                   -0.35527664653396968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93956997070046033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4055686541484817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33895849191503741,
                                   0,
                                   0,
                                   0,
                                   0.12924544554756615,
                                   0.99280569529331608,
                                   0,
                                   0.22417648662067113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43176614653560746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2774574883006371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39239476769644754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64067707094030324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10424883410320074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34559453041610766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24202944406741841,
                                   0,
                                   0,
                                   0,
                                   0.45677994160671881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14380950696018976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24409637642493515,
                                   0,
                                   0,
                                   0,
                                   0.4735698599593971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69452319345379754,
                                   0,
                                   0.060920781998493406,
                                   0,
                                   0,
                                   0.20401250970375961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028535677536157503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21761060581511726,
                                   0,
                                   0.16592757497517341,
                                   -0.48145324978198994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00094128250049932416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54904688823885572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76182164187566415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11284470653760771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066603348511516308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35294795884246727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14126418646320324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50786811291435163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087279460287220445,
                                   0,
                                   0,
                                   0,
                                   0.79199452770727619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47794214500323778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0084950041942067969,
                                   0.2230380201020524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23366880272647325,
                                   0,
                                   0.45215965214934084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093169065728232511,
                                   0,
                                   0,
                                   0,
                                   -0.013074305442627498,
                                   0,
                                   0,
                                   0.70174501927402466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010197087665373587,
                                   0.77649617719187136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36524218137650705,
                                   0.66585144226748638,
                                   0,
                                   0,
                                   0.52228676804695873,
                                   0,
                                   0.22100308029407487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090882534950427946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20817948345183845,
                                   0,
                                   0,
                                   0.12357504715440239,
                                   0,
                                   -0.095753237065431734,
                                   0,
                                   -0.0013271899390739916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039823894649619287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14509573772869008,
                                   0,
                                   0,
                                   0,
                                   -0.054183871170207024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14791337272116442,
                                   -0.032759487230937995,
                                   0,
                                   0,
                                   -0.37702225412943829,
                                   0,
                                   0.44989648630463036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022801713834896181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58951492103533076,
                                   0,
                                   0,
                                   -0.054740177058713813,
                                   0,
                                   -0.1366567680114959,
                                   0,
                                   -0.31965645771297196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18576075935370245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34333631000718412,
                                   0,
                                   0,
                                   0,
                                   0.090605572240491955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37447987796743115,
                                   0,
                                   0.039539192702275357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43007551619410367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15146644524532812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33076253787092003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45464540983517437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23114650055221733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52986736992621819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18551662705629415,
                                   0,
                                   0,
                                   0,
                                   0.30721750576768964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43598953084149961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053969117668200339,
                                   0,
                                   0,
                                   0,
                                   -0.097686895085080411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14450597204453947,
                                   0,
                                   0.40246791945416338,
                                   0,
                                   0,
                                   0.19385643581046749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61082559628875921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0217679729121398,
                                   0,
                                   0.26287717096212843,
                                   0.44745730633622061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29998256023267611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40761415100840998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2253348051723833,
                                   -0.10783250055565259,
                                   0,
                                   0,
                                   0.32637104659732535,
                                   0,
                                   -0.48532097937726942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24254676655494972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050645419210781042,
                                   0,
                                   0,
                                   0.075533074632032238,
                                   0,
                                   -0.087275248416011211,
                                   0,
                                   -0.23521493067406468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29153964750832628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49265936822581335,
                                   0,
                                   0,
                                   0,
                                   0.37120220195523296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17078237342274769,
                                   -0.51983816566595309,
                                   0,
                                   -0.44245701001454013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38439283802240032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25003137746288534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14123421028036728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22011281307626857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35793618989956477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0081684991004667869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16454049766329792,
                                   0,
                                   0.061871345894851458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23451020518098895,
                                   0,
                                   -0.040402506606514135,
                                   0,
                                   0,
                                   0,
                                   0.10222075305804271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0040913893284011266,
                                   -0.28791053744128459,
                                   0,
                                   0,
                                   -0.029609240082639366,
                                   0,
                                   0.27373375566258618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43104567311406267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10888264451858932,
                                   0,
                                   0,
                                   0.73498623630066851,
                                   0,
                                   -0.28100105219719995,
                                   0,
                                   0.070719069087644526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11561418736615661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074090643967683445,
                                   0,
                                   0,
                                   0,
                                   0.024586476458474518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48012414545439347,
                                   0,
                                   0,
                                   0,
                                   0.084880284731799718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51920445451905384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54982224686759273,
                                   0,
                                   0,
                                   0,
                                   0.2138212845295196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15381028599693716,
                                   0,
                                   0.37078425905229073,
                                   0,
                                   0,
                                   -0.30257753925337777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38773879584724769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044739018762139385,
                                   0,
                                   0.03277692661747849,
                                   -0.36065635457227058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67123135496416308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13030948590461863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1669301735623625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1010516563957482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12863163387653023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52637302304018929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96628321017036278,
                                   0,
                                   0,
                                   0,
                                   -0.49258646647027365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33073600409049708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37514303600286636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42549313113028431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35411219798007643,
                                   0,
                                   0,
                                   0,
                                   0.22986629500795486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16982177047606734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18453660713299891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05616681477455656,
                                   -0.11932903543361179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36725305849858347,
                                   0,
                                   0,
                                   0.61792611929012131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20910956999918751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53580478563422407,
                                   -0.48454237203505518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68979864562260884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52948951551490608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11941497887625786,
                                   0,
                                   0,
                                   0.16164756503849106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027299860214648856,
                                   0,
                                   -0.055227413800133823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34251505723883002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57288472255671163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43511262724245192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51785795619635322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07447899993259173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29604762794246064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07915754834489043,
                                   0,
                                   0,
                                   0,
                                   0.4709379919058313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26724693530744154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45747222295691176,
                                   0,
                                   0,
                                   0,
                                   -0.47762881574578331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21173655639262715,
                                   0,
                                   -0.085993859270710737,
                                   0,
                                   0,
                                   -0.25308409355360606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59406300744130158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43364728916580825,
                                   0,
                                   0.52863060613386592,
                                   -0.1140004714644864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48574087378488251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31489115879612306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24555963949746026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.247610307868632,
                                   0,
                                   0,
                                   0,
                                   0.19381937661652851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32422768308018796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39110892048305995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11519388869674366,
                                   0.53143906155740017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38905432183666083,
                                   0,
                                   0,
                                   0.27812273820262978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24149790680435529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46635904330905614,
                                   0,
                                   0,
                                   0,
                                   0.32636919466017739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38891475483501009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30917218989589479,
                                   0,
                                   0,
                                   0,
                                   -0.0083665692135663876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044812278706602794,
                                   0,
                                   0.42995669322362928,
                                   0,
                                   0,
                                   -0.87681225001723229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026090203890113718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062240868025034951,
                                   0,
                                   -0.045381824009753415,
                                   0.071727453663384885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21667565346955966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49974195571333024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20272550783076093,
                                   0,
                                   0,
                                   0,
                                   0.17729439784737949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35291967582014894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92750993116961455,
                                   -0.72280736264949164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45109720377884877,
                                   0,
                                   -0.08682569711274675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24687125518488368,
                                   0,
                                   0,
                                   0,
                                   -0.30656179359105229,
                                   0,
                                   0,
                                   -0.64258557560589669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010267434074717603,
                                   0.31342951919917511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11457250141714553,
                                   0,
                                   0,
                                   0,
                                   0.57030453014452132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29609984065993905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26441702905179665,
                                   -0.49535738401709267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29281418664510223,
                                   0,
                                   0.34202870772632776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27749410700783322,
                                   0,
                                   0,
                                   0,
                                   0.71656337984806462,
                                   0,
                                   0,
                                   0.49045940769902346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54560057196899581,
                                   -0.20672436334092822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6975889623631002,
                                   0,
                                   0,
                                   0,
                                   -0.57161098235389496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37579117901173859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.509647692815554,
                                   0,
                                   0,
                                   0,
                                   0.248980799695219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54173964894878879,
                                   0,
                                   -0.19087060553340199,
                                   0,
                                   0,
                                   -0.1978235073216934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22304290025934898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37245385970346623,
                                   0,
                                   0.39846741134711428,
                                   0.10634354673895538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075928092322870733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14940679643612026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12556002566765567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27010266166137192,
                                   0,
                                   0,
                                   0,
                                   0.12597514673543886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10220357055479926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46399532255694498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20050517102246407,
                                   0.70661290556963008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24770495314037616,
                                   0,
                                   0,
                                   -0.17890952944466398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19183789999164549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055451649714402723,
                                   0,
                                   0,
                                   0,
                                   -0.19044634113787876,
                                   -0.42378082754172675,
                                   0,
                                   0.0076720871252888567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11190627500409134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43382017230047026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1977001303730364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21830247887926171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42820155493707535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19998973612884682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36566394004372116,
                                   0.11445933549877343,
                                   0,
                                   0,
                                   -0.044636114120516109,
                                   0,
                                   -0.31686026478966062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20201735636452711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34942356917323708,
                                   0,
                                   0,
                                   -0.070393891911765635,
                                   0,
                                   -0.502469080850656,
                                   0,
                                   0.27660058949815719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41304774156040142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1669252158851465,
                                   0,
                                   0,
                                   0,
                                   -0.23553654189888135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053833196409895472,
                                   0,
                                   -0.099240038067057945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31630266730115614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36108729562310998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7441498233324304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22341968208750579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022484779673689708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39069311509132248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078309223490571789,
                                   -0.2656420794244172,
                                   0,
                                   -0.21805389852690105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17118352225393019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23831321024056637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16634435443641221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017044193086695469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52936805424827926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15792458488004016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51550862010603016,
                                   0,
                                   0.19871053459514038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32206796705072682,
                                   0,
                                   -0.20032316891319543,
                                   0,
                                   0,
                                   0,
                                   0.086218574105937709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38437338374171193,
                                   0,
                                   0,
                                   0,
                                   0.04413422586212587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19050907170062439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62857558120516122,
                                   0,
                                   0,
                                   0,
                                   0.21793950239202894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30384365261420831,
                                   0,
                                   0.30008155255401026,
                                   0,
                                   0,
                                   -0.27241660220614033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18029235987785697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027280512526413281,
                                   0,
                                   0.54842540992482391,
                                   -0.36985152570710561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42560067775085697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06255653917867382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10599672453614434,
                                   0,
                                   0,
                                   0,
                                   -0.089639478884549761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75717780011821312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82761692596367076,
                                   -0.313620875685172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054325696664174375,
                                   0,
                                   0.93386516028188571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13652393623934922,
                                   0,
                                   0,
                                   0,
                                   0.038675043563011713,
                                   0,
                                   0,
                                   -0.70840281300341457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31674274805375729,
                                   0.31585731306188564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53197406254527746,
                                   -0.81245805161352036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69650674486002961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.004993910173857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34817629436819381,
                                   0,
                                   0,
                                   0.46468059436162457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5008086913554225,
                                   0,
                                   0,
                                   0,
                                   0.53348615112344755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86016891806538953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087659490912453272,
                                   0.022099370898581355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78296082747897,
                                   0,
                                   -0.31331068349934921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50905713559699406,
                                   0,
                                   0,
                                   0,
                                   0.50719344325402349,
                                   0,
                                   0,
                                   -0.15088619227233988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16616829240344633,
                                   0.6840908374796858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017895117857092642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20741611418395417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52214511902651795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93409387291628099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35032829623539874,
                                   0,
                                   0,
                                   0,
                                   0.11718335632719745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10920115424424939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034508179807829401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41036671501967181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051111615032348956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1342648997672079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052146095064465735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81386958698041356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38191200408092851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21831657425201714,
                                   -0.23110231135487241,
                                   0,
                                   -0.2739162556274361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47020002954665729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015741378941689352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22101888857286506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4337228740925162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15288697654809677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21813867323009348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16181597568684369,
                                   0,
                                   -0.34342712890957078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00053863827264032105,
                                   0,
                                   0.22018258150430309,
                                   0,
                                   0,
                                   0,
                                   -0.31942537475657029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10648556660959065,
                                   -0.095994620749363962,
                                   0,
                                   0,
                                   0.089013374741833434,
                                   0,
                                   0.010881059389987791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31204018585891308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23925384312733983,
                                   0,
                                   0,
                                   0.1159263185846684,
                                   0,
                                   0.0041256509711160051,
                                   0,
                                   0.7775998090163827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15752227512247802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38235048322503912,
                                   0,
                                   0,
                                   0,
                                   0.16634315438739111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88373512116886177,
                                   0.58265066272043509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69468873913192253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30438736902026459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79625817410263355,
                                   0,
                                   0,
                                   -0.46487027277579429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87908599813353827,
                                   0,
                                   0,
                                   0,
                                   0.55598874785487107,
                                   0.20122089331321452,
                                   0,
                                   -0.30340900232068352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20438808339427025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84243066494607444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13272634370323516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4705233826200268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39954978530244323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04263508820252393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38698714541004864,
                                   -0.24310883049374418,
                                   0,
                                   0,
                                   0.41262639240701526,
                                   0,
                                   0.24257377084290332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092185083835597023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22104648041711841,
                                   0,
                                   0,
                                   -0.085486428847821053,
                                   0,
                                   0.080015971420090995,
                                   0,
                                   -0.047653760245135054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1214788035170284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35450149845474899,
                                   0,
                                   0,
                                   0,
                                   0.59014155712799299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46981997192673935,
                                   -0.1758816342029498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63675099208037222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61020975610623795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3048021373740069,
                                   0,
                                   0,
                                   0.20436192414861098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066365995909405603,
                                   0.34414664153315183,
                                   0,
                                   0,
                                   -0.39227913659098929,
                                   0,
                                   -0.16678769304537544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50080508572898508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16981718159130726,
                                   0,
                                   0,
                                   0.040262837909121191,
                                   0,
                                   0.47319512366879607,
                                   0,
                                   0.18848246107314623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081556299054708098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09326473527351356,
                                   0,
                                   0,
                                   0,
                                   0.37336828872180589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46405166336154446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23375964832989438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49608323528433229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22092208373685879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21071544139780213,
                                   0,
                                   0,
                                   0,
                                   -1.0201572388419189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62033800529501504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074408001805498489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087469008074999632,
                                   -0.29937787965571033,
                                   0,
                                   0,
                                   0.19656060156703054,
                                   0,
                                   -0.0082498113667764383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46839209809409532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22030445255009518,
                                   0,
                                   0,
                                   -0.48675594421099877,
                                   0,
                                   -0.14499894732587881,
                                   0,
                                   0.017148955979510369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56729032620428854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03307076168816564,
                                   0,
                                   0,
                                   0,
                                   -0.12219082955654574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19741406457514532,
                                   0,
                                   0,
                                   0,
                                   -0.30927578288394275,
                                   0.25831411494570122,
                                   0,
                                   -0.47046082077093998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7662372028945057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20402652003528771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39683247562776136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65866505939974807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21670834410097226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48836170370053933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031804054230036335,
                                   0,
                                   0,
                                   0,
                                   0.0083986187525915725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30238625036455363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25999137352980745,
                                   -0.18934497900343547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40369776955424408,
                                   0,
                                   0.51378746848421752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67145496271470173,
                                   0,
                                   0,
                                   0,
                                   0.0026577925794382517,
                                   0,
                                   0,
                                   -0.12120314767383134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48276596286391249,
                                   -0.51467114037072526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12763304638708683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84720938961040493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83729382977429601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30121216980848164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078803335616862757,
                                   0,
                                   0,
                                   0,
                                   0.56361501916802748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0055080428875072945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13953383294057986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18520882167778654,
                                   -0.09673419930405712,
                                   0,
                                   -0.2055388015233196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16405290502952188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15189232379537784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1659995066770287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30628421906189729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40612030805982535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27469894443881238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14085581295334842,
                                   0,
                                   0.25027885926214416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51128911158203438,
                                   0,
                                   0.26324977721391135,
                                   0,
                                   0,
                                   0,
                                   0.29858568691398008,
                                   0,
                                   0,
                                   -0.093928509482977346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12931971976317352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68509718050862778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30605169331185256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37637780460379627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51939176703947187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33254647244084384,
                                   0,
                                   0,
                                   0,
                                   -0.28554813557146114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.912603128382388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16141267169744422,
                                   0.029313603750753918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3723462908702681,
                                   0,
                                   0.13186901536956103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031559529111428258,
                                   0,
                                   0,
                                   0,
                                   0.43469055042877269,
                                   0,
                                   0,
                                   -0.68281529150169307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15946982137901877,
                                   0.16762192619003929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57403600470531224,
                                   0,
                                   0,
                                   0,
                                   0.51127887905221869,
                                   -0.1420778218374586,
                                   0,
                                   -0.11660292491194851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21232268373173954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86897183499242958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016224095572634989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73337055879184243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78662455303377921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16220652438550842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10857243138453718,
                                   0,
                                   0,
                                   0,
                                   -0.036323844337773845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035036453655266808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28023100957768826,
                                   0,
                                   0,
                                   0,
                                   0.69339451537981422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14404824163955943,
                                   0,
                                   0.44993889092165579,
                                   0,
                                   0,
                                   0.38120246809115421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6330723442834042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23047780319976974,
                                   0,
                                   0.11522862176400148,
                                   0.96552989235347841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079414785719697609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40725511997243774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49184272109213784,
                                   0,
                                   0,
                                   0,
                                   -1.0004669777253803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066284272366602698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39664784093487815,
                                   0.13387579229467722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0040032455135848,
                                   0,
                                   -0.33766374989696946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089917976697794819,
                                   0,
                                   0,
                                   0,
                                   0.067797199140228456,
                                   0,
                                   0,
                                   0.68769683508670287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13866960569143974,
                                   0.11619540225070206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26194602478234785,
                                   0,
                                   0,
                                   0,
                                   -0.16889338941789511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55584639032574956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55308097473742501,
                                   0,
                                   0,
                                   0,
                                   0.33918463251020581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17689609513933163,
                                   0,
                                   -0.24151953022423328,
                                   0,
                                   0,
                                   0.0090777274541240238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68801416973937812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61612665768743446,
                                   0,
                                   -0.51187932683142012,
                                   -0.11927212653635273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020184131978498804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42450206459637474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043073139870947338,
                                   0,
                                   0,
                                   0,
                                   -0.13583976256555982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037118250735084173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057183485122762438,
                                   0,
                                   0,
                                   0,
                                   0.10544514595562818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1957484268670921,
                                   0,
                                   0.76114252038745933,
                                   0,
                                   0,
                                   0.21668176650524137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0013071768260792135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087085335113613632,
                                   0,
                                   -0.53827269756663298,
                                   -0.36567794075509197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45140963549889046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43554394253900447,
                                   0,
                                   0,
                                   0.025738246526840286,
                                   -0.10285705479786562,
                                   0,
                                   0.046137781296054878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52378047599851418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57772960294221443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24676848179441813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14154065540258798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34716109194777306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054854317654957178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21000043363910209,
                                   0,
                                   0.0085203990965734694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21737135896412269,
                                   0,
                                   0.27474935824865732,
                                   0,
                                   0,
                                   0,
                                   -0.084517663101264823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29981344405624927,
                                   0,
                                   0.25126570427371497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32650480281955763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25421215837269762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04681692230397614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046180822822494708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78453902547582766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23647888232372993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1237175270242345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37002404171607173,
                                   0,
                                   0,
                                   0,
                                   -0.47919890305093205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2799334365079898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30381573480870122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25550603574832381,
                                   0.23459958789885418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20956312066329255,
                                   0,
                                   0,
                                   -0.22606684903652396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48180352952193006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0066082970461731781,
                                   0,
                                   0,
                                   0,
                                   -0.22738324462147397,
                                   0.28386534799777008,
                                   0,
                                   -0.44369649539688361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21599615118979887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21387881180536447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13999191095558561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14516758352414816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69809605756348014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8046393714206691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62658414417040342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63089091925039686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57033418805559288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18794840764182394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86897331078212015,
                                   0,
                                   0,
                                   0,
                                   -0.3577036634805647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019902293937159241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54073980703774749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08231784265405806,
                                   -0.24169671953683391,
                                   0,
                                   0,
                                   0.25607344088626133,
                                   0,
                                   -0.15619768104911089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0097481841990400345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42881848355840224,
                                   0,
                                   0,
                                   0.29126935882768523,
                                   0,
                                   0.57177111880088405,
                                   0,
                                   -0.10830072422133007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085301709415478572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016182392291763714,
                                   0,
                                   0,
                                   0,
                                   -0.47940325083785718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47036635674573712,
                                   0,
                                   0.15989005512524004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032262732865261989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4356932325229419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077647282088521091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040026900469901407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44360904188877404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59824823333890964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19955902687788274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40547594367275908,
                                   0,
                                   0,
                                   0,
                                   -0.31192250726279103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21630846754314603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12994702801845529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44805532850547769,
                                   0.1122168814534264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55464536385703678,
                                   0,
                                   0,
                                   0.23197272906180227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24495956313985986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09428469451998675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28921023151039826,
                                   0,
                                   0,
                                   0,
                                   0.12711917039511159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085433208762482449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21655203892323477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73474978397379109,
                                   -0.027306555379566576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44461349417598539,
                                   0,
                                   0,
                                   -0.13984655404776319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28155607837005825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76682468099007495,
                                   0,
                                   0,
                                   0,
                                   -0.79611205816791464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28611264193462682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44648825593624403,
                                   -0.22927746478912678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03119843763246705,
                                   0,
                                   0.55242781513578876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14065484774596645,
                                   0,
                                   0,
                                   0,
                                   0.45190929047495776,
                                   0,
                                   0,
                                   0.13188763031877404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071800480396755878,
                                   0.3061139482904135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23526940992206113,
                                   0,
                                   0,
                                   0,
                                   -0.44650651663141239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22332212757177422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41898729926201517,
                                   -0.99590868861942017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52156490248945586,
                                   0,
                                   -0.2479227345286423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56715083786997733,
                                   0,
                                   0,
                                   0,
                                   0.14752156244297082,
                                   0,
                                   0,
                                   0.057342395119922132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013115766281400418,
                                   0.50003337407363557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17631630205388532,
                                   -0.30455364266994689,
                                   0,
                                   0.48096117798721905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10241188342461066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016912248011802692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045627851925948412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39287704127960416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21544685820352105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.008385814128134406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09388178789123075,
                                   0,
                                   -0.12431481978406894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50278968337049723,
                                   0,
                                   -0.3892399391373581,
                                   0,
                                   0,
                                   0,
                                   0.050662275638338958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070729249292831281,
                                   0,
                                   0.64019189090136996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53266531971383402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13279367265608927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28532326053543144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41444927881116794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026834189800881689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17288022542596052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062607703955388422,
                                   0.33113849147675373,
                                   0,
                                   -0.10795337817440108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034796781765463559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011201307722158205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037692370405885182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37232272479763812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016899497849123032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5539397404649834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0097784405342854763,
                                   0,
                                   0.56745062098507171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041288997828915722,
                                   0,
                                   -0.27261796847402808,
                                   0,
                                   0,
                                   0,
                                   -0.16773919988774766,
                                   0,
                                   0,
                                   0.37438107003665139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68915214452695805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064987855156958915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58331735489239889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19504683907872783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048808901041855673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42000230812793998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48762115270782286,
                                   0,
                                   0,
                                   0,
                                   -0.11599113432587305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54561473044008246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16388788776015523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072234050028757338,
                                   0.13788449639997552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032031592484565045,
                                   0,
                                   0,
                                   -0.24889988166011867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40075926588246991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60099289633127839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42716547715697928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13021050920960664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37985675671819008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29111513520023402,
                                   0,
                                   0,
                                   0,
                                   -0.79445856068368947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19641305114233518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0607870814377629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.518052480063943,
                                   -0.19995448599137625,
                                   0,
                                   0,
                                   -0.19812382595430586,
                                   0,
                                   -0.39569511923952438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25815873340881046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27471643339279289,
                                   0,
                                   0,
                                   0.1317488809641531,
                                   0,
                                   -0.14256107240748322,
                                   0,
                                   -0.081810291714848229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12836651088836376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51580430705735969,
                                   0,
                                   0,
                                   0,
                                   0.16367867329358721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33786511622458404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34019430272900752,
                                   0,
                                   0,
                                   0,
                                   -0.38432607060950258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19454884061070704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32839613996452655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30818454991182215,
                                   0.24706171300152874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12888047520590568,
                                   0,
                                   0,
                                   0.55102532828645412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021421923687384048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56947131888828506,
                                   0,
                                   0,
                                   0,
                                   0.33237058129472474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72336867671339178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50613342226686064,
                                   0,
                                   0,
                                   0,
                                   0.86437757749966293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36184613394175991,
                                   0,
                                   -0.19731769430662729,
                                   0,
                                   0,
                                   0.060291672044677988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26781311641737066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31325853536350484,
                                   0,
                                   -0.082786618226396214,
                                   -0.10084349589180934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088164814556013799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24843370053713273,
                                   0,
                                   0,
                                   -0.26431291767712767,
                                   0.024901681120890421,
                                   0,
                                   -0.30722028677214597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15286348445350517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16649029331656712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48533866096109485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19102837856783009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096279942575585933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46281655826362161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37914086541879843,
                                   0,
                                   0.25530468717597965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18935311681645667,
                                   0,
                                   0.070462103196670137,
                                   0,
                                   0,
                                   0,
                                   -0.19694105571833009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46033580510481137,
                                   -0.27049475135860229,
                                   0,
                                   0,
                                   0.012410993123449949,
                                   0,
                                   0.26469751046688333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25094842236201031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17258608152998717,
                                   0,
                                   0,
                                   -0.26338662566067006,
                                   0,
                                   0.18573836352963893,
                                   0,
                                   0.31592532628039993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55058341853936255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19243065568808393,
                                   0,
                                   0,
                                   0,
                                   -0.08995521628245054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24051900018254252,
                                   -0.064434473620919905,
                                   0,
                                   -0.25029711748987876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082587042873372415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077857182140716588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2854169496085267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38638862560255144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15974712494367951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095256431654223664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38975961348155452,
                                   0,
                                   -0.13570971650294619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076542105742947231,
                                   0,
                                   -0.63666013838384472,
                                   0,
                                   0,
                                   0,
                                   -0.12486535005334964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51071775200183078,
                                   0,
                                   0,
                                   0,
                                   -0.48443269524999905,
                                   -0.5793878117306539,
                                   0,
                                   -0.26723671580734149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041526247395521729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082080960940635633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06819853152194473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38665879540342418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76178756304204953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39591325327192339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5300472823503477,
                                   0,
                                   0,
                                   0,
                                   0.084860264257681367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52482376626511895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34175218916537731,
                                   0,
                                   0,
                                   0,
                                   0.27323196199190158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011721202291194527,
                                   0,
                                   -0.4633626277841158,
                                   0,
                                   0,
                                   0.019645957105150658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023355976474662844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35024986844775746,
                                   0,
                                   -0.16178784334031893,
                                   0.036677939632646858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6301741575175388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25637705440301461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61713666883893936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039929799612030241,
                                   0,
                                   0,
                                   0,
                                   -0.47377269077786149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30710977915831833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41407452224310065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11225756221949347,
                                   -0.23349643235518927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17732884081098593,
                                   0,
                                   0,
                                   0.099255124764641198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13745476474617488,
                                   0,
                                   -0.6868604009637943,
                                   0.060063452239596443,
                                   0,
                                   0.13120845664630362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13792072265298153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18814113196381146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073128686087986255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29789922799970758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099568572727475602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085350848441305027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16269732256028052,
                                   0,
                                   -0.03200531813976764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26901956356806528,
                                   0,
                                   -0.19268278076461762,
                                   0,
                                   0,
                                   0,
                                   0.45243445868346815,
                                   0.25355361412390548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045551470810358492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19060379677715916,
                                   0,
                                   0,
                                   0,
                                   -0.47543994303768483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61978287432133072,
                                   0,
                                   0,
                                   -0.025545055182275893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08843282360457462,
                                   0,
                                   0,
                                   0,
                                   0.14724524507584963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086307806630799788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22358767988279585,
                                   0,
                                   0,
                                   -0.30854754857846478,
                                   0,
                                   -0.32301039618130151,
                                   0,
                                   -0.68277632857256076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42160413256590079,
                                   0,
                                   0,
                                   0,
                                   0.075921409925034058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086568134593689672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042110503952072664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0400487783938133,
                                   0,
                                   0,
                                   0.079726497907312802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11033550164796221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58288034488043783,
                                   -1.0850095300622629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22559703897156927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65981511377663171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24212601475634188,
                                   0,
                                   0,
                                   0,
                                   0.52824857933382652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47112128674356812,
                                   0.057929435941435431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16198437000000007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.539132886108184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.087345074963969,
                                   0,
                                   0,
                                   0,
                                   0.86996034233032515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48513821429440246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23283065627541283,
                                   0.21423351716668498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5815719641262338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053173035431333893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33504443292466579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78540405722542528,
                                   0,
                                   0,
                                   0,
                                   -0.01906244077599123,
                                   0,
                                   0,
                                   0.064444973383772045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12266953749455184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46880759584739962,
                                   0,
                                   0,
                                   -0.068002293212214016,
                                   0,
                                   0,
                                   0,
                                   0.17013613489756363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58534759641638412,
                                   0,
                                   0,
                                   0,
                                   0.22145785591667239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079885516961409164,
                                   0,
                                   0.062996812903984081,
                                   0,
                                   0,
                                   -0.090910906334074351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067803548845082245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31202205467193034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14582869636337156,
                                   0,
                                   0.24757783953415169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38888807777106865,
                                   0,
                                   0,
                                   -0.024668358068617155,
                                   0,
                                   0.66858795363000156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096705890943068168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080872786712746864,
                                   0,
                                   0,
                                   0,
                                   0.22277176574604818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1966335123026248,
                                   0,
                                   0,
                                   -0.01086732352042824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084875099043515187,
                                   0,
                                   0,
                                   0,
                                   -0.16702542272526291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44249123977550081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44399141101798234,
                                   0,
                                   0,
                                   0.13351800996257807,
                                   0,
                                   0.053220402085356833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071549602520102895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59510841624296607,
                                   0.51091592362384142,
                                   0.4939889887342549,
                                   0.30552597262815462,
                                   0.20571899606631058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57586314133073102,
                                   0,
                                   0,
                                   -0.042482299731822437,
                                   0,
                                   0,
                                   0,
                                   -0.35321142659744342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48108829808999826,
                                   0,
                                   0,
                                   0,
                                   -0.17460472947890882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18338172430294,
                                   0,
                                   0.043333453350990474,
                                   0,
                                   0,
                                   -0.12203010457298274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0070560010014073683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16413827597922029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094190765130829412,
                                   0,
                                   0.3734897414536601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19734160086601812,
                                   0,
                                   0,
                                   -0.1232334201057091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1012713667402685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52658794164669931,
                                   0.15849490952970924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49429172810244065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1279666321947637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98597831345738096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042847778784991498,
                                   0,
                                   0,
                                   0,
                                   -0.3547590375235774,
                                   0,
                                   0,
                                   -0.28039733198371608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78798484077887088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50285352890460433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22272516872479303,
                                   0.066324793150796063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23966995738370109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097108246054954661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64346685704405282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15475579191554029,
                                   0,
                                   0,
                                   0,
                                   -0.87262353101677992,
                                   0,
                                   0,
                                   -0.010959426893336996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11703135513480445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37035124666792163,
                                   0,
                                   0,
                                   0.58507291567846187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48088082030808343,
                                   0,
                                   0,
                                   -0.45370587919309724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64012222177027511,
                                   0,
                                   0.4276343701793745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23251029200743092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12087015219534716,
                                   0,
                                   0,
                                   0,
                                   0.21015079936745806,
                                   -0.55121239378826181,
                                   0,
                                   0.11465325016218732,
                                   0.037941839877453309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29180368696120318,
                                   0,
                                   0,
                                   -0.17523647063641412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03604128885638852,
                                   0,
                                   0,
                                   0.17778770628325766,
                                   0,
                                   0,
                                   0,
                                   0.11102655675529588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13716038011033399,
                                   0,
                                   0,
                                   0,
                                   -0.14849403648737597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18476126822921224,
                                   0,
                                   -0.024063698521654169,
                                   0,
                                   0,
                                   0.19040576701052828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81958513966994306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33444193295015129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15049878659918478,
                                   0,
                                   0.18530729734025417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034721529125533251,
                                   0,
                                   0,
                                   -0.03415547575929348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98762952722897634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061031404844556048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30818192648208126,
                                   0,
                                   0.37576867829531552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1498213153299735,
                                   0,
                                   0,
                                   -0.08474735954910334,
                                   0,
                                   -0.065465108885668574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5395549569754321,
                                   0,
                                   0,
                                   0.036611797968524262,
                                   0.16037050930439811,
                                   0,
                                   0,
                                   -0.78652949050877008,
                                   0,
                                   0,
                                   -0.099497051382688773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44601290536395527,
                                   0,
                                   0,
                                   -0.30034314303250209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19278491937444989,
                                   0,
                                   0,
                                   0.19325411754735528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43137177817949901,
                                   0,
                                   -0.027258665513901159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59618142005315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5147412614591671,
                                   0,
                                   0,
                                   0,
                                   0.61625234408200313,
                                   -0.0645901486831542,
                                   0,
                                   0.2849302111039731,
                                   -0.63294229565293947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27383652919806084,
                                   0,
                                   0,
                                   -0.64291038623531094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11431083111877985,
                                   0,
                                   0,
                                   -0.094205984649022773,
                                   0,
                                   0,
                                   0,
                                   0.36333960102699414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58045776231273916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19630192196173296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052168323222211536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3897444029420768,
                                   0,
                                   -0.33937159081175111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36166020338102711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26454400266043843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3528781682347199,
                                   -0.72370086738019557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27654638225511563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43892790930832926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69425649501433084,
                                   0,
                                   0,
                                   0,
                                   -0.9410267194054428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09455762959902636,
                                   0,
                                   0,
                                   0.23450288885817133,
                                   0,
                                   0,
                                   0,
                                   0.15881738401779186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26967298449897953,
                                   0,
                                   0,
                                   0,
                                   0.37067924072615921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26088017909708755,
                                   0,
                                   0.062363693098352935,
                                   0,
                                   0,
                                   0.049452739547530773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0035161250762615337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019126914771188674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32476571461254167,
                                   0,
                                   0.48007254669025384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43165639752728791,
                                   0,
                                   0,
                                   -0.32198840312402088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19975609421125834,
                                   0,
                                   0,
                                   0.046352795990242231,
                                   0,
                                   0,
                                   0,
                                   0.12814587317570264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094479935927613001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54874413392757648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10299961776507931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10996832614796055,
                                   0,
                                   -0.050477005492057012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39977488744135548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66814005326491588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10780908552336364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46362009285372296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58223422236782452,
                                   0,
                                   0.10702666008854231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66806810838820618,
                                   0,
                                   0,
                                   0.58587322155351895,
                                   0,
                                   0.051514202272129495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6145522482687662,
                                   0,
                                   0,
                                   -0.0015150251835656381,
                                   0.50236225451647309,
                                   0,
                                   0,
                                   0.53813623749260919,
                                   0,
                                   0,
                                   -0.48637306379237122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018484400024643931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41425799426724325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13878442514714129,
                                   0,
                                   0,
                                   0,
                                   -0.38463517205796788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037905730996417565,
                                   0,
                                   0,
                                   0.40254778151152604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52602372735126335,
                                   0,
                                   0,
                                   0,
                                   -0.3013271627138227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066626118115357472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15920374733244178,
                                   0,
                                   0,
                                   0.19258246313263935,
                                   0,
                                   -0.25097778674610338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22151293270443023,
                                   0,
                                   0,
                                   0.15457678764543892,
                                   0,
                                   0,
                                   0,
                                   0.2476261353250028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4151756606495105,
                                   0,
                                   0,
                                   0,
                                   0.45256750218547875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30371412938662273,
                                   0,
                                   -0.26659103948585194,
                                   0,
                                   0,
                                   -0.26406334863212216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11013415503738312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30264625665235351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10052226632128849,
                                   0,
                                   -0.28123879257308476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24730535604930962,
                                   0,
                                   0,
                                   0.037475886236643802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44560787157159798,
                                   0,
                                   0,
                                   -0.40506441535844834,
                                   0,
                                   0,
                                   0,
                                   -0.20735199790996628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38394453898141923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36622350237170898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17677348346056326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36332578804732973,
                                   0,
                                   0.22964574454459485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20251964083430263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23626820530352072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018681089132106296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1029403524048282,
                                   0,
                                   0,
                                   0,
                                   -0.095221243381338472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0225804334742363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08726648944140919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0270545184879496,
                                   0,
                                   0,
                                   -0.0018607108560092789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1039857011190426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01290937449800654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56949075505442892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20054596941891467,
                                   0,
                                   0,
                                   0,
                                   0.36246263141805035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077329860622803753,
                                   0,
                                   0,
                                   0.50335204285302104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23151524627464465,
                                   0,
                                   0,
                                   0,
                                   -0.021464961841013045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16109903106725254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082237373829865845,
                                   0,
                                   0,
                                   -0.32274224022389031,
                                   0,
                                   -0.23159038324218931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19002063001887584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75156132335503401,
                                   -0.93115063234084783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50219063545937048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70931483995161793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38341518544628439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17441156337984848,
                                   0,
                                   0,
                                   0,
                                   -0.4280530288916658,
                                   0,
                                   0,
                                   -0.057116257708356669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31114269474114842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58829137643896745,
                                   0,
                                   0,
                                   0.089002511439926824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33118573992504596,
                                   0,
                                   0,
                                   0.23002052048763402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5308073046171311,
                                   0,
                                   -0.78573420151656936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17036236240966571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22441321100382672,
                                   0,
                                   0,
                                   0,
                                   0.22212855307327589,
                                   -0.25051615309804076,
                                   0,
                                   -0.20463276661176688,
                                   0.2044292357063974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11403082116703472,
                                   0,
                                   0,
                                   0.21028193079999308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12553112698886609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023675210924021195,
                                   0,
                                   0,
                                   0,
                                   0.27852097216948263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029601725167848855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1717329154086899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093759345460955434,
                                   0,
                                   0,
                                   -0.30913593193926109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0354279129500101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34803520873248422,
                                   0,
                                   0,
                                   0.3455258372930447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67155344129704042,
                                   -0.14227538873359705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39793913358680255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11824663939989037,
                                   0,
                                   0,
                                   0,
                                   -0.28698714062360431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18318743907753998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42340987064514729,
                                   0,
                                   0,
                                   -0.22155018591133099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057702996549346408,
                                   0,
                                   0,
                                   -0.038920793559282768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47073081099542408,
                                   0,
                                   0.15414584115469651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043500331189518737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33825190760034307,
                                   0,
                                   0,
                                   0,
                                   -0.4163734841105744,
                                   0.25695848374891456,
                                   0,
                                   0.13135924324203274,
                                   -0.41856988766513864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.045510066691212,
                                   0,
                                   0,
                                   -0.0010740861902488567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48497366968659533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077028480117372358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39617401740079716,
                                   0,
                                   0,
                                   0,
                                   -0.15264967388334488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054881928611663473,
                                   0,
                                   0,
                                   -0.16684964147737852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22053047948663559,
                                   0,
                                   0,
                                   0,
                                   0.22732964790751656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30094912821034692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59542563392854453,
                                   0,
                                   0,
                                   0.041248710314811934,
                                   0,
                                   0.025388351646130833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075839489318035525,
                                   0,
                                   0,
                                   0.25345536293454762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21864301211319523,
                                   -0.39172018894139699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25596952722430988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33084333184021003,
                                   0,
                                   0,
                                   0,
                                   0.061818007235341949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74159294938690001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38099231727049332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067604403712563904,
                                   0,
                                   0,
                                   0,
                                   -0.63398411783314812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64499859181067043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90254754340381083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16917172839664985,
                                   0,
                                   0,
                                   0.33996021746129557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41725137597059297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10137622878889815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066634716439278457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094990660557696546,
                                   0,
                                   0,
                                   0,
                                   0.09716328769464741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38823132902666208,
                                   0,
                                   0,
                                   0.39909969310799126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078838314160690731,
                                   0,
                                   0,
                                   0,
                                   0.340830513749246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19481080160295372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12688011171416966,
                                   0,
                                   0,
                                   0.67050673540935968,
                                   0,
                                   0.17551240005965105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61133176530707201,
                                   0,
                                   0,
                                   -0.11940276779195486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55733171553080507,
                                   0,
                                   0,
                                   -0.28619800471197121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088172495307185295,
                                   0,
                                   -0.20795387642747715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014731631169777576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36945568853134425,
                                   0,
                                   0,
                                   0,
                                   0.2075158582574918,
                                   0.8095821955778193,
                                   0,
                                   0.39154654871930505,
                                   -0.3212996669505449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20205027722087376,
                                   0,
                                   0,
                                   -0.080887018137513936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39719013069682318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36335934609976933,
                                   0.48801387040438404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42681967907058271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41893900280677177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030197833667952874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5681409100928011,
                                   0,
                                   0,
                                   0,
                                   -0.15637876924448957,
                                   0,
                                   0,
                                   -0.39343148765583041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31047575812624795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20985203863941107,
                                   0,
                                   0,
                                   -0.20108237795472542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27944417861802895,
                                   0,
                                   0,
                                   0.68428018406115199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90042390338498868,
                                   0,
                                   0.095198022136689986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27953035129113141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49460010781658109,
                                   0,
                                   0,
                                   0,
                                   0.37890605831079527,
                                   0.21777595936069186,
                                   0,
                                   -0.41221374870901861,
                                   0.32213186487438344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18070922776441478,
                                   0,
                                   0,
                                   0.29728123981618326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45418358966013861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070466187184694412,
                                   0.35339682810415651,
                                   -0.35096903701609078,
                                   0.37248384763588382,
                                   -0.63398657993633478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4432370444490597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15665344577259077,
                                   -0.26760823295875918,
                                   -0.47239641234499907,
                                   0.66552446998108628,
                                   0.20323696383358367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11027347888666297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21294699137178488,
                                   0.68298732050469613,
                                   -0.49792455965057109,
                                   -0.22994784940438501,
                                   0.41858903258546482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71545159022205951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18796152497060023,
                                   0.14922130166621861,
                                   -0.048416646218845449,
                                   -0.32095638478302196,
                                   -0.57024145565227335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26097437727421985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73189086024109151,
                                   0.23178170265373185,
                                   0.3992044650734583,
                                   0.41121506389928419,
                                   -0.11850464845121772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0631855767499416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022690700642325257,
                                   0,
                                   0,
                                   0,
                                   0.79422109564558607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5535497669830175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27089632785673251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19062248092052236,
                                   0,
                                   0,
                                   0.14331502493564025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028983897461201391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47212639680734708,
                                   0,
                                   0,
                                   0.10062220759430818,
                                   0,
                                   0,
                                   0,
                                   0.30050569521159254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33693443257749883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39675293980255449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35655287402694746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1455442149872534,
                                   0,
                                   0.36884521067915554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05561480426693171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34391509189905312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.003921157781789,
                                   -0.16130865123546329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98552858146313416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020125708837686773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052433135441474307,
                                   0,
                                   0,
                                   0,
                                   0.032440586287832807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15437490460708325,
                                   0,
                                   0,
                                   -0.18174322853035063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72893923998809973,
                                   0,
                                   0,
                                   0.2291059623711913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08894955972750325,
                                   0,
                                   -0.3555758919142471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50305136374372028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2537178924582249,
                                   0,
                                   0,
                                   0,
                                   -0.73904982684798659,
                                   -0.50263140315782373,
                                   0,
                                   0.47510344958391454,
                                   -0.043495176291165394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23287958109085471,
                                   0,
                                   0,
                                   0.56342644526246599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73842500850590276,
                                   0,
                                   0,
                                   0.28506435511475481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25726437673653269,
                                   0.26462357086220667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31097275886306647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32998671906075444,
                                   0,
                                   0,
                                   0,
                                   0.15776602482587848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082284970449137115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36694460266670648,
                                   0,
                                   0,
                                   0.79889870602705881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070212769224167026,
                                   0.37029321838558282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012797866113820389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24130799569313119,
                                   0,
                                   0,
                                   0,
                                   -0.016418142293035065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16248915649584589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30483000417142075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51695727695793647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23758322597373516,
                                   0,
                                   -0.48520928725654855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18088114078699469,
                                   0,
                                   0,
                                   0.35778134066969813,
                                   0,
                                   -0.95599004069974547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32278566245267254,
                                   0,
                                   0,
                                   0.70857191426486354,
                                   0.11421115688826547,
                                   0,
                                   0,
                                   -0.074047569299699939,
                                   0,
                                   0,
                                   -0.055324371475689083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047759356958807259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21637119676580888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32173667234067788,
                                   0,
                                   0,
                                   0,
                                   0.024314667964479324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22526738252444095,
                                   0,
                                   0,
                                   -0.31780288912299798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71560360887331986,
                                   0,
                                   0,
                                   0,
                                   0.09429447528499621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0089301040113951638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15240488035528038,
                                   0,
                                   0,
                                   0.03325335538753544,
                                   0,
                                   0.38685919480027492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018477734918299633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55781689466325024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32796235382031635,
                                   0,
                                   -0.3990863554347549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24159086097736501,
                                   0,
                                   0,
                                   -0.34974181678123883,
                                   0,
                                   0.34943616940865896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010277702256080951,
                                   0,
                                   0,
                                   -0.43875931233414395,
                                   -0.52409355328505247,
                                   0,
                                   0,
                                   0.1162430858769844,
                                   0,
                                   0,
                                   -0.46488242953075209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15911912548376475,
                                   0,
                                   0,
                                   -0.21230370981662222,
                                   0,
                                   0,
                                   0,
                                   0.10603817225244765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13951961900495613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17981590697876479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71906707338469766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2401770281431086,
                                   0,
                                   0.24341478234182695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48202662694736642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014892078981550448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00086604096247826223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52303152796351848,
                                   0,
                                   0,
                                   0,
                                   0.11250482318316815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68519865248713308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77823294232045592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12732280716137898,
                                   0,
                                   0,
                                   0.062332841446606557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12950338631434505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1228109878758662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17838154400755332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32482235878698112,
                                   0,
                                   0,
                                   0,
                                   0.11962929451543641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19368104698424626,
                                   0,
                                   0,
                                   0.054523578307180603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10800153793748671,
                                   0,
                                   0,
                                   0,
                                   -0.32723817167319902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57267258060506998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35567636228926303,
                                   0,
                                   0,
                                   -0.34612637024150172,
                                   0,
                                   0.31587878679371895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076563642195382017,
                                   0,
                                   0,
                                   -0.11000448476699054,
                                   0,
                                   0,
                                   0,
                                   -0.42872369292590901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096620520372729765,
                                   0,
                                   0,
                                   0,
                                   0.49335460769797435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12889063489334449,
                                   0,
                                   0.40580337843467607,
                                   0,
                                   0,
                                   0.55256738181779075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081937539536702408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0090805497433893712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10360198733810537,
                                   0,
                                   -0.19591926439113927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0081166595456793143,
                                   0,
                                   0,
                                   0.053842429576317921,
                                   0,
                                   0,
                                   -0.72956612537055132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21493323890138735,
                                   0,
                                   0,
                                   0,
                                   0.86845373105498469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20481522772701297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10957299670044732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071341942601778563,
                                   0,
                                   0,
                                   0.81416916375031223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092094352218090925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52185180394959729,
                                   0,
                                   0,
                                   -0.054007664668265787,
                                   0,
                                   0,
                                   0,
                                   0.39385482745873929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10228121764072723,
                                   0,
                                   0,
                                   0,
                                   0.1276468988946462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15305294185158627,
                                   0,
                                   -0.071416741010596724,
                                   0,
                                   0,
                                   0.23506022980584784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013413392973187367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029633708143231387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054057491828351789,
                                   0,
                                   -0.034366240298219719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56328051476667762,
                                   0,
                                   0,
                                   -0.36966462226864444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2843343865466077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30749836782438855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81662579426843562,
                                   0,
                                   -0.46506860104181913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25276750996680164,
                                   0,
                                   0,
                                   -0.14086906990838255,
                                   0,
                                   0.065397974257348196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019221709497718002,
                                   0,
                                   0,
                                   0.43654004009264707,
                                   0.27244344235718176,
                                   0,
                                   0,
                                   -0.48367318374547136,
                                   0,
                                   0,
                                   -0.098908785332677968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32449405530550801,
                                   0,
                                   0,
                                   -0.21446018108958065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1362800017014868,
                                   0.26631335486780339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24009774107717188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71929095733852433,
                                   0,
                                   0,
                                   0,
                                   -0.40237985144906407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14926300788274982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1632765752305417,
                                   0,
                                   0,
                                   0.3400449197446278,
                                   0,
                                   0,
                                   0,
                                   0.38884388285102867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.007703102651340523,
                                   0,
                                   0,
                                   0,
                                   0.076900130814730766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09337965761774665,
                                   0,
                                   0.26802164194197803,
                                   0,
                                   0,
                                   0.20543734980870521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20687987890997359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16882958339843912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38307907264823005,
                                   0,
                                   0.2738747103650413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018500483820220931,
                                   0,
                                   0,
                                   0.5332690694063037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026785488132959112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22548638207761842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56668515008423304,
                                   0,
                                   0.52232580349522462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29209681703471907,
                                   0,
                                   0,
                                   0.11955488491330588,
                                   0,
                                   0.13327589058951481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14677709125359031,
                                   0,
                                   0,
                                   0.60675728440605237,
                                   -0.94618714749948007,
                                   0,
                                   0,
                                   0.031602762397855894,
                                   0,
                                   0,
                                   0.1379633671028766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.502805750283433,
                                   0,
                                   0,
                                   -0.81868361249144084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18133497369235926,
                                   0,
                                   0,
                                   -0.068522240145899166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25986717715412133,
                                   0,
                                   0.38774736758674122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26949678612536998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50212274929320122,
                                   0,
                                   0,
                                   0,
                                   0.3845450383456458,
                                   -0.12236796267916751,
                                   0,
                                   -0.070720182910042062,
                                   -0.23085635583923728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34798486090363295,
                                   0,
                                   0,
                                   0.65269596076933201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11031881163038462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17840967775177541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032455673595959099,
                                   0,
                                   -0.65840947315967269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27376608335474667,
                                   0,
                                   0,
                                   -0.23420638298253474,
                                   0,
                                   -0.60360331565255476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41163099643031925,
                                   0,
                                   0,
                                   -0.22686656739596966,
                                   -0.27163193238094457,
                                   0,
                                   0,
                                   -0.15716972638948026,
                                   0,
                                   0,
                                   0.64513789933015275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53974444908071673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20543091645656572,
                                   0.012695415970728922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34241916032308084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65312524638785774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036373232383586411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34125897814603606,
                                   0,
                                   0,
                                   0,
                                   0.43549065111763863,
                                   0,
                                   0,
                                   -1.0209356316892173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36823787154177995,
                                   0,
                                   0,
                                   0,
                                   -0.11620959016715643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063900033669682221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28733321562614372,
                                   0,
                                   0,
                                   0,
                                   -0.2772651599829401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14949110634117252,
                                   0,
                                   0,
                                   0.51096103339323573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13586613570265049,
                                   0,
                                   0,
                                   0,
                                   0.11123844206366172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22559602139129925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050964453896968735,
                                   0,
                                   0,
                                   -0.28898136884021519,
                                   0,
                                   0.60968207518139483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23663316565999643,
                                   0,
                                   0,
                                   0.012003311393795343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47707574741582182,
                                   0,
                                   0,
                                   0.62767811053551981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062481032299161542,
                                   0,
                                   0.58346904326184768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2802872723737253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65177255679877677,
                                   0,
                                   0,
                                   0,
                                   -0.12363437787150833,
                                   -0.01749333281718328,
                                   0,
                                   0.76834214739176943,
                                   0.48874326345093028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092496096245461012,
                                   0,
                                   0,
                                   -0.10366765468783018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26956969255848995,
                                   0,
                                   0,
                                   -0.11046050135807581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02445766069382857,
                                   0,
                                   0,
                                   -0.030946142576825212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16227967153707309,
                                   0,
                                   0.18222115025459948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074167138408316971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84777849251796633,
                                   0,
                                   0,
                                   0,
                                   -0.008770739601254433,
                                   -0.097872901625423225,
                                   0,
                                   -0.29444109448481581,
                                   -0.83840738737538401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22572393913649422,
                                   0,
                                   0,
                                   0.22055765713552339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12336390192833152,
                                   0,
                                   0,
                                   0.066136364517606516,
                                   0,
                                   0,
                                   0,
                                   -0.13411620981944006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1300051495780663,
                                   0,
                                   0,
                                   0,
                                   -0.15237390738245346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67299206394110067,
                                   0,
                                   -0.13380534502857655,
                                   0,
                                   0,
                                   0.029987723431840408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094486233135944661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099170343782586184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50718770207024244,
                                   0,
                                   0.3582531309546092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19299458786122289,
                                   0,
                                   0,
                                   0.094792327699820933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49210245544080494,
                                   0,
                                   0,
                                   0.58126087860143993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0071205890251257731,
                                   0,
                                   0,
                                   0.80306127655824355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32436652102047037,
                                   0,
                                   0.083513826224225374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3857061025681599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31714741814718667,
                                   0,
                                   0,
                                   0,
                                   -0.36206025575646972,
                                   0.32378998015918314,
                                   0,
                                   -0.4462769369734354,
                                   -0.38691753828399883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11084464826547974,
                                   0,
                                   0,
                                   -0.31626030390080584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35954072594077213,
                                   0,
                                   0,
                                   -0.79306863523771709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82131539963694578,
                                   0,
                                   0,
                                   0.057850443842358608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18517805483884703,
                                   0,
                                   0.1093018211743009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56903692133381556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15106098312445607,
                                   0,
                                   0,
                                   0,
                                   0.1544458436520745,
                                   -0.2364091204873863,
                                   0,
                                   -0.36410228213161955,
                                   0.43789111798191027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23753351468918088,
                                   0,
                                   0,
                                   -0.51425163460868206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16973311725526169,
                                   0,
                                   0,
                                   -0.66980265818045859,
                                   0,
                                   0,
                                   0,
                                   0.15110985853366946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078989899693582388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081853382657986251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077296725270061789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32225520157251053,
                                   0,
                                   -0.53996764831747535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20379321648188684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20943152379101912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14162172260688677,
                                   0,
                                   0,
                                   -0.10781242366696872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26943008908206828,
                                   0.41124999622478375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050675548607541032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33785311091261472,
                                   0,
                                   0,
                                   0,
                                   -0.66305425688762742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41260992878801034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49137025507938659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36738682610784534,
                                   0,
                                   0,
                                   0,
                                   -0.97190611272972849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45665954708353734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.125975062603568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4563073486533864,
                                   0,
                                   0,
                                   0.52984976648052173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52431073028289543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53963240619580244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38754506489327989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14966019945009079,
                                   0,
                                   0.38884351979079324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08979411160099357,
                                   0,
                                   0,
                                   -0.74829839324247771,
                                   0,
                                   -0.83803879239529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35515663099236849,
                                   0,
                                   0,
                                   0.40697503409747227,
                                   -0.45067114515711437,
                                   0,
                                   0,
                                   0.49842416476074519,
                                   0,
                                   0,
                                   -0.60653000186326123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043232657330509405,
                                   0,
                                   0,
                                   -0.29401444433557394,
                                   0,
                                   0,
                                   0,
                                   0.060510310631476459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094504647211696546,
                                   0,
                                   0,
                                   0,
                                   0.19488226440236991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28649341011287294,
                                   0,
                                   -0.46176590427177983,
                                   0,
                                   0,
                                   0.19838097344592787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083315914231678279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50503686729547315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40256512089466484,
                                   0,
                                   0.046967604553318401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23110666721250445,
                                   0,
                                   0,
                                   -0.2162747855726741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24385263884953273,
                                   0,
                                   0,
                                   0.060569427042653133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57871473656074868,
                                   -0.24659944265477524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66168404825364491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20288820888471465,
                                   0,
                                   0,
                                   0,
                                   -0.15436169699418512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1957760585130737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3503612425670532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19430856384292267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29022818453734878,
                                   0,
                                   0.34718657286803389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.486022691967542,
                                   0,
                                   0,
                                   0.75000357430286957,
                                   0,
                                   -0.48805537273308108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30865258011214336,
                                   0,
                                   0,
                                   -0.55370326916949097,
                                   -0.38179441571537071,
                                   0,
                                   0,
                                   -0.17935001303235698,
                                   0,
                                   0,
                                   -0.38478161088510082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48728618135905521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87182843258981246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12329235191895942,
                                   0,
                                   0.35075973705764707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20110534380421408,
                                   0,
                                   0,
                                   -0.79867802705264201,
                                   0,
                                   0.10228108636434524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66170083085038778,
                                   0,
                                   0,
                                   0.43089605725891239,
                                   0.15149181476466214,
                                   0,
                                   0,
                                   -0.11755219243875674,
                                   0,
                                   0,
                                   0.46140050199996324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58928144993553044,
                                   0.4155819230828004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81027469595424673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93772587497448068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84666346818159777,
                                   0,
                                   0,
                                   0,
                                   0.36512509415501515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61849294993655868,
                                   0,
                                   0,
                                   0.10168974777026529,
                                   0,
                                   0,
                                   0,
                                   0.16701627018172943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10335723637531544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33235742650766043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26471146544013657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46443930663979827,
                                   0,
                                   -0.12919265125470808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3407163661574143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19882817082241197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28825457432355495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42946523941497716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80983810986337945,
                                   0,
                                   -0.13838427328118633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42823363701984091,
                                   0,
                                   0,
                                   0.28761869288092623,
                                   0,
                                   0.14136231549453188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034944766709097297,
                                   0,
                                   0,
                                   0.37820257031491444,
                                   0.069247161708139757,
                                   0,
                                   0,
                                   0.4028985612500835,
                                   0,
                                   0,
                                   0.50184799250179468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16058281066035474,
                                   0,
                                   0,
                                   -0.48468348047469234,
                                   0,
                                   0,
                                   0,
                                   -0.41162478667314822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068582686742766991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17206713665989234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37667931412653344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10991158449319505,
                                   0,
                                   0.36330031278380409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2179067831900654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44956766977481916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82609037340433333,
                                   -0.25778891592440928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91831417087731926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5448452014932782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93191630705822381,
                                   0,
                                   0,
                                   0,
                                   0.47874246151732991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21487276780962034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07648816048047713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6925495511482479,
                                   0,
                                   -0.70243092793973005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6420694562550795,
                                   0,
                                   0,
                                   0.44518208771782636,
                                   0,
                                   0.086849127289392286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45394297072063156,
                                   0,
                                   0,
                                   1.0330584868184869,
                                   -0.053848635323730396,
                                   0,
                                   0,
                                   -0.038216518791301134,
                                   0,
                                   0,
                                   -0.39661661456498737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49186337355332344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44338422631529373,
                                   0.57015113663909067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24856465683439422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87295768030440268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077904545502318928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32232420629257397,
                                   0,
                                   0,
                                   0,
                                   -0.01050162587576392,
                                   0,
                                   0,
                                   0.69845550069119844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21528870174151321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16954260587849737,
                                   0,
                                   0,
                                   -0.43263784470756417,
                                   0,
                                   0,
                                   0,
                                   -0.021806835257425421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18300738531423907,
                                   0,
                                   0,
                                   0,
                                   0.27723998062880206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28275007861623236,
                                   0,
                                   -0.26227336505112381,
                                   0,
                                   0,
                                   -0.15532717276303901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28235730890635685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038874944109424145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1709999022360926,
                                   0,
                                   0.16664032399888429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053717250979680435,
                                   0,
                                   0,
                                   0.59938024506360943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24611930003311294,
                                   0,
                                   0,
                                   0.21565073904182527,
                                   0,
                                   0,
                                   0,
                                   -0.66758512538749204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095698682059014273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36968634213005808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0026571128736362498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059062893963163998,
                                   0,
                                   -0.4404466242052929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30177274751451427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11343903362393225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059405002494276417,
                                   0,
                                   0,
                                   -0.51714682997538586,
                                   0,
                                   0,
                                   0,
                                   0.37514735662456672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24138787786902402,
                                   0,
                                   0,
                                   0,
                                   -0.32963208776610775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0072473661299997227,
                                   0,
                                   0.042099653500901016,
                                   0,
                                   0,
                                   0.42453956952305594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21232054171528886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22331763844286112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21357869576651822,
                                   0,
                                   0.053964028116889093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30621864793643727,
                                   0,
                                   0,
                                   0.045407869472741565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6712719755302653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011585239132337319,
                                   0.39018636710149951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49049710982528766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74821758455653142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27395523747443618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05027606680875972,
                                   0,
                                   0,
                                   0,
                                   -1.0566393625230339,
                                   0,
                                   0,
                                   0.065827908513533137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.280532415448564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091557725030206039,
                                   0,
                                   0,
                                   0.18864279008687806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063410237007159614,
                                   -0.56418938132929219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42569412581148369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19170760897479869,
                                   0,
                                   0,
                                   0,
                                   -0.5131074109623901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3904536506420887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040641467703751127,
                                   0,
                                   0,
                                   0.23901395090760827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32450988585641827,
                                   0,
                                   0,
                                   0.58197865995400733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53118143208491253,
                                   0,
                                   -0.47505534733227506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5019396239907441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3201698315276294,
                                   0,
                                   0,
                                   0,
                                   0.67681267398677969,
                                   -0.47370882952527538,
                                   0,
                                   0.25712836537746098,
                                   -0.39835630571137226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49864276842435418,
                                   0,
                                   0,
                                   0.17262477092661596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30934868282876948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58332716955238495,
                                   -0.26492341346259446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86325066017141017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72041031597311078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41678234798134151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76630275575060358,
                                   0,
                                   0,
                                   0,
                                   0.25259815622539483,
                                   0,
                                   0,
                                   -0.20740964612168611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34879494017426493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050373819668916117,
                                   0,
                                   0,
                                   -0.17117842476762363,
                                   0,
                                   0,
                                   0,
                                   0.20294546842256495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58562311915369614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2303097811580132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30543733026946629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53852692565340732,
                                   0,
                                   -0.0028518704689881914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36980478856261267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10444903955311839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57020969811950961,
                                   0,
                                   0,
                                   0.51602497457328833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25010546603858264,
                                   0,
                                   0,
                                   -0.047115444072643793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22835032578230474,
                                   0,
                                   0.14345638921842946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72798965924509418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22186801539225637,
                                   0,
                                   0,
                                   0,
                                   0.49260468678730218,
                                   0.62134903647903905,
                                   0,
                                   -0.20841612094471493,
                                   0.37355740593948578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12799257916322532,
                                   0,
                                   0,
                                   0.60938358058561293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064284994864527961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58337435785477232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13795164058616025,
                                   0,
                                   0,
                                   0,
                                   0.44980179998809028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040192289678284879,
                                   0,
                                   0,
                                   0.083520098748593993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16918210421707466,
                                   0,
                                   0,
                                   0,
                                   0.54284596487979908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.003671951557277453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015218440416584749,
                                   0,
                                   0,
                                   -0.26373501858047349,
                                   0,
                                   -0.18025783316991126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18429849809734375,
                                   0,
                                   0,
                                   0.026783652785834264,
                                   0,
                                   0,
                                   0,
                                   0.28412655297330913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029590533545739615,
                                   0,
                                   0,
                                   0,
                                   -0.148734673698909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020949934903420224,
                                   0,
                                   0.30898442035034951,
                                   0,
                                   0,
                                   -0.16087262019357657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34737631429300619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54609129776017695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34593070320886937,
                                   0,
                                   -0.37944080746540559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23587776227958346,
                                   0,
                                   0,
                                   0.040413130672284442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012287608442319006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43044989102645237,
                                   0.33299520091766649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29810609173165614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20107547642549545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5966725883825803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082597694225628515,
                                   0,
                                   0,
                                   0,
                                   0.42403831388068502,
                                   0,
                                   0,
                                   -0.51608479725569512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66493470297116986,
                                   0,
                                   0,
                                   0,
                                   0.44500916281802605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12552423147224362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37262881036669898,
                                   0,
                                   0,
                                   0,
                                   -0.33691747438965769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40363909264204589,
                                   0,
                                   0,
                                   -0.041707803298870062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10779452505960296,
                                   0,
                                   0,
                                   0,
                                   0.51754011217232643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22685384312915566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15267515009119448,
                                   0,
                                   0,
                                   -0.11942596659238533,
                                   0,
                                   0.026047707335821887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033393769770281675,
                                   0,
                                   0,
                                   0.45417650647241814,
                                   0,
                                   0,
                                   0,
                                   -0.1171067763060385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15391795004430786,
                                   0,
                                   0,
                                   0,
                                   -0.14749347882794051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31836833771279227,
                                   0,
                                   -0.52899859573224783,
                                   0,
                                   0,
                                   0.44173668678967071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021285571055409819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1671229834955742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23959681097615168,
                                   0,
                                   -0.18848466200371289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022035771037240436,
                                   0,
                                   0,
                                   0.18793201753720076,
                                   0,
                                   -0.098396690263921935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20849076154223972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53123026222026504,
                                   0,
                                   0,
                                   0,
                                   -0.068192483701249015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37537559603862497,
                                   0,
                                   0,
                                   0.1514403043031588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13180175277647149,
                                   0,
                                   0,
                                   0,
                                   0.020941946280256148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45545093703495965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41745599654026572,
                                   0,
                                   0,
                                   0.078751833876497965,
                                   0,
                                   -0.30072528978219232,
                                   -0.18742699630331178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47582958172345502,
                                   -0.39605257393710852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62398278326425782,
                                   -0.04605906241227542,
                                   0,
                                   0,
                                   0,
                                   -0.70038234199161864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64339946206830523,
                                   0,
                                   0,
                                   -0.56921686207772881,
                                   0.12639311261148212,
                                   0,
                                   0,
                                   0,
                                   0.11269243613439026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68244133263497953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22855210157196054,
                                   0,
                                   -0.10581747201886346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044544848573431495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0016299024713848521,
                                   0,
                                   -0.14958296024413542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25677819452243245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37310577699480574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31807044268984935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79514465894047237,
                                   0.033276714542845781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15737396102692214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29752879660945697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16110775633098584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037345710258665857,
                                   0,
                                   0,
                                   0,
                                   0.82513457332636397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15782612713415978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13064235331427007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26947805885317422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29779893347019493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47218665359683754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61054629886456413,
                                   0,
                                   0,
                                   0,
                                   0.21612279238961341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54193113383182634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25048197123956351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033665234073348455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88899964249126229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23926152415235541,
                                   0,
                                   0,
                                   0,
                                   -0.61076032037310524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32502277188817719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16946789271091423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85264053235241177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14238338797466099,
                                   0,
                                   0,
                                   0,
                                   -0.76211799303734684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037452618099206997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025334583347832937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45971228876454523,
                                   0,
                                   0,
                                   0.25138497650001057,
                                   0,
                                   0,
                                   0,
                                   0.23912066412279009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34066416725159432,
                                   0,
                                   0,
                                   0.38192599072403582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25418278692372703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20772370777756735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35432097010924868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36305584466043173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1980315935408897,
                                   0,
                                   0,
                                   0,
                                   0.68226225477749702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13237749913661612,
                                   -0.254753480065251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11535543540219792,
                                   -0.55340282439792576,
                                   0,
                                   0,
                                   0,
                                   -0.16485179138939951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33071155974662286,
                                   0,
                                   0,
                                   -1.0155109860211784,
                                   -0.15031932021048872,
                                   0,
                                   0,
                                   0,
                                   0.38179023309149895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62759537182461145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53213006274539476,
                                   0.55649901507247312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096393773583489523,
                                   -0.43228559083571277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1929567313558134,
                                   -0.42902150309235476,
                                   0,
                                   0,
                                   0,
                                   0.50625590465221348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5905634405301976,
                                   0,
                                   0,
                                   0.21406402616001116,
                                   0.77551761668789976,
                                   0,
                                   0,
                                   0,
                                   0.57353094778958513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20882317939042272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89231709897548295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23443130492232922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30079685320338556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2446962765507851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13724177455164308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0068263896587989897,
                                   0,
                                   0,
                                   0.42378206411753289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29623023176133823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2643213795993733,
                                   0.24395360049432668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06773213239209859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33381792483365524,
                                   0,
                                   0,
                                   -0.50665468284899151,
                                   0,
                                   -0.076305790561210479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02321024193131966,
                                   0,
                                   0,
                                   0,
                                   0.29517472156761698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48687716526455921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18529048716873242,
                                   0,
                                   0,
                                   0,
                                   -0.071111577701412118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1939607517942521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61619200397752794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26155577557702014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38821167657978439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27985906941773225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044203702196829162,
                                   0,
                                   0,
                                   0,
                                   0.73354991894614674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25821190580906928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096222664593548266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052930238866215007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6102523364670106,
                                   0,
                                   0,
                                   0,
                                   0.80707540414004231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42891676619267305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48261390952584393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075364566526368942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1105842542102116,
                                   0,
                                   -0.34646771797797599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18367159002641298,
                                   0,
                                   0,
                                   0.36739692653282102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074039315534557615,
                                   0,
                                   0.1624017389810784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23432891981271842,
                                   0,
                                   0,
                                   0.68565991715055796,
                                   0.29350158519650482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16358652063345622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09142595270261461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10444444901870693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032033957950816767,
                                   -0.54685363722972369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088681139439483803,
                                   0.78600167259245979,
                                   0,
                                   0,
                                   0,
                                   -0.046273174363889703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70783527505430799,
                                   0,
                                   0,
                                   0.048133304349944527,
                                   0.38140530063133787,
                                   0,
                                   0,
                                   0,
                                   0.054585120298590875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42136312640170992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0072104996325729059,
                                   0.57226725996551209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19834409208239584,
                                   -0.31650220631153358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067389813701958123,
                                   0.01224489161501207,
                                   0,
                                   0,
                                   0,
                                   -0.068981715763779289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063995674451328532,
                                   0,
                                   0,
                                   -0.15365359247335852,
                                   -0.89541353505545618,
                                   0,
                                   0,
                                   0,
                                   -0.66316929681658388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49199452229171697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19557122123597001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22942984904017269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47179707327476184,
                                   0,
                                   0,
                                   0,
                                   0.11900314657293092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50322707473922168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7928879415297273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57929580320387486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08522901274042112,
                                   0,
                                   0,
                                   0,
                                   -0.31487389923410641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10422620824235299,
                                   0.046725678593019931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34454546167502076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46793026202055543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20954708374676009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30627461817364066,
                                   0,
                                   0,
                                   -1.0676797824788236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25450375487935423,
                                   -0.32693446251583447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41347686625004026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52546691623644226,
                                   0.6214068492633662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046459244811778024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33864881381559048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94542880817748132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3572887757440259,
                                   0,
                                   0,
                                   0.64664455250030184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17362477732627091,
                                   0.48904610157119233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012365856623453943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36528425326255815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86523105590384952,
                                   -0.12750556284556999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44884446344230211,
                                   -0.13886020068045868,
                                   0,
                                   0,
                                   0,
                                   0.24484868637889792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28587784442688013,
                                   0,
                                   0,
                                   0.50934542452988119,
                                   -0.0830197871824601,
                                   0,
                                   0,
                                   0,
                                   -0.2978625590347494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070971678544928057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50533670370279404,
                                   0,
                                   0,
                                   0.16370888046267679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15100414438209842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7364572494372319,
                                   0,
                                   0,
                                   0,
                                   -0.22356041514365227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044586647400589957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16025954331128375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51091487256656154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26333156668117214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019980752142832237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32623148329958446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054817008533722317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56172862024183978,
                                   0,
                                   -0.061877730381619034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023250338404622255,
                                   0,
                                   0,
                                   -0.5262330847783887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67630474728591738,
                                   0,
                                   0.040446199337416791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054798797609700411,
                                   0,
                                   0,
                                   -0.44946276263165075,
                                   -0.49229957553961168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23380330439141894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38799283642701499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38173725685344972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044496687108315613,
                                   0,
                                   0,
                                   0,
                                   0.37753068629807413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28650981754074556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40827600554438598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67896253226461634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23493897892161714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61067846262621617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14472542150922957,
                                   0,
                                   0.05480439045138602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0069024205736966425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10271671509709686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1146350655229488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039023623438917146,
                                   0.53238751399344808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48910903606863032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44219434052984891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33955282187449182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35731350424527414,
                                   0,
                                   0,
                                   0,
                                   0.269483555787845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32908984366506061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23633333815808957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56756198103761157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050926858891603657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16724179546073809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16952708805909936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054555069863493851,
                                   0,
                                   0,
                                   -0.066295986491803821,
                                   0,
                                   0,
                                   0,
                                   -0.48021881876674205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086366097781694046,
                                   0,
                                   0,
                                   -0.14576842503265489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4123547273691528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53215879066319316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42020444886550418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013918296636722246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21588605054715104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25552855529077168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17114503294801631,
                                   0,
                                   0,
                                   0,
                                   -0.39578698434222742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10719568114220182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54925079410457067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65999988581323021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65262308379233458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055006340490115713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71221587286214394,
                                   0.80685823739279805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25515944982831473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33267128032453197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039272806674035439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32565189937428007,
                                   0.62967932176213104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0029338455744012349,
                                   -0.95627534225980826,
                                   0,
                                   0,
                                   0,
                                   0.12016085161711008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61257809819127917,
                                   0,
                                   0,
                                   0.1061040485915867,
                                   0.11823215233526595,
                                   0,
                                   0,
                                   0,
                                   -0.03724290156950253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94914115398884713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024590427497972391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30087971054774509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49035954830684492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049092473792598096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21681012961828017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063542720273009362,
                                   0,
                                   0,
                                   0.0011294069186772171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02486312681839517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083225140213136761,
                                   -0.47818503491825803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24821731595049079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13742997140377061,
                                   0,
                                   0,
                                   -0.20028741678308715,
                                   0,
                                   -0.01363965278917071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50848579914402692,
                                   0,
                                   0,
                                   0,
                                   0.18880032627953899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31779078763503621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28480482727386003,
                                   0,
                                   0,
                                   0,
                                   -0.13410727223690147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23484726969456504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24184575308152842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25273829195245423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76599324370396338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019438004139093412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17783628521631564,
                                   0.58433259853657582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7695963539727807,
                                   0.69958369346162175,
                                   0,
                                   0,
                                   0,
                                   0.62271683729242888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17589587014500313,
                                   0,
                                   0,
                                   -0.39129810635422874,
                                   0.19596883697500803,
                                   0,
                                   0,
                                   0,
                                   -0.39983365585530095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039908635092395034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18518200190585801,
                                   0.70597402133125942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1611840110864371,
                                   0.29724791161330988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48812394126221187,
                                   0.16223757926525495,
                                   0,
                                   0,
                                   0,
                                   -1.1901576403318088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11844192340454501,
                                   0,
                                   0,
                                   0.40161892269565574,
                                   0.081301113251902091,
                                   0,
                                   0,
                                   0,
                                   0.37069997793630616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058155016390362302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24130829704951373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094640826782433018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41753836286588991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27970424373400982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37366693117721628,
                                   0,
                                   -0.58303263413307282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51208068600079837,
                                   0,
                                   0,
                                   -0.21630865176171152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17047383455140921,
                                   0,
                                   -0.71950963000190871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27834301265312816,
                                   0,
                                   0,
                                   -0.33189060176371232,
                                   0.25521046081585863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041532966826412859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035794827317383884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058357762151533488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30093349929977598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30407600602960588,
                                   0,
                                   0,
                                   0.27718552769382854,
                                   0,
                                   0,
                                   0,
                                   -0.038584480677816502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059712913396921419,
                                   0,
                                   0,
                                   0.22848653533297983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4537409896131363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46640618215023888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13747212758570646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0071148815065242843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48694358562484125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2180143914092067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14067411866232443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028050193990712319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14043898030996665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036967360037390082,
                                   0,
                                   0,
                                   0.19398052484281397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47002171745648696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081129945856957042,
                                   -0.41157569401348421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20093051273066681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28397377264907347,
                                   0,
                                   0,
                                   -0.26927295532553974,
                                   0,
                                   -0.018078157035617364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53144107250824457,
                                   0,
                                   -0.2235500705419026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.547388269082556,
                                   -0.25307196156975048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35982686950202303,
                                   -0.21503275125536409,
                                   0,
                                   0,
                                   0,
                                   -0.59789784085643582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67063250760379289,
                                   0,
                                   0,
                                   -0.37726873930224281,
                                   -0.22319867764331269,
                                   0,
                                   0,
                                   0,
                                   -0.25114660545702017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27832690928431519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1887490554928748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091108686960714391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2574381641369709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18110080341520957,
                                   0,
                                   0,
                                   -0.14365059911107425,
                                   0,
                                   0,
                                   0,
                                   0.16152721973362133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67214448137848526,
                                   0,
                                   0,
                                   0.18663221740855535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23441430132294319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1426325300621106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27162973517711475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093449354420203259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44886676628553085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097854955262898252,
                                   0.39243638745449055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27003892101305849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86977082905895109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63330502279261602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054737636460638936,
                                   0,
                                   0,
                                   -0.34021398378261147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49901099288236905,
                                   0.5681375465317795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17109418522683811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46657342053091283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045683865692819764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14006690999325849,
                                   0,
                                   0,
                                   0,
                                   0.12161843847097542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8092000152365515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20470661820224612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037269146476447745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21843532302388394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28674359375166347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53943807038356706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085484153160296283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74952557171914336,
                                   0,
                                   0.25821074308600522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26068213949895763,
                                   0,
                                   0,
                                   -0.43425988145113853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055752013653130802,
                                   0,
                                   -0.18657088500993571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2288713099488752,
                                   0,
                                   0,
                                   0.37054886873992293,
                                   0.23174467118810127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30554235393946072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73902717635174164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25379641287338994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051031702097025872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076561475792506939,
                                   0,
                                   0,
                                   -0.70298721996022318,
                                   0,
                                   0,
                                   0,
                                   -0.094474000962339821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063098505216166612,
                                   0,
                                   0,
                                   0.58428811224473443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11829147163090464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088091097138007612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034103064142975564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10958310275298039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2090614976828499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079738819437067066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.264116885255121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1441200297139969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26937766597119206,
                                   0,
                                   -0.014542673628572356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87343439178637328,
                                   0,
                                   0,
                                   0.20882671971358413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030794965554330998,
                                   0,
                                   -0.72890123619319835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24296290732143136,
                                   0,
                                   0,
                                   -0.12385901185407175,
                                   -0.010226161921219327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12304132872780638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13769836943563396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0187269653919766,
                                   -0.70200776883054061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049212182012217026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19703356380952067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17444001868183054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21713237455150541,
                                   0,
                                   0,
                                   -0.48199553853328247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067876357833132756,
                                   0.13353478409263991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34729977319197008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0198649356692151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48145762414369869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58632182085007212,
                                   0,
                                   0.15960672751418903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50259428034057152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06161077629887976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066582443396370872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031520259231388181,
                                   0.0409252560405515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36750215228236149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56667960806628614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13160344941903349,
                                   0,
                                   0,
                                   0,
                                   0.14496592138528119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64945126580113777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52380736774524506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5568826405815962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012450544617720632,
                                   0,
                                   0,
                                   0,
                                   -0.58433551265795569,
                                   0,
                                   0,
                                   0,
                                   -0.34463669309334222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39556916093420913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098877286345369811,
                                   0,
                                   0.099716623986000938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5492984761028753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23203132198301621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093706342049894725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12501423878872053,
                                   0.18369077863154779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53973268847885325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057156934987091276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079740057905543144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31561800944854201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081065012345129708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089592606410021453,
                                   0,
                                   0,
                                   -0.053372211002399701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0062985318924724965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08751959835472771,
                                   -0.22291562960719946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22686260951844572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4305165267596715,
                                   0,
                                   0,
                                   -0.18850886786085908,
                                   0,
                                   0.7311574842312728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094785034995178832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30582864200228177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055430355225161987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34144030212140269,
                                   -0.59120849226410499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94193120640975025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0050205796571942823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060760692138842998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40398244515324755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014578961161887116,
                                   0,
                                   0,
                                   -0.034486885864131969,
                                   0,
                                   0,
                                   0,
                                   0.1683857100241119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15267861003942551,
                                   0,
                                   0,
                                   -0.18905813770096666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11586186043166923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50671494616554302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33349794734828547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5938143254886642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10137358999009635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50353582198467539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6357904027788811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12474356868699736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026600594475374686,
                                   0,
                                   0.18452103205084672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35594078888634473,
                                   0,
                                   0,
                                   0.34900725677253952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53287744264766579,
                                   0,
                                   0.22496369516437947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43913041515998036,
                                   0,
                                   0,
                                   -0.36408845863662209,
                                   0.047134218507377257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047417338116109924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3613321038510714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23793210356314001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44508259212048829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1680071729155124,
                                   0,
                                   0.13578822493407755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2148531651277977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096379858129428064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17237725526562508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11935323875732337,
                                   0.75246633477003411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18168458874658819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075937321521841752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076881347885795426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10485122321314318,
                                   0,
                                   0,
                                   -0.31432975101347449,
                                   0,
                                   0,
                                   0,
                                   -0.29372011123231501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34961121683201019,
                                   0,
                                   0,
                                   -0.27978401680871828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61057061341179797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24216366250903451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35959583517784727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11012362917384315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13737217930003837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0066923093799571565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2450827188486713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35993244268875835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17602569062451717,
                                   0,
                                   0.39448339238756008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47417925974091768,
                                   0,
                                   0,
                                   -0.11280551230219936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28055995018700824,
                                   0,
                                   -0.10264609193047267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36596881150232197,
                                   0,
                                   0,
                                   0.067528143914317995,
                                   -0.31793178016166646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69930715955745359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54490086685259032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057716696239709014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050472066164744589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2906340543327709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47709453358722842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1390221660503419,
                                   0,
                                   0,
                                   0.25094522716386908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14415470868615635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16429329872116322,
                                   0.075983014514085567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024223091383180975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4547911361284861,
                                   0,
                                   0,
                                   0.19361918752251631,
                                   0,
                                   0.50792117626886335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20806970715055667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26690538657744201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76963095409061455,
                                   0,
                                   0,
                                   0,
                                   0.12303924572436298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4030658271383093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3773851011062872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12809948317384481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40067893578560299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31366424876779547,
                                   -0.75690067574552777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67437746976089086,
                                   -0.79764061484597581,
                                   0,
                                   0,
                                   0,
                                   0.20978416337614117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18507731112009601,
                                   0,
                                   0,
                                   0.072810887887679615,
                                   -0.13214921532256818,
                                   0,
                                   0,
                                   0,
                                   -0.32146425487149105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15356184721479285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064229027815922088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47162362832317467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081935053774787728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018040589380200416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18684498679038045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71709900677896421,
                                   0,
                                   0,
                                   0.20190179021146684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16254838899737964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022527878707207082,
                                   -0.076986498790316382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3666522680718472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012318547048794651,
                                   0,
                                   0,
                                   0.043552170160176248,
                                   0,
                                   0.03883114311987107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098890258551540933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086171495887830046,
                                   -0.55208546738537811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21238943668168792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27295107913328559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97982500098116565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42917513622339049,
                                   0,
                                   0,
                                   0.04848802034019617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40368322406102319,
                                   -0.020054789967744336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31199079953952141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69353079462805634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24721036607031513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39787139139588967,
                                   0,
                                   0,
                                   -0.12555344738446228,
                                   0,
                                   0,
                                   0,
                                   -0.34700044228173532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076283283313961225,
                                   0,
                                   0,
                                   0.037963355639716839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058346120268198264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16872549366508413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21236727463385968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022592324451214826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28050715234700652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19336531060204784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79241296391751281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12323813181975916,
                                   0.41243588717456542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6149762601073262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83143930686121481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4457659946713442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012736359097218597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23956113604978552,
                                   -0.47308348900293684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29872063839558333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90019597559223474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1963042172298497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058118351887923386,
                                   0,
                                   0,
                                   0,
                                   -0.71641153052370443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40554765163197354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50782929539528943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14993978590889784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59514627463276537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12404092041623883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66949643485885435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14791990801429639,
                                   0,
                                   0.091502326340580586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071899513627531414,
                                   0,
                                   0,
                                   0.31948445603823505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6930662560843307,
                                   0,
                                   0.14207123738276883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053841002796010257,
                                   0,
                                   0,
                                   -0.063100400790511324,
                                   -0.60229941468690529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1100970453532592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27499380654429317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95534123151027972,
                                   0.22569287686934869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50717841932163565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35682805013855379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0093283495483881471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16692626372086186,
                                   0,
                                   0,
                                   -0.0026226947018623704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85610460073347772,
                                   -0.33148156628131492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027753032828722029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.144405800513009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28441244716154351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33271149574384806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40514346793038131,
                                   0,
                                   -0.89445809245927776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.245246413332805,
                                   0,
                                   0,
                                   -0.32083235582056363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11180059356377797,
                                   0,
                                   0.19190816109199077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22478116813743584,
                                   0,
                                   0,
                                   0.29875455418229446,
                                   -0.18425710635703113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29618121815112708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48685766110766071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72445644175735724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10325912005519373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28780063537494349,
                                   0,
                                   0.24006107260061546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010170596441704136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16434530656374247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060799583528039977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18980886393644325,
                                   -0.15718632649307684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48217998462959855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25630904040997526,
                                   0.29297798338772324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62389204742883353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75797132530747602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15847065088189194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.14273457255997,
                                   0,
                                   0,
                                   0.17754603725753196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0062257975867781659,
                                   -0.18343244367269268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62406047717584368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11805070674490252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026496126882422186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56997649564429109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062274175093611023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14741150763973271,
                                   0,
                                   0,
                                   0.35068071099830789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036752740246473542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5955596676545496,
                                   -0.059673900105674867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18629226392746939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12271222705984687,
                                   0,
                                   0,
                                   0.30039420000676254,
                                   0,
                                   -0.10378469389395309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039108840637442209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15221813954421173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52222781469127943,
                                   0,
                                   0,
                                   0,
                                   0.35651867539632354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12140964999557996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086455745568318476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55709267322635381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6681731111679593,
                                   0,
                                   0,
                                   0,
                                   0.70914814942603033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49180968581287915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092696792405901271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43913778122570152,
                                   0,
                                   0,
                                   0,
                                   0.047220113167138852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12285322533758322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53173616525766698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45777257337670296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2169488747982809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17856177395143313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.145734050801717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49580541854949189,
                                   0,
                                   -0.27062001048745077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42120050012622434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17293430410101152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54003717213658653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1913892894334418,
                                   0.24740887008949841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17613002282810974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092324200268781326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07188493135538368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32637388223205777,
                                   0,
                                   0,
                                   -0.40625693229068033,
                                   0,
                                   0,
                                   0,
                                   0.58634228708870506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17753924624808876,
                                   0,
                                   0,
                                   -0.36738982674545928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13936485233956106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17972331506674097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12632905919425141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33263682618512619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16162340452689752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8863243554408784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42431799439360396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0798890474497074,
                                   0.74178135479240903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3098853021444008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38338927789070576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2877144820475836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031774763575445807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32548890365979666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35920973995103822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14240081354766615,
                                   0,
                                   0,
                                   -0.23510534008877826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35851453629616059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39130244772254419,
                                   0.03079448407348781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099589793876814284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088210728910756181,
                                   0,
                                   0,
                                   0.082387996251322912,
                                   0,
                                   0.30777773146191245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45152055620200388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34255308047448962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21383632083449206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14720710669173553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20120600852392079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020051315447099226,
                                   0,
                                   0,
                                   -0.34230235691835886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63353452637347873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21889924215579021,
                                   0.26409300981839423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0022221673296013711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36118909618873846,
                                   0,
                                   0,
                                   -0.081950934280475674,
                                   0,
                                   -0.0034424730474936372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031406470316127366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18592791518035365,
                                   -0.00025849247341991344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41878780089816137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11943418082350687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37216112124684742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44598305124580628,
                                   0,
                                   0,
                                   -0.59437674749021407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044654540791926878,
                                   -0.48619005159810458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80177835413169374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81756172021590079,
                                   0.1236168503003372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33967814699171783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098897276030036299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14191721482369674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24898743503408288,
                                   0,
                                   0,
                                   0.50267619792734142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.016349601408316,
                                   -0.8016993159076925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21238969738399086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0025576099388780471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40824149340710469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50310491988286965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088699259118371343,
                                   0,
                                   0.10467925468986949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19244157827781011,
                                   0,
                                   0,
                                   -0.53335629485224456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26709026123247864,
                                   0,
                                   -0.089675505984427306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49511136416183044,
                                   0,
                                   0,
                                   -0.28299210098586175,
                                   -0.017453055303694849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46351924766053421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57766670917121099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32680113155877843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69801565220112616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025612358578905398,
                                   0,
                                   0,
                                   0,
                                   0.39558802968317186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31957976517553244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37224441506230732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031435335148985527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084522046845146054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45598474051009885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086314977875602633,
                                   0,
                                   0,
                                   0,
                                   0.70776778958670239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0020204857098582198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028033638081550499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33954502370689238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25286126129642,
                                   0,
                                   0,
                                   0,
                                   -0.82198552661372393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71988018031912393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26717600965929855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029131386368897991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083840421802189188,
                                   0,
                                   0.56320353930319556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31888055079136773,
                                   0,
                                   0,
                                   -0.22601889094121189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35323647347282799,
                                   0,
                                   0.33547941475941712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36562070443931943,
                                   0,
                                   0,
                                   -0.39718814181308676,
                                   0.595352929598152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32594325296072141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39512948206905918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058428265319058648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26701760438459354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20191660809525644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16705855281018633,
                                   0,
                                   0.12930069193567079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11589787934105003,
                                   0,
                                   0,
                                   0.39855101707458274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39086045907733696,
                                   0,
                                   0.39174627551548297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60159160184855698,
                                   0,
                                   0,
                                   0.5702939802544611,
                                   0.30130697393608358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6950168990194312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017924995137396676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38574918644898004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22415986992860504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57737936186889249,
                                   0,
                                   0,
                                   -0.051936271772984585,
                                   0,
                                   0,
                                   0,
                                   -0.25709662663314758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00081179161008142469,
                                   0,
                                   0,
                                   -0.071141718404658771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051266491342438228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050567215854220068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49301852042802763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11834266314377076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36258459928903419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28085699287693677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057968474558586544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029305057389864039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29431308318409788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039692872945480004,
                                   0,
                                   0,
                                   -0.22792611763655915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015441085797233269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40315768197177959,
                                   0.079688261713110178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6556495696332616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090128322709140785,
                                   0,
                                   0,
                                   0.17827534770339085,
                                   0,
                                   -0.12445096518903265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3497996728926101,
                                   0,
                                   0,
                                   0.095234566363216588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048769465688363225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081308931681908267,
                                   0,
                                   -0.52212887044756018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083917295491376359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5038573226449955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45257667029462478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49003600809211467,
                                   -0.0014013878933035635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058694183566682538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42581849859303844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058869512340937916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40544027958060891,
                                   0,
                                   0.67481484729901242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15371072140376701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22251197967750511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33031291270032415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0019912464400642649,
                                   -0.11480089148236787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0052622535616790589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61348969873502424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20604011389176374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63077375075872544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55138058651470701,
                                   0,
                                   0.31263028045419439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51318349752919035,
                                   0,
                                   0,
                                   0.17803788329723244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054658394173685523,
                                   0,
                                   -0.45308890015241865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019753849407294202,
                                   0,
                                   0,
                                   -0.19240510914172529,
                                   -0.36540562996867204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2800099470593726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16391791482941642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13139240651243259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60527634732736779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0074203549730786078,
                                   0,
                                   0,
                                   0.22801973597347186,
                                   0,
                                   0,
                                   0,
                                   -0.080680351860561009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37119468728226296,
                                   0,
                                   0,
                                   0.21545163513329418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046915960757112622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19411091908458217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0059601722494693615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57563843042682461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048363339131176145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12211219653443033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53455457508353577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48051238460615436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029807309738396688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23184978376350396,
                                   0,
                                   0,
                                   -0.18678636801329307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092113974130878129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1080788928081033,
                                   0.45422222512947641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081708156618066921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30282497294526461,
                                   0,
                                   0,
                                   -0.042115725906140253,
                                   0,
                                   0.1873471685624796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13107317268496388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33016174406142978,
                                   0.47785648812177051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57423942964253583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27876230388050155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38556688440644532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2134258905078215,
                                   0,
                                   0,
                                   0.32948466704820983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092977958611026146,
                                   0.51584228586723901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53994425603566865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1035042390558629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031108090726216883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31245849134399523,
                                   0,
                                   0.24881141060998924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35403842399798541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65039866267925295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48321111055077531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15019429649763269,
                                   0.12138176430620312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098159408504626663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17295894036282466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2444627209380314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14501683457342146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51425390236711122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42678967590411898,
                                   0,
                                   0,
                                   0.28638842293119449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29984667975511331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073579237637980202,
                                   0.26706801644786149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35142766778295831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0390622637098453,
                                   0,
                                   0,
                                   0.031620707596915931,
                                   0,
                                   0.20466390576199217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16157585767109323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20944884289317023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035314516609218069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36375356015616872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05308337191392621,
                                   0,
                                   -0.50045203647448944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19031268671956936,
                                   0,
                                   0,
                                   0.90171047611190724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36253533558112594,
                                   0,
                                   -0.04230329515411152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35481904049803048,
                                   0,
                                   0,
                                   -0.70897642726663246,
                                   0.50468455256066047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37404762840943889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42842796749641998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18067894235235674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4802140556679092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2129121013638362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052065211912834336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067607824132275396,
                                   0,
                                   0,
                                   -0.17125932837135011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0063730833868905594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23167781151771347,
                                   0.15781599078401942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025546046551050503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36637260993580945,
                                   0,
                                   0,
                                   -0.64610587203106307,
                                   0,
                                   -0.03189454095861393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15110921541200253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12671347551970519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84510824817908647,
                                   0,
                                   0,
                                   0,
                                   -0.37381096039280248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11475516590827589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64808821745604084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46890711728238688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36911559589789322,
                                   0,
                                   0,
                                   0,
                                   0.36849977364075198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67546114413766023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015908838920337842,
                                   0,
                                   0,
                                   0,
                                   -0.3545843277452746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53460349590147849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26188345262250323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25176430552068985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15756666131893513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0523235103619699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17365183614952368,
                                   -0.73879043514808218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15956869278722197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028991514360894893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47903547250821432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3989724818996449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21240788239267133,
                                   0,
                                   0,
                                   0.072531481286704946,
                                   0,
                                   0,
                                   0,
                                   -0.1557761923806037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31064340654245703,
                                   0,
                                   0,
                                   -0.32021039414719327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27686500334370379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10775409712218999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24361615747283843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16105883479785105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40510967632640599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2511108993212417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19981409267552827,
                                   0,
                                   0,
                                   0,
                                   -0.24009460166384722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58265621939080181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41192686109971233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54294830433730823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44680307308489881,
                                   0,
                                   0,
                                   0,
                                   0.43249007484778945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45557237561132957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082134938169554528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043817302134019895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34243697152085922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41049222017651338,
                                   0,
                                   0,
                                   -0.42729694059717016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11638443992780594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30403086204725105,
                                   -0.31286704878991306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31875649649001364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088478660873395912,
                                   0,
                                   0,
                                   0.0028931035763765101,
                                   0,
                                   0.024076857151855591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039369443426852932,
                                   0,
                                   -0.37991845947594011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23485234848977901,
                                   0.022476653828794466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33238005785561148,
                                   0.059170723322520061,
                                   0,
                                   0,
                                   0,
                                   0.55448813769816729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067619040048182588,
                                   0,
                                   0,
                                   0.18953469186703129,
                                   -0.7120360289801827,
                                   0,
                                   0,
                                   0,
                                   0.6655235308444386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13960376598228397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28338846427059516,
                                   -0.34788934707206581,
                                   0,
                                   0,
                                   0.83328720587755256,
                                   0.58439921235902814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51644812321421296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075011313700957455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32541713678256223,
                                   0,
                                   0,
                                   0,
                                   -0.27417986758794205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039414914678878706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36581993515902606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32929435775660759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3936323860194389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59797123885429881,
                                   0,
                                   0,
                                   0.18099295487294428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90695244206275905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051797862636787713,
                                   0.17919460000822365,
                                   0,
                                   0,
                                   0,
                                   -0.34115914504977407,
                                   0.48744420329097576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22229043562700559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42449067008896707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37099324036802317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051352700699199581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30765801153447719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19044609749087904,
                                   0,
                                   0,
                                   0.34151804247971063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28228126467234077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14465805855493072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20318394820330188,
                                   0.14857404870748905,
                                   0.58752081402121026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21893341143427161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23471258527184624,
                                   0,
                                   -0.4092804402596697,
                                   0,
                                   0,
                                   0.18634724551797238,
                                   0.042452168364236903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076617236434765465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23622477784963719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0056837164913535743,
                                   0,
                                   0,
                                   0,
                                   -0.81669778770318446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.4040002465736832,
                                   0,
                                   0,
                                   0,
                                   0.75267583892248269,
                                   0,
                                   0,
                                   0.31113193198328165,
                                   -0.71920373218470313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26691804760838972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65168660905000531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9601655667415312,
                                   0,
                                   0,
                                   0,
                                   0.15762008549485529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13919475366777936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54940097388599451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1851592077874929,
                                   0,
                                   0,
                                   0.027284178503067053,
                                   0.23258648437537427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10737203105113823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55514706884018461,
                                   0.054585177177535235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45078391943675866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18098940548148343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22444123723870318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59184499190304285,
                                   0,
                                   0,
                                   0,
                                   0.27569628577393579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81753532994017908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53186078996324992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042539276902347822,
                                   0,
                                   0.80430041021570298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063156735599553565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45132274672142436,
                                   0,
                                   0,
                                   -0.078014240751300867,
                                   0,
                                   0,
                                   0.067342289218216361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11130618061672595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14063382226535365,
                                   0,
                                   0,
                                   0,
                                   0.13184236111469994,
                                   0.38142046686239017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2260147178040271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26909926771214149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35893262645666046,
                                   0,
                                   0,
                                   0,
                                   0.076531953120570873,
                                   -0.55027663055344711,
                                   0,
                                   0.16023630039660142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16769320408721075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25501753608294409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36491816034901392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39617473907223211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2931019918252119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2843521006920639,
                                   0.4153469648306517,
                                   0.33145477331527357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031615141126508164,
                                   -0.49450156572788168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0078401546100890281,
                                   -0.0075161540903885132,
                                   0,
                                   0,
                                   0,
                                   -0.74687006331729933,
                                   0,
                                   0,
                                   0,
                                   -0.28221710298088315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46785247815186004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055493163479266999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19426635113857216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42277354263371092,
                                   -0.34263865429011442,
                                   0,
                                   0,
                                   0.53899668636837905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10132195813181077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37864610050675729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082943070365122426,
                                   0,
                                   0,
                                   0,
                                   -1.0668980540351087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65026067145795174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11361705037381582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14317676715783184,
                                   0,
                                   0.32058009793672532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35311393602133251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52596014169322269,
                                   0,
                                   -0.034729638128483065,
                                   -0.2114423206634555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013751762916471864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53958579915713478,
                                   0.040159819365550034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35820818979229163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85565714895220246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5699253434519812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028942482483973117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022403948778410107,
                                   0,
                                   0,
                                   -0.11910679501150995,
                                   0.8454239002747036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17452065275139775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040572820601764675,
                                   -0.32064858196101498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17106167316486651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25981680718597877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19505486809856126,
                                   0,
                                   0.52376048044685874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11272938947252195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16575076847979786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024120072534900672,
                                   0,
                                   0,
                                   0.43466537163263513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047389983199583693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13265593449901825,
                                   0.29602115426259296,
                                   0,
                                   0,
                                   0,
                                   -0.50487693985484916,
                                   -0.19565394155192434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99127875064399429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68789674596036432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37360748160839524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13769757504719499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12395581548403035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070528760331351914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087724144798008385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97921445754386049,
                                   -0.10577779611185389,
                                   0.43400292513220629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46291043134625043,
                                   0.31148427011730773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32547388914663727,
                                   0.45642886761676843,
                                   0,
                                   0,
                                   0,
                                   -0.31003862410360505,
                                   0,
                                   0,
                                   0,
                                   -0.72677762713568672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34720835097439784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52647459868872171,
                                   0,
                                   0,
                                   -0.41149427481346651,
                                   -0.13171977078466107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27434547424123079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41575908015173735,
                                   0.12556815374194857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19402855206685388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32330075950418169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097643988124193198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20140430887698885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41019064752633233,
                                   0,
                                   0,
                                   0.56153173993123007,
                                   0.068401482418851467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48553453924403722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15139050170438373,
                                   -0.070594441887771461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29084165270849482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31394000758322177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15617181550516493,
                                   -1.074057498854756,
                                   0,
                                   0,
                                   0.0015648790044847372,
                                   -0.64776667229014606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12566550474007565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82549355160017168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50662764485167777,
                                   0,
                                   0,
                                   0,
                                   0.10719466891224932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57201993404045293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092981839976617284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31854619514381505,
                                   0,
                                   -0.3821842832562502,
                                   -0.59407471586240668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11540536351819758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063685315913305257,
                                   0.48676110199280614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0578505056597531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41870634884504709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54884216252422791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33086549475068872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21466223768048059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63675608611758039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22446151887704102,
                                   0,
                                   0,
                                   0.93340070164423605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27297926277590201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52929744505216514,
                                   0.10559026786502822,
                                   0,
                                   0,
                                   0,
                                   0.53964515213304964,
                                   -0.013284353403349339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58706934045762982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27891375667991614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24779216440837742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63671153083956533,
                                   0,
                                   -0.73209884940706427,
                                   0.29592831562396227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46251747694663181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093888274822968187,
                                   0.14067471209734306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20854032254971583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083759854581067883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80375021667242019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71849200149049808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37960784975899081,
                                   0,
                                   0.73334089889104714,
                                   0.49677157777963982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63104337998430371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65711317552131376,
                                   0.13608824933166741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094473277033580286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035536237538625795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1822590906004796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024021831406810801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077940504324247067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12349891094493913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042060933759301117,
                                   0,
                                   0,
                                   0.54368987584364303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24523684153284117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5571447999320388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22347963680161087,
                                   0.22541318215973519,
                                   0.025715614418061715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3770508604223386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25805835326643378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08936358709649822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14854777721152901,
                                   0,
                                   0,
                                   -0.50434008708039701,
                                   0,
                                   0,
                                   0.19538311748409048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041596206005594799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035938218528714122,
                                   0,
                                   0,
                                   0,
                                   0.23974286634523023,
                                   -0.64914987598007368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062149982222481408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3299733133231213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21940711810190866,
                                   0,
                                   0,
                                   0,
                                   0.068371059376946597,
                                   0.1485524474550966,
                                   0,
                                   0.088844218295521499,
                                   0,
                                   0,
                                   0,
                                   0.23124043006405637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0005931193499062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40066655366859411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4781530130680095,
                                   0,
                                   0,
                                   -0.05388397861838555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15687773411988662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0902545157645533,
                                   -0.60056837286926423,
                                   0,
                                   0,
                                   0,
                                   -0.27243315280052482,
                                   0.29098033476029833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14835051815543082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23678359169421218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54014716797800921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17777731709788661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27763509061004515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036190019269192589,
                                   -0.14450197909643595,
                                   0,
                                   0,
                                   -0.26807254165973926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36033213325908436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61291300002881233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5919055996774546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01076152934548779,
                                   0,
                                   0,
                                   0.33288917975626897,
                                   0,
                                   0,
                                   -0.17271520075615565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34872969290323497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04133299071790994,
                                   0,
                                   0,
                                   0,
                                   -0.31625100044385634,
                                   -0.32156582138243267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02055186987863164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22084649187513947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061190189107253032,
                                   0,
                                   0,
                                   0,
                                   -0.090621058261104226,
                                   -0.28308813156981782,
                                   0,
                                   0.20212683735790518,
                                   0,
                                   0,
                                   0,
                                   -0.05100377117530585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33655809994981167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75563970390733604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46034289795144212,
                                   0,
                                   0,
                                   -0.28906086776612333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088411887323256791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47955343859380445,
                                   0.21968667245460052,
                                   0,
                                   0,
                                   0,
                                   0.92343619425137013,
                                   -0.42148233167528809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3128300036519418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32738850008336168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38632549781267106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35857275076006412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68830423667490903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27958705991895594,
                                   0,
                                   0.12469185652523553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3933172851143053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47216789415256427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33198099732014064,
                                   0,
                                   0,
                                   0.051321230226559662,
                                   0,
                                   0,
                                   0.036512892907077307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25355330952032584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010145824872343903,
                                   0,
                                   0,
                                   0,
                                   0.043933602712248623,
                                   0.20238120672045362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21087051953025021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31091293607395321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098426943246941206,
                                   0,
                                   0,
                                   0,
                                   0.42720953147773821,
                                   0.21935478954096072,
                                   0,
                                   -0.41731631151379933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21773229458793869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11986321829146016,
                                   0,
                                   0,
                                   0.045392503953356575,
                                   0.090167966950945616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24614104283522342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19173332379473881,
                                   0.65750807843561432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55118820360764786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.109567085557939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28732799976976298,
                                   0,
                                   0,
                                   -0.59226433926008237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076890569157289965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43419654890859166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17605198534892247,
                                   0,
                                   0,
                                   0.052890761390530908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36481877437249316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11559030777067379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33752842245748726,
                                   0.38114496611652371,
                                   0.036969513594729102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059351576068652649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10223640486906263,
                                   0,
                                   -0.1271247781918432,
                                   0,
                                   0,
                                   0.82930875575992735,
                                   0.26259313526963179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66616134111764702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23383253959152461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70073533931968468,
                                   0,
                                   0,
                                   0,
                                   0.17458956461729377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31041428469781629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75416450480342789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40740429925252941,
                                   0,
                                   -0.17786361767384429,
                                   0.46210913771750933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2932956882419584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70460112199342806,
                                   -0.4919689016337318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12073887270581632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16816697895661226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19194589373806084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06725086264681901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18719417342695999,
                                   0,
                                   0,
                                   -0.36045317803924043,
                                   0,
                                   0,
                                   -0.24892893003373026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36459230338296722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24881814142161818,
                                   0,
                                   0,
                                   0,
                                   -0.015863085888999321,
                                   0.0017357390787242286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65430934328717227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30004547752936828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10026625152046108,
                                   0,
                                   0,
                                   0,
                                   0.055342208753895512,
                                   0.10804825201798895,
                                   0,
                                   0.17467793319324221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50996376832079982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18145972240569166,
                                   0,
                                   0,
                                   0.19155907748476936,
                                   -0.36129222275028533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025889898524245017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15609253637208284,
                                   -0.5203818775876784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26589700656398485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37310756209396539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1844977980576113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15119371664378034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22807437957568624,
                                   0,
                                   0,
                                   -0.26219602732262792,
                                   0.025997131796579642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45593465130454952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22689875439964713,
                                   -0.34362709375797978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16986578251088927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61022057333497415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27755606111381026,
                                   0,
                                   0,
                                   0.085091722194374775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16149295083776677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11694169765616549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4606120779863403,
                                   0,
                                   0,
                                   0.023017983692386446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19638551326742815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59685102198147932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20674818481749094,
                                   0.056084287199642952,
                                   -0.23760080164872693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38597653704168661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30690397762877875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20179510320313165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32484382634902298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52670591718000903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036217923803458757,
                                   0.1152510724678024,
                                   0,
                                   0,
                                   -0.27647390470846406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67963386968863404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1529756094657756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08830640618050728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15750668669469739,
                                   0,
                                   0,
                                   0.063694658148933353,
                                   0,
                                   0,
                                   -0.12344242181279831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15953542316544075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59361221977162537,
                                   0,
                                   0,
                                   0,
                                   0.7022814213844224,
                                   0.033261093715990703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10027189257986149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080450541848531579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11138207723128159,
                                   0,
                                   0,
                                   0,
                                   -0.058310905814496723,
                                   -0.20731007984034866,
                                   0,
                                   0.025607171194760605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2889433107962629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2528792244385587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0068406614290371578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12349333991986497,
                                   0,
                                   0,
                                   0.42701991181784665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071418688085242737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13350475330276895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1440293594911797,
                                   0.41351275966295209,
                                   -0.48085377787399497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15739667867202828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42926096856893092,
                                   0,
                                   0,
                                   -0.14231345849266819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0557951415038611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10594205509025079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24725960861741375,
                                   0,
                                   0,
                                   -0.86721018284496965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35580597128922448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78683213060979795,
                                   0.16111138797660007,
                                   0,
                                   0,
                                   0,
                                   0.083164401302016855,
                                   0.040930465268240082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022484781103473434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49128687294626816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6394897175633989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15145792403350616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1072207225364166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30870189112565205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48456257884098974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33968642767926716,
                                   -0.55249609742234529,
                                   0.45038361310368724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46485421137139771,
                                   0.34218295798304804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049247947135908805,
                                   0.020873164415168566,
                                   0,
                                   0,
                                   0,
                                   -0.16347929020995233,
                                   0,
                                   0,
                                   0,
                                   -0.47613669369192724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19715168584501597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2599665221228698,
                                   0,
                                   0,
                                   0.16868215778885337,
                                   0,
                                   0,
                                   -0.23116017146659965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24585865341950597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46792889417062616,
                                   0,
                                   0,
                                   0,
                                   0.37774797606706012,
                                   -0.14404833379336515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15454274459342532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0045952338691983927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24436981299592087,
                                   0,
                                   0,
                                   0,
                                   -0.45147804477741849,
                                   0.1054914946426348,
                                   0,
                                   -0.2650103387043844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32186758567991663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44095621152658365,
                                   0,
                                   0,
                                   -0.082183408122161045,
                                   0,
                                   0,
                                   -0.048584826585314295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0068360618389321226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36863745924031727,
                                   0,
                                   0,
                                   0,
                                   -0.18581314317172848,
                                   0.029926867961448573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037675891338532455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46361421809654374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3875317539106839,
                                   0,
                                   0,
                                   0,
                                   -0.14399529339753267,
                                   0.1864292503257754,
                                   0,
                                   -0.31536144812843409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0643364754815299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80802285069802249,
                                   0,
                                   -0.26102472773003055,
                                   -0.14165986669787195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14337783098786802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48119744981466245,
                                   -0.37965158897544321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06266138656829788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51182683897036774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36812404586077724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.334409608112678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28513659382476969,
                                   0,
                                   0.487352396299363,
                                   -0.69192520612004893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42168695341839652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21407392130250591,
                                   -0.48901989306859173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027980980814717775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10430210083055808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13175375889343713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21092623119736412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5266628847906949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26012004915571318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85127789503302198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37900043588772603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040787690152402613,
                                   -0.61339217942609192,
                                   -0.55965888313511158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03432290959213366,
                                   0.11956411809038664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25975535578447129,
                                   0.25556001112276699,
                                   0,
                                   0,
                                   0,
                                   0.095694437923466366,
                                   0,
                                   0,
                                   0,
                                   -0.47647073505997362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37701246820061335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57727735017179727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069308986683875418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39632513363402716,
                                   0,
                                   0.57538601476027385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17794956204785761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42289229126017913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13901010376799736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18071201609289925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71292918223092616,
                                   0.33932835552604873,
                                   0,
                                   0,
                                   0.13208928824802901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.354216081933452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053414452839423393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18836002251370126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081362337758208503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46546220667151961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38257267553546409,
                                   -0.3805208629972468,
                                   0,
                                   0,
                                   0.21749769209510691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50025353389701044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39054933438422557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61074935956738263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094333908067943673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38365282959657843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83097296987274216,
                                   0,
                                   0,
                                   0.15407760064108827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24861416730179592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048441011847819571,
                                   0.14925510882760121,
                                   0,
                                   0,
                                   0,
                                   0.23636399138309827,
                                   0.36155331777549865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17445686428844151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64438468975674978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29431544916912417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20151620139519968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25923973458991506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91645591419293571,
                                   0,
                                   0,
                                   0.14295151028598613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75269108781790295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6559549090866974,
                                   0.85476961323291056,
                                   0,
                                   0,
                                   0,
                                   0.21930045356301214,
                                   0.33334029361258527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12609404634690688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19861367541661767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024395254754861706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66288398523338066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19347303131660093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21159076104298249,
                                   0.52595009962353878,
                                   0,
                                   0,
                                   0.41493083237771988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1187895941109416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12200475007250743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4731415948715485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20549361758484322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38289437566065471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8439417897245427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4756266179148374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15473162531017856,
                                   -0.051479031458436297,
                                   -0.19774029617100031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46460036743729194,
                                   -0.26326404862656455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69115029482951706,
                                   -0.036901495180387614,
                                   0,
                                   0,
                                   0,
                                   0.80256064608131106,
                                   0,
                                   0,
                                   0,
                                   -0.10672407681564032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5256146555174469,
                                   0,
                                   0,
                                   -0.65481339559687679,
                                   0.74644745070301433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44053642133232312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0415817982935436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0058877501667059656,
                                   0,
                                   0,
                                   0,
                                   -0.25363449914801733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19907844041840303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81575975791773692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75601325864824898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011772291525923309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094138839829386561,
                                   0,
                                   0,
                                   -0.48517740116922886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064199531978768987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17317458200893243,
                                   -0.021999372586621005,
                                   0,
                                   0,
                                   0,
                                   -0.36908761344776897,
                                   0.037043765550390566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58944108828878061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45453896423946832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10649993443379246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029089819128049449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30039191162676909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21965264126336281,
                                   0,
                                   0,
                                   0.10856614572929357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68414789623635774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10796506459883809,
                                   -0.82293534910529076,
                                   0,
                                   0,
                                   0,
                                   -0.23392666675084442,
                                   -0.2445878645373909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48754867583126821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52151801429228872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21226986836356612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54911665445804969,
                                   0,
                                   0,
                                   0.26985141360676695,
                                   -0.1600836801833215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51992238892676101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34455953767803871,
                                   -0.13647091516046889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19989526792565204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2694215998379797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18642649999352456,
                                   0.0033044675231298087,
                                   0,
                                   0,
                                   -0.21361085598525389,
                                   0.0086755729808223186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93902435575058696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051715444772876644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74584581633186553,
                                   0,
                                   0,
                                   0,
                                   0.66820645194185024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06461276128334531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038914538319643158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065616150615324553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5215789370198527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57996422186418373,
                                   0,
                                   0,
                                   -0.092333860715854504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16624357048362076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.371416796015754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1499179434275987,
                                   -0.11183221402761272,
                                   -0.13519077195041904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2190614259254996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33229189483211824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26992891653884105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40316136652533757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30852668490292029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54458648693449463,
                                   0,
                                   -0.4321583786827583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4313644297378269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20552383154309159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69447086165528749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51719204341754343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39710234030940617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022892282154370405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24176726247275809,
                                   -0.042875383531788346,
                                   0.010420511343657138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73466097841226108,
                                   0.022624501926814984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050355989654050186,
                                   -0.47109933293799555,
                                   0,
                                   0,
                                   0,
                                   0.20276886270997252,
                                   0,
                                   0,
                                   0,
                                   -0.78594791038838352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23906742518211618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34483761954821635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018416618598899599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29442313245404572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36965488688883313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31260473918628545,
                                   0.24875349847207173,
                                   0.72564245377772818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2890219473281565,
                                   -0.24301306172827031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37668200674116586,
                                   0.5211538006385048,
                                   0,
                                   0,
                                   0,
                                   0.25628536754391046,
                                   0,
                                   0,
                                   0,
                                   0.33019695907884261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58389775507006036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64446439008876921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24679929327318856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0066332025521019244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20221234559302392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47346041897635582,
                                   0.37900332782091561,
                                   0.28913646896774836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19490318316423388,
                                   -0.55431747251856678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22383121662704875,
                                   0.40119331315364426,
                                   0,
                                   0,
                                   0,
                                   0.44400829731592556,
                                   0,
                                   0,
                                   0,
                                   -0.26474464063115044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28319176335651741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13654866199858354,
                                   0,
                                   0.29037358028230809,
                                   0.61364025026538216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64107141814923674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37903867599101015,
                                   -0.11436465892256072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19122677415323661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46684865298051736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75248691206813301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13261205760695022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5296997825654618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15284141370341234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02989693063438164,
                                   0,
                                   0,
                                   0.24848775345998619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46226933049708224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30845324432854032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044763113146653502,
                                   -0.23977424238726003,
                                   0.21516210843522396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088330820389965828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43977592760461964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38872218189088004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21262256034221888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44580913468461431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54423169835122376,
                                   0,
                                   -0.12778286379693873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54076272597218089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1000331463392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37645605259181114,
                                   0,
                                   0,
                                   -0.29327253333223846,
                                   0,
                                   0,
                                   0.15948774445346695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18588992113634711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031509957092893226,
                                   0,
                                   0,
                                   0,
                                   -0.07595005935016938,
                                   0.029624772349128622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034240478271456973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076104453926812657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69358199931843478,
                                   0,
                                   0,
                                   0,
                                   0.35332978352992306,
                                   -0.15783599163105264,
                                   0,
                                   -0.23845479154889163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50933684602936702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44405569973685122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38442294737856841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37108318492522119,
                                   0,
                                   0.033406263658984747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5067453026431985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2275969178619624,
                                   0,
                                   0,
                                   0,
                                   -0.20660529327789812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72445538630813444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55259885626931315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85691482547806463,
                                   0,
                                   0.50428361984385495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20449219335964819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26772153515840252,
                                   0,
                                   -0.085758831270558944,
                                   0.68741737658421109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54067101344137602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47790278388775326,
                                   -0.61854996240857607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70728574729067439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078661706287291966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29181302090079403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23850996661916105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59228624147930076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082548038401224474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23020158530117255,
                                   -0.5578868531664013,
                                   0,
                                   0,
                                   -0.021230385870013118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054976605658434319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46668207386695837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0097625885291185849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53295936385049003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036736430146938406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23900595777849012,
                                   0,
                                   0,
                                   0.12721209033082034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40001883643480574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093676958978724925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48650261116495164,
                                   -0.14328839290750869,
                                   0.26943850529379226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37762048423648564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0012428439003575251,
                                   0,
                                   0,
                                   0,
                                   -0.18954605990557913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34705978301434964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2103836204790589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17981772651205161,
                                   0,
                                   0,
                                   0.0078880611135272449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39831900238055973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16375539542207379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6728691084716163,
                                   0.29368107649316272,
                                   0.058955691389604131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067586823762683892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18559329955556836,
                                   0,
                                   0,
                                   0,
                                   0.026344230326316352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31553136629782452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21729527314923414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22284608458051555,
                                   0,
                                   0,
                                   0.30882673816866912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059056676940692866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050220984228929844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05141465534423325,
                                   -0.4477963296693675,
                                   -0.46419299629427568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32355402489612012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42208668330582855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25707924444203373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24869617296297214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42758963584392745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43264587574958074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32409210785686976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45306828381015396,
                                   0.217938923491311,
                                   0.020934068978372446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093810302498857925,
                                   0.1297002119728031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13373852589298676,
                                   0.68794731135239406,
                                   0,
                                   0,
                                   0,
                                   -0.66565546157179334,
                                   0,
                                   0,
                                   0,
                                   -0.053229560674865437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14306618523181919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039427438317105684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11642287609770324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024012990886727564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8095559809223869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28727342642551368,
                                   0.61200314669763833,
                                   -0.4236486808375442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0073709544906191971,
                                   0.59190922635306498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28640953925278823,
                                   0.43285244233562747,
                                   0,
                                   0,
                                   0,
                                   0.18174972527012284,
                                   0,
                                   0,
                                   0,
                                   0.50800066340309658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42051671930597617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2088789461286879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56053753397450401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25738645102814034,
                                   0.025179607788706475,
                                   0,
                                   0,
                                   -0.56904368323426935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071668626314780909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26363619707120134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6760441840755228,
                                   0,
                                   0,
                                   0,
                                   0.30586096822428888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051239355741201448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73371668857900851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1519769069350487,
                                   0,
                                   -0.36438138530629566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14713728620823838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46604125062334717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81977308167151308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096193959807416976,
                                   0,
                                   0,
                                   -0.2479051061187926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13668447141135115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17555090726459305,
                                   0.79917952943299653,
                                   0,
                                   0,
                                   0,
                                   -0.61991091597002546,
                                   -0.052817814313376843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049563567143671564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48126133049220821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074974570843482968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28860229777470003,
                                   0,
                                   0,
                                   0.10354125352082377,
                                   0.075867505497860949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092099443507698664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16186684946275923,
                                   -0.1138315330115844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44853302567817704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038036646129966656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80270878526700851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8465308379601324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58673214255032524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17318142323336491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19433780247114105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36598925754274036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27271515487487863,
                                   -0.48543565297741431,
                                   0.29015120360493807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2509070476893841,
                                   -0.08452458685150048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68560082725086002,
                                   0.21515266949362272,
                                   0,
                                   0,
                                   0,
                                   -0.080848742923485456,
                                   0,
                                   0,
                                   0,
                                   0.20709840652310754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.327169710603192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53478975375314164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073215822149334309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41183982884446158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43923971735707751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29165484567048816,
                                   0.23864393572754081,
                                   -0.72020339388778409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85961079501261717,
                                   0.075740092880417192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22102866631973031,
                                   0.18373669440452714,
                                   0,
                                   0,
                                   0,
                                   0.15170698227610585,
                                   0,
                                   0,
                                   0,
                                   -0.43483974755472821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32578380179780142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32486974800361479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24572694589511765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039383403037245211,
                                   0,
                                   0,
                                   0.36588432131287218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30767466656216647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022726943568775582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1187094167937191,
                                   -0.47932405890669544,
                                   0.094532487843829782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41423920494498512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27012263270616876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15205846866382081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023840866531069434,
                                   0,
                                   0,
                                   -0.33456723043060127,
                                   0,
                                   0,
                                   -0.76300805594657173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09591263083874349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090633070794781515,
                                   0,
                                   0,
                                   0,
                                   -0.10477221625160742,
                                   0.14628036971974723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25408856683057823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35241949917159149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0038914453166363529,
                                   0,
                                   0,
                                   0,
                                   -0.041163854872273635,
                                   -0.0049341412596067731,
                                   0,
                                   -0.20471957575823344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67074538905473391,
                                   0,
                                   0,
                                   0,
                                   0.67503435597494166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08139096252626643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8039602042967724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13210519395521841,
                                   0,
                                   0.42008061247371675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2108979917837781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074457109138976213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0211351766649954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23543047928446045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16607518273444111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010584721574907707,
                                   -0.40764275002501738,
                                   -0.052618064781641112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087036892068671518,
                                   -0.40534291673210521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46362026292659914,
                                   0.41395732620494002,
                                   0,
                                   0,
                                   0,
                                   0.2538638464925384,
                                   0,
                                   0,
                                   0,
                                   0.31380192947451413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8508461587642111,
                                   0,
                                   0,
                                   0,
                                   -0.073864301784354436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82507860013155765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1684462670578305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091780966004329001,
                                   0,
                                   -0.9238703576924614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4745773184214464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36502539404423179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28234383259346973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18518140025306887,
                                   0,
                                   -0.67020711122537979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27990188960140422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11903042841742445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23306946184474056,
                                   0,
                                   0,
                                   -0.35755108434717509,
                                   0,
                                   0,
                                   0.078289082354832701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50978168693390291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27849591274361035,
                                   0,
                                   0,
                                   0,
                                   -0.3109390624942619,
                                   0.034130088148786854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23175735639006739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035612554933468044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23666121541202884,
                                   0,
                                   0,
                                   0,
                                   -0.44304670584511546,
                                   -0.20799225266109206,
                                   0,
                                   0.10822985523919459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42783956517776622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33558838080024733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61154361010687996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34444327047004208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40503365592933704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22696179720291965,
                                   -0.32390205688102408,
                                   0.037940348443095497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45171514577712324,
                                   -0.532655482589665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23357605753744379,
                                   0.31734523625777389,
                                   0,
                                   0,
                                   0,
                                   -0.7758704826894427,
                                   0,
                                   0,
                                   0,
                                   -0.011537720538824264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094307055322940814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011980723152158382,
                                   0,
                                   0.42977892772112941,
                                   0.31558870774164954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79268904950744468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22401652079148865,
                                   0.33624206464194029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59223574503950771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53759445532635153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27988834272729729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22589690341977597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035033358546764842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42849942057565765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55633422221590756,
                                   0,
                                   0,
                                   -0.22628493519605411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31647249101667146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32799809355737508,
                                   -0.38494750178738196,
                                   0,
                                   0,
                                   0,
                                   0.29734077465743658,
                                   1.0927746577201329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47301583127396618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09297885937751274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42185588866873519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24818904890092189,
                                   0,
                                   0,
                                   0.35305753654146305,
                                   0,
                                   0,
                                   -0.10393729244127591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07632609980852148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31383814263331444,
                                   0,
                                   0,
                                   0,
                                   -0.19081265769218084,
                                   -0.2802994106077733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55606074433349739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24238072292041316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020701042937724144,
                                   0,
                                   0,
                                   0,
                                   0.093541020898332453,
                                   0.092916337134894181,
                                   0,
                                   -0.14115973015760769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1187831562388926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1421800670624532,
                                   0,
                                   0,
                                   -0.080199826002595592,
                                   0,
                                   0,
                                   0.39829449170251113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50182390405779753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024078053207235481,
                                   0,
                                   0,
                                   0,
                                   -0.042978711310638101,
                                   0.11901831938128549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076535507048185847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27172845685816893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099279449675321124,
                                   0,
                                   0,
                                   0,
                                   -0.45254121672816916,
                                   -0.067782048470326456,
                                   0,
                                   -0.48295647489415194,
                                   0,
                                   0,
                                   -0.51841903222715358,
                                   0,
                                   0,
                                   0.32167083359997839,
                                   0.28407795309477052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024999756419380764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2863899374880865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47881892216195088,
                                   0,
                                   0,
                                   0,
                                   0.99795860443387641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4174844352145618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14343607234844941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25222462032074822,
                                   0,
                                   0,
                                   -0.0067874566860379182,
                                   0,
                                   0,
                                   -0.09969598908709712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14079110101325129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14879825446565109,
                                   0,
                                   0,
                                   0,
                                   -0.028979886984555052,
                                   -0.38708103294277618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046709230556168012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31298549115230778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17284219208310833,
                                   0,
                                   0,
                                   0,
                                   0.17705323859255964,
                                   -0.6040786343949871,
                                   0,
                                   -0.43233542601900166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50826042690415285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029397811300357707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48911234141765847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47500605395290957,
                                   0,
                                   0,
                                   -0.29382196409401168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15893770749989425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097592179322247438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026576014648833808,
                                   -0.025564399807346257,
                                   -0.0078147435077075712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39165012685620154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0042406633957628517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39394663043732026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18880977043180563,
                                   0,
                                   0,
                                   -0.55622029709375942,
                                   -0.19599043068601793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31475523283985002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48668176191345169,
                                   -0.14379961395097535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028138670133155935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31470338446084228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070180675668956791,
                                   -0.10581912671828062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047528467489406062,
                                   0,
                                   -0.3105755575677917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33274642851031355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45038166377612976,
                                   0,
                                   0,
                                   -0.2136068175940754,
                                   0.32001919718686617,
                                   0.019709932055303678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43990463257474122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48433214348717585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3119603710726464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83221900826226802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064201906729886848,
                                   0,
                                   0,
                                   0,
                                   0.24157463508001403,
                                   0,
                                   0.50945782374802207,
                                   0,
                                   0,
                                   -0.30379044638962727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47586766588993656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23758692704596959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19113763313624607,
                                   -0.082513865000976544,
                                   0,
                                   0,
                                   0.3915769144317926,
                                   0,
                                   -0.43649939964458734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18240507420717739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93218572273575229,
                                   0,
                                   0,
                                   0,
                                   -0.39111187269181641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075955912950153928,
                                   0,
                                   0,
                                   0.53902319755805828,
                                   0,
                                   0.16850100936962997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08447189680807575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0010108262317971026,
                                   0,
                                   0,
                                   0,
                                   0.19531329015370028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0095633603938559252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075539508961961183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27299537391822293,
                                   0,
                                   -0.10636099281150979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27440180062108888,
                                   0,
                                   0,
                                   0.44208497397906565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3386259257372683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94000054308602832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60735810986945749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39630382077306398,
                                   0,
                                   0.24702195571747854,
                                   0,
                                   0,
                                   -0.12545167900706089,
                                   0,
                                   -1.0679061369118545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59353666321532383,
                                   0,
                                   0,
                                   -0.26071661949996305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21679316595749204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36011377136738876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040528521111178842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068022854635214014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59013354620445679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38057176668262133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32446588281234084,
                                   0,
                                   0,
                                   -0.6287763904305298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16459224358696764,
                                   -1.1282940286369811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4913663517056539,
                                   0.3707249325753072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049126987151724574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084496265077910873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26083892605285369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063037234970813247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24731730508504213,
                                   0.34372244088584603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15704196853347746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047721910084667932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074177061681112821,
                                   -0.16438016186679474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24201167888913994,
                                   0.27033120891441531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22907991445624054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0333799478737087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20220746803774614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5182414942739908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34019775282807779,
                                   0.17745541870909695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22740053908646637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3090311832377014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025491514737493212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092902390029267257,
                                   0,
                                   -0.3418881545293439,
                                   0,
                                   0,
                                   0,
                                   0.51954703898998844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36007214620424843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39961022403948043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86107490241571616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60897288843063158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38692691486389991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0643902026911925,
                                   0,
                                   0,
                                   0.029978933301895466,
                                   0,
                                   0.20318526851788704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42293915780040503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24889291990758033,
                                   0,
                                   0,
                                   0,
                                   0.3429473427609353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13932704256115977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3157751294675154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12907728212767991,
                                   0,
                                   -0.16220375610718299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4461781865473432,
                                   0,
                                   0,
                                   0.2891470164318925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02724786562136354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11083133657414039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35153196429624795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67534971672436173,
                                   0,
                                   0.56031266982769024,
                                   0,
                                   0,
                                   -0.046005421697721302,
                                   0,
                                   0.53197800728330069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048902480929828865,
                                   0,
                                   0,
                                   -0.087405493576940982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098310135170650778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71123863180352032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34916390225197397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38323302635096029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34213572755475241,
                                   0,
                                   0,
                                   0,
                                   -0.026336704264914752,
                                   0,
                                   0.10522379833741402,
                                   0,
                                   0,
                                   -0.92147682127825148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056119445202491541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37793927862846577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47395342424539777,
                                   0.10396578292414327,
                                   0,
                                   0,
                                   -0.068907899325490143,
                                   0,
                                   -0.50037145208174982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0403544107042655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61081712506551944,
                                   0,
                                   0,
                                   0,
                                   0.40534705894217765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33854610995989776,
                                   0,
                                   0,
                                   0.27705347556846888,
                                   0,
                                   0.24543036007942121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078382570668524762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38846391413816578,
                                   0,
                                   0,
                                   0,
                                   -0.45540469069192047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076245016033308272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3542806480106972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25730438568288894,
                                   0,
                                   0.14549703442679637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014650451679699181,
                                   0,
                                   0,
                                   0.018564187437758964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019541040280051495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40380544139199631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16286264813290433,
                                   0,
                                   0.33368139246870004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048730067860794091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32947035410922532,
                                   0,
                                   0,
                                   -0.65186373542436682,
                                   0.21932989529048152,
                                   -0.27523682768963648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029060398361603332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19625638159253342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025537912861678481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053290336911075223,
                                   0,
                                   0,
                                   -0.37005704428745728,
                                   0,
                                   -0.17729874285545982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022554931604104392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17247473958236478,
                                   0,
                                   0,
                                   0,
                                   -0.0481320119292264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52719591193614423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08476317515718286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3103714037660214,
                                   0,
                                   -0.49895124436330313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031208380199927742,
                                   0,
                                   0,
                                   0.36340248388094326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17921924341380557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32825129876743758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064944742670075828,
                                   0,
                                   -0.27919872973574633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30341270276589705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44624884957354188,
                                   0,
                                   0,
                                   0.020861055792782572,
                                   -0.14424506750762042,
                                   0.33498497100741581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54455006804774231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29814845306462701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69508264793305696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37412810264346241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20643985485516936,
                                   0,
                                   0,
                                   0,
                                   -0.030936994906123227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46570039898622029,
                                   0,
                                   0,
                                   0.32404504807669282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051907015614368529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093473905232368176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14395063091273907,
                                   0,
                                   -0.10972228759633607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14669811518538062,
                                   0,
                                   -0.34060742793377963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.364769513944873,
                                   0,
                                   0,
                                   -0.12718599470447917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16825047005959648,
                                   0.39011829514367696,
                                   0,
                                   0,
                                   -0.085331515274511882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49753212993372686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49104023914209705,
                                   0,
                                   0.063495620290294624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30249339885851673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55061845230694062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65125390337185829,
                                   0,
                                   -0.43301714431695199,
                                   0,
                                   0,
                                   -0.83971983811791884,
                                   0,
                                   0.29309824937316714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31681679548536812,
                                   0,
                                   0,
                                   0.02238636199821107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45486367044449461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096985395222544651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35230709187521064,
                                   0,
                                   0.25744478136039473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47581362533386534,
                                   0,
                                   -0.56100964920887986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15895888908678726,
                                   0,
                                   0,
                                   -0.047411073730306355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031621031239486501,
                                   0.068873805859407985,
                                   0,
                                   0,
                                   0.35353870467862036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31648060767041725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076501515824653005,
                                   0,
                                   -0.064885770882278301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080818813501531514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49352268003470184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39843495811823143,
                                   0,
                                   0.55980844383556438,
                                   0,
                                   0,
                                   -0.15528760879307002,
                                   0,
                                   0.50557082926965724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039795348595259558,
                                   0,
                                   0,
                                   -0.86359199398327002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74759513318529158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52054945301431854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27688172531816385,
                                   -0.15686292013929465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2475048847523017,
                                   -0.42111704336280648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059194983035776721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22154230473944103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23131958447907772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42456079492968435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53538623000656504,
                                   -0.62984889076871475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83799396750464994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023813059104670103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28722147431274653,
                                   -0.24023874744271986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37890650160753886,
                                   -0.23522966716080942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23367010214443973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1134750585811732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80128981119079512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098741106602319453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024899849812130941,
                                   -0.30728415908555001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25024797497343032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55247003048829146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010120761704716166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089419869157173149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98883368157582241,
                                   0,
                                   -0.25414875187774111,
                                   0,
                                   0,
                                   0.71246487534490277,
                                   0,
                                   -0.062261238830547933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58358011485103989,
                                   0,
                                   0,
                                   0.069141806225562472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65630304463635503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5287472813035341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19761228830922278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82236697399399927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15841210640332987,
                                   0,
                                   0,
                                   0,
                                   0.64911466349654112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64927491107507662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50426215457991108,
                                   0,
                                   0,
                                   0,
                                   0.074531483386139505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37247858951143753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65896471267253975,
                                   0,
                                   -0.48482419692136558,
                                   0,
                                   0,
                                   0.30929714239945061,
                                   0,
                                   -0.078918079390064677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25550518781686216,
                                   0,
                                   0,
                                   -0.5650812338126332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021243950407279742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86792151486023628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020597281440501838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43022925775793486,
                                   0,
                                   0,
                                   0.12960515724814137,
                                   0,
                                   -0.1364595533614377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53609905088136911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20775590185099019,
                                   0,
                                   0,
                                   0,
                                   0.092494298787123785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22283680279952076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31397928769071926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18198492432363164,
                                   0,
                                   0.048015683202730898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46582410393721974,
                                   0,
                                   0,
                                   0.14722359980272506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13270189304031341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058476814649603609,
                                   0.40787473799197577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33399095120393263,
                                   0.68000696639831282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66541005455138413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32783225363676055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02567667103115142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14725353628746204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40056560242085187,
                                   -0.42876222189150648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20888398035930342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90701109347312348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35555402498357436,
                                   0,
                                   -0.31860185854314288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30347513880922777,
                                   0,
                                   0.15671941076454254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29522299828311321,
                                   0,
                                   0,
                                   0.57537664189732052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011697385293422902,
                                   -0.16091002185774395,
                                   0,
                                   0,
                                   0.43535358468034979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11175135461349237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088323272439813735,
                                   0,
                                   0.036744868287147014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040277110908790964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57884967269951093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67377077833861632,
                                   0,
                                   0,
                                   0,
                                   0.31273380715778643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31865381981652374,
                                   0,
                                   0,
                                   -0.090629737525043011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.001209813754170258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042259259497040458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10143456505636789,
                                   0,
                                   0.32121916539463546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63724338953450821,
                                   0,
                                   -0.31091857099149567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38889333248167546,
                                   0,
                                   0,
                                   -0.062804963413569129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12076787411886393,
                                   -0.11037441641434664,
                                   0,
                                   0,
                                   0.067562729384123096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14120257977534714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23746697310776974,
                                   0,
                                   -0.34775918183720905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0028716486417514932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090386087469518733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20063438740232958,
                                   0,
                                   0.42480564256494496,
                                   0,
                                   0,
                                   -0.59685329600408921,
                                   0,
                                   -0.27462891823986574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39928656570979354,
                                   0,
                                   0,
                                   0.78310249662928599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61995168101362041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2617199972038593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16935058435226794,
                                   -0.20809022646724498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16126125365854255,
                                   -0.16610329744997931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32730789588658082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33398632873732392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11761515894266134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24897233359988669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6839919781172592,
                                   0.56152036817574058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   5.4365970064841618e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83761836810196422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051348529553210023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0014256846657753584,
                                   0,
                                   0,
                                   -0.06860642830799478,
                                   0,
                                   0.15760918017285924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064131788838706377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17880260611949075,
                                   0,
                                   0,
                                   0,
                                   0.14911036292029536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50491619209796279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27446114211853462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61677668878759051,
                                   0,
                                   0.22183755105511824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.004976095667565926,
                                   0,
                                   0,
                                   0.14601200377682919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35813085931034983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28480374721984852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68285745213488325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00026401833861677479,
                                   0,
                                   -0.49588454791544812,
                                   0,
                                   0,
                                   0.72151203525859509,
                                   0,
                                   0.46599408463175157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4553501250933466,
                                   0,
                                   0,
                                   0.45871528197046968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43729167853310497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24443003976226618,
                                   0,
                                   0,
                                   0,
                                   0.15339620585969471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090759525332313407,
                                   0,
                                   0.26526514129755679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71407132587283118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19502026531697866,
                                   0,
                                   0,
                                   0.018295131850435232,
                                   0.23952516951997591,
                                   0.31347281119425785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43862975513717101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039593824655865091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19565019654911819,
                                   0,
                                   -0.1177911499936557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078710544727893822,
                                   0,
                                   0.32392118134671982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43594014728173086,
                                   0,
                                   0,
                                   -0.18191754064262458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.008373893855899546,
                                   0.52746253117637276,
                                   0,
                                   0,
                                   0.50678513069422759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20951818654636009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077294701678761096,
                                   0,
                                   -0.16910885962664193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12461717386212648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1689505042632149,
                                   0,
                                   0,
                                   0.049969849605182609,
                                   0,
                                   -0.067486603774328136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5057833096176344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28141324170578147,
                                   0,
                                   0,
                                   0,
                                   -0.27007117182373097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031363186844763802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6562325510105087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15114338865331839,
                                   0,
                                   -0.15700099253148336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057853698211653405,
                                   0,
                                   0,
                                   -0.014069625500944077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24137688775252295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17301078555599206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2770125782446804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98701901389602476,
                                   0,
                                   0,
                                   0,
                                   0.1479677930704959,
                                   0,
                                   -0.11153508179167901,
                                   0,
                                   0,
                                   -0.30650800932904682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26193309922087715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33720365971186783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51540502571674573,
                                   -0.3819384067249435,
                                   0,
                                   0,
                                   -0.45930412260959358,
                                   0,
                                   0.48684719997295384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36491138603813761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42672977214587315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22394742793588476,
                                   0,
                                   0.091699537359297326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25176582487979554,
                                   0,
                                   -0.37635218857763619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02681525509362781,
                                   0,
                                   0,
                                   0.34680321171195172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13059720616978324,
                                   0.27677260272236598,
                                   0,
                                   0,
                                   0.05251388106245012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28941572022346457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6264076312905259,
                                   0,
                                   0.20701649004890726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92140382805999377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071342126433816377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18685091867670861,
                                   0,
                                   -0.39955339474480966,
                                   0,
                                   0,
                                   -0.35956166399058459,
                                   0,
                                   -0.66901920846634233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82382109673072801,
                                   0,
                                   0,
                                   -0.075243403329596614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67811391632478735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25654530309804757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076108399453772818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031630388763459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44172359724640831,
                                   0,
                                   0,
                                   0,
                                   0.28347252956953417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48227566957744233,
                                   0,
                                   0,
                                   -0.37460462626427316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5648692175146548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1604211278909925,
                                   0,
                                   0,
                                   0,
                                   0.60616645583891537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18444188628498337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14686459906639848,
                                   0,
                                   0,
                                   0,
                                   0.55763525770925915,
                                   0,
                                   0.019731254904660579,
                                   0,
                                   0,
                                   0.19210705836553288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74100269576862354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22759274203362501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66212036212936409,
                                   0.65688940708283372,
                                   0,
                                   0,
                                   0.33624371556581722,
                                   0,
                                   -0.35725549466677814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31326204043230549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38260569678876633,
                                   0,
                                   0,
                                   0,
                                   -0.25303406190689615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47100218712733488,
                                   0,
                                   0,
                                   -0.0018145039648233413,
                                   0,
                                   0.053888931818991959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092940973644442385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31133235772196288,
                                   0,
                                   0,
                                   0,
                                   0.35840714158832643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16106252774486632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23788986505374424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076980313354030994,
                                   0,
                                   -0.45613873724431009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098516373131104909,
                                   0,
                                   0,
                                   -0.41310006505477753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017985317060944708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74062681726141188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06180661861042816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087517286085626061,
                                   0,
                                   0,
                                   0,
                                   0.1136274119802177,
                                   0,
                                   0.1205371478625325,
                                   0,
                                   0,
                                   0.39169062156403445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24762347906647986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17764446407179313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4173238909667617,
                                   0.53444902902105873,
                                   0,
                                   0,
                                   -0.53058870592627438,
                                   0,
                                   -0.34644683871615872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58903527047576532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17390060013600664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041904998313831432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44851820824139732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49264212516694184,
                                   0,
                                   0,
                                   0,
                                   -0.044787618888518232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33953340866911835,
                                   0,
                                   0,
                                   0.054248105256073778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54036317916407206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37703452862422815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23810666926286023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30417070947411218,
                                   0,
                                   -0.46924617032572369,
                                   0,
                                   0,
                                   0,
                                   -0.10453120875422051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0032254053964844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031682564805280311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45582187408636121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61174556823846182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28199000343633251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46141262032522623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64503428279500941,
                                   0,
                                   0,
                                   0,
                                   -0.58910885345192632,
                                   0,
                                   0.009852829245583259,
                                   0,
                                   0,
                                   0.25955840533186803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1047245129587145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47336320980949359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8564150721544983,
                                   -0.82352546182325037,
                                   0,
                                   0,
                                   0.35565495861744345,
                                   0,
                                   -0.038954924027769185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11923378884640137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0455168459910157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55487860769580755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0648561471313736,
                                   0,
                                   1.0781253057577067,
                                   0,
                                   0,
                                   0,
                                   0.17993280117584284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52348705062216871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22489945917326143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20501822406921455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33538368468809199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44626381009024807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13857805175419566,
                                   0,
                                   0,
                                   -0.20654053985937321,
                                   0,
                                   0.38456720911249459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2385002524199244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21298599034544477,
                                   0,
                                   0,
                                   0,
                                   0.11546583894683807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28708880562259514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2151600838798049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063516384094031569,
                                   0,
                                   -0.32545593999682598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44526092771956999,
                                   0,
                                   0,
                                   0.10671367123282827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.164927846878656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22390717085390383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058362058403982439,
                                   0,
                                   0.3516050743563166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38402908618567266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0019575225219612968,
                                   0,
                                   0,
                                   0.41562079088446158,
                                   0.60841605383086483,
                                   0.29271337334786218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21423197358361057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029393127056383431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61886048562419416,
                                   0.32233156640770078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19787708126264034,
                                   0.54749208929936388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77080349103052914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059959408244558539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30596257562963503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31330952285088626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050025942912797744,
                                   0.2258091473430992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53294827816681067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25776077627750421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23009571895561898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2496198099868171,
                                   0,
                                   0.82967185637347507,
                                   0,
                                   0,
                                   0,
                                   0.2194219259810373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20834182696973502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37654265124221453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71209977678824743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18785951264678524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17865343429011571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2603302331511374,
                                   0,
                                   0.13160582129725223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08025766637923773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40520257576083107,
                                   0,
                                   0,
                                   0.01426389204153055,
                                   -0.22132827541931924,
                                   0.47872600823494382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076540774939341708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65431938852788241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32634392580512672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6014824091352875,
                                   0,
                                   0.025966363288294644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017552752478348373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015098189195643541,
                                   0,
                                   0,
                                   -0.48586994032745395,
                                   0.21670449736433692,
                                   0.23607218894209403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047904737703977476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43526183700596044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.434607990104735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020981149771448049,
                                   0,
                                   -0.15861258995398345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17408843320287393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53148412720432758,
                                   0,
                                   0,
                                   0.233688497972871,
                                   0.46725270598810686,
                                   -0.39083987688235183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21404662835465046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035048519867056135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25667440521119944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18811222628581653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62212413974212211,
                                   0,
                                   0,
                                   0,
                                   0.00086869800787348073,
                                   0,
                                   -0.31469646785209765,
                                   0,
                                   0,
                                   0.066871220299117823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16847091835261296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1082589616652763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35780615460713711,
                                   0.12498465343377417,
                                   0,
                                   0,
                                   0.24094136964987439,
                                   0,
                                   -0.49073646146257421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57389705544701042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15369877848527369,
                                   0,
                                   0,
                                   0,
                                   0.21945923469803291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17435946535439573,
                                   0,
                                   0,
                                   0.097460709333678036,
                                   0,
                                   -0.66821195407793732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33755794068796496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22637183485416817,
                                   0,
                                   0,
                                   0,
                                   -0.020992066823319909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1315021164636877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13394772400477223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077128161848307689,
                                   0,
                                   -0.14184054260040355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2631725375571945,
                                   0,
                                   0,
                                   -0.12480280176018392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39199816552772265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26911963487195972,
                                   -0.1828848081374157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094942521274899092,
                                   0.27745811006751753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63006927875336516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12658083798835806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43240089947605853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5945969778791218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0020032798927150444,
                                   0.32674545129212823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66178567443905201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46764221988813048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3393140076900828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33492428206624075,
                                   0,
                                   0,
                                   -0.0092249292068184024,
                                   0,
                                   -0.29095757481291851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24464915091999978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0052613390598256135,
                                   0,
                                   0,
                                   0,
                                   0.58248712308882644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12232761255652153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050891302282032633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22671845141793667,
                                   0,
                                   0.39992103702939352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1817630524113566,
                                   0,
                                   0,
                                   0.094214638658893374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13405937354646263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62970776724207189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42912871101242295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10687780246151268,
                                   0,
                                   0,
                                   0,
                                   -0.255044210253421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.70115720758603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20926852439449958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10181237926645612,
                                   0,
                                   0.076744722089391482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024392269583440089,
                                   0,
                                   0.081683487264156182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19580386311160206,
                                   0,
                                   0,
                                   -0.21525467840860912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86307179795175248,
                                   -0.14688174859206826,
                                   0,
                                   0,
                                   0.21420907169789349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20369581154698119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13479805179860957,
                                   0,
                                   0.14067118208413412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42357448670097697,
                                   0,
                                   -0.45985471320992982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14580661535054379,
                                   0,
                                   -0.085067902396135681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043382385360008283,
                                   0,
                                   0,
                                   -0.17869456564220892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32667017905407092,
                                   0.27698590332491374,
                                   0,
                                   0,
                                   -0.45062970910692207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3454373454422956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18926893786812643,
                                   0,
                                   0.071812108904423896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098673703670778393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22001926504119029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031920296998406053,
                                   0,
                                   0,
                                   0,
                                   0.54972529877101062,
                                   0,
                                   0.16602110926022928,
                                   0,
                                   0,
                                   0.51322885979918065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61377320315524986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71370097537027188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098298987680919492,
                                   0.065238370760569236,
                                   0,
                                   0,
                                   -0.18354887424204244,
                                   0,
                                   0.55769956140230748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14243787699183899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35997523337449888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011646253375260518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25821213876317145,
                                   0,
                                   -0.69309329877780801,
                                   0,
                                   0,
                                   0,
                                   -0.091250415918373184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18375764919553461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37695218257573337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1825297879640756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1773056873422378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17096120044048235,
                                   0,
                                   0.17857482475734332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21920279044191873,
                                   0,
                                   0.04990190051387098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23106575133572979,
                                   0,
                                   0,
                                   0.55765637535359902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22677638583974835,
                                   0.41632964001208606,
                                   0,
                                   0,
                                   -0.18724289258369445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2324948418804885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4392338845953131,
                                   0,
                                   0.13104642861822921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025671667802502712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33573452599016723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044861121496014018,
                                   0,
                                   0,
                                   0,
                                   0.77535711969445387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12589861357810073,
                                   0,
                                   0,
                                   -0.20674627299852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4649245951799838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093181268207173873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73439231395454196,
                                   -0.069279220676334782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91082629810370297,
                                   0.15340307179760418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21506842457787123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59009693918668582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02381613227013149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36307895477460517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5600233928313203,
                                   -0.076824727674188797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0003175527892541781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05048896861162238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75355347560316888,
                                   -0.94933642304426957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39070214319723395,
                                   -0.029474212330074127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53343722361085832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19201722376105382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2474326779042193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48128309808885805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22337567437059622,
                                   -0.62262196678716175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18948910965253449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075099938519963327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49813655268877294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13689482066680542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046770148019662443,
                                   0,
                                   0,
                                   0,
                                   0.33861762598808487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18081014185481473,
                                   0,
                                   0,
                                   0.67042721407013151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23764141879447467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27862526605516974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53636362627377054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76158584869404444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52496407877727935,
                                   0,
                                   0,
                                   0,
                                   0.12807802479610292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00018517267781092972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0014026658436483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36163536987541722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085912071391098854,
                                   0,
                                   0.0090656054028440645,
                                   0,
                                   0,
                                   0,
                                   0.47921217364227331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78578586949485019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82841329102688399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053647472600234544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62153889247651573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22543604113725965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6424207591414457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60256099516487704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06302367417311483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28654751824109614,
                                   0,
                                   0,
                                   0.29548763590037125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52076999473567998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70177350474778433,
                                   0,
                                   -0.17102530754811826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16742410163243537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.007181122987349603,
                                   0,
                                   0,
                                   0.21600806561233715,
                                   -0.017389020769042307,
                                   -0.33872080718876485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044488564858509869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12372399274848336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30310763914938255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1004225494051703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2140402648786175,
                                   0,
                                   0,
                                   0,
                                   -0.13864325684294387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016762251675522921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15257842487117818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63691163150676244,
                                   0,
                                   -0.46525078530480279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086205557169331787,
                                   0,
                                   -0.2258708842665863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096826059844411672,
                                   0,
                                   0,
                                   -0.16708385815739304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032579445345394101,
                                   0.14961708918590888,
                                   0,
                                   0,
                                   0.30182260072209116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38060809971375509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10692960650875064,
                                   0,
                                   -0.10631971688592023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038828431211689662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15020519444511385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1711915830450601,
                                   0,
                                   0,
                                   0,
                                   0.038225740658760311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12190253440517057,
                                   0,
                                   0,
                                   -0.40159053674358403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1982250079747985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85424507388333648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51362867470744666,
                                   0.1594069851369207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31327580335925703,
                                   0.0088185338765514147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10215984274210564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49493961368159045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37924348275088243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84800484920037866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050881732483184651,
                                   -0.47053250007968028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44208529776836053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067283535744774442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056319652527749647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50775844048182206,
                                   0,
                                   0,
                                   0.066475406297805059,
                                   0,
                                   0.27091516316693037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028136352623167035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48850589174454245,
                                   0,
                                   0,
                                   0,
                                   0.19176580774907137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15716030775908732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15168003917235479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14242430470567519,
                                   0,
                                   0.12311542329542688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34748218474591408,
                                   0,
                                   0,
                                   -0.36566899838440764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21768256754981008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85016291203525296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02421265578973214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26168569944201209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35402799122726603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21306731534390766,
                                   0,
                                   0,
                                   -0.19345248917142482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.389452192740757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027341744647189206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42705579742546557,
                                   0,
                                   0,
                                   0,
                                   -0.39304182921354314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25500858413080835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31818413960782926,
                                   0,
                                   0,
                                   -0.1672640604851732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043362857389040277,
                                   0,
                                   0,
                                   0.028488995804005754,
                                   0,
                                   -0.15267643692607968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057755900630931861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29546969484153635,
                                   0,
                                   0,
                                   0,
                                   -0.10386427399406602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36006183373952072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090783448576435583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40069815594369168,
                                   0,
                                   0.061943439669442893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26757602367938144,
                                   0,
                                   0,
                                   0.43561420815704033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53005280870168758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55716499614074244,
                                   0.0074721975029786395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4998155320604265,
                                   0.25521545845992222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46702016871805629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43911150723061521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17240278359606598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12901443566163462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79938352421959358,
                                   -0.79893600273993193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19411256796896587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25540216451464287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36253339125596218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45767562569901088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55299256797583474,
                                   0,
                                   0,
                                   0,
                                   0.15869163288946084,
                                   0,
                                   0.61779902619971749,
                                   0,
                                   0,
                                   0.13465563536679259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97134690179865468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37447368783304713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22990317421558501,
                                   -0.19076827492802245,
                                   0,
                                   0,
                                   -0.35859501322770715,
                                   0,
                                   0.56392653809968485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1579392020367911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18647055325976061,
                                   0,
                                   0,
                                   0.023132100418440132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63952837049434474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0025176662093431279,
                                   0,
                                   0,
                                   0,
                                   0.64643445935737831,
                                   0,
                                   -0.19593181302426854,
                                   0,
                                   0,
                                   0.12742108746122807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36081069827983153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076390128304383298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81349159287917039,
                                   -0.71596389762482615,
                                   0,
                                   0,
                                   0.2819322112109422,
                                   0,
                                   -0.32367569462261636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016586776855737811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48823903615755748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3597267504895022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40736193570728985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29811827622188031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76672110676926519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0068946667445404786,
                                   0,
                                   0,
                                   0.16694196508536246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.023355604750483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55434719185011172,
                                   0,
                                   0.28915429151650723,
                                   0,
                                   0,
                                   0,
                                   0.51357914507236402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41851498609124138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14875304052289789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23098950129771773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27551426003567575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21723700378249455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68166581437865714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39526629261362983,
                                   0,
                                   0,
                                   0,
                                   0.26924576281912305,
                                   0,
                                   0.37491682096358486,
                                   0,
                                   0,
                                   0.5256192493002696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18039974310550916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17225713311872914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17237412656455792,
                                   -0.64185295593719938,
                                   0,
                                   0,
                                   0.091125437620664967,
                                   0,
                                   -0.29342340714050014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4797890868045338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86608452563283267,
                                   0,
                                   0,
                                   0,
                                   0.23695387212377872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12516527851313689,
                                   0,
                                   0,
                                   0.64294362762518154,
                                   0,
                                   -0.10941363867227047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12867096172324666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28908500438675044,
                                   0,
                                   0,
                                   0,
                                   0.041476685552362967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31017023723590792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051588451393513951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24848803077913068,
                                   0,
                                   -0.32102140713288113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03840589490802522,
                                   0,
                                   0,
                                   -0.12406237466717633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34706990085350176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20945218916877423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2236568166598161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12378259388864171,
                                   0,
                                   0,
                                   0,
                                   0.45622468458248217,
                                   0,
                                   0.7203894922511811,
                                   0,
                                   0,
                                   -0.82574596406211442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0055774271302174161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10956688474220741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11568402958186086,
                                   0.11692322253218772,
                                   0,
                                   0,
                                   0.68058870689343498,
                                   0,
                                   0.21852238629926768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81065609386566628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44245706360361509,
                                   0,
                                   -0.2140720572024874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18131845553509382,
                                   0,
                                   0.66921890547058205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26904037729521973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066983896984591562,
                                   0,
                                   0,
                                   0.13561859967536083,
                                   -0.29420835405581686,
                                   -0.27440606813565444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46353498750618261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038195895743634155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071200515098479009,
                                   0,
                                   -0.082573285229721391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06122318790031251,
                                   0,
                                   -0.1474077913181214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38657246335098311,
                                   0,
                                   0,
                                   -0.15560890422543083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14336012505673207,
                                   -0.18471403508500564,
                                   0,
                                   0,
                                   0.18133030285225635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048151232738902143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15877502022294382,
                                   0,
                                   0.82091551077769398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054643846109815097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62064637301759018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35838881881948181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36789533440226962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071943357606397362,
                                   0,
                                   0,
                                   0.58553117808445765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016854234020465972,
                                   0,
                                   0.47136931293283341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.321308709937558,
                                   0,
                                   0.3351296277197674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40011453322698587,
                                   0,
                                   0,
                                   -0.22765896874668287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1191512480664767,
                                   0.34934140367016653,
                                   0,
                                   0,
                                   0.077797501968508209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36077982163896061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083134515213065224,
                                   0,
                                   0.26588191090237812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.831338840894289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16861372157381793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0019316483807059696,
                                   0,
                                   0,
                                   0,
                                   0.43860965122557238,
                                   0,
                                   -0.5330249074332134,
                                   0,
                                   0,
                                   0.2891249099799052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.009963680428400179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2564705173883397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11453671879823385,
                                   0.15321140907528941,
                                   0,
                                   0,
                                   0.96935379828934531,
                                   0,
                                   0.54628971006285953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39143498436327545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086893333276682222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30392395166756636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17588786134333861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053536785346911767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051469366471050777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87292115719554875,
                                   0,
                                   0,
                                   -0.33043465630137525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023047289831396686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28165664843776661,
                                   0,
                                   0.52771774124358495,
                                   0,
                                   0,
                                   0,
                                   -1.2652580075181472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2214807802090806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8250964667652233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30006732742109693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4004313003898034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49297459361110046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87064402174479039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07529168024200189,
                                   0,
                                   0.19293026286102677,
                                   0,
                                   0,
                                   0.35737846806416546,
                                   0,
                                   -0.45783554559308975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33064323191198264,
                                   0,
                                   0,
                                   -0.14615309789182407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5371522803589468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49558287300306553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50732892959630826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41081953496047041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17914519155676034,
                                   0,
                                   0,
                                   0,
                                   0.31871004916840057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51991069256048494,
                                   0,
                                   0,
                                   0.30002990614941849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27260433392049577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074413547796762902,
                                   0,
                                   0,
                                   0,
                                   -0.279854694336022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46117631401260706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49959930343443998,
                                   0,
                                   0,
                                   0,
                                   -0.76070685251689518,
                                   0,
                                   0.80290556743523422,
                                   0,
                                   0,
                                   0.6751291541114417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10401711273486045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14003795108381598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25310202491044942,
                                   0.32944795948258815,
                                   0,
                                   0,
                                   0.33279777621707601,
                                   0,
                                   0.13202928837899791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28576011156143816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1275484127974891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5226511442183408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39807243940887843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036167138384017777,
                                   0,
                                   0,
                                   0,
                                   1.4699063118336257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074379501301355788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38236318231607214,
                                   0.012255314212934467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064758554565801318,
                                   0,
                                   -0.32482603216069272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27871412089107611,
                                   -0.40933379075341508,
                                   0,
                                   0,
                                   0,
                                   -0.001251727040852134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018473218207451701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035555795578867698,
                                   0,
                                   0.3480790600878742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67997367790639451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12039364207925747,
                                   0,
                                   0,
                                   0,
                                   -0.21279935924973292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81740377156874766,
                                   0,
                                   0,
                                   -0.095797873095759364,
                                   -0.22687334938178202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065288819875617438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47876434543140078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38067566054367458,
                                   0,
                                   0,
                                   0.27732408309475076,
                                   0,
                                   -0.23094899394729385,
                                   0,
                                   0,
                                   0,
                                   0.21786537874189948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51352328859330854,
                                   0,
                                   0,
                                   0,
                                   -0.76952555283512025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066908659549385921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092986539849323119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69637325644033876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36952456942094236,
                                   0,
                                   0,
                                   0.30303654843309363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19934166535753647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044976054480175331,
                                   0,
                                   0,
                                   0,
                                   0.15875574349102764,
                                   0,
                                   0.060387191953627822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030754219135624931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08375300640908577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22009002151818957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22993769882176276,
                                   0,
                                   0.094720030195841201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29863866938694617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28657309468543118,
                                   0,
                                   0,
                                   0.065968997802368062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32945821174854023,
                                   0,
                                   0.15687407256307012,
                                   0,
                                   0.39810660541262483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27627634671247375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49476881129192474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24716769800482122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025548496649510657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48889007202955803,
                                   0,
                                   0,
                                   0,
                                   -0.061478861879303306,
                                   0,
                                   0,
                                   0.31363914769304035,
                                   0.3547342368802614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24483845421617306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24834624052691834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52316217224083394,
                                   0,
                                   0,
                                   0.97776367310784751,
                                   0,
                                   -0.14424667292046695,
                                   0,
                                   0,
                                   0,
                                   0.21811784646692467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12047661339668683,
                                   0,
                                   0,
                                   0,
                                   -0.7185501048287436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67094855987433821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053826150578016478,
                                   0,
                                   0,
                                   0.55364069655880355,
                                   -0.23501883470846691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20979859009378821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79835673507083882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066586468305325636,
                                   0,
                                   0,
                                   0.042390329197805353,
                                   0,
                                   0.41961130323441864,
                                   0,
                                   0,
                                   0,
                                   1.0397931864755336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49955217932977503,
                                   0,
                                   0,
                                   0,
                                   0.080133168625748333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1346891363215835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67778056386131613,
                                   0,
                                   0,
                                   -0.08021530463734329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25356563780897584,
                                   0,
                                   -0.27245961661243245,
                                   0,
                                   0.094963959535305426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12139696681283843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14932357732300452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4148951380063679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24123342489066105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34534734407460932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.95633653474799807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10134298766527522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0051031238701116158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62790154827322775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1076145818417865,
                                   0.034753208206335429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19768651014289884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20227744624488958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10699330715763314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3401375604451965,
                                   0,
                                   0,
                                   0,
                                   -0.36885604186601895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81479286269111606,
                                   0,
                                   0.78355147264041947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23323200382266454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021916523196214753,
                                   0,
                                   -0.35394773533317675,
                                   0,
                                   0.012901116422297854,
                                   0,
                                   0,
                                   -0.042162552696711833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.545385155426649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49200501710225586,
                                   0,
                                   0.28784195261457762,
                                   0,
                                   -0.12640940811203114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24759058644688442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67749904930397797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26348350971115353,
                                   0,
                                   -0.2696771410615047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0079108210951942676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60994431633372836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33123290393141758,
                                   0,
                                   0,
                                   0,
                                   -0.13156808544222534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.155940548108459,
                                   -0.55340116029731334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072540896937502722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25780597176498987,
                                   0,
                                   -0.019406275399179884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24783015555745763,
                                   0.67545516465261368,
                                   0,
                                   0,
                                   0,
                                   -0.089334896744455744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26933381792873778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35035644589828496,
                                   0,
                                   0.1843037824806858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061217782723946845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07826865813782298,
                                   0,
                                   0,
                                   0,
                                   -0.40388770440004018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30812824381073034,
                                   0,
                                   0,
                                   0.42947678126224198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31408710391180755,
                                   0,
                                   -0.38838282935617041,
                                   0,
                                   0.26008823219342075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33937235216208611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34335598519403776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29040190985087777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24492862064810644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16148881006624319,
                                   0,
                                   0,
                                   -0.4731212625430537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022204679928451591,
                                   0,
                                   0.16164646265815347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06667568022442108,
                                   -0.14620124012903485,
                                   0,
                                   0,
                                   0,
                                   0.31131876991676655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6831640527865539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14732900759062029,
                                   0,
                                   0.11859060770385188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051940534343918592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039216492433879577,
                                   0,
                                   0,
                                   0,
                                   0.34651893838312453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016066122986450049,
                                   0,
                                   0,
                                   -0.43542993178373013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075270547916566719,
                                   0,
                                   -0.18414128343406236,
                                   0,
                                   0.14406081506959156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070832755343100767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16905081060282451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45877287920389936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6583272244837991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26898461503873539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61987532945413315,
                                   0,
                                   -0.98266055251446627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06106945804124049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070455842413016889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24766074675900016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27083836474437983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29437982198725898,
                                   0,
                                   0,
                                   -0.11021467217461793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28257611912450958,
                                   0,
                                   0.21884713782839299,
                                   0,
                                   0.78877719600767515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14259165467131155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30177673186054449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18592559251587853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061247328071052293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03948812029910146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43801413381355286,
                                   0,
                                   0.36595768252389821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43924023304678228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55362360795902243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0610286438355403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27532253315377458,
                                   0,
                                   0,
                                   0,
                                   -0.36964011235861965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29377462254502817,
                                   0,
                                   -0.089269691090639994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48416947922062975,
                                   -0.095248858469973052,
                                   0,
                                   0,
                                   0,
                                   -0.13547787366707167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084385739556288794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57158411841641954,
                                   0,
                                   -0.13051844997308237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16266989202933396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32280861750750395,
                                   0,
                                   0,
                                   0,
                                   -0.16036076912688702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03448750129865924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51512735500095586,
                                   0,
                                   0.062900050307196295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38923143719338055,
                                   0.0062121877857927998,
                                   0,
                                   0,
                                   0,
                                   -0.54749388770391139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12213150431248293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30245402882422573,
                                   0,
                                   -0.22797957205810596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03808850315910331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25778678864357896,
                                   0,
                                   0,
                                   0,
                                   0.22789197519851057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053214966044493606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39154168554426438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14642281288122413,
                                   0,
                                   0,
                                   -0.35177925583357178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0069876968142712891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45938273618155495,
                                   0,
                                   0,
                                   0,
                                   -0.23655529134755696,
                                   0,
                                   0.036609874218612087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49079939350119661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23985260199096831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047701791241262816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3127459928032334,
                                   0,
                                   -0.17463425700434154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036041919695873198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17529251198595991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19799170273385402,
                                   0,
                                   0,
                                   0,
                                   -0.50901808408003679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46372659812740374,
                                   0,
                                   -0.0081281793633054163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12772981577268097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41632253141566139,
                                   0,
                                   -0.25404944043407207,
                                   0,
                                   0.41066342011893697,
                                   0,
                                   0,
                                   0.38387718136183135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0042818205354611186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073285526067815757,
                                   0,
                                   0.63629675302184674,
                                   0,
                                   -0.52326016985530011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0479109222883518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058484729027202503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00038966847509097624,
                                   0,
                                   -0.26643120974342088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082681515380664067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16659369148521957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1799133026998376,
                                   0,
                                   0,
                                   0,
                                   0.75594321941481657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35489759809295351,
                                   -0.1986031716390694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03363373449513482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15110585501435994,
                                   0,
                                   0.61528020434881459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21750490512348686,
                                   0.28070293946181246,
                                   0,
                                   0,
                                   0,
                                   -0.0057739942696821691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1022300570574055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43628427156536465,
                                   0,
                                   0.20357271002995445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29585028835752014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30371441021857537,
                                   0,
                                   0,
                                   0,
                                   0.22208909268540647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34990424446711238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48253948575747374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0036348618974374938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1151165878343661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80616843133247074,
                                   0.041660528313967084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71615336598441892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22260805973803022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5438152023030105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40924544986174177,
                                   0,
                                   0,
                                   0,
                                   0.33176937112129429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046086714794708321,
                                   0,
                                   0.2471048642570319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23622259047864547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13772815694804083,
                                   0,
                                   0.44780018299521335,
                                   0,
                                   0.031656721497948202,
                                   0,
                                   0,
                                   0.1039016332575235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4856885508743175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47411864965360939,
                                   0,
                                   -0.18169337363548471,
                                   0,
                                   -0.4683335729966403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38393147335482436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02266056749106626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095418896993446661,
                                   0,
                                   0,
                                   -0.21149396521861419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39365101884403714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037789057482481861,
                                   0,
                                   0,
                                   0,
                                   -0.016100619081083276,
                                   0,
                                   -0.36278958699416286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031893648932768498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26678347970756605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18112176913841224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34626988384690843,
                                   0,
                                   0.29828776015769665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4428429313995052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12317870632611003,
                                   0,
                                   0,
                                   0.097328422181802987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080532869144037803,
                                   0,
                                   -0.34890315913925557,
                                   0,
                                   0.33054613304559083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39328165435418899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41583975560674674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41645616261416607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12714668307388005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46976515900123572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51336536291374191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3865112294205803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38776647234565997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37295664648597648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49891397480529098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22065906326900908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39877372711618203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049914751022226027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10120619977553906,
                                   0,
                                   0,
                                   0.15107862722991319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38032698616084315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038803602080933933,
                                   0,
                                   0,
                                   0,
                                   -0.2124912669541707,
                                   0,
                                   0.45254225369062551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22641159902590607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21350560393653617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16954863702023265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28005819153083122,
                                   0,
                                   0.0091249816932803419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45300084827088005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087240692707479528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53842673961531762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52316988066567516,
                                   0,
                                   0.79041527307722959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53007497787724167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65555261736144843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29291718873859934,
                                   0,
                                   0,
                                   0,
                                   -0.23239818291113362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37398294472200155,
                                   0.61439230418389812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71962474405949417,
                                   0,
                                   0.0010894060554798302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68567483992211864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37501120303097113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45292833240525943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16614138535980638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45642001204573102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13443289828564062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084162174138225437,
                                   0,
                                   0.3590939825885423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11808501814805886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040549271372664134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41009920318664267,
                                   0,
                                   0,
                                   0,
                                   0.75244124300920934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098041145854985787,
                                   -0.61815263484305494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14017494160448704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38572025598551168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055346665052155936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29949694391063986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15815703672534975,
                                   0.90222311533125743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89612561028659965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1490581826693205,
                                   0,
                                   0.94804219002624956,
                                   0,
                                   0,
                                   0.14382758837201587,
                                   0.3720315643040607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90910265872642593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031369793402858948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019821711565951156,
                                   0,
                                   0,
                                   0.51757937476520077,
                                   0,
                                   0.18788463817698509,
                                   0,
                                   0,
                                   0,
                                   -0.14169447674791522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15326508866562102,
                                   0,
                                   0,
                                   0,
                                   0.45235100416353297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059347314252554205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49557521088319922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090646778474545192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1784002694820693,
                                   0,
                                   0,
                                   0.28854256954232349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031970856969143049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11945512127495997,
                                   0,
                                   0,
                                   0,
                                   -0.011341438319245407,
                                   0,
                                   0.26972919697031722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39414280277187885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17775467156091801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044392434386439909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36212188622579289,
                                   0,
                                   0.47208276162057028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0045185100354830365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4890159995780915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49002862231413291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64441730201360103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13434734118618219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29425202086905827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028778159526650512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14850828397176324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5308196422264303,
                                   0,
                                   0,
                                   0,
                                   -0.17559517311478617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61997115470865483,
                                   0,
                                   0.42427531607044611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45206359430805021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098136416127967835,
                                   0,
                                   -0.12012398188053111,
                                   0,
                                   -0.058674262930180396,
                                   0,
                                   0,
                                   0.5580897887700772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14788871498797268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037487380524039299,
                                   0,
                                   -0.39577214845953024,
                                   0,
                                   -0.4721010809041945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35096719882283767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1395600695556144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42924933788500841,
                                   0,
                                   -0.18664366844032546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22200057978899398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1195613109139598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53616179728294644,
                                   0,
                                   0,
                                   0,
                                   0.23233010491313286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3339029432533992,
                                   0.69709364481334668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11894367641577902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19674522786188334,
                                   0,
                                   0,
                                   0,
                                   0.38383224738717814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066469387744817185,
                                   0,
                                   0.2066063105990211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4924301315875263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075224409406578818,
                                   0,
                                   -0.050944202658120129,
                                   0,
                                   0.70013342806055689,
                                   0,
                                   0,
                                   0.61353442166990524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71099694921928813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050268317499994983,
                                   0,
                                   -0.1965296163715434,
                                   0,
                                   0.16150640268371069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20352160605618455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27513667010562692,
                                   0,
                                   0.31079097908843961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035165103051575192,
                                   -0.17262079276298187,
                                   0,
                                   0,
                                   0,
                                   0.15159798795714258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066686263845484497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041475577016692342,
                                   0,
                                   -0.54013284599346967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075340293269873709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25521908367099988,
                                   0,
                                   0,
                                   0,
                                   -0.6029490445916329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21185566450116355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14696169326005026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98272452950654821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17667395462019839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81779015770713903,
                                   0.36271356220298606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69147363069282652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49832219364812058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17011796983932193,
                                   0,
                                   -0.47511491178490006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44750479868981236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79166192634278398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88898532187852197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025818706602867614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10139475596113613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31568861737769632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75197471859011755,
                                   0,
                                   0.24191038828916994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9210793201166716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074240889137816013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24029019929810921,
                                   0,
                                   0,
                                   0,
                                   0.33709725994352502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14813556141521084,
                                   0.033813819466886497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033760573014195688,
                                   0,
                                   0,
                                   0.0060894990207164962,
                                   -0.23816978609403228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0076384706518126174,
                                   0,
                                   0,
                                   -0.39208510219621195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35423132424031833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59406114788658271,
                                   0,
                                   0,
                                   0,
                                   -0.55670525649024294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44194138654662118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32932980543831197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31853986740885415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35511956103911235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68077836504441924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072062181712732376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12384432547109434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047673609001581622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051814463046724102,
                                   0,
                                   0,
                                   0.040788977492748131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0089028591035047646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18122533958276249,
                                   0,
                                   0,
                                   0,
                                   -0.36103392055991929,
                                   0,
                                   0.43514341392840417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26896044131788188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48422577579771497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5246055284529122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078413940953830794,
                                   0,
                                   0.16896249972184346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093283491723197942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12171921128699764,
                                   0,
                                   0,
                                   0.59623238621144992,
                                   -0.28555308078557939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72701629092232445,
                                   0,
                                   0,
                                   0.021570233833916597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036529294071143803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13283862795626189,
                                   0,
                                   0,
                                   0,
                                   0.012343444956484567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13844393087755302,
                                   0,
                                   0,
                                   0.092740594854522462,
                                   0.37504210643030406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13310981227783961,
                                   0,
                                   0,
                                   -0.66389208343556594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3928576015004554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28410375063341042,
                                   0,
                                   0,
                                   0,
                                   0.37155473583282672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46848918001722323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089391109881872391,
                                   0,
                                   -0.30806413755098516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14996042572297491,
                                   0.021948139825320026,
                                   0,
                                   0,
                                   0,
                                   -0.44170036054502188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059588882507177907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079567540691607971,
                                   0,
                                   0.069614988630010005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18333599976292253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63306777748902043,
                                   0,
                                   0,
                                   0,
                                   0.10217422086511109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1015063478062916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12541636827329924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35172654160595612,
                                   0,
                                   0,
                                   -0.12588665065423327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40878854353011829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084720901276018792,
                                   0,
                                   0,
                                   0,
                                   -0.44561920396550536,
                                   0,
                                   -0.30933282507491455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19447215965142287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31111349940032856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027748816336270417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39747323299760973,
                                   0,
                                   0.19326980815526199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18745664593274686,
                                   0,
                                   -0.11646866558877189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4500533375689752,
                                   0,
                                   0.38043209442057457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41395626987222012,
                                   -0.17686268827800244,
                                   0,
                                   0,
                                   0,
                                   -0.54022359698153888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010524282633542728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095797643293860826,
                                   0,
                                   -0.010626048875654159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30526953049732664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19591762680422592,
                                   0,
                                   0,
                                   0,
                                   -0.060849499288723456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074038443966829015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069677297325682799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0027892156303888638,
                                   0,
                                   0,
                                   -0.25484132375996049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40539142587616928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09451672169383242,
                                   0,
                                   0,
                                   0,
                                   0.53209797290586214,
                                   0,
                                   0.37589999688507048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38515216772063704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080066689929952875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1543043474966472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37035913940870369,
                                   0,
                                   -0.061224638506665527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086774284520108505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74910743001280911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59524135338161444,
                                   0,
                                   0,
                                   0,
                                   -0.36395302746412189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16668375546264896,
                                   0,
                                   -0.0073411021141497473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0061681824480246394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0493407658323144,
                                   0,
                                   0.013137125660982074,
                                   0,
                                   0.041616483714536495,
                                   0,
                                   0,
                                   -0.35155371313138867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24787671454895305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079737635563855574,
                                   0,
                                   0.011254738654401991,
                                   0,
                                   -0.22583342378440174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30033901467386515,
                                   0,
                                   0,
                                   0.2308829199608963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65160016725455161,
                                   0,
                                   0.016546468480725433,
                                   0,
                                   0.036603177516706484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18854455358728356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22956073139826294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28722549914186402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35312441637952963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36722020431505181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1328695993224572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50430801183069274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31044983285030253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036501307854247753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12093810812566055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78465382723236499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10114372577787287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07545750973682,
                                   0,
                                   -0.36524303032543892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28113774817728959,
                                   0.42968053178504501,
                                   0,
                                   0,
                                   0,
                                   0.068871108221255223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039187045228201059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24484189650086341,
                                   0,
                                   -0.4457167583183243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51678099207623451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15370531017170749,
                                   0,
                                   0,
                                   0,
                                   0.17729098617223654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44094636390823849,
                                   0,
                                   0,
                                   0.82810498582097458,
                                   -0.10333206489935778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31592884578777114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19431194217858705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46841880508690625,
                                   0,
                                   0,
                                   -0.60922350515976131,
                                   0,
                                   -0.39220255388380498,
                                   0,
                                   0,
                                   0,
                                   0.24869951076690458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.491162977741465,
                                   0,
                                   0,
                                   0,
                                   0.33438979394505874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0060721992151022142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2221166561639617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25235404381535581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1405684802075472,
                                   0,
                                   0,
                                   -0.19664569172315211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21899709852620208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39055908299167752,
                                   0,
                                   0,
                                   0,
                                   -0.11210902334999982,
                                   0,
                                   0.056648821068472799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077511522845391867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38677983705364677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31721640594608214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18978575965305791,
                                   0,
                                   -0.32268013092970099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46465570610717782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1427244366978673,
                                   0,
                                   0,
                                   -0.54875030830044302,
                                   -0.63692757828234547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20334214404568546,
                                   0,
                                   0,
                                   -0.061798959758825656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47597199497343057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011773511929647408,
                                   0,
                                   0,
                                   0,
                                   0.031160869344695766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41136826569992457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1592490173170977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33274808168107128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8306339510084495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067778133030412191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012164650062637061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65646409311033505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31180270092958851,
                                   0,
                                   0,
                                   0,
                                   0.41475199234689858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39290386213143491,
                                   0,
                                   0.067796391164160835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77190915019034312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25900393709145764,
                                   0,
                                   -0.41139082680892125,
                                   0,
                                   -0.36861819023780418,
                                   0,
                                   0,
                                   -0.075130752527586345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091448744690332345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062128072300288689,
                                   0,
                                   -0.1538221645527027,
                                   0,
                                   0.23166692455004967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55386479240577979,
                                   0,
                                   0,
                                   0.1807475505014681,
                                   -0.090800789553407396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018907251827626616,
                                   0,
                                   0,
                                   0.40039076254541517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26799641113813816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61319826673678812,
                                   0,
                                   0,
                                   0,
                                   0.20932007481893083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058177599050241752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25051976626358807,
                                   0,
                                   0,
                                   0,
                                   -0.46280206854119449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37235199293737636,
                                   0,
                                   0.66577640556913464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24644325267142847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13196989501421574,
                                   0,
                                   0.18698065332039276,
                                   0,
                                   -0.42369903273033088,
                                   0,
                                   0,
                                   -0.75673693610294757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42484173676645964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25591867519300193,
                                   0,
                                   0.27060069849168766,
                                   0,
                                   0.17912667689158063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11305905513433261,
                                   0,
                                   0,
                                   -0.44165551149089954,
                                   -0.29470522357515638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076281318762243755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068630973859641425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3243485779519542,
                                   0,
                                   0,
                                   0.10170686718658424,
                                   0,
                                   -0.42621758673147986,
                                   0,
                                   0,
                                   0,
                                   0.12610341519348822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0090293302640823987,
                                   0,
                                   0,
                                   0,
                                   0.63498109438166717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011333761842582155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10776322434661267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59240149359489358,
                                   0,
                                   0,
                                   0,
                                   0.11156139250707094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19607587610008911,
                                   0,
                                   0.51164585927203698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035278386376204382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43972552822801425,
                                   0,
                                   0.23788527430053466,
                                   0,
                                   0.41900993148528398,
                                   0,
                                   0,
                                   0.097069010152767921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27431507310065106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54232391404343061,
                                   0,
                                   -0.66364601741989926,
                                   0,
                                   -0.083570133818835671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4308871363710467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06904911174090593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35241046930311892,
                                   0,
                                   0,
                                   0.00075875091067845396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15752741409754303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2946239417637983,
                                   0,
                                   0,
                                   0,
                                   0.31363168991304563,
                                   0,
                                   -0.23015350676817922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23891200611011776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28530656674951399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011973287271399945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2867623591500203,
                                   0,
                                   0.36284893062063672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26439934582445457,
                                   0,
                                   0,
                                   -0.48542583369695064,
                                   0,
                                   0,
                                   -0.77457457799778673,
                                   0.16916416770968251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9345474475653891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12502391032894566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34729016368892585,
                                   0,
                                   0,
                                   -0.50420881866714895,
                                   0,
                                   -0.075664846984369288,
                                   0,
                                   0,
                                   0,
                                   0.47359676877827284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14915646603589619,
                                   0,
                                   0,
                                   0,
                                   -0.2116964336759864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18468380181699398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22274483586539837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46168796741704221,
                                   0,
                                   0,
                                   0,
                                   -0.31545869290002415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18787570761021818,
                                   0,
                                   0.3371847259972463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087426738375475807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35392814630159136,
                                   0,
                                   0.36930650023341566,
                                   0,
                                   -0.10980701436793519,
                                   0,
                                   0,
                                   0.42337408572645657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31312064816235063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11550948168889243,
                                   0,
                                   0.13554884302431464,
                                   0,
                                   0.87823993107817855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4648120431439875,
                                   0,
                                   0,
                                   -0.094188874809596229,
                                   0.044054906011044698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17475120145882983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77711967142598459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26935010098517675,
                                   0,
                                   0,
                                   -0.60831573643654413,
                                   0,
                                   0.1919352456373635,
                                   0,
                                   0,
                                   0,
                                   0.44123213665763045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58164146620165935,
                                   0,
                                   0,
                                   0,
                                   -0.051047837864768207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27894926309115675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59582630647894985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69614292254164845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99139185115810635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71619079926611595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72533754955634921,
                                   -0.088708631796725168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047899194156224012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089655116502532814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40769338944496375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2869871871730665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92480620562751359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018973805253359038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82610160402715582,
                                   0.0084595061509542546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13210807474699565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069742453258214959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12429479141940737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41669990113057154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20968616433792528,
                                   0,
                                   0.77593340875633676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23447678754110626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14012362480646684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13806914654784985,
                                   0,
                                   0,
                                   0,
                                   -0.35690707013762202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79063461691551051,
                                   0.13590030078196425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3027244640403608,
                                   0,
                                   0,
                                   -0.078315427234512361,
                                   -0.053300693978168154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082262767377927204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47013810773074077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093882254888445107,
                                   0,
                                   0,
                                   0.19348299087070478,
                                   0,
                                   1.2855356038518442,
                                   0,
                                   0,
                                   0,
                                   0.39845326372608603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49015960169035855,
                                   0,
                                   0,
                                   0,
                                   0.14335185927229627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44672039700824528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64717767786820957,
                                   0,
                                   0,
                                   0.1935469540265963,
                                   -0.13544415563980289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14734158405869929,
                                   0,
                                   0,
                                   -0.40049617827736961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27755288007500961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40998885832509913,
                                   0,
                                   0,
                                   0,
                                   -0.31324481506132373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14275741316427198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2702956295239477,
                                   0,
                                   0,
                                   0,
                                   0.6060118464614882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40177587910178725,
                                   0,
                                   -0.051517396313281179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26609092919326416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21648366209912379,
                                   0,
                                   0.81264594404154689,
                                   0,
                                   0.46021555638429823,
                                   0,
                                   0,
                                   -0.12026428680254848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56181470147314716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2016284693663106,
                                   0,
                                   0.1933037081566876,
                                   0,
                                   -0.26836027397813822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023084382907567494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26146583724952299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72729353392923635,
                                   0,
                                   0.56335377727368652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40855103701480339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48118863428853575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17010527828295505,
                                   0,
                                   0,
                                   0,
                                   0.11764262441746856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60599308247225092,
                                   0.13040432201820973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30802075635545473,
                                   0,
                                   -0.94090077041339792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36735735099311773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3481879272812104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25739011914694515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3042298906952356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11805544692912934,
                                   0,
                                   0,
                                   0.68441209810863612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44835236665006578,
                                   0,
                                   0.022453844499887174,
                                   0,
                                   -0.064214873986907881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33183312373962598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14135635752501396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026186511004436357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32417620045978374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27590693617874024,
                                   0,
                                   0,
                                   -0.56256124292457843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0040774185359842927,
                                   0,
                                   0.088575836809332037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13526841387098931,
                                   0.071307586134523843,
                                   0,
                                   0,
                                   0,
                                   0.23929742039231963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64659377915093375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34459260096918681,
                                   0,
                                   0.040819296842343464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088055363485943741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19063443782993231,
                                   0,
                                   0,
                                   0,
                                   0.11148069749223194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36009300807237044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60044567206448407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59247399660630662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12219528273199712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48230881846346596,
                                   -1.0690845390582342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13416553864014449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88198552360945304,
                                   0,
                                   0.0092074183432218973,
                                   0,
                                   0,
                                   0.23823363685456111,
                                   0.51846935076747214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12686869598329981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90476784577461389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60718422971192132,
                                   0,
                                   0,
                                   -0.35429402373151209,
                                   0,
                                   0.3869965611728472,
                                   0,
                                   0,
                                   0,
                                   -0.62021741704291411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28918729695994405,
                                   0,
                                   0,
                                   0,
                                   -0.20999929324080707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48520033584390537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089536919454389602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48901550806603167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30839351118504266,
                                   0,
                                   0,
                                   -0.012451519552443183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20864386977269225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070152452948038901,
                                   0,
                                   0,
                                   0,
                                   0.28545163745659052,
                                   0,
                                   0.024688946420744311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39976828268989129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016642633902784847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48926640310768099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02264722522049379,
                                   0,
                                   -0.33270995465275621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12789636954103459,
                                   0,
                                   0.17497473153079188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51225700292281762,
                                   0,
                                   -0.0039202570916068201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36166689377682754,
                                   -0.1251242920486382,
                                   0,
                                   0,
                                   0,
                                   0.070936622532327451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013750519179170171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22322517721199939,
                                   0,
                                   -0.47257322989120881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091960125591353331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38817194719815673,
                                   0,
                                   0,
                                   0,
                                   0.35070224338636335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02823142531510639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21852096864429518,
                                   0,
                                   0,
                                   0,
                                   -0.52193791399335177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3231491196605415,
                                   0,
                                   0.027839273039482457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68678511960377242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45188478036874818,
                                   0,
                                   0.43996137271669361,
                                   0,
                                   -0.41604427416519668,
                                   0,
                                   0,
                                   0.37137305660508529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074988432629944507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010974838282631988,
                                   0,
                                   -0.43749324331980299,
                                   0,
                                   -0.17917560020701551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38029457283578877,
                                   0,
                                   0,
                                   0.20659430216439442,
                                   -0.26679762157328601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14710072804210628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.395865778330241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037785487222528315,
                                   0,
                                   0,
                                   0.6083322947158234,
                                   0,
                                   -0.48801004072930337,
                                   0,
                                   0,
                                   0,
                                   -0.080561872269883886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36575831351531329,
                                   0,
                                   0,
                                   0,
                                   -0.27780768696734215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94770728632981416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23664176791477498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11507680577665927,
                                   0,
                                   0,
                                   0,
                                   -0.12477487124562078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36101325270362256,
                                   0,
                                   -0.21821851595205985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28046965660126238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21988402632506049,
                                   0,
                                   -0.34898422309122196,
                                   0,
                                   0.18703538306346229,
                                   0,
                                   0,
                                   -0.58074960411621412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27726099686221711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1200170509475074,
                                   0,
                                   -0.28701297601231018,
                                   0,
                                   0.31430327635762001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1766508954949397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050274928734481181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13846516832215919,
                                   0,
                                   0,
                                   0.2295911468523133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24979507897407363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.603990688225434,
                                   0,
                                   0,
                                   0,
                                   0.18734959839679829,
                                   0,
                                   -0.052334628870764677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21636953210195453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28371514616007371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40885640561444236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087580403981169508,
                                   0,
                                   0.23493981120056323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26832893195828744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67768007667003827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43028718647447917,
                                   0,
                                   0,
                                   0,
                                   0.61694018102178216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06201204974792876,
                                   0,
                                   0.17733349086252831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016142542928606979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044786303539468969,
                                   0,
                                   0.021036682821235633,
                                   0,
                                   -0.45684652970719097,
                                   0,
                                   0,
                                   0.26397466263619762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1011609332595079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29617037434273052,
                                   0,
                                   0.16013815468638953,
                                   0,
                                   -0.011819294276056276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03804935035494203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047312025110354025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11596052354197603,
                                   0,
                                   0,
                                   0.67501718314673798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22315633451916383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012891451954859606,
                                   0,
                                   0,
                                   0,
                                   -0.083809817306005813,
                                   0,
                                   -0.26187168994586285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082881865399859686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27329097465677565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057041420897848479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30220231749930954,
                                   0,
                                   -0.42099430683989425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21972583093463705,
                                   0,
                                   0,
                                   -0.0020752697648088667,
                                   0,
                                   0,
                                   0.0094154512840704876,
                                   -0.95659417234365451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62442603617628822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26150019483673898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15528530207942595,
                                   0,
                                   0,
                                   -0.11654968068588992,
                                   0,
                                   0.61353767706735596,
                                   0,
                                   0,
                                   0,
                                   -0.59062499710806582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45490361929224904,
                                   0,
                                   0,
                                   0,
                                   -0.53568486817106908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59069198489725405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35343542038952069,
                                   0,
                                   0,
                                   0.20948197058506393,
                                   0.25255409146748781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089211409808200554,
                                   0,
                                   0,
                                   0.27379598798796639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58376223332789434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062710530714463059,
                                   0,
                                   0,
                                   0,
                                   -0.582909310352974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3716999204884382,
                                   0,
                                   0,
                                   0.0073594729760733113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094731547696363994,
                                   0,
                                   0.66106314162441382,
                                   0,
                                   0.010122912399157559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34008326276948997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29815216178024456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39442070388611705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14412341291611377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18658350294945433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24178026008464845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62404978514873699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040626810827803152,
                                   0,
                                   0.65821037059370657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54830538796350825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57975129749203302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17860772007311676,
                                   0,
                                   0,
                                   0,
                                   -0.36878240651074196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036036517206955311,
                                   -0.35880750880643486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027392798506137718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28633338039993816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14633588001239728,
                                   0,
                                   0.17471413859746693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40752261735509121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91060325244249229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85560518629021776,
                                   0,
                                   0,
                                   0,
                                   0.30099730223904508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43216624746901272,
                                   -0.37035480275087329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30657123006304626,
                                   0,
                                   0,
                                   -0.46981841642811251,
                                   0.47437094944360314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61830171811611734,
                                   0,
                                   0,
                                   0.074551949589951177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051607381885839278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023581896552978068,
                                   0,
                                   0,
                                   0,
                                   -0.26302567038871816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33930662640929693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47152526738402822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35467657391213642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15955915229954154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42640533572154671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57398504335632206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48989667961730482,
                                   0,
                                   -0.53909285547265839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8501363380491771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43372370703069019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04082864434321104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32237134511044307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13839912301423107,
                                   0,
                                   0,
                                   -0.26788610407737001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04397607211599415,
                                   0,
                                   -0.33014712797486817,
                                   0,
                                   -0.084246917677511496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59365103226280269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40108406160256393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15877139503703261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42106152825246312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27434105560336647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36015369993849705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12380671750801328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62670177681085004,
                                   0,
                                   0,
                                   -0.062993777041942742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31551456789038507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33399964117422709,
                                   0,
                                   0,
                                   0,
                                   0.16342498887547172,
                                   0,
                                   -0.17721774342498206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12431409599055682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2509318395301276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27459625573071667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028116827068549073,
                                   0,
                                   0.0070253270586994737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18535107307358478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40926160468329886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15347609579818808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16010939171076022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39324259723524607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17070155880158772,
                                   0.74207588088506315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87044856406368309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16435103409391597,
                                   -0.03952784170284418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42830080224979039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30754191227339961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14035127807389097,
                                   -0.41202736609799701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31514612417058102,
                                   0,
                                   0,
                                   -0.22798263538332569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05941610788880082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33371359699207759,
                                   0,
                                   -0.41387128386143118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079206652340272368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29529236251031449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20153851798832847,
                                   0.16434976909239951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028826310857091239,
                                   0.46195429540608873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63446910956917779,
                                   0,
                                   0,
                                   0,
                                   -0.17221552016832012,
                                   0,
                                   0,
                                   -0.18088974287339032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24358049515776689,
                                   0,
                                   0,
                                   0.075582259734580326,
                                   0,
                                   0,
                                   0.22921862057976816,
                                   0,
                                   0,
                                   0,
                                   0.29842658050842108,
                                   0,
                                   -0.2201211074333983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5890908291838588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73054643990060553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23684727289080193,
                                   -0.33755171957636043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1381175540759052,
                                   0.045201224820760076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69562014300928265,
                                   0,
                                   0,
                                   0,
                                   0.36388510881842029,
                                   0,
                                   0,
                                   0.46509827559658024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15543688687382437,
                                   0,
                                   0,
                                   -0.5834330712529382,
                                   0,
                                   0,
                                   0.26606112275622629,
                                   0,
                                   0,
                                   0,
                                   0.63427440930656276,
                                   0,
                                   -0.32490086052141132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12536050415876698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63937240482311009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30374277125659654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40380104905534875,
                                   0,
                                   0,
                                   0,
                                   0.28927084624089588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34189932615157026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13660279509483689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48689762163294648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24067517435095145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48006053040729951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61426955275861306,
                                   0,
                                   0.0097891361833389451,
                                   0,
                                   0,
                                   0,
                                   -0.077998254976790263,
                                   0,
                                   0,
                                   0,
                                   -0.38209572796594382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12281661612954152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11826120837515514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16942360091144709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10788831401542498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13132673750221874,
                                   0,
                                   0,
                                   -0.081801177254366517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53728263453764491,
                                   0.041892983983973869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28900195762501479,
                                   0,
                                   0,
                                   -0.056519104995139798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3194107257248171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045419127186824504,
                                   0.50034755188439051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5441566811994436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53489499557124742,
                                   0.25168843541106989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16302634884737055,
                                   0,
                                   0.14216626780356634,
                                   0,
                                   0,
                                   0,
                                   0.019811008256379159,
                                   0,
                                   0,
                                   0,
                                   -0.49706481892681853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14522767976754256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32925878691534438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066994360372878564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027307232913665588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1104408561440402,
                                   0,
                                   0,
                                   0.38994730525286714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24423879777629892,
                                   -0.21021917970893583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32275988337189321,
                                   0,
                                   0,
                                   -0.4457961135360714,
                                   0,
                                   -0.32394062427160686,
                                   -0.29936711770953572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62494170332310217,
                                   0.5418577835585191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10039683709917802,
                                   0,
                                   0,
                                   0,
                                   0.20174411864570696,
                                   0,
                                   0,
                                   -0.40683934193580074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12969043561121776,
                                   0,
                                   0,
                                   -0.29710312283015672,
                                   0,
                                   0,
                                   0.46008921382094919,
                                   0,
                                   0,
                                   0,
                                   0.26848387034223853,
                                   0,
                                   0.94516953517471725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010337065990514926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024303805168660153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53753760431039621,
                                   0.78766163257331423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46820109430417478,
                                   -0.34015591300310594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40879609416992424,
                                   0,
                                   0,
                                   0,
                                   0.31654697510026514,
                                   0,
                                   0,
                                   0.097644632048873206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60625676049461608,
                                   0,
                                   0,
                                   0.024362482284056859,
                                   0,
                                   0,
                                   0.31258050797909842,
                                   0,
                                   0,
                                   0,
                                   0.29018442426654489,
                                   0,
                                   0.1309750506899035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032002775754852324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31327723865950419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033329492159826828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12802793475611104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21100406405052508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061242754971386801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0928713863691593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36328091664964623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069997858441404034,
                                   0.20138480764686731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35376280005143151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40574253117522818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087588026430668708,
                                   0,
                                   0.35878990490000556,
                                   0,
                                   0,
                                   0,
                                   0.042379201219749724,
                                   0,
                                   0,
                                   0,
                                   -0.08226641729804901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12332535647492741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60303636368036884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12794263866553438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50812983708031789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044719673371268323,
                                   0,
                                   0,
                                   -0.23336617316318389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14484244977740601,
                                   -0.10780381438311792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013293335251644873,
                                   0,
                                   0,
                                   0.3352160522526042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33344926887310539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2134155098918371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54653664383207512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14674306726967229,
                                   0.80137953954530317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40396104092517193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38505520370901658,
                                   0.45278355295744616,
                                   0,
                                   0,
                                   0,
                                   -0.42976196064513028,
                                   -0.60546743169771255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25795059320377345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71290907990164742,
                                   0.095100994073947676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0350022179476581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13741589158676873,
                                   -0.16084744868892192,
                                   0,
                                   0,
                                   0,
                                   -1.0668061397076705,
                                   0.16640886513611536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2336025373523045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15354385182254679,
                                   -0.36427562314779793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041544443113649333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047871046152500832,
                                   0,
                                   -0.133414325576238,
                                   0,
                                   0,
                                   0,
                                   -0.26708171749174642,
                                   0,
                                   0,
                                   0,
                                   0.34138753831492319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070096062527693292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16836922522779646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050025629771596192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055773496361822092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.533926591680838,
                                   0,
                                   0,
                                   0.41393555376279634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42732173640170895,
                                   -0.1974518754010379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26808613074460969,
                                   0,
                                   0,
                                   -0.057222845515337871,
                                   0.079813035144286865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14152869399817386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25386434639181632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49214176700271151,
                                   0.29468160908356444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47136125992499017,
                                   0,
                                   0,
                                   -0.5631132074449714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095968146404180998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078908709697814425,
                                   0,
                                   0.1084253976891747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048151423487836215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10640777448675567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18615579044651603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37414182812120012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31032236297308735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3113481565355296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040238647099243831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24110575459430106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59554429144297061,
                                   -0.29361423456774649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2329087445997598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027831466339563404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83407432684556193,
                                   0.56811906471430662,
                                   0,
                                   0,
                                   0,
                                   0.42995170568374314,
                                   0.79870199197222258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20952373220429168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23045031589598386,
                                   0.1251212084658353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54794575440665672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22558483460428846,
                                   0.25214317263198072,
                                   0,
                                   0,
                                   0,
                                   0.13454870852310796,
                                   0.41639076497421956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045340743631912879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65993896311923839,
                                   -0.95028909769747161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59649343608542815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47307532387578494,
                                   0.3213560440907543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20624281196945365,
                                   -0.23439589605422678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50214490749674445,
                                   0,
                                   0,
                                   0,
                                   -0.60513918694760405,
                                   0,
                                   0,
                                   -0.59822041621016209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97008814200516802,
                                   0,
                                   0,
                                   -0.13895087201213366,
                                   0,
                                   0,
                                   -0.18144582073345789,
                                   0,
                                   0,
                                   0,
                                   0.2778644316830306,
                                   0,
                                   0.30329214419728368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29498055020983244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047701057190651035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13266095794851049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35384179136630867,
                                   0,
                                   0,
                                   0,
                                   -0.3465282879078142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038430990752200148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12486020178835031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24877368371206354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55718141345228756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58966831214960413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14441123747545231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35085020084136054,
                                   -0.19446801010353409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66713968081122443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39259817584913825,
                                   -0.46799897725719858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33043055337304372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31153946778392738,
                                   -0.76256578671545261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21930808756110726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14053874652583184,
                                   0.38000664967441306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28285955911941801,
                                   -0.5910995720759844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16853107962580324,
                                   0.028820025015740248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25320093389456999,
                                   0,
                                   0,
                                   0,
                                   0.33067124819203703,
                                   0,
                                   0,
                                   -0.33392856438271018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10995189829694879,
                                   0,
                                   0,
                                   -0.1789288577718405,
                                   0,
                                   0,
                                   -0.25212737806164176,
                                   0,
                                   0,
                                   0,
                                   0.94065861898200509,
                                   0,
                                   -0.37883710516108093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40169583750132887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46787585542917787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25182438208880475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12680410960175742,
                                   0,
                                   0,
                                   0,
                                   0.39969736454865401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63896488856013689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26204047193020819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3635103014207704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38474395845486892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060317697220152837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47871992204198316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37580234051246963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41617296823066102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17263341130793386,
                                   -0.11789891253870369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03658240348820984,
                                   0,
                                   0,
                                   -0.0036088203348209821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34510263369827254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25772691169072587,
                                   0,
                                   0.22683079058578021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34383694882289889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23696225392243586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090782758882202802,
                                   0.15038162701639424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24006344067055954,
                                   0.42409001474686658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093337055237424027,
                                   0,
                                   0,
                                   0,
                                   0.38824798643609559,
                                   0,
                                   0,
                                   0.13697118668809596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22519132889599169,
                                   0,
                                   0,
                                   -0.19290906443264361,
                                   0,
                                   0,
                                   -1.1706127041249119,
                                   0,
                                   0,
                                   0,
                                   0.30285408440691297,
                                   0,
                                   0.18736999752250583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1413447311782752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19974185157614363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24500061566583031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37156159901184005,
                                   0.6342117770256015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23456162677532696,
                                   0.08892248569966904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24019204482172421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17015443113479042,
                                   0,
                                   0,
                                   -0.21993908831630926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17661285271525418,
                                   0,
                                   0,
                                   0,
                                   -0.41298387617749316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19138689619805871,
                                   0,
                                   0.09353035335742696,
                                   0,
                                   0,
                                   0,
                                   -0.12278622579718532,
                                   0,
                                   0,
                                   0,
                                   -0.20997149952429023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50502715652451857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39622303969810413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063717642259816507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2611173463896766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27848013275490491,
                                   0,
                                   0,
                                   -0.22615433947725988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040080221496560826,
                                   0.018062685756112237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50816796389417174,
                                   0,
                                   0,
                                   0.14935519631756411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031060402219134895,
                                   0,
                                   0,
                                   -0.32755746348672521,
                                   0,
                                   0,
                                   0,
                                   0.21415913374395637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77747571444445218,
                                   0,
                                   -0.27475969358098851,
                                   0.16938515143157612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24134791878411369,
                                   -0.21339548013005505,
                                   0.14922740276499705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1916049320888404,
                                   0,
                                   0,
                                   0,
                                   -0.41314504545021413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.271049616461148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02238240742923446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39185147733306031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33170284620165824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043907110747420458,
                                   -0.069340449698245377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085141024024296408,
                                   0,
                                   0,
                                   -0.15658608874761037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14251777701317109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4910234865905454,
                                   0,
                                   0.38922827715024871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27742692988540013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45556646668107198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20980581994127778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058505976562094955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22670465339277862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40241745907671339,
                                   -0.41739598190659033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25469364301773878,
                                   0,
                                   0,
                                   0.046118860662902134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1210097731378288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01847853648331467,
                                   0,
                                   0.55453077957142682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045986530119899872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41641875872891254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073419279315058747,
                                   0,
                                   0,
                                   -0.30363782852474031,
                                   0,
                                   0,
                                   0,
                                   -0.05852998955046837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22049900015205087,
                                   0,
                                   -0.4848510356743338,
                                   -0.42999019400427785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47835165062530111,
                                   -0.040393677068918624,
                                   -0.09619138449067291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30041859032933521,
                                   0,
                                   0,
                                   0,
                                   0.14411134548314652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50841838676383377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76985142835147624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37057464597632039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5728227575327447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21946980385913697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065801183256173151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73958960063643386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47471062649986434,
                                   0.25692823905271733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34620316577385413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051697662332574307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8218021003068614,
                                   0.32530783014836728,
                                   0,
                                   0,
                                   0,
                                   0.43057134173282341,
                                   0.49236726630491362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87664989255904058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24335506448726069,
                                   0.7710337939600419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20842995125818267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1876065181403791,
                                   0,
                                   -0.13631017567735748,
                                   0,
                                   0,
                                   0,
                                   0.091663849289348065,
                                   0,
                                   0,
                                   0,
                                   -0.27108702989907152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5522819144515545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33592348696854912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23233710742070746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070397225067015456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12935747763935501,
                                   0,
                                   0,
                                   0.22815286644488009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020059499888328832,
                                   -0.10214121267402068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33295708827633003,
                                   0,
                                   0,
                                   0.44390761135499446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23906138139492311,
                                   0,
                                   0,
                                   -0.29651084388531096,
                                   0,
                                   0,
                                   0,
                                   -0.024944847127000014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21423034484304532,
                                   0,
                                   0.85751069373052824,
                                   -0.27940509791015755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029778298766044334,
                                   -0.4851364170366832,
                                   -0.62382334049158461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06082881509001524,
                                   0,
                                   0,
                                   0,
                                   0.15460608719567939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18799500792170293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18605111416423509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48408741635554664,
                                   -0.071042428627043533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029537788739378446,
                                   -0.46315550044091308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35020873256239315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3155592999739889,
                                   0,
                                   0,
                                   -0.32441640501876307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32224538471619019,
                                   0,
                                   0,
                                   0,
                                   0.28160239886714505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31140256233435387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0064395751333784883,
                                   -0.21751773014677356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20437748618625928,
                                   -0.40235706122464721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023758717488185657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23998991487305363,
                                   0,
                                   0,
                                   0.23282571137691607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23631234028058123,
                                   0,
                                   0,
                                   0,
                                   -0.69555782045336423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73460936815867206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12097334656653491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55159138426950838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14410571417986484,
                                   -1.2219198139602221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3361787076339024,
                                   0,
                                   0.77800076970738186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11450370270930704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34531097278030753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10902120410073932,
                                   -0.049366925189751359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037795652555843544,
                                   0,
                                   0,
                                   0.22710839855074941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015842095327011113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13077631572377701,
                                   0,
                                   -0.089689354706969815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14683926637549016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38480542739330365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85164650017088273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90855316093181837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13130579072785237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20814995947192394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37632774088280013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31922079083974408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27705538911983363,
                                   0.14965780328931022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06651326851683384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94866335187519502,
                                   0,
                                   0,
                                   0,
                                   -0.6898448910036582,
                                   0.17688876774367007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26381639732329765,
                                   0.033195003331510875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26142643427297974,
                                   0,
                                   0,
                                   0,
                                   -0.32396873725627406,
                                   0,
                                   0,
                                   0.82752632692538575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051392526084297514,
                                   0,
                                   0,
                                   -0.26106028645990192,
                                   0,
                                   0,
                                   0.12320955201053196,
                                   0,
                                   0,
                                   0,
                                   0.84129917771587692,
                                   0,
                                   -0.042454934287489504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038014483123865704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5583415640435283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09291059113183113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28559957575905903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29604035746987523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050061890339964638,
                                   0.032331905240190681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39860504392526386,
                                   0,
                                   0,
                                   0.11153712333467768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08940563900415445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24032405907003454,
                                   0,
                                   0.27814526299018355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70567571415778951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078679938459280938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054629529632629195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20400639084048428,
                                   0,
                                   0,
                                   0,
                                   0.57840182454827838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11093470123718584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6063569352761824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45972503894737504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16956543462529594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02781272005109801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24468354741330034,
                                   0.60465491578971209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42330422608426338,
                                   0.67399754420619429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27197982611102334,
                                   0,
                                   0,
                                   0,
                                   0.69173609761151855,
                                   0,
                                   0,
                                   0.37241675560553544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4034957442314675,
                                   0,
                                   0,
                                   0.67572503028164554,
                                   0,
                                   0,
                                   0.41427570673189562,
                                   0,
                                   0,
                                   0,
                                   0.016465690417588295,
                                   0,
                                   0.30627283216797063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1589640486729432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33650325471838993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29047355190523139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060228356643579339,
                                   -0.028076249652921919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13813598779199679,
                                   0.61771436609136987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33722312793894132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26627174084674105,
                                   0,
                                   0,
                                   0.3623259303693484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43548707373610468,
                                   0,
                                   0,
                                   0,
                                   -0.070764726427357399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2284652276116427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055591557127746112,
                                   0.28958493752446762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51583836310127418,
                                   -0.21480335081967736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6190157742358261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35413867615489181,
                                   0,
                                   0,
                                   0.16988327078089399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092613517947717452,
                                   0,
                                   0,
                                   0,
                                   -0.050909390466542241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33023699985970456,
                                   0.19766791712856363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5669717078117541,
                                   -0.046118759782573043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55866455851682661,
                                   0,
                                   0,
                                   0,
                                   0.44690940570609489,
                                   0,
                                   0,
                                   0.014524616985908539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45479605670326229,
                                   0,
                                   0,
                                   0.0056519809409829175,
                                   0,
                                   0,
                                   0.059429783535228597,
                                   0,
                                   0,
                                   0,
                                   -0.41338619220118289,
                                   0,
                                   -0.40629631837706759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84570245356397078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37204726832873058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38600399686715187,
                                   0,
                                   -0.5213036589455925,
                                   0,
                                   0,
                                   0,
                                   0.1397425492644323,
                                   0,
                                   0,
                                   0,
                                   0.23099247728938471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072434772336109537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31051862668834956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40765860273673588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094756255831627001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12897119338217647,
                                   0,
                                   0,
                                   -0.20040304641613715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12772021733859729,
                                   0.020988243437322262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38144819129245289,
                                   0,
                                   0,
                                   0.10234438973307503,
                                   0,
                                   0,
                                   0,
                                   0.035725289636394264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11760759142926253,
                                   0,
                                   0,
                                   0,
                                   0.45199980011152874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20425410353298562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64436404393456126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47898818521060843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21339930664231502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22066860502844859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0036442772550242374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12300462455577157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065681946036320327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069186427660739278,
                                   -0.2820163947184125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17829538595798769,
                                   0,
                                   0,
                                   -0.04094979554293661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60920853199035918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58408790098448082,
                                   0,
                                   -0.11590420864567523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3182736140554524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18902574947005429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76584841084690725,
                                   -0.026914802581114991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039304791720733021,
                                   -0.34031211651414361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0047355120958177746,
                                   0,
                                   0,
                                   0,
                                   -0.18769146688984734,
                                   0,
                                   0,
                                   -0.18632460684179575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33144052925578138,
                                   0,
                                   0,
                                   0.40962983011858284,
                                   0,
                                   0,
                                   0.035183696268445946,
                                   0,
                                   0,
                                   0,
                                   0.54955085983533025,
                                   0,
                                   0.16564822667210627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15827489974750189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48177307106899792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87426839675751089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089354991889619734,
                                   -0.13585174163099714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39440499281541164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2029561133961037,
                                   0.11166144289192047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076761260223580957,
                                   -0.42938775738527146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52644990042909412,
                                   -0.73765868890958142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13955548313692104,
                                   0,
                                   0,
                                   0,
                                   0.3367279443607018,
                                   0,
                                   0,
                                   0.072576488346581716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12625938968666683,
                                   0,
                                   0,
                                   0.32120906736095295,
                                   0,
                                   0,
                                   -0.15242587586788306,
                                   0,
                                   0,
                                   0,
                                   -0.21229171440068517,
                                   0,
                                   -0.090589300394637945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78985973789914621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12985601734703903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73986566416892718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0052192258888161536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081612033705383641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10220759884517942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19851561212885097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1296399565210678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21100217299005949,
                                   -0.81562056897645663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68360968633324626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50482650980479726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81644376996149337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30087354012716638,
                                   0,
                                   0,
                                   0,
                                   0.25359448188649492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13001834716086502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041690293395835937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32107327828915611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077381182401746004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22553441758636053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047693103028882342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071931264500415426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32390246645076282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49279128017599561,
                                   0.16893873705647711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34210423899171932,
                                   0,
                                   0,
                                   0.22149430239804332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3094974975876737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14805529506558363,
                                   0,
                                   0.42647017656178832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35473912267143332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15727093263218234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34613254388287978,
                                   0,
                                   0.66299528504627214,
                                   0,
                                   0,
                                   0,
                                   -0.14426118390151024,
                                   0,
                                   0,
                                   0,
                                   0.28943100951951267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054999026765332616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030005244415851839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23991396217062633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18854599108604744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055678192387136782,
                                   0,
                                   0,
                                   0.15575164431640337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10794646452444759,
                                   0.35593652126832459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22593950990652856,
                                   0,
                                   0,
                                   0.14921080274337745,
                                   -0.20546520998829793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4290894939362872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29831713980943292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42367454723202652,
                                   0.39129896658366259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021023494537416261,
                                   0,
                                   0,
                                   0.53826461324092489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17146694727402434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098480193315991088,
                                   0,
                                   -0.12952235788893118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035746304108262815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068805896758024954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34789828791666427,
                                   0.29501373551958815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28462524657022581,
                                   0.099139333497463164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25024720814073464,
                                   0,
                                   0,
                                   0,
                                   0.33723000760683075,
                                   0,
                                   0,
                                   -0.81265924657462463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22473194638783633,
                                   0,
                                   0,
                                   -0.85179856296907519,
                                   0,
                                   0,
                                   0.46186771494816037,
                                   0,
                                   0,
                                   0,
                                   0.1540724580689192,
                                   0,
                                   -0.63224606141445661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12171133439807021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16634416942046709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44717385033099882,
                                   0.011253702704237584,
                                   0,
                                   0,
                                   0,
                                   -0.28855989068409743,
                                   0.62623078626107587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62511443491484353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1164991990572368,
                                   -0.45365049363439908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18902273725054819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2837529727148615,
                                   -0.4224682174698986,
                                   0,
                                   0,
                                   0,
                                   -0.47850554196255679,
                                   0.21166292231539352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42252733093830164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19306669460352641,
                                   0.81185078714849779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76319562872200852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0866013440530438,
                                   0,
                                   0,
                                   -0.32824091986055531,
                                   0,
                                   0,
                                   0,
                                   0.36391501648573843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35305292819168271,
                                   0,
                                   0.021920252054605419,
                                   -0.087605377832714548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09198606949739345,
                                   0.44295711698462392,
                                   -0.20009841742755693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047014581483064824,
                                   0,
                                   0,
                                   0,
                                   0.067362166965079892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35989848672450514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20375252832538526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58127088012278982,
                                   0,
                                   0,
                                   0,
                                   -0.16984801295051771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25422282480809272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32114506546020805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15350888552083508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29471680489378305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55997710031353609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35156879883866615,
                                   0,
                                   0,
                                   -0.1313873783461294,
                                   0,
                                   0,
                                   0,
                                   -0.20653361056546907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34224760613650834,
                                   0,
                                   -0.26721778729614581,
                                   0.083548347981319798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46082394726532938,
                                   -0.38778466638212794,
                                   -0.095062752238447165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46454107026955932,
                                   0,
                                   0,
                                   0,
                                   -1.1433523637010861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16699780414476043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29317230320744825,
                                   0,
                                   0,
                                   0.47914795020193318,
                                   0,
                                   0,
                                   0,
                                   -0.54067268031676818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13843561249629019,
                                   0,
                                   0.30332477749958636,
                                   -0.15428616207696488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82386447831216481,
                                   0.65338018387251151,
                                   -0.11902429291720384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15174819150332841,
                                   0,
                                   0,
                                   0,
                                   0.13128693308139541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92059999865014019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22713890017012267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23624195031849946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16874069342546863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13702811884726374,
                                   -0.35899134710437508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19320698829067209,
                                   0,
                                   0,
                                   -0.01382418591339327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55169859866526461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3326183633194757,
                                   0,
                                   0.047917907513876021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13530615720365233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49329757429576943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18371744917936034,
                                   0,
                                   -0.0075071067416995849,
                                   0,
                                   0,
                                   0,
                                   -0.16737006196992965,
                                   0,
                                   0,
                                   0,
                                   -0.3554576755762115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50105778616649221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093219661484902169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43014593010681818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21034188477908108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42853041021293814,
                                   0,
                                   0,
                                   -0.28277700383058574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18059482274914729,
                                   0.11179744368853682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02488646963270677,
                                   0,
                                   0,
                                   -0.11609032792484066,
                                   0,
                                   0,
                                   0,
                                   -0.33818585954431729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4602287919716237,
                                   0,
                                   0,
                                   0,
                                   -0.066869584113087535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58119834730816389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096635447668771773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038377078181883656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56254677691295152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065472415262764663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4081842550025957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1031443461244546,
                                   0.0060208849836669298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40236598971875964,
                                   -0.25208166176845304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48184207860417005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21181006629371532,
                                   0,
                                   0,
                                   0.37062756049586632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42708208921508983,
                                   0,
                                   0,
                                   0,
                                   0.021630082474815765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14455757438739805,
                                   0,
                                   -0.056291532138488143,
                                   0,
                                   0,
                                   0,
                                   0.54110039601077831,
                                   0,
                                   0,
                                   0,
                                   -0.17492227120924536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21784259935847639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1085675252309025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24386111074100864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056735326912143592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28587584870499827,
                                   0,
                                   0,
                                   0.45795351239657778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05592500792285747,
                                   0.25105210214724655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19332102332900775,
                                   0,
                                   0,
                                   0.36829782015803492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25907223543260494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55746134496722966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44154876090517192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31936193634272381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25614054861199442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64872166742336357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59483665596982682,
                                   0.86462215533597775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57242229400631983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42768526299063603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5458758731154375,
                                   0,
                                   0,
                                   -0.0033351072416278327,
                                   0,
                                   0,
                                   0,
                                   0.42058631201536734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46728022203475517,
                                   0,
                                   -0.2006306612547252,
                                   0.075670015862357998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32373922126024002,
                                   0.021680336011252462,
                                   -0.73290357977976661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62364627388043892,
                                   0,
                                   0,
                                   0,
                                   0.21197491079837275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21200888787809991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.459215428371472,
                                   0,
                                   0,
                                   -0.90798021332306811,
                                   0,
                                   0,
                                   0,
                                   0.075939558678856239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39711107127217732,
                                   0,
                                   -0.14190780912136952,
                                   0.45401462809506704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55724298151374441,
                                   0.47228951572039951,
                                   -0.46362620054434006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29150109204502189,
                                   0,
                                   0,
                                   0,
                                   0.10691138861417174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31236229713467006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.387510382224592,
                                   0,
                                   0,
                                   0.21526331262978504,
                                   0,
                                   0,
                                   0,
                                   0.19113799682107574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28681905424972526,
                                   0,
                                   0.22695796630328263,
                                   0.048298272425863584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69916738259177347,
                                   0.81977512697255084,
                                   -0.15709276579267906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16176776771399742,
                                   0,
                                   0,
                                   0,
                                   -0.82238891199919562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16372568096084253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25083709939526394,
                                   0.080580029926919206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52356978019820488,
                                   0.50104334016426488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27730698336329851,
                                   0,
                                   0,
                                   0,
                                   -0.45096784567996029,
                                   0,
                                   0,
                                   -0.13746963655612257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17455338155660005,
                                   0,
                                   0,
                                   0.38043017818403435,
                                   0,
                                   0,
                                   0.20231484373514677,
                                   0,
                                   0,
                                   0,
                                   0.080186509967773004,
                                   0,
                                   -0.58440751273802971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31698092830117275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31590424141646195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091442278071569294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37870781596331288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26977050207346764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29005070030202668,
                                   0.39613493141569633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50807026090881025,
                                   0,
                                   0,
                                   -0.44675831181405751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15578509795322545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12755195147165063,
                                   0,
                                   0.081899431890276181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16685310962987313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039697985924600214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34913640249453542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32854510514458046,
                                   -0.037745027165219526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02314138108559699,
                                   -0.15708129711047633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077050975843393488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0080572005607279784,
                                   0,
                                   0,
                                   0.64179783037996185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47958861829479849,
                                   0,
                                   0,
                                   0,
                                   0.3092178400495561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65341381457092118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34269433025934454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0134786981128738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33018049211773615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10714893787967517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17389930983271268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18152715570816047,
                                   0.84034535455091297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29328062169941693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.628339474218511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027545145278812033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33492063400148442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70613658620397923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1618667941516001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022058722885067009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86604104636294954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71608398815451246,
                                   -0.31835947518311175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73383975215039587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78691480114847501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57819550241758588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43043739325065467,
                                   -0.24368748122292502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21827098415651391,
                                   0.14211369606728685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22909049855334493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27267257722810745,
                                   0,
                                   0,
                                   0.084841672160035103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29561870444375582,
                                   0,
                                   0,
                                   0,
                                   -0.36300162421781451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05660731593715132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8207673584875228,
                                   -0.1328330915092934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11089236631931351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052412134586021925,
                                   0.53893206999039234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019703156949631727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31006616734802217,
                                   -0.30696516967991672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20704999410232464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70431857915363649,
                                   -0.51991228209856399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37209618486266133,
                                   0,
                                   0,
                                   0.31867191328244798,
                                   0,
                                   0,
                                   0,
                                   0.042461493608665801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40813159877374117,
                                   0,
                                   -0.010696633148205681,
                                   -1.3001681399075051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46085233678867593,
                                   0.14842076034762,
                                   0.15680241973567149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19861309504300562,
                                   0,
                                   0,
                                   0,
                                   0.0098781814433910042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22707743395982857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83323741138999252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3633645356882203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1532999878022114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31576904280990858,
                                   0.64542368354718138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9560741875803459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0065009515490948439,
                                   0,
                                   0.29615520876554807,
                                   0,
                                   0,
                                   0,
                                   0.6365886628623787,
                                   0,
                                   0,
                                   0,
                                   0.16368398556885139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11972393139265253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19406492035044781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20628898647224064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087133279877973119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058298379118270377,
                                   0,
                                   0,
                                   -0.18283401273222083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19331141826448781,
                                   -0.48539389733929811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13584854065959714,
                                   0,
                                   0,
                                   -0.22318500498020416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14245613558310202,
                                   0,
                                   0.052486121655094559,
                                   0,
                                   0,
                                   0,
                                   -0.34629861941963092,
                                   0,
                                   0,
                                   0,
                                   -0.092897901956639245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15503240580192745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019207506693445883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42513612191818007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22753989801777449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28522746289932543,
                                   0,
                                   0,
                                   0.11735290366302284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020646913968505601,
                                   -0.56696180517473505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14561023414092042,
                                   0,
                                   0,
                                   0.39150845009609442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33805183864171084,
                                   0,
                                   0,
                                   0.076056167680544712,
                                   0,
                                   0,
                                   0,
                                   -0.52395642703927292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44700783099952424,
                                   0,
                                   -0.25632235240700918,
                                   0.33037843531043498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14928578703175771,
                                   -0.15143903408248605,
                                   -1.0182651732507573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0052435756730856431,
                                   0,
                                   0,
                                   0,
                                   -0.0083534676479671277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3608778915773837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073509507478403791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46255075487718506,
                                   -0.45337962819117977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3728061065197672,
                                   0.25823511524982212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17590917851842633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53320346886095027,
                                   0,
                                   0,
                                   -0.22963898771001989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03023100154718858,
                                   0,
                                   0,
                                   0,
                                   0.022854758457130836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62943730197076342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45062981326571289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32599754525142677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27832711846422564,
                                   -0.39741991743767446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72461975049999261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27643378694025672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80735550929406796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44795305770381694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64903337406476913,
                                   -0.24890298029278715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74743647560723758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37985276093368331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57453290934920265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19663055258562945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55654260329856409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11327046858680374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098882488184381973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58215143383321499,
                                   -0.44318942398327421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28277409646176965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61090531598846742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20878836304889048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32098569216154571,
                                   0.44087311843401805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51779040997958292,
                                   0.1134710367103107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025730227526466892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46257442683341354,
                                   0,
                                   0,
                                   0.15109982960599683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33194479875474792,
                                   0,
                                   0,
                                   0,
                                   0.17426491497185703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50358645015349257,
                                   1.2283738549164078,
                                   0,
                                   0,
                                   0,
                                   -0.50851044740355555,
                                   -0.024119395683189958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60075768512400496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5535529646087789,
                                   0.6199089271168805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016820575148049688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0060583973473515886,
                                   0,
                                   0,
                                   0.31386168441502815,
                                   0,
                                   0,
                                   0,
                                   0.96704860917429225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67067518024285699,
                                   0,
                                   -0.31223436307131208,
                                   0.13038316157141405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033918573288689767,
                                   -0.17403428304579649,
                                   -0.3318898853168839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15608977964833226,
                                   0,
                                   0,
                                   0,
                                   0.33698581895671043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1316140584799867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35195826702749095,
                                   0,
                                   0.028420341160416741,
                                   0,
                                   0,
                                   0,
                                   -0.067239803801585341,
                                   0,
                                   0,
                                   0,
                                   0.17314903519428798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0099349702719682739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14443659717880963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056168627026337931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29700381603916653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40885375912670208,
                                   0,
                                   0,
                                   0.067182249581889814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58368202013422543,
                                   -0.34763774851086604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3058232607596621,
                                   0,
                                   0,
                                   0.04182875305728672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26465415186183627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11632102056299014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65810132793486364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024301899680544858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044319356090035761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14368442814927065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.089373988029303,
                                   -0.29125918801063688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27299347695906062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2264463320586152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50337749670369725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12549429166226356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2270859885323526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93605803113508568,
                                   0.038462536423126165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17689886192370302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21596394461366247,
                                   0,
                                   -0.0043810374685979842,
                                   0,
                                   0,
                                   0,
                                   -0.078011159275208103,
                                   0,
                                   0,
                                   0,
                                   0.081000911701590253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.195910933461524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19767043876038853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44182152095562344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64311814594127281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22843459310841488,
                                   0,
                                   0,
                                   0.32623625388356697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062413790015226241,
                                   0.11010364527700638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058593220057557696,
                                   0,
                                   0,
                                   -0.276347017789285,
                                   0.74237038729504456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37550149050219417,
                                   0,
                                   0,
                                   0,
                                   -0.76222510765239293,
                                   -0.12308374800668066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027718151102407287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52105103896844929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81588010859278493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3659184563123426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3364120479399787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17975871880985186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15467504339472957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26709558389213767,
                                   0,
                                   0,
                                   0.71398739089403818,
                                   0,
                                   0,
                                   0.28944214435610333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70368352500779963,
                                   0,
                                   0,
                                   0,
                                   -0.2184481002783869,
                                   -0.22658116727057134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32367889544153228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40768803513754748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09278311653636119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40918089994583978,
                                   0,
                                   0,
                                   -0.096941601638184924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68694844380090969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39097922404815133,
                                   0,
                                   0,
                                   0.37880828770003694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34618471117964045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2347705850413597,
                                   0,
                                   0,
                                   0.020335540975497807,
                                   0,
                                   0,
                                   0.55825801120439744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51074492960485063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79616882051788074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62830369915980644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33296037962131597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19013876384531342,
                                   0,
                                   0,
                                   0,
                                   -0.55394330283707693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11912117900507541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0017253242642607178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4836861337863898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38901819720550362,
                                   0,
                                   0.032576270781179917,
                                   0,
                                   0,
                                   -0.13054625990529919,
                                   0,
                                   0.27849038209868426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036784856005120867,
                                   0,
                                   0.22279503938838821,
                                   0,
                                   0.060830509735336658,
                                   0,
                                   0,
                                   -0.53957604358097178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59663390441686182,
                                   0,
                                   0,
                                   0,
                                   -0.12244004419114758,
                                   -0.44262947838515054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04517730664816888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47780230414640729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13800101565330419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31054843643949348,
                                   0,
                                   0,
                                   -0.56826322587440103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26038427117795543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0071096302046380344,
                                   0,
                                   0,
                                   -0.24852845282932085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51727748863096457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1188115189322745,
                                   0,
                                   0,
                                   0.51211204094568541,
                                   0,
                                   0,
                                   0.1478928785475353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10471283894892509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34947030746361307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.4768716190857889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10275791499519588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4382808541912625,
                                   0,
                                   0,
                                   0,
                                   -0.48861797447455524,
                                   -0.48819121038030489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18367862993321427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27641850558548275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72407004380952167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047723287736569919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72811952282840142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31842934637356296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21483484689762472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27989623518049883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72925117212072754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40174495711518532,
                                   0.35450654778058882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31864448703244413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57413153602671096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030058245477819323,
                                   0,
                                   0,
                                   -0.25929096311123162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82600436657053888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52430815896957994,
                                   0,
                                   0,
                                   -0.27501033953822585,
                                   0,
                                   0,
                                   -0.70016490514165364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68592623244450324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43544390252479698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3786903850367388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32131442081302913,
                                   0,
                                   0,
                                   0.31567328225640223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085370310179408729,
                                   0,
                                   0,
                                   0,
                                   0.24780924017867847,
                                   0.41203582375226244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12169015300322178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4528076116084046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25160148012174377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037130808287769185,
                                   0,
                                   0,
                                   -0.79357012138822325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61331404417109658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1822920936370464,
                                   0,
                                   0,
                                   0.72647316563875153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33151862464879145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0261799661507296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02190980273625498,
                                   0,
                                   0,
                                   0,
                                   -0.79802164341965365,
                                   0.09354954437311877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18414971755633408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072775919325252875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059289665774039595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13224461530815745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4127159812953593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56476350206301218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22619199779492558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49724570597688733,
                                   0,
                                   -0.34001846583705131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31576940796895597,
                                   0,
                                   0,
                                   0,
                                   0.12514632726489047,
                                   -0.96292088975717427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38077333410038755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13562220516911921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59393307257110795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22917924132046141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24420600855224808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089594898574910098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30202025098417229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21602721934147684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65860928383381179,
                                   0,
                                   0,
                                   0,
                                   -0.063036864016165761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34366308993066963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056750523613889048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11116985525637507,
                                   0.40678885609485149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1008030944680457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50292946791449811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040684897037664057,
                                   0,
                                   0,
                                   -0.067277185692109998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84533390862833246,
                                   0,
                                   0,
                                   0,
                                   -0.23293673253274849,
                                   0.58566061837081085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063100073320517702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2208578825111733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16482035711588927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26938691357694527,
                                   0,
                                   0,
                                   -0.27769888902977202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24921766240123713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41292652506996291,
                                   0,
                                   0,
                                   -0.59671331552130447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84863427345751896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32278419487506638,
                                   0,
                                   0,
                                   0.37077341017770832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61706715757024666,
                                   0,
                                   0,
                                   0,
                                   0.62154505104781765,
                                   0.23935116394887182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055328994800071002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13208960687669735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11570018110346102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45574838974973486,
                                   0,
                                   0,
                                   0.046614409933189785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49288604601818342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21310044156438776,
                                   0,
                                   0,
                                   -0.34286173226848837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71475337405374928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29961580505579155,
                                   0,
                                   0,
                                   0.79648884732477598,
                                   0,
                                   0,
                                   -1.0774994116498271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51846815511256128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36167036962780996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020919146687296108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23506646034504355,
                                   0,
                                   0,
                                   0,
                                   -0.43996920516870602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027940165602862485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23755155107979536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42262428912427624,
                                   0.19766746820057277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28657044689354283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62781615674841351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0074706291120487586,
                                   0,
                                   0.046506609771276616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37272052463828109,
                                   0,
                                   0.32405270363688532,
                                   -0.18798164462358674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3348735150392117,
                                   0,
                                   0,
                                   0.096746335313815629,
                                   0.0040235029986951248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60603314009830589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06427067595640075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16905673592931106,
                                   0,
                                   -0.31864226035657228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22612429191800676,
                                   0.21058256536371447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65259896430012321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014190690041869652,
                                   0,
                                   0,
                                   0,
                                   -0.15350977005371458,
                                   0.35175431972295346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33360939083249808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38653156137295686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52065506792164629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30529182743983152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5335395205144644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10300632273996849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84758177729505635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17174001560085708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33230190848821883,
                                   0,
                                   -0.43557542319744991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40045033335323282,
                                   0,
                                   0.023776856822871784,
                                   0.12523315697946061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27253119845804036,
                                   0,
                                   0,
                                   -0.027678722692684732,
                                   0.10262261829484851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0015985679607199588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14559013755804245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24747137533886182,
                                   0,
                                   -0.27524237505949711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25154765511517513,
                                   -0.46496651459498312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74395998141479569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061676467744070262,
                                   0,
                                   0,
                                   0,
                                   -0.1675622435372168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17716133001507742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085764675268154122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.001356604767628701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18568557248890949,
                                   0,
                                   0.014958590411522033,
                                   0,
                                   0,
                                   0.36038165981156656,
                                   0,
                                   0.059078018291475229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11179192674554775,
                                   0,
                                   0.44196540368078852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.307018126935589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075412939585826594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16781735359937663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2985421478553304,
                                   0,
                                   0,
                                   0,
                                   -0.61860172043628558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46416268130166427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079437669366138386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30935810059873559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02305615961015911,
                                   0,
                                   0.28653661651625156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.242603239895262,
                                   0,
                                   0,
                                   0.17964604004183207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14413090918817489,
                                   0,
                                   0,
                                   0,
                                   0.40388040954914933,
                                   -0.099107607152821589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0098217849657326745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3058287602140613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58427915061766222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73948735731180926,
                                   0,
                                   0,
                                   0.20641888432501423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22965956305680713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35240763010183945,
                                   0,
                                   0,
                                   0.34697213323169429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44078796970634782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47657636344394122,
                                   0,
                                   0,
                                   0.28218945470065188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079537175246979355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21775460874832639,
                                   -1.100768425458061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38643817351124365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85380925509329575,
                                   0,
                                   0,
                                   0,
                                   0.10887037807031628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4602981444971207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52680166422518915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32764979553102108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12421504787226603,
                                   0,
                                   0,
                                   0,
                                   0.030834969143980026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17915221484594523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26142858075029518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048975720589744504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36626133953714513,
                                   0,
                                   -0.30591397851438701,
                                   0,
                                   0,
                                   -0.65352538812800243,
                                   0,
                                   -0.25309606771201737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23090248345613854,
                                   0,
                                   -0.035023671258965938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.001176989749714462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14063991165873771,
                                   0,
                                   0,
                                   0,
                                   -0.091705623068161379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22228301346710627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13732955596813898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95054719168645663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51309437581862849,
                                   0,
                                   0,
                                   0.21582168274130589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15312905551548767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70059239173007948,
                                   0.50716353382781165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3718984044293997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47619040354157283,
                                   0,
                                   0,
                                   0,
                                   -0.82076196559673398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46476167987218703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45577507218913227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23629272767972187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62542986646458865,
                                   -0.12573672469751529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85734334165652071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091771757317721109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69289530368076258,
                                   0,
                                   0,
                                   0.34183844793630913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28861248486107505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54817659424107301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0040568194804660694,
                                   0.72530634420168194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54343043608782571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75975285341288956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23693482751858991,
                                   0,
                                   0,
                                   -0.3364376457027074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14345054285557657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029607334175517044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19695383854666593,
                                   0,
                                   0,
                                   0,
                                   0.53998923434761747,
                                   -0.28362168761561318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67964323804483107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32097125763584267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34836327236485254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26887980563731534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3197812001837802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1626038430503933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37519871856764814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88717953617466461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097284560670673564,
                                   0,
                                   0,
                                   0,
                                   -0.4394996188253642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19640867446027835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41428011754694483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10510639591288677,
                                   0.4642857923249934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59600691258734784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07306520951159641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1841193512594565,
                                   0,
                                   0,
                                   0.0028495455849475992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39360466457495685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49694834014905687,
                                   0.025161313631038185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77328100538997835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15232901340562993,
                                   0,
                                   0,
                                   0,
                                   0.77529308998838253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51871598521056161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31917287735299416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54482750185136286,
                                   0,
                                   0,
                                   0.26452659369516757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3629042351431393,
                                   0,
                                   0,
                                   0,
                                   0.41826090224167378,
                                   -0.66569766117490825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3537231380623358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067883658370561026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54319693401804314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35356379863294102,
                                   0,
                                   0,
                                   0.07558512692326104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028753780426694141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57192070228397374,
                                   0,
                                   0,
                                   0.43653236722114963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57261840674451059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17426914538150412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47694798342377992,
                                   -0.5501874244661451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25004026073160018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76800154235966922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11839061082639719,
                                   0,
                                   0,
                                   0.090543702124947514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78535253075464417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11158659603204006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094724500301573533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46407610420844053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39820222222946666,
                                   0,
                                   0,
                                   0,
                                   0.018921249103150128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10433411909542115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047223775847758914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40420674816334329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65114024611655319,
                                   0,
                                   -0.061673640146823985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25369565409659822,
                                   0,
                                   0.13630624390561707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042124281390306099,
                                   0,
                                   -0.1026729731650422,
                                   -0.24277313643900758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37046403916361309,
                                   0,
                                   0,
                                   0.021594061515369481,
                                   -0.27823597208515644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4913578718296755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20721936963389231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12867287936375021,
                                   0,
                                   -0.57006811294076887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054212925946576423,
                                   0.042815169544698869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0023897066505116672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91704043600041252,
                                   0,
                                   0,
                                   0,
                                   -0.22175266888267653,
                                   0.32904928165003161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031264829112373625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18102054060510431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54216284561695971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79690326438089798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36931127410787051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090129198504128399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29864837707523456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051070410336741957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21977947237845696,
                                   0,
                                   0.25420116376779567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01772466241748874,
                                   0,
                                   -0.24011027744050092,
                                   0.25700934251098723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36923275976839987,
                                   0,
                                   0,
                                   -0.36823949915218018,
                                   -0.038410339677430239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21574937173622033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38451604836114589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14942725942443327,
                                   0,
                                   -0.31488696057996846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41575640395040314,
                                   -0.030220073389842381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21226019608260543,
                                   0,
                                   0.0066266977046264136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39073756306004315,
                                   0,
                                   0.21595781189353436,
                                   0.05480689090528193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010235052706958125,
                                   0,
                                   0,
                                   -0.14006914690710665,
                                   -0.39100979127736046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051713883132667213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32090627790136439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47441698521249637,
                                   0,
                                   0.021229478058073604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28533516001483972,
                                   0.4091185853824113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29345760916319952,
                                   0,
                                   0,
                                   -0.20689985948011336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0334135666672966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12051918757186778,
                                   0.46454021012751645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42206467145278165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65165226747376248,
                                   0,
                                   0,
                                   0,
                                   0.098316013710330594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57335029029148665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28865899711067322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.107038070792699,
                                   0,
                                   0,
                                   -0.75097841231291562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62994291039766903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32392542835332866,
                                   -0.03470028253122287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29951772923203579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91909597270109633,
                                   0,
                                   0,
                                   0,
                                   -0.051601060677299207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19152186962489112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24265575935030759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44096499964814106,
                                   0,
                                   0,
                                   0,
                                   -0.36531551831448472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59011566964704065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47050712215965457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098586951305750598,
                                   -0.0017995644151972221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22420715828347801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20612983862750206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74616018664916062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39615386227253818,
                                   0,
                                   0,
                                   0,
                                   -0.36193646386299072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022599095034084367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39167665398615187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037252771956558614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43524638192503001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30798299833961995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2002545193102345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14219538214145183,
                                   0,
                                   0,
                                   0,
                                   0.33699397446632007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097062466603973871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46986026583451213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39282739719246307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2202043933318088,
                                   0,
                                   0.32989027124305159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29492596095326329,
                                   0,
                                   0,
                                   0.2607083843324699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33561192929408723,
                                   0,
                                   0,
                                   0,
                                   0.75704104608043776,
                                   0.10682389027809962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57741342993838962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82610343865556768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3262960857445501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48616461174339204,
                                   0,
                                   0,
                                   0.046934597920065498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04303028451774378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16693901402692296,
                                   0,
                                   0,
                                   0.12965618098245549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063248258686532555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54248289227498714,
                                   0,
                                   0,
                                   1.2268809793219024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01995528162957819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12167285179048896,
                                   0.40780949527702764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47340276666808784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60954582085466047,
                                   0,
                                   0,
                                   0,
                                   -0.065076292200414859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65124548587138609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41442166635558542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33116688293882535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36956888433065921,
                                   0,
                                   0,
                                   0,
                                   0.17339801318985201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75509894138510569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35878523583243194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15741412791977558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49947469439398628,
                                   0,
                                   0,
                                   0.030843365374722959,
                                   0,
                                   0,
                                   -0.092391016754852825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31769378934113884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.6340354587561547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65435955482846975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46496102108036519,
                                   0,
                                   0,
                                   0,
                                   0.22091537744393999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29943032529665076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34514523928919444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046795246834836934,
                                   0.52413357543140726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48521679972929016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11782506614924518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010046474295547076,
                                   0,
                                   0,
                                   0,
                                   0.1117470087391034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36078384359193194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63486842778116404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46021739285447416,
                                   0.48768815915503139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052751141531131383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042027369691274921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39462299625435737,
                                   0,
                                   0,
                                   0.68912037158861605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088300160794304722,
                                   0,
                                   0,
                                   0,
                                   -0.44809668098982747,
                                   -0.42781962773982535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038139833642423265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74601962964007795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31680261182737285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066590714296539483,
                                   0,
                                   0,
                                   -0.22394093633808512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28399636765480907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37851697186485139,
                                   0,
                                   0,
                                   -0.021912918714077967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34791806391388397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37030661185792907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029034434856795115,
                                   0,
                                   0,
                                   0,
                                   0.22771878952418154,
                                   -0.20415617569806921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50656365114423474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68775358378444651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31550003460907006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028733064942616217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83136732291624582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42916061024659541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66116035443342402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40380273193873117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21877254897404885,
                                   0,
                                   0.4395895162129092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065919557925580186,
                                   0,
                                   -0.17292532006243783,
                                   0.3651988186322222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3374903963038911,
                                   0,
                                   0,
                                   -0.26979315964190681,
                                   -0.0068758358387950649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072063970396536212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39919916471054223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042624603790183166,
                                   0,
                                   -0.15503641116568531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45831021447116821,
                                   -0.063960272987206662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14738269903268836,
                                   0,
                                   0,
                                   0.040591495191171945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15162783989449546,
                                   0,
                                   0,
                                   0,
                                   0.22795964470212857,
                                   -0.30964012170965166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052981441500152521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18476609514812389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42270677180872823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33813585462991869,
                                   0,
                                   0,
                                   -0.46855256973606058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3001362640191324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78702398515415029,
                                   0,
                                   0,
                                   -0.53809328511461862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34438884750855903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022358369758450871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62648499597546614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29007806975511097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075237355881514936,
                                   0,
                                   0,
                                   0,
                                   -0.41823968202699169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075371726732974847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17309191260485834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48751947968104037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041717255750262666,
                                   0,
                                   -0.25928554785932356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27683780481259185,
                                   0,
                                   0.028378874547003635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42838620312336362,
                                   0,
                                   0.41552616383154162,
                                   0.10438485036910894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18427520404533806,
                                   0,
                                   0,
                                   -0.0021425161458359064,
                                   -0.54941994596153554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30363578835402111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18020057731250488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035125580790834735,
                                   0,
                                   0.063010192324275044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14259809348847835,
                                   -0.26353951350854171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12085127147948879,
                                   0,
                                   0.42045288903978545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2576393380465507,
                                   0,
                                   -0.31073202363012509,
                                   -0.10756244166573786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040943707065316026,
                                   0,
                                   0,
                                   0.41977146749907107,
                                   -0.41055389902030698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27810612377456545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055938771340287172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15943877615290869,
                                   0,
                                   0.21485264441766486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.179119118897868,
                                   -0.32176864545817241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14472915558265265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84709601648754407,
                                   0.63538152297222283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40567966292957069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28736807053811958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11572284648363666,
                                   0,
                                   0,
                                   -0.83751192697414023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10596281911592148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72643049012864935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051505456988413093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26296444510958789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03041293578005241,
                                   0,
                                   0,
                                   0,
                                   0.21295893161832563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055035884702620747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43344729923216674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026657674490965746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39409323210278402,
                                   0,
                                   -0.085402349418185947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51748597581995526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51832935312090211,
                                   0,
                                   0,
                                   0,
                                   0.21247901710971295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55019931435321523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31023573858421916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13939194668768626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10051532556621248,
                                   0,
                                   0,
                                   0,
                                   -0.54070737399802293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12093243102368198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15454780755131084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67496848389687236,
                                   -0.25896881525769028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36899457872132368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014772497504638549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.207890373655713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21252325891216317,
                                   0,
                                   0,
                                   0,
                                   0.084756232832325598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12714769370318357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12591723909998609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17573856117663061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47307894249502491,
                                   0,
                                   0.12888225806184739,
                                   0,
                                   0,
                                   0.17869714654308153,
                                   0,
                                   0.20005753877749666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16083114105292023,
                                   0,
                                   -0.70942895468511646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19682342801393538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38779039811134908,
                                   -0.34800952105427313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81095188135541363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51936759665886534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0474237916541806,
                                   0,
                                   0,
                                   -0.22799973228180145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051463375537242131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068383019744042234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15007698461993382,
                                   0,
                                   0,
                                   0,
                                   0.30326336784913976,
                                   -0.18909155146894269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29254314950794824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97041191184422426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30490371281806733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28976652193177205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40751250833208219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69106182099122648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025458708509265026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27770685484143787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060880586676885499,
                                   0,
                                   0.074844960778295416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28239690551342156,
                                   0,
                                   0.31903013647325501,
                                   0.45529482389394743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10270927980470987,
                                   0,
                                   0,
                                   0.57947692445038268,
                                   0.037054940571433173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0075136467855907978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055412493218474482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39152859398471651,
                                   0,
                                   -0.22286035872761978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016080117911637992,
                                   0.21864914701821597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57424809491583351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25185475670618623,
                                   0.42948853743102033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56015647935533974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011632991501556078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0069387888546560555,
                                   0,
                                   0,
                                   0.80316061171396669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070197582172628836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18060768266996852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088218414208079091,
                                   0,
                                   0,
                                   0,
                                   -0.10658838020583825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58442500202306702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12453396506177433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13385709160870757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36045327977263619,
                                   0,
                                   -0.061634327694924704,
                                   0,
                                   0,
                                   -0.45290362605014917,
                                   0,
                                   0.40566278516760251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26241136480269928,
                                   0,
                                   -0.031451705144556752,
                                   0,
                                   0.18906994249656336,
                                   0,
                                   0,
                                   0.4640423002180929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011424753502955572,
                                   0,
                                   0,
                                   0,
                                   -0.79533528459139691,
                                   0.15414702608963549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75316196002259916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20198872104229607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68484264016539442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072053229562607304,
                                   0,
                                   0,
                                   -0.41233102019853168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1451183084333928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74722380968421065,
                                   0,
                                   0,
                                   -0.13395293478416903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0089390372718991095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037888896592385202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18641441652631588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10638059323526419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18276173739025386,
                                   0,
                                   0,
                                   0,
                                   0.046210847624993362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68764630362483292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15465401047212385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20665376092203333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032474680802382971,
                                   0,
                                   -0.61353425941548567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40028360880376562,
                                   0,
                                   0,
                                   0.45465596480168796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56002112177811381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41369312709186945,
                                   -0.50232490362423277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48865566366935487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61190383242343149,
                                   0,
                                   0,
                                   0,
                                   -0.31739451043639305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051252566676218594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090828456488587755,
                                   0,
                                   0,
                                   0,
                                   -0.097786331347499922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29558144625047822,
                                   0,
                                   0,
                                   0,
                                   0.017888674179859163,
                                   0.22085305840928013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8035004060043125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53679704871368128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19393273754123025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8815675351195511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086904438862886318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20729746490831077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41303480714496588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32386863556413836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14125982130748244,
                                   0,
                                   0.24710474768238722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26407400175449036,
                                   0,
                                   -0.16564289372997026,
                                   0.15068699119088078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095462519193291559,
                                   0,
                                   0,
                                   0.35274075866859755,
                                   0.39244933192720488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33567859225954494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067376775264970226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60425783849806847,
                                   0,
                                   -0.10412375725913164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095272258992646727,
                                   0.096354731995396181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28402489391890656,
                                   0,
                                   0,
                                   0,
                                   -0.34954634479569402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50975876885213733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035713992149056614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34451550622399124,
                                   -0.016287124816267609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35755838773177728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53778575261580941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3769997318884763,
                                   0,
                                   0,
                                   0.077925909304204843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022569964118188346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67766763879539016,
                                   0.35096851141806051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24368448979396595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25266055285807215,
                                   0,
                                   0,
                                   0,
                                   -0.00072180733387146312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62368679770138646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82643691271716013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16825401735396592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15763437328787533,
                                   0,
                                   0,
                                   0,
                                   0.7510947355683314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27676455432039337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55219945046281715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034290473667253983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23407952057379416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18825003922544425,
                                   0,
                                   0,
                                   0,
                                   -0.48417284835886132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41936118730432631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21801941238958017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25905506756120933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35839085999491949,
                                   0,
                                   -0.37849151288630578,
                                   0,
                                   0,
                                   0.00063650716604372881,
                                   0,
                                   -0.048771808105792541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21319912773238567,
                                   0,
                                   -0.25555187289178832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51540091007680144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17752949161539572,
                                   -0.61539183876756831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15407229903127592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0065923350639449513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2610356008658925,
                                   0,
                                   0,
                                   -0.46399356974893802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63366811060481232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17488516468493215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081451346211645098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55413165844180523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63446055145064018,
                                   0,
                                   0,
                                   0,
                                   -0.32351311594861948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30136863881214293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099493017659872535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11399887774135316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07149683224198651,
                                   0,
                                   -0.17230373408215865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52014797342059405,
                                   0,
                                   0,
                                   -0.14388138320410201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76460238418397874,
                                   0,
                                   0,
                                   0,
                                   0.18393797599607015,
                                   0.27813140000343756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62606857282750195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10955615621691414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58064563220725285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096110125656493905,
                                   0,
                                   0,
                                   -0.62611309020129091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23244222636243944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22046918878627439,
                                   0,
                                   0,
                                   -0.20745806851914195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38288430158712511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19357411157828261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62704661584380739,
                                   0,
                                   0,
                                   0,
                                   0.47035579015833739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024232777467748545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54574050586532352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22290605264122465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065615337170415594,
                                   0,
                                   0.47507562399558712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32511179868932882,
                                   0,
                                   0.39042616569912447,
                                   -0.20537597214123901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14113911129642354,
                                   0,
                                   0,
                                   -0.26537248908279848,
                                   0.26470517433426233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20781360454297559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16801636455111177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037775831284682024,
                                   0,
                                   0.25082054894161243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4031461434371264,
                                   0.10486092405124889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24584960213221027,
                                   0,
                                   0,
                                   -0.50705587828203968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49244799386528781,
                                   0,
                                   0,
                                   0,
                                   -0.23510684936634976,
                                   0.65915489635898283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53345809560624935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45659530323897196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20566436153515755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24970889887960368,
                                   0,
                                   0,
                                   -0.28928192308523365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49866462681030749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16409662463363406,
                                   0,
                                   0,
                                   0.26642188489197255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13717633007865454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.007270246352352891,
                                   0,
                                   0.11924051428689977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17686437705417724,
                                   0,
                                   0.11281788821152519,
                                   -0.4410794091121456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57644652028256682,
                                   0,
                                   0,
                                   -0.0086851410418678637,
                                   0.07911683162864315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068598011537355702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34118150738746683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095187311524304527,
                                   0,
                                   -0.44013248922053366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26409455123129438,
                                   -0.1221054723835895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12376760058589389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084972144453266105,
                                   0,
                                   0,
                                   0,
                                   -0.13114898578759049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03951765431259846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3470572192073148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51151358915724876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4254657755731201,
                                   0,
                                   -0.12150345251838006,
                                   0,
                                   0,
                                   -0.062103006522697013,
                                   0,
                                   -0.086011227730981382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59290218406195505,
                                   0,
                                   0.13428633289351388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11308715163332494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54635928100145625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096877953601761921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030833767184760254,
                                   0,
                                   0,
                                   0,
                                   -0.19507883484139465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027161504334731232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38621860430832067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50223528331456435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45780031839827096,
                                   0,
                                   0.16907706035969827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070618804858731843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084964512396660169,
                                   0,
                                   0,
                                   0,
                                   -0.54637464552276527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098852100889933056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18920951335457731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59559744799250913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020255275875396318,
                                   0,
                                   0.19588855697791277,
                                   0,
                                   0,
                                   0.082582834251529819,
                                   0,
                                   0.12184951360965383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42841138832499964,
                                   0,
                                   -0.21207148755035382,
                                   0,
                                   -0.10614019747583181,
                                   0,
                                   0,
                                   -0.47631404470114058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29838021185500824,
                                   0,
                                   0,
                                   0,
                                   0.23991162519146558,
                                   -0.028267926774660911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94042448671574563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5750500175921528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19536980133282406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53443882705868362,
                                   0,
                                   0,
                                   -0.51518667785174577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82951179076902626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22987628701466395,
                                   0,
                                   0,
                                   0.40758873699039083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0018983675460464283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13747793003298248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036811458586621049,
                                   0,
                                   0,
                                   0,
                                   0.50573774435203056,
                                   0.18233001682003769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46423559002772091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66476973938589479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24554840713725939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35661843510246982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033587708178973025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52023059483274381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13478467236539762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51481754980998351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.176303172677654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017316828022997444,
                                   0,
                                   0,
                                   0,
                                   -0.037274021668671449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034142754073249862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58517537096622063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085734044875033485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043988616043574194,
                                   0,
                                   0.6556372364021138,
                                   0,
                                   0,
                                   -0.37883792342387934,
                                   0,
                                   -0.12955120568428541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10673739813259436,
                                   0,
                                   -0.11310151993208913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098994213051656565,
                                   0,
                                   0,
                                   0.50265817488783504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22878193187612006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55654811323839093,
                                   0.22183438054223403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75128104967757292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026018930368759241,
                                   0,
                                   0,
                                   0,
                                   -0.19336172709129154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66356845903671535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053062974917022721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091278626254433878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04077927788804285,
                                   0,
                                   0,
                                   0,
                                   -0.21171082458735144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099398457995707998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57057731714959814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083381931035817786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093849497770214091,
                                   0,
                                   0.46826183273715327,
                                   0,
                                   0,
                                   0.0033308343088521847,
                                   0,
                                   -0.38894363435375656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45942713820007997,
                                   0,
                                   0.11114990872448212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35478108108370171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27079288589186468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11126791059634616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30370880342151368,
                                   0,
                                   0,
                                   0,
                                   -0.18406550667372101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43680596364022839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50289891677637877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044726816358280533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1266542037204238,
                                   0,
                                   -0.44783183865827614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057351177958930896,
                                   0,
                                   0,
                                   -1.1942673479154453,
                                   0,
                                   0,
                                   -0.41173203036374961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51975003181813773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19472286481112913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65016421176332284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070491318486659099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28658063535906464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.472153190773616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44313727061126085,
                                   0,
                                   0,
                                   0,
                                   0.32311140435126007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017853182425006955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34200098906656512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19563471760732451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37169368137305792,
                                   0,
                                   -0.3090140927525723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48531244790055394,
                                   0,
                                   -0.16583293942168137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071945482535085051,
                                   0,
                                   -0.14868012697988542,
                                   0.3182457928021627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13425106020431346,
                                   0,
                                   0,
                                   -0.19382873166456605,
                                   -0.19307902351774059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046560049745283189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50270492047566873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22715345520225785,
                                   0,
                                   -0.067038256274375568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31333764031432726,
                                   0.3261642852933776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5737141508807525,
                                   0,
                                   -0.14130278417515862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.008853859626887492,
                                   0,
                                   -0.40495487684014375,
                                   -0.31166720361267541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021801429748618484,
                                   0,
                                   0,
                                   0.12999960317660231,
                                   -0.13495082744278344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067372744040690977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2845723034553389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19297967509492608,
                                   0,
                                   0.048251330701399725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16164243401076619,
                                   0.45041900208100971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20657711606271084,
                                   0,
                                   0,
                                   0.44113311283205314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2594555059997623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51536611926136844,
                                   -0.0006556688285725143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55520169038704659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032804634404918639,
                                   0,
                                   0,
                                   0,
                                   0.80590098191127013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0076189590340552393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32826527241617343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12625079256181165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11463119139736941,
                                   0,
                                   0,
                                   0,
                                   -0.21045870924535812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60010240984312935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11542020102836029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064934730593218581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0058072158187543049,
                                   0,
                                   -0.18587809901109004,
                                   0,
                                   0,
                                   0.095519477786868923,
                                   0,
                                   -0.67645649663246532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14620956606271243,
                                   0,
                                   -0.16213365957815756,
                                   -0.030981669959367245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42363003837183388,
                                   0,
                                   0,
                                   0,
                                   0.584166549447522,
                                   0.24646595457544643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13564673801872457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71405894751019339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11237261730757962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60530673079789188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51053026744948071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58272114808676934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53534684733190097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2597726578610125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14837953096693318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90922209523352904,
                                   0,
                                   0,
                                   0,
                                   0.070155994715876649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079015828127285553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088548017367105658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1132877197786574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075207895864740679,
                                   0,
                                   0.068198237570990763,
                                   0,
                                   0,
                                   -0.16000807887352647,
                                   0,
                                   0.0056550231574916121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11721993024255908,
                                   0,
                                   0.26415179151712587,
                                   0.31963937005819165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31643203700807432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20925570876654812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010893227259440717,
                                   0,
                                   -0.053598205855408351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31115973157961263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59246842434697422,
                                   0,
                                   0,
                                   -0.41039408329945393,
                                   0,
                                   0,
                                   0,
                                   -0.33642143952901682,
                                   0,
                                   0,
                                   0,
                                   0.14656110109585968,
                                   0,
                                   0.27091274353959871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16205226114425103,
                                   0,
                                   0,
                                   0,
                                   0.29701940032264162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13557236982965121,
                                   0,
                                   0.14547600395291804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018551180892349112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052770376935935101,
                                   0,
                                   0,
                                   0,
                                   -0.87718460525482367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38589397557983335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21032867424226601,
                                   -0.56495018572128919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19831385032558041,
                                   0,
                                   0,
                                   0,
                                   0.06031443565241891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047475660036205361,
                                   0,
                                   0.15878748475418572,
                                   0,
                                   0,
                                   0,
                                   -0.7088332506713988,
                                   0,
                                   0,
                                   0.65612648582565403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53020340944710342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051936858641931524,
                                   -0.14973601682443827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52060185244030788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5080414916614463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28992524000455566,
                                   0,
                                   0,
                                   0,
                                   0.10592409598623079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20003688432367725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33510666426264485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20104105523981536,
                                   0,
                                   0,
                                   -0.17675783020561181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13914575206476326,
                                   0,
                                   0,
                                   0.47869946116288881,
                                   -0.94186171280500586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8020620654271069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70483883035299244,
                                   0,
                                   0,
                                   0,
                                   -0.027425732706598399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3050927126388952,
                                   0,
                                   0,
                                   0,
                                   -0.49390349182266757,
                                   0,
                                   0,
                                   -0.21378438766329108,
                                   0,
                                   0,
                                   0.19695282622661547,
                                   0,
                                   0.25744659789686958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015723212000973413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11216497882775744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22409257734590424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38691461730897747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19407354159324458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20545402992247944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46859400592223865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19847798240950651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57732332697840971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22350867453650503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012395079826257019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040706739972996772,
                                   0,
                                   0,
                                   0.078625832212353086,
                                   0,
                                   0,
                                   0.053663032460496696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49437582228978932,
                                   0,
                                   0,
                                   0,
                                   -0.33286212392237363,
                                   0,
                                   0.18342919178079267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067709177343301369,
                                   -0.0038459717028785298,
                                   0,
                                   -0.25781527404636706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32643033632687024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15819510251340332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64482334983990919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7162071949568416,
                                   0.62651525986398549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39438089075730004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52857077974659372,
                                   0,
                                   0,
                                   -0.1817417305779967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50299256269476467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1869974162294179,
                                   0,
                                   0,
                                   0,
                                   0.49153132205135452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26272102354263804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078925815382408726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41719822923426109,
                                   0,
                                   0,
                                   -0.21683308679545341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62748973302907807,
                                   0,
                                   0,
                                   -0.19773382518582283,
                                   -0.26842075448270308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71644387316588876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19134762568004526,
                                   0,
                                   0,
                                   0,
                                   0.45871246298087498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12394917801697618,
                                   0,
                                   0,
                                   0,
                                   0.21778859160578656,
                                   0,
                                   0,
                                   0.12486514134216338,
                                   0,
                                   0,
                                   0.34850573093817694,
                                   0,
                                   0.17658240780150361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28568583801716774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22886668418980505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29730661176648188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52913000846273717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20816882642107251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11538224863143391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45821650761068639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36431733712768249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29675779804422386,
                                   -0.50842427790281408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012240954326271355,
                                   0,
                                   0,
                                   0,
                                   0.42164768079019282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066479784398258468,
                                   0,
                                   0.4757088471399018,
                                   0,
                                   0,
                                   0,
                                   -0.36581461689745987,
                                   0,
                                   0,
                                   -0.0043758237712709491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21594150764015374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90046121941163992,
                                   0.33814667621362793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38185703384820674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059063233548304075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19121326174011027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72070416517664504,
                                   0.57183109596846937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050003786530940841,
                                   0,
                                   0,
                                   0,
                                   -0.67808272993062457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060287463567759499,
                                   0,
                                   -0.31236741936329693,
                                   0,
                                   0,
                                   0,
                                   -0.15670974002569804,
                                   0,
                                   0,
                                   0.31265446413735232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3884530278059804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34029685044410107,
                                   0.18709986399693224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39441849299844955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24283275923745978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50345221802700157,
                                   0,
                                   0,
                                   0,
                                   0.36111969836806934,
                                   0,
                                   0,
                                   -0.39060552297546886,
                                   0,
                                   0,
                                   0.083742143807804842,
                                   0,
                                   -0.15175480303820332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16028268879786928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4284379787929472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40073218175792114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0082769736469099197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1434166999735762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073829291087039006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19388125308346435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43300258985250695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26267841676849951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33982210039843019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053784989463423,
                                   0,
                                   -0.19422136728519196,
                                   -0.045723385952119791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042405294167736488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62749234160182454,
                                   0,
                                   0.8172339116363847,
                                   0,
                                   -0.61004047901184699,
                                   0,
                                   0,
                                   0.32511355106754558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36541435024846441,
                                   0,
                                   0,
                                   0,
                                   -0.27676800276421687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37777821127186523,
                                   0,
                                   -0.13828335193601823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54336769641499671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47539330410007286,
                                   0,
                                   0,
                                   0,
                                   0.032971120176510126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1612794475855911,
                                   0,
                                   0,
                                   0,
                                   0.038149277740120308,
                                   0,
                                   0,
                                   -0.13218625919654187,
                                   0,
                                   0,
                                   0.16117516150297331,
                                   0,
                                   -0.22227063364527461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044908926348739373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41837777718664781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52978797842198611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22191861584659181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29659769387989671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40005420470612824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35310789999708508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89592182300273893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29391248161722922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32687303336617535,
                                   0.67764662036939771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29829312799506091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41025142694125472,
                                   0,
                                   0,
                                   0.61364823714729033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19079342200858809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28260690112528708,
                                   0,
                                   0,
                                   0,
                                   0.11589865517907855,
                                   0,
                                   0,
                                   -0.28787962568414011,
                                   0,
                                   0,
                                   -0.21881246610054297,
                                   0,
                                   0.67427330430133781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12819905076492183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31604999045826226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0041958919661015566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23643545130668459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30096193366191804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24182943621240371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0011380261621641088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28392995442946961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1261742014396243,
                                   0,
                                   0,
                                   0,
                                   0.39814189687039192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30913263160355214,
                                   0,
                                   0.086903174586904552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74556898350348866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26145659621107697,
                                   0,
                                   0,
                                   0,
                                   0.13266150641791921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33739914312342678,
                                   0,
                                   0,
                                   0,
                                   -0.32845338591486523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20021361581012342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3534251481264602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4137377795142041,
                                   0,
                                   0,
                                   0.14098759026540442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14589035164658953,
                                   0,
                                   0,
                                   0.92556168299956365,
                                   -0.37928580595056083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42202809010186748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1178038999705842,
                                   0,
                                   0,
                                   0,
                                   0.34145705296188122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2471870096532045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52725891992739449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1566635406945574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24782605857890669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3972741773170092,
                                   0,
                                   0,
                                   -0.3337250762319367,
                                   0,
                                   0,
                                   -0.23269818867859612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28468702901128151,
                                   0,
                                   0,
                                   0,
                                   -0.21932596051666625,
                                   0,
                                   0.24052206011173852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11197011661608131,
                                   -0.13594648136433141,
                                   0,
                                   -0.11273265315995007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14442610946677581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063163302254669429,
                                   0,
                                   0,
                                   -0.9497315220704261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15605247720943893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8612265548211695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3016854156986003,
                                   0.22860749758440724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22526158931856211,
                                   0,
                                   0,
                                   0,
                                   -0.40934754657817246,
                                   0,
                                   0,
                                   -0.047432459529799173,
                                   0,
                                   0,
                                   0.58208975611047375,
                                   0,
                                   0.27334949282883347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17367534505173582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19908002745588546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033932641750068507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30822945817800651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011448275813404803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098860266254203286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43593154707368403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23569857184006004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088191241505253315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27123313327523346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18808071865995607,
                                   0,
                                   0.73713074702855197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23640957045454081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053231172194254078,
                                   0,
                                   0,
                                   -0.46131677999161275,
                                   0,
                                   0,
                                   0,
                                   0.11318028303899041,
                                   0,
                                   0,
                                   0,
                                   0.0043577465749167765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80542484523821545,
                                   0,
                                   0,
                                   0.46685765684681657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19605737223207068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88083992701606573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58660212134166334,
                                   -0.84899010550425114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3147159531530731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34121963884424911,
                                   -0.37969840612722344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069651426244100312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055991021194180479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79521433063683777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2532237616196738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27060002344097767,
                                   0,
                                   0,
                                   0,
                                   -0.40535453106121649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49125769987352874,
                                   0,
                                   -0.64522265046742089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027111349199735651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023356940549476513,
                                   0,
                                   0,
                                   0,
                                   -0.19852982074381542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58749581793205585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0075624909417024988,
                                   -0.22971952551372421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15402247857053741,
                                   0,
                                   0,
                                   0,
                                   -0.019588811132568246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0048018975337544671,
                                   0,
                                   0.19426731539921938,
                                   0,
                                   0,
                                   0,
                                   -0.53404550337148482,
                                   0,
                                   0,
                                   0.55441367214929727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031107557114065529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85758423147429741,
                                   -0.24050106383794589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33525545224503717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54010206454273768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67303646757501689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27673179974769235,
                                   0,
                                   0,
                                   0,
                                   -0.12842485868654016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56884649251011099,
                                   0,
                                   0.1220584472890133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029822430970658561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19023393048900031,
                                   0,
                                   0,
                                   0,
                                   -0.27997420899063852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071537187382444772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10616107133582373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33025760245145497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74068492199287239,
                                   0,
                                   -0.16026518000549123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066828731510810729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14158434635096029,
                                   0,
                                   0,
                                   -0.37995833523392175,
                                   0,
                                   0,
                                   0,
                                   0.059995788673710831,
                                   0,
                                   0,
                                   0,
                                   0.35743958164728895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029204110423246978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0958967006830867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042651234571446123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20169404579600547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027337628136859946,
                                   0,
                                   0,
                                   -0.47815883811582083,
                                   0,
                                   0,
                                   0.56385278877834322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097734652418164675,
                                   0,
                                   0,
                                   0,
                                   0.12069565507368174,
                                   0,
                                   0.21053449622400619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45002882918105286,
                                   -0.21694358537632033,
                                   0,
                                   0.073624911770128199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27691653529267229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31724721196200184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24093504616340738,
                                   0.33207563658450939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31603404142039926,
                                   0,
                                   0,
                                   0,
                                   -0.76974791085770278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042783583927891382,
                                   0,
                                   0.067174289658570349,
                                   0,
                                   0,
                                   0,
                                   0.16470047904599255,
                                   0,
                                   0,
                                   -0.38335118494332454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70504848864517644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31758661068874128,
                                   -0.22895511009540542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82805303134783692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15985381781890798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22255508301387486,
                                   0,
                                   0,
                                   0,
                                   0.052663969196317932,
                                   0,
                                   0,
                                   0.24982263573049621,
                                   0,
                                   0,
                                   0.42480634173529663,
                                   0,
                                   -0.24578497167958879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0041359998982127468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16894655040303866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074581553046195459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47605434182249823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54745711904356487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28921126954643106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017637129374300245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17350536763383539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48559338101855476,
                                   0.15258905772151765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79472373170537691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021239520975193295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28066814601928047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19767837452267076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55128928704243119,
                                   -0.097609344135816845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45585033118460361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62918189637816568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20929982084216542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34820742055379311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26139078485183181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23873875940421863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31619935108984942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39697241737028999,
                                   0,
                                   0,
                                   0.14107427888802876,
                                   0,
                                   0,
                                   0.05680716810949777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14055648596659659,
                                   0,
                                   0,
                                   0,
                                   0.51698674980438186,
                                   0,
                                   -0.30360921695795706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2033646676906935,
                                   0.20194902784939356,
                                   0,
                                   -0.036632182052545689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10019791320436065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27139689251045629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.391392803530068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043663767601923573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24096292427962182,
                                   0,
                                   0.2956541998772248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51741193707700495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27517536897259581,
                                   0,
                                   0,
                                   0.35497898360161745,
                                   0,
                                   0,
                                   0,
                                   -0.27501660432153785,
                                   0,
                                   0,
                                   0,
                                   0.2840660678901093,
                                   0,
                                   0,
                                   0,
                                   0.036457609418629321,
                                   0,
                                   0,
                                   0,
                                   -0.9239491314731676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1357812208475162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78682127810556857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71483657960618696,
                                   0,
                                   0,
                                   -0.61556387721439643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45524887388508184,
                                   0,
                                   0,
                                   -0.13764593204842546,
                                   0.22368405395017776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31819168464405279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075507511672816885,
                                   0,
                                   0,
                                   0,
                                   -0.014858925704410379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099130778413969223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11198971505623458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19071645658748343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049831900708597943,
                                   0,
                                   -0.14454605342675905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1706990853286709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2615719382172515,
                                   0,
                                   0,
                                   -0.21149338336063853,
                                   0,
                                   0,
                                   0,
                                   -0.80733151760196176,
                                   0,
                                   0,
                                   0,
                                   -0.35186667741675176,
                                   0,
                                   0,
                                   0.01664603911856697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37034760309730957,
                                   0.53214270399511532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075283968319842062,
                                   0,
                                   0,
                                   0,
                                   0.12699187741311896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22050937058684192,
                                   0,
                                   -0.622275956483332,
                                   0,
                                   0,
                                   0,
                                   -0.60547122784601148,
                                   0,
                                   0,
                                   0.03793095000683179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63641462980792607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028424237315726936,
                                   0.76659618503810911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11942148370763897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35944254582147311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37467924167755029,
                                   0,
                                   0,
                                   0,
                                   -0.00023158009650400824,
                                   0,
                                   0,
                                   0.45086097685775167,
                                   0,
                                   0,
                                   0.12556494819587399,
                                   0,
                                   0.02780158793798726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37693845287992983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31580987641421776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17636161950195692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049447677328296719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50005463753511914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09802735704837523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32368091554662148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29698892596737902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45586022924456637,
                                   -0.17902222180640309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0611878613260006,
                                   0,
                                   0,
                                   0,
                                   0.18756636656957121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50075657105968807,
                                   0,
                                   0.374353866137211,
                                   0,
                                   0,
                                   0,
                                   0.10047761760072432,
                                   0,
                                   0,
                                   0.24280812104834873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095030335444126965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23448666507113222,
                                   -0.011170045710831744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26643977826609072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06777586478245648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0071912467658357,
                                   0,
                                   0,
                                   -0.36785676524949829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37185303383255924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058271274931726152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32511761852636689,
                                   -1.029936536218045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065317437258593958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18031171598311199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59935131230297256,
                                   -0.58266638412460936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036666840533800427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25332543238812094,
                                   0,
                                   0,
                                   -0.54558188563509358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93511777092410908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0024171189489953053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059307189178287159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43076112935253963,
                                   -0.61021249083175788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63397751012850123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63355007706285604,
                                   0,
                                   0,
                                   1.0152770778939288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4492976417291577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42827533190006717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16870033809212706,
                                   -0.15119597720739256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36293221739516107,
                                   0,
                                   0,
                                   0,
                                   0.39642243293638102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16478897609661805,
                                   0,
                                   -0.54045512421231467,
                                   0,
                                   0,
                                   0,
                                   -0.47202010429981794,
                                   0,
                                   0,
                                   -0.87249207700665699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27339835765115134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49841310694638413,
                                   0.25676509309726547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22592699402483796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075980722047222629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31728642575168248,
                                   0,
                                   0,
                                   0,
                                   0.6559789172514976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39416904023696248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1359475551435065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10008590530578915,
                                   0,
                                   0,
                                   0.19834459250367736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21941816027211453,
                                   0,
                                   0,
                                   0.39994597964953649,
                                   0.68297496677289504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41514362057242343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087585100091221738,
                                   0,
                                   0,
                                   0,
                                   0.38530351755310049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4045255004504627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15710645174637108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.189081515652064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35020363188564835,
                                   0,
                                   0.49242190401222208,
                                   0.02878657824339155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64838972010419837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079515463863677555,
                                   0,
                                   0.51885389234630186,
                                   0,
                                   -0.24110031237069737,
                                   0,
                                   0,
                                   0,
                                   0.20576657703600698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10509035636171998,
                                   0.33633970974918176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048872311087002185,
                                   0,
                                   0,
                                   0,
                                   0.67099663863967995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051953144684731459,
                                   0,
                                   -0.14624528345658744,
                                   0,
                                   0,
                                   0,
                                   0.1491504940859909,
                                   0,
                                   0,
                                   0.45251919855491107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80003896741071279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32363016753984175,
                                   0.41822862507231801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20471273072938453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37588494871678507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0096794395023274,
                                   0,
                                   0,
                                   0,
                                   -0.39415699983970587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84364697706464198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011714848358782486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22422175119970866,
                                   0,
                                   0,
                                   0.18398354585471244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015203062777203869,
                                   0,
                                   0,
                                   -0.36961563528637381,
                                   -0.4570521611430195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49849078976467104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28375108230444968,
                                   0,
                                   0,
                                   0,
                                   0.41899320028564735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16743110460122601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27285660293942787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51382826210572952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53754784483805507,
                                   0,
                                   0.19736031177641594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18097442811088088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1468451787180034,
                                   0,
                                   0,
                                   0.01100474835794055,
                                   0,
                                   0,
                                   0,
                                   0.033140753532092379,
                                   0,
                                   0,
                                   0,
                                   -0.5000531713501809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14579936996309226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29588495931717457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0154633775743271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20161100911377908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42045075065406107,
                                   0,
                                   0,
                                   0.32562772188128419,
                                   0,
                                   0,
                                   0.18085379879340321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4963429473242052,
                                   0,
                                   0,
                                   0,
                                   0.043047925973719744,
                                   0,
                                   0.11063454025453198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0040808669286633344,
                                   0.10618779559671623,
                                   0,
                                   0.50447820276103372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092455236461558329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23159130037198955,
                                   0,
                                   0,
                                   0,
                                   0.086193280359396912,
                                   0,
                                   0,
                                   -0.0098951093421278669,
                                   0,
                                   0,
                                   0.21048109348462513,
                                   0,
                                   0.0782485675179794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73797521540711208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17364196613457211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32425856197248004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28565934216201438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22554822736974126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2735699410801497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034594862675363415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32858671558619762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25738007903268378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32734501031693725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62649134123819428,
                                   0,
                                   -0.11915184508770785,
                                   -0.44866706471209111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21350032151588894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72488059979394104,
                                   0,
                                   -0.10870555061597162,
                                   0,
                                   -0.28024947352129026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49618876916528992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1162697048934121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14722122065976961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14468310153602085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02682316927405836,
                                   0,
                                   0,
                                   0.037206521369374738,
                                   0,
                                   0,
                                   -0.10626877413445472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19744977228347318,
                                   0,
                                   0,
                                   0,
                                   0.36062364382120643,
                                   0,
                                   0.38615079770601102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30984652913786936,
                                   -0.46574780736252425,
                                   0,
                                   0.2137716695728803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086610804042080103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1453254752977606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32020491166484044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31428377423826748,
                                   -0.54852606519622837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29169822129974465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02196465555228409,
                                   0,
                                   0,
                                   -0.55334216554961824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45801314197711995,
                                   0,
                                   0,
                                   0,
                                   -0.29325861012417365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64038520424610468,
                                   0,
                                   0,
                                   0,
                                   0.26042510415374492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16960477869202684,
                                   0,
                                   -0.41084242352386419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15737215846902622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42316579859448089,
                                   0,
                                   0,
                                   0,
                                   -0.18625889405283469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58004850144798314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18930368120497817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17692746989967123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17600554024021353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011578541755948191,
                                   0,
                                   0,
                                   -0.0089698218668104492,
                                   0,
                                   0,
                                   0.33791603119793667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27254306805654632,
                                   0,
                                   0,
                                   0,
                                   -0.25977055387382919,
                                   0,
                                   0.012489572250949366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10833599398901789,
                                   0.50536885867914949,
                                   0,
                                   -0.15321247709188784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13601441064193592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28996706832632119,
                                   0,
                                   0,
                                   0,
                                   -0.42554037706237502,
                                   0,
                                   0,
                                   0.45117205841081581,
                                   0,
                                   0,
                                   -0.39133470787238367,
                                   0,
                                   -0.01142475728824574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17044172064105964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23510725746212283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44233624341723893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0012732017982250814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1692169930307629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26034175982596375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040048511222583121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12002370383602512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10335744552540681,
                                   -0.44099304311134957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020249585748824489,
                                   0,
                                   0,
                                   0,
                                   -0.70296080096566382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89461386947957622,
                                   0,
                                   0.010925726942999519,
                                   0,
                                   0,
                                   0,
                                   0.6349993678082273,
                                   0,
                                   0,
                                   0.52802241854764942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017920641357465059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31654682685693625,
                                   0.56045089677073368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14631075620398271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24592866650076795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16168979496201452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57807603838056443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60131767742217546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6829733915202939,
                                   0,
                                   -0.93575792226670329,
                                   0.1190684472499471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029851235185292382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42859331909293485,
                                   0,
                                   -0.53269462824303782,
                                   0,
                                   -0.58188382759055357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83682721858670495,
                                   0,
                                   0,
                                   0,
                                   -0.32344112682376103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5166646026194176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26940919039976147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060338340486444403,
                                   0,
                                   0,
                                   0.38481025973395039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15971990920077703,
                                   0,
                                   0,
                                   0.30403212955246495,
                                   -0.78686770178840315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66270153077161753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39176807847573403,
                                   0,
                                   0,
                                   0,
                                   -0.41803333927633979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031579772144792947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28097208175696653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40377499402737427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77095373897514996,
                                   0,
                                   0.2742681157641283,
                                   0.39174437614240981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081302490328854421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6028545374154155,
                                   0,
                                   0.64465040606680513,
                                   0,
                                   0.32526969496256869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059345331980462906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6414195588492777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22369171060024198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04878219945413928,
                                   0,
                                   0.83020189637525421,
                                   -0.5876249516994001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19884753601724775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21884325556560155,
                                   0,
                                   -0.14935989238289921,
                                   0,
                                   0.71232850344307241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03586494322726913,
                                   0,
                                   0,
                                   0,
                                   0.3090230130515087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2488576700461132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69141211770408539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1601102212465639,
                                   0,
                                   0,
                                   0.64407356850302322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30253532730946781,
                                   0,
                                   0,
                                   0.53318056453599816,
                                   0.25944715495382537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00083541430649000659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27239185330788102,
                                   0,
                                   0,
                                   0,
                                   0.15674688435104184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77731863548122659,
                                   0,
                                   0,
                                   0,
                                   0.10984743174260678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62065147683849253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29406795323771123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12954681746519742,
                                   0,
                                   0,
                                   0.9350186455883216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097725013046450107,
                                   0,
                                   0,
                                   -0.45433116570022924,
                                   -0.17201294656492569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34636245493078777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018053002397269424,
                                   0,
                                   0,
                                   0,
                                   -0.74539606109650491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094541387315897285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26241849320305033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21418442600975135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13712907936308852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0020813048280034765,
                                   0,
                                   0,
                                   -0.22575477288890405,
                                   0,
                                   0,
                                   -0.1070524344444455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1572373506200814,
                                   0,
                                   0,
                                   0,
                                   -0.31371428483220221,
                                   0,
                                   -0.1458895332298899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46854709015871521,
                                   -0.1449730519981704,
                                   0,
                                   0.065082816396314067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63708398770426133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12838422331513538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35269244053883797,
                                   -0.19286301813467674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090615825496695779,
                                   0,
                                   0,
                                   0,
                                   0.041324274665468112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89772759384911982,
                                   0,
                                   -0.58933826073341222,
                                   0,
                                   0,
                                   0,
                                   0.35023037549921038,
                                   0,
                                   0,
                                   0.07956953587087183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043364024573746385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12675702456704746,
                                   0.25390456632598951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42025667965492258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53417434787805496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5341613048804601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53654344431750944,
                                   0.25684592793494038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53701301374852228,
                                   0,
                                   0,
                                   0,
                                   0.35910920971391003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31953965454746602,
                                   0,
                                   0.52626583372380176,
                                   0,
                                   0,
                                   0,
                                   0.10797577526287391,
                                   0,
                                   0,
                                   -0.076461610340829517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5784906087111007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74303021691265592,
                                   -0.067252810693407938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36504326721161473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31323746958752208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14831931683509791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29107984310645185,
                                   -0.46702145734578754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36855904591283328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65704920912060594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32804790814622969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20612264232989008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21794812081269957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.218452291004987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12299446500542557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29660912511435511,
                                   0,
                                   0,
                                   -0.24472063007898645,
                                   0,
                                   0,
                                   0.052870321818252977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22050344096059696,
                                   0,
                                   0,
                                   0,
                                   0.16130437043748966,
                                   0,
                                   -0.66266743928824534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10462677168606778,
                                   -0.30039188873573036,
                                   0,
                                   -0.23231598771940515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16607477670340182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27933059817029732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44250323162809013,
                                   0,
                                   0,
                                   0,
                                   0.4092321995327084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18509377113473124,
                                   0,
                                   0.10542855408227274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31249173471316233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60949618192832444,
                                   0,
                                   0,
                                   0,
                                   0.21019693054880567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024541440446683417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052051803846891648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030458865158020265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40550945812131911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46490039483322343,
                                   0,
                                   0,
                                   0.061807165837444278,
                                   0,
                                   0,
                                   0.048157151717659774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065427359227058432,
                                   0,
                                   0,
                                   0,
                                   -0.29454623815366504,
                                   0,
                                   -0.34333209302742163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049574445672415077,
                                   -0.068935755390029052,
                                   0,
                                   0.60059506320456046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17947619443513979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096209272532767537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27212162537125306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041683060714788757,
                                   -0.39371048060246983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36895987253276674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1801940765312915,
                                   0,
                                   0,
                                   0.92687521928386651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36664850080931849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45034286807855778,
                                   0,
                                   0,
                                   0,
                                   -0.19204343525452627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83397810400536221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26276553096150435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23721485475436621,
                                   0,
                                   0,
                                   -0.40238916718845591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31195036221515332,
                                   0,
                                   0,
                                   0.78124999347715751,
                                   -0.033086183143931192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56302717608238106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75434732536202054,
                                   0,
                                   0,
                                   0,
                                   0.41432285700491178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24323792808064482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26188605668327952,
                                   0,
                                   0,
                                   0,
                                   -0.51045519905859171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33969814087028971,
                                   0,
                                   0.58399064623014196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1565017822520347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33995228807310168,
                                   0,
                                   0,
                                   0,
                                   -0.12323240484038163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01458625249556611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0276927629398978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081509363228296411,
                                   -0.29496282220748815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9833686242847659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59414987278099274,
                                   0,
                                   0,
                                   0.091198594142898562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040880170529193904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8833341115797082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05018087104939252,
                                   0.010680034162357105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10867319704873216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28462285906679285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3525175580174062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27827379608362124,
                                   0,
                                   0,
                                   -0.59998038882436211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3025477666569509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40985035593597052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061966373163919342,
                                   -0.10860452764148876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39118445770723037,
                                   0,
                                   0,
                                   0,
                                   -0.35846350474285493,
                                   0,
                                   0,
                                   -0.32196210835639177,
                                   0,
                                   0,
                                   -0.15453777587025574,
                                   0,
                                   -0.17595646078138166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30899937190461996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47116453854250162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0004301378722606948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24057797675828266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092419597566737288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41953096147200014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0086165278219673506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097480726371136972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11631476186814148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069402511478702772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50010929291913897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014299891670529169,
                                   0,
                                   0,
                                   -0.35921419221413819,
                                   0,
                                   0,
                                   0.398801806466487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19739441631928925,
                                   0,
                                   0,
                                   0,
                                   -0.026054512089895437,
                                   0,
                                   -0.038336751910083261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34549576128642723,
                                   0.083876438033664374,
                                   0,
                                   0.23952775673130661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45702400719565373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053650115472836636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11051648337694076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37280211614233155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40687416840163504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2249972229601967,
                                   0,
                                   0,
                                   0.41109057310522862,
                                   0,
                                   0,
                                   0.3217293208018866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17791437792598469,
                                   0,
                                   0,
                                   0,
                                   -0.2207910049376999,
                                   0,
                                   -0.090746256794876592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1075999239923234,
                                   -0.45363480007065893,
                                   0,
                                   -0.11882956847614931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19269400904178158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05469768551957907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42037714789960945,
                                   0.2105455617990184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10823842179582613,
                                   0,
                                   0,
                                   0,
                                   -0.38149178182660481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51816944462882197,
                                   0,
                                   0.96931770918644455,
                                   0,
                                   0,
                                   0,
                                   -0.26953486414443084,
                                   0,
                                   0,
                                   -0.49011176489732333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26986259795914219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1516614682723669,
                                   0.28402808002436114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10473354199137069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10644757245771093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24117072307187953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16943531171975426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22401620390319912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29583862953124396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29173721862875812,
                                   0,
                                   0,
                                   -0.22955657795756079,
                                   0,
                                   0,
                                   -0.41196114014605284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29798586105890951,
                                   0,
                                   0,
                                   0,
                                   -0.17698740152146777,
                                   0,
                                   -0.12582200597417231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49067437972977623,
                                   0.022618183082921774,
                                   0,
                                   0.29700513419066921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049694317517521319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60174868325256703,
                                   0,
                                   0,
                                   -0.1457472502431936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11760019716424611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1181937495194155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3866013796259289,
                                   -0.54599911751823027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24680345873645426,
                                   0,
                                   0,
                                   0.72703251654228773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48489761761349842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25218101102081431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73873685917459386,
                                   0.54096419376041249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028537475973644755,
                                   0,
                                   0,
                                   0,
                                   -0.27565055491588175,
                                   0,
                                   0,
                                   -0.33246627617750063,
                                   0,
                                   0,
                                   0.050017279562931442,
                                   0,
                                   -0.44982718176324199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18053474510044276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03489622111266874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28546400991420379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039262683453523808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28625477542717331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54667131398418145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33194761008870499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38731190585347652,
                                   0,
                                   0,
                                   0,
                                   -0.44261303985967754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063408559448806204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014046437641688947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080808676804302537,
                                   0,
                                   0,
                                   0.3872707771869518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.018945246198697,
                                   0,
                                   0,
                                   0.1904654058885159,
                                   0.50175832624948136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26540492868896109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79732569508986917,
                                   0,
                                   0,
                                   0,
                                   0.15418415330496602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59833112951304301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15318386866263428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30968296025137398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25079701350826678,
                                   0,
                                   -0.04494289885214503,
                                   0.7069728764871388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41531812835495358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52524908879806087,
                                   0,
                                   0.13401478776962333,
                                   0,
                                   0.25504824358939038,
                                   0,
                                   0.7225826634653566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18217848395683023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030936547792836125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0098108025282825917,
                                   0,
                                   -0.34903774435790902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48954658614560653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24080505286269555,
                                   0,
                                   0,
                                   0.054512480441929176,
                                   0,
                                   0,
                                   0,
                                   0.049354932720567013,
                                   0,
                                   0,
                                   0,
                                   0.13694587332829614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22564513186991861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027321598120490787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72454333937996229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060511221526434539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25396228166094065,
                                   0,
                                   0,
                                   -0.24700097467756049,
                                   0,
                                   0,
                                   -0.12160260494858405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22039838892274738,
                                   0,
                                   0,
                                   0,
                                   0.26062929075886837,
                                   0,
                                   0.081648796933395176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.163063294752615,
                                   0.28412198156478896,
                                   0,
                                   0.10845486925365432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19280204975593876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56401254764994324,
                                   0,
                                   0,
                                   0,
                                   0.10927393528065009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.542998762992699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.332212097801381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29465573376368953,
                                   0,
                                   0,
                                   -0.47871864644527201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20628293443806933,
                                   0,
                                   0,
                                   0.73680531104088476,
                                   0.69908928955178318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027314159803157489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032978301993884018,
                                   0,
                                   0,
                                   0,
                                   -1.1083818775279028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21790902016773056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74773840755708432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073591162976826413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082182613659837978,
                                   0,
                                   0.032397183195295345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0026664533468166163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27262189843660112,
                                   0,
                                   0,
                                   0.29340378209475165,
                                   0,
                                   0,
                                   0,
                                   -0.24604603599367131,
                                   0,
                                   0,
                                   0,
                                   0.39903567935959178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17174179471675574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50655972351546708,
                                   -0.77768567624354912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090098338299667305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29634472233360659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11475663991974797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57869830145513235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44648899260311325,
                                   -0.21855494930795111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19860658827378846,
                                   0,
                                   0,
                                   0,
                                   -0.33340373282939439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55823010111228655,
                                   0,
                                   -0.19714372658781792,
                                   0,
                                   0,
                                   0,
                                   -0.27762921586809175,
                                   0,
                                   0,
                                   0.031396442936285289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0086946474190594848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10836487932730293,
                                   0.44732487643513519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044913389933223039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65238759863247808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29908646150604151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45559858316496471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36579318717412801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51750069977236257,
                                   0,
                                   -0.027088840025468845,
                                   -0.42506525931548966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66470598628616373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21102228279334523,
                                   0,
                                   0.55014017896540879,
                                   0,
                                   -0.34328953849269733,
                                   0,
                                   -0.20635204099347004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064951298252267836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68130257785115711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11633150755602566,
                                   0,
                                   0.096508519330166909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058621387520634137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41346621539951045,
                                   0,
                                   0,
                                   -0.2416588842686607,
                                   0,
                                   0,
                                   0,
                                   -0.12984209777085834,
                                   0,
                                   0,
                                   0,
                                   0.46532921941549388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69437143625849473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19384699782799181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63481607303797216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20041757232672913,
                                   0,
                                   -0.51530487120533641,
                                   0.049694548377674966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24581432506482961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24040058223833727,
                                   0,
                                   0.27870302619593246,
                                   0,
                                   0.42905504236191783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6361473611991979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84354868794966964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40462579736462223,
                                   0.30143843263958586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71867574235496123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44222929812844169,
                                   0,
                                   0,
                                   -0.073687528070778358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09551430463902183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34564371419586498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0083192531139223581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082686887219561744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14722595085791212,
                                   0,
                                   -0.49914854452398749,
                                   -0.55387366062319965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61800063436196884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055644630698738741,
                                   0,
                                   0.63472814190750249,
                                   0,
                                   0.72317403396253621,
                                   0,
                                   0.33682594384662362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21005178364131341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027015654498819409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21448901841473336,
                                   0,
                                   0.38553039736510092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51973030125100672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.396399455088145,
                                   0,
                                   0,
                                   0.39506726980254714,
                                   0,
                                   0,
                                   0,
                                   -0.24912083578368027,
                                   0,
                                   0,
                                   0,
                                   0.040816752890063972,
                                   -0.27549551353035079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26650149793755007,
                                   0,
                                   0,
                                   0.28103759575035181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0119504648704365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36759489629421183,
                                   0,
                                   0,
                                   0,
                                   0.26574204322072364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57688746643267941,
                                   0.30384046168331952,
                                   -0.17877671375412971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0989904771671207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39004295973248249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45186976852942218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15505523190376355,
                                   0,
                                   0,
                                   0,
                                   -0.063458523907473835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19406366461473182,
                                   0,
                                   0,
                                   -0.57221927316024546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27291207529832034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07410024326122587,
                                   0,
                                   0,
                                   -0.092320283094576822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42470314514739538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.388662024624855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020678750644817195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058683895562915679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018168590329345258,
                                   0.0025102417813476965,
                                   0,
                                   0,
                                   0.42743615492695103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064360588463583862,
                                   -0.054929940978063849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57321990912785126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13029015407407624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12366199842866646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033806086074141553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46595231839056583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33406115323229091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16245933079278319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081493483062019534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018025292168756729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51844106342296581,
                                   0,
                                   0,
                                   0,
                                   -0.23991690123664358,
                                   -0.007411229289119324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22606401078636096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12739807728935648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13748600751930451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058045966618803235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48746352247293173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32196454514921458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39411750314697092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18556508308242325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.564717705429858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053170135981279912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17641155027048272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77607775912050758,
                                   0,
                                   0.39303521213492271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49556648889872906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18444173061734953,
                                   0,
                                   0,
                                   0,
                                   -0.12697743497634228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72729237899436827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089853728058858523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31332471216205882,
                                   -0.011436580958265302,
                                   0,
                                   0,
                                   0,
                                   -0.10317211533088852,
                                   0,
                                   0,
                                   0,
                                   -0.018540940025018545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27372585321534554,
                                   0,
                                   0,
                                   -0.34666453363446265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54477659684778312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065861552744929955,
                                   0,
                                   0,
                                   0.034185983003001109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031225813128363922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44204537156866563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088034504862911145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21295589135457391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31752995139505674,
                                   -0.23391269493166389,
                                   0,
                                   0,
                                   0.29428179352915662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50648846757827637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5004835338522623,
                                   0,
                                   -0.33093397123685625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037425975827050539,
                                   0,
                                   0,
                                   -0.42891008440838119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16342402847123449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28667838724666683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18352185120239461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084592997460885846,
                                   0.21994465480267744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074875580157342497,
                                   0,
                                   0.0045075122808340765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68113956992113833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41225506126043698,
                                   0,
                                   0.025266199835101047,
                                   -0.97860062283519589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89586614882685267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070674720488923079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27610448953429378,
                                   0.38478543240526603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39469558733066029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22294285551369775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21221280138013213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10071023151002165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11558946631395325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089387877836256999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040616000469402572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35050489402724261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18026179276170995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58025232700674179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92880686876902319,
                                   0,
                                   -0.50932313397147511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33633444780877775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79258922222569794,
                                   0,
                                   0.14046952163671386,
                                   0.45679297162362903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10629969956830074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17978148403548555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39486368972619462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81559737248123154,
                                   0,
                                   0,
                                   -0.37089470850444634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13470285756615616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19547876913494439,
                                   0,
                                   0,
                                   0,
                                   0.83496757900709306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29789546542343015,
                                   -0.20369239009555565,
                                   0.19363148115680884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039333381561310006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63321504233578607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15200813921850526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11951593807731625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71415703976333256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10007006695926615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35334918688527484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43694206800306579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29967983475375115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11535383607490894,
                                   0,
                                   0,
                                   0,
                                   0.21631716363300377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58754991446340743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16267518286678001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98683930876469039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21419376162689327,
                                   0,
                                   -0.010122488148255365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13465609673017997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1530112449523271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62492675924708596,
                                   0,
                                   0,
                                   0.26120147951624328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48598286270384317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2521097773067032,
                                   0,
                                   0,
                                   0,
                                   0.18331792312267312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093335853047362319,
                                   -0.87108758609052406,
                                   0.056753294554420061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1581690322344583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082242192310506626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32143848881810355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04708182569798728,
                                   -0.060848075893818757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42110148159472993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39516768114962486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028270555066352329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21255452135403857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29546256397207366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44324981405501718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2602744962371657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51128104590652035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035859003386220195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0203149379354743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3485694532128184,
                                   0,
                                   0,
                                   0,
                                   0.47474897966102547,
                                   0,
                                   0,
                                   -0.25349250568302478,
                                   0,
                                   0,
                                   0,
                                   -0.11524329100797932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35746894310763633,
                                   0,
                                   0,
                                   0.50192673477812078,
                                   0,
                                   0,
                                   0.16789044485216459,
                                   0,
                                   0,
                                   -0.26129034798762929,
                                   -0.13152253545443288,
                                   0,
                                   0,
                                   -0.85464173842090774,
                                   0,
                                   -0.0267460422952574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22674317741261463,
                                   0,
                                   0,
                                   0.06507518237023821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52636892617796771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32461781625308955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31673471025721595,
                                   0,
                                   0.02217499940586037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26327400400279055,
                                   0,
                                   0,
                                   -0.04471796902622302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050892566004533277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54981403322595912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15020759647473828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45081781912579522,
                                   -0.43796485665682455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39458090936457468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6064999131787383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20801009867070147,
                                   0,
                                   0.2511508899216619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14586367293921565,
                                   0.59062896943720256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094540412215205039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037420872997248451,
                                   0,
                                   -0.33194980148239761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40101509757435566,
                                   0,
                                   0,
                                   -0.2257535809782607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.006784329247162213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13133110838974094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22341825906410545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63164356791672116,
                                   -0.44889879447711523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20779246158373249,
                                   0,
                                   0,
                                   0,
                                   -0.23234771658807185,
                                   0,
                                   0,
                                   -0.268722369494239,
                                   0,
                                   0,
                                   0,
                                   -0.041192278576080883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39891006854506017,
                                   0,
                                   0,
                                   0.44975151467077445,
                                   0,
                                   0,
                                   -0.10637555788574439,
                                   0,
                                   0,
                                   0.98240103033793136,
                                   0.49666405665752933,
                                   0,
                                   0,
                                   0.17857607121718047,
                                   0,
                                   -0.60117176177154197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14861815642781495,
                                   0,
                                   0,
                                   -0.096848101901936601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20642956117056024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96775878640974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83028324878869619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2241082512695167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24138942349628001,
                                   0,
                                   0.12617457703895377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6458718821705236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84622984995029893,
                                   0,
                                   0,
                                   0,
                                   0.22733753908965285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21000978570218484,
                                   0,
                                   0,
                                   -0.058380730989376468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12495764870084405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14128125417353377,
                                   0,
                                   0,
                                   -0.076868902890875224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16337295923431613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13170666806970321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049683672106333766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065492270967041896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19759754750136982,
                                   0.18392604654948205,
                                   0,
                                   0,
                                   0.13981406624377307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18217409424969916,
                                   0,
                                   0,
                                   0,
                                   -0.57019335891453016,
                                   0,
                                   0,
                                   0.20254668860239475,
                                   0,
                                   0,
                                   0,
                                   0.18370745597351454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10958202540947712,
                                   0,
                                   0,
                                   -0.16158168678283874,
                                   0,
                                   0,
                                   0.72423433005047555,
                                   0,
                                   0,
                                   0.10792855251362096,
                                   0.2216980045349774,
                                   0,
                                   0,
                                   -0.51179336949299892,
                                   0,
                                   -0.12571231518082637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77535879174711353,
                                   0,
                                   0,
                                   -0.39123518067723462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24097112934982945,
                                   0,
                                   0,
                                   -0.13940959992208285,
                                   0.14072171778269746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082584442710996839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091790373942133546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15128721544572638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18968078358703327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27641106725474479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63663398983836417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45007161800574141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1750934471670792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40567207333640504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084570412493855107,
                                   0,
                                   0,
                                   -0.12786995165577644,
                                   0,
                                   0,
                                   0,
                                   -0.39628063794706886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077782015788689859,
                                   0,
                                   0,
                                   0.17991658199007504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10387658924066259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36693214943224922,
                                   0,
                                   0,
                                   0.26836858003527991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38553344379248844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20588482760842722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29015005421745443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34767050481971762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026897656998747826,
                                   0.39875408769957693,
                                   0,
                                   0,
                                   0.1221676362720228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7004942651027517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079783159215809057,
                                   0,
                                   0.38431221967441304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14089581967615622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57007618945317284,
                                   0,
                                   0,
                                   0,
                                   -1.0514437770784424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36531673755687483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013457362886048124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36623899438291763,
                                   -0.66249201215927855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37793883857211935,
                                   0,
                                   0,
                                   0,
                                   0.011337920506860728,
                                   0,
                                   0,
                                   0.28059923206010473,
                                   0,
                                   0,
                                   0,
                                   0.51030467704690885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20927706364081064,
                                   0,
                                   0,
                                   0.59954849313728698,
                                   0,
                                   0,
                                   -0.11644305181251562,
                                   0,
                                   0,
                                   0.45558182794897756,
                                   -0.66385855364200819,
                                   0,
                                   0,
                                   -0.2413234781016767,
                                   0,
                                   0.77168042432023787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05119820345235096,
                                   0,
                                   0,
                                   -0.27732373750659678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38290760467341217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87275336238632795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32787279711594586,
                                   0,
                                   0.054644215389794498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051068360983606072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93898357281463485,
                                   0,
                                   0,
                                   0,
                                   -0.15024650520604982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066151161841422779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29938850589215571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26401113256889369,
                                   0.039011956975014042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15719531582963342,
                                   0.530030954400323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059884986489211943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082521944791558152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47937305066378399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37414682725917647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21881852566600224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23356743717955547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089813137978442287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16752094033118251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022608461553308201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4184498349944053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14515055430287283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060213063964875913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55355260951327279,
                                   0,
                                   -0.68915681449699906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4087585963615098,
                                   0.1639039564729679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13721871970791283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29316980935410786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44809471449412414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62989622962549729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28087317770395426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46347256726946684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057267347086685037,
                                   0,
                                   0,
                                   0,
                                   -0.026234347405549141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29725916136063757,
                                   0,
                                   0,
                                   0,
                                   0.026790781993180874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65142135597762463,
                                   0,
                                   0,
                                   -0.10040574968598188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13969463153716491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068124211949756264,
                                   0,
                                   0,
                                   0.23058898012269125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17300812732752788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13000263151646516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24799883289727798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056062841131396229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2280904012235539,
                                   0.36357863358327114,
                                   0,
                                   0,
                                   -0.32166404489810563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16276427833295132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2498594845847843,
                                   0,
                                   -0.38099123286752878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69565564202793728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19864231730490606,
                                   0,
                                   0,
                                   0,
                                   -0.11470868396920503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52656617780584292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097193052711293165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62810229719813404,
                                   -0.64785693803714517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2453076413071418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18175523876706476,
                                   0,
                                   -0.19889267343608258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33156731186206712,
                                   0,
                                   0,
                                   0.12472253128530675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34406269366680503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085600721934040058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77508868637653816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11962338712798085,
                                   -0.030975141308549531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34180273585339493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55105139680779425,
                                   0,
                                   0,
                                   0.57346355815056516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013707771771435978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63066430933555473,
                                   0,
                                   0,
                                   0,
                                   -0.27935678373051603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2948311733997363,
                                   -0.4743748485778701,
                                   0.61609810870125647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27987598092814625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36061764481416403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20255079019267472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7433521398002938,
                                   0,
                                   0,
                                   0,
                                   -0.077267292647091187,
                                   0,
                                   0,
                                   -0.25759573141402564,
                                   0,
                                   0,
                                   0,
                                   -0.019372868520015855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35447947158894266,
                                   0,
                                   0,
                                   0.22805527405794401,
                                   0,
                                   0,
                                   0.44943439774033772,
                                   0,
                                   0,
                                   0.44574919866169732,
                                   -0.75302476197691559,
                                   0,
                                   0,
                                   -0.036789136248676427,
                                   0,
                                   -0.10802372273011324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093648892251174468,
                                   0,
                                   0,
                                   0.10430451708393279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.431376168012022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10796777870955737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43298980559111483,
                                   0,
                                   -0.41637616434449504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16160511713305414,
                                   0,
                                   0,
                                   0.29126658112432435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071619219692969957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63987064841858476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058127996591320057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21914337036591541,
                                   0.22488842014856059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11214785125752397,
                                   0,
                                   0,
                                   0,
                                   0.083592091197973006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0036070418896219547,
                                   0,
                                   0,
                                   0.011015471612818614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16250521544582208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34089854803153519,
                                   0,
                                   0,
                                   -0.28936221931098138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28602168566942088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28378089653514615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15674074056948209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27147584930954166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30473267984773483,
                                   0.56506070323278368,
                                   0,
                                   0,
                                   0.28493544600586201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61897673582803658,
                                   0,
                                   0,
                                   0,
                                   -0.38223536197147789,
                                   0,
                                   0,
                                   -0.64602722389354916,
                                   0,
                                   0,
                                   0,
                                   -0.34391751017364675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32127259523720231,
                                   0,
                                   0,
                                   0.560150526708593,
                                   0,
                                   0,
                                   -0.16389925330665611,
                                   0,
                                   0,
                                   -0.25719578178215746,
                                   -0.36179004451930841,
                                   0,
                                   0,
                                   0.084185721153156395,
                                   0,
                                   0.086032235661160056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56101257469309074,
                                   0,
                                   0,
                                   -0.22941117100827008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33182588008519887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47752483017773145,
                                   0,
                                   -0.23306347639764693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07682110874613364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49305472730933458,
                                   0,
                                   -0.031390876987999965,
                                   0.52924473013975259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64928164971594593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87604516905500451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049023093257184493,
                                   0,
                                   0,
                                   0,
                                   0.63447918701427997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37721760045807939,
                                   0,
                                   0,
                                   -0.15403068957558011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2028568574432055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1452132185636261,
                                   0,
                                   0,
                                   0.31743038616102787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24600661340219937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12226513977014263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039818946833568486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11555109967482897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22182407753630995,
                                   0.34940648104764283,
                                   0,
                                   0,
                                   -0.065711938447093693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2706537980278213,
                                   0,
                                   0,
                                   0,
                                   0.016146107318517483,
                                   0,
                                   0,
                                   -0.25168248311998298,
                                   0,
                                   0,
                                   0,
                                   -0.014003597248714333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38667785375454022,
                                   0,
                                   0,
                                   -0.51421965430450478,
                                   0,
                                   0,
                                   -0.36152742405232063,
                                   0,
                                   0,
                                   0.29397177643272954,
                                   -0.38128587355706384,
                                   0,
                                   0,
                                   -0.06785986013076678,
                                   0,
                                   -0.46632741267740607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014087695728988089,
                                   0,
                                   0,
                                   -0.71182350203021072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21179746730144189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38031427558705205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40317547503242385,
                                   0,
                                   0.27710401140561969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23841374111463304,
                                   0,
                                   0,
                                   0.050263069826839896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30232637549365826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13395855327886882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14684009652501559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34531400413030067,
                                   0.55363034610435014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010647433112000941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38158125830370476,
                                   0,
                                   0,
                                   -0.11435518747633239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68786207712699654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1119483003283188,
                                   0,
                                   0,
                                   0,
                                   -0.0907840805070141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13148635954766508,
                                   0.051544462766358906,
                                   -0.40440000530548725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20985487695687433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20845942841294096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061444430701381766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55047125551976883,
                                   0,
                                   0,
                                   0,
                                   0.30412434369444497,
                                   0,
                                   0,
                                   -0.47679143543667885,
                                   0,
                                   0,
                                   0,
                                   -0.78797628046221246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80478293664463985,
                                   0,
                                   0,
                                   -0.17971963665741095,
                                   0,
                                   0,
                                   0.12428114859228405,
                                   0,
                                   0,
                                   0.50799276385987846,
                                   0.022953113253344839,
                                   0,
                                   0,
                                   -0.20877237031868992,
                                   0,
                                   0.25186201479353187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50608553580913174,
                                   0,
                                   0,
                                   -0.12746788800145425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028873381537063703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2638534393187677,
                                   0,
                                   0,
                                   0,
                                   -0.20924219325964663,
                                   0,
                                   0,
                                   -0.23528455315604582,
                                   0,
                                   0,
                                   0,
                                   0.047229422269082895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012869302464795965,
                                   0,
                                   0,
                                   -0.020782347565708962,
                                   0,
                                   0,
                                   -0.68690510183269249,
                                   0,
                                   0,
                                   0.26299721927580089,
                                   -0.14441187782449488,
                                   0,
                                   0,
                                   -0.31928550854198767,
                                   0,
                                   0.42986541660703748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5277848191510085,
                                   0,
                                   0,
                                   1.0582469074970684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37803501421771279,
                                   0,
                                   0,
                                   0.43984156874015512,
                                   -0.3773406501967746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26202347072252269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15147311250145154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1524175523539878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39926339701967128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28675031513003935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074460554286739172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18096525229900895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5019385133040839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11324633578184809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068008168731515786,
                                   0,
                                   -0.1462556618972144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21057789661201914,
                                   0,
                                   0,
                                   -0.55474922380578195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12671711063731278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10461188620342926,
                                   0,
                                   0,
                                   0,
                                   0.39216120344082106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65630823005470307,
                                   -0.4366244834306468,
                                   -0.15842892089603236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36544721194923324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42865254369488703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00092971000473587861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20116293871346894,
                                   0,
                                   0,
                                   0,
                                   -0.087959314289114646,
                                   0,
                                   0,
                                   0.055373709472051502,
                                   0,
                                   0,
                                   0,
                                   0.18845558100135332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91581479495413665,
                                   0,
                                   0,
                                   0.1894733157596763,
                                   0,
                                   0,
                                   -0.36211256491766847,
                                   0,
                                   0,
                                   -0.34791072664145795,
                                   -0.15749482405468698,
                                   0,
                                   0,
                                   0.21877963753538388,
                                   0,
                                   -0.95191945826685376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47512439834570197,
                                   0,
                                   0,
                                   0.22497610307124138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091039551829881743,
                                   0,
                                   0.03026567578038027,
                                   0,
                                   0,
                                   0,
                                   -0.26531907496863161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14386053507503896,
                                   0,
                                   0,
                                   0.31942807254787758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42668909286326534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1508764553531482,
                                   0,
                                   0,
                                   -0.32321247884130283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043978494088205172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46575286557558715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38795396666074489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18977547886220239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045288798990497703,
                                   0.16358906588334696,
                                   0,
                                   0,
                                   0.24994144687619055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44459275714787339,
                                   0,
                                   0,
                                   0,
                                   0.6887860122723638,
                                   0,
                                   0,
                                   -0.40652598369959991,
                                   0,
                                   0,
                                   0,
                                   0.80354796429259112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10274786122263035,
                                   0,
                                   0,
                                   -0.27446094110172903,
                                   0,
                                   0,
                                   0.18578095071205761,
                                   0,
                                   0,
                                   -0.012133351031111409,
                                   -0.18505424546391935,
                                   0,
                                   0,
                                   -0.22425495410324114,
                                   0,
                                   -0.010799106855897175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2553191164557988,
                                   0,
                                   0,
                                   0.40926427567587242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26853128061223158,
                                   0,
                                   0,
                                   0.017659086060585114,
                                   -0.27305308204565754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12894648343202139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43567647856357855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35696030350376962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66058837725867448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19652359116707108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077114630750198823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10397656963111111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31316913843523164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02813243229998634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025409857270362223,
                                   0,
                                   -0.095784916877956441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38850280464747394,
                                   0,
                                   0,
                                   -0.49636047885646783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41991479163969919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072960922986029131,
                                   0,
                                   0,
                                   0,
                                   -0.93569595771967207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17822426147161718,
                                   -0.097226851181321752,
                                   -0.55568680620682531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5684533127540905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10250106724306246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36832415548216163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31346796197014581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28540868059655639,
                                   0,
                                   0,
                                   -0.0072444319024695808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54924505465752627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044717674741655236,
                                   0,
                                   0,
                                   0,
                                   -0.4317456862645051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91263711441409423,
                                   0.36073620714138721,
                                   0.095498996280122816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28439834470732406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48136968181564427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15949983975053567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10621300130337152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17344517213535435,
                                   0,
                                   0,
                                   -0.41845796518105322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37749199990895893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36446146689864961,
                                   0,
                                   0,
                                   0,
                                   -0.41226413413191887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082916747294664139,
                                   -0.11629032370488929,
                                   -0.1041467156611223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62685570736085372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34381779002243396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78368206272923902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63691105349462529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54207733231304067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13247257570623358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8063330263236187,
                                   0,
                                   -0.227036273025739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61121079008350698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093504788160347713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04627394041775533,
                                   0,
                                   -0.48731481627889361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45557271398097537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58642283743593704,
                                   0,
                                   0,
                                   0,
                                   0.38575605369183064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48093413129324436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77722417098410268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2000690819701883,
                                   0.16143226469438587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42931044969206011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10641564576560583,
                                   0,
                                   -0.39037819518679889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0044333439533027902,
                                   0,
                                   0,
                                   -0.068396909654657806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58398115480365786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3454170364594582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2206798000287358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21058928196316629,
                                   0.30640003752373224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11158548409280829,
                                   0,
                                   0,
                                   0,
                                   -0.20543677231142221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079787623063862875,
                                   0,
                                   0,
                                   -0.14092022373369703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19239614804608196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21462212128433295,
                                   0,
                                   0,
                                   -0.1803042341631183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17302150543780459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064014764983559069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43677039271525692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68963621741029479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06607800298905625,
                                   0.31126628833663006,
                                   0,
                                   0,
                                   -0.043329712157245744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25759932501260852,
                                   0,
                                   0.98349613771384337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18545203809809305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38485184367648645,
                                   0,
                                   -0.86585129365839997,
                                   0.1924102085461879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042510497130880218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.532953917055209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050501810442689053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47189313095399532,
                                   0,
                                   -0.69181730057631696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0553176713675152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49381238192976012,
                                   0,
                                   0,
                                   0,
                                   -0.10514454791985903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15416214773992928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29562963459212716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6209143284921862,
                                   -0.47801821949201889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69601147843267752,
                                   0,
                                   0.77990762177519313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53284709022485444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16034936522716203,
                                   0,
                                   0.51585384296195458,
                                   0.5221873107003423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4470244702249665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09836851247051237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0013698130426748056,
                                   0,
                                   -0.44617576822925242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1757327713857571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80661444780342084,
                                   0,
                                   -0.39173572465467965,
                                   -0.51900991410288744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4694910112189728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1223143814195424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62255205847295858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1500739628508346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074571464296726453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016896674475135459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40329886493455702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39636923976610661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40687488352961376,
                                   0,
                                   0,
                                   0,
                                   -0.31425247768657527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21198630789143363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23082145834236936,
                                   0,
                                   0,
                                   -0.29234256450117285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28173417567163456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40779490486444459,
                                   0,
                                   0,
                                   0,
                                   0.053545083616507817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30445014541304238,
                                   0.045106895744846144,
                                   0.77504999211998082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53450831905918161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51675546612294365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62535448842560126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14739660783377889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15066511301961105,
                                   0,
                                   -0.24921486588492284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10550796341330299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16872950558173672,
                                   0,
                                   0,
                                   0,
                                   0.39659090330374797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053946815713748049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11411508418792961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73736145476250481,
                                   -0.81863962631600828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64350659569625057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25420732266865648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63991119235748717,
                                   0,
                                   0.26464985423573673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078849248465349575,
                                   -0.18850680349029755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2473486549973728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028123165699099319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38922526008433095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77631418001663977,
                                   0,
                                   0.85548463363828553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25995389178719319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2028158245606517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45597785171294614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23143495469957392,
                                   0,
                                   0.62077512906892074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.545132896509259,
                                   0.12188587314010352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13466631998971956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42208084548223823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066984757675120965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67981974263886191,
                                   0,
                                   0.72264624702436531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34377717721863199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012014577199664728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23488507550078752,
                                   0,
                                   0,
                                   -0.39869607665394091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1036877719493921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063218178461001806,
                                   0,
                                   0,
                                   0,
                                   -0.40542949713453724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0088014616228783565,
                                   -0.49634162207718358,
                                   0.58673428792793803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21949876411368804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31576572311766593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84988437409356743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3512780560971428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28436463615988183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28012529306328987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073214201865370226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38708558067907178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13156200603926646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72077313839776069,
                                   0,
                                   0,
                                   0,
                                   0.15890958624074764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25015819586743371,
                                   0,
                                   0,
                                   0,
                                   0.43280023503152371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21432165231756617,
                                   0,
                                   0,
                                   0.30587531374598154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16142198825106155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40473108637760152,
                                   0,
                                   0,
                                   -0.37910182525813318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25971114361130199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31123913589097019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064015138914883418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062654003518094331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23536755447840013,
                                   -0.10014073662749831,
                                   0,
                                   0,
                                   0.19814050084140092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42845927396277333,
                                   -0.5681716196229134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10753023666259991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10277032847467268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55272610701604008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19611492336612635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28553000027504416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17369124938812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10692461050277972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02244859683502351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022523035405835067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058067429156616023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50658533047200283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29233270885856377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43023083692063169,
                                   0,
                                   -0.045004797073683697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58773741832518078,
                                   0.35405312113490317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33372672668573095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52013139246005757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046521628877855575,
                                   0,
                                   -0.067523163038549411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40350693560033901,
                                   0.66973750073848581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33602271861865013,
                                   0,
                                   0,
                                   0,
                                   -0.26222057993004788,
                                   0,
                                   0,
                                   0.14776341859716083,
                                   0,
                                   0,
                                   0,
                                   -0.3334466655107719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21949237177602154,
                                   0,
                                   0,
                                   -0.21233399924276858,
                                   0,
                                   0,
                                   0.24299678153319812,
                                   0,
                                   0,
                                   -0.1898977171882498,
                                   -0.32359541991305285,
                                   0,
                                   0,
                                   -0.70623428181075965,
                                   0,
                                   -0.12794301958992738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28643508843758436,
                                   0,
                                   0,
                                   0.031427091375148528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96453058051966789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32875879833586591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06137686938093033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075589016343781207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35946078403446063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011196203962490964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44898823718000713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40478590654356827,
                                   0,
                                   0,
                                   0,
                                   0.62262135807068453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21239332792271748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11286166068239235,
                                   0,
                                   -0.40899045930339606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5463334483521225,
                                   0,
                                   0,
                                   0.53931636363429891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22919341118806966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17338097662128926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2038821382893925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22788324014756786,
                                   0.097192936414604747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72551880839059135,
                                   0,
                                   0,
                                   0,
                                   -0.7366921432366953,
                                   0,
                                   0,
                                   -0.44150475946425294,
                                   0,
                                   0,
                                   0,
                                   0.29250281369236036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32776816779582912,
                                   0,
                                   0,
                                   0.30159646627640652,
                                   0,
                                   0,
                                   0.45649286070977491,
                                   0,
                                   0,
                                   -0.28301786299185228,
                                   0.12794388959656033,
                                   0,
                                   0,
                                   0.64278550036117543,
                                   0,
                                   -0.18060274947195951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49812406466746917,
                                   0,
                                   0,
                                   0.41898563315084064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23695012415748187,
                                   0,
                                   0,
                                   0.50364521176411925,
                                   -0.0094125592918640685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27367591743541964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41347566152947068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0067680263471610151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35108642714415372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2777443411642419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16961002344583445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074582653217968337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23711545976408824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14210114979576585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43496696326539375,
                                   0,
                                   0,
                                   0.070892071943987889,
                                   0,
                                   0,
                                   0,
                                   -0.11971123273769647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26188913822761617,
                                   0,
                                   0,
                                   -0.40594475936760815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.122071542273928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6360502094011995,
                                   0,
                                   0,
                                   -0.1251424124864482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33110217062119923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026629594066198532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27167718694473597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32071877756821443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038611953461191076,
                                   -0.067035361788622308,
                                   0,
                                   0,
                                   -0.13839465038588467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56481014857974288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42415630260716941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13756205709471614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17580987199556738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60395130558492882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19259401857925468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19086101502778607,
                                   0,
                                   0,
                                   0,
                                   -0.11389000750300643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32786662549739376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17101404670394002,
                                   0,
                                   0.36902249300610507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11445139525312724,
                                   0,
                                   0,
                                   0.48130729343094975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59997856864240684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078799131975907141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23098658584694248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23806210178965817,
                                   -0.078181107725223353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27526001457726501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45980602802341702,
                                   0,
                                   0.18504144140633033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51378961193619255,
                                   0,
                                   0,
                                   -0.36463196252127328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04699923053118539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089342887193199272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35286829927011754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23686748985550879,
                                   0.30136431268829272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35237106620530162,
                                   0,
                                   -0.35120253473481056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73807425483800748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03654890434692188,
                                   0,
                                   -0.57120936959050972,
                                   -0.21050356401129333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45426866877388111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15295794139398922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34288756474548182,
                                   0.039733427780651989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13992056914785717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42652132181184066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22664962885003126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073383581220411165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18717087442510758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20060963435935802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37932192742584997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16496977285200948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60899745363996849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073080462687492936,
                                   0,
                                   -0.09623514292502211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1246283375717761,
                                   0,
                                   0,
                                   0.67919290247054731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022379987783381381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41891832002800389,
                                   0,
                                   0,
                                   0,
                                   0.070360778316095871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15970198030757743,
                                   -1.0332506367521268,
                                   -0.43464940774772426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02635301707201243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32390623102220273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010688870568486213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21518514741758629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038233570152846494,
                                   0,
                                   -0.4850364778727605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45161191754139035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35338348841910383,
                                   0,
                                   0,
                                   0,
                                   -1.0470206459913443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10696431192243977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3205923495752363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50372624686477296,
                                   0.29909316883559994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47476578710170858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9844131543359097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14610018756033163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16034064847802826,
                                   0,
                                   -0.10824074647762957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98930979893060256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1695596787245186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12870231932348455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28626207564906608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55393561554014203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15999597486237049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38622936888079989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17117040151551724,
                                   0,
                                   0,
                                   0,
                                   0.60151761613409316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17645369078719741,
                                   0,
                                   0,
                                   0,
                                   0.23861244136823709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11455656375668298,
                                   0,
                                   0,
                                   0.085193912235348779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26181708053581282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12333145391028305,
                                   0,
                                   0,
                                   0.0030712292653669107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44170742072893876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33190575404297828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57536443384076341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27268923092658359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0044579527712294217,
                                   -0.099569437881063511,
                                   0,
                                   0,
                                   0.2952528669261254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12250028584952717,
                                   0,
                                   0,
                                   0,
                                   -0.067559211893999049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30936677224429543,
                                   0,
                                   0,
                                   -0.071009508948554845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043006270035619056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082329562473406032,
                                   0,
                                   0,
                                   0.35986140386338483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19400634630784624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20161030053262624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1332799267953651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11589492005236958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64971186344356746,
                                   0.073669565653337127,
                                   0,
                                   0,
                                   0.45223699444334209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10854592320607095,
                                   0,
                                   0.064680427168390425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48612207054327317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5576793336293584,
                                   0,
                                   0.1550324485298672,
                                   -0.58513548802264415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25510828778467853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55520374642338388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0087343707179903529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31686869312070265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77368147873733151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075917340274754289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16500127137528647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36484520259994929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26224795905543885,
                                   0,
                                   0,
                                   0,
                                   -0.25702146904132284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0489890572126341,
                                   0,
                                   0,
                                   0,
                                   -0.029897829287855001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1420942350278328,
                                   0,
                                   0,
                                   0.30023057564647654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42991063813877012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18560690271791389,
                                   0,
                                   0,
                                   0.498848209422593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17138545342534342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10959363953984827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22252933707022007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17221435297462745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42371178128900527,
                                   -0.15926630901693972,
                                   0,
                                   0,
                                   0.3046246005148317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15795634721256704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50047608949859967,
                                   0,
                                   0.2489403339896491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30701240588230666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25912725353502308,
                                   0,
                                   0,
                                   0,
                                   0.022163236720163959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1691806408346146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67264926517698931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39002731026912341,
                                   0.32241576229066193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72102026106534245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26927993148825058,
                                   0,
                                   0.7703665903402237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54720916078478588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03112881487052141,
                                   0,
                                   0,
                                   0,
                                   -0.15455341758631697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13978026569924856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5453352612518777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50337402531183972,
                                   -0.13612152517789655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25907841300531398,
                                   0.054770070740757237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29235938930008132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41169825072175714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39963944863959439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036125256553729231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075990611829541296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098758931193225777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57776717359842722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28632421432426275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27697248526093404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076513464643813339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31604012541410204,
                                   0,
                                   0,
                                   0,
                                   0.45774983216295956,
                                   0,
                                   0,
                                   0.15123963354301748,
                                   0,
                                   0,
                                   0,
                                   -0.54672300629091741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30874512059963444,
                                   0,
                                   0,
                                   0.13955266828396184,
                                   0,
                                   0,
                                   0.065056709857438833,
                                   0,
                                   0,
                                   0.23043585745012266,
                                   -0.40839946724977894,
                                   0,
                                   0,
                                   0.60714611476511049,
                                   0,
                                   -0.21938634441811383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45564490333740398,
                                   0,
                                   0,
                                   0.43743707716240976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20909539697792132};

const double rot_24_30[9000] = {0.99929033778849663,
                                -0.10731884622174448,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22490831190887589,
                                0.42171048111570641,
                                0,
                                0,
                                -0.48027363454264471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68111940434420071,
                                0,
                                0,
                                0.68210980125329801,
                                0.5715220935598655,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69587556596195221,
                                -0.19246528042585159,
                                0,
                                0,
                                0.25023702796839442,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47211411506575252,
                                0,
                                0,
                                0,
                                0,
                                -0.21281778541855711,
                                -0.11300916609344852,
                                -0.3738207475399748,
                                -0.15225310050041146,
                                0,
                                0,
                                -0.2910629468671031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69199907892078882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30732112266609846,
                                -0.34783318413017439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20695622954988735,
                                0.54808121730803394,
                                -0.23888868303882665,
                                0.037457471109960269,
                                0,
                                0,
                                0.034267942425569173,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0071904717683227842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53831711776821478,
                                -0.55434097739031285,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.079481360175641808,
                                -0.40937794732119343,
                                0.12796920492996594,
                                0.40154507133393635,
                                0,
                                0,
                                -0.15890490998692947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38298905162501856,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23724600446014554,
                                -0.64827524801880565,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59112482840348091,
                                -0.44513459292110402,
                                -0.59409412586302124,
                                -0.20691881500319761,
                                0,
                                0,
                                -0.020277975688969482,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13516892612101705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12964615701175736,
                                0.14551097597080531,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2984371391717312,
                                0.049512924173191405,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40787883489550214,
                                -0.81703373659791079,
                                0.014100285696694019,
                                0.27271900474890215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13743167370508425,
                                0.83443403191542564,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23407431046382093,
                                -0.25270754498412568,
                                -0.012267401384805456,
                                -0.40746779774140757,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50481162675949387,
                                0.076301417013633147,
                                0.27822139382866307,
                                0.48884384659570396,
                                0,
                                0,
                                -0.46663999146606855,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38119044995508322,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.080375478957803337,
                                0.23118954673944531,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10675008640517203,
                                0,
                                0,
                                0,
                                -0.33381858105638434,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79563540753845385,
                                0,
                                0,
                                0,
                                0.26076178085781243,
                                0,
                                -0.19821648387075835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40307638242371541,
                                0,
                                0,
                                -0.80871343003880225,
                                -0.17991749634178295,
                                0,
                                0.23536186273646062,
                                -0.53488373311245041,
                                -0.013019296860160755,
                                -0.67892758545176557,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.413334480136475,
                                -0.63479375728417708,
                                0,
                                0,
                                -0.4475947195321891,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.050919321802641193,
                                0,
                                0,
                                -0.60959648524800891,
                                0.57639856675147472,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.85607354275848779,
                                0.16261965025047248,
                                0,
                                0,
                                -0.15684005595257705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0980388480010876,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.098398011618484882,
                                0,
                                0,
                                0,
                                -0.29660649897730335,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.059219927458474764,
                                0,
                                0,
                                0,
                                0.63252471416967382,
                                0,
                                -1.3561226357977891,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12579226391818293,
                                0,
                                0,
                                -0.003904630268244863,
                                -0.094920573163973954,
                                0,
                                -0.45094119624708329,
                                -0.18395678651863645,
                                0.16839343773099136,
                                0.45749125993548667,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.97008333353994347,
                                -0.76795860175212804,
                                0,
                                0,
                                -0.22037646016124482,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10086553859667885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35438065836302135,
                                0,
                                0,
                                0,
                                -0.10653697656163287,
                                0,
                                -0.6636821810041772,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.023918706754501973,
                                0,
                                0,
                                -0.56588547379596887,
                                1.06629288794726,
                                0,
                                0.57912756959397038,
                                0.49867949507596565,
                                0,
                                0,
                                0.18159598885281847,
                                0.094516506908791348,
                                -0.20047361450460108,
                                0.47127225423132885,
                                0,
                                0,
                                0.73118295692081647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23750004439910613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32338704861972811,
                                0.013724002240085936,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74899777158245318,
                                -0.19169731443423194,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49745967469050878,
                                -0.14920552912682777,
                                -0.15698583026123153,
                                -0.32845320676652212,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42792853012462273,
                                0.36620235758043951,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.020040767181260133,
                                0.14039902762511863,
                                -0.14958237477946082,
                                0.80017785538963015,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.069771909443785821,
                                -0.15309394346775956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31209166748424677,
                                -0.16477495197095035,
                                -0.91998109980755638,
                                -0.027873058906590371,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3782316762885955,
                                -0.32707573149945957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65846420101602865,
                                -0.4466204297743539,
                                0.32598470984993067,
                                0.103205239927842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8756613172606601,
                                0,
                                0,
                                0,
                                -0.57304724316697286,
                                0,
                                -0.59096555560113506,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11096507549088036,
                                0,
                                0,
                                -0.0014591874295590875,
                                -0.15353038483527495,
                                0,
                                0.28547549054423249,
                                -0.36389326765639152,
                                0,
                                0,
                                0.34293387438759187,
                                -0.25638742582280388,
                                0.56115140617676906,
                                -0.44824203721441847,
                                0,
                                0,
                                0.33783959735910246,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31929264391350021,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10334849565935351,
                                -0.27218692757200647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38822201896355202,
                                -0.4905211612239424,
                                -0.037129277916565007,
                                0.3307194022767041,
                                0,
                                0,
                                0.1480848091340827,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22907225268761663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64880991302000324,
                                0.050608667062382165,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72345027872791823,
                                0,
                                0,
                                0,
                                -0.31732148456044351,
                                0,
                                0.074402379062472032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.077034689803947676,
                                0,
                                0,
                                -0.8597013042191638,
                                0.50509501743941809,
                                0,
                                -1.1300032113507026,
                                -0.17236637603858052,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.01830370639412271,
                                0,
                                0,
                                0,
                                0.029050755620434687,
                                0,
                                -0.30682798780112636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.994294684254454,
                                0,
                                0,
                                0.42438515520742026,
                                0.10522586126742484,
                                0,
                                -0.14058173681156419,
                                -0.76208397562329844,
                                -0.031303078725107555,
                                -0.31881074810697363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42598320048629834,
                                -0.46768112167534981,
                                0,
                                0,
                                1.0076629482799442,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.91635172553198663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12931479131057072,
                                0,
                                0,
                                0,
                                -0.27673364854907001,
                                0,
                                -0.14770218820439945,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0942320154216465,
                                0,
                                0,
                                -0.41209518808471718,
                                -0.44937070314729616,
                                0,
                                0.38851756750684135,
                                1.0749804110834218,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70301527883812531,
                                0,
                                0,
                                0,
                                0.58445336503553591,
                                0,
                                0.63362315236527333,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.043367847034905177,
                                0,
                                0,
                                -0.31773159317408078,
                                0.17283706392893441,
                                0,
                                0.46583879073743539,
                                0.20802276006489728,
                                0.13950705434110994,
                                -0.88075758521127034,
                                0,
                                0,
                                -0.060208580747855234,
                                0,
                                0,
                                -0.32874648587127608,
                                0,
                                0,
                                -0.13005290304391692,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19277222238297947,
                                -0.19258856236694397,
                                0.044037382373432833,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.043367658966215611,
                                -0.25540159439109555,
                                0,
                                0,
                                -0.32286228990178922,
                                0,
                                0,
                                0.41257651578190918,
                                0,
                                0,
                                -0.22422534557789875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6739331959723136,
                                -0.016696032148382993,
                                -0.39203075950800687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57134333409164684,
                                -0.39065918027427543,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46530823675859784,
                                0,
                                0,
                                0,
                                0,
                                -0.33093201537211048,
                                0,
                                0,
                                0,
                                0,
                                -0.17665359051985635,
                                0,
                                0,
                                0,
                                0.83484069711454001,
                                0,
                                0.15197947766744513,
                                0,
                                0,
                                0,
                                -0.35766597251768306,
                                0,
                                0,
                                0.56628445311962761,
                                -0.16876531110378934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47752178692213032,
                                0,
                                0,
                                0,
                                0,
                                -0.86180250699560335,
                                0,
                                0,
                                0,
                                0,
                                0.035365009977215617,
                                0,
                                0,
                                0,
                                -0.6409367396637411,
                                0,
                                -0.37415751805143721,
                                0,
                                0,
                                0,
                                0.30199381112679097,
                                -0.22250345432029889,
                                -0.30249022646753776,
                                0,
                                0,
                                -0.05683191065675311,
                                0,
                                0,
                                0.047545291563580228,
                                0,
                                0,
                                0.57383860471529957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23043897903077831,
                                0.61178483943030071,
                                0.31117181397625998,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61769524253473973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64343262455941064,
                                0,
                                0.34445693475632211,
                                0,
                                -0.36245461068353113,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38088005619617132,
                                0,
                                -0.61754191765474109,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47167266299251426,
                                0,
                                0.35736786789509878,
                                0,
                                0,
                                0.20399096852882295,
                                0,
                                0,
                                0,
                                0,
                                0.33097427371633009,
                                0,
                                0.68861680758501687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15640880150928221,
                                0,
                                0,
                                0.49741978973684386,
                                0.026683669070725571,
                                0,
                                0,
                                0.23956968543054732,
                                0,
                                0,
                                -0.25309302939099027,
                                0,
                                0,
                                -0.086034121459290097,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.062428701101118325,
                                0.59946704162849362,
                                -0.50965858386199792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17612288982741608,
                                0,
                                0.008419820025234467,
                                0,
                                0,
                                -0.15369698668292464,
                                0,
                                0,
                                0,
                                0,
                                -0.78955240619900902,
                                0,
                                0.46865119454629289,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31978137267496554,
                                0,
                                0,
                                0,
                                0,
                                -0.1713042002741276,
                                -0.77721426565152851,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51734965915511766,
                                0,
                                0,
                                0,
                                0,
                                0.65204637653660358,
                                0,
                                0,
                                0,
                                0,
                                -0.25016616166989153,
                                0,
                                0,
                                0,
                                0.11455609389733987,
                                0,
                                -1.127105622466829,
                                0,
                                0,
                                0,
                                -0.11119352914560318,
                                0.020548469396401425,
                                -0.080159945136649452,
                                0,
                                0,
                                0.19255549559209231,
                                0,
                                0,
                                0.35155221861393249,
                                0,
                                0,
                                -0.67020188679466053,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.083626938097683734,
                                0.36944997943070795,
                                0.48972261655553118,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35276495729843971,
                                0,
                                0.24668223015418453,
                                0,
                                0,
                                0.25511194531870274,
                                0,
                                0,
                                0,
                                0,
                                -0.12770864024198705,
                                0,
                                0.28299412846072547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80822489694918964,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.065391075753181996,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18971059542512025,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58050685768155585,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76916133555714583,
                                0,
                                -1.1245275997296416,
                                0,
                                0.0031933294522106213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.012155813699506779,
                                0,
                                -0.094955610225563591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64971110413564526,
                                0.1529778890102601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14200722057699844,
                                0,
                                0,
                                0,
                                0,
                                -0.28423771768464923,
                                0,
                                0,
                                0,
                                0,
                                -0.37884800714579803,
                                0,
                                0,
                                0,
                                0.084766775791912552,
                                0,
                                0.28609960513281879,
                                0,
                                0,
                                0,
                                0.92337078955953178,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51331755707104443,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10932080523935378,
                                0,
                                -0.036026703065011628,
                                0,
                                1.0843490737297308,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43831979164866114,
                                0,
                                0.42976085371932249,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16206304700718421,
                                0,
                                -0.077455478232078059,
                                0,
                                0,
                                -0.86761670692663606,
                                0,
                                0,
                                0,
                                0,
                                0.31130513524398368,
                                0,
                                0.29760510072887908,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17174919021427146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29158944821202176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57800098330897831,
                                0,
                                0.53165670585881153,
                                0,
                                -0.50912064985883121,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25621434044124092,
                                0,
                                0.38299066221818817,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75670063365896989,
                                0,
                                -0.057887552264395882,
                                0,
                                0,
                                0.27162594828712572,
                                0,
                                0,
                                0,
                                0,
                                0.39044916185877704,
                                0,
                                0.18874443766140694,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40273752716345607,
                                0,
                                0,
                                0,
                                0,
                                0.83079888456776563,
                                -0.37504536204488953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.094164236689000799,
                                0,
                                0,
                                0,
                                0,
                                0.62654894035087738,
                                0,
                                0,
                                0,
                                0,
                                0.19229141407624495,
                                0,
                                0,
                                0,
                                0.081755269163842556,
                                0,
                                0.43716845593781262,
                                0,
                                0,
                                0,
                                0.52767203356769965,
                                0.51434993610256441,
                                0.20217348219808109,
                                0,
                                0,
                                -0.73260566408062566,
                                0,
                                0,
                                -0.17833876993936484,
                                0,
                                0,
                                -0.01823424847353422,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00077628500287688085,
                                0.073837054376859668,
                                0.34679857177595025,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.010791667196159621,
                                0.11605925541393418,
                                0,
                                0,
                                0.30874326760503834,
                                0,
                                0,
                                -0.5861634021044908,
                                0,
                                0,
                                -0.164218898091956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65661958955087041,
                                -0.10089659615309442,
                                0.28143666233448061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64546745626284363,
                                0.077809137613745499,
                                0,
                                0,
                                -0.40298918732435829,
                                0,
                                0,
                                -0.39548516676836054,
                                0,
                                0,
                                -0.34589842312793656,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11623295182605195,
                                0.27724383380820888,
                                -0.22020158305055623,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10926874015132365,
                                0.11450177614953294,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1595652602054267,
                                0,
                                0,
                                0,
                                0,
                                0.32909361251940694,
                                0,
                                0,
                                0,
                                0,
                                0.18105454740209126,
                                0,
                                0,
                                0,
                                -0.46344567584581753,
                                0,
                                0.74314285236525324,
                                0,
                                0,
                                0,
                                -0.59167514256917264,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.98434779140749573,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27262863115994729,
                                0,
                                -0.12723348881761015,
                                0,
                                0.14958263444342468,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.9112854267768371,
                                0,
                                0.77394328757969977,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.024330865653566291,
                                -0.062274499824526486,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34594234907269139,
                                0,
                                0,
                                0,
                                0,
                                0.12641129505827664,
                                0,
                                0,
                                0,
                                0,
                                -1.4663100319476461,
                                0,
                                0,
                                0,
                                -0.099748822178559904,
                                0,
                                0.37359004590466349,
                                0,
                                0,
                                0,
                                -0.059733390933272207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35140501122611129,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28073433513444312,
                                0,
                                1.2184224383923907,
                                0,
                                0.21478806165680123,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48570778670186454,
                                0,
                                -0.86136853282277548,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15232278681019951,
                                0,
                                0.89555282989764828,
                                0,
                                0,
                                -0.20770991906469896,
                                0,
                                0,
                                0,
                                0,
                                -0.037310802528867738,
                                0,
                                -0.31920841889015311,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16838460834373853,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33413837930640022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.098384814468168491,
                                0,
                                0,
                                0,
                                0.70460696857969207,
                                1.3328498201094177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65474514624084512,
                                0,
                                0,
                                0,
                                0,
                                0.35551175571526239,
                                0,
                                0,
                                0,
                                0,
                                0.040767604134147262,
                                0,
                                0,
                                0,
                                0.19069427750071902,
                                0,
                                -0.22655494956116368,
                                0,
                                0,
                                0,
                                -0.013595771635213805,
                                0.047708964525049635,
                                0,
                                0,
                                0,
                                0.0069488840116279423,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27025135827170099,
                                0,
                                -0.24716792997620007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.060694753849512645,
                                -0.42625868974265929,
                                0,
                                0,
                                -0.85310986534227173,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27408504819673152,
                                0,
                                0,
                                0.52965376521962093,
                                0,
                                0,
                                -0.15639266458394838,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.01639158135730949,
                                0,
                                0,
                                0,
                                0.025856622091837242,
                                0,
                                0,
                                0,
                                0,
                                -0.5700618975578029,
                                0,
                                0,
                                0,
                                -0.7231041507725865,
                                -0.087638896801850746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37885616665195659,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2217848858272606,
                                0,
                                -0.076151015271095412,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5120443813510035,
                                0.16406605930771376,
                                0,
                                0,
                                0.24563503144057225,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45569384305329141,
                                0,
                                0,
                                -0.033220057836471473,
                                0,
                                0,
                                -0.81353114445592389,
                                0,
                                0,
                                0,
                                -0.5819265243721885,
                                0,
                                0,
                                0,
                                0.5270287906936888,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59795255317408624,
                                0,
                                0.2053307986358173,
                                0.2101934381199706,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.069271749019218648,
                                0,
                                0,
                                0,
                                0,
                                0.21637468748552069,
                                0,
                                0,
                                -0.63689741187574866,
                                -0.028737618085576816,
                                -0.31309739908146383,
                                0,
                                0,
                                0.054005352014941138,
                                0,
                                0,
                                0,
                                -0.85311881644192433,
                                0,
                                0,
                                0,
                                0,
                                0.0060138660789313403,
                                0,
                                0,
                                0,
                                0.17085770388440322,
                                -0.38144308986398529,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30748065730972995,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11668578377425279,
                                0,
                                -0.51036477692599136,
                                -0.033595754224730011,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22174840061926171,
                                0,
                                0,
                                0,
                                0,
                                0.48207987457124502,
                                0,
                                0,
                                -0.17858269975639085,
                                0.43287001132599634,
                                0.47322506446179047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28454629517316965,
                                0,
                                0.29008035800918869,
                                -0.091303693120941845,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.050391814829616702,
                                0,
                                0,
                                0,
                                0,
                                0.00088091507229163396,
                                0,
                                0,
                                -0.045679784908671077,
                                0.81036699722470262,
                                -0.40648370627798935,
                                0,
                                -0.51190328702136167,
                                0,
                                -0.72908280892453314,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14765419403149943,
                                -0.17748081140237848,
                                0,
                                0,
                                -0.48374494371692173,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.095340133189571005,
                                0,
                                0,
                                -0.63248910625838839,
                                0,
                                0,
                                -0.67378211862988913,
                                0,
                                0,
                                0,
                                0,
                                0.27787236975964014,
                                0,
                                0.44256501843837642,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29611628963952707,
                                -0.29249726869938197,
                                0,
                                0,
                                -0.58298340101149804,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.91590099080227605,
                                0,
                                0,
                                -1.2350279641447912,
                                0,
                                0,
                                0.29741009605556284,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66024603847292551,
                                0,
                                0,
                                0,
                                -0.26195636976456582,
                                0,
                                0,
                                0,
                                0,
                                -0.022963377048061201,
                                0,
                                0,
                                0,
                                -0.33397885803707505,
                                0.030900787192972221,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61840923025956884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.044948153428966797,
                                0,
                                -1.2567403053747093,
                                0,
                                0,
                                -0.77743621264316498,
                                -0.161661556135442,
                                0,
                                0,
                                -0.3287273193006427,
                                0,
                                0,
                                0,
                                0.2692299620691761,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.032620010493155195,
                                0,
                                -0.20975170099518567,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30714597885876599,
                                1.0124742701727978,
                                0,
                                0,
                                -0.13421371411459548,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.040203958759584157,
                                0,
                                0,
                                0.17922725609760942,
                                0,
                                0,
                                0.03547363229300815,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0410190877612588,
                                0,
                                0.44223580741350954,
                                0,
                                0,
                                -0.13481832176640848,
                                -0.14316495677667729,
                                0,
                                0,
                                -0.22799006295188629,
                                0,
                                0,
                                0,
                                -0.31001539061510186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74892528091512633,
                                0,
                                0,
                                0,
                                -0.29327615642401045,
                                0,
                                0,
                                0,
                                0,
                                -0.0081511257126443276,
                                0,
                                0,
                                0,
                                -0.26578580241494204,
                                0.0023532854448869989,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53139998881373296,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.00064993145921898865,
                                0,
                                0,
                                0,
                                0.041918985359129024,
                                0,
                                0,
                                0,
                                0,
                                -0.81023093785638345,
                                0,
                                0,
                                0,
                                0.51125572235680738,
                                -0.093262055386538284,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26774610917513247,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.014088556215251458,
                                0,
                                -0.080514575097133792,
                                0,
                                0,
                                0.61346069863059682,
                                -0.15773034951622528,
                                0,
                                0,
                                -0.81070621857491454,
                                0,
                                0,
                                0,
                                -0.7311472870312008,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54939194526720847,
                                0,
                                0.169294208889186,
                                0,
                                0,
                                -0.85316041104721685,
                                -0.096910980717478334,
                                0,
                                0,
                                -0.1760390569498087,
                                0,
                                0,
                                0,
                                -0.56630730952281205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62572099590929986,
                                0,
                                0.29329555482195452,
                                0.17653436247009813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34270081157248822,
                                0,
                                0,
                                0,
                                0,
                                0.19317056568406749,
                                0,
                                0,
                                -0.48426810649007906,
                                -0.26199966132140029,
                                0.18267029444348837,
                                0,
                                0.5218845787182862,
                                0,
                                -0.55665364427179975,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75284159268541362,
                                -0.46593884330129132,
                                0,
                                0,
                                0.65470143407822212,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49782805534651164,
                                0,
                                0,
                                0.20318216333177169,
                                0,
                                0,
                                0.023658598698039379,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13525440114076601,
                                0,
                                0.36460410831475931,
                                0,
                                0,
                                0.11734374839001037,
                                -1.2237567067824711,
                                0,
                                0,
                                0.19702564800338518,
                                0,
                                0,
                                0,
                                -0.09949642216132934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00063866302101233535,
                                0,
                                0,
                                0,
                                0.33930881981775973,
                                0,
                                0,
                                0,
                                0,
                                0.13388553384183183,
                                0,
                                0,
                                0,
                                -0.066042775041044749,
                                -0.9149657837241334,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15943571497713946,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15743815426587304,
                                0,
                                -0.42994586467482021,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.058156720167098053,
                                0.017431871530905623,
                                0,
                                0,
                                -0.24735150226958466,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61160513197789435,
                                0,
                                0,
                                -0.078812850862936268,
                                0,
                                0,
                                0.90519702638303934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19389143346718749,
                                0,
                                -0.070608149086234376,
                                -0.57499998847557876,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69400273527932799,
                                0,
                                0,
                                0,
                                0,
                                -0.31259112801698108,
                                0,
                                0,
                                -0.1393033404242861,
                                -0.092205497783494655,
                                -0.13976884559427141,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40762282967877966,
                                0,
                                -0.3238536000921759,
                                0,
                                0,
                                0.12209979756347762,
                                -0.38442260160332592,
                                0,
                                0,
                                0.7865387475491521,
                                0,
                                0,
                                0,
                                -1.3909635507089095,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56391068185396731,
                                0,
                                -0.79158640006588687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.95446321872734063,
                                0.32745229557826883,
                                0,
                                0,
                                0.14965382752550505,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45554512151984139,
                                0,
                                0,
                                0.26612566026791257,
                                0,
                                0,
                                0.18477427140364744,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26926045875027349,
                                0,
                                -0.66826583306814091,
                                0.21008416076776937,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.058716003935159133,
                                0,
                                0,
                                0,
                                0,
                                0.082697190169192081,
                                0,
                                0,
                                -0.059755769957131243,
                                -0.15551523864337641,
                                -0.63146028475935712,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13319935494046772,
                                0,
                                0.27501520621949049,
                                0.052287410232352421,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36587167931072495,
                                0,
                                0,
                                0,
                                0,
                                0.64646645082347831,
                                0,
                                0,
                                0.52792416846500856,
                                -0.15198398053203899,
                                -0.2242912819814889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16883916140561653,
                                0,
                                0.00025101436991354503,
                                -0.73327688067871866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45507849755992724,
                                0,
                                0,
                                0,
                                0,
                                0.40124111837364829,
                                0,
                                0,
                                -0.15552351601895337,
                                -0.17513776368252956,
                                -0.10414709075135938,
                                -0.73526275900684168,
                                0,
                                0,
                                0.22396256972183087,
                                0.54430957292059312,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61158060802189196,
                                0,
                                0,
                                -0.50778759386495276,
                                0,
                                0,
                                0,
                                0,
                                0.29497252576201471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.094276816410081676,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.032462329757455805,
                                0,
                                0,
                                0,
                                -0.10940219543624122,
                                0,
                                1.2959571502123868,
                                0,
                                0,
                                0,
                                0,
                                0.80358653116312451,
                                0,
                                -0.086752930322796379,
                                -0.4775218895991839,
                                0,
                                0,
                                0,
                                0,
                                0.11394792191961002,
                                0,
                                0,
                                0,
                                0,
                                0.39373306154026522,
                                0,
                                0,
                                0,
                                0.09352981701225202,
                                0,
                                0,
                                0,
                                0,
                                0.82554614493887546,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.039709268954304253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38974384129552037,
                                0,
                                0,
                                0,
                                0.034970334394629474,
                                0,
                                0.042839093042121856,
                                0,
                                0,
                                -0.35089544192904504,
                                0.93351834880248874,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6642681053686873,
                                0,
                                0,
                                -0.086369034628069274,
                                0,
                                0,
                                0,
                                0,
                                -0.93795370515098364,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64377256164518115,
                                0,
                                0,
                                -0.93824946344904547,
                                -0.086701842372848309,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.99245353677239301,
                                0,
                                0,
                                0.30132631760786172,
                                0,
                                0,
                                0,
                                0,
                                -0.36807921949490596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64549524579767592,
                                0,
                                0.2353936626111072,
                                0,
                                -0.035676801603739511,
                                0.10655904768922184,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2851626789095556,
                                0,
                                0,
                                0,
                                -0.18288830180497165,
                                0,
                                0,
                                0,
                                0,
                                -0.35199478321010769,
                                0.52595801605347747,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16786827764929513,
                                0,
                                0,
                                0,
                                -0.67659112863407866,
                                0,
                                0,
                                0,
                                0,
                                -0.032443808743707753,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60701328634952023,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.034315706888169359,
                                0,
                                0,
                                0,
                                0.37861509180544362,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25549579331266931,
                                0,
                                0.14814884292428335,
                                0,
                                -0.42450486930773634,
                                0.23318477375741045,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.011838924646659366,
                                0,
                                0,
                                0,
                                0.69058192753751069,
                                0,
                                0,
                                0,
                                0,
                                0.059225512022042778,
                                0.4445706660464317,
                                0,
                                0,
                                0,
                                0,
                                0.63186699588381323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35749013508908539,
                                0,
                                0,
                                0,
                                -1.099012339354221,
                                0,
                                0.24323258027431227,
                                0,
                                0,
                                0,
                                0,
                                0.35437830348588878,
                                0,
                                -0.68948670079510022,
                                0.12057816152993336,
                                0,
                                0,
                                0,
                                0,
                                0.16997486504650522,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2545396357509313,
                                0,
                                -0.08794091611027291,
                                0,
                                0.66204247947889505,
                                -0.23857576269004646,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32811078641742464,
                                0,
                                0,
                                0,
                                0.12291883119268515,
                                0,
                                0,
                                0,
                                0,
                                -0.25858994312113537,
                                0.49256760350142692,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16308541244831787,
                                0,
                                -0.57424851863991666,
                                0,
                                -0.2933128298605171,
                                0.35902782240369757,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59540948090911616,
                                0,
                                0,
                                0,
                                -0.20379627460115723,
                                0,
                                0,
                                0,
                                0,
                                -0.083553610909289588,
                                0.16025547189391995,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28239685311274015,
                                0,
                                0,
                                0,
                                0.094907857508306825,
                                0,
                                0,
                                0,
                                0,
                                -0.013111410989577825,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61686943887771051,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28748334715697788,
                                0,
                                0,
                                0,
                                -0.66925184147911509,
                                0,
                                0,
                                0.68629471629539396,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.039216903148190527,
                                0,
                                0,
                                0,
                                -0.067205572960213081,
                                0,
                                -0.2364957211624529,
                                0,
                                0,
                                0,
                                0,
                                0.59389901439693171,
                                0,
                                0.32118506735781055,
                                -0.22699532579489984,
                                0,
                                0,
                                0,
                                0,
                                -1.0041816234696439,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068010434826273863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19600648452076025,
                                0,
                                -0.39594030134560698,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1840386136054348,
                                0,
                                0,
                                0,
                                0.1183307937440249,
                                0,
                                -0.022255420002545545,
                                0,
                                0,
                                0,
                                0,
                                0.26597116892778216,
                                0,
                                0.85300229005676131,
                                -0.11796215046382882,
                                0,
                                0,
                                0,
                                0,
                                0.74208432831040205,
                                0,
                                0,
                                0.10800119216430529,
                                0,
                                0,
                                1.1242351516056301,
                                -0.22733649929951125,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1692196181838265,
                                0,
                                0,
                                0.62984621110202776,
                                0,
                                0,
                                0,
                                0,
                                -0.48917946540447299,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21331407742103686,
                                0,
                                0.43808808473659777,
                                0,
                                0.2334420877541471,
                                0.72536544106698519,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1437561186615188,
                                0,
                                0,
                                0,
                                -0.09618570084037234,
                                0,
                                0,
                                0,
                                0,
                                -0.31403292954125778,
                                -0.23106603259992928,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3787719317750754,
                                0,
                                0,
                                0,
                                -0.021806718124111418,
                                0,
                                0,
                                0,
                                0,
                                0.2090781820829774,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.097709782134936807,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79277489002152512,
                                0,
                                0,
                                0,
                                -0.41749655896475629,
                                0,
                                -0.28543291996497278,
                                0,
                                0,
                                -0.20701390144090948,
                                0.28120742458264214,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10270431358004814,
                                0,
                                0,
                                1.0401404914061592,
                                0,
                                0,
                                0,
                                0,
                                0.21170794721737426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53782056045328219,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33730868155648897,
                                0,
                                0,
                                0,
                                0.21685367061884431,
                                0,
                                -0.40587103944512765,
                                0,
                                0,
                                0,
                                0,
                                0.5324798629194516,
                                0,
                                -0.035598554976911376,
                                0.52900786663426025,
                                0,
                                0,
                                0,
                                0,
                                0.57874572925449796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13721781183561715,
                                0,
                                0.23343678187781713,
                                0,
                                -0.29016138895178356,
                                -0.41709784543265777,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37853913532343053,
                                0,
                                0,
                                0,
                                0.23167613365079448,
                                0,
                                0,
                                0,
                                0,
                                -0.60408456022675128,
                                -0.32654315625877284,
                                0,
                                0,
                                0,
                                0,
                                0.17552259276730933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00028380052546783663,
                                0,
                                0,
                                0,
                                0.033735845704202669,
                                0,
                                -0.57710361232306284,
                                0,
                                0,
                                0,
                                0,
                                0.19458102247810768,
                                0,
                                -0.7641984222046776,
                                -0.89398624447910524,
                                0,
                                0,
                                0,
                                0,
                                -0.071747574247428725,
                                0,
                                0,
                                0,
                                0.41661163577212246,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55155401318879582,
                                0,
                                0,
                                0,
                                1.0006939776267656,
                                0,
                                0.1091412346640647,
                                0,
                                0,
                                0,
                                0,
                                0.03211345946342313,
                                0,
                                -0.59955647487946495,
                                0.81100016583515799,
                                0,
                                0,
                                0,
                                0,
                                -0.05007944473778736,
                                0,
                                0,
                                0.32901438879777872,
                                0,
                                0,
                                0.75155671695321991,
                                0.75634258768429363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12102577654947053,
                                0,
                                0,
                                -0.30484892746647896,
                                0,
                                0,
                                0,
                                0,
                                1.037178924357741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74801735755614496,
                                0,
                                0,
                                0,
                                0.31075509924259065,
                                0,
                                0,
                                0,
                                0,
                                -0.51314042676961491,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14191776284777113,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24451746965011251,
                                0,
                                0,
                                0,
                                -0.025666303363328619,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41283669404543311,
                                0,
                                -0.40177956035649098,
                                0,
                                0.35742222213841679,
                                0.21924261917893387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18506118054692811,
                                0,
                                0,
                                0,
                                0.59132731068048061,
                                0,
                                0,
                                0,
                                0,
                                -0.10504935564381351,
                                -0.31204179521878628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4380693436765089,
                                0,
                                0.42107726347353613,
                                0,
                                0.16658522177610546,
                                -0.01605294418124889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50810196725751444,
                                0,
                                0,
                                0,
                                0.14287407571788013,
                                0,
                                0,
                                0,
                                0,
                                0.56936090740182876,
                                -0.0053293212292128897,
                                0,
                                0,
                                0,
                                0,
                                -0.74783318184776615,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.04446837126063391,
                                0,
                                0,
                                0,
                                -0.13029217069395324,
                                0,
                                -0.43324568839383809,
                                0,
                                0,
                                0,
                                0,
                                0.63145485642213506,
                                0,
                                -0.6427827554189689,
                                0.25737428680432406,
                                0,
                                0,
                                0,
                                0,
                                -0.49777689745963916,
                                0,
                                0,
                                0,
                                0,
                                0.18452206224544265,
                                0,
                                0,
                                0,
                                -0.65377737182154327,
                                0,
                                0,
                                0,
                                0,
                                -0.10110523697712342,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46876677206943235,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27567131937809985,
                                0,
                                0,
                                0,
                                -0.48225255289168356,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3488492931979878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25929068748808975,
                                0.16438554191740662,
                                0,
                                0,
                                0.56701017738812975,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79572448612535807,
                                0,
                                0.97626744377950259,
                                0.62591585147470241,
                                0,
                                0,
                                0,
                                0.57440958730979541,
                                0,
                                -0.25014117623794241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2405086531418088,
                                0,
                                -0.84147614774317492,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.952835873812935,
                                0,
                                -0.27448495228122272,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71603070960927884,
                                0,
                                -0.29901386162037741,
                                0.58330651008951695,
                                0,
                                0,
                                0,
                                -0.44196101624152867,
                                0,
                                -0.0052083465517536454,
                                -0.20405132191042538,
                                0.098496913996296273,
                                0,
                                0.34571302239671792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56246675611727281,
                                0,
                                -0.15038879482467529,
                                0,
                                0,
                                0,
                                -0.54295636473678688,
                                0,
                                0,
                                0,
                                0.17110283185746006,
                                0,
                                0,
                                -0.63745691758197753,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4986589664642832,
                                0,
                                0.29705304073917604,
                                0.26715878103686019,
                                0,
                                0,
                                0,
                                0.46470457079456329,
                                0,
                                -0.95341498592313767,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80531431429744216,
                                0,
                                0,
                                0.11381365340038757,
                                0,
                                0.65742393228184171,
                                0.41518018294949344,
                                0.27888132587505321,
                                0,
                                0.15922461941601226,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21536174524060023,
                                0,
                                0.26913660490190583,
                                0,
                                0,
                                0,
                                -0.40065343438882595,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.032468446864691053,
                                0,
                                -0.32879626984348698,
                                0.034184250726672152,
                                -0.42364613043341187,
                                0,
                                0.51825969433803176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1179531848505945,
                                0,
                                0.64845884056337311,
                                0,
                                0,
                                0,
                                -0.084789584087400449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36662080933259689,
                                0,
                                0.3672151712297167,
                                -0.5105738838133288,
                                -0.061139341245427865,
                                0,
                                -0.2335360170396899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46178357874236692,
                                0,
                                0.43689520630829726,
                                0,
                                0,
                                0,
                                0.087509566087635299,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13275519264893745,
                                0,
                                0,
                                -0.69619707120294361,
                                0,
                                0,
                                0.52826112696208916,
                                0,
                                0,
                                0,
                                0.2423346061760718,
                                -0.36953327117243956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15279063701685044,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10592683731043145,
                                0,
                                0.29800674798889898,
                                -0.54940824152269685,
                                -0.37506377777046246,
                                0,
                                0.22304276252092403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48225210189450329,
                                0,
                                -0.36339228611156249,
                                0,
                                0,
                                0,
                                -0.20755749261821049,
                                0,
                                0,
                                0,
                                0,
                                -0.25409315608818872,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.082517757178918016,
                                0,
                                0.32960349044571108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.057688749140884836,
                                0,
                                -0.71293172496006985,
                                1.2987393669441296,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63087429945795392,
                                0,
                                0,
                                -0.34532955394466791,
                                0,
                                0,
                                0.1943367112686,
                                0,
                                0,
                                0,
                                -0.061890676890798413,
                                0.66415078554814144,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0071859779364823739,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38164690314422345,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.89543847826841594,
                                0,
                                -0.31774175579933206,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57865877859580939,
                                0,
                                0.68501002454902682,
                                0.55303946628286094,
                                0,
                                -0.82425145254598897,
                                0,
                                0,
                                -0.050541666217431926,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.93716923733655111,
                                0,
                                -0.38720075399582821,
                                0.42084137182048681,
                                0,
                                0,
                                0,
                                0.26438819321495388,
                                0,
                                -0.10721577507137223,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.097967393270758776,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30029701760091593,
                                0,
                                0,
                                -0.34047655261847987,
                                0,
                                0,
                                -0.5510221621029926,
                                0,
                                0,
                                0,
                                -0.41790640624296749,
                                -0.34479273269163452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4435585669474722,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.049762494517418113,
                                0,
                                0,
                                -0.64517553382568882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57050809118422641,
                                0,
                                0.95600345217090066,
                                0.21071255573889552,
                                0,
                                0,
                                0,
                                -0.56724616326503385,
                                0,
                                0.98985187598970059,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26597951898885164,
                                -0.68538635568859141,
                                0,
                                0,
                                0.80618719978180531,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16870921560276989,
                                0,
                                0.49393139747743958,
                                -0.16251795041644446,
                                0,
                                0,
                                0,
                                -0.93802208043998236,
                                0,
                                -0.84271884770500782,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13119019610155785,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.097968162654715293,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.021208091207906773,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62970261957220397,
                                0,
                                0,
                                0.41721506532245228,
                                0,
                                0,
                                0.40543290786867558,
                                0,
                                0,
                                0,
                                -0.071741265023803388,
                                -0.50585330049681887,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.063213816988805266,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.028254645992306829,
                                0,
                                0,
                                0.29437602971576632,
                                0,
                                0,
                                0.046989259291807486,
                                0,
                                0,
                                0,
                                0.46658301882730485,
                                0.14709106340091835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8191464723902715,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1250150157891288,
                                0,
                                0,
                                0.073491849497276218,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42085499867500115,
                                0,
                                0.3225657886963692,
                                -0.87143053394334113,
                                0,
                                0,
                                0,
                                0.75878896128605666,
                                0,
                                0.49527753324073159,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52878480339231315,
                                0,
                                0,
                                0.47518860721202538,
                                0,
                                0.12192929390552085,
                                0.41472989016967055,
                                -0.42403778810093024,
                                0,
                                0.27115095047009241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41674164118031837,
                                0,
                                -0.38979171800367224,
                                0,
                                0,
                                0,
                                0.091575599736853447,
                                0,
                                0,
                                0,
                                -0.031098495824899271,
                                0,
                                0,
                                0.11215807848148771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16111170724832305,
                                0,
                                -0.084135812209022109,
                                1.0398580315447661,
                                0,
                                0,
                                0,
                                -0.026906641000275511,
                                0,
                                0.24536177517076857,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2156787203631343,
                                0,
                                0,
                                0.64737796976220774,
                                0,
                                -0.4462639494582421,
                                -0.14242601514571285,
                                0.45459462784694754,
                                0,
                                0.089863380868930615,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.060489537502631419,
                                0,
                                -0.085199589849909454,
                                0,
                                0,
                                0,
                                -0.36853144335840704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4071605727775181,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46567318903311994,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31124213116467314,
                                0,
                                0,
                                -0.13930971514800722,
                                0,
                                0,
                                -0.46148040911153315,
                                0,
                                0,
                                0,
                                0.73481371504576498,
                                -0.16106993660978419,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32382441347259183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1806614771795475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.019354893059869972,
                                0,
                                1.1072961355972295,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79540769153623436,
                                0,
                                0.72384837523650902,
                                0.024319685544597069,
                                0,
                                0,
                                0,
                                -0.011355682488647711,
                                0,
                                0.14827808401692638,
                                -0.17320147932153174,
                                0.44963578853552705,
                                0,
                                0.63297038288694507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.01392013343021823,
                                0,
                                -0.048186117843817919,
                                0,
                                0,
                                0,
                                0.58527462427884103,
                                0,
                                0,
                                0,
                                0,
                                -0.42849853324901443,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47024792558147283,
                                0,
                                0.54351790377951004,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21944534851336964,
                                0,
                                -0.89201921304488119,
                                -0.49002345031182915,
                                0,
                                0,
                                -1.0447836498674103,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33170685508473735,
                                0,
                                0.79911139123160801,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.97954945666423798,
                                0,
                                0.44595355567585288,
                                0.31823061637614336,
                                0,
                                -0.61138702561827485,
                                0,
                                0,
                                -0.5764564993468676,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.84488683298333933,
                                0,
                                -0.73549672675030564,
                                0.55166884058364896,
                                0,
                                0,
                                0,
                                -0.3901047980301971,
                                0,
                                -0.098804207112330511,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17732339869901059,
                                0.65425743954666638,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61916715498837305,
                                0,
                                -0.27809038808762598,
                                0,
                                -1.2244338493919782,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33014478159689331,
                                0.20777010225745346,
                                0,
                                -0.23428470144167907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.035301788791780385,
                                0,
                                -0.28044168893840382,
                                0,
                                0.51354715626078484,
                                0,
                                0,
                                -0.48421169732685415,
                                -0.39557056160135323,
                                0,
                                -0.16426375367346116,
                                0,
                                0.12939884620191672,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14469482313791684,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44946802595499497,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26658464296517503,
                                0,
                                0,
                                0.45623016248922554,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.033578372324582995,
                                0,
                                0,
                                0,
                                0,
                                0.88539629086429417,
                                0,
                                0,
                                0,
                                0.91966708138964437,
                                0,
                                0,
                                0.39512424598875112,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25740612486410375,
                                0,
                                -0.48334875971957958,
                                0,
                                0,
                                -0.12408931563319606,
                                -0.62734996257096198,
                                0,
                                0.37864616398202328,
                                0,
                                0.12229843999079032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3642135654889791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.012983926956467502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1497322584311539,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.059886375738257995,
                                0,
                                0.0023843558781774798,
                                0,
                                0,
                                -0.015624660757516944,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.9534954511665088,
                                -0.25414657623913972,
                                0,
                                0,
                                0,
                                1.009163680732919,
                                0,
                                0,
                                -0.1271016904618005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73653741736533618,
                                0,
                                0,
                                0,
                                0,
                                -0.55069244995047828,
                                0,
                                0,
                                0,
                                0.56620660606515816,
                                0,
                                0,
                                1.0715665875315661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14555689364201407,
                                0,
                                -0.53912733502605736,
                                0,
                                0,
                                -0.068650410781217835,
                                0.25924714187954406,
                                0,
                                -0.1436060378619087,
                                0,
                                -0.31321364384978384,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.039917767239727397,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70421164355780319,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37439953169325946,
                                0,
                                0.25803446453725837,
                                0,
                                0,
                                -0.026971296682848894,
                                0.1720376951057779,
                                0,
                                0.6720668973525038,
                                0,
                                0.082452522580242382,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37581221340814236,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40399459606928445,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15821278580124953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.077360641297183397,
                                0,
                                -0.52883633968077881,
                                0,
                                0.48246563489985228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58446110740371515,
                                0.1870530728276005,
                                0,
                                0.36524923314188906,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15003302866397616,
                                0,
                                -0.44481236772552496,
                                0,
                                -0.11754346199102736,
                                0,
                                0,
                                -0.52863784857643115,
                                0.034450507520649015,
                                0,
                                0.39816101506609608,
                                0,
                                -0.42786794918126397,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22043945331872744,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34275931965611506,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26688919242520392,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29476405488735341,
                                0,
                                0.21788422863444973,
                                0,
                                -0.57744010326653183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18862455266819958,
                                -0.62422074924456317,
                                0,
                                0.88831292504348058,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26816189374765254,
                                0,
                                -0.69171439744036833,
                                0,
                                -0.12365052480550867,
                                0,
                                0,
                                0.39906997101360814,
                                -0.036506909076404442,
                                0,
                                0.29500282557182933,
                                0,
                                0.49281972226024029,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.077834469292064057,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.098468236299400824,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.037372293435957896,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39447556874079603,
                                0,
                                -0.12079112229080652,
                                0,
                                -0.076404100968123778,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79209941987065058,
                                -0.32826221775892311,
                                0,
                                1.0248931914922008,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15484780183361471,
                                0,
                                0,
                                -0.79194284987410879,
                                0,
                                0,
                                -0.67942412320576673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.91198742979425163,
                                0,
                                0,
                                0,
                                0,
                                0.2585959934427397,
                                0,
                                0,
                                0,
                                -0.095414013194139891,
                                0,
                                0,
                                -0.026703925685778784,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16080117503801877,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76594124855960766,
                                0,
                                0.32862990107547507,
                                0,
                                0,
                                0.52458849507287331,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.056998225580548588,
                                0.032210046543150878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21550922630136723,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40013895943266192,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.064077691352344535,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.091552747100466042,
                                0,
                                -0.72647547331169759,
                                0,
                                0,
                                0.31950828111842805,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16219081361728349,
                                -0.57563367597871418,
                                0,
                                0,
                                -0.13191886116267376,
                                0,
                                0.33624569364634016,
                                0,
                                0,
                                0.48019414879308892,
                                -0.11370285778130174,
                                0,
                                0.26163284937587222,
                                0,
                                -0.60199463164996114,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43451644773100173,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.079797615342831113,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44824126778633933,
                                0,
                                0,
                                -0.19981742935653221,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50083939840694114,
                                0,
                                0,
                                0,
                                0,
                                0.82824431575717949,
                                0,
                                0,
                                0,
                                -0.55588466866357644,
                                0,
                                0,
                                -0.061239455972567108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54544165788081023,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2035268666825798,
                                0,
                                -0.21849740375814594,
                                0,
                                0,
                                0.59844767655067954,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22882992369583688,
                                0.45036245557329208,
                                0,
                                -0.60433578629626261,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4759687320227326,
                                0,
                                -0.22530391784711004,
                                0,
                                -0.27057668265098161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0623394428728299,
                                0.44336697809486486,
                                0,
                                0.3816356155578004,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1231717309218117,
                                0.31058108843237531,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18712806532952231,
                                0,
                                0.40941396482406806,
                                0,
                                -0.17169028962623573,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44727473557999858,
                                0.62961076593619003,
                                0,
                                0.65726835937613315,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.89175299213746984,
                                0,
                                0,
                                -0.066573959927061513,
                                0,
                                0,
                                0.81788755788238998,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61267806232466704,
                                0,
                                0,
                                0,
                                0,
                                -0.28476032885898522,
                                0,
                                0,
                                0,
                                0.054152861802532148,
                                0,
                                0,
                                -0.97696391896399748,
                                0,
                                0,
                                0,
                                0,
                                -1.0978519119982835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67917456472751914,
                                0,
                                0.11402179887300226,
                                0,
                                -0.35949477055514961,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15157539389204497,
                                0.63988474613481694,
                                0,
                                0.17470602993253606,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75638094073716733,
                                0,
                                -0.0018142024810543296,
                                0,
                                0.056887101134225238,
                                0,
                                0,
                                -0.27458934233671328,
                                0.5811213078180868,
                                0,
                                0.20817608944598132,
                                0,
                                0.27396720220367921,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67832686696352662,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.071670318290782853,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34362479229638471,
                                0,
                                0,
                                0.67199271415991102,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30410617963441378,
                                0,
                                0,
                                0,
                                0,
                                -0.036729544059029923,
                                0,
                                0,
                                0,
                                -0.39604008630915677,
                                0,
                                0,
                                0.78417189751890648,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0448986218335772,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49186206690756168,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4780592960121377,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5973070054847528,
                                0,
                                0.34271680514448843,
                                0,
                                0,
                                0.51308466443951772,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.074895804097905,
                                -0.16841492752213882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64928421335118314,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.056275003255904545,
                                0,
                                -0.44613245305090593,
                                0,
                                0,
                                -0.032889886868437954,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.057612944843101449,
                                0.6097769859256349,
                                0,
                                -0.25626485856611902,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46430454828785089,
                                0,
                                -0.84663513961948433,
                                0,
                                -0.23148702475119123,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23554435390845233,
                                -0.036611029732321956,
                                0,
                                -0.40129777195332389,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38544309700044782,
                                -0.05066797958321851,
                                0.3761681225185598,
                                0,
                                -0.31547928583083668,
                                0,
                                0,
                                0,
                                -0.22563901245133994,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28656524094625119,
                                -0.26769373223895204,
                                0.46327150877935203,
                                0,
                                0,
                                0.58059460320620582,
                                0,
                                0,
                                0,
                                0,
                                -0.19850519532241651,
                                0.14931115015129931,
                                0,
                                0.32880155579131953,
                                0,
                                0,
                                0,
                                0.10995972198653831,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12728961013142034,
                                0.8172073079329405,
                                0.080265234653349116,
                                0,
                                0,
                                0.35724967101449245,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.068123240188283,
                                0,
                                -0.076567355664234449,
                                0,
                                0,
                                0,
                                0,
                                -0.15206445284159692,
                                0,
                                -0.22215563166118807,
                                -0.85178620717445142,
                                0,
                                -0.37515373479895375,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22524389446971282,
                                0.02320544355870751,
                                0,
                                -0.38854895417086616,
                                0,
                                0,
                                0,
                                -0.27210171834140678,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4707854387175705,
                                0.3872292571030177,
                                0.22787626892488666,
                                0,
                                0,
                                -0.54790878773530061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.042710999370900407,
                                0,
                                0.13068571292474757,
                                0,
                                0,
                                0,
                                0,
                                0.051000047403614954,
                                0,
                                -0.53720306756016045,
                                -1.1697211255387587,
                                0,
                                0.59418265171515094,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4984754618411808,
                                0,
                                0,
                                0,
                                0,
                                -0.41343008588890723,
                                0,
                                0,
                                -0.087425663184105273,
                                0,
                                0.59591331687309668,
                                -0.31725412637685713,
                                0,
                                -0.36050313034608411,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.030918612951717463,
                                0,
                                0,
                                -0.87533557927909467,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14266135091418045,
                                0,
                                0.91830828151207733,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.064871725835658894,
                                0,
                                0,
                                0,
                                0.23147045308025666,
                                0,
                                0,
                                -0.019818775803209787,
                                0,
                                0.27960318976231674,
                                0,
                                0.48915715368289064,
                                0.34171649019583628,
                                0,
                                0.60690694885652929,
                                0,
                                0,
                                0,
                                -0.35615550472532559,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26982495577096965,
                                -0.15502385070411659,
                                -0.22765612760896814,
                                0,
                                0,
                                -0.010349769599145983,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70692536814596829,
                                0,
                                0.025639845721649637,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26161450827013316,
                                0,
                                0,
                                0,
                                -0.062063255812674363,
                                0,
                                0,
                                0.49766268269255298,
                                0,
                                0.42383602699489309,
                                0,
                                0,
                                0,
                                0.49116229434612502,
                                0,
                                -0.36680531583217135,
                                0,
                                0,
                                0,
                                0,
                                0.78980914281435888,
                                0,
                                0.86985323174138973,
                                -0.21159565016601475,
                                0,
                                -0.26252823558847371,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.026079265151695952,
                                0,
                                0,
                                0,
                                0,
                                -0.90365888897580016,
                                0,
                                0,
                                -0.58474067354790649,
                                0,
                                -0.72314955512103307,
                                -0.33336018559499991,
                                0,
                                -0.17567002487094829,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.91098571223322078,
                                0,
                                0,
                                0.082732082712724947,
                                0,
                                0,
                                0,
                                0,
                                -0.11359525730697514,
                                0,
                                -1.190062102631086,
                                0,
                                0,
                                0,
                                0,
                                0.32809659061203833,
                                0,
                                0.43141792810603707,
                                0.36271318303389871,
                                0,
                                0.95464068972013805,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40891075684868811,
                                0,
                                1.0048052573209665,
                                0,
                                0,
                                0,
                                0,
                                0.47360616750949935,
                                0,
                                0.31775947983792996,
                                -0.15891475175524827,
                                0,
                                0.58219664809633231,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.99243409990593634,
                                0,
                                0,
                                0,
                                0,
                                -0.15977947593401715,
                                0,
                                0,
                                0.35035833354397311,
                                0,
                                0.58453152259295837,
                                0.22221716115567436,
                                0,
                                0.67536979396057184,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0030461881091086019,
                                0,
                                0,
                                0.83005213169134306,
                                0,
                                0,
                                0,
                                0,
                                0.074865180193201167,
                                0,
                                -0.0099498412954848181,
                                0,
                                0,
                                0,
                                0,
                                -0.61490098185324527,
                                0,
                                0.958197861572476,
                                -0.59409221210973617,
                                0,
                                0.13927456992063741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.021873619990071438,
                                0,
                                0,
                                0,
                                0,
                                0.97770605788018194,
                                0,
                                0,
                                0.38118153637228641,
                                0,
                                0.40935896849354869,
                                -0.3489294020696222,
                                0,
                                -0.1336591857087957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0683684554743378,
                                0,
                                0,
                                0.44426582392168162,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48917036263112679,
                                0,
                                0,
                                0,
                                0,
                                0.91322907920058594,
                                0,
                                0,
                                -0.94049742756561305,
                                0,
                                -0.11544234690237995,
                                0.20056411118604642,
                                0,
                                0.13659064345008007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50746464391158586,
                                0,
                                0,
                                -0.045672186358043723,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42464214323613703,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38145259732680259,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28561197979931774,
                                0,
                                0,
                                0,
                                0,
                                0.12775626834082779,
                                0,
                                0,
                                0.1227581325552377,
                                0,
                                0.26278010556236864,
                                0.67295963921096758,
                                0,
                                0.34312432661105319,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76156674955010606,
                                0,
                                0,
                                -1.0790009390842361,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29793414850086697,
                                0,
                                0.00020532409434840387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50609850445686522,
                                0,
                                0,
                                0,
                                0.46541508313833546,
                                0,
                                0,
                                0.54072625169448418,
                                0,
                                -0.3822347785084107,
                                0,
                                0.63472371456613186,
                                0.31931091804821543,
                                0,
                                -0.11176783775160187,
                                0,
                                0,
                                0,
                                0.5775622243443933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2807868712944912,
                                0.086269169917391364,
                                0.25045388456400913,
                                0,
                                0,
                                -0.0092404639766544006,
                                0,
                                0,
                                0,
                                0,
                                0.086485080008921508,
                                0.34917536586685693,
                                0,
                                -0.44140736170888667,
                                0,
                                0,
                                0,
                                -0.37196795064632371,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4097002480418373,
                                0.24010668377142025,
                                -0.54037652316460338,
                                0,
                                0,
                                0.1410105666396656,
                                0,
                                0,
                                0,
                                0,
                                -0.077800590420330301,
                                0.14739657359514546,
                                0,
                                -0.21772450351404024,
                                0,
                                0,
                                0,
                                0.50450255439137703,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58793988094523031,
                                -0.099192714927083786,
                                -0.55497402994843537,
                                0,
                                0,
                                0.082376326618217699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16084423401339557,
                                0,
                                0.071342572190675579,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80060731999219148,
                                0,
                                0,
                                0,
                                -0.3902496672554514,
                                0,
                                0,
                                -0.38536445560235455,
                                0,
                                0.16512638347064157,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38515483433213804,
                                0,
                                0,
                                0,
                                0,
                                -0.9141435416623297,
                                0,
                                0,
                                -0.42975512542387712,
                                0,
                                0.99459333043548237,
                                0.57891757707958857,
                                0,
                                0.070665912079405646,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22027957200650206,
                                0,
                                0,
                                0.23221792277340009,
                                0,
                                0,
                                -0.50160952494291711,
                                0.6879581552232592,
                                0,
                                0.13534974993074833,
                                0,
                                0,
                                0,
                                0.098227797720610993,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1219197187740684,
                                -0.1077061083352536,
                                0.11158846662821895,
                                0,
                                0,
                                -0.45630712969869897,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40986039780148453,
                                0,
                                -0.38177684652708943,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.021218244404047126,
                                0,
                                0,
                                0,
                                0.35326688345746848,
                                0,
                                0,
                                0.019401065673799012,
                                0,
                                0.74875682806717581,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34685022864178155,
                                0,
                                0,
                                0,
                                0,
                                -0.27773533243196907,
                                0,
                                0,
                                0.50392149632774896,
                                0,
                                -0.18826030716754841,
                                0.60580610187471773,
                                0,
                                -1.102379301823788,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23190069797751003,
                                0,
                                0,
                                0.7785804473638348,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44416561402560711,
                                0,
                                -0.072174324442775412,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17260219383175518,
                                0,
                                0,
                                0,
                                0.66997469226482309,
                                0,
                                0,
                                -0.5573796068375384,
                                0,
                                -0.090433082990886482,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66264490476447824,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3350181573221096,
                                0.4357062765956593,
                                0.42719459365464674,
                                0.0981432143889302,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31815973843212558,
                                0,
                                0,
                                0,
                                0,
                                0.058570327252549417,
                                -0.47225904408702724,
                                -0.52574321454410822,
                                0,
                                0,
                                0,
                                -0.11807664630216957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5567873642309531,
                                0.5786090670191768,
                                0.042422382114357268,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.042615240927605449,
                                0,
                                0,
                                0,
                                0,
                                0.11652483738546768,
                                0.39282382946706945,
                                -0.38929805596430944,
                                0,
                                0,
                                0,
                                0.17928214141376564,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36500853402681988,
                                0.06016370217280384,
                                -0.58354459235409983,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17231743905935082,
                                0,
                                0,
                                0,
                                0,
                                0.07494848127482448,
                                -0.55842073663339442,
                                0.16524376027719179,
                                0,
                                0,
                                0,
                                0.3849350772541143,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3330415146982397,
                                0.4120859670660611,
                                -0.21045801079883986,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33975249308799749,
                                0,
                                0.82154343739430347,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.070460565106741924,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42641914557523308,
                                0.20316547853090627,
                                0.19154652739957945,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.83059401875810446,
                                0,
                                -0.47302580047678588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7645312940002551,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13590946647761576,
                                0.14296702027245262,
                                -0.95447126423765161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47622182013152092,
                                0,
                                -0.37664623345812054,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23688289409811558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41295735636451214,
                                0,
                                0,
                                -0.026449013843100999,
                                0,
                                0,
                                -0.036237128240640876,
                                0,
                                1.2976889061440948,
                                0,
                                0,
                                0,
                                0,
                                -0.42554731456834616,
                                0,
                                0,
                                0,
                                0,
                                0.49772406157037541,
                                0,
                                0,
                                0.0029485652062779255,
                                0,
                                0.061054811101081838,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24851535591670404,
                                0.23251154254463796,
                                0,
                                0,
                                0.32097094433153917,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61119066688168744,
                                0,
                                0.62836599478167154,
                                0,
                                0,
                                -0.11295263906076231,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27096032416813487,
                                -0.33587764344630333,
                                0,
                                0,
                                -0.60392640041062029,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20835321493760639,
                                0,
                                0.23055543631553171,
                                0,
                                0,
                                -0.59369414925300268,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73762752228011164,
                                0,
                                0,
                                -0.31955153615536003,
                                0,
                                0,
                                0.12894702345865738,
                                0,
                                -0.28935569927603572,
                                0,
                                0,
                                0,
                                0,
                                -0.55964586579403508,
                                0,
                                0,
                                0,
                                0,
                                -0.28227534323932829,
                                0,
                                0,
                                0.06670081110937677,
                                0,
                                -0.84347792543237221,
                                0.2283802438127252,
                                0.30585682732487773,
                                0.12873668383919762,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48595019223015118,
                                0,
                                0,
                                0,
                                0,
                                -0.45994418108721147,
                                0.24366927199590999,
                                0.39111426307902714,
                                0,
                                0,
                                0,
                                0.42152059463982688,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11202083038103412,
                                -0.067737961990197507,
                                0,
                                0,
                                -0.39870016623126997,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6185307471695598,
                                0,
                                -0.2156501433557409,
                                0,
                                0,
                                0.62834370370827242,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71482005739995769,
                                0,
                                0,
                                0.023274579092338342,
                                0,
                                0,
                                0.43717708761431234,
                                0,
                                0.13947270502745429,
                                0,
                                0,
                                0,
                                0,
                                0.28367241576435065,
                                0,
                                0,
                                0,
                                0,
                                -0.22183906888427041,
                                0,
                                0,
                                -0.75635015151840113,
                                0,
                                -0.71962640228189156,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63885248038416131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18433419218713229,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1712572525907399,
                                0,
                                0,
                                0.013100793240711103,
                                0,
                                0,
                                0.64735229661434046,
                                0,
                                -0.71536946130865076,
                                0,
                                0,
                                0,
                                0,
                                -0.60294026180950866,
                                0,
                                0,
                                0,
                                0,
                                0.28201426245606964,
                                0,
                                0,
                                -0.3398877115178951,
                                0,
                                0.62759591650568569,
                                0.068061687582745334,
                                0.59061561341877156,
                                0.018818931717565088,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26585893586466236,
                                0,
                                0,
                                0,
                                0,
                                0.26172745330327352,
                                -0.1215959770755297,
                                0.59926027287339045,
                                0,
                                0,
                                0,
                                -0.36483689753287957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50660340230327128,
                                0.14540274905628742,
                                -0.60503389958126363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44337612521365022,
                                0,
                                0,
                                0,
                                0,
                                -0.063328397631970512,
                                0.28239463065708209,
                                -0.15508238965944074,
                                0,
                                0,
                                0,
                                0.22749695456547739,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11806783229848636,
                                0.0080696963480231809,
                                -0.50824862638956847,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43333684706436298,
                                0,
                                0,
                                0,
                                0,
                                -0.22583788698048279,
                                0.25482230315550242,
                                -0.031928267329573656,
                                0,
                                0,
                                0,
                                -0.65033899321098021,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.083310697376211149,
                                0.91343486641665683,
                                0.14964782199337123,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0051663432867613338,
                                0,
                                -0.94184735230071059,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.090208454389273884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.022631668023044754,
                                0,
                                0,
                                -1.2215430846200739,
                                0,
                                0,
                                0.1280809889793191,
                                0,
                                0.20430345850581455,
                                0,
                                0,
                                0,
                                0,
                                0.45202106940423542,
                                0,
                                0,
                                0,
                                0,
                                0.60392668528251991,
                                0,
                                0,
                                0.19236918966565975,
                                0,
                                0.21522195224100166,
                                0,
                                0,
                                0,
                                -0.46529966155688024,
                                0.37005398887104141,
                                -0.33481981684326512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39128251869267727,
                                0,
                                0.88021355857801586,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49982444519440655,
                                0,
                                0,
                                0,
                                -0.19884590095348059,
                                0.12455671233921559,
                                0.082060879066344447,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41961082890786328,
                                0,
                                0,
                                0,
                                0,
                                -0.80144310934798701,
                                -0.30329142060608483,
                                -0.087076933842427318,
                                0,
                                0,
                                0,
                                -0.14233608724891966,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49399796459627465,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12847176816464237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87683032035753683,
                                -0.25549773329540826,
                                0,
                                0,
                                -0.15368916797959417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10831328570160931,
                                0,
                                -0.31187664237595314,
                                0,
                                0,
                                -0.18240156059959756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43054128340358722,
                                0,
                                0,
                                -0.2417754830892056,
                                0,
                                0,
                                -0.38346987918889475,
                                0,
                                -0.20419146389082929,
                                0,
                                0,
                                0,
                                0,
                                -0.55686283092849942,
                                0,
                                0,
                                0,
                                0,
                                -1.2197323462642793,
                                0,
                                0,
                                0.1886737487422632,
                                0,
                                0.072447563191260972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28480102145321207,
                                -0.37151234837107577,
                                0,
                                0,
                                0.56684047013269967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39442173870744213,
                                0,
                                -0.47377149355940518,
                                0,
                                0,
                                -0.28201223117489649,
                                0,
                                0,
                                0,
                                0,
                                0.12974387536592963,
                                0.41545534015503621,
                                0.29567638865522772,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4915365468792724,
                                0,
                                0.90399935063463177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.610963114349097,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.92060696377722895,
                                0,
                                0,
                                -0.13321800261404732,
                                0,
                                0,
                                -0.20854037518855872,
                                0,
                                -0.33948484967180148,
                                0,
                                0,
                                0,
                                0,
                                -0.34245580236278822,
                                0,
                                0,
                                0,
                                0,
                                0.81741043947456449,
                                0,
                                0,
                                0.75898999645019105,
                                0,
                                -0.15458628104835487,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.04825890220407128,
                                -0.79071843472287962,
                                0,
                                0,
                                0.16840503049087396,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18208334773742574,
                                0,
                                0.42868276719368703,
                                0,
                                0,
                                0.35658367971728427,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12836440013809181,
                                0,
                                0,
                                -0.1627031906282031,
                                0,
                                0,
                                -0.96842948357446645,
                                0,
                                -0.46549292722848934,
                                0,
                                0,
                                0,
                                0,
                                -0.42540690971417461,
                                0,
                                0,
                                0,
                                0,
                                0.16119616167206235,
                                0,
                                0,
                                -0.72462382381957047,
                                0,
                                -0.099131136624744626,
                                -0.43826152882112446,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33546251357380713,
                                0,
                                0,
                                0,
                                0,
                                0.017326063422119481,
                                0.16140352338483127,
                                0,
                                0,
                                0.00021095206139733202,
                                0,
                                0,
                                0,
                                0.34891538361657903,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48011940325187291,
                                -0.56283551211997795,
                                0,
                                0,
                                0,
                                0.17517919115981664,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60181036311216196,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24474792213416988,
                                -0.3306957595251877,
                                0,
                                -0.087060895439456415,
                                0,
                                0,
                                0.56002806666143323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.83951477330748814,
                                0,
                                0,
                                0,
                                0.04176544166216703,
                                0,
                                0,
                                0,
                                0,
                                0.86500655651070124,
                                0,
                                0,
                                0,
                                0,
                                0.66647355026641142,
                                0,
                                0,
                                0,
                                -7.4730316700501176e-05,
                                -0.30170768558209105,
                                0,
                                0.60152269919688817,
                                0,
                                0,
                                0.13622636359604606,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72372197978156783,
                                0,
                                0,
                                0,
                                -0.28903156079489406,
                                0,
                                0,
                                0,
                                0,
                                -1.0378958828361509,
                                0,
                                0,
                                0,
                                0,
                                -0.26895040528209407,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28509402616313556,
                                0,
                                0,
                                0.52893763227768253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4603441924959869,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53128461026290419,
                                0,
                                0,
                                0.29671210625295619,
                                0,
                                0,
                                0,
                                -0.23817680563505034,
                                0,
                                0,
                                0.99290870730921776,
                                -0.51570593118335462,
                                0,
                                0.22571506962970123,
                                0,
                                0,
                                0.11954497930534519,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21548729202012434,
                                0,
                                0,
                                0,
                                0.28201981073638571,
                                0,
                                0,
                                0,
                                0,
                                0.11529046944042043,
                                0,
                                0,
                                0,
                                0,
                                0.38133108972726171,
                                0,
                                0.017437596341727757,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.032260581186024179,
                                0,
                                0,
                                0,
                                0,
                                0.56595072684030834,
                                0.50250950137350237,
                                0,
                                0,
                                -0.14147267598357949,
                                0,
                                0,
                                0,
                                -0.61354281195471538,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.063102165067335597,
                                -0.15939880039136087,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17352694650673955,
                                0,
                                0,
                                0.32070312021592667,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42395702784975436,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52800205590992799,
                                0,
                                0,
                                -0.63512067365807401,
                                0,
                                0,
                                0,
                                0.071651272868138105,
                                0,
                                0,
                                -0.20998742471115986,
                                -0.49819060093427464,
                                0,
                                0.20458119085435919,
                                0,
                                0,
                                -0.57761198954533222,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068094711966472238,
                                0,
                                0,
                                0,
                                -0.96910495892719206,
                                0,
                                0,
                                0,
                                0,
                                0.26831734190868423,
                                0,
                                0,
                                0,
                                0,
                                -0.16321122522530773,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2888321944082906,
                                0.41526352919925191,
                                0,
                                0,
                                -0.35422074557607219,
                                0,
                                0,
                                0,
                                0.6056882539009667,
                                0,
                                0,
                                0,
                                0.27797376958187026,
                                0,
                                0,
                                0.029359336120854777,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48311586952683172,
                                0.70981003798546616,
                                0,
                                0,
                                -0.10385928184679413,
                                0,
                                0,
                                0,
                                -1.2051298969578677,
                                0,
                                0,
                                0,
                                -0.69675704504316816,
                                0,
                                0,
                                -0.27655004099544045,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19669339963812354,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24839069716414364,
                                0,
                                0,
                                0,
                                0,
                                -0.13450940501670927,
                                -0.48171770342715126,
                                0,
                                0,
                                0.30825932705541853,
                                0,
                                0,
                                0,
                                -0.46514250861649037,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48899979904928353,
                                -0.31459000740501775,
                                0,
                                0,
                                -0.57449230056833711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28222569912483675,
                                0,
                                0,
                                0,
                                0,
                                0.0065127558770365218,
                                -0.23935713695221095,
                                0,
                                0,
                                0.4342063902319252,
                                0,
                                0,
                                0,
                                -0.32406462339807734,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48468616590292751,
                                -0.067076430048610969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57238096256328908,
                                0.16630979731966031,
                                0,
                                0,
                                0.87634132957638877,
                                0,
                                0,
                                0,
                                -0.049817737299949288,
                                0,
                                0,
                                0,
                                0.18199779967657523,
                                0,
                                0,
                                0.5136698489813265,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26879043160501565,
                                0.50517781126772832,
                                0,
                                0.63054356696578928,
                                0,
                                0,
                                -0.60124080649389533,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11815382405927405,
                                0,
                                0,
                                0,
                                0.035050041043242636,
                                0,
                                0,
                                0,
                                0,
                                0.69567210873484053,
                                0,
                                0,
                                0,
                                0,
                                0.11830555885687016,
                                0,
                                0.03576458761860446,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65467688669509139,
                                0,
                                0,
                                0,
                                0,
                                -0.19712168211256037,
                                0.006249558949679733,
                                0,
                                0,
                                -0.012542851348718645,
                                0,
                                0,
                                0,
                                -0.24084502029468163,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40604970932785722,
                                0.55514236046964005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12314717229825296,
                                0,
                                0,
                                0.21569253421318565,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71740634432539752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.064643800309764091,
                                0,
                                0,
                                0.62644143503267724,
                                0,
                                0,
                                0,
                                0.16441395718437207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42377725444739617,
                                0.097341325170616902,
                                0,
                                0,
                                0.79225566460274954,
                                0,
                                0,
                                0,
                                0.38461026502623019,
                                0,
                                0,
                                0,
                                -0.0036659412393788907,
                                0,
                                0,
                                -0.93846678315621979,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15513840425060368,
                                0.83590225485773006,
                                0,
                                -0.2004958497539451,
                                0,
                                0,
                                0.17566725427764598,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.038853682763292229,
                                0,
                                0,
                                0,
                                -1.2357869622970488,
                                0,
                                0,
                                0,
                                0,
                                -0.17040764788798324,
                                0,
                                0,
                                0,
                                0,
                                0.1177694448476215,
                                0,
                                -0.15005399604337552,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21402479919930659,
                                0,
                                0,
                                0,
                                0,
                                0.59977607343802919,
                                -0.069634169709619137,
                                0,
                                0,
                                0.48689227090739601,
                                0,
                                0,
                                0,
                                0.29131217351360611,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28063496117711001,
                                0.40793881942977972,
                                0,
                                0,
                                0,
                                -0.40137976921369617,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26635172703391047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16859033638169607,
                                0.70757344401033184,
                                0,
                                0,
                                0.50939210415489322,
                                0,
                                0,
                                0,
                                0.50496380024004761,
                                0,
                                0,
                                0,
                                -1.071025467724362,
                                0,
                                0,
                                0.34405473969350747,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48762517259365729,
                                0,
                                0,
                                -0.4546784401748093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10037024936954356,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39843058005163962,
                                0,
                                0,
                                -0.028507338385478698,
                                0,
                                0,
                                0,
                                0.62117262067205081,
                                0,
                                0,
                                0.86893688804846303,
                                0.0038602365278332246,
                                0,
                                -0.36128960546094391,
                                0,
                                0,
                                -0.28012046138259389,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3878082016940223,
                                0,
                                0,
                                0,
                                -0.021923660808202683,
                                0,
                                0,
                                0,
                                0,
                                0.59116251597142977,
                                0,
                                0,
                                0,
                                0,
                                -1.0685317137453119,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58835581325193576,
                                1.3283509498120318,
                                0,
                                0,
                                -0.15353080143808268,
                                0,
                                0,
                                0,
                                0.11528620925556415,
                                0,
                                0,
                                0,
                                0.91294092424994999,
                                0,
                                0,
                                0.8303174481494946,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.78524272066610568,
                                0,
                                0,
                                -0.22574261201592399,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16945432581940084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39472720828247165,
                                0,
                                0,
                                0.33658443697094054,
                                0,
                                0,
                                0,
                                0.18606644526269775,
                                -0.11278456246248331,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30451727948169033,
                                0,
                                0,
                                0,
                                0,
                                -0.50102599568234019,
                                0.6410599729206905,
                                0,
                                0,
                                0.45839176376809776,
                                0,
                                0,
                                0,
                                -0.078666388222582373,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.08289683208200363,
                                0.09685368986782944,
                                0,
                                0,
                                -0.63433224790303866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42182420397137038,
                                0,
                                0,
                                0,
                                0,
                                -0.10793072829852848,
                                -0.12744981523697016,
                                0,
                                0,
                                -0.49908117549616099,
                                0,
                                0,
                                0,
                                -0.17717317133320068,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20238023581272294,
                                0.26526275742497618,
                                0,
                                0,
                                0,
                                0,
                                0.67742465429590315,
                                0.019651917907235222,
                                0,
                                -0.72089032055264168,
                                0,
                                0,
                                -0.84334318693642263,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18226870966491016,
                                0,
                                0,
                                0,
                                0.61651197836962202,
                                0,
                                0,
                                0,
                                0,
                                -0.41712427137446928,
                                0,
                                0,
                                0,
                                0,
                                0.45025679756089615,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13805842868505103,
                                0,
                                0,
                                -0.55960612013215905,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23427087867739663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34672060056396359,
                                0,
                                0,
                                0.045310405166848089,
                                0,
                                0,
                                0,
                                -0.70044971861765193,
                                0.075447342024108605,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30303921454018612,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.034124450423649824,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1852222652758545,
                                0.14936945516508804,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32534328644599808,
                                0,
                                0,
                                0.87881720481166969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25307917078371084,
                                0,
                                0,
                                0,
                                -0.45094668225181811,
                                -0.2610790909114496,
                                0,
                                0,
                                0,
                                -0.2543817330482912,
                                0,
                                0,
                                0,
                                0,
                                -0.011009035378319446,
                                0,
                                0,
                                -0.75293712464128204,
                                0,
                                0,
                                0,
                                0,
                                0.13637798566002007,
                                -0.24101483407821872,
                                0,
                                0,
                                0.14160548790494215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32821632694644398,
                                0.5526739357604693,
                                0,
                                0,
                                0,
                                0.46181633911269859,
                                0,
                                0,
                                0,
                                0,
                                -0.24263953635099988,
                                0,
                                0,
                                -0.45779744030635022,
                                0,
                                0,
                                0,
                                0,
                                0.3167316805969953,
                                -0.055580339881508234,
                                0,
                                0,
                                0.041117633182666147,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1733833175606011,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46276814290300861,
                                0,
                                0,
                                -0.69268639609878135,
                                1.107644619521547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.077339912814630263,
                                0,
                                0.26149178085677077,
                                0.14691769616463046,
                                0.1735382802815249,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55907367498722582,
                                -0.17816414292421034,
                                0,
                                0,
                                0.11896523220884336,
                                0,
                                0,
                                0,
                                0,
                                -0.083375833903554727,
                                0,
                                0,
                                0,
                                0.47584650042430909,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.94400256905396029,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65316173520024101,
                                0.66171079021099888,
                                0,
                                0,
                                -0.24813299881457146,
                                0,
                                0,
                                0,
                                0,
                                -0.60982508880350517,
                                0,
                                0,
                                0,
                                0.14721223578704143,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43795538062737999,
                                0,
                                0,
                                0.031551745455639074,
                                0.27588532335710819,
                                0,
                                0,
                                0,
                                -0.26151097601706219,
                                0,
                                0,
                                0,
                                0,
                                -0.31848848572430871,
                                0,
                                0,
                                -0.046465891336772251,
                                0,
                                0,
                                0,
                                0,
                                -0.49793100789906136,
                                0.19646204373283749,
                                0,
                                0,
                                0.681452248720117,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29723178057917943,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33986305877235456,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068660825020269295,
                                -0.38134672481486209,
                                0,
                                0,
                                1.331331676366734,
                                0,
                                0,
                                0,
                                0,
                                -0.90513746261440819,
                                0,
                                0,
                                0,
                                0.25302049695038736,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31893561029023154,
                                0,
                                -0.76405291305605449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.032172976612742453,
                                -0.55022466901089662,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10420986691813988,
                                0,
                                0,
                                -0.07098638339370987,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31071224026077121,
                                0,
                                0,
                                -0.46747281618790748,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53227138085040415,
                                0.29070641887020404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19171065345670635,
                                0,
                                0,
                                0.066965775419799659,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61025300618206035,
                                0,
                                0,
                                0,
                                -0.24307823055518896,
                                -0.40667181651380147,
                                0,
                                0,
                                0,
                                0.72329287009676346,
                                0,
                                0,
                                0,
                                0,
                                0.059745051452067433,
                                0,
                                0,
                                0.072787105040420491,
                                0,
                                0,
                                0,
                                0,
                                0.031608840721162601,
                                0.18728910123077203,
                                0,
                                0,
                                0.45544996593036613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.070940768418439548,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.015385162095473696,
                                0,
                                0,
                                0.62845097082893719,
                                0.65809322876913723,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28740798216940067,
                                0,
                                1.0549618412784605,
                                0.61156576546219965,
                                0.064738730853639126,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18163152021251086,
                                -0.5806749030481011,
                                0,
                                0,
                                -0.67914201384452366,
                                0,
                                0,
                                0,
                                0,
                                -1.2366568314628441,
                                0,
                                0,
                                0,
                                -0.30464479898889807,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.091236908899402697,
                                0,
                                0,
                                0.41342701071914723,
                                -0.039924096799516584,
                                0,
                                0,
                                0,
                                -0.17398680988923709,
                                0,
                                0,
                                0,
                                0,
                                0.5300120594907578,
                                0,
                                0,
                                0.093174782572761516,
                                0,
                                0,
                                0,
                                0,
                                0.30042480646937486,
                                -0.38881815786270035,
                                0,
                                0,
                                0.51593004927811992,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21584396085074589,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10686202084828966,
                                0,
                                0,
                                -0.44199367475813384,
                                -0.78375025696151002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35776149209857888,
                                0,
                                0.5273474603795304,
                                -0.29952292807859088,
                                -1.2172686543770657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56103789921818603,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77518173892069864,
                                0,
                                0,
                                0.94314874865313114,
                                -0.13723135931693775,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19786967605682743,
                                0,
                                -0.055103363794111251,
                                -0.19558359126263811,
                                -0.73342112954484184,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.75130460403234844,
                                0.76490738350736842,
                                0,
                                0,
                                -0.42635494170646387,
                                0,
                                0,
                                0,
                                0,
                                -0.17470297252231953,
                                0,
                                0,
                                0,
                                -0.53688978458887693,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53266825357463476,
                                0,
                                -0.10166873472887997,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29834241639680514,
                                -0.018043297927830021,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87339060127609902,
                                0,
                                0,
                                0.35023546750450629,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12187569594264722,
                                0,
                                0,
                                0,
                                0.27758685092540702,
                                -0.077028938801244007,
                                0,
                                0,
                                0,
                                -0.081806942670158797,
                                0,
                                0,
                                0,
                                0,
                                0.47701031243921599,
                                0,
                                0,
                                -0.38115613510269281,
                                0,
                                0,
                                0,
                                0,
                                -0.081510843779566508,
                                0.72370430636545136,
                                0,
                                0,
                                -0.08431446320825367,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50162420983091505,
                                0.40284502717743964,
                                0,
                                0,
                                0,
                                -0.19410130504862311,
                                0,
                                0,
                                0,
                                0,
                                0.098962902982902515,
                                0,
                                0,
                                0.24336053704879698,
                                0,
                                0,
                                0,
                                0,
                                0.56956967809262937,
                                0.35920542655583598,
                                0,
                                0,
                                0.16111348714231599,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43069408429747608,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60791637657378661,
                                0.62574063619387288,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21542201279610651,
                                0,
                                0,
                                -0.080817471944626365,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.021232844642125014,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52029467776566041,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44983000651953869,
                                0,
                                0,
                                0.43094780138377509,
                                -0.19043536048760604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.242818664676756,
                                0,
                                -0.19266287181435113,
                                0.87514051972236984,
                                -0.33686523571887556,
                                0,
                                0,
                                0,
                                0,
                                -0.35949324443358038,
                                0.46377046498208258,
                                0,
                                0,
                                0,
                                0.23629628393952865,
                                0,
                                0,
                                0,
                                0,
                                0.56369778452788244,
                                0,
                                0,
                                -0.053518761583255726,
                                0,
                                0,
                                0,
                                0,
                                -0.45917205914127512,
                                -0.2473703945555828,
                                0,
                                0,
                                -0.08482385921198865,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7888951041728699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.022739313143344118,
                                0,
                                0,
                                -0.61536476601017798,
                                -0.38771632224140107,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16734483304142442,
                                0,
                                -0.039797945790933917,
                                0.57646553405151535,
                                -0.12595832613756658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11307091272331189,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63600187717539658,
                                0,
                                0,
                                -0.64137924419240011,
                                -0.49403030377622154,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2295031742252556,
                                0,
                                0.071545357022294365,
                                0.31710920418306737,
                                0.4131971508581514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.076841420750850487,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49717474886366003,
                                0,
                                0,
                                0.12639129252552789,
                                0.36360673173146973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.8629950809137229,
                                0,
                                -0.40816156432469347,
                                0.70686418585936128,
                                -0.64861464109825961,
                                0,
                                0,
                                0,
                                0.02634213713758142,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47198969355429188,
                                -0.44559449404000773,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19318718631956788,
                                0,
                                0,
                                0.29826245548591779,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67208302058616176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16595875936899143,
                                -0.13845564338742733,
                                0,
                                0,
                                0.47181395155000139,
                                0,
                                0,
                                0,
                                0,
                                0.43499076470844944,
                                0,
                                0,
                                0,
                                -0.99710718025698908,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69167629052357138};

const double rot_24_2[32]
    = {-1.1720696655824552,  -0.29848898515013034, 2.1086402136387061,   -2.0225710059701711,  0.66005337565701139,
       0.75121870402951507,  0.75121870402951518,  -0.66005337565701139, -0.44218760626925108, -0.89692258353877419,
       0.89692258353877419,  -0.44218760626925124, 0.51907281903698754,  -0.85473002084693117, 0.85473002084693117,
       0.51907281903698732,  0.57666510504561863,  -0.8169806341785133,  -0.81698063417851352, -0.57666510504561852,
       -0.80514296679421626, -0.5930807727635512,  0.59308077276354521,  -0.80514296679421649, -0.86058077282168044,
       -0.50931398316720022, -0.50931398316720022, 0.86058077282168044,  0.79962026525631491,  0.60050597948015516,
       0.60050597948015505,  -0.79962026525631491};

const double rot_11_50[2500] = {1.2052599167964657,
                                0,
                                0,
                                -0.39722296207295033,
                                0,
                                0,
                                0,
                                0,
                                0.70166988763467653,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87081617431423664,
                                0,
                                0,
                                0,
                                0,
                                0.41884955013962699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32633901489170691,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2923643591441451,
                                0,
                                0,
                                0,
                                0.37581158984452173,
                                0,
                                0.18518645453788291,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56314048887361545,
                                0,
                                0,
                                -0.047746184920010905,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.299870061403476,
                                0,
                                0,
                                0,
                                0.72211891052689547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18687240033183822,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29376738427795485,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87191953364068708,
                                0.39173594523645061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.019283930027444701,
                                0,
                                0,
                                0.23829882512456602,
                                0,
                                0,
                                0,
                                0,
                                0.26337514441695009,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10438104312302063,
                                0,
                                0,
                                0,
                                0,
                                -0.56924772564175385,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40764477296436497,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48383976549944463,
                                0,
                                0,
                                0,
                                0.65415288277562156,
                                0,
                                0,
                                0,
                                0,
                                -0.64022993932289163,
                                0,
                                0,
                                -0.075777821945311255,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40103514511141869,
                                0,
                                0.048378159320564891,
                                0,
                                -0.16056263270046708,
                                0,
                                0,
                                0,
                                0,
                                0.15790526087884754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1334684177298717,
                                0,
                                0,
                                -0.59385643350713135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74150715260353151,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.93519886807496078,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1407009712495908,
                                0,
                                0,
                                0,
                                0.80729242620151986,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25960353438673522,
                                0,
                                0,
                                -0.027358393126921843,
                                0,
                                -0.15051176549137513,
                                0.94128317573977283,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.78313295174115405,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17257608052370593,
                                0,
                                0,
                                0.22778521796590293,
                                0,
                                0,
                                -0.39888283231216232,
                                0,
                                0,
                                0,
                                0.56924715496109957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.78198350153406126,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41659411350277625,
                                0,
                                0,
                                -0.4153891545366527,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12305680801834878,
                                0,
                                -0.3440422497986963,
                                0,
                                -0.16483065890936538,
                                0,
                                0,
                                0,
                                0,
                                -0.55172268057316209,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26089874280313891,
                                0,
                                0,
                                0.34750241851008501,
                                0,
                                0,
                                0,
                                -0.20324423548686082,
                                0,
                                0,
                                0.1638610700465282,
                                0,
                                0,
                                0,
                                0,
                                0.24405120776686776,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49316855923663883,
                                0,
                                0,
                                0,
                                0,
                                1.1306423470494713,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17927769987932324,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25375573716622352,
                                0,
                                0,
                                0,
                                0.67905979205508693,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2232144165017671,
                                0,
                                0,
                                -0.17236685124552004,
                                0,
                                -0.36504960613958948,
                                -0.17004700673556408,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.81768726236923994,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0062032073963543821,
                                0,
                                0,
                                0.82596156863002945,
                                0,
                                0,
                                -0.70846815106562055,
                                0,
                                0,
                                0,
                                -0.20358546784336834,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47867703748225926,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47799775914969544,
                                0,
                                0,
                                0,
                                0,
                                -0.13485871685537937,
                                -0.1280661219520291,
                                0,
                                0.74766926049551963,
                                -1.234909006539102,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1008492544582966,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39921067066103322,
                                0,
                                0,
                                -0.21567047227455602,
                                0,
                                1.1140110229001203,
                                0.14385013670641944,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64273171034766807,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10546739620338152,
                                0,
                                0,
                                -0.38216257562348238,
                                0,
                                0,
                                0.41213952699785983,
                                0,
                                0,
                                0,
                                0.20031688372978054,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40508391269430205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.038967176324370453,
                                0,
                                0,
                                -0.33053830381830113,
                                0,
                                0.27714261398619455,
                                -0.37922709344746469,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36536104037746869,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1160404695523791,
                                0,
                                0,
                                0.59470465697248243,
                                0,
                                0,
                                0.54986448002142452,
                                0,
                                0,
                                0,
                                0.35606230838325575,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69363371850559286,
                                0,
                                0,
                                0,
                                0.95402006782289162,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2419123765413238,
                                -0.17698619230700932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.059551944768356818,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42571672381048864,
                                0.90289469870100048,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5339001623494386,
                                0,
                                0,
                                0,
                                0,
                                0.72016915755884758,
                                -0.79096749453982218,
                                0,
                                -0.075422392413732525,
                                -0.77143285495059466,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55030967568206357,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28932715870004821,
                                0,
                                0,
                                0,
                                0,
                                -1.1665532616539569,
                                -0.37011779362800451,
                                0,
                                0.04150839190859483,
                                0.33917814561416892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57801384554958335,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59096849523466211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22574330125783534,
                                0,
                                0,
                                -0.23145884242631098,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26146712233080877,
                                0,
                                0,
                                0,
                                0.28118715510154257,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63149958953740692,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90395283170717589,
                                0,
                                0,
                                0,
                                0,
                                -0.58857939933646941,
                                0.81480477151253672,
                                0,
                                -0.82752151834594834,
                                -0.97621835588690009,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3583472433665047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1955420547793689,
                                0,
                                0,
                                0,
                                0,
                                0.76336905305685798,
                                0.76501010804776892,
                                0,
                                0.83407302266183636,
                                0.089382498858743747,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.77804233696598657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24980983171150306,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10366209628742559,
                                0,
                                0,
                                -0.94775077561641452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0055822415433448569,
                                0,
                                0,
                                0,
                                0.037241415178411841,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16492301436401685,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.042150188754696324,
                                0,
                                0.14406759139382647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59645927227512563,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67424838927518416,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40877051847555262,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37327103816928575,
                                0,
                                0,
                                0.70041160955224591,
                                0,
                                0.67351159905748881,
                                -0.6861765960833841,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42155663349758921,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56292372858465345,
                                0,
                                0,
                                0.41375221105755289,
                                0,
                                0,
                                -0.2400059581180379,
                                0,
                                0,
                                0,
                                -0.1881012601806111,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12932186356912448,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5100057694480421,
                                0,
                                -0.078024781455632172,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65721348093085907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51671667621563122,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18676339473227904,
                                0,
                                0,
                                -0.83607475734216308,
                                0,
                                0,
                                -0.86760247985012284,
                                0,
                                0,
                                0,
                                0,
                                0.38141408706342095,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28188878198800321,
                                0,
                                0,
                                0,
                                0,
                                -0.39528383798334421,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47139817492166336,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46098025646980911,
                                0,
                                0,
                                0,
                                0.081653130108157557,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28649162697910757,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3490294550874491,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1450072480656901,
                                0,
                                0,
                                0,
                                -0.36145515989728749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.303110895786803,
                                0,
                                0,
                                -0.11829553043465614,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46843638462139253,
                                0,
                                0.15528308820068898,
                                0,
                                0.10527495163743561,
                                0,
                                0,
                                0,
                                0,
                                0.25533945850213813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45116458335246301,
                                0,
                                0,
                                0.60889566646033033,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1468581962446176,
                                0,
                                0,
                                0,
                                0,
                                0.062206953882073507,
                                0.77470219323123068,
                                0,
                                -0.46804007968957967,
                                -0.49977443725208581,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20933669050966125,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15409895452551886,
                                0,
                                0,
                                -0.046646498319097507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26680685016729344,
                                0,
                                -0.62685259869372179,
                                0,
                                0.27232304509423455,
                                0,
                                0,
                                0,
                                0,
                                0.46084144637904456,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45703300850469253,
                                0,
                                0,
                                0.12055575544314517,
                                0,
                                0,
                                0,
                                0.026323628737428176,
                                0,
                                0,
                                -0.67248102309691127,
                                0,
                                0,
                                0,
                                0,
                                -0.1848347839777455,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2251581642523689,
                                0,
                                0,
                                0,
                                0,
                                0.71714804585043712,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71272395509201791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27936758930846572,
                                0,
                                0,
                                0,
                                -0.21517080997135218,
                                0,
                                0,
                                0,
                                0,
                                -0.14749009748535533,
                                0,
                                0,
                                -0.25275673943041149,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25417521870924975,
                                0,
                                -0.32675759576233809,
                                0,
                                0.62252064259132966,
                                0,
                                0,
                                0,
                                0,
                                -0.056671976606291315,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50923124605627579,
                                0,
                                0,
                                -0.30483603506996237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.087299826295481844,
                                0,
                                0,
                                0.046364071278385835,
                                0,
                                0.16697672055855053,
                                0.33919571948280669,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47834643467820703,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.095687261365524523,
                                0,
                                0,
                                1.054308435239746,
                                0,
                                0,
                                0.6513847449742115,
                                0,
                                0,
                                0,
                                0.76934202264801244,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.89353713256710399,
                                0,
                                0,
                                0.66741770449495197,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31785413143521352,
                                0,
                                0,
                                -0.059884393584723083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38639043662976924,
                                0,
                                0,
                                0,
                                -0.21790147893503198,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50314768629123829,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.038774001720827386,
                                0,
                                -0.5305173607425886,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15289221747309134,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41386368532047679,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72276464118714789,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33451465024442001,
                                0,
                                0,
                                -0.61924585219719097,
                                0,
                                -0.31801173481981576,
                                -0.46867932582496902,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29200940234345152,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18412159177094151,
                                0,
                                0,
                                -0.39130595277284014,
                                0,
                                0,
                                -0.34668107697904171,
                                0,
                                0,
                                0,
                                0.31916099658935959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25202277380802718,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25423799658943069,
                                0,
                                0,
                                -0.11204888621372659,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12742837393113737,
                                0,
                                -0.49152634024979736,
                                0,
                                -0.64396244607176945,
                                0,
                                0,
                                0,
                                0,
                                0.052094332643240371,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47930830194117746,
                                0,
                                0,
                                -0.13354420538662953,
                                0,
                                0,
                                0,
                                0,
                                -0.29365264370456939,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72077815128027867,
                                0,
                                0,
                                0.19961501352185781,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11664507891256407,
                                0,
                                0,
                                0,
                                0.57210785700818889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11613506522126972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.81240444979513948,
                                0,
                                0,
                                0.17095040744949083,
                                0,
                                -0.78637903762294736,
                                -0.40713541770684814,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.066910563375814108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.042868032740189965,
                                0,
                                0,
                                0.0091551549868932706,
                                0,
                                0,
                                0.9563608295964332,
                                0,
                                0,
                                0,
                                -0.075371154078070934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25742949071660637,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2999060774912512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47549066801960022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1130257951107384,
                                0,
                                0,
                                0,
                                0.18432087386945573,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.244685441014448,
                                0,
                                0,
                                -0.35285247273367543,
                                0,
                                0,
                                0,
                                0,
                                0.020119903380834303,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87847424377279137,
                                0,
                                0,
                                0,
                                0,
                                -0.29456612563913687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25760341482899851,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79129236969599948,
                                0,
                                0,
                                0,
                                0.23743523488724777,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69875820481042861,
                                0,
                                -0.5066110904158353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29945394596124003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.088858531730612964,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39687991869670963,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.89426479358416466,
                                0,
                                0,
                                -0.6052871056927932,
                                0,
                                0.40255846492716035,
                                0.52296934442322585,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23801712341427625,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.021846422275826255,
                                0,
                                0,
                                0.2021277058172278,
                                0,
                                0,
                                -0.21281457053919883,
                                0,
                                0,
                                0,
                                -0.91595691957902481,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47325565278750092,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23151185164660129,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.92436535281370358,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3069268974329347,
                                0,
                                0,
                                0,
                                -0.94433251598135182,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4440062534806003,
                                0,
                                0,
                                -0.35229996596033841,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61416306338698945,
                                0,
                                0.15426553738081189,
                                0,
                                0.20573389890570729,
                                0,
                                0,
                                0,
                                0,
                                -0.4514659272931541,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.045365977537197608,
                                0,
                                0,
                                -0.17188095827830227,
                                0,
                                0,
                                0,
                                0,
                                0.14959610706179677,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.024789701253663976,
                                0,
                                0,
                                0.049832511359564485,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.82387989709654319,
                                0,
                                0,
                                0,
                                0.15265217092554748,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52196017678287898,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44390715288918869,
                                0,
                                0,
                                -0.3451926337651825,
                                0,
                                0,
                                0,
                                0,
                                -0.80560621042193181,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36735681747583526,
                                0,
                                0,
                                0,
                                0,
                                -0.077376431683115809,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14743794508541846,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4080167808579922,
                                0,
                                0,
                                0,
                                0.67790184687539723,
                                0,
                                0,
                                0,
                                0,
                                -0.13191067266517956,
                                0,
                                0,
                                0.77780695254247645,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27453595745352716,
                                0,
                                -0.3001182108983993,
                                0,
                                0.13138424171161386,
                                0,
                                0,
                                0,
                                0,
                                -0.42819145090295441,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10285131574416785,
                                0,
                                0,
                                0.031414261395190594,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49834829659417346,
                                0,
                                0.65958562416655109,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31505250528153911,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31498253505888746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3436912876379169,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65886194551079802,
                                0,
                                0,
                                -0.59373457338102265,
                                0,
                                -0.10158434662517496,
                                0.086294738412062644,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2347270085667508,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87811926158863152,
                                0,
                                0,
                                0.30317135477753593,
                                0,
                                0,
                                0.36380013504181996,
                                0,
                                0,
                                0,
                                -0.50073649723987823,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57177394122714265,
                                0,
                                -0.50855967874027974,
                                0,
                                0,
                                0.29843184883990115,
                                0,
                                0,
                                0,
                                0,
                                0.73163620927224549,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52905459611118344,
                                0,
                                0,
                                0,
                                0,
                                0.052131370205033924,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57041995030518433,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69054628686962549,
                                0,
                                0,
                                0,
                                0.059178823675696116};

const double rot_11_20[400] = {1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67420426354789631,
                               0.52309197891175963,
                               0,
                               0,
                               0,
                               0,
                               -0.2185031857356215,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.47337062692503667,
                               0,
                               0,
                               0,
                               -0.61804479098386478,
                               -0.72681768503026567,
                               0,
                               0,
                               0,
                               0,
                               0.2938218051351511,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.058527223512463644,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.068880334100394611,
                               0.32946900130255791,
                               0,
                               0,
                               0,
                               0,
                               0.927577708788769,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16218899750935939,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.8169178562711572,
                               0,
                               0,
                               0,
                               -0.22772611967400552,
                               0,
                               0,
                               0.03901915159106259,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22158320219522082,
                               0,
                               0,
                               0,
                               0,
                               -0.90324014535851749,
                               0,
                               0,
                               0,
                               0,
                               0.36750255008317645,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.76134220695957378,
                               0,
                               0,
                               0,
                               0.94718375212713946,
                               0,
                               0,
                               0.34868622978272096,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38088089460344848,
                               0,
                               0,
                               0,
                               0,
                               -0.26676740237664326,
                               0,
                               0,
                               0,
                               0,
                               -0.88530497409383979,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12821410312053372,
                               0,
                               0,
                               0,
                               0.27695194541210799,
                               0,
                               0,
                               -1.0172876836723741,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               -0.39840274462629771,
                               0.2992674581475907,
                               0,
                               0,
                               0,
                               0,
                               0.074328317676937067,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.86382263385456004,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.89768069413961915,
                               0,
                               0,
                               0,
                               0,
                               -0.33614341112379797,
                               0,
                               0,
                               0,
                               0,
                               -0.28491573934598313};

const double rot_11_10[100] = {0.18255968298969438,
                               0.60556758632414942,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.77457075889827298,
                               0,
                               0,
                               -0.95377400021285752,
                               -0.082203168229459611,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28906365328592082,
                               0,
                               0,
                               0,
                               0,
                               -1.1978854923077471,
                               0,
                               0,
                               1.0331266597430666,
                               0,
                               0,
                               0.3508814482627311,
                               0,
                               0,
                               0,
                               0,
                               -0.52176822103159504,
                               -0.62589230077738733,
                               0,
                               -0.093038452782095771,
                               0,
                               0,
                               0.57215434775332097,
                               0,
                               0,
                               0,
                               -0.42233616333994756,
                               -0.2241208680131854,
                               0,
                               0.7117701402902018,
                               0,
                               0,
                               -0.51457289964355657,
                               0,
                               0,
                               0.22327189008228226,
                               0,
                               0,
                               1.3276975604668588,
                               0,
                               0,
                               0.26431693582424032,
                               0,
                               0,
                               0,
                               0,
                               0.24978635069139918,
                               -0.6479937224821678,
                               0,
                               -0.45738039450376766,
                               0,
                               0,
                               -0.55544044627264588,
                               0.23871974921373162,
                               -0.79153682007003501,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.56256763487490979,
                               0,
                               0,
                               0,
                               0,
                               -0.34758991799994776,
                               0,
                               0,
                               0.74104110742358131,
                               0,
                               0,
                               -1.2166175991596846,
                               0,
                               0,
                               0,
                               0,
                               0.69785160862828932,
                               -0.37166221219315282,
                               0,
                               0.52490979074385558,
                               0,
                               0,
                               0.31518255653484084};

const double rot_11_100[10000] = {0.17709433891210427,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11033272653841608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.84709116458286493,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61861927860467236,
                                  0,
                                  0,
                                  0,
                                  -0.3032988096716886,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.81961241784061001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032646409545922461,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037977034479516197,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.57725100327589851,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65636418502671401,
                                  0,
                                  0.48277240031858321,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019751002954814217,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.69423360539436629,
                                  0,
                                  0,
                                  0.078302284448916931,
                                  0,
                                  -0.22174166776700222,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061001786858872468,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59351209672473848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10111342827086954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27796572444814754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13882503327529458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60329795468840974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.63638091050807599,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23900293711096471,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42110734205874756,
                                  0,
                                  -0.089429748199358422,
                                  -0.44396123255989128,
                                  0.28570002891430668,
                                  0.033843876809823759,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14984592747497813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.76689541887897317,
                                  0,
                                  0,
                                  0,
                                  -0.2482594649944812,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53062762877187397,
                                  0,
                                  0.041453390516980965,
                                  0,
                                  -0.077569154455929559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32816279946584798,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38605622669391138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022956546721759785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.006473395158655304,
                                  0,
                                  0,
                                  -0.16641888339076494,
                                  0,
                                  0,
                                  0.12411025670085489,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23555058094588122,
                                  0,
                                  0,
                                  -0.32732332373668038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46131388228604847,
                                  0,
                                  0.49489255248144381,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27672162132387018,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051707173413771707,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23886612565774218,
                                  0,
                                  0,
                                  0.2570639664404849,
                                  0,
                                  -0.39031545848026955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32896727970696094,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15969628827277987,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.027660143886086425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18234726196218343,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.74617487959035245,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084366283789176155,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53583653460694913,
                                  0.37246608552591998,
                                  0,
                                  0,
                                  0,
                                  -0.25834948411017761,
                                  -0.0089118604235786658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31602533087406437,
                                  0,
                                  0,
                                  0.10954106870060372,
                                  0,
                                  0,
                                  0,
                                  0.22494739671248254,
                                  0,
                                  0.025944622917920025,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27956214839233745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42025630786982104,
                                  -0.067077559975340054,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22952903084147178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15845387933153962,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12473008745372492,
                                  0,
                                  0,
                                  -0.34350259930176086,
                                  0,
                                  -0.45575309479715292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23155188677176128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11455740933535988,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7564069685326108,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063199897697899882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12590504646210837,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.345116131597481,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16074668863203978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030445892374838742,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32219101517370574,
                                  0,
                                  -0.22087067421218104,
                                  -0.1656027191589404,
                                  -0.08016512789614251,
                                  -0.68180036976904379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6626968600904688,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12180361619191958,
                                  0,
                                  0,
                                  0,
                                  0.46897329720950726,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62162255593256399,
                                  0,
                                  0.31838963799288833,
                                  0,
                                  0.40156933186083477,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10899594083402307,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45634369951456338,
                                  0,
                                  0,
                                  0,
                                  -0.56384846023942348,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.093152622026564116,
                                  -0.053151477775757648,
                                  0,
                                  -0.21689156835765233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24838353877727856,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55915951749578396,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.89010738933534739,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6491276806067463,
                                  0,
                                  0.12743779501708663,
                                  0,
                                  0,
                                  0.38160367914766147,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4716465839828855,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.059655005243450659,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58643221283739644,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62806107753270746,
                                  0,
                                  -0.13105373011947458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13583903203254777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22063742925957847,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085246102139403812,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.68505008136118173,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083877219376699841,
                                  0,
                                  0,
                                  -0.12062891206481173,
                                  0,
                                  0,
                                  0.42388279681167779,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20590029397563742,
                                  0,
                                  0,
                                  -0.11070150509016448,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22526792348784383,
                                  0,
                                  0.1866310062586512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28746468281806986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22501732624798002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.96399591558988607,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38423883361046285,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2131342386472031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16650688160277211,
                                  0,
                                  0,
                                  0,
                                  0.336441078470122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084377046061297742,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098618312692005841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.66362955810324631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14659866357501555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.75603981917537455,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.77305460707594675,
                                  0,
                                  0,
                                  -0.27341192358721811,
                                  -0.48283293863721205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.88810484197884221,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16815787318511202,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.047954606559776479,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33327122231351664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26673335292764855,
                                  0,
                                  0,
                                  0,
                                  0.072657774621742721,
                                  0,
                                  0,
                                  -0.62288880996420037,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49099569198348247,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25170899984816769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.1999673975486633,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.6699899588117102,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.91294681001858902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36941157634671007,
                                  0,
                                  0,
                                  0,
                                  0.38739127986865429,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22206546206434422,
                                  0.67992461137084925,
                                  0,
                                  0.6140108798211843,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14949135990853055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16518214962643712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.066271785643125067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32077058906821176,
                                  0,
                                  0.60926182354133651,
                                  0,
                                  0,
                                  0.11885065906390518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42065896185046364,
                                  0,
                                  0,
                                  -0.35059690928169074,
                                  0,
                                  -0.054829671642163166,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50301397197148012,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4060129983385124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48399466634405064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20330373189842907,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060569768473671945,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45746419218447182,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44146940008962826,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37666190301875879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063490655365268267,
                                  0,
                                  -0.45070788381783955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49677805166244343,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043042680537222509,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48001864218220847,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18312931744461688,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48680737371769184,
                                  0,
                                  -0.71805651059037667,
                                  -0.29882383496574361,
                                  -0.70260935114600864,
                                  0.70191734215674517,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.024826284235573235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21741264008506991,
                                  0,
                                  0,
                                  0,
                                  0.26246876980752204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01519051852957715,
                                  0,
                                  -0.063656628923752179,
                                  0,
                                  0.33367969389432556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49494603487285665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25351613619484459,
                                  0,
                                  0,
                                  0,
                                  -0.3295517740336209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0789530249190789,
                                  -0.4549766274785515,
                                  0,
                                  0.39003496878829746,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38096489334179234,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48040878602954529,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28602849524739266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43216093644177139,
                                  0,
                                  0.42193315388688535,
                                  0,
                                  0,
                                  0.2741600298923032,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.058640874872055909,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13324294790408583,
                                  0.15977987976465785,
                                  0,
                                  0,
                                  0,
                                  0.22354195053227233,
                                  -0.28052203962171418,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3468087726960965,
                                  0,
                                  0,
                                  0.2710285257142393,
                                  0,
                                  0,
                                  0,
                                  0.13107328169367402,
                                  0,
                                  -0.13997534336453621,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36154454042232803,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26383468763950119,
                                  0.053298597042440353,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.00093150593444405101,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62525470212896173,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11906168837131323,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.076918877023964688,
                                  -0.19335871782777816,
                                  0,
                                  0,
                                  0,
                                  0.24997964122548771,
                                  0.29931571734277301,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31218762061384514,
                                  0,
                                  0,
                                  0.32801085273786512,
                                  0,
                                  0,
                                  0,
                                  0.33367475141839448,
                                  0,
                                  0.5592006487350818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22394257652253202,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13108779748855681,
                                  0.13421705134333969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1237137383149543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24635433399183626,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.71702340948368937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38595933955671552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65378219972732621,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48544662963416196,
                                  0,
                                  0,
                                  0,
                                  0.39782637128906817,
                                  0,
                                  0,
                                  -0.192457990396247,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59047204218000326,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10169971571391959,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41058243262105604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44444801760111652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21403973499077197,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057335568249798033,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15934809415566475,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0097302890092453853,
                                  0,
                                  0,
                                  0.49530937599044222,
                                  0,
                                  0,
                                  0.44333983988735787,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12882980658474516,
                                  0,
                                  0,
                                  0.34015671687735777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37085205661542964,
                                  0,
                                  -0.40024216223468401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19244765805342234,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12832260412739965,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31337635498101241,
                                  0,
                                  0,
                                  0.55717211770866737,
                                  0,
                                  -0.47767787803398465,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0032109217608365104,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11172484614809657,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17383174580746796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14776002956837517,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54647514378050166,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1178668357246152,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.041880202615267113,
                                  0.052702732830648982,
                                  0,
                                  0,
                                  0,
                                  0.045412186601068799,
                                  -0.27453137483845302,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21310628816156132,
                                  0,
                                  0,
                                  0.42604441967070278,
                                  0,
                                  0,
                                  0,
                                  -0.51550018936809905,
                                  0,
                                  0.060554310524158064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040698020486023466,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22164592152108931,
                                  -0.48929972796661347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24295473100939888,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24204599005182073,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55845496611874157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21260363560880435,
                                  -0.22076922477665639,
                                  0,
                                  0,
                                  0,
                                  -0.3189017757831985,
                                  -0.013005210820066594,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019281863961801385,
                                  0,
                                  0,
                                  0.24012994320017136,
                                  0,
                                  0,
                                  0,
                                  0.072304217281180222,
                                  0,
                                  -0.28184634518559032,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069369611030882419,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36043155186710246,
                                  -0.036850304509486453,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39756229144558025,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23555255710883644,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34413352848539785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31069016296410013,
                                  0,
                                  0,
                                  0,
                                  0.16345806561189691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45365642771850079,
                                  -0.493307637921858,
                                  0,
                                  -0.11935561094537442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58835026261986079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61672772810233267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.91868530876098298,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.83406410860741376,
                                  0,
                                  0.39545244693866261,
                                  0,
                                  0,
                                  -0.16105838240063919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12133650523697974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.63949126176534499,
                                  0,
                                  0,
                                  0,
                                  0.074527092110067097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41997136682228697,
                                  -0.02506499851124664,
                                  0,
                                  0.2565076347447664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61650137886222989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35381750048843386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34639091338909,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.2122822202243506,
                                  0,
                                  0.060446275506522991,
                                  0,
                                  0,
                                  0.0082036088047754592,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14954376729511465,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35837732605636319,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12358652356094482,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39024767227029267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43171140226161209,
                                  0,
                                  0,
                                  0.62898737916232539,
                                  -1.1200645058767433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17962602841398145,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53590967431017889,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18513463937873781,
                                  0,
                                  0,
                                  0,
                                  0.06948391818733185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72446356654578314,
                                  0.29110168946151493,
                                  0,
                                  -0.62714059723492555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38355882547439063,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53556776405218876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16381304871093266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10499834215903986,
                                  0,
                                  -0.52291299534843172,
                                  0,
                                  0,
                                  0.56794949923789795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26518479078525148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.88784723575636071,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23619828679476049,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.073758208533553124,
                                  0,
                                  0.22713532251660354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16906789745658768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064038398485674747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30120504590336777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078026452567144522,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.031192600895832742,
                                  0,
                                  0.0053993966675102666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62753930035652428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033659816059406981,
                                  0,
                                  -0.23510895664110465,
                                  0,
                                  0,
                                  0.13496366858697037,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65548026260603443,
                                  0,
                                  0,
                                  0,
                                  0.37274228404690285,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.011595587756793604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24599747946777095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25662491422609296,
                                  0,
                                  -0.68823002168767222,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51078083633767302,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.210813701570499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38003645487284599,
                                  0.013925224958967614,
                                  0,
                                  0,
                                  0,
                                  0.13431507767363282,
                                  0.46238052663829349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.071105912443744757,
                                  0,
                                  0,
                                  -0.10346375250219475,
                                  0,
                                  0,
                                  0,
                                  -0.18166822182520428,
                                  0,
                                  0.25241722660146676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17599634013276946,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47829833595583882,
                                  -0.43016783979629269,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068033243997188131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13116467599261347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.72524989002778106,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1603222263093321,
                                  0,
                                  0,
                                  0,
                                  0.56494031052653881,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14189728721274342,
                                  1.0764973622372673,
                                  0,
                                  -0.36896260657144297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12167302511705431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16237743554023132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46958776613571401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27767672348679129,
                                  0,
                                  0.22586568843364413,
                                  0,
                                  0,
                                  -0.30337877807448332,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1602895354983617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48344545737442379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23569954831274068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31641899164023096,
                                  0,
                                  0,
                                  -0.053881747021667946,
                                  0,
                                  0,
                                  -0.25798798553806884,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036876473492018252,
                                  0,
                                  0,
                                  -0.36146455215716849,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2001985599023639,
                                  0,
                                  -0.55859773555460046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1499055936821278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094087079505717014,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13757504181941482,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24007866866168109,
                                  -0.74512028597668767,
                                  0,
                                  0,
                                  0,
                                  0.21454497373872447,
                                  -0.095799093192707296,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088045751548580062,
                                  0,
                                  0,
                                  -0.19190640885942795,
                                  0,
                                  0,
                                  0,
                                  0.10276556030638395,
                                  0,
                                  -0.097118107990354585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11188940096347792,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16423694576708037,
                                  -0.1809309593797554,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40471765516112285,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11147139480195289,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12177239661695463,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21798842084170675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61611320656203683,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068383961697872614,
                                  0,
                                  0,
                                  0,
                                  -0.54931357511970458,
                                  0,
                                  0,
                                  -0.59639385769866637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14093571891144227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50015115639310148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38735960167981248,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31037426836482512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21637560383387916,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36059205528385441,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41240861938770151,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1038438999739236,
                                  0,
                                  0,
                                  -0.3485932810571683,
                                  0,
                                  0,
                                  -0.012662055305489407,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40162551234559746,
                                  0,
                                  0,
                                  -0.092599206719629748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37767109894415846,
                                  0,
                                  -0.13796752091538239,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42304033166859112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10050699630571688,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59828959630744361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10815092366879346,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25436186661646831,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31527393843502605,
                                  0,
                                  -0.1461749475454483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66699940474111485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45712535945960125,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.047521051817614075,
                                  0.22832791421711787,
                                  0,
                                  0,
                                  0,
                                  0.20724289321630773,
                                  0.44059534090789659,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12052221985754641,
                                  0,
                                  0,
                                  0.079914566990595307,
                                  0,
                                  0,
                                  0,
                                  0.033964799073624208,
                                  0,
                                  -0.23470760541245869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44824266013785996,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33653951959847772,
                                  0.064010481510717102,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20752585197505555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24712908576781548,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45636404539579178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19788610958851627,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049334003184722683,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27045014847046844,
                                  0,
                                  0,
                                  -0.4003313607185276,
                                  0,
                                  0,
                                  -0.086940071373510813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12845644380959001,
                                  0,
                                  0,
                                  -0.07323154226661055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038430962911122267,
                                  0,
                                  -0.2564533705912137,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14814817704691288,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.63096352932610389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.03547519107123584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11558998920264783,
                                  -0.088992981889771561,
                                  0,
                                  0,
                                  0,
                                  -0.19076624242335394,
                                  0.18170572212453895,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68675778317825809,
                                  0,
                                  0,
                                  -0.4239170489501341,
                                  0,
                                  0,
                                  0,
                                  -0.32197610867509618,
                                  0,
                                  -0.1825791002822095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18468472560854529,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15463668177283926,
                                  0.076556291031299725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23554395279051368,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.018535250428316524,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4980451989508225,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49214640568715595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.78423986871823026,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42299510893061443,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66464882717302876,
                                  0,
                                  0,
                                  -0.13799660085707335,
                                  0.083620473892623254,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48437392058793138,
                                  0,
                                  0,
                                  0,
                                  -0.62394376508667204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.014356910825842483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20769377691042351,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063346979529080513,
                                  0,
                                  0.031524729726800302,
                                  0.30336773377940585,
                                  0.086633263036766467,
                                  0.59953282680840003,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.83256694922347041,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45943981551441049,
                                  0,
                                  0,
                                  0,
                                  -0.2679401570177069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45016497252052418,
                                  0,
                                  0.48821251896262796,
                                  0,
                                  0.37526710954045056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32793526142164153,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2193019690405057,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16131149605595521,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55967240636118731,
                                  0,
                                  0.22787797058219192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43594272998330125,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31558488114900463,
                                  0,
                                  0.15587343107249305,
                                  0,
                                  0,
                                  0.21875128107121949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30231376001259652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044661564478980023,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30147093881037312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22623207253962294,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37489891757776705,
                                  0,
                                  -0.71280063699142993,
                                  -0.15556438862074087,
                                  -0.42992803331591201,
                                  -0.35738779318734487,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68333102963355197,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40069025599570174,
                                  0,
                                  0,
                                  0,
                                  0.41028661095326313,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1970889228896531,
                                  0,
                                  -0.19767776469303622,
                                  0,
                                  -0.65206490321397581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10967222223107202,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12004697943300142,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.82792827195187679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26601817404665978,
                                  0,
                                  0.42183214383862383,
                                  -0.57719909960622406,
                                  -0.41646000687255069,
                                  -0.0096432474679738513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11071061883717423,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10312800135037099,
                                  0,
                                  0,
                                  0,
                                  0.036149788447577061,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.80060090839292053,
                                  0,
                                  0.33822139464685747,
                                  0,
                                  0.24154343378732193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40134614547682501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052539168539258024,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17259903026193513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10336335771960573,
                                  0,
                                  0.27679418160448221,
                                  0.54169026249367636,
                                  -0.087037468175644228,
                                  0.53758837911549218,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35164891585695057,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1471873878726612,
                                  0,
                                  0,
                                  0,
                                  0.25212082562506455,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1628808480551327,
                                  0,
                                  0.6946332090336782,
                                  0,
                                  -0.48275131592310588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37717067338671739,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.89992717506600384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52149598031655109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.120542495987982,
                                  0,
                                  0.31108063269504338,
                                  -0.673095402481522,
                                  0.06380873733788206,
                                  0.11640424971289678,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17188269671196921,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56614067930056522,
                                  0,
                                  0,
                                  0,
                                  0.12285756238012088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043614031306308948,
                                  0,
                                  -0.045895922749196238,
                                  0,
                                  0.20200288502496569,
                                  0,
                                  0,
                                  0,
                                  0.22977858304902735,
                                  0,
                                  0,
                                  0.39525314532052958,
                                  0,
                                  0.27091021200331933,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068066258004117197,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60612755769425752,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22984872625460934,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53921417645662484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044479368147216557,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19072242027680908,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.3642199884588051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27021782452916543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41991404623537076,
                                  0,
                                  0,
                                  0,
                                  0.30113959506874205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46017819619368616,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49877267207679671,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046684946690239842,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14259698349952382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03103864886788759,
                                  0,
                                  0,
                                  0.017601071010681018,
                                  0,
                                  0,
                                  -0.14637196067550393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42442093962652394,
                                  0,
                                  0,
                                  0.033971351461804911,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13118548349834736,
                                  0,
                                  -0.0014000931661416506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56999757966497533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42733882629990355,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5208637068798232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.0794252843445074,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59910781564417115,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.73538075895528787,
                                  0,
                                  0,
                                  0,
                                  0.02499603357485386,
                                  0,
                                  0,
                                  -0.27071170616508722,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0042746631234276133,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.92821634916073337,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29797771835336445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13918289308133797,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44115193328357383,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38465786550642095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3210218175224564,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45156014299776187,
                                  0,
                                  -0.17917653250227883,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.031122756838818266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48761388988533283,
                                  0,
                                  -0.042235892542223881,
                                  0,
                                  0,
                                  0.17079140602194504,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22060823149408038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28724840861590095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036217871432841969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.013455504513126368,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46815180548813323,
                                  0,
                                  0,
                                  -0.092491720756316398,
                                  0,
                                  0,
                                  -0.3100072991902042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13748501961066331,
                                  0,
                                  0,
                                  0.11900980120901114,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58832377705662042,
                                  0,
                                  -0.075772141623189931,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43494238721426587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13440082700715186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25853037441864846,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.230873313791467,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50415806441790023,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47387115265323448,
                                  0,
                                  -0.1291750364169347,
                                  0.36183018427869368,
                                  -0.57276100139789698,
                                  -0.2727352747680013,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28554520620564117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49945552954139028,
                                  0,
                                  0,
                                  0,
                                  -0.89786466607347948,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072418039204681373,
                                  0,
                                  0.16484272924762311,
                                  0,
                                  -0.34485606131285995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39194852041022221,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19497922138429813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14626768788251887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36909204641525206,
                                  0,
                                  0,
                                  0,
                                  0.74505254224153017,
                                  0,
                                  0,
                                  -0.47727943402822348,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.7634779840196193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45973745935566734,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26359218544385837,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10581402694418662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38923503958514966,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20464067816043841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.5696563241918835,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31706089302514667,
                                  0,
                                  0,
                                  0,
                                  -0.40411169604094915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38004586360433451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30454112196421007,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2218037284607261,
                                  -0.11343543808245168,
                                  0,
                                  0,
                                  0,
                                  0.36238538775699974,
                                  -0.20746774524629846,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08096272323631197,
                                  0,
                                  0,
                                  0.17960430598944546,
                                  0,
                                  0,
                                  0,
                                  0.025689554625744911,
                                  0,
                                  -0.14250685382962369,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47042513443099149,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12154755447940535,
                                  -0.1159002696440825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59881166020483956,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054419297947683451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14426891565944031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.042103549123543138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40886753001079035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.75417897235963216,
                                  0,
                                  0,
                                  0,
                                  -0.1500428527353791,
                                  0,
                                  0,
                                  -0.091315261918497231,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.82797843375271374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48468894292808795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0058868183621295089,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17772819475285689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31010284499069263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32737820206418994,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13474583070291662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38799405044003565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.81431172763231885,
                                  0,
                                  0,
                                  -0.35855220428300744,
                                  -0.073598688942123305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68144480691198817,
                                  0.13949154039516234,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.57687130663071118,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20608084491566325,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.2116815169627708,
                                  0,
                                  0,
                                  0,
                                  0.21673195372536352,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.76233981549031116,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057675704940216094,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.66466692060122157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34962540674317705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24772787266648139,
                                  0,
                                  0.097765218937107046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32907278743154722,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21722849841608549,
                                  0,
                                  0.42727034233417227,
                                  0,
                                  0,
                                  0.04993154775173668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14558884193784932,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27467702418773504,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0030807811943899255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49361847312894624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.088480340249972061,
                                  0,
                                  0,
                                  -0.24754807476388757,
                                  0,
                                  0,
                                  0.61551037835622702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044303849305664264,
                                  0,
                                  0,
                                  -0.35680752275525568,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053374587796791002,
                                  0,
                                  -0.29739142050899842,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097835206268462718,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052776204900444393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073115751488361636,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46876865337260221,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12259411430938648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082661421183350334,
                                  0,
                                  0.053775286209461093,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27809395299424305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085652398894677365,
                                  0,
                                  0.769124458872398,
                                  0,
                                  0,
                                  -0.20627191203260675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17715223007216868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.010648603269205699,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049391712989826586,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.065705036849567452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21068603572507089,
                                  0,
                                  0,
                                  -0.3857462339343451,
                                  0,
                                  0,
                                  -0.013426605132077309,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61083544889625163,
                                  0,
                                  0,
                                  0.2878272937335194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.011131880940130186,
                                  0,
                                  -0.2246147674388641,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019654629776903802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54114172270921745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26923738642267292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16244427172642384,
                                  0,
                                  0,
                                  0,
                                  -0.57949699280452038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35284312176410282,
                                  0.3218873027102514,
                                  0,
                                  0.066848318419417685,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15840111660053444,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.77494295924411816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.055244553080039754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.036962219613627341,
                                  0,
                                  -0.097074696236397973,
                                  0,
                                  0,
                                  1.174032455657519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0085500060345272,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34499056231958675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053356144068123293,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40271759469779156,
                                  0,
                                  0,
                                  0,
                                  1.3909291993089634,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10865154845959774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11053981208889693,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49069784490998269,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20007777872740451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23721570355704469,
                                  0,
                                  0.058147704862059918,
                                  -0.28935952814781563,
                                  -0.36668200575724624,
                                  0.16621448337721251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22240327267679874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68281264311881229,
                                  0,
                                  0,
                                  0,
                                  -0.58766211445572569,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44677469943764109,
                                  0,
                                  0.53121716058454949,
                                  0,
                                  -0.029150792874960613,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23036493925200197,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14844092604923875,
                                  0.32062513242317903,
                                  0,
                                  0,
                                  0,
                                  0.49629676752520774,
                                  -0.24739360408852368,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.083229701038335602,
                                  0,
                                  0,
                                  -0.46562247754787867,
                                  0,
                                  0,
                                  0,
                                  0.2552998355345063,
                                  0,
                                  -0.090272556815943872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.090330170821617678,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068739482706880212,
                                  -0.19755260970883978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026372179667935331,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40609966377515916,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14818030160401224,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49656145164137522,
                                  0.081713009031336492,
                                  0,
                                  0,
                                  0,
                                  0.3696513856207696,
                                  0.29997704743319908,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30576559448958535,
                                  0,
                                  0,
                                  0.083210030113855651,
                                  0,
                                  0,
                                  0,
                                  -0.40545769922527164,
                                  0,
                                  -0.17428376760866376,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32756841136002413,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26688121256590436,
                                  0.090940258847343608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11372841821008886,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056971188419215571,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.052111976168977801,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10357453486004567,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4632317461636638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13147740797639865,
                                  0,
                                  0,
                                  0,
                                  -0.26384933118788439,
                                  0,
                                  0,
                                  0.50682128400604665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72481421001361679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075788918354656912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56526525835819619,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56983352405665022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45143954631143535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47613552745752075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63579455616662239,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49114583930124456,
                                  0,
                                  0.60955165037599679,
                                  -0.29258117378475035,
                                  -0.56052990179729356,
                                  -0.13222388408271099,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097767138471670706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31081425095662585,
                                  0,
                                  0,
                                  0,
                                  0.092962729502616068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.088349575953397999,
                                  0,
                                  0.058044369110375402,
                                  0,
                                  -0.36057052428942288,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23766084817186883,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.87181366870777299,
                                  0,
                                  0,
                                  0,
                                  0.23926545603876098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59738110989769599,
                                  -0.045407460235333028,
                                  0,
                                  -0.31114745496365548,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25425852227227813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.014733553163529992,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32848132404488201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26677007115688717,
                                  0,
                                  0.73151405552583038,
                                  0,
                                  0,
                                  0.25385545698462969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27970234402287808,
                                  0,
                                  0,
                                  0.03757588126878654,
                                  0,
                                  0.50543612038914532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29379901740351461,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16688435867490303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25426099513816808,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.67420818171292762,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17752577944074255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2319997932443863,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22050956456538717,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70664991418649303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12764252091247322,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34613841142647117,
                                  0,
                                  0,
                                  0.84495264911862789,
                                  0.68400554615310349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2456280643940956,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45590348634877204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58362511469042688,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10439803352896357,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67950069571120442,
                                  0,
                                  0,
                                  0,
                                  0.45548359890481238,
                                  0,
                                  0,
                                  -0.0080437126081499902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.001622687452777799,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4449293118555413,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17381829536099297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022649653448515959,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2751174538948799,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015036801569174474,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.047464591717807175,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44437837921419965,
                                  0,
                                  0.23189150778133971,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18579526623422779,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11068022842667249,
                                  0,
                                  0.25524503117763858,
                                  0,
                                  0,
                                  0.73296536095132425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1463807985525464,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043887979841968211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.75230147360489208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.77502688304750533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.09448927507107166,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15463007255100997,
                                  0,
                                  0,
                                  0.24662951295058599,
                                  -0.25757646232470488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31186096513786482,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.1000399571679331,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40262426709448201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5941299496805349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072998058162120849,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30906022178307607,
                                  0,
                                  0,
                                  0.54012281970006448,
                                  0.20887259405629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.039932359489408514,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45620223272343674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23528037414816183,
                                  0.086301143990270057,
                                  0,
                                  0,
                                  0,
                                  -0.11485219929917072,
                                  -0.25482582957999855,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.094522028545164533,
                                  0,
                                  0,
                                  -0.27902753025731064,
                                  0,
                                  0,
                                  0,
                                  -0.17548213678435082,
                                  0,
                                  0.58178168409303121,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13551253867253382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0090660022128281892,
                                  -0.085702096006509118,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22895239812109394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34158889713018897,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.6897802624244751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61798452940905646,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60052114907829879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0056461847870090103,
                                  0,
                                  0,
                                  0,
                                  0.56007953686186562,
                                  0,
                                  0,
                                  -0.49063414947150658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33876491237283002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11429211665171389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18325305073776055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.095951586327141319,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33192666908535157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45811652827153226,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037420773733687275,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.72501091641284199,
                                  0,
                                  0,
                                  0.1269747549475797,
                                  0,
                                  0,
                                  -0.12896206021476581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10470245520640618,
                                  0,
                                  0,
                                  -0.08807649826943309,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19729766665974088,
                                  0,
                                  -0.11793676666166654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21700284583401055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038900248163606474,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46031475987009779,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083898069393913727,
                                  0,
                                  0,
                                  0,
                                  0.089223392098504203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.72610771867826573,
                                  0.21592630498013177,
                                  0,
                                  -0.04082077800300421,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.85564204675043887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.73990394491788747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.564201183826187,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15449012501888856,
                                  0,
                                  -0.39519045540245284,
                                  0,
                                  0,
                                  0.40576229675892422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40272525344020932,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12342689299669241,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13471192221056394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27846784794554225,
                                  0,
                                  0.18488477582802043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35292124475182662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62952377162427187,
                                  0,
                                  -0.09990971339136312,
                                  0,
                                  0,
                                  0.23719433722652891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32497301301668241,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097718795002083206,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22494859150802321,
                                  0,
                                  0,
                                  0,
                                  -0.51257033112610184,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11108995360517843,
                                  0.60262833795093351,
                                  0,
                                  -0.73025894656434831,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67180390108186483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19148931769673724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.79757550895037088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17263356860488946,
                                  0,
                                  0.65707331806824421,
                                  0,
                                  0,
                                  -0.017140049237209361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57702926215475381,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035459603948167655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40519112096013327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18212254181701112,
                                  0,
                                  0.05800390146712002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17983302010992516,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27376018037365824,
                                  0,
                                  0.085043896355489562,
                                  0,
                                  0,
                                  -0.43411053284884787,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40261390842722483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19807771180014389,
                                  0,
                                  0,
                                  -0.46775728363347607,
                                  0,
                                  -0.17530866896109382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70032763082119709,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19117291933296826,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18684776024705127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27751805508031707,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26888841979549083,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.083504552035313595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.64299383898603735,
                                  0,
                                  0,
                                  0,
                                  1.20058893478974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20276331871753092,
                                  -0.36555601980460284,
                                  0,
                                  -0.42311004946905661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53509104750726222,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25163714305186724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11872676867753304,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21392604892520231,
                                  0,
                                  0.17417040331634992,
                                  0,
                                  0,
                                  0.46322433051182499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10280417258218655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12606148846246354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21192945772445218,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09532493859293989,
                                  0,
                                  -0.86543472414811695,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098317973295735772,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20487221586325774,
                                  0,
                                  0.22705193733234968,
                                  0,
                                  0,
                                  0.16957124428743364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19650843405460772,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0037435231356942964,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47083995911296095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082625444598065756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.103886939395715,
                                  0,
                                  0,
                                  -0.43894078806703563,
                                  0,
                                  0,
                                  0.14456594271403375,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34825169610961637,
                                  0,
                                  0,
                                  0.62215184462787643,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097401863898111382,
                                  0,
                                  0.068379330996356,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.096177021992090606,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12386643721604841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0045585849136464962,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22673387875901937,
                                  -0.039883149139058383,
                                  0,
                                  0,
                                  0,
                                  0.21483906283646814,
                                  -0.21637495113787494,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1473952268645104,
                                  0,
                                  0,
                                  0.017602429308177028,
                                  0,
                                  0,
                                  0,
                                  -0.37482938512989594,
                                  0,
                                  0.15828126498339998,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31759071450424142,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27172217778701035,
                                  0.66186101181203627,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15274359154073827,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1741658025130676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0089289083435779223,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044263734721068065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19634918441666233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60162390230087592,
                                  0,
                                  -0.75458924445632192,
                                  -0.38179773530444155,
                                  0.59377368009897957,
                                  0.21639563187117516,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29023236382317885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17276945548971778,
                                  0,
                                  0,
                                  0,
                                  -0.23812460946991437,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53749644958959764,
                                  0,
                                  0.28562476139812176,
                                  0,
                                  0.24865728489627401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20901770368616268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30587405080183389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.047667519345097872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23943649922218491,
                                  0,
                                  0,
                                  0,
                                  0.1270804066797816,
                                  0,
                                  0,
                                  -0.95983094408727421,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19799358262238831,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33557251760200596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069071602532734852,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.92234220585527915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35483472339115613,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057648746584603505,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17253112521854846,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59585972343430749,
                                  0,
                                  -0.20894201236838356,
                                  0.048034106942474238,
                                  -0.19518903828842632,
                                  0.92051661653716899,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.71369107715571567,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30449564859800271,
                                  0,
                                  0,
                                  0,
                                  -0.22926073858835386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092892676658245396,
                                  0,
                                  -0.70152558525790543,
                                  0,
                                  0.36282583765985887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32196491899051122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13814898397490158,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.70574364729837136,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31050490593074775,
                                  0,
                                  -0.2513775283072901,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1687452684447954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28550619399204286,
                                  0,
                                  -0.10302416888937554,
                                  0,
                                  0,
                                  0.22139553762324593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22350990858128897,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61786682617562205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1980553981514892,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13388307131196903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40863244152848449,
                                  0,
                                  -0.25756037180792368,
                                  -0.51613277455026141,
                                  0.29988713554027002,
                                  0.089066063363916842,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074940288925156792,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044829465617915981,
                                  0,
                                  0,
                                  0,
                                  0.2322681127167282,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23154599230736314,
                                  0,
                                  0.20236517876676779,
                                  0,
                                  -0.75953504963897744,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67717092038771065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.77845983529155405,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54006530069536873,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65090139452938522,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10987449841049948,
                                  0,
                                  0,
                                  0.41627076703220967,
                                  -0.12350532888764094,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60287855310668825};

const double rot_11_30[900] = {-0.54595025199359593,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.055905569040092334,
                               0,
                               -0.025657375845883346,
                               0,
                               0.62160164262806705,
                               0.36955861981454946,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41855772926406409,
                               0,
                               0,
                               0,
                               0.0013566279162334285,
                               0,
                               0,
                               0.56905098513393115,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.03278825416739567,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.86829141837103219,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24472137174653852,
                               0.42947362282437612,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.81452460086671485,
                               0.14105661541724229,
                               0,
                               0,
                               0,
                               -0.46384042953616111,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2721568182372634,
                               0,
                               -0.76216695119778133,
                               0,
                               -0.46511624242092808,
                               0.035904028036266467,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25152078697114122,
                               0.35395590301780694,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.055077896104198353,
                               -0.60323964486605353,
                               0,
                               0,
                               0,
                               -0.83263946550259227,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22842741897927579,
                               0,
                               0.63273857446308901,
                               0,
                               -0.2429907126443886,
                               0.30200853113126175,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.265981302695598,
                               0,
                               0,
                               0,
                               0,
                               -0.57491029169521224,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1525500833346847,
                               0.9533992019880706,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4240884558187471,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.64026839368243904,
                               0,
                               0.20610274705161841,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67432830705638203,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30472836430427719,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35473266197955944,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.93496777405688969,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.71837812743780671,
                               0,
                               -0.11960557028265789,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67991075250871014,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.085724805041190816,
                               0,
                               -0.47338796637574748,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.8393852387566119,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10223071465910766,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.76853994582556284,
                               0,
                               0,
                               0,
                               0,
                               0.038480463243422885,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19967178388294698,
                               0.055415912300689998,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.91393477463333683,
                               0,
                               0,
                               0,
                               0,
                               0.049837042519848468,
                               -0.35083293199244381,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10463706510999299,
                               0.29497928118535549,
                               0,
                               0,
                               0,
                               0.36224571887296975,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.098634694396137465,
                               0,
                               0.34959709621830726,
                               0,
                               -0.63895329066128193,
                               0.73546435140566424,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.08852396479821506,
                               0.18445103819727632,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.097496800106449968,
                               0.43491083333535296,
                               0,
                               0,
                               0,
                               0.10561333908774612,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.85719806920629338,
                               0,
                               0.0045265215024896804,
                               0,
                               0.67409588073386684,
                               0.9143800103931834,
                               0,
                               0,
                               0,
                               -0.051753675773662716,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21193593644345685,
                               0,
                               -0.90586301201163399,
                               0,
                               -0.03283809073506444,
                               0.16303754665926168,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1890622908387749,
                               0,
                               0,
                               0,
                               -0.26155838299691253,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17667089804810182,
                               0,
                               0.93783137147872031,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.015926188474944758,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29833884925346366,
                               -0.21286995542904019,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33244767751366672,
                               0,
                               0.18802627178480708,
                               0,
                               0.48622742823189857,
                               -0.27251016874194323,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.70301660936113153,
                               0,
                               0,
                               0,
                               -0.062448281319191168,
                               0,
                               0,
                               0,
                               0.53225074531620764,
                               0.60571874016939753,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.74920081983835263,
                               0.60970426940511735,
                               0,
                               0,
                               0,
                               -0.10242753655583711,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.77464936578420185,
                               0,
                               0.56181154986290271,
                               0,
                               0.42208405858093428,
                               0.17116961566851302,
                               0,
                               0,
                               0,
                               0.72203482757873516,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21047149915598284,
                               0,
                               -0.1844962874207077,
                               0,
                               0.60162449791850336,
                               -0.048577875400199422,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.051196178494798558,
                               0,
                               0,
                               0,
                               0.18274485100214269,
                               0,
                               -0.16162138601647982,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.34617448159949282,
                               0,
                               -0.11564299844815615,
                               0,
                               -0.11142059870677992,
                               0.37316682143108315,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43044967490660585,
                               0,
                               0,
                               0,
                               0.7097277673312461,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.024727210304025839,
                               0,
                               0,
                               0,
                               0,
                               -1.3786155667570403,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0635019248856792,
                               -0.033546695346880484,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.43020513365785829,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.031375728493165583,
                               0,
                               0,
                               0,
                               0,
                               0.068144527629231733,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.007051467303117,
                               1.3061616173483228,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.54203433916181321,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.93496777405688991,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35473266197955983,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17842339848235833,
                               0.45924994184695983,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.5962506116362557,
                               -0.21957236941833502,
                               0,
                               0,
                               0,
                               0.72804677912400906,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38353017555696745,
                               0,
                               -0.52556361749924396,
                               0,
                               0.21164843966908203,
                               0.84760954813463063,
                               0,
                               0,
                               0,
                               0,
                               -0.72152086054038711,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.64115088787617214,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.63327308097793544,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.87697373973178827,
                               -0.29963527416214419,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.38203557418733719,
                               0.33821379965282294,
                               0,
                               0,
                               0,
                               -0.59832177074740056,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20240655732188995,
                               0,
                               -0.30612236957110123,
                               0,
                               -0.27516259836750195,
                               0.30272863962725427,
                               0,
                               0,
                               0,
                               0.27346559214052085,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.75366297233594903,
                               0,
                               0.17684098065730275,
                               0,
                               -0.041810380486817615,
                               0.51951734092229351,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.070876757975474186,
                               0,
                               0,
                               0,
                               0.22195961648147544,
                               0,
                               0,
                               0,
                               -0.19071993464090389,
                               -0.7365880601537399,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30515023999444696,
                               0.21557401670287865,
                               0,
                               0,
                               0,
                               -0.033357578940188537,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.89359763665589831,
                               0,
                               -0.12571888172557177,
                               0,
                               0.87536852976745794,
                               0.59179383034485133,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67700702749676922,
                               0.2882712029343199,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.186491078987012,
                               0.94224821066424402,
                               0,
                               0,
                               0,
                               -0.62334417786358665,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30020670216113732,
                               0,
                               0.055632552940499319,
                               0,
                               -0.013966754956458022,
                               -0.15654326362970733,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.9551944131972635,
                               0,
                               0,
                               0,
                               0,
                               0.42430587220032678,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3607986097772008,
                               0.14738337768103155,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.70621022336032357,
                               0,
                               0,
                               0.17806478239218076,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33059547542579237,
                               0,
                               0.25439164304410378,
                               0,
                               0.0011186981887502112,
                               0.59251315489024114,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31921942027028238,
                               0,
                               0,
                               0,
                               -0.58421770631128789,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20682515285413577,
                               0,
                               0.25236577399774307,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28766136244927687,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.90043645684479501};

const double rot_11_2[4] = {0.33891212050501374, -0.94081803478398252, 0.94081803478398252, 0.33891212050501418};

const double rot_10_50[2500] = {-0.38467935041588525,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69740688031457443,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.86142150039020882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52796476459554553,
                                0.39736171835256123,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36090697314110975,
                                0,
                                0.16199231291495855,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11317781737930455,
                                0,
                                0,
                                0,
                                0,
                                0.81242797514656162,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59274543268371238,
                                0,
                                0,
                                0,
                                -0.20859487999721216,
                                -0.91022320240216892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5379652264317617,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22699139213493014,
                                0,
                                0,
                                0,
                                0,
                                -0.17349584500395163,
                                0.3125836602487021,
                                0,
                                0,
                                0,
                                0,
                                -0.24633412081251616,
                                0,
                                -0.04764559221379587,
                                0,
                                0,
                                0.38447235861598555,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39705125497709393,
                                0.1223508834905586,
                                0,
                                0,
                                0,
                                0,
                                0.079095251896492635,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.053852376253580962,
                                0,
                                0,
                                0,
                                0,
                                -0.36450922616950815,
                                0,
                                -0.27244015605687588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68067232630300156,
                                0,
                                0,
                                0,
                                0,
                                -0.15869263816665874,
                                0,
                                -0.24264106547051556,
                                0,
                                0,
                                0.72673017006619678,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50490162869755006,
                                0,
                                0,
                                0,
                                0.3645264945009562,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.242010397504629,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5052873976982919,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25922396578971674,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.051744986780915547,
                                0,
                                0,
                                0,
                                0,
                                -0.16844129906987573,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37463921615400819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12429914127687025,
                                0,
                                -0.52970149780076081,
                                0,
                                0,
                                0.0027679059130069072,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62422973950683092,
                                0,
                                0,
                                0,
                                0.56062074321020228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53288223126027978,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17463620303012095,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17381996496630228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.98761651051649646,
                                -0.096776594095145593,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26487081099093829,
                                0,
                                -1.1334943956916363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32300845187316624,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29109327681236524,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46678344579384345,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35360777786219211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12269813200678834,
                                -0.63108617805134015,
                                0,
                                0,
                                0,
                                0.39876667693956647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.96137493680953923,
                                0,
                                -0.11957523866251896,
                                0,
                                0,
                                0.116291039062524,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17361965735535023,
                                0,
                                0,
                                0,
                                -0.13338891253329976,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16205408957724443,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0664025047312391,
                                0,
                                0,
                                0,
                                0.12000905738226568,
                                -0.50422335744721969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58396763000091412,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44713096236990202,
                                0,
                                0,
                                0,
                                0,
                                0.70296654229462152,
                                0.17915425946855984,
                                0,
                                0,
                                0,
                                0,
                                -0.20842921105153489,
                                0,
                                0.6669853070034778,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.041088526946822218,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.98620015722246146,
                                0,
                                0,
                                0,
                                0,
                                0.16037762577034734,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61555908692639727,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56421960524015546,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0778364696820748,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46994058312026421,
                                0,
                                0,
                                0,
                                0,
                                0.55969213135000118,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15200427208237538,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61149477745332226,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20779050617775807,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.4069530563144548,
                                0,
                                0,
                                0,
                                0,
                                -0.33751290693004726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68166436032564448,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48122799119102633,
                                0,
                                0,
                                0,
                                -0.21969988484644898,
                                -0.41224496689289403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13929922603659678,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12612049873493827,
                                0,
                                0,
                                0,
                                0,
                                0.6490602027147172,
                                0.24243782714782366,
                                0,
                                0,
                                0,
                                0,
                                0.5442294050786789,
                                0,
                                -0.86047942353051254,
                                0,
                                -0.097608760190708022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45090111874271049,
                                0,
                                0,
                                0,
                                -0.038128293300308896,
                                -0.47407264483855027,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71217990560334599,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32989775662009324,
                                0,
                                0,
                                0,
                                0,
                                0.15007057804426799,
                                0.61903400816641629,
                                0,
                                0,
                                0,
                                0,
                                0.71903801849729265,
                                0,
                                0.61068049161297877,
                                0.59478004317978339,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25023126701604598,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0057475690334337,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23658573968015872,
                                -0.50034559494104591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1901958400420214,
                                0,
                                -0.34130717060751947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60497019128229745,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47761890231172616,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67540025948397575,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4613756647879742,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27656548328001102,
                                -0.026682335145334357,
                                0,
                                0,
                                0,
                                -0.16014604595262372,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47380126472638928,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42619712868536996,
                                -0.73616256917276157,
                                0,
                                0,
                                0,
                                0,
                                0.037615466525838331,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16104613031595286,
                                0,
                                0,
                                0,
                                0,
                                -0.09995710133123932,
                                0,
                                0.060128375347687564,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10476362800506259,
                                0,
                                0,
                                0,
                                0.2462292813644249,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18664972490875187,
                                -0.079865086850045633,
                                0,
                                0,
                                0,
                                0,
                                -0.019045974584389419,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61533096591215408,
                                0,
                                0,
                                0,
                                0,
                                0.29359676931786061,
                                0,
                                0.57263882616199024,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32410701034127798,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.031985301182371556,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35983720090667964,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25803649449257587,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.9190417311948732,
                                0,
                                0,
                                0,
                                0,
                                -0.91878113415892448,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1305220696644704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55367888221123429,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32373388214136334,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53761712907760839,
                                0,
                                0,
                                0,
                                0,
                                0.87802102391262893,
                                0,
                                0,
                                0,
                                0,
                                0.38216781155495066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77557981799932718,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11224693627181895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2798066827083126,
                                0.22939153744468288,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36389045594801789,
                                0,
                                0.29459103855456364,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31108132158862384,
                                0,
                                0,
                                0,
                                0.054944041219762214,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50137455262903652,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72511307187850071,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16378694042395422,
                                0.62056421755490798,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0439063415112175,
                                0,
                                -0.13188943892376959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0637630169366599,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33850381347675756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0020370575996015217,
                                -0.17247960706089599,
                                0,
                                0,
                                0,
                                0,
                                0.38742406516402994,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54139217896985659,
                                0,
                                0,
                                0,
                                0,
                                -0.073890887475086708,
                                0,
                                -0.43956284031276088,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.462367334759407,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58946875712090829,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52592276992017251,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.018618933491032663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25467389175161048,
                                0.54346134910399901,
                                0,
                                0,
                                0,
                                -0.12400052686837505,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1341885870946129,
                                0,
                                0.35916732011186259,
                                0,
                                0,
                                -0.4603085609495623,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36152797514294099,
                                0,
                                0,
                                0,
                                0.71442691100125932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90991426655994645,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.029375366719580104,
                                0,
                                0,
                                0,
                                0,
                                0.41375489766377949,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.065914184046237403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3655737019998021,
                                0,
                                0,
                                0,
                                -0.31958706138216464,
                                -0.48063857152647227,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56716170703197766,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.089258805107755385,
                                0,
                                0,
                                0,
                                0,
                                -0.5677091916240532,
                                -1.0817728743866841,
                                0,
                                0,
                                0,
                                0,
                                0.10775689714505308,
                                0,
                                -0.24039435584663568,
                                0,
                                0,
                                0,
                                0,
                                0.28499415423880309,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77495441902713158,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6340808471373528,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52382728300631198,
                                0,
                                0,
                                0,
                                0,
                                0.35847517112054206,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46360445617706941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1308358667855587,
                                0,
                                0.71919554714794398,
                                0,
                                0,
                                0.4964353145805771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44109558535838461,
                                0,
                                0,
                                0,
                                0.15692802152475907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58933864448855844,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30850459649243622,
                                -0.36955924716286737,
                                0,
                                0,
                                0,
                                0,
                                -0.04025408464678315,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42815728672341108,
                                0,
                                0,
                                0,
                                0,
                                0.46077817096319262,
                                0,
                                0.089099068674824297,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12544567952637381,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41275629669820341,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16293046898748653,
                                0,
                                0,
                                0,
                                0,
                                0.89615060219334863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45091845002200209,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.04932263881192131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.88909644009876254,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69513438861373222,
                                -1.2243727290036968,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29854224012763164,
                                0,
                                0.0808126228906626,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37757329488116598,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61801569404062262,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.195169111725686,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64901615413408942,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25566976282828852,
                                0,
                                0,
                                0,
                                0,
                                0.82598101581186345,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17109903209661567,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1501064534744985,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15681059667230554,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.054436415290776849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.033708495430239481,
                                -0.22199704420587296,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44198457727736173,
                                0,
                                -0.26946639923780535,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12642951091603721,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10682400797522396,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25661717286367897,
                                -0.070734559794250029,
                                0,
                                0,
                                0,
                                0,
                                0.87071015982528921,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28367549563340749,
                                0,
                                0,
                                0,
                                0,
                                0.1118997653632797,
                                0,
                                0.09246608502509536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24094268270318994,
                                0,
                                0,
                                0.11412079035690514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19916736925266482,
                                0,
                                0,
                                0,
                                1.0608439878052507,
                                -0.07627654272894549,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.061190011998916376,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.94076645989071817,
                                0,
                                0,
                                0,
                                0,
                                -0.24749917281057404,
                                0.096961603560174359,
                                0,
                                0,
                                0,
                                0,
                                0.64338878362776397,
                                0,
                                -0.30968466526466398,
                                0,
                                0,
                                0.09132292457546265,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65693585119404529,
                                -0.46446079238584276,
                                0,
                                0,
                                0,
                                0,
                                -0.28625181630822555,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.082603299050344609,
                                0,
                                0,
                                0,
                                0,
                                0.008476715722115169,
                                0,
                                -0.41035705342235951,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29520062642647066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33746477373428191,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.085775939518961841,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53147703784462053,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38076368179488901,
                                0.53573409630785473,
                                0,
                                0,
                                0,
                                0.40533957321143188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44427276123185866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.167726157769093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11948013375594246,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83553066826160172,
                                0.019377011998093607,
                                0,
                                0,
                                0,
                                -0.24844955436757399,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11109920971430065,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.10577274049467,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27635986533189105,
                                0,
                                0,
                                0,
                                0,
                                0.10311757484253152,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70342058761323289,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20450201377436678,
                                0,
                                0,
                                0,
                                -0.02582439518930893,
                                -0.42891573783938408,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0141906560593787,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.017647628633866291,
                                0,
                                0,
                                0,
                                0,
                                -0.47450043633925704,
                                -0.38413018542682681,
                                0,
                                0,
                                0,
                                0,
                                -0.1976679919842953,
                                0,
                                0.9842674531155966,
                                0,
                                -0.084658846703802915,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38423054214593311,
                                0,
                                0,
                                0,
                                0.32809014010804849,
                                -0.41701891700343918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12985561511892191,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26625799498279679,
                                0,
                                0,
                                0,
                                0,
                                1.2026800427581041,
                                -0.76548916444392057,
                                0,
                                0,
                                0,
                                0,
                                -0.35666141664522788,
                                0,
                                -0.19091164962869478,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16855477698185489,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11774280657838665,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60415563108692372,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.022481809103139627,
                                0.13520932051098561,
                                0,
                                0,
                                0,
                                0.75758491272464479,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60134936201305267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34495888847564615,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15547193140132692,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.83681696957512175,
                                0,
                                0,
                                0,
                                0,
                                0.40371810980629852,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17714277008221543,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60357162136321452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21391197890141356,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0944136946471572,
                                0,
                                0,
                                0,
                                0,
                                -0.50007680706089097,
                                0,
                                0,
                                0,
                                0,
                                0.05672400193966786,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39447863617770101,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51630325412020706,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62259652055116654,
                                -0.60734981672482347,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25600255877490263,
                                0,
                                -0.70677606066606602,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22075776541096756,
                                0,
                                0,
                                0,
                                0,
                                0.33286828336715391,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46123028713597358,
                                0,
                                0,
                                0,
                                0.79253801302634508,
                                0.024851047969353723,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17208130883084377,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.99572829595180656,
                                0,
                                0,
                                0,
                                0,
                                -0.22681028294038413,
                                -0.26737157978001402,
                                0,
                                0,
                                0,
                                0,
                                0.25490591948157404,
                                0,
                                0.050482417992160897,
                                0,
                                0,
                                -0.29224714394475831,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18240577556571763,
                                0.2228587968468734,
                                0,
                                0,
                                0,
                                0,
                                -0.013121977590760836,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16974281254525478,
                                0,
                                0,
                                0,
                                0,
                                0.73523652023756647,
                                0,
                                -0.46491794095482963,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2143535755357826,
                                0,
                                0,
                                0.56628769848321947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.01960043895005209,
                                0,
                                0,
                                0,
                                -0.60394300623370234,
                                0.58927313242926038,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44196917937814473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.091680704184028905,
                                0,
                                0,
                                0,
                                0,
                                0.46707449360414477,
                                -0.62251972906878483,
                                0,
                                0,
                                0,
                                0,
                                0.77602554467739249,
                                0,
                                0.3404327430901945};

const double rot_10_20[400] = {1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.86300558641972736,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46161783829495218,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20525673966093672,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.70017153155127398,
                               0,
                               0,
                               0,
                               0,
                               -1.5774337537379204,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26424737828554096,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11728505278267669,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21211992408144215,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.97018006277260094,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1839063693534097,
                               0,
                               -0.018404702506845561,
                               0,
                               0,
                               -0.78922419586249493,
                               -0.58563203712064804,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0508705558517799,
                               0,
                               0,
                               0,
                               0,
                               0.86669912611915356,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.2532845236220358,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41308546127467444,
                               0,
                               -0.85221011436381189,
                               0,
                               0,
                               -0.10819439001777394,
                               0.30231158864355623,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49139146736803102,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.86134436155092997,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12891980694336469,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40126095151615249,
                               0,
                               0.48161630491776752,
                               0,
                               0,
                               -0.4095498745108766,
                               0.66280033487758028,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.79657297078364919,
                               0,
                               0.20358026117236788,
                               0,
                               0,
                               0.44462123534757669,
                               -0.35544132646035503,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.067335520917856981,
                               0,
                               0,
                               0,
                               0,
                               0.84993171769672837,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.95162375486559803,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1};

const double rot_10_10[100] = {-0.44568271056880143,
                               0.37423604013310852,
                               0,
                               0,
                               -0.2202692934468386,
                               0,
                               -0.7828127145939614,
                               0,
                               0,
                               0,
                               -0.88762664144260184,
                               -0.085541110850273161,
                               0,
                               0,
                               0.053697666629273014,
                               0,
                               0.44935311766404762,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1471011924046846,
                               0,
                               0,
                               0,
                               0,
                               -1.0686538833157408,
                               0,
                               -0.83964448937229208,
                               0,
                               0,
                               0,
                               0.80282159842160139,
                               0,
                               0.50009139693595195,
                               0,
                               0,
                               -0.32463221623620903,
                               0,
                               0.06025500122703633,
                               -0.013205165102193162,
                               0,
                               0,
                               -0.97063789949955548,
                               0,
                               0.23250166987969084,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.57624743330381978,
                               0,
                               -0.7905726647639334,
                               0,
                               0,
                               0.20720462673119511,
                               0,
                               -0.099273368677116336,
                               -0.92328529081460831,
                               0,
                               0,
                               -0.080374542101918023,
                               0,
                               -0.36225543890849843,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.94629678166254294,
                               0,
                               0,
                               0,
                               0,
                               0.46652529044944235,
                               0,
                               -0.7500639542625902,
                               0,
                               0,
                               0,
                               0.15302410502448544,
                               0,
                               0.35341683100653509,
                               0,
                               0,
                               0.92286519429586944,
                               0,
                               0,
                               0,
                               -1.1712955526736537,
                               0,
                               0,
                               0,
                               0,
                               -0.73604592353555143,
                               0,
                               0.075594075746454881};

const double rot_10_100[10000] = {0.1854107034746664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.76622220739120084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024015893465599333,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.98714897106566357,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.033405560516564278,
                                  0,
                                  0,
                                  -0.82745428560524226,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056599034863176662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21607429926818317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24936337496334268,
                                  -0.80360688805233227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17238129628980817,
                                  0,
                                  0,
                                  0,
                                  0.011262582674151138,
                                  0,
                                  0,
                                  0,
                                  -0.7275013100754808,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54914157627303606,
                                  0.68207911858293357,
                                  0,
                                  0,
                                  0,
                                  0.23195533304379704,
                                  0,
                                  0.32551395844088299,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21914614006528693,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21001194446471641,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.013269643630601624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081095752266000395,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032306515622165605,
                                  0,
                                  -0.13129624406367324,
                                  -0.29648150090689385,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16343459351337694,
                                  0,
                                  0,
                                  0,
                                  -0.67234190532382543,
                                  0,
                                  0,
                                  0,
                                  0.17212090928364571,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.099200529691435807,
                                  0.023327190783931188,
                                  0,
                                  0,
                                  0,
                                  -0.44348544107429538,
                                  0,
                                  0.14825442142958467,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11284056400158249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23646353752766863,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.090513290496888735,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.64695328202494862,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60294551349421321,
                                  0,
                                  0,
                                  0,
                                  0.43289628147700054,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7383367267108879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14908106325146209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27932118262765221,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61622066371516315,
                                  0,
                                  0,
                                  0.54934806718084395,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19674465491201115,
                                  -0.2917017165652217,
                                  0,
                                  0,
                                  0,
                                  -0.025178831808654205,
                                  0,
                                  0,
                                  0,
                                  0.29142048656189568,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068007797560577843,
                                  0,
                                  -0.15338735674854845,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.083586363333695471,
                                  0,
                                  0,
                                  0,
                                  -0.27421798165445588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13375071603019628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36203553197199495,
                                  0,
                                  -0.24053460550580974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4598992564334049,
                                  0,
                                  -0.3879049669794572,
                                  0,
                                  0,
                                  0,
                                  -0.19174442670063691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.055428764957483993,
                                  0,
                                  0,
                                  0.33544478289779506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33180160789976426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29422877068416353,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.065529983608531184,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53302707825371909,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38647663721727876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061271853836427068,
                                  -0.19785161620919711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12101645291670586,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33374058345706858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62713356069488424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28861525354889639,
                                  0.44122353598558389,
                                  0,
                                  0.2473840751016543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12984126779845295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.64080338897858935,
                                  0,
                                  0,
                                  -0.01260590250126431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37674333695288897,
                                  0,
                                  0.98499035754875919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21154110728525344,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53364187162260335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19278106104774934,
                                  -0.17426725528015902,
                                  0,
                                  0.14682769078270005,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59782649127388365,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16990293355575253,
                                  0,
                                  0,
                                  1.0151449754769439,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32462524577038804,
                                  0,
                                  0.35892795735452321,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50732856690660511,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31533655413176964,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.094048696770411888,
                                  0,
                                  0,
                                  0,
                                  0.15127161892361432,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65639369798403546,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20758541248628676,
                                  0,
                                  -0.16188690266633823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42628250461307515,
                                  0,
                                  0.15770647539444255,
                                  0,
                                  0,
                                  0,
                                  0.29524490137763365,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34533026492786451,
                                  0,
                                  0,
                                  0.19875131062622539,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.037731198577348218,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11909493629856834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3133098546793921,
                                  0.53360451582284063,
                                  0,
                                  0.0075060743366011651,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.70604673922626848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38481118120914354,
                                  0,
                                  0,
                                  -0.65837957414940607,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6920393708429432,
                                  0,
                                  -0.06564736357086734,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36448557668839432,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53574432396222649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24030137985262695,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52544556145898791,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25062368100122168,
                                  0,
                                  0.26392267834805438,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.3876406852804,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.032945644595118839,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56359113884241185,
                                  0,
                                  0,
                                  0,
                                  0.05781946559429095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.75252333749415756,
                                  0,
                                  0,
                                  0,
                                  -0.094752624644913158,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31701415053900822,
                                  0.05704851114875592,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23111056142904046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03430828972438052,
                                  0,
                                  -0.39069667499427502,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41054543165414714,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10186045317972903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45208624277569437,
                                  0,
                                  0,
                                  0,
                                  -0.62387111392761563,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11328123358816666,
                                  0.082863847820693948,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.023402170139849653,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.027505566863185001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14735536286416476,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39066111872225823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.004628386760585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3801710793376567,
                                  0,
                                  0,
                                  -0.10610792726877691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14470581970460414,
                                  0.012412395383371945,
                                  0,
                                  0,
                                  0,
                                  -0.67738840078243034,
                                  0,
                                  0,
                                  0,
                                  -0.45016198548112268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30856422195453109,
                                  0,
                                  0.3394049285257425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.73270362585423054,
                                  0.14381420798320765,
                                  0,
                                  0.030946727063554665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.84517826747921454,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31956726008413722,
                                  0,
                                  0,
                                  0.2916509984855245,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35970834258319667,
                                  0,
                                  -0.38032888440133034,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073137495280242035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31565494896804275,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31218647479813089,
                                  0,
                                  0,
                                  0,
                                  0.46640931385277673,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30457740058524796,
                                  0,
                                  0,
                                  0,
                                  -0.75654298517215968,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13802646104287342,
                                  -0.028739721571529292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24210771213680471,
                                  0,
                                  0,
                                  0,
                                  0.094710221998223126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019696356227785247,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037677056621249316,
                                  0,
                                  -0.032670078425526522,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48638993611276449,
                                  0,
                                  0.090595358189958036,
                                  0,
                                  0,
                                  0,
                                  -0.18736533501322991,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54886978368161521,
                                  0,
                                  0,
                                  0.41602517585230941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39926895408090046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12609459460197811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30023103634559395,
                                  -0.66900611403236487,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.82833519329330829,
                                  0,
                                  0,
                                  0,
                                  0.13584927901006272,
                                  0,
                                  0,
                                  0,
                                  -0.23474415492261624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29976525578847357,
                                  -0.12178476770795961,
                                  0,
                                  0,
                                  0,
                                  -0.014239105630608749,
                                  0,
                                  -0.51401219498403317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.83974942773250327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31264907416951387,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09890295924761168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1563874253726083,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25318889759971458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.05689693697217596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26667031214568498,
                                  0,
                                  -0.32793403086409029,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.02264174560214826,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.083542406400269331,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58049110916065438,
                                  0,
                                  0,
                                  0,
                                  -0.31733642455113403,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55487070932820926,
                                  -0.042047750057132363,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25158521569590431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.556079695320013,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.63135490033665043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4502737961089272,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14939184143393366,
                                  0.10823545435075337,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021530171317113461,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.090483421850404838,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21618565410109566,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59157761083021476,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12426129640558463,
                                  0,
                                  0.012411617130042185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33019000924160585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54908177887573961,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18619571549388275,
                                  0,
                                  0,
                                  0,
                                  0.13379836892180424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34560567126406372,
                                  -0.22602767129634621,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028672880008276523,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11822661058838856,
                                  0.20788497914154622,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45781860034135441,
                                  0,
                                  0,
                                  0,
                                  0.0055264374937532453,
                                  0,
                                  0,
                                  0,
                                  0.06128054102464417,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61419623487381392,
                                  0.18356889747610139,
                                  0,
                                  0,
                                  0,
                                  0.27041120148227976,
                                  0,
                                  0.36230270342387,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20044177951993836,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.64072980808384283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58295131666205757,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34632377953290444,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51918389727250913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.038923592536092039,
                                  0.10198823317957276,
                                  -0.21510199814046649,
                                  0,
                                  0,
                                  -0.38068586556732842,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38916021142401269,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23075443475270563,
                                  0,
                                  -0.032202321159746583,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3246646039905825,
                                  0,
                                  0,
                                  0.028617757287920514,
                                  0.18427187433982067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55845974118362196,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.065970100713257193,
                                  0,
                                  0,
                                  0,
                                  0.36325375531010656,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052892866639882123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28225725672474439,
                                  0.32289524466361769,
                                  -0.26341802480190635,
                                  0,
                                  0,
                                  -0.21428952209214308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16018443570660776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37891075010298553,
                                  0,
                                  -0.38174078114150556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17056578565086961,
                                  0,
                                  0,
                                  0.10985661254781039,
                                  -0.48773238903717686,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095179408275548827,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19142108920515083,
                                  0,
                                  0,
                                  0,
                                  0.071658988400672502,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2364779129563222,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039480552788696784,
                                  0.31239420267938023,
                                  -0.47248748942595098,
                                  0,
                                  0,
                                  0.25830086750687442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.6140795534009118,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.094313822781288831,
                                  0,
                                  -0.24152665325904712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28788745750096267,
                                  0,
                                  0,
                                  -0.16458216330484515,
                                  0.063336434112689827,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097882504105021056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20516859870201434,
                                  0,
                                  0,
                                  0,
                                  0.0070397748906917109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.029339145752024513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24356294951612764,
                                  0.19623564982687608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  5.1674855283206922e-05,
                                  0,
                                  0,
                                  0,
                                  -0.56404188452170867,
                                  0,
                                  0,
                                  0,
                                  -0.084257602398514139,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60434862874597395,
                                  0.49871426531064339,
                                  0,
                                  0,
                                  0,
                                  -0.029153311135189017,
                                  0,
                                  -0.22094447320310212,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34205560312594385,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26726271359518866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.78966922306388643,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.067808744893911699,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10658763355897397,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5527022622051645,
                                  0,
                                  0,
                                  0,
                                  -0.062004933114968019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16039112157396132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50028979803276619,
                                  0,
                                  0.37810872951453001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036590738310456769,
                                  0,
                                  0.22695865545165717,
                                  0,
                                  0,
                                  0,
                                  0.27541120820355769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27874944765788978,
                                  0,
                                  0,
                                  -0.009455172509537646,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06360079653603451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24730149452992917,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.028065932310506449,
                                  0.39696718940908987,
                                  0.47940515161144692,
                                  0,
                                  0,
                                  -0.10807695379075866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20364142181949968,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18016818084302952,
                                  0,
                                  -0.4189818532236706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082921568067265305,
                                  0,
                                  0,
                                  -0.21101039287666881,
                                  0.12473703529530136,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22358623759062352,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4420684664138444,
                                  0,
                                  0,
                                  0,
                                  -0.18152794470464162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072902685623625257,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026753854141079947,
                                  0,
                                  0,
                                  0,
                                  0.54984872320422384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022284136632061621,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13347079679530646,
                                  0,
                                  0.30636245080326713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10472815668491839,
                                  0,
                                  -0.51452208321305681,
                                  0,
                                  0,
                                  0,
                                  0.27189484531283831,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15032774224983167,
                                  0,
                                  0,
                                  -0.092755868852090112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38613585393971905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23420264399890345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.93519338993501644,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36307842923021622,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19190272572423428,
                                  0,
                                  -0.048311484697265511,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.63557952758137359,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27813859757063458,
                                  0,
                                  0,
                                  0,
                                  -0.75070671209963247,
                                  0.22735994035673796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12432116829913509,
                                  0,
                                  0,
                                  0,
                                  -0.26443209597100914,
                                  0,
                                  0,
                                  0,
                                  -1.1696696558854613,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14462853657871835,
                                  0.10335395582131299,
                                  0,
                                  0,
                                  0,
                                  -0.5103727142880895,
                                  0,
                                  0.15362251043497988,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36435776440911222,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082546642782221125,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18117676760409684,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51611518531504563,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25140571473654233,
                                  0,
                                  -0.099930376749359812,
                                  0.43189513191188211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38092153578205284,
                                  0,
                                  0,
                                  0,
                                  0.11223645991566822,
                                  0,
                                  0,
                                  0,
                                  0.35383345290490087,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17128240492314514,
                                  0.013859089221164805,
                                  0,
                                  0,
                                  0,
                                  -0.40389664541741832,
                                  0,
                                  0.66553499224191748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36531574331898164,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.85905470896604774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.6356418122875217,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28145412301255379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29896676497933894,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.028127559685316827,
                                  0,
                                  0,
                                  0,
                                  -0.76459242952155937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.015579808345376846,
                                  0,
                                  0,
                                  0,
                                  -0.44969268249108896,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073834312309140976,
                                  -0.45463118273628045,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36314914633645601,
                                  0.25555200289839342,
                                  0.10971619050460284,
                                  0,
                                  0,
                                  -0.0043268315846412379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12413432378951159,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21731124208546046,
                                  0,
                                  0.47578150006277448,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015987899568235542,
                                  0,
                                  0,
                                  0.45054628495332083,
                                  0.21074012783987653,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072888169120522484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32168793851267502,
                                  0,
                                  0,
                                  0,
                                  -0.08955564248351168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37051716280789149,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10059017934317706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14180813641572887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42211940995893488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06483580861199234,
                                  0.49859930375076755,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58421670456629904,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0042917315923081192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44435880476079009,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14680515564404339,
                                  -0.40771534040583773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3034223096605001,
                                  0,
                                  0,
                                  0,
                                  0.35685456503837382,
                                  0,
                                  0,
                                  0,
                                  0.16113472933659018,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48753038813965599,
                                  -0.12731306876199425,
                                  0,
                                  0,
                                  0,
                                  0.45932086606597167,
                                  0,
                                  0.21452151042542023,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28612234998579428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42309151875211537,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66900611563266676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52455884146162113,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.70732657926200371,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58527586837458034,
                                  0,
                                  0,
                                  0,
                                  -0.14402164301605411,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.075850170802270994,
                                  0,
                                  0,
                                  0,
                                  0.31883986184204549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.71190372000992286,
                                  -0.14996970283087946,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.012965739043032838,
                                  -0.29178126609198263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24051685351044483,
                                  0,
                                  0,
                                  0,
                                  0.51769576084241498,
                                  0,
                                  0,
                                  0,
                                  -0.15110865738876442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13046028828163689,
                                  -0.4684625270312765,
                                  0,
                                  0,
                                  0,
                                  -0.59541926200855522,
                                  0,
                                  0.1692530821857976,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48860472105212815,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21082653049863764,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42567761666612397,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40429397941442979,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16601844557111822,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34113286251402158,
                                  0.12557540846857598,
                                  -0.41681248201965404,
                                  0,
                                  0,
                                  -0.05435023563094598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24628762458418774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049682438807396721,
                                  0,
                                  0.31155633787650105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082450095872566062,
                                  0,
                                  0,
                                  0.053479623211304998,
                                  -0.20802041241980782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40675354535474484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5014740608996695,
                                  0,
                                  0,
                                  0,
                                  0.1657098841836912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18347827304253236,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18802575114417097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10179329551970789,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084277313266231724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29555057269183865,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.02583717477500333,
                                  0,
                                  0,
                                  0.073624784944310476,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.7742198821530849,
                                  0.081145644314989648,
                                  0,
                                  0,
                                  0,
                                  -0.28853729257020566,
                                  0,
                                  0,
                                  0,
                                  0.60868210208464735,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13417955182853344,
                                  0,
                                  0.76584684421068394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34238690599058735,
                                  0.1738537629169378,
                                  -0.15589559415979209,
                                  0,
                                  0,
                                  -0.2035657724104889,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.09943959347196113,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58259885808192413,
                                  0,
                                  -0.029224486903579205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21160274029381648,
                                  0,
                                  0,
                                  -0.010732270889272172,
                                  0.44775979942518612,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036193364669810393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15790827073472818,
                                  0,
                                  0,
                                  0,
                                  -0.36069293218365223,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18685762138035253,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38660583590416664,
                                  0,
                                  0,
                                  0,
                                  -0.12493535848674001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46981654061520561,
                                  0,
                                  0,
                                  0,
                                  -0.33558712313932654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57887503397803353,
                                  0.40802509705775597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30348238680490203,
                                  0,
                                  0,
                                  0,
                                  -0.39770164773462746,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33796105234913726,
                                  0,
                                  0,
                                  0,
                                  -0.046514173187122837,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18192308047307024,
                                  0.77476099015589217,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061580228353327215,
                                  0,
                                  0,
                                  0,
                                  -0.22844001947745662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42906143590195145,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42760385607911894,
                                  0,
                                  0.17034353733386939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39589182602379236,
                                  0,
                                  0.086563262483176223,
                                  0,
                                  0,
                                  0,
                                  0.13540154265077031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30878444262323224,
                                  0,
                                  0,
                                  -0.2825337016326665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37637455040615048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22063385488061296,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48524268187140274,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26432813291566648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13244433778733866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21182333079312271,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035112310153225856,
                                  0,
                                  0,
                                  -0.60888175053917259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.2890426000021362,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2926822216043885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12851408009530482,
                                  0,
                                  0,
                                  0,
                                  -0.24416991568235588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0089163648124712669,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06830942612258975,
                                  0,
                                  -0.39177967414806941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26764628281835401,
                                  0,
                                  -0.51143781543226619,
                                  0,
                                  0,
                                  0,
                                  0.1675512723159247,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45248373255413304,
                                  0,
                                  0,
                                  -0.34455924963639717,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23313372934391591,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16290380612336311,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12288053463779861,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59831750703409803,
                                  0,
                                  -0.092796726031095317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.023019987639076749,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3726182366912888,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32009011839289575,
                                  0,
                                  0,
                                  0,
                                  0.13406639679168433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15309381574671482,
                                  -0.41115184107912955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4074506068121424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54257010409380768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41775218620303045,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073685564209310175,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19861920898287888,
                                  -0.59109269151772148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25983759420719987,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15796165286162589,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21062671106146227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087574744444446129,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10210562111051941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25174014928552463,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5092766232143533,
                                  -0.060030387115334476,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67248893221328954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0025772053218542784,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45090760832387183,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56479642998851531,
                                  0,
                                  0,
                                  0,
                                  -0.0023607294235128955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13425066646905182,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55006354535775148,
                                  0,
                                  -0.078515791337418414,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10560343388726061,
                                  0,
                                  0.053918099857962434,
                                  0,
                                  0,
                                  0,
                                  -0.38668312990309844,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092566849842605714,
                                  0,
                                  0,
                                  0.23985685157409134,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.047339645582140419,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34973916293026031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38818351861208139,
                                  -0.74313555871711379,
                                  0,
                                  -1.1634426698395821,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56259186390385318,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.089172001512222765,
                                  0,
                                  0,
                                  -0.32756312448237312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21814991785049009,
                                  0,
                                  0.21384995256254991,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083505055577939802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25426990547553235,
                                  0,
                                  0,
                                  -0.59484004945200608,
                                  -0.55626596462211297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43384217012530968,
                                  0,
                                  0,
                                  0,
                                  -0.22050456221311684,
                                  0,
                                  0,
                                  0,
                                  0.11509428831829277,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28230637484415066,
                                  0.04264187356932142,
                                  0,
                                  0,
                                  0,
                                  -0.30113367942814712,
                                  0,
                                  0.73976313704893482,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58331078906341882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.023956864824662694,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077053359576406327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37855996022640592,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.87519654685294601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0012408004887244917,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48070092713418006,
                                  0,
                                  -0.22951232553249779,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41589246820030201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13614531149928275,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13033749506549031,
                                  0,
                                  0,
                                  0,
                                  0.22376887687129376,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34598430391636315,
                                  -0.075939934032174236,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57638068629395112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1014726339305829,
                                  0.15339639585032452,
                                  0,
                                  0.13631592361849582,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12695535814827785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.093737360155164623,
                                  0,
                                  0,
                                  0.48760677808683961,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33177174990496588,
                                  0,
                                  -0.29213103470198121,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.70459640861088879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56983935435376232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39044855890600877,
                                  0.071506711840774173,
                                  0.11711143484607994,
                                  0,
                                  0,
                                  -0.39516512094582257,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25410432379049497,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16219276324959073,
                                  0,
                                  0.23096224251231315,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0096296959272893778,
                                  0,
                                  0,
                                  -0.41587439801650322,
                                  0.13269636631375711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26360543555967886,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062508100907243402,
                                  0,
                                  0,
                                  0,
                                  0.40803292900938842,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3127436068834834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11888341024656091,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050045203202244148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.052616774165930913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56175131690923341,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24145571527943815,
                                  0,
                                  0,
                                  -0.15862620227265511,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046444234867965367,
                                  0.12423930976759229,
                                  0,
                                  0,
                                  0,
                                  -0.40894646057456119,
                                  0,
                                  0,
                                  0,
                                  0.54669292939128111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.84491983855995112,
                                  0,
                                  -0.57875267537841468,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19095822542284652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14053151630205257,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49688131237728345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39849440541174763,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30011015632046817,
                                  0,
                                  0,
                                  -0.90558080393721596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.84684526387133885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.7407575234075453,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31393392991657254,
                                  0.19871094770676012,
                                  -0.083583893015349409,
                                  0,
                                  0,
                                  -0.27528178106693557,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15718389654211642,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.366400644829528,
                                  0,
                                  0.075503806822683345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18852471282588962,
                                  0,
                                  0,
                                  0.0012385297595691319,
                                  0.25864940315262541,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30728772648346975,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38224305783108181,
                                  0,
                                  0,
                                  0,
                                  0.086395995265980116,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51390047760491986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.086159135209902413,
                                  -0.00086974066501235956,
                                  -0.068123166609945981,
                                  0,
                                  0,
                                  0.49358676434198562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22736532182087191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15851896716535716,
                                  0,
                                  -0.2664514118418263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24305192137453885,
                                  0,
                                  0,
                                  0.11600348703533261,
                                  0.49659670400132483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1573123502548629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01506189651824567,
                                  0,
                                  0,
                                  0,
                                  0.50236738062496644,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0011074834082803499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11748778247165699,
                                  0,
                                  0,
                                  0,
                                  -0.0015710817233737361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20345456033276005,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0014124971634484063,
                                  0,
                                  0.57906334353541444,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19154652481299506,
                                  0,
                                  -0.23743926790969416,
                                  0,
                                  0,
                                  0,
                                  -0.55137524753622902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32539970148272335,
                                  0,
                                  0,
                                  -0.10370802915135399,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29941075383019228,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078197073625119101,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52769770490939594,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094139839418112076,
                                  0,
                                  -0.23620833837593769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22431304972333665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34550237023664171,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24881536207438665,
                                  0,
                                  0,
                                  0,
                                  0.26908472073747308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35344937946091293,
                                  -0.40455210732389629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25354618694423869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53232119241877773,
                                  0.11711344396654474,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.86355541216820741,
                                  0,
                                  0,
                                  0,
                                  -0.14245629314072861,
                                  0,
                                  0,
                                  0,
                                  -0.45554481204730424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13770436024202728,
                                  -0.34430466385295971,
                                  0,
                                  0,
                                  0,
                                  0.48897024307238401,
                                  0,
                                  0.35535383157164313,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23263760559026422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.014801919703730057,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045124984478692287,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41725860022697786,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39269917334408988,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043369278395898471,
                                  0,
                                  0,
                                  0,
                                  -0.49472578501954989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061500382732548875,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22728028843074019,
                                  0,
                                  0.37452275589671313,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14156725014134758,
                                  0,
                                  -0.24694334188636799,
                                  0,
                                  0,
                                  0,
                                  0.39076426196765696,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13064699029875451,
                                  0,
                                  0,
                                  0.51157740901343229,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17731107561519069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11713784268876096,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.034676801262611356,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36780788060886588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1084333636977743,
                                  0,
                                  0.34514388354086933,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35916037225743208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.080571128327844674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39403100341688868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046859139874624617,
                                  0,
                                  -0.2839522687323463,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21321052064459942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44017011082180768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17465838596944738,
                                  0,
                                  0,
                                  0,
                                  -0.17051133348851621,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39301221490758542,
                                  -0.54869347433087678,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.087198907025727884,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3216453229808468,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022817739008286278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053227369488232285,
                                  0,
                                  0.10333239504910297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18992288144195829,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0517092792940441,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054464953488126785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1061132192939071,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17575883324043326,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12991796901143648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32343472575050614,
                                  0,
                                  0,
                                  0.16611443184276026,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41103794055716719,
                                  0.27194220399086183,
                                  0,
                                  0,
                                  0,
                                  -0.25385711654460696,
                                  0,
                                  0,
                                  0,
                                  0.55763320106117553,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55238360432626255,
                                  0,
                                  -0.97016230772146228,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27338291766974648,
                                  0.64238438657014818,
                                  0.30133055142750281,
                                  0,
                                  0,
                                  0.20525409188883786,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064370878428186784,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030536533490245758,
                                  0,
                                  0.17903003142499327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10991957666273174,
                                  0,
                                  0,
                                  0.12941763678391807,
                                  -0.18917957818619385,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25369844117500157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24914787945799358,
                                  0,
                                  0,
                                  0,
                                  0.19609347977328911,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33620905131705076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42806289109035162,
                                  0,
                                  0,
                                  0,
                                  0.31502136193724162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13201997486008504,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.095577100181811453,
                                  0,
                                  -0.098685426512288774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18603227435002823,
                                  0,
                                  -0.32116179214726914,
                                  0,
                                  0,
                                  0,
                                  -0.053592029791015752,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.088608595152241565,
                                  0,
                                  0,
                                  0.22800348730327488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13836843207640798,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6794208767050347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18459868638631713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.86729895738001295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31955439962101745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41183005710268955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40524964117137341,
                                  0,
                                  0,
                                  0.55267399985177701,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077735024494435548,
                                  -0.31106162484621119,
                                  0,
                                  0,
                                  0,
                                  -0.47360506434132388,
                                  0,
                                  0,
                                  0,
                                  0.21352166818052837,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37085882198292713,
                                  0,
                                  -0.41606199219198381,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35321923572345809,
                                  -0.56495958469806107,
                                  0,
                                  0.45311315077881942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24573215474479865,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32946336504495582,
                                  0,
                                  0,
                                  0.12742021169596271,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27311927590941609,
                                  0,
                                  -0.20295037126950682,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48266782627582688,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48311095848876762,
                                  0,
                                  0,
                                  -0.25581860214215696,
                                  -0.2544077447728082,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1225605261342787,
                                  0,
                                  0,
                                  0,
                                  -0.1652947002085258,
                                  0,
                                  0,
                                  0,
                                  0.4714649119033677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23231763048938689,
                                  0.22231226757046146,
                                  0,
                                  0,
                                  0,
                                  -0.091375139598170882,
                                  0,
                                  -0.26017992383881483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.79029820255325811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59276444887228374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48661924938515583,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19496048061237853,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047195687266168879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3981113009577974,
                                  0.80074172159418433,
                                  0,
                                  -0.29877881463373751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36879458157896583,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.96298799046598482,
                                  0,
                                  0,
                                  0.24023633407317646,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50272717361599395,
                                  0,
                                  -0.67126832196819408,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29212087367794237,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24626124159560947,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2074755577286001,
                                  0.060527150617890699,
                                  -0.2253232333854471,
                                  0,
                                  0,
                                  -0.2393513326943964,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.074635421346420913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26995934939722011,
                                  0,
                                  -0.14457649017767071,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61573114205433088,
                                  0,
                                  0,
                                  0.1830162487673869,
                                  0.2265543058350758,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15735740204836929,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.066267231188951975,
                                  0,
                                  0,
                                  0,
                                  -0.30231977430901502,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40172539764229681,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26744426767643342,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43787059535443101,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29162543429086352,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54703140108169879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18862968182268267,
                                  0,
                                  0,
                                  -0.8766539970025562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.020213500927279832,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.0532603327457335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33048585551398113,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.03905617971382077,
                                  0,
                                  0.46660697059821193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13226032585168568,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1535090741216987,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3172629575805449,
                                  0,
                                  0,
                                  0,
                                  -0.52670984204787019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1174710960518118,
                                  -0.12329675501452841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47264492943524217,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1823311142755159,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38068105904982519,
                                  0,
                                  -0.38104201437422858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13164640278900236,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14484319636354448,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27371859073460325,
                                  0,
                                  0,
                                  0,
                                  0.18379890573674598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33729858194983564,
                                  0.53088291132559895,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36609158532068792,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27803484267161077,
                                  -0.055565451540529151,
                                  0.047661758203020183,
                                  0,
                                  0,
                                  -0.031922766631206252,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088701082087069533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30298587256362886,
                                  0,
                                  0.050707392664713143,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48720863858961777,
                                  0,
                                  0,
                                  -0.48293654065953046,
                                  -0.016134192497157585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41185213741653043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28110580272182251,
                                  0,
                                  0,
                                  0,
                                  0.086645265784320635,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29507373745303733,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50477656665755277,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10883820348765884,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53185591825081246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14307806323791905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46072775497292501,
                                  0,
                                  0,
                                  -0.56094341653192537,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051853287268221554,
                                  0.45440153296279023,
                                  0,
                                  0,
                                  0,
                                  -0.22059704662109847,
                                  0,
                                  0,
                                  0,
                                  -0.84213082946965867,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.040414941581969288,
                                  0,
                                  -0.14281880161884553,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12058432586325542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.77430668992002893,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27258067431847854,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26220968900622732,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18654389505761981,
                                  0,
                                  0,
                                  0.6107105191668406,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44987091793373185,
                                  0.26748535564193576,
                                  0,
                                  0,
                                  0,
                                  0.45519859217972281,
                                  0,
                                  0,
                                  0,
                                  -0.26266938273732132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60390147572300978,
                                  0,
                                  0.18463476731886944,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.71127028240366497,
                                  0.24375202169861454,
                                  0,
                                  -0.27921948505571637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16201484330096241,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16511208429561641,
                                  0,
                                  0,
                                  0.10452335708735713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.2082263555634749,
                                  0,
                                  0.0596580091118235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.71491514782452636,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.05370731115076964,
                                  0,
                                  -0.66429409774081805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4510524328030216,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.93954185356032716,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43162987833145416,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24792536152989122,
                                  0,
                                  0,
                                  0.020596469287526065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48669126299809029,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25334996383653385,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08232897789511498,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028174972459070587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29399773407876978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.7930311531675257,
                                  0.072968217633533561,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29367638126132434,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29781283261105645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3111790028662404,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28813378084766511,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34697696419253521,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72314707128468692,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.013449650053006235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18289274320502485,
                                  0,
                                  0,
                                  0.85737280636227631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07086702821722396,
                                  0.75798378763495056,
                                  0,
                                  0,
                                  0,
                                  0.093293310886395517,
                                  0,
                                  0,
                                  0,
                                  -0.35146845780911201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46079061950015177,
                                  0,
                                  -0.12372146221188686,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1086757934121181,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.64728861579838448,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45884266218989078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24775633613346731,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28541225906644241,
                                  0,
                                  0,
                                  0.066206184842247703,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29272753529829132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25494167450036165,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28483564763619013,
                                  0,
                                  0,
                                  0,
                                  -0.36189673547897505,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50975134172340242,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073757899950727707,
                                  0,
                                  0.063645977756165345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16443096077144881,
                                  0,
                                  -0.087950918963563149,
                                  0,
                                  0,
                                  0,
                                  -0.18885519987774665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19145200230308268,
                                  0,
                                  0,
                                  -0.29270231713000472,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48727853728958537,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29724376854193418,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.045766544513494031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40707524276497481,
                                  0,
                                  -0.42312626910965817,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.6463893975097208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40756375782058252,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19115810978673159,
                                  0,
                                  0,
                                  0,
                                  -0.10699587415514251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098716089667468046,
                                  0.060816606252844026,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088310784391542385,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0561301458404111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19270021966393919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085950927701859775,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35022808173092429,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59183903454678366,
                                  0,
                                  0,
                                  0.25096071433192557,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41921911914787563,
                                  0.20078381559173514,
                                  0,
                                  0,
                                  0,
                                  0.28201622440580298,
                                  0,
                                  0,
                                  0,
                                  0.19473423210660845,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25846891466220462,
                                  0,
                                  -0.1212717930728856,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31221142203165275,
                                  -0.23420945999709841,
                                  0.22805744572583575,
                                  0,
                                  0,
                                  -0.33218341565965265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39977978983395723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14633610808884406,
                                  0,
                                  -0.33090862837623236,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025054681853904193,
                                  0,
                                  0,
                                  0.48954186279727979,
                                  -0.043877390906146591,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0036788299534520341,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21415527372640542,
                                  0,
                                  0,
                                  0,
                                  0.31724588295294032,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.076486051895813645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18398682682358997,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26103891179702021,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.87631917935420278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25393882836485926,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.3023054591503282,
                                  0,
                                  0,
                                  0.72307165858581823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12931263967471213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29792515790162505,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41290945797901429,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31362478391562276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.055596984375724912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2027662581299346,
                                  -0.23532666873805164,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16630082925559203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.77415225064743542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.067777432119611181,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52296175487009067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.032577994556068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26548807561942966,
                                  0,
                                  0.43070664775259632,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13901966130686882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092795683901869513,
                                  0,
                                  0,
                                  0,
                                  -0.37488908107224383,
                                  0.55807960961981962,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15002660325795222,
                                  0,
                                  0,
                                  0,
                                  0.60706916837034686,
                                  0,
                                  0,
                                  0,
                                  0.32082485865342714,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24833137461195268,
                                  0.85700304245103986,
                                  0,
                                  0,
                                  0,
                                  -0.14914793362847942,
                                  0,
                                  -0.10313763966280391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10523711855374961,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53458645814357986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027622130164035488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39863979411762634,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12202789158586452,
                                  0,
                                  0,
                                  0,
                                  -0.25014316398184455,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12630768064024764,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63142413994469049,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.059783892217104617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37405524565967624,
                                  0,
                                  0,
                                  0.35487628997997545,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.72059590882265567,
                                  0.31137786754800711,
                                  0,
                                  0,
                                  0,
                                  -0.4437121359408866,
                                  0,
                                  0,
                                  0,
                                  0.0076335338510562512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.034474391755012518,
                                  0,
                                  0.45857355293521451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25394473322406408,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62478690937938541,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0514868515756512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61099874039132673,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.88160166808953078,
                                  0,
                                  0,
                                  0.014785831329544433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42754282185026771,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44963904042841984,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35510796143592394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52900115356691146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28568275148198308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41937022924579792,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32233852180101363,
                                  0,
                                  0,
                                  -0.037208746637257456,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59498648645977947,
                                  0.67862274730509298,
                                  0,
                                  0,
                                  0,
                                  0.71594240536327958,
                                  0,
                                  0,
                                  0,
                                  0.83768844812677989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20238113676513264,
                                  0,
                                  0.48060045268372115,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4438906111984362,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11431008274222024,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55801089927395919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.029988682902480981,
                                  -0.53557570850188885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09961721697381698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40920512967405137,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11578029994830714,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36395169163442176,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49080160179424648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36404347148817012,
                                  0,
                                  1.0835824650404628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51629587288808965,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0029055172064679675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30316813397252457,
                                  0.13939638459871895,
                                  0,
                                  -0.74257227449999785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29415998489174777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49521311317374833,
                                  0,
                                  0,
                                  0.67325681652959068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70336352187349183,
                                  0,
                                  -0.15814878992878212,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28412348239947904,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58491716423068729,
                                  0,
                                  0,
                                  0.66307124998357836,
                                  -0.11725222269063465,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.75116982501011598,
                                  0,
                                  0,
                                  0,
                                  0.093891634319810749,
                                  0,
                                  0,
                                  0,
                                  -0.042796743763681339,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28116890557566221,
                                  0.061873658300884385,
                                  0,
                                  0,
                                  0,
                                  -0.65023643758469274,
                                  0,
                                  0.43725788099954677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19103428628299185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2949869401374946,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23041890438720852,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.144642687732635,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033317198221456179};

const double rot_10_30[900] = {-0.37609176672957922,
                               0,
                               0,
                               0,
                               0,
                               0.3997536508902772,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.79039758246805425,
                               -0.0081009894876929861,
                               -0.18971041764608684,
                               0,
                               0,
                               0.18985158884738146,
                               0,
                               -0.043867628665913927,
                               0,
                               0,
                               1.6227651477760467,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29845951831645823,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0474666189895656,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13667421691617918,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11502947067293232,
                               0,
                               0,
                               0,
                               0,
                               -0.22567988622810287,
                               0,
                               0,
                               0,
                               0.95768312518239795,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12789317379203496,
                               0,
                               0,
                               -1.0721231458568907,
                               0,
                               0,
                               0,
                               -0.092169836246650552,
                               0,
                               0.86174169428776826,
                               0,
                               0,
                               0,
                               0,
                               -0.85872920776423523,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.047425746030360746,
                               0,
                               0,
                               -0.24623234648834069,
                               0.36420718822310921,
                               0.15681016309573945,
                               0,
                               0,
                               0,
                               0,
                               -0.5685434567833797,
                               -0.4545144223010304,
                               0,
                               0,
                               -1.3137197472576965,
                               -0.27714755257492701,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.050421641827516142,
                               0,
                               0,
                               0,
                               0,
                               0.067104838129736721,
                               0,
                               0,
                               0,
                               0,
                               -0.56330469151660123,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39156275489546799,
                               -0.68330950879648122,
                               0.16807823963853522,
                               0,
                               0,
                               -0.15486828238228006,
                               0,
                               0.075610910944936174,
                               0,
                               0,
                               0,
                               0,
                               0.41371121938615257,
                               0,
                               0,
                               -0.83443071310183525,
                               0,
                               0,
                               0,
                               0.12270815483545244,
                               0,
                               -0.30586846634935239,
                               0,
                               0,
                               0,
                               0,
                               0.68895499384215309,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14505612617274927,
                               0,
                               0,
                               -0.51074555034749525,
                               0.39452912248289557,
                               -0.43174778126601032,
                               0,
                               0,
                               0,
                               0,
                               0.72591426195155984,
                               -0.13104354614176897,
                               0,
                               0,
                               0.14065343384158055,
                               0.56037802166222062,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12697924383877235,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31356689042693442,
                               0,
                               0,
                               -0.21133776304383872,
                               -0.8223478165831658,
                               -0.6685923136904045,
                               0,
                               0,
                               0,
                               0,
                               0.53663160387336617,
                               -0.023223789480743745,
                               0,
                               0,
                               -0.033361505603640165,
                               -0.65588156238877993,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40917278949496927,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.094288654636301816,
                               0,
                               0,
                               -0.79115860812682814,
                               0.1017521907923,
                               0.0383755746752176,
                               0,
                               0,
                               0,
                               0,
                               -1.0262180473377203,
                               -0.25817241700863824,
                               0,
                               0,
                               0.59415446099927638,
                               -0.1905423048530159,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.95687419921542782,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13734173354994689,
                               0,
                               0,
                               -0.43792360261589203,
                               0,
                               0,
                               0,
                               0.60248693853686408,
                               0,
                               -0.89644473697463845,
                               0,
                               0,
                               0,
                               0,
                               -0.88930725403232147,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.029720510909691328,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13211531873736015,
                               0,
                               0,
                               0,
                               0,
                               -0.96690663124193532,
                               0,
                               0,
                               0,
                               -0.21622627094450037,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.4331695969548377,
                               0,
                               0,
                               0.52339610026317107,
                               0,
                               0,
                               0,
                               1.1168734403201532,
                               0,
                               0.1339892777091648,
                               0,
                               0,
                               0,
                               0,
                               0.78993792363730364,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.80194465142001004,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36870738435298878,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.000550411729392,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0923912028546441,
                               0,
                               0,
                               0.2305210015610793,
                               0.46238592077366025,
                               -0.060129862963451929,
                               0,
                               0,
                               0,
                               0,
                               0.39398981683366124,
                               -0.4641141892637799,
                               0,
                               0,
                               -0.24849287260213185,
                               -0.3625370228830001,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57974574348303909,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37903887549518578,
                               0,
                               0,
                               -0.59290206491824637,
                               0.10148616288673551,
                               0.56501822483556841,
                               0,
                               0,
                               0,
                               0,
                               0.2268770313929809,
                               -0.11403820243986826,
                               0,
                               0,
                               0.18098771212794273,
                               0.024879698220012236,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.88118017902056067,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.036867479582050888,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.98333910408142811,
                               0,
                               0,
                               0,
                               0,
                               -0.10034972855296176,
                               0,
                               0,
                               0,
                               -0.1470201595460601,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0009513273239297,
                               0,
                               0,
                               -0.064115394216836818,
                               0,
                               0,
                               0,
                               -0.11092516217594223,
                               0,
                               -0.29821863225844669,
                               0,
                               0,
                               0,
                               0,
                               0.30223828252057794,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67579449251048507,
                               0,
                               0,
                               -0.096771422445005306,
                               -0.36085380642942522,
                               1.2290350565640684,
                               0,
                               0,
                               0,
                               0,
                               0.24096409768365148,
                               -0.21253629182005782,
                               0,
                               0,
                               0.20112971517009559,
                               0.29695210524755256,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21891162174358927,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.52314623546151395,
                               0,
                               0,
                               0.14170275538413113,
                               0.61102339835379504,
                               0.19559462584485987,
                               0,
                               0,
                               0,
                               0,
                               -0.0083985942755784963,
                               0.73042328206098839,
                               0,
                               0,
                               -0.22532838439693856,
                               -0.86261321667658286,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.025642444593591378,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.98948352114165261,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.048558931371743747,
                               0,
                               0,
                               0,
                               0,
                               0.063953791066590826,
                               0,
                               0,
                               0,
                               -0.12030920239683206,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.092711358272773089,
                               0,
                               0,
                               0,
                               0,
                               3.1050294747953823e-05,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.040668181866777522,
                               0.074159532186639801,
                               -0.37118117149918295,
                               0,
                               0,
                               -0.14347187265278419,
                               0,
                               0.90878568735131759,
                               0,
                               0.85889891946094088,
                               0,
                               0,
                               0,
                               0,
                               0.12257270482111672,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.2885813708473971,
                               0.095499103078539302,
                               0.12630714447892838,
                               0,
                               0,
                               0.37270820569100843,
                               0,
                               0.0020953655675581481,
                               0,
                               0.048620026093574437,
                               0,
                               0,
                               0,
                               0,
                               0.52602224302855005,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.042862836603487414,
                               -0.11029383345618286,
                               0.64328378435517752,
                               0,
                               0,
                               -0.50900413240157949,
                               0,
                               0.18448714433669308,
                               0,
                               0,
                               -0.1158216750357669,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.614542460846687,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.65636335035027571,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.43518043928137551,
                               0,
                               0,
                               0.35708709216947476,
                               0.30176532094022762,
                               0.03578725844824393,
                               0,
                               0,
                               0,
                               0,
                               -0.24577541325141039,
                               -0.93664058973776076,
                               0,
                               0,
                               -0.070668670247427456,
                               -0.59124156339752743,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25590174700057855,
                               0,
                               0,
                               0,
                               0,
                               0.2777946232104116,
                               0,
                               0,
                               0,
                               0,
                               -0.080400289962275703,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23376402720919387,
                               0.25502085318820628,
                               -0.4016178152398146,
                               0,
                               0,
                               -0.72207197720038252,
                               0,
                               -0.33763867511792733,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28904317015556186,
                               0,
                               -0.95731606368347499,
                               0.16797444529420652,
                               0,
                               0,
                               0,
                               0,
                               0.47402232795216576,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28378569169719442,
                               -0.664230689591639,
                               -0.45488439107350276,
                               0,
                               0,
                               0.0018594171738456344,
                               0,
                               -0.13574764767369268,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.95731606368347499,
                               0,
                               0.28904317015556175};

const double rot_10_2[4] = {0.0054104988346266869, 0.99998536314406161, -0.99998536314406128, 0.0054104988346269645};

const double rot_9_50[2500] = {-0.38821095420643859,
                               0,
                               0,
                               0,
                               0.20453415847666104,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3311748997690524,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15869349748134023,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.75376501555024844,
                               0,
                               0,
                               -0.32316542822988037,
                               0,
                               0,
                               0,
                               0.0076722265736122452,
                               0,
                               0.62616066216174238,
                               0,
                               -0.70578896831154825,
                               -0.252118415559204,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.072214101919924431,
                               0,
                               0,
                               0,
                               0.2078393842446945,
                               0,
                               0,
                               0.90800442612397947,
                               0,
                               0,
                               0,
                               -0.51172855568817643,
                               0,
                               0.054511351174121543,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61367710081461102,
                               0,
                               0,
                               0.88724571032142119,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4596087525393443,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.38877127649844562,
                               0,
                               0.58782488579562786,
                               0,
                               0,
                               0,
                               -0.38087182167439992,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23999604775488989,
                               0,
                               0,
                               0,
                               -0.047392284203579597,
                               0.6603023827738308,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.61469583880875689,
                               0,
                               0.21409134971374119,
                               0,
                               -0.028733355911318259,
                               0.25907713859463805,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.83091052697528456,
                               0,
                               0,
                               0,
                               0.68332287223158872,
                               0,
                               0,
                               0.36292204276048368,
                               0,
                               0,
                               0,
                               -0.75460431569933939,
                               0,
                               -0.69629245314550492,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.4411162456997676,
                               -0.46279256174686439,
                               0,
                               0,
                               0,
                               0.20074127834424807,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.72206939346559429,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.013576849716676775,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20453433934391604,
                               0,
                               0,
                               0.42675888761880459,
                               0,
                               0,
                               0,
                               -0.39849270894079636,
                               0,
                               -0.090218727328622253,
                               0,
                               0.54694284106603297,
                               -0.03591616950363663,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0381411515374435,
                               0,
                               0,
                               0,
                               0.14906392972652213,
                               0,
                               0,
                               0.44256952740800748,
                               0,
                               0,
                               0,
                               -0.09869236472451097,
                               0,
                               0.086786270646998509,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.66317684736659899,
                               0,
                               -0.47318687419185335,
                               0,
                               -0.67113300995209269,
                               0,
                               0.17486797115712047,
                               -0.12263188927170869,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28721453895294546,
                               0,
                               0,
                               0,
                               -0.56026267957942133,
                               0,
                               0,
                               0.33360544553992821,
                               0,
                               0,
                               0,
                               -0.24771227971797938,
                               0,
                               0.57500939490961411,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0033495449323679566,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25310385368279653,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.021446766364702434,
                               0,
                               0.44998906343833228,
                               0,
                               0,
                               0.64215372173105023,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56623927443816746,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20687839609787953,
                               0,
                               0.12587482239169828,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.54353534492772093,
                               0,
                               0,
                               0,
                               -0.19620429520267296,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.62897061689859424,
                               0,
                               0,
                               0.37660482183775196,
                               -0.25534430787100398,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.069239564981213253,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.054658515273192848,
                               0,
                               0,
                               0,
                               -1.1931461762040869,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39393853910340754,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.36802873462377872,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.60028326348026684,
                               0,
                               -0.014417331204755012,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50114127082918336,
                               0,
                               0,
                               0,
                               -0.18550041108810489,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32872059495973699,
                               0,
                               0,
                               -0.38783618452189811,
                               -0.1314764377243863,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27953350255807818,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.92250346786928561,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30832927548504274,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.49122474972775304,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.62121127044928159,
                               0,
                               0,
                               0,
                               0.25149824741294802,
                               0,
                               0,
                               -0.71709002206060568,
                               0,
                               -0.7266009823549926,
                               0,
                               0,
                               0,
                               0.17300680727136417,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23506028608657661,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10711113941891887,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.582860987165158,
                               0,
                               0,
                               -0.18885600979758102,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.4440101997492951,
                               0,
                               0,
                               0,
                               -0.13293629866898901,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18397269541633765,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.084933854221478033,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.88512877893638442,
                               -0.32459808412692853,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33344134188746355,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46384856120884338,
                               -0.67286717542630536,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57627621545428287,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51514511205875146,
                               0,
                               -0.022536641852818132,
                               0,
                               0.19611024334802191,
                               -0.4883479684169485,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14430553791893763,
                               0,
                               0,
                               0,
                               0.87782014680679288,
                               0,
                               0,
                               -0.13943417977410702,
                               0,
                               0,
                               0,
                               0.15293558037254654,
                               0,
                               -0.078157989487311397,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.63295459952786137,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.8108819404009181,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20683362313486392,
                               0,
                               -0.26154362932867548,
                               0,
                               0,
                               0.48060522361491531,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.017432156039473252,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18366404917961904,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50318300522996173,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27404839526605052,
                               0,
                               -0.40910804188423594,
                               0,
                               0,
                               0,
                               -0.69975376172309978,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35923589216162094,
                               0,
                               0,
                               0,
                               -1.3711289884375473,
                               0.49981615811028712,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.38567432580804106,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22893081223128803,
                               0,
                               0.81391937627550437,
                               0,
                               0,
                               -0.096327543418328498,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35651402626813955,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63409097539029269,
                               0,
                               0.66234962885583637,
                               0,
                               -0.39558906522077286,
                               -0.18717666099383645,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29593202309581018,
                               0,
                               0,
                               0,
                               -0.318971473895375,
                               0,
                               0,
                               -1.0531409721889124,
                               0,
                               0,
                               0,
                               -0.47488976043353992,
                               0,
                               -0.26969303332612182,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49703399001422255,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27584674888702787,
                               0,
                               0.26468334039378127,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.030847138853169843,
                               0,
                               0,
                               0,
                               -0.5608008549122816,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30123721720641455,
                               0,
                               0,
                               -0.27255747088920596,
                               0.52963377841073833,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30472738701871749,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22799261772851043,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58857508705505057,
                               0,
                               0.21933954398905253,
                               0,
                               0,
                               -0.53727291740027849,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51461316523221656,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.68288126295350549,
                               0,
                               0.565125422249104,
                               0,
                               0.32704008503251092,
                               -1.1227507610559462,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.65320610897931697,
                               0,
                               0,
                               0,
                               -0.056771148993151985,
                               0,
                               0,
                               0.30106262432101433,
                               0,
                               0,
                               0,
                               0.059187968272264427,
                               0,
                               0.36205936143622108,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27488728578296512,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1340974635009613,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30159946308192975,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28712114108797337,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40177171198013018,
                               0,
                               0,
                               0,
                               -0.85465670970038332,
                               0,
                               0,
                               0.23749132888214838,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41139081238070402,
                               0,
                               0.34576085609713342,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.088023699553803833,
                               0,
                               0,
                               0,
                               -0.37693801259849485,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.45336342640158833,
                               0,
                               0,
                               0.27227467030386504,
                               -0.23780932201966654,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.47450123996440718,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16876083765311109,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.53120503644407868,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17381921419386309,
                               0,
                               -0.46760177943372239,
                               0,
                               0,
                               0,
                               -0.53896366360820425,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.9734645737000196,
                               0,
                               0,
                               0,
                               0.11244951153648755,
                               -0.61676820478018635,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5686481128507046,
                               0,
                               0.46029704913612324,
                               0,
                               -0.65330408293828546,
                               -0.034609863471013448,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34676739812867025,
                               0,
                               0,
                               0,
                               0.55373053030647001,
                               0,
                               0,
                               0.1931408880852277,
                               0,
                               0,
                               0,
                               0.55972022486567807,
                               0,
                               0.99158734147852035,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3405235747876158,
                               0,
                               0,
                               -0.72520167795893908,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.813114368878321,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.044789736881740851,
                               0,
                               -0.066070278783068537,
                               0,
                               0,
                               0,
                               0.59950300238399834,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.107645451194498,
                               0,
                               0,
                               0,
                               -0.29042482944563136,
                               0.47899554086873197,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.076480474504003637,
                               0,
                               0.59279067048238132,
                               0,
                               0.53206317900620836,
                               0.41109643109344873,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.086531369882079157,
                               0,
                               0,
                               0,
                               0.14173433659150456,
                               0,
                               0,
                               -0.32581017303288673,
                               0,
                               0,
                               0,
                               -0.20905884135772596,
                               0,
                               0.52359822648088949,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28752272607287466,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2486297797347321,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18436786311232947,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.241930301145372,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.45512114522191177,
                               0,
                               0,
                               0,
                               -0.50609831897827706,
                               0,
                               0,
                               -0.0076460018767320892,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11014573582099096,
                               0,
                               0,
                               0,
                               0.071224770880532501,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1936387476691406,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.4721217703112741,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10231809837579744,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.8125477430542889,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10389519987769469,
                               0,
                               -0.46447116890047246,
                               0,
                               0,
                               0,
                               0.093278637412801568,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30492330059071504,
                               0,
                               0,
                               0,
                               0.54829919937872051,
                               0.55061878295723721,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38607817663680366,
                               0,
                               -0.5638185167224572,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.072512684670636679,
                               0,
                               0,
                               0,
                               0.070724862031283697,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.092462131660249872,
                               0,
                               0,
                               0.38253894960343127,
                               0.54710561621633436,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2618823726940892,
                               0,
                               0,
                               0,
                               -0.022917368422314937,
                               0,
                               0,
                               0,
                               -0.11860187447580195,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16125224457834575,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.94414548515592034,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18593119105432462,
                               0,
                               0,
                               -0.1828250482474415,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27871777599638969,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.74694707889024214,
                               0,
                               -0.13612562620405239,
                               0,
                               0,
                               -0.24231391480515868,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.535854684838448,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15096774379298875,
                               0,
                               -0.67824791354043024,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15860733394430068,
                               0,
                               0,
                               0,
                               -0.4020722538185183,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.045704706958331683,
                               0,
                               0,
                               -0.29458631785495792,
                               -0.42436117700616682,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24782594090397392,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13625388327583418,
                               0,
                               0.12483904312190483,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.089192414622942612,
                               0,
                               0,
                               0,
                               0.55057967040970424,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26952966133676509,
                               0,
                               0,
                               -0.3729014501380673,
                               -0.1246445390945756,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.65384924969632763,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.49245994505265367,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23685503665582924,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19314762203686872,
                               0,
                               -0.22349362054088223,
                               0,
                               0,
                               0,
                               -0.73116373932235124,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.75867999859954582,
                               0,
                               0,
                               0,
                               1.0113040412641199,
                               0.089613630352392268,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.037303578421796907,
                               0.66474494959717667,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.7461384556648829,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22688775580151113,
                               0,
                               0,
                               0,
                               0.86739641611195251,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.3962366540942144,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.94149190815345452,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.070073108406920465,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.5988766311260216,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27227036253300235,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.067416240282614365,
                               0,
                               0,
                               0,
                               -0.19823570144075717,
                               0,
                               0,
                               0.3459936048705235,
                               0,
                               0,
                               0,
                               0.90519275798374721,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.76223648638449126,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.025740311711550279,
                               0,
                               -0.63957878416029756,
                               0,
                               0,
                               0,
                               0.33462646084025394,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44817087464941047,
                               0,
                               0,
                               0,
                               -0.11717496655825491,
                               -0.28203643173788628,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.019447420384993943,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.033577828957340752,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.2736626706337888,
                               0,
                               -0.18273767087734813,
                               0,
                               0,
                               0,
                               0.044557543027313865,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41316827984817067,
                               0,
                               0,
                               0,
                               -0.61564383988008453,
                               -0.084158743682482925,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32637584954752447,
                               0,
                               0,
                               0,
                               0.8957967299557249,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13538456373633539,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.026906892628947507,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12331386173809171,
                               0,
                               0,
                               -0.23825984547753132,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.79358950948514395,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.070160337167153586,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46409168729458405,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.2324122668939293,
                               0,
                               0,
                               0,
                               1.1362479256231179,
                               0,
                               0,
                               0.56769054959380694,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4013910369972995,
                               0,
                               -0.029042910479227864,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63746166565693696,
                               0,
                               0,
                               0,
                               0.026674537477039961,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.34171928790902267,
                               0,
                               0,
                               0.43261783709336227,
                               -0.29241202594366522,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20380819664707592,
                               0,
                               0,
                               0,
                               0.010950402887028534,
                               0,
                               0,
                               0,
                               0.26724366371195141,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51899361480508754,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2665043504523657,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.022368699088191016,
                               0,
                               0,
                               0.76653872254768574,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23154365598910012,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49510229378028647,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.061126531885394908,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.3985783910305511,
                               0,
                               0,
                               0,
                               0.364947015067137,
                               0,
                               0,
                               -0.3948594776380831,
                               0,
                               0,
                               0.62659256234545491,
                               0,
                               -0.56570412422711103,
                               0,
                               -0.34443091629472755,
                               -0.28901724449120569,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15148914964332172,
                               0,
                               0,
                               0,
                               0.4930177495191379,
                               0,
                               0,
                               -0.55923473303910165,
                               0,
                               0,
                               0,
                               -0.8048703524717411,
                               0,
                               0.56873445982099424,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18144026272087255};

const double rot_9_20[400] = {1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.17959355038184827,
                              0,
                              0,
                              0,
                              0,
                              0.3883630270548481,
                              0,
                              0,
                              1.7967487628790486,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.68858729747152903,
                              -0.69425238947003676,
                              0,
                              0,
                              0,
                              0,
                              -0.028016876269052797,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.20754808628393584,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.24056630068552698,
                              -0.24191969701164123,
                              0,
                              0,
                              0,
                              0,
                              0.93295926598951595,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.11484652008911647,
                              0,
                              0,
                              0,
                              0.70298589023707936,
                              0,
                              0,
                              0,
                              0,
                              -1.0236297681034761,
                              0,
                              0,
                              -0.35923145546437879,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.01145634411319911,
                              0.76745343250624032,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.64100232535767832,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.96636023241334823,
                              0.17321643063521769,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.19011567365163357,
                              0,
                              0,
                              0,
                              0,
                              1.5503381470918656,
                              0,
                              0,
                              0,
                              0,
                              0.67211309232757666,
                              0,
                              0,
                              0.089842653111804338,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.19768256478655308,
                              -0.45283721280280298,
                              0,
                              0,
                              0,
                              0,
                              -0.061642006446454123,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.86721411734453135,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.25693706114451426,
                              0.61726112553147672,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.74362090443856799,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.65490227691980629,
                              0.50440751244795023,
                              0,
                              0,
                              0,
                              0,
                              0.35355667959986742,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.43780559998890056};

const double rot_9_10[100] = {0.64684837003248408,
                              1.2089928947674122,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.2105859772131158,
                              0,
                              -0.42136626294544766,
                              -1.0891014743959637,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.52698477310920011,
                              0,
                              0,
                              0,
                              -0.50177677405194698,
                              0.39461328272817486,
                              -0.75067427135414322,
                              0,
                              0.17026028439844734,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.51104331518596058,
                              -0.085216714153634937,
                              0.46030847557115978,
                              0,
                              0.72089454773216044,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.66645779361361912,
                              0.47477630944385846,
                              -0.066401173981215256,
                              0,
                              0.57097491137216605,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.37827569332621785,
                              0,
                              -0.34317918378759948,
                              0,
                              0.85972992715936447,
                              0,
                              0,
                              0.20709613313007758,
                              -0.78205237977658582,
                              -0.46924953887904614,
                              0,
                              0.35399171909827332,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.83904502850187834,
                              0,
                              0.26521597506342781,
                              0,
                              0.47504097372483289,
                              -1.1014141704440727,
                              0.083199219322819443,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.096797116972810196,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.39103828455133538,
                              0,
                              -0.90104857493146961,
                              0,
                              -0.18761803119401088};

const double rot_9_100[10000] = {0.36692362826680552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14904841663130855,
                                 0.21689656047191724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22807218076916336,
                                 0,
                                 0,
                                 0,
                                 0.34190695534659554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013617369607452724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28537523601533066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63246312543277683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20685361630561866,
                                 0,
                                 0,
                                 -0.32057407119533909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79061272908316071,
                                 0,
                                 0,
                                 0,
                                 -0.10480140022014102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24031209234001472,
                                 0.075391413690489809,
                                 0.32664610529334942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24365415735474119,
                                 0,
                                 0.09056545511682719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27022514937564429,
                                 0,
                                 0,
                                 0.036584658866811892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5305347718453528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28377588438399676,
                                 -0.058947628527971738,
                                 0,
                                 0,
                                 0,
                                 -0.60367704886689499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27949645183535382,
                                 0,
                                 0,
                                 0,
                                 0.21234615279492963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090069279936530369,
                                 0.47356152233227977,
                                 0,
                                 0,
                                 -0.38240435606210621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15472934963641155,
                                 0,
                                 0,
                                 0,
                                 0.0053482037907528653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34017351471685225,
                                 0,
                                 -0.49461303494966213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16942316908087504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11133548586425024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017693183448249189,
                                 0,
                                 0,
                                 -0.38802104386459657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1653451824402214,
                                 0,
                                 0,
                                 0.58914415260516828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0406312713710415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80675902893318707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33104419508057886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0276318453519355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16608788747756395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86202377408853081,
                                 -0.033253279463145102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38282210219656482,
                                 0,
                                 0,
                                 0.28678877856900387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75866160179927111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57994792629881164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094406357071516414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21837122099178063,
                                 0,
                                 -0.071636635353593714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023296920784771386,
                                 0,
                                 -0.50344853924112887,
                                 0,
                                 -0.57914837096205429,
                                 0,
                                 0,
                                 0,
                                 0.39834224492040149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065509136946653265,
                                 -0.21549777398534178,
                                 -0.56164214744813212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025597299533879528,
                                 0,
                                 0.2402904173340514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36783075596719206,
                                 0,
                                 0,
                                 -0.25722380032724473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57649832591027284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40166989677804693,
                                 0.3202075123297331,
                                 0,
                                 0,
                                 0,
                                 -0.61278382840737122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18895876506708165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44418764427587498,
                                 0,
                                 0,
                                 -1.0895221124217087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18527996130772154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48545639384642997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28831223253031407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12720545538179184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16112096058678604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24891065133153681,
                                 0.13288667847273686,
                                 0,
                                 0,
                                 0.03080898961381659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73242492853224173,
                                 0,
                                 0,
                                 0,
                                 0.20120603763977474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079180595185433328,
                                 0,
                                 0.15308908044241445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42153982275024032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075114530248042322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31576561715511758,
                                 0,
                                 0,
                                 -0.061591736766695639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45264324067841588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010829701026410479,
                                 -0.12612211050628166,
                                 0,
                                 0,
                                 -0.30754411705717521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24591408321477209,
                                 0,
                                 0,
                                 0,
                                 0.38963616646027754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.301601204613268,
                                 0,
                                 -0.11894724374852945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24301724960517959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34524038389987283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43456192423921419,
                                 0,
                                 0,
                                 0.0035297751386152987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56754898139741461,
                                 0,
                                 0,
                                 0.24636777085774458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40039593264843032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18280044120245345,
                                 0,
                                 0,
                                 0,
                                 0.1357635484995556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60929164226513954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.142808770395986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11574013856358956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054863568183183622,
                                 0,
                                 0,
                                 0.26795221992235962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018325579650014731,
                                 -0.44573327323451783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27425067000700137,
                                 0,
                                 -0.24653090538461875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32056689760398488,
                                 0,
                                 0,
                                 0,
                                 0.036183969747826526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15883272544083363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17075010760564857,
                                 0,
                                 0.32249433389539117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0070961410305389432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40293391385887667,
                                 0,
                                 0.4065982817274626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44095060013330123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22444955922441995,
                                 -0.33497862065730521,
                                 0,
                                 0,
                                 -0.29561522912701171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076974321055071876,
                                 0,
                                 0,
                                 0,
                                 0.33484363961081398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012797848064813433,
                                 0,
                                 -0.019918367483397259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36533858640429301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37694545596661533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39824038373943743,
                                 0,
                                 0,
                                 -0.053146265325598262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75440963752861656,
                                 0,
                                 0,
                                 0.29533321875924845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48779063843453896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049158735562674499,
                                 0,
                                 0,
                                 0,
                                 0.038521804804276943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17794580691564166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26482016989674007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0031206483883390174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36696316224752212,
                                 0,
                                 0,
                                 0.53569138834246055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23070749881374455,
                                 0.096566102967012235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19121569379389908,
                                 0,
                                 0.15287948599857493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011941635972555239,
                                 0,
                                 0,
                                 0,
                                 0.37570816135525259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11928796539311816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053957284975241826,
                                 0,
                                 -0.32593684342979773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41523981234520413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13188767374059557,
                                 0,
                                 -0.037319088296587519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49445798976937433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46251179435145162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21589444456849641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47871088641071624,
                                 0,
                                 0,
                                 0.85276849135636912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51579303067992655,
                                 0,
                                 0,
                                 0.47277977127731668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036655772737815881,
                                 0,
                                 0,
                                 -0.18868252740779862,
                                 0,
                                 0,
                                 -0.87154257753163966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90188962768980241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30498464466920261,
                                 0,
                                 0,
                                 -0.19668377101662526,
                                 -0.44862783722056143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64148280353016551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38328407011783339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57255047143136573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15688941335499573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15401507756555383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36501232156329777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35240549466873217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28156392038800687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21580242153281123,
                                 0,
                                 0,
                                 0,
                                 -0.77006934876869648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15747983331935261,
                                 0,
                                 0,
                                 0,
                                 0.069459155165632641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38735065382710038,
                                 -0.7181087075693583,
                                 -0.17083816504608781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46592383745000132,
                                 0,
                                 -0.016363600039469611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49078375922213141,
                                 0,
                                 0,
                                 0.23402400461708114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51316779676103175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053311636719894036,
                                 0.37422672268872104,
                                 0,
                                 0,
                                 0,
                                 0.36705031114592179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11539834307091298,
                                 0,
                                 0,
                                 0.0878808317448109,
                                 0,
                                 0,
                                 0,
                                 0.065564767002657204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6949351914529881,
                                 -0.36692372414000435,
                                 -0.3821237770096621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41473373011030773,
                                 0,
                                 -0.11875453751893468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1223102057372235,
                                 0,
                                 0,
                                 0.779989417571053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05749918349484695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039400861421733872,
                                 -0.3599183872786792,
                                 0,
                                 0,
                                 0,
                                 -0.09864749473780661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38203652416854683,
                                 0,
                                 0,
                                 -0.107436620098431,
                                 0,
                                 0,
                                 0,
                                 -0.79886988907511758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4171473971077222,
                                 -0.15903447592870398,
                                 -0.55877097000261555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22076008482172976,
                                 0,
                                 0.56083756213572145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019713477590471401,
                                 0,
                                 0,
                                 -0.14610171382904633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0030808265728044792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37689760283895896,
                                 0.010972092269185996,
                                 0,
                                 0,
                                 0,
                                 -0.18984119901616742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16979858286428581,
                                 0,
                                 -0.13698875529614052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19458605830338763,
                                 -0.81859253563106826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31387145507540359,
                                 0,
                                 0,
                                 0,
                                 0.0080570182026730441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012435687041705668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015114492565403922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20029789832668216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13160469375404688,
                                 0,
                                 0,
                                 -0.34186878170155122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62910596183057976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023401168828835101,
                                 -0.2886041921772744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.003456578987475254,
                                 0,
                                 0,
                                 0,
                                 0.42666521980214195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24168720198861937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00095352941028412769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4300034749666572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16338541482828678,
                                 0,
                                 0,
                                 0.26137930585994151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018798807027199591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59864208658609408,
                                 -0.34135081227222253,
                                 0,
                                 0,
                                 0.33137348263435124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060336366335832309,
                                 0,
                                 0,
                                 0,
                                 0.27765803757531271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36038787869406658,
                                 0,
                                 -0.22198186363881695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28696472390531064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2682787809940485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023442708986208489,
                                 0,
                                 0,
                                 0.013558888627165866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35661195710074434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073747635386994789,
                                 0.2019049664196492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14873053920196277,
                                 0,
                                 0,
                                 0.064099359461170846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41849446884382158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66219054489831819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33438563869504478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7331866085758787,
                                 0,
                                 0.43132814804251085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53283163448798243,
                                 0,
                                 -0.75300035077448046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32580005116349814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044304033210087405,
                                 0.10409750754681474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23597225310561593,
                                 0,
                                 0,
                                 0.53558534057202611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12163372106346459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88557339061065254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37918054946476504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50686741055744933,
                                 0,
                                 -0.1689331984076555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48417588803261258,
                                 0,
                                 0.12511361775727714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78448403636381292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.98237252627359495,
                                 0,
                                 0,
                                 0.046621454132928938,
                                 0.33366909724335608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20891846906032513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24610751752176629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6412824108955415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46909674622387365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011011982806139679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20229926545305302,
                                 -0.13874472307909505,
                                 0,
                                 0,
                                 -0.042467134568150662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44177623134755334,
                                 0,
                                 0,
                                 0,
                                 -0.28960338477649278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060731555871294883,
                                 0,
                                 -0.41279465847720059,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28865026357221374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51592101741980678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10767695263006571,
                                 0,
                                 0,
                                 0.3516934456655525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21467355279929945,
                                 0,
                                 0,
                                 -0.44042673241071989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11282176623826295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24364434749531044,
                                 0,
                                 0,
                                 0,
                                 -0.1830830610790109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48379538386926224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15838452339788778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62863757614685523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27449239668845105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23905066342240205,
                                 0,
                                 0,
                                 -0.18198217996658214,
                                 -0.067030278534604096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59461333017060092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60447591552345625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46622255775200727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0715333467788892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11981926812289984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072881739284154701,
                                 0,
                                 0,
                                 0.56901777663138675,
                                 -0.55973707890089841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72654005535771693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49433425224313071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88119122505387715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25722585428951866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21534967853092812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21737918936734812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24060041286177322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65448793355312851,
                                 0,
                                 0,
                                 0.76997353819211944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4250216637009725,
                                 0,
                                 0,
                                 -0.17603732801097827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0943728569348758,
                                 0,
                                 0,
                                 -0.071782697242195687,
                                 0,
                                 0,
                                 -0.33896802904513396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34150609129018339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65708607569334254,
                                 0.084659870205627569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65910470220709949,
                                 0,
                                 0,
                                 0.039949854200991258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71560561985293236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01285895169073312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18301653970660389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033562405832258446,
                                 0,
                                 0.39599641993111517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40141064590476022,
                                 0,
                                 -0.6060239851425494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05775084480946794,
                                 0,
                                 0,
                                 0.34661293614213878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070663916639461491,
                                 -0.16388833513005285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3551675837672435,
                                 0,
                                 0.15673063326798506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043826467244166056,
                                 0,
                                 0,
                                 0,
                                 -0.44496628582147207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047603612389730141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22903529064910022,
                                 0,
                                 -0.39149335933657026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35314755443786666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21837551324204119,
                                 0,
                                 -0.33712890640616072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046302899414919149,
                                 0,
                                 0,
                                 -0.040291165715781202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092359337797498969,
                                 0.37127509180625107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34333603057110212,
                                 0,
                                 0.079862939922856618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23413386213597168,
                                 0,
                                 0,
                                 0,
                                 0.15450956430215101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037229198722923587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10564963451390957,
                                 0,
                                 -0.22151437419038131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60343196733341542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34771004028630054,
                                 0,
                                 0.31663661297567203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17106490125256499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42734490362552774,
                                 -0.23859888444041163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34457397353158881,
                                 0,
                                 0,
                                 -0.35543281839055496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26582015736538589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054298031666535636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092774203981999037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61717438880580133,
                                 0,
                                 -0.12560919111443711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4840922846278381,
                                 0,
                                 1.10839345950943,
                                 0.10440512153545815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65149640740028536,
                                 -0.33826331494271117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33914683191463207,
                                 0,
                                 0,
                                 0,
                                 -0.26789105273624075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041337942616872049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46067510996960137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1285799740281986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13448400379758182,
                                 0,
                                 0,
                                 0.12204344442850006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0025281371667565389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15157756401460304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59994845109607975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08538477991760926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61124648215526445,
                                 0,
                                 0,
                                 0,
                                 -0.48597004439421576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095289956091535025,
                                 0,
                                 0,
                                 0.2885484056505947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12570811614320193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26608261394570759,
                                 0,
                                 0,
                                 0,
                                 -0.17719380695558651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39144204890577383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42855429913847154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6728847180395211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16351710384439588,
                                 0,
                                 0,
                                 0.18364806054599325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15460355410690316,
                                 -0.2667326857078427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044918301101210416,
                                 0,
                                 -0.17848122265163444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077986260870043261,
                                 0,
                                 0,
                                 0,
                                 0.51801000996351321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55899583539931263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38094771341984762,
                                 0,
                                 -0.12036779599096309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13950585026056897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20789084733997548,
                                 0,
                                 0.037830368630700731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1243265846973618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44353318453232904,
                                 -0.075082925003242318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14687598836807267,
                                 0,
                                 0,
                                 0,
                                 -0.28142943105658819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1562103738535158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22355964839667528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31877840935893842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0053688396007307293,
                                 0,
                                 0,
                                 0.71090055021947463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032969748464674403,
                                 0,
                                 0,
                                 -0.086510151625520254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20035751860630721,
                                 0.25851864415978942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10325836109931713,
                                 0,
                                 -0.27289554137424321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028993521927582477,
                                 0,
                                 0,
                                 0,
                                 -0.32115980787542653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63065377807437373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16859700399117056,
                                 0,
                                 -0.1978570857419257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35671372132815921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23728482756739222,
                                 0,
                                 0.21561567719989239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0071668663962325017,
                                 0,
                                 0,
                                 -0.027782565688761415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22736895003100063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1705255040200587,
                                 0,
                                 0,
                                 0,
                                 0.81007951394528355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27717891860877758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26332505065194894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34059378146748348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07607020626565468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23130048061014227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076511217671448709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47964240603747177,
                                 0,
                                 0,
                                 0.68570693949488037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28801318739119297,
                                 0,
                                 0,
                                 0.42323994032624801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33754392711471887,
                                 0,
                                 0,
                                 0.6967286401544639,
                                 0,
                                 0,
                                 0.45852041970073171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22649087419255523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59268075033491163,
                                 0,
                                 0,
                                 0.30416363357107989,
                                 1.1069328007886021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.005703593979018512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.664756414331238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69469731219784903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12471725136492975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.055493955509289219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35310555942129168,
                                 -0.34881600587103645,
                                 0,
                                 0,
                                 -0.17361942611462683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14184329208979574,
                                 0,
                                 0,
                                 0,
                                 -0.27714093429320419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22620403049734816,
                                 0,
                                 0.24509654260564109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044747064012066934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16154831542020884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085868049224116311,
                                 0,
                                 0,
                                 -0.69049250417284513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12797395145570412,
                                 0,
                                 0,
                                 0,
                                 -0.17060254578152637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39589750759117925,
                                 -0.16547262185989897,
                                 0.34257232227558182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11418934985804971,
                                 0,
                                 -0.44092500387149824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64745349355779969,
                                 0,
                                 0,
                                 0.38788985249329794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45898624955196199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6890442802229324,
                                 -0.081052192814572266,
                                 0,
                                 0,
                                 0,
                                 0.043458238267085836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12493112969297918,
                                 0,
                                 0,
                                 0,
                                 -0.23743755714984852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16722339953865811,
                                 0.47045114642708297,
                                 0,
                                 0,
                                 0.27823553083836905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25161572596958226,
                                 0,
                                 0,
                                 0,
                                 0.010724312366306953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18562569913647547,
                                 0,
                                 0.33168301435474967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17275790653831349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034136648327779504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58460487115889848,
                                 0,
                                 0,
                                 -0.19039690719763522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10472892967835516,
                                 0,
                                 0,
                                 0,
                                 -0.20348044088837558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23062850177578292,
                                 0.66330772097112267,
                                 -0.213294666876093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36436823836160209,
                                 0,
                                 -0.67207122395649643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38072176703389909,
                                 0,
                                 0,
                                 -0.15045826056490774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32547527385850611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17245403501123291,
                                 0.71194986697420026,
                                 0,
                                 0,
                                 0,
                                 0.15621334465466721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12450707682778767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36234361799353654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29822242784720215,
                                 1.1601390480867018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10227191247359169,
                                 0,
                                 0,
                                 -0.21907298359942853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.100226100747909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2274645294341188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42177818183215449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088332878384068947,
                                 0,
                                 0.64432223367776054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069592249347296103,
                                 0,
                                 0.14882541161388979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67674147576495036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50985187784550368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14758840856337679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48523922889374133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12393613279560334,
                                 0,
                                 0,
                                 0,
                                 0.097326384012260375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1821323157470538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3731488026675166,
                                 -0.10650903146411834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088888710195282952,
                                 0,
                                 0,
                                 0,
                                 0.33995458108112725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37029721207455407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45297748071156135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2741915909084286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39313800660468506,
                                 0,
                                 0,
                                 0.34745669195280049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50562309276397022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5257572960547251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43402940724258987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33512312256948518,
                                 0,
                                 0,
                                 0.34274905035513581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68356114994801309,
                                 0,
                                 0,
                                 -0.27062152226735375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43252097011190455,
                                 0,
                                 0,
                                 0.13728580639762716,
                                 0,
                                 0,
                                 0.058978143502145919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28679820632596914,
                                 0,
                                 0,
                                 -0.52489818702979252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1225601533172695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085591929344913609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18062436045864394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40401272903663937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35671193711466015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29917017596812678,
                                 0.14296484172165014,
                                 0,
                                 0,
                                 -0.10016523730538296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14173084333632813,
                                 0,
                                 0,
                                 0,
                                 -0.29186959625626363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23687966648638939,
                                 0,
                                 0.25601454079152586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56612598963774052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11912448544570221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26246837003442086,
                                 0,
                                 0,
                                 0.34967404806563096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13090190025531229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.213106711858633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11727241908163749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27091469073932078,
                                 0,
                                 0,
                                 0.49341379254099937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43162504252373474,
                                 0,
                                 0,
                                 -1.0765364520507339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21216469992162917,
                                 0,
                                 0,
                                 -0.091811073932547643,
                                 0,
                                 0,
                                 0.16811444940672737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1733730069950063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043207724999074153,
                                 0.091825193796603727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1054800774169532,
                                 0,
                                 0,
                                 0,
                                 -0.33276749476525952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31991403358593529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15225530231886727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14760492070285888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83094217104120294,
                                 0,
                                 0,
                                 -0.0020010562459022996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029437167896290944,
                                 0,
                                 0,
                                 0.14339423485091515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25546189699048744,
                                 0.18600168062860345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094185315145346074,
                                 0,
                                 -0.68422939935872618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40998285155959246,
                                 0,
                                 0,
                                 0,
                                 -0.087707900327717928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29405841954728734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32664211876967625,
                                 0,
                                 -0.11090600682109231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0028912000179873894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13308156606541641,
                                 0,
                                 0.05205909319707186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016505958947736335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17459531259242575,
                                 0,
                                 0,
                                 1.0359279367804495,
                                 0.50660828565792682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083968696744915361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6518930357030075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11995503824847109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77796135890383822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18554664714392027,
                                 0,
                                 0,
                                 0.3694483873106072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088278591087727828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063651318647012164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0809139624098538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18578224954101516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15770225575716157,
                                 0,
                                 0,
                                 0,
                                 -0.29075323454952789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49823827545349231,
                                 -0.15939532059934231,
                                 -0.57255431386694855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50094449763755211,
                                 0,
                                 -0.78479125089158697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043804701831184678,
                                 0,
                                 0,
                                 -0.5038038201911772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43720219162461033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024801154047005024,
                                 -0.56165201476443272,
                                 0,
                                 0,
                                 0,
                                 -0.0063061497229855625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32062037433135421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48757586597178215,
                                 0,
                                 0,
                                 0.1502509135356481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61397172765186836,
                                 0.11907692486928435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19582571551666184,
                                 0,
                                 0.012667986538749324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18584256471238003,
                                 0,
                                 0,
                                 0,
                                 0.067287114285470573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21573780850891439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055885548609741348,
                                 0,
                                 -0.10211499083658235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14459152759670663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21645234906450045,
                                 0,
                                 0.37832372510541407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27491418811462243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29680991426166009,
                                 -0.20512787305638555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64802729699868922,
                                 0,
                                 0,
                                 0,
                                 0.09510929341116868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46790028765287373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26368620646286745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12243400482876667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20403353041231986,
                                 0,
                                 0,
                                 0.14206548694416393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25932571463212611,
                                 0,
                                 0,
                                 0,
                                 -0.044732478049560209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50659732873745877,
                                 -0.16885223207783809,
                                 -0.065349956640340601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07947661698137333,
                                 0,
                                 -0.32681942656391472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03056050387790743,
                                 0,
                                 0,
                                 -0.78726681799199094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093134286098915109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89925894638855142,
                                 -0.049654572583934964,
                                 0,
                                 0,
                                 0,
                                 -0.25977148692377133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25393173225546556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17967188601566639,
                                 0,
                                 0,
                                 0.25309449313306931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71570889898628443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13259415853226283,
                                 0,
                                 0,
                                 0,
                                 0.45035476983712569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36226298815464719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18995119369037669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060872035206467209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32847620278005191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70177681123552405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042883099833543548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43861569199348338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32397874546672545,
                                 0,
                                 0,
                                 0,
                                 -0.31690342123562987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34947383167163398,
                                 0,
                                 0,
                                 -0.048190616500040702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11600007200087363,
                                 -0.38507631902212192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12517564204419052,
                                 0,
                                 -0.020512327047451658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44228498123296928,
                                 0,
                                 0,
                                 0,
                                 0.14470533516008288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030973962413389518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55631591241960021,
                                 0,
                                 -0.29273557365821157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051555602758936003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23614253335043939,
                                 0,
                                 -0.16309018558853394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12142431300249677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13284546920289325,
                                 0.43694334177987632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35638425884736363,
                                 0,
                                 0,
                                 0.55743806852025291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038974542363143128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45001157765583655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67428511529923152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56847976666086153,
                                 0,
                                 -0.50679393423558761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63924082386753667,
                                 0,
                                 -0.15545367978202099,
                                 -0.11822598351505366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28687891141753752,
                                 0.13153385825649613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52327114249606677,
                                 0,
                                 0,
                                 0,
                                 0.15140289223109771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66841198892416076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03209064386759513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3186198583137535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091659914980348381,
                                 0,
                                 0,
                                 0.17877884747753589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28489850209449463,
                                 0,
                                 0,
                                 -0.052579556265237422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62156882831617633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73420212689466358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12024968634971925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6145908935894735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14721384014287653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42633483648166254,
                                 -0.16976196126452281,
                                 0,
                                 0,
                                 0.48440912415710452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023132348655262314,
                                 0,
                                 0,
                                 0,
                                 -0.38335599558055533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10915921245531307,
                                 0,
                                 -0.36961657547528259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22957318263535759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11946307838870118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31888965372152678,
                                 0,
                                 0,
                                 -0.26153472703952441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52123288237324061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081862046287057399,
                                 0.018857541926079038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0091321846393087602,
                                 0,
                                 0,
                                 0,
                                 0.54014019616579312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099832012149567828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59766265084074122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20817957062337009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0053493093013392556,
                                 0,
                                 0,
                                 0.1374410015898907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14403824858035141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08794690426706947,
                                 0.75533525877897956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21150639648235223,
                                 0,
                                 0,
                                 -0.34837494761653998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15554101828814135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099642281722244722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48083197227403968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40644970042163031,
                                 0,
                                 -0.85348327514255862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66852731521435849,
                                 0,
                                 -0.13618243117514281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050335829335648619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18213539111660393,
                                 0,
                                 0,
                                 0.61323661231628912,
                                 -0.30069511960114803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60352757563054305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62009720702136573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040490726648215292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20077755600325603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40687327029344134,
                                 0,
                                 0,
                                 0,
                                 -0.042016913253195232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12959680461384748,
                                 -0.59311284052443258,
                                 0.14615419845461544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48730603297089647,
                                 0,
                                 -0.27301378514106139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17439872105665932,
                                 0,
                                 0,
                                 0.028433036673027837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53574114282248542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43124402757573999,
                                 0.29402209684226921,
                                 0,
                                 0,
                                 0,
                                 -0.061527961168126144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32662079651639242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4074179676834716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1745481527075023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041925850441789161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062990617086618683,
                                 0,
                                 0,
                                 0.062382668758505302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18549214641706632,
                                 0,
                                 0,
                                 -0.33754566317857804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36824576562167721,
                                 0,
                                 0,
                                 0.21489852248814453,
                                 0,
                                 0,
                                 -0.35402126436193593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05052452237699924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19239614337996275,
                                 -0.26678104895734189,
                                 0,
                                 0,
                                 -0.36849562300926353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094205608930075097,
                                 0,
                                 0,
                                 0,
                                 -0.39953589205647982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62240426933636872,
                                 0,
                                 0.25026827928120415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025743330182432526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32188090266068586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13877286512373335,
                                 0,
                                 0,
                                 0.106850315172073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65121531716529046,
                                 0,
                                 0,
                                 -0.83982023285579288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1632939420277838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07544382133094657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18674685481736952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73751434031528962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025459351601408033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014204677377263299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64573711174419468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24481672195414458,
                                 0,
                                 0,
                                 -0.17192160058373515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10904020620898616,
                                 0,
                                 0,
                                 -0.29106250834631398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29232299976548876,
                                 0,
                                 0,
                                 1.0942139406302889,
                                 0,
                                 0,
                                 -0.37069994221864944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56411606309123563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13860418589801476,
                                 -0.1754012323319136,
                                 0,
                                 0,
                                 0.26683536165657767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24795085599172922,
                                 0,
                                 0,
                                 0,
                                 0.25668287376313359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33507857073227498,
                                 0,
                                 0.25064138985988549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17230722120577546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47244350173751676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037700509761870643,
                                 0,
                                 0,
                                 -0.061780220822383151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50946911646201654,
                                 0,
                                 0,
                                 0.20000753169482055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36798219777709296,
                                 0.13123056679233275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09397780700894387,
                                 0,
                                 0.44338067144475035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052793156721015609,
                                 0,
                                 0,
                                 0,
                                 -0.099157364982484147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0040913106099711438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30380656306902359,
                                 0,
                                 0.13813426406236298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.307333172155838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32216298621006989,
                                 0,
                                 0.14187807710103853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028459259285153672,
                                 0,
                                 0,
                                 0.69016098278480076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091459810359783691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17726539142334508,
                                 0,
                                 0,
                                 0,
                                 -0.23646924344443709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038867081238378953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63958567671907873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12877026648893064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15700698848824465,
                                 0,
                                 0,
                                 0.37939359178495957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38604272042665794,
                                 0.066746110407598258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071226754346638971,
                                 0,
                                 -0.096914503965757182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30386807578287001,
                                 0,
                                 0,
                                 0,
                                 -0.26818995075828583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075032297819664806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35222047137781615,
                                 0,
                                 -0.22797162506209484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041739508875861038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54368071770562176,
                                 0,
                                 0.14215089389353336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086329639102244143,
                                 0,
                                 0,
                                 0,
                                 -0.47348248446095564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34675307011048806,
                                 -0.0052766685681392214,
                                 0.47524400327708427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63352693522178571,
                                 0,
                                 0.30324811384974476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35695271098553788,
                                 0,
                                 0,
                                 -0.82042589569656288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47523005542636781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51931472055991668,
                                 -0.24553656288822129,
                                 0,
                                 0,
                                 0,
                                 0.47569971229673919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32848923270139185,
                                 0,
                                 0,
                                 0.87748048895590036,
                                 0,
                                 0,
                                 0,
                                 -0.33583066304512843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077451472060753021,
                                 -0.075245892050388979,
                                 0.044271278600657535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051598267902234825,
                                 0,
                                 0.038227034853184863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75099513626781855,
                                 0,
                                 0,
                                 0.059722016402713657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37713061512689727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0969060515987408,
                                 0.69615861334690077,
                                 0,
                                 0,
                                 0,
                                 -0.052174899849248696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2619067687676388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61753064252397238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1619346479000172,
                                 0,
                                 0,
                                 0.28929162036681499,
                                 0.48460976645543868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.008270196208726599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29182068824809371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13885872114329317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.089882426953459701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5802900603464265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30173759497523139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34314667901364754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52448041337949847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36162041508308279,
                                 0,
                                 0,
                                 0,
                                 -0.22049761381932614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14934021040063047,
                                 0,
                                 0,
                                 -0.30150950426416245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20571249146408702,
                                 0.26654501536116104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57694124343227937,
                                 0,
                                 -0.063010928647663486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27929363399700124,
                                 0,
                                 0,
                                 0,
                                 0.35064530753718887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25185079089777151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046894029250125105,
                                 0,
                                 -0.3307171298819116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16721060270193033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10929960121725069,
                                 0,
                                 -0.14397751738253048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16882064599634355,
                                 0,
                                 0,
                                 0,
                                 0.35873098747934923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12348035878667422,
                                 -0.34779047891901677,
                                 0.39808899787350244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70803833340407563,
                                 0,
                                 0.55663624584674987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069890630503396695,
                                 0,
                                 0,
                                 -0.43313723618723765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.144940927802684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29548287833509018,
                                 0.40801697766887696,
                                 0,
                                 0,
                                 0,
                                 0.35197423219509766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67562534114074735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92478691647740285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45791481101135884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14184117714059663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37217128906762165,
                                 0,
                                 0,
                                 -0.55417453383987447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34586580860508248,
                                 0,
                                 0,
                                 0.11822710353821977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43710278228278243,
                                 0,
                                 0,
                                 0.1720449661849674,
                                 0,
                                 0,
                                 -0.47059025209269761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27140517580687046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017465418473294747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61196509822293144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45881440643806437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57333701762750788,
                                 0,
                                 0,
                                 0,
                                 0.11093652654862562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1496765545189405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4560728052183497,
                                 -0.51933155061204395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45703649109954625,
                                 0,
                                 0,
                                 0.10042491059567704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14076926881108728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0021781744967371997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54185825315695602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21127334697829153,
                                 0,
                                 -0.012426574018329917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.284673847778247,
                                 0,
                                 -0.10593620357517622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60042023185368631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19635509242716143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57992240288106189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53215898618441981,
                                 0,
                                 0,
                                 0.33392815822752769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46418958930904708,
                                 0,
                                 0,
                                 0.53649559927016544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015344581929727492,
                                 0,
                                 0,
                                 -0.23107443616392423,
                                 0,
                                 0,
                                 0.215634227227711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041261458137340223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70991459604454632,
                                 0.097262698116802326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0412575236745378,
                                 0,
                                 0,
                                 0.19552644730969329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47110895851274537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30549673770624347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036972920972197995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47082241464770885,
                                 0,
                                 0.1039282484091873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76622777295214972,
                                 0,
                                 -0.10355068045764493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31381695289121331,
                                 0,
                                 0,
                                 0.1778267995863041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26762660854637971,
                                 0.24173392910913158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47063497997689407,
                                 0,
                                 0.23475038624788366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50125740423916754,
                                 0,
                                 0,
                                 0,
                                 0.098544293792231369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17639763528126495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20345220120279431,
                                 0,
                                 0.19069952502153636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15993290565308121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10113876933324922,
                                 0,
                                 0.23995717587520751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14622482437663614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12617334577024392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0258311220594096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24108758711148459,
                                 0,
                                 0,
                                 -0.36591920502909264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94234812944519109,
                                 0,
                                 0,
                                 0.25117278897618045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12011993347978375,
                                 0,
                                 0,
                                 0.29997650522728142,
                                 0,
                                 0,
                                 0.16430173167942555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25159844181409874,
                                 0,
                                 0,
                                 -0.35542844726008449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12169470829963294,
                                 -0.37562785890108535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019195202152941314,
                                 0,
                                 0.21159443584185583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10395243832801013,
                                 0,
                                 0,
                                 0,
                                 -0.12886774779343127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11191882806892625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22696407935289278,
                                 0,
                                 -0.45670240010641411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13663386490429683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10128320295243977,
                                 0,
                                 0.529496539864863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14298972857471659,
                                 0,
                                 0,
                                 0.18356047173993101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030188480177342821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86943758517148573,
                                 0,
                                 0,
                                 0,
                                 -0.014189300613272851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015519595689885979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4315554564622639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04841617279248428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43689413569616287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051910858037177737,
                                 -0.25567828582403468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15161706010597681,
                                 0,
                                 0,
                                 -0.52140253152641347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090590745416363083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098050331363491838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96386506822585649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34165515742080288,
                                 0,
                                 -0.86136304920917883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20452021045730007,
                                 0,
                                 -0.23307809764244461,
                                 0,
                                 -0.36561201218764283,
                                 0,
                                 0,
                                 0,
                                 -0.60437207424125039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30618281831642924,
                                 -0.15836742613156723,
                                 0.78673254267032866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1914589414035249,
                                 0,
                                 0.11412402551867117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33313341966350185,
                                 0,
                                 0,
                                 0.14172078254349882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05470686422564737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.133354892437684,
                                 0.073579599760608405,
                                 0,
                                 0,
                                 0,
                                 -0.52326566709308331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60190363344074926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088872494178804981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045039285659193837,
                                 0.040012975988926586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12658448720624874,
                                 0,
                                 0,
                                 1.1109733296506301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54483414492486815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38945677770310272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37361880292133581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27138710009351491,
                                 0,
                                 -0.41284607489623026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57753520822277427,
                                 0,
                                 0.24746219004901682};

const double rot_9_30[900] = {-0.08105575285323266,
                              0,
                              -0.289174050685442,
                              0.014818616597073614,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.78160718123756256,
                              0.99656402949619538,
                              0.15569881287153658,
                              0,
                              0,
                              0,
                              0.40885692179393818,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.72267796116288052,
                              0,
                              0,
                              -0.60332149561850323,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.4410397936874077,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.89748754887417159,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.19348589715602543,
                              0,
                              -0.9577711503450872,
                              0.61069062556827081,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.35757290912879502,
                              0.55036056966293578,
                              0.19568580379007058,
                              0,
                              0,
                              0,
                              -0.79023854943605598,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.37972736041536831,
                              0,
                              0,
                              0.13961436204696467,
                              0,
                              0,
                              0,
                              0,
                              -0.66666739928252849,
                              0,
                              0.073733734804724033,
                              0.32196838566112168,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.25342622540960535,
                              0.36460755952734408,
                              -0.06807455306499674,
                              0,
                              0,
                              0,
                              0.75951064566338611,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.69610012475214322,
                              0,
                              0,
                              -0.28814151702407809,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.65350975781916087,
                              0.061340556250678274,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.90027258279819877,
                              0,
                              0,
                              -1.0287148865419702,
                              0.49294869675497688,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.28456603573616313,
                              -1.0434414751562011,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.034585318859500599,
                              0,
                              0,
                              0.15024107046157067,
                              -0.79771374875358247,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.25333790052750316,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.33800756407370569,
                              0,
                              0.11034815126699143,
                              0,
                              0,
                              0,
                              -0.0062173886049174676,
                              0.45530830878115292,
                              0,
                              0,
                              0,
                              -0.43555393884750465,
                              0,
                              0,
                              -0.64213903065102595,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.81920630364774105,
                              1.2441586565446541,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.20841941269046435,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.3745211425000277,
                              0.29884573056745201,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.0048480448443214141,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.44181912056685996,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.44910652739476559,
                              0,
                              -0.38379162456649107,
                              -0.67513197277684478,
                              0.49175757478208032,
                              0,
                              0.25094924889385178,
                              -0.058983466773746066,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.83328093022197114,
                              0.46620817575999579,
                              0.71466592586705047,
                              0,
                              0,
                              0,
                              0.36309032771023952,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.36511751388844937,
                              0,
                              0,
                              -0.56150470001863262,
                              0,
                              0,
                              0,
                              0,
                              -0.37177700307777517,
                              0,
                              0.24721643037356705,
                              -0.06637751058817265,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.70779299658510675,
                              -0.5550927952983773,
                              0.32777436992592573,
                              0,
                              0,
                              0,
                              -0.67091027494202526,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.15694452986790311,
                              0,
                              0,
                              -0.86620579921983976,
                              0,
                              0,
                              0,
                              0,
                              -0.77797606461489566,
                              0,
                              -0.23176188515246565,
                              -0.58194784626147711,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.38065053755046702,
                              0.38589808383929747,
                              0.42794988088211772,
                              0,
                              0,
                              0,
                              0.1058140423097044,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.53848722514055958,
                              0,
                              0,
                              0.12009422382816702,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.20525036886737164,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.71080381385118552,
                              0,
                              -0.24861922429984987,
                              0,
                              0,
                              0,
                              0.096043417514754939,
                              -0.30159937726863195,
                              0,
                              0,
                              0,
                              0.51693475461752914,
                              0,
                              0,
                              -0.15300536805855527,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.1272739027271237,
                              0.67718215613160893,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.85499982430461952,
                              0,
                              0,
                              -0.47815072416448645,
                              -0.27386858870454678,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.14948165130600899,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.44991810360169848,
                              0,
                              0.073741359790208752,
                              0,
                              0,
                              0,
                              -0.087266960896315096,
                              -0.44929856758498693,
                              0,
                              0,
                              0,
                              -0.67241458919973929,
                              0,
                              0,
                              0.32888454321223037,
                              0,
                              0,
                              0.35620325781923984,
                              0,
                              -0.46747461089143871,
                              -0.57259290029020049,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.38781429082171942,
                              0.21796788730650085,
                              0.070192383981439274,
                              0,
                              0,
                              0,
                              -0.37216420186728727,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.84436196340936098,
                              0,
                              0,
                              0.50138957052446553,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.82316531471089416,
                              -0.099449284269537946,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.58653423565010288,
                              0,
                              0,
                              -0.76648580124062571,
                              -0.51017110299617663,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.81020658446163707,
                              0.56248043752681487,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.64562673148056593,
                              0,
                              0,
                              -0.27151938451965263,
                              -1.1214744577630826,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.14954751801851018,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.092554905812524027,
                              0,
                              0.74542311919901938,
                              0,
                              0,
                              0,
                              0.62600683397365176,
                              -0.066330029884546657,
                              0,
                              0,
                              0,
                              0.12889456912773548,
                              0,
                              0,
                              -0.022703824156275712,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.47747241387317119,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.20039130556531853,
                              0,
                              -0.017888289847121874,
                              0,
                              0,
                              0,
                              0.18689909717389877,
                              0.50957664361471045,
                              0,
                              0,
                              0,
                              -0.015551094990440301,
                              0,
                              0,
                              0.6608342930968738,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.83580835235235929,
                              0.45657282947359978,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.1110000940143629,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.51936787445579946,
                              0,
                              -1.3050262755244095,
                              -0.20301788530462053,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.039025314848196789,
                              -0.31939095059480671,
                              0.079578042109007818,
                              0,
                              0,
                              0,
                              0.45775556527137962,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.11558106684453887,
                              0,
                              0,
                              -0.55920016402720241,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.89748754887417159,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.44103979368740764,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.75709793214307353,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.34954047837496782,
                              0,
                              -0.029386148554878318,
                              0,
                              0,
                              0,
                              -0.17404914673887512,
                              0.48453202150834718,
                              0,
                              0,
                              0,
                              0.15624876798138621,
                              0,
                              0,
                              0.11950969229311001,
                              0,
                              0,
                              0.32213001681070624,
                              0,
                              -0.21749265452622182,
                              -0.34560410293527744,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.86323828339681463,
                              0.12592205952003033,
                              -0.75107075056234529,
                              0,
                              0,
                              0,
                              -0.31413556059440573,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.082676107547144911,
                              0,
                              0,
                              -0.4634997854422846,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.22113095018517712,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.52191846216199633,
                              0,
                              -0.82349086377641079,
                              -0.023770128342910868,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.21864534101659913,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.08474014949408995,
                              0,
                              0.60310431552083099,
                              0,
                              0,
                              0,
                              -0.72526722618651307,
                              -0.031994504262710784,
                              0,
                              0,
                              0,
                              0.22284640910851061,
                              0,
                              0,
                              0.067688897019757235,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.85667865225002571,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.24837964718221309,
                              0,
                              0.085438070486456352,
                              -0.4439702397191399,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.14831943349004256,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.6813310478552338,
                              0,
                              -0.40898303424585458,
                              0.5886613853283873};

const double rot_9_2[4] = {0.99982794924372143, -0.018549175482837799, 0.018549175482838964, 0.99982794924372254};

const double rot_8_50[2500] = {0.026456339663628425,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23048675083870271,
                               0,
                               0.25104819416484414,
                               0,
                               -0.56256153809236609,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.45627187094863064,
                               -0.63753218014065893,
                               0,
                               0,
                               0.31287889329758101,
                               0.058024926175204425,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15891812048564047,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.64475917339332722,
                               0,
                               0,
                               0,
                               0,
                               -0.34565739260794814,
                               0,
                               -0.65205977097611645,
                               0,
                               0.2937351644597101,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19823220678892101,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18219065384728478,
                               0,
                               0,
                               -0.10743735815392152,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.53274236974536371,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.034813999528483158,
                               0,
                               0,
                               0.57673053818132802,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3660339789377372,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22306305295963191,
                               0,
                               -0.69072937332621631,
                               0,
                               0,
                               0,
                               -0.033802116987742908,
                               0,
                               0,
                               -0.073445467579222032,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.79929044651953129,
                               0,
                               -0.24744553596007096,
                               0,
                               0.0079279872038910786,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13888672736950797,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30465565876776091,
                               0,
                               0,
                               -0.29602832239141924,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.016445030402888226,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31596651043026525,
                               0,
                               0,
                               0,
                               0,
                               -0.55225086560057302,
                               0,
                               0.7070324868479928,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17659882139761726,
                               0,
                               0,
                               0,
                               0,
                               -0.97797781968119935,
                               -0.91605696568027106,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.42814807350606476,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18361969351791463,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39114952630390343,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.052152537160207159,
                               0,
                               0.12648520794893006,
                               0,
                               0.079558337495737305,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.59426837592645199,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.053453057434481616,
                               0,
                               0,
                               0.15352004658747187,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39094845387422467,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.66522991943129051,
                               0,
                               0,
                               0,
                               0,
                               -0.16341872865929441,
                               0,
                               0.39934188023060085,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.2877797677584966,
                               0,
                               0,
                               0,
                               0,
                               0.50928496960422476,
                               -0.18171712887563624,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.057652471607000433,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17049176532443472,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27681971640330494,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.2509283283415028,
                               0,
                               1.05476186868802,
                               0,
                               0.2701106285835505,
                               0,
                               0,
                               -0.7320356085461579,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12321820731861934,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.65974412939507054,
                               0,
                               0,
                               0,
                               0,
                               -0.33201381760505239,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.6309703239882084,
                               0,
                               -0.19688637688740845,
                               0,
                               0.30928827792054531,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.4201225375752386,
                               -0.32726577759344644,
                               0,
                               0,
                               -0.60531153438851903,
                               0.50039879775996665,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28819836216502159,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.72143077884017537,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.3122344671205921,
                               0,
                               0.060567162235885388,
                               0,
                               0.61163405543423965,
                               0,
                               0,
                               0.058695789887057009,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.97387011708564941,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37292142280136492,
                               0,
                               0,
                               0,
                               0,
                               0.30521038901495945,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.57325137005292603,
                               0,
                               0.075486375872744538,
                               0,
                               0.47771353553418883,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49701807888124877,
                               0.18720569800154718,
                               0,
                               0,
                               0.070929407657453314,
                               -0.33829394624996817,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10585312841925747,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.62089061870881623,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.81342220433709633,
                               0,
                               0.44765965913084643,
                               0,
                               -1.0703122167185148,
                               0,
                               0,
                               0.92308653863454682,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13404943010587964,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.80964676061857421,
                               0,
                               0,
                               0,
                               0,
                               -0.23787514677293864,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15990787387119265,
                               0,
                               0.31106232148778434,
                               0,
                               -0.017931195038377437,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37287833709428764,
                               0.741987981955052,
                               0,
                               0,
                               0.31606679792477171,
                               1.0361560663734988,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11359930290578585,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39029033007453018,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.06074470567244078,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40859209412358949,
                               0,
                               -0.61889244861511605,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56683966217570325,
                               0,
                               0,
                               0,
                               0,
                               0.35359230164723343,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44363160456397982,
                               0,
                               0.53902751815806904,
                               0,
                               0.13457466702040377,
                               0,
                               0,
                               0.86314766804813114,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63173195256503645,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.8017508222221702,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.34175675587313897,
                               0,
                               0.54952879119901565,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51503910689464161,
                               0,
                               0,
                               0,
                               0,
                               1.0863611193220086,
                               -0.085045560531080311,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20572660166380566,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.60480136618001101,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12512111125257938,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.063567989193903371,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.62267032433149427,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51565271472834295,
                               0,
                               -0.46707435591407215,
                               0,
                               0,
                               0,
                               -0.17772440361042094,
                               0,
                               0,
                               0.30430024342550338,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.015338511487362767,
                               0,
                               -0.4627739040825074,
                               0,
                               -0.062409076560932183,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.072087852783876777,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.78693508765376052,
                               0,
                               0,
                               -0.070092249924592134,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27585273767765622,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2761141138099012,
                               -0.096187037794023031,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.47662473124658655,
                               0,
                               0.26103995119615425,
                               0,
                               -0.27968664251843278,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0474511626943155,
                               0.20188202401488847,
                               0,
                               0,
                               0.34957960825248219,
                               -0.14585041078109451,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29824058148177096,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.092353718796762338,
                               0,
                               0,
                               0,
                               0.83851523500252934,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3602295990187212,
                               0,
                               -0.42185497631619573,
                               0,
                               0.24057988048939896,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1991535846116404,
                               -0.38475268507938087,
                               0,
                               0,
                               0.21454278234221472,
                               0.66089594861314205,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.086304336265239034,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16234771816063243,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.048581021954185344,
                               0,
                               0.91224707666684934,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17907803650286566,
                               0,
                               0,
                               0,
                               0,
                               -0.43175386654350378,
                               1.0823974423485077,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5751399241599312,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.26388372627124879,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.045748231015345475,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.82264424852509999,
                               0,
                               0.64962540327530593,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12810058204866048,
                               0,
                               0,
                               0,
                               0,
                               0.05577114712444968,
                               -0.27121211281421592,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11627991245910621,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0082119038174880699,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0871168299744987,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26087868855417845,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17501845975974734,
                               0,
                               -0.39861573226649549,
                               0,
                               -0.96907726751168344,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24815097148153684,
                               0.7265242207142405,
                               0,
                               0,
                               -0.41938173748151542,
                               0.082020763195379542,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.62643156634057484,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35956011020336798,
                               0,
                               0,
                               0,
                               0.40964903163095434,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.067947998218034988,
                               0,
                               1.0336957332823344,
                               0,
                               0.075683976960992466,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.36396817883354071,
                               0.022438125215153898,
                               0,
                               0,
                               -0.40180503656416655,
                               -0.00091808283008039393,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38571660050356754,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39320560941254551,
                               0,
                               0,
                               0,
                               0,
                               -0.10094810964241673,
                               0,
                               -0.24588946764152958,
                               0,
                               -0.33735212542299087,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.62906382887169066,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10502768763254627,
                               0,
                               0,
                               -0.56489687362325491,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11430955702401241,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27679256441363098,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.62259778852005976,
                               0,
                               1.0714960257320243,
                               0,
                               -0.10064103453439077,
                               0,
                               0,
                               0.35410179100974204,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.92038773920471828,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.033595559569538823,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15756371324980223,
                               0,
                               -0.50298588700639624,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26445622760600906,
                               0,
                               0,
                               0,
                               0,
                               1.2962455089703786,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22381785001854815,
                               0,
                               -0.1295474887180548,
                               0,
                               -0.82254494297302161,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26500036399444343,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24324608692673605,
                               0,
                               0,
                               0.18333975663830773,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.024841888255537126,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30482519166036404,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.3894985608092798,
                               0,
                               0.62732708303314222,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31581817843015902,
                               0,
                               0,
                               0,
                               0,
                               0.51841538056422554,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.9293439841952813,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31289843460723304,
                               0,
                               0.18338817543388489,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.038391533470980538,
                               0,
                               0,
                               0,
                               0,
                               0.057525611071602006,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.75831048926961298,
                               0,
                               -0.16017701491459951,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.48832320859746126,
                               0,
                               0,
                               0,
                               0,
                               -0.33890673284042899,
                               0.32345875958360681,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.80032663656454095,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.76349504710223648,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.7010048235215609,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29989333432982046,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34656413232356131,
                               0,
                               0.75134124396362534,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31901633780959537,
                               0,
                               0,
                               0,
                               0,
                               0.35167058668746592,
                               0,
                               0,
                               0,
                               0,
                               -0.51105066597821569,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25617026482071914,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27800296778878847,
                               0,
                               -0.45978315516320167,
                               0,
                               0,
                               0,
                               0.5082763524782381,
                               0,
                               0,
                               -0.35520833586096268,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11894462809710094,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.85807977009243985,
                               0,
                               0,
                               0,
                               -0.49955108207764676,
                               0,
                               0,
                               0,
                               -0.31346932050108944,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13392094242018493,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.50851139818038904,
                               0,
                               -0.13009846547533671,
                               0,
                               0,
                               0,
                               -0.77992852187077388,
                               0,
                               0,
                               -0.0020528662738058256,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.95153559326804693,
                               0,
                               -0.83779952138166047,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31039425408819915,
                               0,
                               0,
                               0,
                               0,
                               -0.25718745790845843,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36587959023546035,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41434516990791798,
                               0,
                               0.25701758143972431,
                               0,
                               0.66777349966377741,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.076820906083926832,
                               -0.46897863721153732,
                               0,
                               0,
                               0.74334735124964457,
                               0.10728132940300832,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.87717432278392726,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0064545421126153378,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.85177581830377769,
                               0,
                               -0.35814460631115347,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10595737768629704,
                               0,
                               0,
                               0,
                               0,
                               0.36587420097143175,
                               -0.03908399682258358,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39205844819393226,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.90335714691628388,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.91017488337394514,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1496182876646544,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23350159435073153,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54162071965602854,
                               0,
                               -0.083743095354833083,
                               0,
                               0,
                               0,
                               -0.31722413518355924,
                               0,
                               0,
                               -0.72256093965054824,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22163605462403729,
                               0,
                               -0.2775036917998645,
                               0,
                               0.30610913485706559,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14639668656777455,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.42491025602324073,
                               0,
                               0,
                               0.23611459599164608,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.679325996748118,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2468840417591088,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13744207560580832,
                               0,
                               -0.85167294349433498,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.3378976831832694,
                               0,
                               0,
                               0,
                               0,
                               0.71071669491140455,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.53058417520976175,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58328361497521608,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23478214595270336,
                               0,
                               -0.2634300900834069,
                               0,
                               0,
                               0,
                               0.0026365866953559358,
                               0,
                               0,
                               0.5037217858198233,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.096262083710342103,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37148028041062503,
                               0,
                               0.057198502232642431,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32286324121296667,
                               0,
                               0,
                               0,
                               0,
                               -0.86326338467560804,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39176721938628623,
                               0,
                               -0.063743571919393033,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20301780496200661,
                               0,
                               0,
                               0,
                               0,
                               -0.40832888721830052,
                               0.22496071070504323,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.96758876949554029,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57863926017154055,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28124371107367074,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.99288750199363962,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10540496112789538,
                               0,
                               0,
                               0,
                               0.055355239629663766,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0024432375613975127,
                               0,
                               -0.25856244488225588,
                               0,
                               -1.4223259259933014,
                               0,
                               0,
                               -0.69073745334508563,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.60654901498863845,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.71186472426869218,
                               0,
                               0,
                               0,
                               0,
                               0.1118782509107811,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40428327924660301,
                               0,
                               0.240881504644536,
                               0,
                               0.22623230688461163,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51245233350991082,
                               0.43743641116103321,
                               0,
                               0,
                               0.50415850448130972,
                               -0.42224456560214846,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3237891550714399,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32136673450071063,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18283172327879837,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.6906828314739718,
                               0,
                               -0.12472201337274409,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.68644503875131369,
                               0,
                               0,
                               0,
                               0,
                               0.052606229896823474,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0051559510929585217,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50258223439327065,
                               0,
                               0,
                               0,
                               0.86451403333930599,
                               0,
                               0,
                               0.35957349795914773,
                               0,
                               -0.3594135314447886,
                               0,
                               -0.13907888443472277,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3093289906507431,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.033454955588211557,
                               0,
                               0,
                               0.68108081134142728,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10868347567724568,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.38690961336079294};

const double rot_8_20[400] = {-0.12490094791197531,
                              0,
                              0,
                              0,
                              -0.35811272728493709,
                              0,
                              0,
                              0,
                              0,
                              0.34828163385639832,
                              0,
                              0,
                              -0.85723680000659797,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.0623507298751156,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.10030155608000305,
                              0,
                              -0.021521670243881935,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.22957520804866732,
                              0,
                              0,
                              0,
                              0.49671252444160696,
                              0,
                              0,
                              0,
                              0,
                              -0.70022197442939094,
                              0,
                              0,
                              -0.45854234094406415,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.56035103049350421,
                              0,
                              0,
                              0,
                              -0.71490678906535954,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.41822841315855808,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.16962684188672827,
                              0,
                              0,
                              0,
                              0.78768755986795258,
                              0,
                              0,
                              0,
                              0,
                              0.58039520648321252,
                              0,
                              0,
                              -0.11796799070982922,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.78336120949004884,
                              0,
                              0,
                              0,
                              0.29346232470123934,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.54792798746480531,
                              0,
                              0.95022192753673917,
                              0,
                              0,
                              0,
                              -0.067677549073974608,
                              0,
                              0,
                              0,
                              0,
                              -0.22700329146475473,
                              0,
                              0,
                              -0.20240440569283877,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.24635573601103194,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.5129251970115052,
                              0,
                              -1.2577920090977319,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.26898315577588761,
                              0,
                              0,
                              0,
                              0.63465592798712755,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.72447216301224637,
                              0,
                              0,
                              0,
                              -0.019044136878842155,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.65677184066082961,
                              0,
                              0.75942519685984944};

const double rot_8_10[100] = {0.87181633097352795,
                              0,
                              0,
                              0,
                              0,
                              0.48181111515979524,
                              0,
                              0,
                              0,
                              -0.87578890249922259,
                              0,
                              0.48437617332600302,
                              0.38417879435538149,
                              0,
                              -0.72069707807799899,
                              0,
                              0,
                              -0.31365920731191327,
                              0,
                              0,
                              0,
                              -0.037855856512403557,
                              0.40279416411680069,
                              0,
                              0.51744350942039707,
                              0,
                              0,
                              -0.75403979340606642,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.74587620141931477,
                              0,
                              0,
                              -0.27738215589271698,
                              0,
                              0.60558057411759947,
                              0,
                              0,
                              -0.1066723919798559,
                              -0.77754921783925712,
                              0,
                              -0.23696858893365555,
                              0,
                              0,
                              -0.57261165067229269,
                              0,
                              0,
                              -1.3214707367301191,
                              0,
                              0,
                              0,
                              0,
                              0.10861287793483232,
                              0,
                              0,
                              0,
                              -0.38495129739357559,
                              0,
                              0,
                              0,
                              -0.4101658107071588,
                              0,
                              0,
                              -0.52507320512483102,
                              0,
                              -0.74569574022310015,
                              0,
                              0,
                              -0.86750657497857941,
                              0.29254184172294495,
                              0,
                              -0.39584570740040903,
                              0,
                              0,
                              -0.071817749497957745,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.52481682507636185,
                              0,
                              0,
                              -0.80458515326362168,
                              0,
                              0.27786693085813829,
                              0,
                              0.40979361604806819,
                              0,
                              0,
                              0,
                              0,
                              1.7373772816031665,
                              0,
                              0,
                              0,
                              0.33961791955216192};

const double rot_8_100[10000] = {0.46807627547742636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19516114474142038,
                                 0.044461152163093966,
                                 0,
                                 -0.061677666243747487,
                                 0,
                                 -0.16116250553918213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066422020765715323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22995107698632142,
                                 0,
                                 0,
                                 0,
                                 -0.68840839118894204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37379543276930499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20035948915256657,
                                 0,
                                 0,
                                 0,
                                 -0.11857385267490272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38022724538845992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27630236446946388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38519402558683608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3769024253214503,
                                 -0.54014717096519382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22590190071534447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36304817325697408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62883612597339211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52434694663754078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46383456610952867,
                                 0,
                                 0,
                                 0,
                                 -0.82521705292037228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60169723359884153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3216652833004203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11198099702993285,
                                 0,
                                 0,
                                 0.10380291746595416,
                                 -0.52454724721451762,
                                 0,
                                 0.058661708571498536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20126454290610957,
                                 0,
                                 -0.33834673369045154,
                                 0,
                                 0,
                                 0,
                                 0.14460878581438669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46997938289094587,
                                 0,
                                 0,
                                 0,
                                 -0.44719218317554665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16320003302977726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22827254442534592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15030800476609488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2467228095697514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37719570699824806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24430405974592542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13365758208831233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15565705961244347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41596842845072185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75935583340907986,
                                 0,
                                 0.69914373748134873,
                                 0.24343530449730325,
                                 0,
                                 0,
                                 0,
                                 0.79359119748973372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062162837231346087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19149095178828257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19355132735480141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15829648055189335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77948115547441721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11003443578702538,
                                 0,
                                 0,
                                 0,
                                 -0.36753791947127579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49475201099617044,
                                 0,
                                 0,
                                 0,
                                 -0.13233604318022285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47436875056142874,
                                 0,
                                 -0.039542542234035249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37584280869283837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29361266117017687,
                                 0,
                                 0,
                                 -0.032094542530157678,
                                 0.29931744789628112,
                                 0,
                                 0.40094751396623263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0048140780751190562,
                                 0,
                                 0.23543902727723251,
                                 0,
                                 0,
                                 0,
                                 0.15925546925031678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3555042830615277,
                                 0,
                                 0,
                                 0,
                                 -0.5295975590815919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10939158364966113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35872760175091106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18462341638803198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39735594685754128,
                                 0,
                                 0,
                                 -0.17436697363586007,
                                 -0.040093937778472144,
                                 0,
                                 -0.38383142160066192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050342880499770259,
                                 0,
                                 -0.5587026246173169,
                                 0,
                                 0,
                                 0,
                                 -0.36855534534752843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42884969750725627,
                                 0,
                                 0,
                                 0,
                                 -0.085294667794998141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033611818777954952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12443509106858403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066732041290436112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16622427001392889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73317276022472599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27349502384359176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4566070682027234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051168360564928433,
                                 0.061952761868054748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029688042061528717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37973665513809701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41815169494227161,
                                 0,
                                 0,
                                 -0.2085474909924066,
                                 -0.16258132414923313,
                                 0,
                                 0.34500547589312724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37809089712225524,
                                 0,
                                 -0.12316485228738777,
                                 0,
                                 0,
                                 0,
                                 -0.36297937902891847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031095027529984456,
                                 0,
                                 0,
                                 0,
                                 0.1895935251747014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10784495123354242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53618474412910944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10140060584032305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027549382213815032,
                                 0,
                                 -0.2342037590793139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017619858670346572,
                                 0,
                                 0,
                                 0,
                                 0.13595076755426921,
                                 0,
                                 0.14049557107997843,
                                 0,
                                 -0.29244973026107646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064723226427721187,
                                 0,
                                 0,
                                 0,
                                 -0.18997795894518618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63282747115601434,
                                 0,
                                 0,
                                 0,
                                 0.56059659036531695,
                                 0,
                                 0,
                                 -0.17392803434040077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046603620338072291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09233718474761822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15608276453009154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30233647523096246,
                                 0,
                                 0,
                                 -0.437232994037414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32724271575645525,
                                 0.17349289642268384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1178903471263897,
                                 0,
                                 0,
                                 0,
                                 0.16030197504412214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49294824898369066,
                                 0,
                                 0,
                                 0,
                                 -0.46184799038069357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018179735205457091,
                                 0,
                                 0.05727596623151255,
                                 0,
                                 0,
                                 0.11084932601268446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2150881061688608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18538421503898714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51256971449340649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29811321418534015,
                                 0,
                                 -0.32158123175157594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071836116862847854,
                                 0,
                                 0,
                                 0,
                                 0.33913637343567626,
                                 0,
                                 0.43585349401944529,
                                 0,
                                 -0.29655267691745207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01635061843374,
                                 0,
                                 0,
                                 0,
                                 -0.21632164517643926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3700709519005782,
                                 0,
                                 0,
                                 0,
                                 -0.12954079298129081,
                                 0,
                                 0,
                                 -0.1193067505092254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3536594002200017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22556903547696511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13653633866280993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4896240075047007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20767777026314013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5690724564045565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0059595068412850311,
                                 0,
                                 0,
                                 0,
                                 0.45729431358464628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15211227024360388,
                                 0,
                                 0,
                                 0,
                                 -0.026435020408180566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69519402046080525,
                                 0,
                                 -0.45465285210758799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096095906049285779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18499018398293143,
                                 0,
                                 0,
                                 -0.53580435956638606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3401077207857446,
                                 -0.28374744825501491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21668866172424053,
                                 0,
                                 0,
                                 0,
                                 0.0099174104443985472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1221242899060464,
                                 0,
                                 0,
                                 0,
                                 0.27698749001228001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20175056838764288,
                                 0,
                                 0.61571204203350349,
                                 0,
                                 0,
                                 0.38835113216349604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21069230221465654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04781381492547862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35995700289622756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63478530986784332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87979585937719318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17056854397442545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20341750757941043,
                                 0,
                                 -0.58928675769277605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58027528791796845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56977839976341504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60685160810783378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39303504437828513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065236941948390498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023454144055049697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6428508750557832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40897237470708014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49801897215486202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37298509905619781,
                                 0,
                                 0.64596649112196902,
                                 0.39413665921449664,
                                 0,
                                 0,
                                 0,
                                 0.33557833762579425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69463314829915523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42967520578871343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069393762688166771,
                                 0,
                                 0.010911387255068617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076200701017735642,
                                 0,
                                 0,
                                 0,
                                 -0.4215283980247001,
                                 0,
                                 0.066787818798770174,
                                 0,
                                 0.15662187162477262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20506868385991939,
                                 0,
                                 0,
                                 0,
                                 0.16928452122333801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068652768226158734,
                                 0,
                                 0,
                                 0,
                                 -0.014555600632912788,
                                 0,
                                 0,
                                 0.11177215236849863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44956301179384178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15013694614607362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68542336274968119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06360639683733188,
                                 0,
                                 0,
                                 0.33538757452374146,
                                 0.26208698425237764,
                                 0,
                                 0.32744747086360493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5419751339483635,
                                 0,
                                 -0.22593258221240745,
                                 0,
                                 0,
                                 0,
                                 -0.27530547163774388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15764906081077296,
                                 0,
                                 0,
                                 0,
                                 0.15274100557764575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32667857577746173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12818597947500066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34007162340370833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56480566602408755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047807967184432441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14829604723744902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3657550988191226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32003371202119801,
                                 -0.10694270769392727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077046173770125792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63493780444288284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076719559207144211,
                                 0,
                                 0,
                                 0.090405996485968254,
                                 0.27393014696036055,
                                 0,
                                 -0.31206281441178241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17267069733752827,
                                 0,
                                 -0.088992525033966846,
                                 0,
                                 0,
                                 0,
                                 0.20442673803406453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13505327201753864,
                                 0,
                                 0,
                                 0,
                                 0.36928343529007263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14580559032377122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32346676775907601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67342048316892766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37202212148355013,
                                 0,
                                 0.58630230974260233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048169910768337071,
                                 0,
                                 0,
                                 0,
                                 0.11132921513623666,
                                 0,
                                 0.21539451477882027,
                                 0,
                                 0.31325323941729594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057697468714442618,
                                 0,
                                 0,
                                 0,
                                 -0.022683147101915505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28053969785590283,
                                 0,
                                 0,
                                 0,
                                 0.15514244484075354,
                                 0,
                                 0,
                                 -0.021454114724764883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28701584436061872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3686304682013809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.182401205881638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55478954215789211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48085993351013034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21617568479278382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17165912916942005,
                                 0,
                                 0.084251320561949589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1888686939017115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40964425414450806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38885415167591736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040932504964607618,
                                 0,
                                 -0.17584308879715468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23528841300931258,
                                 0,
                                 0,
                                 0,
                                 0.3720112649722061,
                                 0,
                                 0.11675347521562385,
                                 0,
                                 0.21831548877814666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30506042368656394,
                                 0,
                                 0,
                                 0,
                                 0.46871374701754742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015073293767496295,
                                 0,
                                 0,
                                 0,
                                 0.0420739644118222,
                                 0,
                                 0,
                                 -0.047484260342110757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25216500890245502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47287944777664837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32886001998970005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28917976514252619,
                                 0,
                                 0,
                                 0.19489244493862934,
                                 0.45181917499358876,
                                 0,
                                 -0.0097465288370938707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41781340229092367,
                                 0,
                                 -0.53412633406894938,
                                 0,
                                 0,
                                 0,
                                 0.31564470476498319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12528424649975745,
                                 0,
                                 0,
                                 0,
                                 -0.24705782270523882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10852044454209187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13496019144165408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089113561017524573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33653851986998606,
                                 0,
                                 -0.21250671192060419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0081849344084463579,
                                 0,
                                 0,
                                 0,
                                 -0.26668510625204395,
                                 0,
                                 0.32828881376379188,
                                 0,
                                 0.52661050289633948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10563449713118689,
                                 0,
                                 0,
                                 0,
                                 -0.42508159564287579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014119475696582288,
                                 0,
                                 0,
                                 0,
                                 -0.090372777883321515,
                                 0,
                                 0,
                                 -0.39008900880307013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043022644800032539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0078826605499459964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17606955550196984,
                                 0,
                                 0,
                                 0,
                                 -0.8447843675523834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41214263658934797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71105402418392805,
                                 0,
                                 0,
                                 0,
                                 -0.70584785546690731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56803563924159928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35315926713834978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27928780944176174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078254389398687785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013994203150724888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86086652520489537,
                                 0,
                                 0,
                                 0,
                                 0.029622997750742647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52593157060548634,
                                 0,
                                 0,
                                 0,
                                 0.43655948009099887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18472132711083375,
                                 0,
                                 0.29243449546041972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027691025800932242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063013631503587075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46240406770690179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60279155312816157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37972097911355268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56781918098999129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0978313076687643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13251007579989779,
                                 0,
                                 -0.44797264272124082,
                                 0.44942122843544718,
                                 0,
                                 0,
                                 0,
                                 0.27158890714161554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072624469745038445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63340204006369027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52190130251444455,
                                 0,
                                 0,
                                 0.44214593148324688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078608850881283263,
                                 0.52465127122632882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75688006461705259,
                                 0,
                                 0,
                                 0,
                                 0.31215626847945332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70212238708011165,
                                 0,
                                 0,
                                 0,
                                 0.073263134545229092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31080688214449037,
                                 0,
                                 0.54589710363072652,
                                 0,
                                 0,
                                 0.21278547001987944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09884068820167824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090637125502910865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088375462418147921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57629263312153667,
                                 0,
                                 0,
                                 -0.044172755765278224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52962897073921444,
                                 0.18924636197336916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13989904591189406,
                                 0,
                                 0,
                                 0,
                                 -0.34606912317415617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18095230539746865,
                                 0,
                                 0,
                                 0,
                                 -0.4636666154673339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12532550773642517,
                                 0,
                                 -0.14650019211838225,
                                 0,
                                 0,
                                 -0.84086861295592896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16775830425162658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35427301284321255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21068516428253448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38370653418949352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81175925029247853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035581458596429888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37978883247719952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087832221729443979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20148478488636923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.414211985038522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086446053636588666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5872147563486646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57734976115204872,
                                 0,
                                 -0.34339948241780949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65862431697925294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042027293431469957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25702672250449038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33567709833253528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24090974553471819,
                                 -0.25369920470301544,
                                 0,
                                 -0.093097712160117169,
                                 0,
                                 -0.16356832367478638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34921527296776295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55288159841402817,
                                 0,
                                 0,
                                 0,
                                 -0.49367182402296722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1856448173270204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15392555473971889,
                                 0,
                                 0,
                                 -0.32669882732863648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40727276119745459,
                                 0.30886135487471261,
                                 0,
                                 -0.18181579262322156,
                                 0,
                                 -0.49152524854311785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063939395063744756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39191523305171805,
                                 0,
                                 0,
                                 0,
                                 -0.24941809931127487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20213451048958089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31079549632685521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073147891355455325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64771956284409238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23626349863081536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19141515285860908,
                                 0,
                                 0,
                                 0,
                                 0.058202021202580473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52454587786515339,
                                 0,
                                 0,
                                 0,
                                 0.16597241087195841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52053599646528614,
                                 0,
                                 -0.29357758566650838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31464695726256547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039459405669833705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1898251162394691,
                                 -0.33481399920025656,
                                 0,
                                 -0.41172991261133446,
                                 0,
                                 -0.14653008789003516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1815682525641123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20609185036602201,
                                 0,
                                 0,
                                 0,
                                 0.1816740032505868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61233083898434604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41942937181073048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11496931449317811,
                                 0,
                                 0,
                                 0.30155135778690612,
                                 0.24804864839562946,
                                 0,
                                 0.20110922927352495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065419721586439744,
                                 0,
                                 -0.085249496928948745,
                                 0,
                                 0,
                                 0,
                                 -0.20105238285511345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020657866184011886,
                                 0,
                                 0,
                                 0,
                                 0.14625451565952707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84252117558112016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053647195411395003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085845327519710579,
                                 0,
                                 0,
                                 0,
                                 0.1849231787698091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1379048025181645,
                                 -0.76772638401893678,
                                 0,
                                 0.19061358628271197,
                                 0,
                                 -0.36086082779211986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13730403498592267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30353734031163532,
                                 0,
                                 0,
                                 0,
                                 0.096283865112498923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23926107478283615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11542983493367684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22174104293475494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92783719317517055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098699355325771843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51459711068560976,
                                 0,
                                 0,
                                 0,
                                 0.093321465465234163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18119431975016162,
                                 0,
                                 0,
                                 0,
                                 0.38499095750988821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66209737603640317,
                                 0,
                                 -0.5439392918917566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40172976042196362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29326951492457015,
                                 0,
                                 0,
                                 -0.72153450171663325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21940454581593632,
                                 0.77951592978936435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43994073553796487,
                                 0,
                                 0,
                                 0,
                                 -0.099003324511148988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04291321820299903,
                                 0,
                                 0,
                                 0,
                                 -0.023015726694323835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13018592330718537,
                                 0,
                                 -0.42866900440229749,
                                 0,
                                 0,
                                 0.3822904054752419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013420822143440259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092777594008213699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71158219033251369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1466068972172509,
                                 0,
                                 0,
                                 -0.054399715394149818,
                                 -0.20624228441371609,
                                 0,
                                 0.45009771524314113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21026364074517848,
                                 0,
                                 -0.32795229467366277,
                                 0,
                                 0,
                                 0,
                                 0.063267286981455464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37347261209268012,
                                 0,
                                 0,
                                 0,
                                 0.10558606905858188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05041057099941864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4802989509602949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43680485548849801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17982536579381675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37276378060790355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60728242521714415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31119113471262261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16721623796115714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12395486203994666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72334285271537835,
                                 0,
                                 -0.054414505658330073,
                                 -0.37298879302565963,
                                 0,
                                 0,
                                 0,
                                 0.32148742654751034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20761805472519512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48082428683023681,
                                 0,
                                 0.14245917661428786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45888423073632878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72337043421049496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07559825459547391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43659011070891102,
                                 0.18548636590601877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0039888793471621331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12295827230347918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67209619205255378,
                                 0,
                                 0,
                                 -0.47366436960875768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18281695930973718,
                                 -0.095387182414489138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099510408512589688,
                                 0,
                                 0,
                                 0,
                                 0.58609323158317972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74040591296678171,
                                 0,
                                 0,
                                 0,
                                 0.071967824930334476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068580489060176428,
                                 0,
                                 -0.01007083468211982,
                                 0,
                                 0,
                                 -0.47397049311045147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2486482351288741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61413499934949722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27834506609924964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17470737437152575,
                                 0,
                                 -0.12321251124857469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25378133568134609,
                                 0,
                                 0,
                                 0,
                                 0.17381433237160548,
                                 0,
                                 -0.048990485087469018,
                                 0,
                                 0.24457580799086126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59317912523868688,
                                 0,
                                 0,
                                 0,
                                 0.33532443444237081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18572876392578244,
                                 0,
                                 0,
                                 0,
                                 0.27182498026077034,
                                 0,
                                 0,
                                 -0.33286957715038779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019146337917778797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19405167166543674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27558935924715294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068457584046566114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55947057953060164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65629552116105572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22083746782061717,
                                 0,
                                 0.31800823705535353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017154227669050226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90010074795895045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60569636851001174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36431638287489926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43390156629721177,
                                 -0.019302602355563164,
                                 0,
                                 -0.47372997926377136,
                                 0,
                                 0.025853842046094394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27018275399078434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068376806890320149,
                                 0,
                                 0,
                                 0,
                                 0.081300867690031364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51453271698443703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32328631716356648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68885319496580455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10448242684658934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98496621028298814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69337149137164966,
                                 0,
                                 -0.43488867206829107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75954926850066007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19250036641345022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15027190921659653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25821633002467681,
                                 0,
                                 0.35648419365733991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19606954003798485,
                                 0,
                                 0,
                                 0,
                                 0.49694545527740597,
                                 0,
                                 -0.28526307786577593,
                                 0,
                                 0.11484514417616827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02367951523895458,
                                 0,
                                 0,
                                 0,
                                 -0.40864773224632178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11756642717502877,
                                 0,
                                 0,
                                 0,
                                 0.021181619740502543,
                                 0,
                                 0,
                                 -0.05498384599402005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21932731848114531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35707307913587688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25656923368486567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42360478189680906,
                                 0,
                                 0,
                                 0.065242420308908533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015560703762076411,
                                 -0.75684790924373535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45040094034544953,
                                 0,
                                 0,
                                 0,
                                 -0.029587261957978599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20154378833597139,
                                 0,
                                 0,
                                 0,
                                 -0.65202165450896921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78481225687117029,
                                 0,
                                 0.099382435315646195,
                                 0,
                                 0,
                                 0.50104716363480806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37423343467951142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26988372436695929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20685357286992095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.063391853655868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060355005539764826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36498163917919973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61815561688095633,
                                 0,
                                 0,
                                 0,
                                 -0.10419756202116837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16228655321765142,
                                 0,
                                 0,
                                 0,
                                 0.026798541401866108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22207191974118068,
                                 0,
                                 -0.044114367958971973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45786888394079522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067533072619281403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1101789685933629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90783479313366267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060756574262036851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36991469140151662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13640977651005234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20832812899066286,
                                 0,
                                 0,
                                 0.69814267313170941,
                                 -0.16361725253537293,
                                 0,
                                 -0.22207048541269214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12147501468593801,
                                 0,
                                 0.19769925533667104,
                                 0,
                                 0,
                                 0,
                                 -0.38196943287582263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17199425153105338,
                                 0,
                                 0,
                                 0,
                                 -0.25939083188130196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17976435012094799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076607361285150277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24149313613170051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031620884377549133,
                                 0,
                                 0,
                                 -0.13465280269413524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30066317663826025,
                                 0.13791246448656966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0469579795759729,
                                 0,
                                 0,
                                 0,
                                 -0.44570569206355526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63941312398194294,
                                 0,
                                 0,
                                 0,
                                 0.02569575024453033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51642279745966746,
                                 0,
                                 0.69485636277409701,
                                 0,
                                 0,
                                 0.33694641795682784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068835363526688287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21911803115700906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08940462774482226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64447242620879885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37354682685073659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049499580464757081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.049076768274369992,
                                 0,
                                 0,
                                 0,
                                 0.56508733453809312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0040516014804790612,
                                 0,
                                 0,
                                 0,
                                 0.64384708607882346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2090111068989165,
                                 0,
                                 0.35674568638223825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12237163809633428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98571834299574113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17027028986592305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.092009939977328,
                                 0,
                                 0,
                                 0,
                                 -0.40032380985179727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075884506111729033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0038022495168661963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055946211920119671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24892807595715249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11220849891137095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41987129153901021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64183612000676382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57798666138600718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52970946595796575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18422773740389545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42984786703133432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10084269919613545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39108152593448992,
                                 -0.38111998184754775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27328278553214547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34299985760067908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43839644318373078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20592805244149193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028265275333246839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58765500990604636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11153385543438182,
                                 0.51988720122224652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36531951849521044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.055533826338909756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30544965820949882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35572172637160004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1499796720005902,
                                 0,
                                 0,
                                 0,
                                 1.0375322574078694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3284601895664283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.074330691683145933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65338869491976126,
                                 0,
                                 0,
                                 -0.35165564340802591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21780789083144531,
                                 0.38558145277478023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20795312907047783,
                                 0,
                                 0,
                                 0,
                                 -0.11942010359064224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37987618014611613,
                                 0,
                                 0,
                                 0,
                                 0.20930096714179153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1714350549034933,
                                 0,
                                 -0.30403419100274759,
                                 0,
                                 0,
                                 -0.024145889520480111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.049703001545120293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17671682705164055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47368608378277044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70709685020381308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40254740644459397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059108478594870603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37978114351280584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038018803424102285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4345073893193096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23560326349886024,
                                 0,
                                 0,
                                 0.43682297397054182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31136077708315429,
                                 -0.33489133858373282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25037618587284427,
                                 0,
                                 0,
                                 0,
                                 0.10307175411634545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34794758695834627,
                                 0,
                                 0,
                                 0,
                                 0.28687230115446832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42530755548644872,
                                 0,
                                 0.12472949877822301,
                                 0,
                                 0,
                                 -0.61840088591712816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59202441446939358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53637664708396993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73400107643475776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.074930720341142454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046647406763953236,
                                 0.050189712070869308,
                                 0,
                                 -0.1907957417683179,
                                 0,
                                 -0.43742753712793425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48556593335383946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37117697976432984,
                                 0,
                                 0,
                                 0,
                                 0.1038788569201375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099526695023653383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60638397752640649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0552691516027679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074364367621529301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.408006230020174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42452558520841815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39738648339456956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019037501840223198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040425775668109565,
                                 0,
                                 -0.35166753270630885,
                                 0.25688928657051513,
                                 0,
                                 0,
                                 0,
                                 -0.2784457567226436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87201237854392499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11287802756636378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37431832946037441,
                                 0,
                                 0,
                                 -0.55448131266408596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40009658957211652,
                                 0.068964456394351226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29485941132456117,
                                 0,
                                 0,
                                 0,
                                 0.072228625230860932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53319737045182525,
                                 0,
                                 0,
                                 0,
                                 -0.18803476755552867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02719516761783167,
                                 0,
                                 0.96907663890006512,
                                 0,
                                 0,
                                 -0.68841567919435531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34913284118448851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44336777102529268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38502142154306834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30002871532193237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88161869608261323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23737639597751703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028552548493909917,
                                 0,
                                 -0.32065996468341906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55009106793798379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40866111113491149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9324382180159686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3958222342222586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11924477751445858,
                                 0.3641952099484298,
                                 0,
                                 0.12274825997273822,
                                 0,
                                 -0.53328040306856905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47884492437416093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20509473844416501,
                                 0,
                                 0,
                                 0,
                                 0.3314650234087711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.067578162105276618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10592442723402055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43982874580251463,
                                 0,
                                 0.17172722907860785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17126292696504983,
                                 0,
                                 0,
                                 0,
                                 -0.21747125240884602,
                                 0,
                                 -0.06682889793008806,
                                 0,
                                 -0.0030482200209067598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20155271906543781,
                                 0,
                                 0,
                                 0,
                                 -0.16103368743352697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46160662754234544,
                                 0,
                                 0,
                                 0,
                                 0.44074684495461741,
                                 0,
                                 0,
                                 -0.29793051862829589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26420158489725976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25183640633257837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0089358945598009172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33572298494609965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17317608578037069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74522770437595121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15813519190135716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62738734794552953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25347991361775829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53462720895133997,
                                 0,
                                 0.43705617391935458,
                                 -0.61849202376210088,
                                 0,
                                 0,
                                 0,
                                 0.064702790430099633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36076244812848696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048875960052209289,
                                 0,
                                 -0.37051514441523248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01884048192211224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12437581725758091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37968370202353863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16471342556643037,
                                 0.28236316352635149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75114122873596512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17793788892110707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16724476821984952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28125599931125284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22110457654000634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48523613065870042,
                                 0,
                                 0,
                                 0,
                                 0.75820225111471951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5872075769877283,
                                 0,
                                 0,
                                 0,
                                 -0.43993932961774662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55763470335595067,
                                 0,
                                 -0.038214602540506154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029531401826138379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16024947253574459,
                                 0,
                                 -0.077794900897991598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27131446764532208,
                                 0,
                                 0,
                                 0,
                                 -0.28922385964240166,
                                 0,
                                 -0.3822265422507643,
                                 0,
                                 -0.21740871935130737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26866659422276185,
                                 0,
                                 0,
                                 0,
                                 0.051829645767056239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098697217900842363,
                                 0,
                                 0,
                                 0,
                                 -0.065213531046144857,
                                 0,
                                 0,
                                 -0.44243464512499214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47902770483702661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13654413584569511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29141060898430016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4342615324836514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.711318066552734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023536796252199205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.646047590221003,
                                 0,
                                 0,
                                 0,
                                 -0.14362672843103116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62021523459151051,
                                 0,
                                 0,
                                 0,
                                 -0.62702221023409432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30365242038803675,
                                 0,
                                 0.58602176772551862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34406267572216132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15602992994900902,
                                 0,
                                 0,
                                 0.071478448624151786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1006890020568853,
                                 0.00089661297328290715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45453410629753987,
                                 0,
                                 0,
                                 0,
                                 -1.0935109147044151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20818291883647172,
                                 0,
                                 0,
                                 0,
                                 -0.44277140614809074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061760663736752153,
                                 0,
                                 0.12872385606585357,
                                 0,
                                 0,
                                 0.20550670252564157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17647226653602086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74647418816686739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2640130224918612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090556009644941524,
                                 0,
                                 0.22732650780413499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2661534440760337,
                                 0,
                                 0,
                                 0,
                                 -0.10138530754113474,
                                 0,
                                 0.43449034873987097,
                                 0,
                                 -0.1930893554619299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50036034244233196,
                                 0,
                                 0,
                                 0,
                                 -0.096350446703784454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11969702180531078,
                                 0,
                                 0,
                                 0,
                                 -0.29451124630246228,
                                 0,
                                 0,
                                 0.014938215781061158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10660513403627728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5104709780807869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0079820294494397908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61685542285268413,
                                 0,
                                 0,
                                 0.24901023895128216,
                                 -0.19388515230698866,
                                 0,
                                 0.26527426432739548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5003543258183939,
                                 0,
                                 0.00037778339859780713,
                                 0,
                                 0,
                                 0,
                                 0.07206498351839416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16872104974113836,
                                 0,
                                 0,
                                 0,
                                 0.30207769920590444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2428017598448956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12315486323141697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011657647941272182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19749160916409511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12287938667088291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11483067200528867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53680089501120809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46852573915795798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67707193561727497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11090284742497265,
                                 0,
                                 -0.34590944894240344,
                                 0.70210529002949307,
                                 0,
                                 0,
                                 0,
                                 0.29316035248125899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76921178735358264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51527545766351734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42869214436412495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15433148870331315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28689745667491484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69468155073229421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47615055274755408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02815813379727497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27002960052747416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41297769116730798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098829695535113019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18192873813982774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011396154721571405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2170760163788428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26515295261351945,
                                 0,
                                 -0.55323197837658067,
                                 -0.49398816927623868,
                                 0,
                                 0,
                                 0,
                                 0.18022968810956563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57391038304067765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42008601395435918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71759942558664913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081755902278698112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096579798821267576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080942065985409373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18204993787079898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50299593467884318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32338514736456181,
                                 0,
                                 0.0096839820659907205,
                                 0.26175572665642161,
                                 0,
                                 0,
                                 0,
                                 -0.80214128979081534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49213367974327682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023068192847629961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52271245793141619,
                                 0,
                                 0.41385356699793718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20627317197333148,
                                 0,
                                 0,
                                 0,
                                 -0.093620646772165722,
                                 0,
                                 0.17577327241696522,
                                 0,
                                 -0.46510478688489421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.266908563584211,
                                 0,
                                 0,
                                 0,
                                 0.18592274473825207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14054910825870556,
                                 0,
                                 0,
                                 0,
                                 0.03234466654818384,
                                 0,
                                 0,
                                 -0.28921245128323514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13425768455359002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15744499245590327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062443472425703958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21326432108265581,
                                 0,
                                 0,
                                 0.60914154156806566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11520975297569382,
                                 0.47563006667890578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58096090653460253,
                                 0,
                                 0,
                                 0,
                                 -0.094358413830022136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69598144120453842,
                                 0,
                                 0,
                                 0,
                                 0.43778934654032575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068826668877403435,
                                 0,
                                 -0.14208213731124714,
                                 0,
                                 0,
                                 0.11269640540506021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42778770581216813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74496043948081458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46355892015208011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12908361564007725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44234310506822533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6651466508463646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0132036749095781,
                                 0,
                                 -0.13642629538524159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089162414254175038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3579859375993677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23823549155965534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05932801716208233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077002109682472841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11771449916426124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73973722557261157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28107306510447083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51057270273314193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6949342643435803,
                                 0,
                                 -0.89488187258678498,
                                 -0.083956092401009999,
                                 0,
                                 0,
                                 0,
                                 -0.15511221093828081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51374261779347818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28920913894612121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12769645251631498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13630198373618793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44915522301419442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051878842903209474,
                                 0,
                                 0,
                                 0,
                                 -0.22210373772241576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031039520600049622,
                                 0,
                                 0,
                                 0,
                                 0.080523811518794244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42998034942998009,
                                 0,
                                 -0.49191600152975223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7624081088531266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46662234978464279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60056319888137488,
                                 0.032974366494640542,
                                 0,
                                 0.22098954152267286,
                                 0,
                                 0.16183662360201131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16213129504086654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4078363210769701,
                                 0,
                                 0,
                                 0,
                                 -0.22447239131865315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2587375646029223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18847451913087326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.773784738791647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65603466441737257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49610318077741761,
                                 0,
                                 0,
                                 0,
                                 0.989642720679487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41416841249303643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1533379533826287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4016412464961856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28474498170102341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2759986196774043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22127134033848855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46403689365227385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64586230863830474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056329798155631286,
                                 0,
                                 -0.14490375864006161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70427040072763636,
                                 0,
                                 0,
                                 0,
                                 -0.060834010896249992,
                                 0,
                                 -0.30178203167326961,
                                 0,
                                 -0.070726262289324521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06849641430443229,
                                 0,
                                 0,
                                 0,
                                 -0.36750509424848093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034913604743900171,
                                 0,
                                 0,
                                 0,
                                 0.078313693443127649,
                                 0,
                                 0,
                                 0.30924527218989378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30972850290843579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099375084084724591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17752223201632483,
                                 0,
                                 0,
                                 0.094576129033573736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16829563515914131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3202553888784706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063057793160849543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60809438878177913,
                                 0.40410005648910985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41204362680659024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39158210365780549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080249597974978659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42451387579788996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65007323799138406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15027306758302361,
                                 0,
                                 -0.95908645218494248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070333506232956033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19861730658315627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10300356672769022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85252768640918353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0691509584000087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18210715912517961,
                                 0,
                                 0,
                                 0,
                                 0.5274299718445703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20845555822495945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49393697142665682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061397469227733245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39203453413507205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12028681198123531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099319208229728811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0058023432189707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4801599847359681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21528279956519519,
                                 0,
                                 -0.048537126031067614,
                                 -0.044657324364837471,
                                 0,
                                 0,
                                 0,
                                 0.12700907377469273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063455052711096291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44519394321246836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72712213780255353,
                                 0,
                                 0,
                                 -0.23412911732860633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34642895539500773,
                                 -0.39617071769516932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13327719204578681,
                                 0,
                                 0,
                                 0,
                                 -0.66316243581277989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24572105299037536,
                                 0,
                                 0,
                                 0,
                                 0.99548047680166962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33387896612065282,
                                 0,
                                 -0.017421221137067663,
                                 0,
                                 0,
                                 0.17724508320820087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1580653573357515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46252848812363034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042056090037169827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12778859240532273,
                                 0,
                                 0,
                                 -0.33519549693175965,
                                 0.3015378764472097,
                                 0,
                                 0.045010044186144404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047548422645450943,
                                 0,
                                 0.067899072822474579,
                                 0,
                                 0,
                                 0,
                                 -0.5228815631258148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4594681826970603,
                                 0,
                                 0,
                                 0,
                                 -0.25399549622594603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072339620700129975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34978625046654499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30802374759456908,
                                 0,
                                 0,
                                 0,
                                 -0.1139606834177552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34294341829992492,
                                 -0.011971245404132969,
                                 0,
                                 0.65106836637688115,
                                 0,
                                 -0.22670029604981803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50336579051558206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048949648871890114,
                                 0,
                                 0,
                                 0,
                                 -0.015460869783620299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081229812459188963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36244435948815618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22647435842153779,
                                 0,
                                 -0.0055635370116701305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34029510622401377,
                                 0,
                                 0,
                                 0,
                                 -0.18988212166748994,
                                 0,
                                 0.27008068016185993,
                                 0,
                                 -0.00080371736344295175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23328318693503744,
                                 0,
                                 0,
                                 0,
                                 0.024296730126727561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2688779411823593,
                                 0,
                                 0,
                                 0,
                                 0.5176562484399565,
                                 0,
                                 0,
                                 0.45858634608015636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22308607018353105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12656127859033806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22916567993900203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35193037077263434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67717328425505241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11683714543978294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10174912243783416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08610422504526638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82523334877060173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18713703844040025,
                                 0,
                                 0.23284227773252181,
                                 -0.56224854590927587,
                                 0,
                                 0,
                                 0,
                                 -0.33555501475882255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1417979882245603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0075184218275979597};

const double rot_8_30[900] = {-0.14598954035715947,
                              0.5355106837572936,
                              0,
                              0,
                              0.59353981477602979,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.10649545365614516,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.3875059041711057,
                              0.21561643767117722,
                              -0.36281302946949728,
                              0,
                              0,
                              0,
                              0.00010961759836705665,
                              -0.15641537583880294,
                              0,
                              0,
                              0.016617632405596744,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.28485870225202276,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.46806444583430057,
                              0.59523687380668722,
                              0.56632352135187236,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.079274897897442659,
                              0.7405897441295477,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.42982284784650177,
                              0,
                              -0.51038675621787444,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.68691207554362887,
                              -0.27861150004350227,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.62960701659803209,
                              0,
                              0.23264229444874962,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.15338250264385583,
                              0.44792794083496279,
                              0,
                              0,
                              -0.05206393018900049,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.21440939052094149,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.22471966226336534,
                              -0.54289166037305603,
                              0.61799841959457835,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.80368773786055037,
                              0,
                              0,
                              -0.29123525053156551,
                              0,
                              0.67180029531245233,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.31512865369204979,
                              0,
                              -0.66821762998896572,
                              0,
                              0,
                              0.48039733431490994,
                              -0.36135534976338507,
                              0,
                              0,
                              0,
                              0,
                              0.45980376370315529,
                              -0.1514716669559425,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.82191214446846228,
                              0.9142879853087067,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.055807377097097016,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.2816388721375489,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.89994456672179224,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.96573653709173535,
                              0.84418907797923737,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.97300608682606826,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.2616461874562156,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.74318282181877571,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.022543604385487984,
                              0,
                              0,
                              0.1506936175680714,
                              0,
                              1.1308029537851132,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.085134411887123881,
                              0,
                              0.40245637342073259,
                              0,
                              0,
                              -0.21730228218008621,
                              0.12387810042937956,
                              0,
                              0,
                              0,
                              0,
                              -0.54940043142205974,
                              0.35540176379543592,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.75144600474312706,
                              0,
                              -0.27427001452265959,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.85969022899171921,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.94688680072192255,
                              0,
                              0,
                              0.27027797054107555,
                              0,
                              -0.27148028348560582,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.10867846563619774,
                              0,
                              0.36264570604104462,
                              0,
                              0,
                              -0.38301683489252403,
                              -0.088516707784781185,
                              0,
                              0,
                              0,
                              0,
                              -0.64397647901805433,
                              -0.40030483077916301,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.9525102988732691,
                              0,
                              -0.68437190359326849,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.2011514672987442,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.64613694503985897,
                              0.061196423645269282,
                              0,
                              0,
                              -0.39766052667550877,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.42614516294969956,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.45015987427067727,
                              0.051705479758463284,
                              -0.18360578031716263,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.33109663720597804,
                              -0.45154810217109947,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.57522728987618321,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.84504397666146414,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.40423154932192124,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.8939320133234594,
                              0.44820258316465261,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.44820258316465267,
                              0.89393201332345829,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.59513317284305245,
                              0.17931272697389125,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.50844695974386045,
                              0,
                              0.59594055211419628,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.14948404679599281,
                              0,
                              0,
                              0.36330377361288357,
                              0,
                              0.19225512359281344,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.0986989274400987,
                              0,
                              -0.021201120229808579,
                              0,
                              0,
                              0.38904220065185879,
                              0.68027719393352692,
                              0,
                              0,
                              0,
                              0,
                              0.34305844379033124,
                              0.51799377426513038,
                              0,
                              0,
                              -0.40949212155724751,
                              -0.5845933705395806,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.40041105535046445,
                              0,
                              -0.57466318853467979,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.22346996957036216,
                              0,
                              0,
                              0.82230054431914346,
                              0,
                              0.3410535579248346,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.040076246894385714,
                              0,
                              0.82307236342872647,
                              0,
                              0,
                              -0.24671999947914469,
                              0.00045424104655733544,
                              0,
                              0,
                              0,
                              0,
                              0.65728988073913253,
                              -0.31703798497261976,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.0080400405257164409,
                              0,
                              -1.4412608872107113,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.23033356104586877,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.49199444365945483,
                              0.037611340034960541,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.48799243993690711,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.98036124480852183,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.41061843938898807,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.012259509979604982,
                              0,
                              0,
                              -0.22247821897671319,
                              0,
                              -0.51194938071094098,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.29456018131126438,
                              0,
                              0.52189552028546038,
                              0,
                              0,
                              0.57867486946002844,
                              -0.57009986358469877,
                              0,
                              0,
                              0,
                              0,
                              0.14944658444968417,
                              0.70409130376530982,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.0083428730928565807,
                              0,
                              0,
                              -0.97919225724056147,
                              0,
                              -0.10379605022129554,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.77115008652277717,
                              0,
                              0.047157522219831355,
                              0,
                              0,
                              -0.52836854569343106,
                              -0.21326800190560469,
                              0,
                              0,
                              0,
                              0,
                              0.20562666658099193,
                              0.024584265411006324,
                              -0.30653043162839755,
                              -0.61596966955675214,
                              0,
                              0,
                              0.13441840381236714,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.055553951151785408,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.55815919885797471,
                              -0.39743211256102745,
                              -0.18966269146913445,
                              0,
                              0,
                              0,
                              -0.51826471811223196,
                              -0.093328633896746754,
                              0,
                              0,
                              -0.1980217535839445,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.72255925000412835,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.12555805511838572,
                              0.37835729627109466,
                              0.049677908061246542,
                              0,
                              0,
                              0,
                              -0.41845988418641766,
                              0.31024059633854073,
                              0,
                              0,
                              -0.65521666118191435,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.39340188128397902,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.2242888612756376,
                              0.026292139336169411,
                              -0.30589444999681281,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.41456570082419969,
                              -0.95118960055472945,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.36642113171482965,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.14357355902383934,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.78764890365485574,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.44440686794214634,
                              0,
                              0,
                              -0.25588082673595669,
                              0,
                              0.11971082264976407,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.46031960140924,
                              0,
                              0.053856186314667515,
                              0,
                              0,
                              -0.58349624644906362,
                              0.52277725412112042,
                              0,
                              0,
                              0,
                              0,
                              0.63764424415070564,
                              0.89634073215103227,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.24248411234851155,
                              0,
                              0,
                              0.54956548884700207,
                              0,
                              0.45750486109910399,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.15260236859832071,
                              0,
                              -0.91234143688206104,
                              0,
                              0,
                              -0.69482870485957593,
                              -0.87835433954610198,
                              0,
                              0,
                              0,
                              0,
                              0.30263014273792455,
                              0.25572271182133138};

const double rot_8_2[4] = {-0.48990991008741397, -0.87177306680015199, 0.87177306680015176, -0.48990991008741391};

const double rot_7_50[2500] = {-0.51363263292630257,
                               0,
                               -0.51948723022891974,
                               0,
                               0,
                               0,
                               -0.28598347309987754,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34774818061360624,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.040333058566958839,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17943280193237274,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.043950629759303181,
                               0,
                               -0.01027699220504542,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1557309638005529,
                               0,
                               -0.95000201802176376,
                               0,
                               -0.22538140130896966,
                               0,
                               0,
                               0,
                               -0.056438497963652384,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.2671063222998342,
                               0,
                               0,
                               -0.58464007587097544,
                               0,
                               0,
                               0,
                               0,
                               -0.48880300507248386,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56032036146491282,
                               0,
                               -0.16369575559592084,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.75631695461971693,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41271301190279436,
                               0,
                               -0.59898109240894293,
                               0,
                               0,
                               0,
                               -0.22279806076522385,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13525315654878206,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.62682628447109745,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.64991233733342746,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.42359219281145255,
                               0,
                               0.24808945519792855,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24930477964241102,
                               0,
                               0.35920267043986043,
                               0,
                               0,
                               0,
                               -0.42013116699131975,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.59279667297010419,
                               0,
                               0,
                               0,
                               0,
                               -0.2419957179169166,
                               0.25041218583357283,
                               0,
                               -0.46075231516878484,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.001726802016247652,
                               0,
                               0,
                               0,
                               0.15489223297383725,
                               0,
                               0,
                               0,
                               0.3384175455259304,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24071161847463934,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.90132726159130283,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.3402261160548039,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20956197413254918,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33762995109364263,
                               0,
                               0.8587940636953949,
                               0,
                               0,
                               0.77507656917762902,
                               0,
                               0,
                               0,
                               -0.32725702491159436,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25490300779505348,
                               0,
                               0,
                               0.16265634583394645,
                               0,
                               0,
                               0,
                               0,
                               -1.5160725351475404,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14614486750911779,
                               0,
                               -0.30653172137943463,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0086528788507316545,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.46376472077393516,
                               0,
                               -0.42085163729190067,
                               0,
                               0,
                               0,
                               0.93757636568174185,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27172422151064479,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.80325944047701681,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30303243532187468,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13347740816884862,
                               0,
                               0.39453105421159873,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30965442453102238,
                               0,
                               -0.17424238942829456,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.09166445073516219,
                               0,
                               0.25983817652994762,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.96129170936246644,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1176707071630808,
                               0,
                               0,
                               0.52244421150840625,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16727133446289472,
                               0,
                               -0.17349937349048711,
                               0,
                               0,
                               0,
                               0,
                               0.41795130460997321,
                               0,
                               0,
                               0,
                               -0.69313824420337322,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41615483958750821,
                               0,
                               -0.88700870574643553,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20007674881886778,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22030883035674981,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10595700612721747,
                               0,
                               0,
                               0,
                               0,
                               -0.059240637731799661,
                               0.40237122290825245,
                               0,
                               0.33756155491146367,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1577288440189453,
                               0,
                               0,
                               0,
                               -0.71305417522667836,
                               0,
                               0,
                               0,
                               0.3571451099173113,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12875873249636716,
                               0,
                               0,
                               0.051344725448951217,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.69386958534393872,
                               0,
                               0.04695682212208957,
                               0,
                               0,
                               0,
                               0,
                               -0.54503109510471492,
                               0,
                               0,
                               0,
                               -0.44728745649110413,
                               0,
                               0,
                               0,
                               0,
                               -0.58127035208381361,
                               0,
                               0.075510999598397327,
                               0,
                               0,
                               0,
                               -0.19986190297326833,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0253865735891552,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44761045686653983,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.089594263476766078,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16960751882405856,
                               0,
                               0.1993511591703151,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18877394742476725,
                               0,
                               0.61458023619108559,
                               0,
                               0,
                               0,
                               0,
                               -0.50791349885896386,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.090960104186272497,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.036736729105871724,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.74366251058429711,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.82055135931886591,
                               0,
                               -0.46288294524502543,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12508777370347254,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.094038054380019026,
                               0,
                               0,
                               0,
                               0,
                               0.75019160834492515,
                               0,
                               0,
                               -0.27994484733680852,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57823293439301315,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2807478055031617,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21693239492916525,
                               0,
                               0,
                               0,
                               0,
                               0.1635032931877114,
                               -0.21166723118428438,
                               0,
                               0.24783569985302911,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.59182922962024009,
                               0,
                               0,
                               0,
                               0.45104688496660217,
                               0,
                               0,
                               0,
                               0.43296304519254725,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17620229110739791,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.4837861744925161,
                               0,
                               0,
                               0,
                               0,
                               -0.34613930655357572,
                               0.44198188012805711,
                               0,
                               0.01760562148010263,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39171385982885604,
                               0,
                               0,
                               0,
                               0.3876712268196072,
                               0,
                               0,
                               0,
                               0.34015379180884853,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.77530468238708528,
                               0,
                               0,
                               0,
                               -0.049523731879061408,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.81629974429541352,
                               0,
                               0,
                               0.22498580275270175,
                               0,
                               0,
                               0,
                               0,
                               0.65308342308297407,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.64404246720358227,
                               0,
                               -0.93959130227807675,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.63527796481905041,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15105311797186738,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.43631776564580732,
                               0,
                               0,
                               0,
                               0,
                               0.12059150901524182,
                               -0.095843934514380821,
                               0,
                               -0.77415718224287078,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24425448742937891,
                               0,
                               0,
                               0,
                               -0.26967339497027665,
                               0,
                               0,
                               0,
                               0.17713851557651727,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.72002539043353742,
                               0,
                               -0.1400622493158008,
                               0,
                               0,
                               0,
                               -0.45666165693834576,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.05020928369537038,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10335725050019329,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.36431845626121234,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.66699936824883455,
                               0,
                               0.22525134123631363,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36498404978888027,
                               0,
                               -0.38531684780634468,
                               0,
                               0.8430819996033746,
                               0,
                               0,
                               0,
                               0.32659606368650745,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.75615816332688823,
                               0,
                               0,
                               0.46882755804258197,
                               0,
                               0,
                               0,
                               0,
                               -0.096016005575637997,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50719152643966481,
                               0,
                               1.0328768774348509,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0043328221679725387,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.42677631961653129,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.86142119522168981,
                               0,
                               0,
                               0,
                               0,
                               -0.05950230739897884,
                               0,
                               0,
                               -0.14585643692540839,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22583372790401574,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37373508212391848,
                               0,
                               0,
                               0,
                               0,
                               1.0366062682456016,
                               0,
                               0,
                               -0.53546023956831834,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.88435673279550164,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.74811895236247761,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.53617047215656122,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.70827035223977508,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22559007245510695,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37365031220514261,
                               0,
                               -0.64669868726465762,
                               0,
                               0,
                               0,
                               0,
                               0.044832408027217135,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.046675244689831336,
                               0,
                               0,
                               0,
                               0,
                               -0.86960560998861813,
                               -0.41937106467980401,
                               0,
                               0.049594168518521303,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20663332876326901,
                               0,
                               0,
                               0,
                               -0.12694313675210281,
                               0,
                               0,
                               0,
                               -0.049537822257147757,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.2235747374053817,
                               0,
                               0,
                               0,
                               1.5094049545001833,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21903786347718909,
                               0,
                               0,
                               0.37727518982636071,
                               0,
                               0,
                               0,
                               0,
                               0.1662879709708342,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.77079390421983074,
                               0,
                               0.08706893893837428,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.077820101271434183,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38557253013201431,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.094918894835690562,
                               0,
                               0,
                               0,
                               0,
                               0.42631056680190205,
                               0,
                               0,
                               0.7746291062920585,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24603511076465306,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.406303152828261,
                               0,
                               0,
                               0,
                               0,
                               -0.40525242590161359,
                               0,
                               0,
                               0.30805654657164555,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12719232905683847,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.78260712738631555,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4045070126155712,
                               0,
                               0,
                               0,
                               0,
                               0.045549930229626764,
                               -0.011240448164899192,
                               0,
                               0.089341490289730291,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16214860207004933,
                               0,
                               0,
                               0,
                               -0.017204605644926735,
                               0,
                               0,
                               0,
                               0.43258403529746137,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.76019394227051018,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31519133195651844,
                               0,
                               0,
                               0,
                               0,
                               -0.41067573277275066,
                               0,
                               0,
                               -0.068209662150366418,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38659084171200098,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14468873416630537,
                               0,
                               0,
                               0,
                               0,
                               0.50858212000801295,
                               0,
                               0,
                               0.79882013306210942,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.74962165111618018,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50032182073539255,
                               0,
                               -0.72739067855172335,
                               0,
                               0,
                               0,
                               0.65321763500271923,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.42355463444568464,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28761728357042937,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26892303545157648,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49196865568828685,
                               0,
                               -0.37144823486737605,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.6946248199916899,
                               0,
                               0.095139095628118897,
                               0,
                               0,
                               0,
                               -0.16669234838051944,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0088767352189479953,
                               0,
                               0,
                               0,
                               0,
                               0.13620516808189154,
                               -0.59165500056519238,
                               0,
                               0.047604437047010742,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58546331103313975,
                               0,
                               0,
                               0,
                               -0.15714823713815426,
                               0,
                               0,
                               0,
                               0.48352697714724024,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20726834797100591,
                               0,
                               0,
                               0,
                               -0.77692086320572873,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28346732579269962,
                               0,
                               0,
                               0.45866204119393122,
                               0,
                               0,
                               0,
                               0,
                               -0.038682774907896691,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.2087911500430615,
                               0,
                               0.36654132123414629,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.83317391334907853,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.77564934836601562,
                               0,
                               0,
                               0.0355227488776588,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31607553778392128,
                               0,
                               -0.32081058817524621,
                               0,
                               0,
                               0,
                               0,
                               0.28631523344161347,
                               0,
                               0,
                               0,
                               0.33512181474813252,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19877363288526065,
                               0,
                               0,
                               0,
                               0.25097859300865011,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1676993903855622,
                               0,
                               0,
                               -0.91833171260668189,
                               0,
                               0,
                               0,
                               0,
                               -0.24511585796421576,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21891321883440626,
                               0,
                               0.66462367812139811,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.99830755590809994,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27005544550661092,
                               0,
                               0,
                               0.81455128680991962,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15557066915156639,
                               0,
                               -0.086867780332439748,
                               0,
                               0,
                               0,
                               0,
                               -0.16707801730344732,
                               0,
                               0,
                               0,
                               0.45156721457865767,
                               0,
                               0,
                               0,
                               0,
                               0.041278146310763986,
                               0,
                               0.76608335789044213,
                               0,
                               0,
                               0,
                               0.12113733853659973,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28713885047179039,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.053614961547856443,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.68004976134108475,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29073834592319203,
                               0,
                               0.88022277962483719,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25443363032075939,
                               0,
                               -0.28658040396190859,
                               0,
                               0,
                               0,
                               0,
                               0.17923929456896656,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.8304530851728712,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17515376551263814,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.194907354474769,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.85758219879824149,
                               0,
                               -0.60182261664765502,
                               0,
                               0.8091306644455647,
                               0,
                               0.60669873291799936,
                               0,
                               0,
                               0,
                               0.15589506379867038,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21647002402902132,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.071607136216917389,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13535543306794259,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46315382095398394,
                               0,
                               -0.48491215237185537,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29598656238878807,
                               0,
                               -0.57492074947426841,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27505275135379975,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37517355505672617,
                               0,
                               0,
                               0,
                               0,
                               0.28857714623243519,
                               0,
                               0,
                               -0.54374072123714856,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.63612895414345949,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51570177320274624,
                               0,
                               0,
                               0.19059901030630527,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.58295136071035225,
                               0,
                               0.16363537911145648,
                               0,
                               0,
                               0,
                               0,
                               -0.57520584958512055,
                               0,
                               0,
                               0,
                               -0.015909202929661651,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.90589906845766688,
                               0,
                               0,
                               0,
                               -0.076467194185668608,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.45064866403406256,
                               0,
                               0,
                               1.2207835569414021,
                               0,
                               0,
                               0,
                               0,
                               -0.25932329133769683,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28736881745471182,
                               0,
                               0.47419324744445646,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10566829779528802,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25846024714799665,
                               0,
                               0,
                               0,
                               0,
                               1.4735392551359823,
                               0,
                               0,
                               0.066321626405589126,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.55827596245986721,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.90466169254551543,
                               0,
                               -0.38170627182118055,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18944008048208555,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17048348696813526,
                               0,
                               0,
                               0.1527485442440194,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16317791383003041,
                               0,
                               0.91129086586688701,
                               0,
                               0,
                               0,
                               0,
                               0.29581170730729933,
                               0,
                               0,
                               0,
                               0.054960194214697569,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.06983760961729292,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.82250194279777988,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51108447780833721,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0194080053124734,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.036508346837625945,
                               0,
                               -0.22879950028547583,
                               0,
                               0.30968640817495929,
                               0,
                               0.095834033445586372,
                               0,
                               0,
                               0,
                               -0.23717635349553445,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.084451345392786509,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20940915887322115,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.65025366313768285,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.91359724928847308,
                               0,
                               -0.49398978291152418,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.52812430882324646,
                               0,
                               -0.021587105084367175,
                               0,
                               0,
                               0,
                               0,
                               -1.0820404588074719,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.59494458814958684,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.43876406890923225,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57996834212294801,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23416315722439723,
                               0,
                               0.33828195686702356,
                               0,
                               -0.4782993071471946,
                               0,
                               0.56012298261593985,
                               0,
                               0,
                               0,
                               -0.045736280961349879,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19988442149056432,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.97279322019485126,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10621038916675782,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.070390172270823018,
                               0,
                               -0.2986312760296575,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31392640016546891,
                               0,
                               -0.58187804494335393};

const double rot_7_20[400] = {0.29107899131066145,
                              0,
                              0,
                              1.0307448732075808,
                              -0.24498124632881274,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.39812296034082706,
                              0,
                              0,
                              0.24500395825680549,
                              0.93864763409453322,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.2622643706663821,
                              0,
                              0,
                              -1.2362791435157265,
                              -0.76592768848913029,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.55534119776966473,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.72833505900497908,
                              0,
                              0,
                              0,
                              0,
                              -0.40140278509742211,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.3816272638571343,
                              0.76934085570680533,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.13787683402359319,
                              0,
                              0.49342198761391698,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.9235329660511844,
                              -0.3246055133340961,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.091552199951667329,
                              0,
                              -0.18258235405925607,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.83150335412005183,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.49447175109723984,
                              0,
                              0,
                              0,
                              0,
                              -0.2531795004614984,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.023454951802569061,
                              -0.31372138030037811,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.92513331377734753,
                              0,
                              0.21250202944374028,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.029955923179866333,
                              0.45202301268392764,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.34166727244935835,
                              0,
                              -0.82343264060128396,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.014082831634954602,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.47436876919865029,
                              0,
                              0,
                              0,
                              0,
                              0.88021357900347053,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1};

const double rot_7_10[100] = {0.41861976283251623,
                              0.47193137005639801,
                              0,
                              0,
                              0,
                              0,
                              -0.77591125531386618,
                              0,
                              0,
                              0,
                              -0.72175801716447086,
                              -0.34566877699550874,
                              0,
                              0,
                              0,
                              0,
                              -0.59964861483142018,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.60166910257992567,
                              0,
                              -1.2020582402390394,
                              -0.99804468283688319,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.95046556349731703,
                              0,
                              0,
                              0,
                              -0.018799758068271805,
                              -0.19256316286365355,
                              0.24327188495641661,
                              0,
                              0,
                              1.830837622979131,
                              0,
                              -0.37761208034529331,
                              -0.70883810129388958,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.29120396101228341,
                              0,
                              -0.45120726841766085,
                              0.94775309609368819,
                              0,
                              0,
                              0,
                              0,
                              -0.55120128703120719,
                              0.81104493005450728,
                              0,
                              0,
                              0,
                              0,
                              0.19591646844515204,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.22983331144632324,
                              0,
                              0,
                              0,
                              0.24851659872112386,
                              -0.074827075745034777,
                              -0.9379856384002625,
                              0,
                              0,
                              0,
                              0.048684035786767769,
                              0,
                              0,
                              0,
                              -0.88040750129716194,
                              -0.42161150873561526,
                              -0.2115566874879613,
                              0,
                              0,
                              0,
                              0.20352328175139395,
                              0,
                              0,
                              0,
                              0.40344603222283171,
                              -0.8829292569311944,
                              0.12745783665089244};

const double rot_7_100[10000] = {0.29902943737738441,
                                 0,
                                 -0.43782672570214903,
                                 0,
                                 0,
                                 0,
                                 0.61807130474216909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49325134682672944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1334392849047952,
                                 0.054437410011109362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61222971754685884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11028050139220222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05196472640302402,
                                 0,
                                 0.14850393010338253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18384718440384898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38360294159281766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062092847889707856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62383636768608397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5166003789341268,
                                 0.36659508864702284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0795680168099251,
                                 0,
                                 0.36408703369899648,
                                 0,
                                 0,
                                 0,
                                 0.31686880769278697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37951060256755215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39134266474696261,
                                 -0.82969739368077389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53980924475728942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39658955022300457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51931050793546663,
                                 0,
                                 0.22742035040545458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2448068375201618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37236268848313575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39038497801971106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26772633647653749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27205928156683407,
                                 -0.42651863512043342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16128054338997783,
                                 0.84133958149804466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051098707483262826,
                                 0.13770612571389423,
                                 -0.30268931125190818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50960379998319372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31625392259363594,
                                 0.40864297779084907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30445691039943557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34733534829173696,
                                 0,
                                 0,
                                 -0.46583319397352452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25491002300062882,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13062826628875468,
                                 0,
                                 0,
                                 0,
                                 -0.49163084606305052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46327868783145432,
                                 0.12820250262880484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10223329029324735,
                                 0.17546066130366303,
                                 0.21310841850490331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26383492387630475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1105308413979095,
                                 -0.99889304413645108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60009057404202926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077458807866335078,
                                 0,
                                 0,
                                 -0.21897669497480737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54634050845404158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27520106877545492,
                                 0,
                                 0,
                                 0,
                                 -0.026514960786986133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60889045180819823,
                                 0,
                                 -0.31845008707823264,
                                 0,
                                 0,
                                 0,
                                 -0.75694454881544004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049542719930418283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27087218300899429,
                                 -0.44303196027773251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06095630894305297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85289763809633523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00037292763430208861,
                                 0,
                                 -0.81989644456569888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061313682286995408,
                                 0,
                                 0,
                                 -0.35786531434976143,
                                 -0.30688844142640581,
                                 0,
                                 0,
                                 -0.25825224974265926,
                                 0,
                                 -0.56340592418222335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93247111597688492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42949629156163088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.055385547722302059,
                                 0,
                                 0,
                                 -0.14890026655083768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2769884428941316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18613486322717213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35261379573283058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31959336218133999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53074891340485686,
                                 0,
                                 0.33186179600143406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30196918424105657,
                                 0,
                                 0,
                                 0.29362781095256302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2223904481335465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20581674189752758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17825607924931069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18837447285101205,
                                 0,
                                 0,
                                 0.10280978455668141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054532900145204705,
                                 0,
                                 -0.070535260762822516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44534405551851963,
                                 0,
                                 0,
                                 1.0461833675124919,
                                 -0.20847663412343143,
                                 0,
                                 0,
                                 0.024956446422001288,
                                 0,
                                 0.02448956348728093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39524436893798942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77495551685512709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26290700401734235,
                                 0,
                                 0,
                                 0.3348092922986533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28366021206238579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36653853449200635,
                                 -0.027330286537419719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062427621004608906,
                                 0.050943460781501096,
                                 -0.594362712970536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5948236628886826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45138612576133452,
                                 0.29338883091538787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22293991361417531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71114962245459756,
                                 0,
                                 0,
                                 -0.031378175580681067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21907429745335733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97042508749595768,
                                 0,
                                 0,
                                 0,
                                 -0.086905320662977001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24864325763147319,
                                 0.38970743722056023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063903716632565388,
                                 -0.22767012361083264,
                                 0.33333322291671502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77226711034136297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2869336974228045,
                                 0.48785889782867953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45612918429608817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17961983145231186,
                                 0,
                                 0,
                                 0.04013114974838676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44159401266446968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26661894908947198,
                                 0,
                                 0,
                                 0,
                                 0.23028589944824313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70250888727941074,
                                 -0.2652370492505256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34819200327292849,
                                 -0.25555696682252388,
                                 0.3970670930380536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014741151317768852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13568143535877489,
                                 -0.063757888154372777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10383317228033187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12213077249158208,
                                 0,
                                 0,
                                 -0.89480972236371981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27702827284994958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26842036537231928,
                                 0,
                                 0,
                                 0,
                                 -0.15904769533044766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30638181796290548,
                                 0,
                                 -0.67343967731996435,
                                 0,
                                 0,
                                 0,
                                 0.51907329334825802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73674805244168129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31344113069069335,
                                 -0.34429494170309555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78811245452196266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27624277236827177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13551526893869639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11443515288985444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29204963266476774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034831928592662119,
                                 0,
                                 -0.033578156380748653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078817322642122933,
                                 0,
                                 0,
                                 0.25976835278171218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60053241918867273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18732054566638437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00016245002223324451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56647849410408824,
                                 0,
                                 0,
                                 -0.30097942195325295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39639658239723835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68526885295585693,
                                 0.0094111876398908587,
                                 0,
                                 0.20486720353983529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073691498902033567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19313156446353341,
                                 0,
                                 0,
                                 0,
                                 0.0011271344646831341,
                                 0,
                                 -0.30534554968512329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27528169097376537,
                                 0,
                                 0.12358314183469411,
                                 0,
                                 0.13872340074417733,
                                 0,
                                 0.11157234706483571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25886396650391014,
                                 0.074120629498932028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62986066011726294,
                                 0,
                                 0.21647868454303593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24121676904260464,
                                 0,
                                 0,
                                 0.08060265321235302,
                                 0.20104822105545683,
                                 0,
                                 0,
                                 0.035455752675239163,
                                 0,
                                 0.56920787482344704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20059896429182206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54770802788394235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53042664292385122,
                                 0,
                                 0,
                                 -0.099113021257476175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057284132919057568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2103871195895696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.5293999477053648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052449018199779762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54340805951158722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80034760590888676,
                                 0,
                                 0.2009370887533064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63426023681527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49715029364038321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33387034829308915,
                                 -0.32201285293510351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11757042785504186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30369898299681397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092721630308420899,
                                 0,
                                 0,
                                 0.080441826311296843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11186402791841296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041907325550168462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37338360819901323,
                                 0,
                                 -0.43830632862092073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40945489818309039,
                                 0,
                                 0,
                                 0.35475712803160353,
                                 -0.11235947869412208,
                                 0,
                                 0,
                                 -0.51301412191122275,
                                 0,
                                 0.13670058514853131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49981713119722793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5451207542099652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23683272925529225,
                                 0,
                                 0,
                                 0.73411005438363508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61095940537053905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30078431752702112,
                                 0,
                                 0.082078211114348903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048261130393913831,
                                 0,
                                 0,
                                 -0.4819119328057947,
                                 -0.0083339429985396229,
                                 0,
                                 0,
                                 0.15377237639773939,
                                 0,
                                 0.59989043512966844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072549010493572832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47300680706336862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28622141988105648,
                                 0,
                                 0,
                                 0.64223144133659393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36674969560318815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044954681325028861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00031127471912649474,
                                 0.19669050983804928,
                                 0,
                                 -0.6800020474281101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088306846336514422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066308923223559676,
                                 0,
                                 0,
                                 0,
                                 0.044333721860496299,
                                 0,
                                 -0.2743024223184849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2890867668697889,
                                 0,
                                 0.18232285709567905,
                                 0,
                                 0.046225904570620854,
                                 0,
                                 -0.43468375873595433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14809632497053749,
                                 0.27866585643876679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42163974783123759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14693990133717824,
                                 0.15893222603763937,
                                 0,
                                 -0.24828147063535344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22191332567979707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22440146007642162,
                                 0,
                                 0,
                                 0,
                                 -0.48791358926531708,
                                 0,
                                 -0.17876673596409881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18650509996226367,
                                 0,
                                 -0.20712035153979455,
                                 0,
                                 -0.25512675685022757,
                                 0,
                                 -0.071760825244167353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19919203489506371,
                                 -0.39560959825793007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19669267328257198,
                                 0,
                                 0.41547056644587133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12065556076605061,
                                 0,
                                 0,
                                 0.19541897853175505,
                                 -0.40685490564665455,
                                 0,
                                 0,
                                 0.25560050952917884,
                                 0,
                                 0.37015133033966935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84249330704880909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44149882288525383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75899850687195236,
                                 0,
                                 0,
                                 -0.45162266193782707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65541958734131778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20002419217073883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063019224346740024,
                                 -0.15673197062802202,
                                 0,
                                 -0.16265066474754447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47101491875948548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27820363740947512,
                                 0,
                                 0,
                                 0,
                                 0.31300807699292099,
                                 0,
                                 0.0078361248943714622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35626760012035563,
                                 0,
                                 -0.1436496268405387,
                                 0,
                                 -0.42681714968037199,
                                 0,
                                 0.19571693757006514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32145467163988051,
                                 0.19062541502187119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81895217625752736,
                                 0,
                                 -0.077829498674762659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11726988438969126,
                                 0,
                                 0,
                                 0.38267868306727026,
                                 0.4400337908673948,
                                 0,
                                 0,
                                 0.16106661698031638,
                                 0,
                                 -0.030580592202814644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22835975583821538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21685470477624835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66820049731011288,
                                 0,
                                 0,
                                 -0.1116289136590265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44188265245363456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38356769062561596,
                                 -0.59086306282894496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32837557863487987,
                                 0.19968665251846873,
                                 -0.53781871588803043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083807541932148039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12939348567697595,
                                 0.36848552478305402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4954690192894739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19112893040306128,
                                 0,
                                 0,
                                 0.25264974653544109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30617731031297835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96101080051336552,
                                 0,
                                 0,
                                 0,
                                 -0.42669609089308941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017707921503899993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10234661160702251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15256365416975015,
                                 -0.20943043649836993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45133662600147628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36955559281551198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24493062942203978,
                                 0,
                                 0,
                                 0.13705298413964023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27608396897274456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65330073208058381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30302912970809937,
                                 0,
                                 -0.57599236377530416,
                                 0,
                                 0.42667967834157533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34992527044728222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51580493308858222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076473339243805338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25470145203304589,
                                 0,
                                 0,
                                 0,
                                 0.45488998376790457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32300733659012648,
                                 0,
                                 0,
                                 0.65003857425370459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54896110888727678,
                                 0,
                                 -0.45069669801289591,
                                 0,
                                 0,
                                 0,
                                 0.8846194463932131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087262403637128116,
                                 0,
                                 0.0066385071807556484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42888382455544166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48581854667247815,
                                 0,
                                 0.11727605647906676,
                                 0,
                                 -0.28337710363594709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087781733675530327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6348598942495588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50908875977281065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0082367053666492773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39610087424068197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16964437439333935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39233547094712701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76065026256832935,
                                 0,
                                 -1.578219475871657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72447401012798329,
                                 0,
                                 -0.059202203083001177,
                                 0,
                                 0.5400790889171232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2994501265239734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29707128250916442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045004003675053028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094039623053491478,
                                 0,
                                 0,
                                 0,
                                 -0.12832612123659398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22601123353398855,
                                 0,
                                 0,
                                 -0.34640755887451669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41276989344923259,
                                 0,
                                 0.77275275412935773,
                                 0,
                                 0,
                                 0,
                                 0.36497881149699735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30479315251133399,
                                 0,
                                 0.81020078353996139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69907929273979874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29031347337784719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1407448372970086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25289714621318726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11419963748642412,
                                 0,
                                 -0.078639893299594893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59308535446534283,
                                 0,
                                 0,
                                 0.53015539549607638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10555409925893415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23365612173514694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29583433919484159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047657194199952471,
                                 0,
                                 0,
                                 -0.15615769212925493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45464379289481016,
                                 -0.42414279620218087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86793610167076773,
                                 -0.3309673354271972,
                                 0.34043491569984935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47520689433622965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32022919448366838,
                                 0.28441848151095661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47727817400609818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35588330500797072,
                                 0,
                                 0,
                                 -0.072823881583322758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45045841689991062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24253102443043792,
                                 0,
                                 0,
                                 0,
                                 -0.52822698694693615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18763997317204534,
                                 -0.067603960137217312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016906421556193985,
                                 0.35303772011277629,
                                 -0.061117938466272212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19860979983743493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0013013841287852213,
                                 -0.20135774341787505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52710839026129386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60592661711028328,
                                 0,
                                 0,
                                 -0.52859316816013913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97040117078221866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047568302389666493,
                                 0,
                                 0,
                                 0,
                                 -0.094651314571320103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19732438608332581,
                                 0,
                                 0.18101909381614897,
                                 0,
                                 0,
                                 0,
                                 0.25951030904656525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56803586505120518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47027199296483596,
                                 0.67083248540404805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.94231691061084877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3798691466416228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19522234300653493,
                                 0,
                                 5.9162498855201695e-06,
                                 0,
                                 0,
                                 0,
                                 -0.75129911643162917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56221446970059907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37259300279758678,
                                 -0.61923120453195823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49453750970697546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56645204176328801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14679530507395891,
                                 0,
                                 0.85101556490101204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083963454539773261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2391148807120233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25804832405277722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084336020771045628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16384602599257819,
                                 0.29908332726645659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099972499224309716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073273566813530144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12238714885728037,
                                 -0.00048367047355946623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45416388522088258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39672825227853076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44837692573588206,
                                 0,
                                 0,
                                 -0.49106356644368443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30306472949866292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26826474010009993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28022287132204404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35831995762766505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31309737625879247,
                                 0.62765155265703565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33508462890685686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16535042650749668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023616951128938676,
                                 0,
                                 0,
                                 0.33786285665826288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1816264132596791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11741301214715318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20039789937806746,
                                 0,
                                 0.54562191187115761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51996878667230984,
                                 0,
                                 0,
                                 0.11518009345948206,
                                 0.62607384533881982,
                                 0,
                                 0,
                                 -0.68925176922293196,
                                 0,
                                 0.13915045239237853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92345456759990197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13313230374098761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2422757135113171,
                                 0,
                                 0,
                                 0.25996894277095206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40073810206904892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053344196752374395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2183091497771264,
                                 0.24947794836310674,
                                 0,
                                 -0.16212130165495811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45067010066461199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13122190472385525,
                                 0,
                                 0,
                                 0,
                                 -0.077007528774446582,
                                 0,
                                 0.32633776177657342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0077960628068986654,
                                 0,
                                 0.27922214892892866,
                                 0,
                                 -0.61629972943064526,
                                 0,
                                 0.24208980997141366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082413785816110335,
                                 -0.070520030745650525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40373713676961115,
                                 0.32644233143128809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21592523596482635,
                                 0.30392640569444607,
                                 0.49230897669458662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36853594419255425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025207732393895316,
                                 0.37830547406271781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66099114425956418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39092155951998797,
                                 0,
                                 0,
                                 0.10916244349239113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74907978922672458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0067473102954696586,
                                 0,
                                 0,
                                 0,
                                 -0.079195452592300805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77455434270327572,
                                 0,
                                 0,
                                 0,
                                 0.8616276716806579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5178724856002126,
                                 0,
                                 0,
                                 -0.23129810377129001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33201600629230255,
                                 0,
                                 -0.080537545572114191,
                                 0,
                                 0,
                                 0,
                                 -0.36304075619088183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21617798015143044,
                                 0,
                                 -0.10705869421204396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21353646778350927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50580406470410955,
                                 0,
                                 -0.24353825655592459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49647311265771399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41388950989491025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44501242516542711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039885567084849624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21488424956522759,
                                 0.14580510966666066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065050303093852041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15409324949690792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083742969991304164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16844486964648184,
                                 0,
                                 -0.18292050191477877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11728951074697631,
                                 0,
                                 0,
                                 -0.31093311983661864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4424860127645911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27558375354972448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47477254691544107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089389586527830966,
                                 0,
                                 0,
                                 0.53628469942120416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068709608107923204,
                                 0,
                                 0,
                                 0,
                                 -0.27706920435617649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18924854311757849,
                                 0,
                                 0,
                                 0.062508182481787994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47676569086301962,
                                 0,
                                 -0.14376709324407827,
                                 0,
                                 0,
                                 0,
                                 0.0062940102381191382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05731271434057153,
                                 0,
                                 1.2459328096463123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043606489936950876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2884041460391179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45281262552808632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35411871691640656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090124613932021355,
                                 0,
                                 0.37877799127070616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58399678823221102,
                                 0,
                                 0,
                                 -0.039945495338422857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26235972604117186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10788199010391805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0012447050265320236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070481131575992395,
                                 0,
                                 0,
                                 0.081855459392972757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3817232710282408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21184199840468482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29109480602938959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069519906328926351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34616309901522191,
                                 0,
                                 0.47703256701163033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093046532553377345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021085140834351188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070600002411529875,
                                 -0.027183529359832214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12494845604761977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11518312121163962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18892701525984559,
                                 0,
                                 0,
                                 -0.32582293624977487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83484057544523094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34275705337008322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14211801381238254,
                                 0,
                                 0.46117724099429924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61769858466926442,
                                 0,
                                 0,
                                 -0.14274836120862119,
                                 -0.0520953527302358,
                                 0,
                                 0,
                                 0.81890146928135954,
                                 0,
                                 -0.7523740587263188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031590173178831844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46442891967832101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080735157557893525,
                                 0,
                                 0,
                                 0.40546316884801287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16869011977701592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13601417671471469,
                                 0,
                                 0,
                                 0,
                                 0.76781109270443304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54602047717180602,
                                 0,
                                 0,
                                 0.38705692859814528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47033202327831808,
                                 0,
                                 -0.14295265098154414,
                                 0,
                                 0,
                                 0,
                                 0.49153186263164161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45962798263850646,
                                 0,
                                 0.38268375035472785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50641106169923822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23103265136092949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061703160475265584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13464292535648428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31398421223319961,
                                 0,
                                 0.36776143791110505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22411687189386503,
                                 0,
                                 0,
                                 0.084274795751439369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052075425773821814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5174690816808325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30638030565853408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34033940385413164,
                                 0,
                                 0,
                                 0.39158248231379983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034943120895249313,
                                 0,
                                 0,
                                 0,
                                 0.059179882572435116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61193137067329761,
                                 0,
                                 0,
                                 0.74944569227366431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37180476297764842,
                                 0,
                                 -0.50505644136850902,
                                 0,
                                 0,
                                 0,
                                 -0.77583422966482052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043581183870985092,
                                 0,
                                 0.26120734560593106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84527769811675035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34818803035093326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51165840409621821,
                                 0.0008385034650763637,
                                 0,
                                 0.21115289188356345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10370111843712104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18251260984373568,
                                 0,
                                 0,
                                 0,
                                 -0.11857741574722459,
                                 0,
                                 -0.21873375849440932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10145392097588643,
                                 0,
                                 0.32802506406035337,
                                 0,
                                 -0.11933227876497741,
                                 0,
                                 0.35109838129038889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23406692277933344,
                                 0.39525151445527573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35318682517149735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6066781795044226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14180642585863384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088269199871104029,
                                 0,
                                 0.16940143090494808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041210279436219077,
                                 0,
                                 0,
                                 0.41521460206524896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091013141177888793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30202973587499554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022111614379478742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0041023697870290754,
                                 0,
                                 0,
                                 0.42010800413418936,
                                 0,
                                 0,
                                 0.035913978141490915,
                                 0,
                                 0.17334629895179793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41819889889770051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15969704040255348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18662922308457952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66606592868748815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21893699107273965,
                                 -0.49179272944373359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0999971185361819,
                                 0,
                                 0,
                                 0,
                                 -0.14569753786066431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33410744829747308,
                                 0,
                                 0,
                                 -0.99589340358843037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24466631711437886,
                                 0,
                                 -0.29387380058027102,
                                 0,
                                 0,
                                 0,
                                 -0.26849732667281501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58581926474384738,
                                 0,
                                 0.15366795344665307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73890264854138843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22490057599719357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12937631039287173,
                                 0.13999086080230008,
                                 0,
                                 0.14031388947362686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23870894854170668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19625626733435636,
                                 0,
                                 0,
                                 0,
                                 0.13562022798071974,
                                 0,
                                 -0.27202328492958311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13245104379147066,
                                 0,
                                 0.30268623202479672,
                                 0,
                                 -0.17416036356402595,
                                 0,
                                 -0.010447342390437486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55686146548053705,
                                 -0.50577679778612428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0010025333175856729,
                                 -0.57062582282010399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40652814698953688,
                                 0.94613860803340388,
                                 0.52452784268436958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53299915465658876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38878179513225158,
                                 0.30513449251694591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42404193266580759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16587004300484004,
                                 0,
                                 0,
                                 0.13286763227506818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25938660732269692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15943240744148102,
                                 0,
                                 0,
                                 0,
                                 0.24122475749405425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32538840216324921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077578283693031727,
                                 0.5555250064227496,
                                 0,
                                 0.20223832544753215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0042635850055978402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27974067050763279,
                                 0,
                                 0,
                                 0,
                                 0.39409486991644727,
                                 0,
                                 0.0071330953632520967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17718413377715655,
                                 0,
                                 -0.48850533070869834,
                                 0,
                                 -0.11319049887236675,
                                 0,
                                 -0.0039190149948398487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14864411648200654,
                                 -0.0025999399207567112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24271758377668129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28160719854121874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10820011214086903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66574354946786241,
                                 0,
                                 0.052170507468213709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10022300927516568,
                                 0,
                                 0,
                                 0.30944287996672937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11143354756185866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17637730126529053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18701242855864092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46425330312730084,
                                 0,
                                 0,
                                 -0.065660849114127257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28862886712178243,
                                 0.5309934757555349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077324047793764589,
                                 -0.3784565559212541,
                                 0.21844671653540226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16396252197143873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0493517556489638,
                                 -0.35898257389549704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043469626514165409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41131550330848876,
                                 0,
                                 0,
                                 0.35720744813777083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28162795006733138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.123036134982714,
                                 0,
                                 0,
                                 0,
                                 -0.35790243342312883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25376271084729013,
                                 0,
                                 -0.84313437777267231,
                                 0,
                                 0,
                                 0,
                                 -0.38258652324734521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63791924138341316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099604839496325495,
                                 -0.0080926503721279967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17544764425988318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36727037706020893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021419497920676538,
                                 0,
                                 -0.54292270381323782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74793338213037797,
                                 0,
                                 0,
                                 0.33489518166025856,
                                 -0.23489725292070363,
                                 0,
                                 0,
                                 -0.024049625155347337,
                                 0,
                                 0.41001754868800255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03260820294712459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12054072451673971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075616225181673768,
                                 0,
                                 0,
                                 -0.23077086079835663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45574313337012157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35273312151912251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0072874134408402388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25307220063356795,
                                 0.060175394257978389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045158867220950583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45851421115753693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47749648417295726,
                                 0,
                                 0,
                                 0.60268651892295011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062962385398005999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019667795885518861,
                                 0,
                                 -0.62675208695848172,
                                 0,
                                 0.10465026432579227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30943790142082822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10878733713655353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16970203004239842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039103904135180667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41177237347092899,
                                 -0.53736324980383066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12208967312255818,
                                 0,
                                 0.75300475068400652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30661608631931481,
                                 0,
                                 0,
                                 -0.66663473709143295,
                                 -0.10973429922125207,
                                 0,
                                 0,
                                 -0.47816429482147182,
                                 0,
                                 -0.089705165606465076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51069369327228553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42797823795723822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080399940825584729,
                                 0,
                                 0,
                                 -0.53426847265709365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5512551560289054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15939534199947566,
                                 0,
                                 -0.33525232391225013,
                                 0,
                                 -0.24789382108597743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.172467820982457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48816643748270316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72986028647180734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78733908438059352,
                                 0,
                                 0,
                                 0,
                                 -0.25474778589467495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53185214134788572,
                                 0,
                                 0,
                                 -0.35681002579421806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50684232292948961,
                                 0,
                                 -0.98761903605055834,
                                 0,
                                 0,
                                 0,
                                 0.55115254202390074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25864079248004462,
                                 0,
                                 -0.44448391036991719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49674693189912927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.233016558166729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40411966373898844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17666686536517942,
                                 -0.52078627842600234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35749266765697468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15576998946098164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041686440182611459,
                                 0,
                                 0,
                                 0.34222662237088952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23660706764369624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3912237595369758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6961684422010771,
                                 0,
                                 0,
                                 0,
                                 -0.076389304684108733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47633287494089777,
                                 0,
                                 0,
                                 0.39535675325696529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20636388100005273,
                                 0,
                                 0.63435431141354448,
                                 0,
                                 0,
                                 0,
                                 -0.80662582537807703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18868980821251247,
                                 0,
                                 -0.18666988083960043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062476299078671804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077762775798269734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47206066157019033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46295207318828852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0574263753247042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67155104178955294,
                                 0,
                                 0.027908387539872168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2262472036855469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062416294305315076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24128701712493419,
                                 -0.070000952271968175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54701594793469066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36943895481222599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6638553227275833,
                                 0,
                                 0,
                                 -0.046832684857873869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0086520255942537372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055796191790924793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09466850850119371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26878363819033096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43811911312335955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28073237725972555,
                                 0,
                                 0.45261327380183142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30492446057145489,
                                 0,
                                 0,
                                 -0.32938424071817446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35767434900039907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023802449870682092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32004801164192492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10132295459042054,
                                 0,
                                 0,
                                 0.02253789404424246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50770511739974578,
                                 0.24156602060218624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19259569145525987,
                                 0.46097565527178741,
                                 -0.28168647773930366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39256708975906812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51693207088579152,
                                 -0.32926627068408409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33473251466216636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13356908069597234,
                                 0,
                                 0,
                                 0.32190781976313793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13207210738438313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022827220103645816,
                                 0,
                                 0,
                                 0,
                                 -0.69931392096596623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11135156604929797,
                                 0,
                                 -0.2736179692448889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36717135345717211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65558406502703892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32954893581603995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053440838921082839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45053401318665698,
                                 0.18354684722864484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20909922644600926,
                                 0,
                                 -0.16377051803600229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49727002234733086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13633071222582474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63787718572800844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28708624541482802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40695975747208846,
                                 -0.093118913869182779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081581696664707243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.249217601603686,
                                 0.23531047847257719,
                                 0,
                                 -0.18898742164414195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46088248779218538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24902694199728009,
                                 0,
                                 0,
                                 0,
                                 -0.40511705896499844,
                                 0,
                                 0.174999449377993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040968786911523336,
                                 0,
                                 -0.03870687490158671,
                                 0,
                                 0.19985054723723061,
                                 0,
                                 0.45455219436869565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26229092253251479,
                                 0.22900849878428181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3383319331627101,
                                 0,
                                 0.73125373118857928,
                                 0,
                                 0.35475149240572806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32489738914101413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053333602941918468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34139138182980083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32537739295665435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28391519535566379,
                                 0.35230720475459748,
                                 0,
                                 0.23056155012330221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017554802680527878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17348389292545213,
                                 0,
                                 0,
                                 0,
                                 -0.27284932670734652,
                                 0,
                                 -0.098651357900803288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46074068522464962,
                                 0,
                                 0.18880744261017918,
                                 0,
                                 0.19984227679427172,
                                 0,
                                 -0.034430725395349485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44482533450190864,
                                 -0.18637817284491309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28797365302798206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15880537861558319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60458379814263563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033334199021884309,
                                 0,
                                 -0.1577393318272961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055785393289684473,
                                 0,
                                 0,
                                 0.03348576993969378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38131895392929155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17873143620984006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2224973163720034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51887337988285132,
                                 0,
                                 0,
                                 -0.0045358930825518395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066566626824033623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031241033708933781,
                                 -0.21861540886768036,
                                 0,
                                 0.14011351706254796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13670773755087196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24236682686563954,
                                 0,
                                 0,
                                 0,
                                 -0.35745939970375867,
                                 0,
                                 0.42717771372647639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54509884497559191,
                                 0,
                                 -0.26555935136122899,
                                 0,
                                 -0.062960151996950556,
                                 0,
                                 -0.2713481759498399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30682125087872958,
                                 0.0095952240732143645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29999341633125931,
                                 0,
                                 -0.6771436923293227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098055953874349899,
                                 0,
                                 0,
                                 -0.17934848256230324,
                                 1.0130162404744647,
                                 0,
                                 0,
                                 0.22109370546181525,
                                 0,
                                 0.037245355427749149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28085387468213319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075585127401090413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44486011503871309,
                                 0,
                                 0,
                                 -0.082043079560424392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13643316703805802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3841911980991215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15265754792410974,
                                 -0.019071775360972931,
                                 0,
                                 -0.25889291380245172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10449541351007716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082819474630438039,
                                 0,
                                 0,
                                 0,
                                 0.31538438197147878,
                                 0,
                                 0.4834012382298401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16272337884124854,
                                 0,
                                 0.32170781614031008,
                                 0,
                                 0.35658214621422984,
                                 0,
                                 0.16223981709101298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070680767906833503,
                                 -0.3497683910938657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51368140786231564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66195818178222521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23905107659960939,
                                 0.39083785414423883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051018512435351229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15376983393786836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077486276572671681,
                                 0,
                                 0,
                                 1.5541753071390829e-05,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052211141002524504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23035831729901379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21158839101129145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26590809890198575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19673746644782716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96806812131645714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83054305834727971,
                                 0,
                                 0.90323357548057626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14888823592981981,
                                 -0.079595878627819305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70998242905662634,
                                 -0.35508534761341448,
                                 0.71163316287669021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12649574191778915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45985117706376194,
                                 0.29615550921310174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.049244669817994025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22545024311723022,
                                 0,
                                 0,
                                 0.097920892333223236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24467808058600116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39591470242146487,
                                 0,
                                 0,
                                 0,
                                 -0.72131944194641495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41784592057337522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080215039824655165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2885053600287579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084976351530235347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43012698848369874,
                                 0,
                                 0.15520718103808412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086114591433307797,
                                 0,
                                 -0.062032914920965521,
                                 0,
                                 0.50858281434097208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80303974454257654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038676800487656884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28932851458978182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2101850820692757,
                                 0,
                                 0.11032971395395576,
                                 0,
                                 0,
                                 0,
                                 0.35863265354995061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21201192172916081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17326717387416762,
                                 -0.56233087098107604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0011171999556293943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69612848372304392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0082986822984875488,
                                 0.081511149093550436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18884530396422133,
                                 -0.28137437947611155,
                                 -0.47897643985417543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89859208595359874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46638572030453579,
                                 -0.13445486180809105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50513191541018687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66584076277879867,
                                 0,
                                 0,
                                 -0.11268665098314809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05039026808544364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21183491921846265,
                                 0,
                                 0,
                                 0,
                                 -0.013445206974731679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25142701715607135,
                                 0,
                                 0,
                                 0,
                                 -0.57386991986130964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31989570051502636,
                                 0,
                                 0,
                                 0.74442248971418024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14594958416637016,
                                 0,
                                 0.26950465784278466,
                                 0,
                                 0,
                                 0,
                                 0.069873174735387039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62616392959348288,
                                 0,
                                 -0.36884968398567891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064991896641309929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26075946747667744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12807822406785369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022067455027966233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16726152794857563,
                                 0,
                                 -0.55181310248997639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19486586322911809,
                                 0,
                                 0,
                                 0.12605255082202285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094167723626612965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36642477981128663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45432042878014028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069998463110483425,
                                 0,
                                 0,
                                 0.41753552035707253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034810910649177768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073799843761380407,
                                 0.38700109235427921,
                                 0,
                                 0.27148451387398975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31896976115319881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27117524938108273,
                                 0,
                                 0,
                                 0,
                                 -0.00083991035792983261,
                                 0,
                                 0.33830810286867541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26701782746478536,
                                 0,
                                 0.30957433232770132,
                                 0,
                                 -0.067752981753558109,
                                 0,
                                 -0.45227158359868297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088630312041114295,
                                 0.30985016214408834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27703586311377471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013781172536864134,
                                 0.37886253869410752,
                                 0,
                                 -0.16381231716336464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31739949601494033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65726767846604794,
                                 0,
                                 0,
                                 0,
                                 0.049933207882831905,
                                 0,
                                 0.012172050185190599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10380902738177619,
                                 0,
                                 -0.25520430126061128,
                                 0,
                                 0.28029363333312612,
                                 0,
                                 0.24665867522404186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024914689335656465,
                                 0.037065777036940514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61512902890629007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22122129769063811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091078179555294611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1003214049331284,
                                 0,
                                 0.068688367979228546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0028589060943206429,
                                 0,
                                 0,
                                 0.25729068623947515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092302842756181197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47274369723255744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40941661642107219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11230894182889237,
                                 0,
                                 0,
                                 0.26674210659425268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080309455995447337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052055053506465554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73255745063647149,
                                 0.15895652749214911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1290120849499965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42256892434147431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13292846486895407,
                                 0,
                                 0,
                                 -0.17534784963218464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16346523617914319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39822948673143083};

const double rot_7_30[900] = {-0.13662865303884886,
                              0,
                              0,
                              0,
                              -0.93023334415612724,
                              0.27816129240581033,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.19653201264940937,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.76386992003122245,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.73472485922580821,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.3976727883521345,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.05139497387576622,
                              -0.44370115807434796,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.90294143299368945,
                              0.12187691006020157,
                              0,
                              -0.14292514893030597,
                              0,
                              -0.37232022556789285,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.11110059270323158,
                              0.25161703076144981,
                              0,
                              0,
                              0.37635982418262004,
                              0,
                              0,
                              0.39380283792741272,
                              1.268507469951687,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.47199353512120973,
                              -0.28899455018006143,
                              0,
                              -0.33721920015842777,
                              0,
                              0.24177642783443665,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.38520182635117223,
                              0.14683586102262172,
                              0,
                              0,
                              -0.30590199280080121,
                              -0.79513759955532481,
                              0,
                              0,
                              0,
                              0.29825096614889546,
                              0.29972000958066819,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.43470734387816623,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.58984568982359009,
                              0,
                              0,
                              0,
                              0.17987655826050836,
                              0.42151288863910674,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.66487094288741722,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.83232580415074509,
                              -0.19965094775546444,
                              -0.18643302284771651,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.30229364063409592,
                              0,
                              0,
                              0,
                              -1.4298594677396961,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.56542303864865318,
                              -0.33394803939463102,
                              -0.34767078009867369,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.83459164570055844,
                              0,
                              0,
                              0,
                              -0.42612018882125591,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.29943623485405169,
                              0.04109154202458476,
                              1.1218000486885524,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.67336713575542273,
                              0,
                              0,
                              0,
                              -0.19733442842336774,
                              0,
                              0,
                              0,
                              0,
                              -0.0644212650840367,
                              0.54941846244397796,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.17496756722412526,
                              -0.29896698034877472,
                              0,
                              0.61238155223948731,
                              0,
                              0.038597697499498915,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.80005203453417584,
                              0.037464590225650747,
                              0,
                              0,
                              -0.076146434680325864,
                              0,
                              0,
                              -0.58008633751504668,
                              -0.054616280347035626,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.1585244523071774,
                              0.66943416180716464,
                              0,
                              0.063286867262119004,
                              0,
                              0.055125286564345476,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.082614333553127722,
                              0.78017409401911175,
                              0,
                              0,
                              -0.16882100921933263,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.65055970106325423,
                              0,
                              0,
                              0,
                              0,
                              -0.053904143683616776,
                              0.10334872578003529,
                              -0.46923773435940863,
                              0,
                              0,
                              0.25969967126603843,
                              0,
                              0,
                              0.21720148898350994,
                              0,
                              0,
                              0,
                              -0.47789224947343051,
                              0,
                              0,
                              0,
                              -0.47028735468071003,
                              0.042745404004424697,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.1434932289524723,
                              0.15415483376786471,
                              0,
                              -0.40999550782569505,
                              0,
                              0.6274704886109338,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.24199411129947379,
                              -0.077293710241606695,
                              0,
                              0,
                              0.78500026822504354,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.13851755629217971,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.99035997829013789,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.56459726598004012,
                              0.36675989761334449,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.1204009018404881,
                              -0.26264922314977102,
                              0,
                              -0.68864364838133607,
                              0,
                              -0.37421295785411252,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.32947798970330738,
                              -0.30188706903021184,
                              0,
                              0,
                              -0.95322188237390415,
                              0,
                              0.83381839005947045,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.70584637246051585,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.69671326414757917,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.24675783285904179,
                              0,
                              0,
                              0,
                              0,
                              0.57091156844789304,
                              0.23039398090420549,
                              0.10789182244177993,
                              0,
                              0,
                              0.56127219371823556,
                              0,
                              0,
                              -0.1098714297658033,
                              0,
                              0,
                              0,
                              0.47047881421836313,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.34618828158563825,
                              0,
                              0,
                              0,
                              0,
                              -0.26518011772793776,
                              -0.36187826573369741,
                              0.059499877581868123,
                              0,
                              0,
                              0.74456567049630196,
                              0,
                              0,
                              -0.21679310739424645,
                              0,
                              0,
                              0,
                              -0.27195546531855724,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.55905741647062945,
                              0,
                              0,
                              0,
                              0,
                              -0.32682219210466606,
                              -0.21071950607459244,
                              0.25095177989764117,
                              0,
                              0,
                              -0.12120876731182037,
                              0,
                              0,
                              -0.66279503530181583,
                              0,
                              0,
                              0,
                              0.13882985870836989,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.99035997829013822,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.13851755629218016,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.034217994370198651,
                              0,
                              0,
                              0,
                              0.11557123517429679,
                              0.80939551269772281,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.57476197028540343,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.14821413884507001,
                              0,
                              0,
                              0,
                              0,
                              0.43889420844885096,
                              -0.40138995164066538,
                              -0.64249873438538663,
                              0,
                              0,
                              -0.17858456117718516,
                              0,
                              0,
                              -0.42377310697523668,
                              0,
                              0,
                              0,
                              0.0031359504550227957,
                              0,
                              0,
                              -0.22572626337000867,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.0004151519567648,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.1425515377330822,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.35245063901235663,
                              -1.2417084410782988,
                              0.38661923754197669,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.13338300067465345,
                              0,
                              0,
                              0,
                              0.56722609818189751,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.030861199020119297,
                              0,
                              0,
                              0,
                              0,
                              0.48128076565293226,
                              0.17575255949806545,
                              0.43645273550767055,
                              0,
                              0,
                              -0.11901008138213678,
                              0,
                              0,
                              -0.27379420422609735,
                              0,
                              0,
                              0,
                              -0.67595102837922683,
                              0,
                              0,
                              0,
                              -0.12950097952580944,
                              0.83507235872924546,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.0026541831116322634,
                              0.27710414712930176,
                              0,
                              0.18172243744797587,
                              0,
                              -0.60916271981475922,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.085635632028428402,
                              -0.53983865706511958,
                              0,
                              0,
                              0.21692718532876853,
                              0,
                              0,
                              0.90570587038144468,
                              0.31316000656742893,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.19746675348687429,
                              0.83785269159677755,
                              0,
                              -0.59398414919631326,
                              0,
                              0.11999517626845463,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.33569756023234271,
                              0.054909559098397016,
                              0,
                              0,
                              -0.44811638799836273,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.75885677190270795,
                              0.18362306111215748,
                              -1.3118295226665273,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.43758046358246228,
                              0,
                              0,
                              0,
                              0.79920345033869189,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.24611233512081646,
                              0,
                              0,
                              0,
                              0,
                              0.26412455890807329,
                              -0.75423882792109687,
                              0.31362821623450426,
                              0,
                              0,
                              -0.049032207647024796,
                              0,
                              0,
                              0.44711112646290696,
                              0,
                              0,
                              0,
                              0.010749489620325278,
                              0,
                              0,
                              0,
                              -0.14484566559813625,
                              0.0082988598776225497,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.49591967675032422,
                              0.46750648940772099,
                              0,
                              0.17791728356986625,
                              0,
                              0.57861579360976356,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.20314010079792294,
                              -0.5812589473787253,
                              0,
                              0,
                              -0.34879370524576936};

const double rot_7_2[4] = {0.57349997183448564, 0.81920558000165267, -0.81920558000165244, 0.57349997183448564};

const double rot_6_50[2500] = {-0.82437624469018644,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56098969464395831,
                               0,
                               0,
                               0.092830819571206424,
                               0.26738422323605698,
                               0,
                               0,
                               0,
                               0.0093097814988737926,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14066006043928392,
                               0,
                               0,
                               0.65089712840350755,
                               0,
                               0,
                               0,
                               0.039624954676028293,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.46757422664451875,
                               0,
                               0.50950695732223861,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27749039936813746,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30649762771985917,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.91964299026910579,
                               0,
                               0,
                               0,
                               0.36599653847207808,
                               0,
                               0,
                               0,
                               0,
                               0.30220324729565162,
                               0,
                               0,
                               0,
                               0,
                               -0.30635562706754843,
                               0.52010540034592978,
                               0,
                               0,
                               0,
                               0,
                               -0.38539253358069325,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.9709234794224616,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.62173518719592025,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24344463146549328,
                               -0.090293269750380711,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.55545549384166848,
                               0,
                               0,
                               0,
                               0,
                               -0.60729095073010553,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22537446228009606,
                               0,
                               -0.07462118368480064,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.90042087391741532,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.87381698827169885,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.024207738725013694,
                               0,
                               0,
                               0,
                               0.2870151598322489,
                               0,
                               0,
                               0,
                               0,
                               -0.40622426751754787,
                               0,
                               0,
                               0,
                               0,
                               0.15729845311354074,
                               -2.6979171943122826e-05,
                               0,
                               0,
                               0,
                               0,
                               -0.19445267031384128,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.60417578252406834,
                               0,
                               0.1800740569000906,
                               0.50870574543067193,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.066812050263776401,
                               0,
                               -0.15273460185102714,
                               0.079341293385525022,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3200432241492463,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.45524609562940821,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31525782817021042,
                               0,
                               0,
                               -0.46976354586193769,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.69512175135311138,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26568473823479583,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35517894563376129,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42360781971101019,
                               0,
                               0.7731150072590417,
                               0.021220000522162635,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.072548651849187046,
                               0,
                               0.30655975579946837,
                               -0.14794435782950599,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25122407610718028,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19533574178300661,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29142537332436103,
                               0,
                               -0.39380658722623552,
                               0.43226420734308391,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20386255655013691,
                               0,
                               0.22632303813299151,
                               -0.47047020048071919,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26564194584651779,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43410294424668627,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.66485730595972559,
                               0,
                               0,
                               -0.36471812992600094,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.032384531188056023,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54185583476164723,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.36095559960990892,
                               0,
                               0,
                               0,
                               0.45138599045670841,
                               0,
                               0.24751897376958917,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4783576711945805,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23965571521998974,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33372783518660232,
                               0,
                               0,
                               0,
                               -0.26430434003097697,
                               0,
                               0,
                               0,
                               0,
                               0.42419694481353076,
                               0,
                               0,
                               0,
                               0,
                               0.67412757931180323,
                               -0.45681006448452288,
                               0,
                               0,
                               0,
                               0,
                               -1.1427808402523598,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4613710029871454,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3761723817287021,
                               0,
                               0,
                               0.73372620257035204,
                               0.19816151222321698,
                               0,
                               0,
                               0,
                               0.67782825236661803,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.048831520724395124,
                               0,
                               0,
                               0.20069944922779639,
                               0,
                               0,
                               0,
                               -0.54665390771875599,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.48765325112926461,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.068904802036209412,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1806606944185819,
                               0,
                               0,
                               0,
                               -1.2104054692067443,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.6804166709725713,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12431967069081916,
                               0,
                               0.3325990130214791,
                               0,
                               0,
                               -0.53599221165430866,
                               -0.025191854906919886,
                               0,
                               0,
                               0.35076115715874301,
                               -0.48905683422792429,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46879459068330315,
                               0,
                               0,
                               0.87691974622774604,
                               -0.23271103174518032,
                               0,
                               0,
                               0,
                               -0.32983312114504798,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11863674370135241,
                               0,
                               0,
                               -0.17550410989520926,
                               0,
                               0,
                               0,
                               0.51527946361047061,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.025756494756882617,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29680887226356567,
                               0,
                               0,
                               -0.13460304393572795,
                               -0.12192409041985744,
                               0,
                               0,
                               0,
                               0.13249690315538373,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.91929371544536931,
                               0,
                               0,
                               -1.3160371615032116,
                               0,
                               0,
                               0,
                               -0.62407242154972964,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.86693524756249973,
                               0,
                               -0.057321967181323152,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41496180421334061,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.87696846453390775,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.66416226570766057,
                               0,
                               0,
                               0,
                               -0.01965654940198,
                               0,
                               0,
                               0,
                               0,
                               0.31945933371191348,
                               0,
                               0,
                               0,
                               0,
                               0.043270455750852151,
                               -0.12365093493714573,
                               0,
                               0,
                               0,
                               0,
                               -0.40348147267151591,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36076718481590442,
                               0,
                               0,
                               0.028367490260067338,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5877420458617455,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.65850637588598049,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29995160326311465,
                               0,
                               0,
                               0,
                               0,
                               -0.42973358699504632,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.4225643800670627,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11614913094747993,
                               -0.21519815885312193,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34998841956371435,
                               0,
                               0,
                               0,
                               0,
                               -0.3142089878189398,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.276016825924359,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3907631855053213,
                               0,
                               0,
                               0.12319637429716364,
                               -0.31393371039935086,
                               0,
                               0,
                               0,
                               -0.9037807550347513,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.011178409343059505,
                               0,
                               0,
                               0.4488841606791425,
                               0,
                               0,
                               0,
                               -0.84215840250294061,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19109992356614469,
                               0,
                               0.18346770247267402,
                               0.35107053733980054,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.75716532317646523,
                               0,
                               -0.28526137866778128,
                               -0.16058444582074349,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3109775768650459,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17147040806383901,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.015760790115866757,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.116079701963886,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13551555042836427,
                               0,
                               0,
                               0,
                               0.16427475880320708,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3433356075909304,
                               0,
                               -0.39902088828251514,
                               0.23024613860402721,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27394508781353433,
                               0,
                               0.19391957085392375,
                               0.19812127468624985,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.70421752931951143,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14854167008222341,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29952754007053173,
                               0,
                               0.10598702985503082,
                               0.36556901291501426,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22954070044644032,
                               0,
                               0.27691662275759843,
                               -0.38286609284463002,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.060294310100703546,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.69700480703981116,
                               0,
                               0,
                               -0.30423763393474834,
                               0,
                               0.3590090051187384,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.56059952167820448,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21305593776323603,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36587292216708084,
                               0,
                               0,
                               0,
                               -0.34499423679664465,
                               0,
                               0,
                               0,
                               0,
                               0.54966458553780184,
                               0,
                               0,
                               0,
                               0,
                               0.035952094757162989,
                               -0.54725881800672571,
                               0,
                               0,
                               0,
                               0,
                               -0.22047422163638761,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16079069627733417,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42239728755243483,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.6315504374369896,
                               -0.081836037583794694,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.61025130756286572,
                               0,
                               0,
                               0,
                               0,
                               -0.085132439794137676,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.012319449426879235,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0018226657310042582,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1822929993115712,
                               -1.2003039180185775,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4350758544216391,
                               0,
                               0,
                               0,
                               0,
                               0.1254129082342571,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.50694260805899971,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35379932317272444,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.3913608737656613,
                               0,
                               0,
                               0,
                               0.64172064469693002,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30425721928835392,
                               0,
                               -0.59195798419197598,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13100224611550843,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29818914754298775,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.71469162614528248,
                               0,
                               0,
                               0,
                               -0.27723116317937657,
                               0,
                               0,
                               0,
                               0,
                               -0.47861382333754066,
                               0,
                               0,
                               0,
                               0,
                               -0.34355954978837688,
                               -0.6207900642177655,
                               0,
                               0,
                               0,
                               0,
                               -0.34730177185661321,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.55553783644739507,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17716024728876603,
                               0,
                               0,
                               -0.33063677472416697,
                               -1.1327865630095404,
                               0,
                               0,
                               0,
                               0.5250295944075305,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3294287820225093,
                               0,
                               0,
                               -0.11621579898905243,
                               0,
                               0,
                               0,
                               -0.44827623162065217,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.56294053128731147,
                               0,
                               0,
                               -0.0037051472543998543,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10188408383764047,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14998162179858632,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.80635561429248637,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.4130185690244055,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37970034048646434,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16520593493598065,
                               0,
                               0,
                               0,
                               1.2355802230190351,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22977651958778622,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.620585696982899,
                               0,
                               0,
                               -0.51725972864562797,
                               0.33457426933691436,
                               0,
                               0,
                               0,
                               0.27205676560865449,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.016369456916745,
                               0,
                               0,
                               0.25294942650016089,
                               0,
                               0,
                               0,
                               0.21668734855245345,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27158964448938522,
                               0,
                               0.91945818806916679,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25548327852307928,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58301404645669075,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16670769946207575,
                               0,
                               0,
                               0,
                               0.2703155158270617,
                               0,
                               0,
                               0,
                               0,
                               -0.76099900135323351,
                               0,
                               0,
                               0,
                               0,
                               -0.49514304440033269,
                               -0.04262012163585574,
                               0,
                               0,
                               0,
                               0,
                               -0.88166590554773294,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25428046993892045,
                               0,
                               0.10218881252726231,
                               0.49213084022774667,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35438854573993606,
                               0,
                               -0.078301660311488774,
                               0.66988307989744866,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28612280810983781,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14273798333271295,
                               0,
                               0,
                               0,
                               0.037413477072167384,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.53030436797131797,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.035146353083176818,
                               -0.49658635312388216,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1868993935973324,
                               0,
                               0,
                               0,
                               0,
                               0.66129433551062489,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.26050940487561425,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.64553650680578067,
                               0,
                               0,
                               0.21019040731380095,
                               -0.55679427004770832,
                               0,
                               0,
                               0,
                               -0.24476063295205588,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22808058933126563,
                               0,
                               0,
                               0.060683186609951055,
                               0,
                               0,
                               0,
                               0.63374408420689377,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16496462457466232,
                               0,
                               0,
                               0,
                               0,
                               0.80153993396786483,
                               0,
                               0,
                               -0.57473507539885749,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16679173630912877,
                               0,
                               0.042497911663049309,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.078853821177798974,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23232372559599249,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28480647082171551,
                               0,
                               0,
                               0,
                               -0.95027671680602244,
                               0,
                               0,
                               0,
                               0,
                               -0.043860976779327709,
                               0,
                               0,
                               0,
                               0,
                               0.20600823265701049,
                               0.80024838726389691,
                               0,
                               0,
                               0,
                               0,
                               -0.29309650844133694,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40223723477478113,
                               0,
                               0.63695747548995096,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34023318243315975,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33512271806793359,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16772752846887606,
                               0,
                               0,
                               0,
                               -0.68153739923668955,
                               0,
                               0,
                               0,
                               0,
                               -0.81464122685548523,
                               0,
                               0,
                               0,
                               0,
                               0.27850051983395896,
                               -0.39397622744587557,
                               0,
                               0,
                               0,
                               0,
                               0.80103362499783848,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5826805279027194,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.91596669154099841,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.73272477562515481,
                               -0.72346983054027092,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57249641322440048,
                               0,
                               0,
                               0,
                               0,
                               -0.8032550104120344,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.022638477069367002,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50526550245155988,
                               0,
                               -0.2106967213267959,
                               0,
                               0,
                               0.12840108575268888,
                               -0.5924814749339824,
                               0,
                               0,
                               0.57643735656884132,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.47753751449732362,
                               0,
                               0,
                               0,
                               0,
                               -0.57477246312597963,
                               0,
                               0,
                               -0.66452579925824817,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19722101538258074,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.69208394091059522,
                               0,
                               0.63569709353358828,
                               0,
                               0,
                               -0.13198715614296369,
                               0.18412135840169769,
                               0,
                               0,
                               -0.16337567472448045,
                               0,
                               0.14420886104641956,
                               0,
                               0.47420632346089731,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10931327245602786,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57768985841545095,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.85599662532801823,
                               0,
                               0,
                               0,
                               -0.066242154000795916,
                               0,
                               0,
                               0,
                               0,
                               0.72252025505459283,
                               0,
                               0,
                               0,
                               0,
                               -1.2482285373894491,
                               -0.30150195696552501,
                               0,
                               0,
                               0,
                               0,
                               0.28279649623735598,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.86298586018929602,
                               0,
                               0,
                               0,
                               0,
                               -0.16483431040558813,
                               0,
                               0,
                               -0.47758251143279418,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.4225276182518965,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.099308608563535905,
                               0,
                               0.42559653829879629,
                               0,
                               0,
                               0.76487711182572893,
                               -0.18662932723276882,
                               0,
                               0,
                               -0.10299658581433542,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.075731391514084978,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1301484283797158,
                               0,
                               0.13234789650611081,
                               0,
                               0,
                               -0.30609594652991823,
                               -0.7532538938832366,
                               0,
                               0,
                               -0.54655651133961713,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10734179560331644,
                               0,
                               0,
                               -0.80342047152326668,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39991988437976839,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42388529137497161,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.058125989777507936,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24864727184103183,
                               0,
                               0.015133419971436027,
                               0.042644548967850804,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.34941020136805173,
                               0,
                               -0.79352272799536716,
                               -0.30017665982566527,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29285168225948444,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.092157542706675602,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.55978539858035559,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.47272655637358041,
                               0,
                               -0.49216421478071087,
                               0,
                               0,
                               -0.0085543065078525216,
                               0.1104919148766115,
                               0,
                               0,
                               -0.45679607782003101};

const double rot_6_20[400] = {1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.18639055797155502,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.39483584242748887,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.14247098185534771,
                              0.88829344068432747,
                              0,
                              0,
                              0,
                              0.93446634198494027,
                              0.059090937910162011,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.83485310749305586,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.87930288903697573,
                              -0.72333593348480751,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.41480812806433565,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.72415442600636326,
                              0,
                              0.13827660882989695,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.67563299708192048,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.52085422573622187,
                              0,
                              0.75177937319823418,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.40439912161921326,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.5122829270140197,
                              0.73103092885166798,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.37597496116619689,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.86667440508149785,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.44400197092838967,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.22650359828996922,
                              0.020828954607294226,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.45200801190699669,
                              0,
                              -0.64475371537058546,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.61642631651131707,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              -0.29859707849281419,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.77103101708559985,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.32678400240232924,
                              -0.45778070206313504,
                              0,
                              0,
                              0.35351636481390769,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.22908094211048255,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.90642724752998438,
                              0.030622650207820776};

const double rot_6_10[100] = {0.8643003368724288,
                              0,
                              0,
                              0,
                              0,
                              -0.0686350386112137,
                              0,
                              0,
                              -0.095042156804866232,
                              -0.48912283486556069,
                              0,
                              -0.58802446090253635,
                              0.49700858976919698,
                              0.63812984186285526,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.76483498892848811,
                              -0.59835101910184507,
                              -0.2387540526369028,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.26316282619519232,
                              -0.62845725362622562,
                              0.73197459469133341,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.3871273194606311,
                              0,
                              0.79864115628598298,
                              0.75735255638610222,
                              0,
                              0,
                              0.25230102263101428,
                              0,
                              0,
                              0,
                              0,
                              -0.059230908370752691,
                              0,
                              0,
                              -0.75603100001038359,
                              0.60104327672491276,
                              0,
                              0,
                              0,
                              0,
                              0.53395026498023901,
                              0,
                              -1.2723247965178694,
                              0.92241538049860317,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.64987902260366304,
                              0,
                              -0.43853736051948994,
                              1.3067762725347232,
                              0,
                              0,
                              -0.42668045112090947,
                              0,
                              0,
                              0,
                              0,
                              -0.35966776277219248,
                              0,
                              0,
                              -0.58337064609132672,
                              -0.59013691829328141,
                              0.085281383037611819,
                              0,
                              0,
                              0,
                              0,
                              -0.92866572640044065,
                              0,
                              0,
                              0.28118108885941523,
                              0.22637192755323549};

const double rot_6_100[10000] = {0.24368259861782915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4082987304675284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30782183143387892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062396664498868153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43244224245973756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092054218802794588,
                                 0.43723104936029533,
                                 0,
                                 0.23955416800042431,
                                 0,
                                 0,
                                 -0.10868662230020389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46841548877088596,
                                 0,
                                 0,
                                 0,
                                 -0.77058840104670567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25785953186316501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33633179364728927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49266499123968904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32482101171351713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44920830874660284,
                                 -0.72362436040570144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79864305968189331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19136411021429078,
                                 0,
                                 0,
                                 0,
                                 -0.29301823883256412,
                                 0,
                                 0,
                                 0,
                                 -0.19903008628281973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22898999768639283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30331332293133223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063547249906242026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8416176062763856,
                                 0,
                                 0,
                                 0,
                                 0.017746192873908606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063242028802879879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31508523309182945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5901371153619358,
                                 -0.21718131255559514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15508005963566798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19957927246464049,
                                 0.26692475523664067,
                                 0,
                                 0,
                                 -0.57062437723117543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29306258484974418,
                                 0,
                                 0.16210857862413919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54736718687429142,
                                 0,
                                 0,
                                 0,
                                 -0.42014725214326087,
                                 0,
                                 -0.026957716581229987,
                                 0,
                                 0,
                                 -0.050642763355042232,
                                 0,
                                 0,
                                 -0.43322760093078216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01717081182416158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075367795046319269,
                                 0.16151345036617368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50076744674665208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29134975920416301,
                                 0.20039528719392388,
                                 0,
                                 0,
                                 0.30030529359799113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1450443126291452,
                                 0,
                                 0.23448724019105985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11906356550202002,
                                 0,
                                 0,
                                 0,
                                 -0.23109118148534161,
                                 0,
                                 -0.2707044623370074,
                                 0,
                                 0,
                                 -0.52707901898520737,
                                 0,
                                 0,
                                 -0.0076797406702233464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22696247815441539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21765395124372305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38942670299163895,
                                 0,
                                 0,
                                 0,
                                 -0.065267200694480554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26520691687728953,
                                 0,
                                 -0.035253137608820082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26142742880142544,
                                 0,
                                 0,
                                 0,
                                 0.45671076565247637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20114973604610414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011870552865975832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5520264696938515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10824027148589736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13270110473641972,
                                 0,
                                 0.090397444494587267,
                                 0,
                                 0,
                                 0,
                                 0.25568474619141079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45586192308339551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36977780010890382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16570172429830884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13050020766943363,
                                 -0.35537214985104271,
                                 -0.55906927612901214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017337598971375795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12975599568361945,
                                 0,
                                 -0.26857494060828074,
                                 -0.2677262619249503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077952038888715242,
                                 0,
                                 0,
                                 0,
                                 0.071382900074656377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34146245346795762,
                                 0,
                                 0.05035920029687313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27252015080440117,
                                 0,
                                 0,
                                 0,
                                 -0.83073151645798193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2170026325854221,
                                 0,
                                 0,
                                 0,
                                 0.21844618682922479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84968204946814763,
                                 0.16960605391946026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038078933586058156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17201867088256834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050224963561137481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58947691680264958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97012641335882255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28828983723620932,
                                 0.092683884278275161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062224584077825246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25338228997899304,
                                 0,
                                 0,
                                 0,
                                 0.33733097909839188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23273178615153539,
                                 0,
                                 -0.074071320228100965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44550996542617172,
                                 0,
                                 0,
                                 0,
                                 -0.83071850615784626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43190855143472884,
                                 0,
                                 0,
                                 0,
                                 0.39226131716778118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.98544718436934264,
                                 0.1806106996371393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020915850563087923,
                                 0,
                                 0,
                                 0.7843956903317062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15078843785500848,
                                 0,
                                 0,
                                 0,
                                 0.53912229252057275,
                                 0,
                                 0,
                                 0,
                                 -0.8782045237022027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36283485071005905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2878642508744409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64503181590829628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30465923849644433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1227523419643119,
                                 0,
                                 0,
                                 0,
                                 0.33416936570449363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43137020745529397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51050814131119482,
                                 0.51415207066367241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054146813925513487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34091730434118539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39437180991889847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44759744812833102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64081298220379868,
                                 0.0088420471945531431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5324001070690757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080134704101390397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31030607894027945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45068751103687349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15771035179360557,
                                 0,
                                 0,
                                 0.12718537839581401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09267050788682013,
                                 0,
                                 0,
                                 0,
                                 -0.91329137052178389,
                                 0,
                                 0,
                                 0,
                                 -0.029471795359068163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19985092994260592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18843318315393312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26931984038703377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76064974078518988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44625328431065991,
                                 0,
                                 0,
                                 0,
                                 0.40284303533392846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070284748205011474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44934158609405866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37580904246241076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084742161061514915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0087660480431542565,
                                 0.0072113455133387266,
                                 0.44225201018955851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16821181428918733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34999538486773552,
                                 0,
                                 0.27296941875226455,
                                 -0.13462309625307847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45160373761166495,
                                 0,
                                 0,
                                 0,
                                 0.081173762945903047,
                                 -0.031677609584452114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12436762938602254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17392481771512397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80770536733924381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029670457589601205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027065783504904638,
                                 -0.12721764474440711,
                                 0,
                                 -0.094071666879117583,
                                 0,
                                 0,
                                 -0.47561282790664849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21917380491896321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01476308190329396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62134934538339925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19162077047294809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29202614831848617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022196110010511583,
                                 0,
                                 0,
                                 0,
                                 0.41452200035605713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058000358446961345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56216016736086893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096249398107030565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87002821710712519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013154282530651651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21029834524521984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10981482809166457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27405091447469926,
                                 -0.24245819357613851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49703763970976744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045410074465680128,
                                 0,
                                 0,
                                 0,
                                 -0.73243221396287084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12373571094215136,
                                 0,
                                 0,
                                 0.35595989347370521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37223206589730495,
                                 0,
                                 0,
                                 0,
                                 -0.072989893909871206,
                                 0,
                                 0,
                                 0,
                                 0.26522080125901248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81196164982372454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0025423058052505415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084144229316900854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68414236032412157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5760062077341126,
                                 0,
                                 0,
                                 0,
                                 0.68180945196004195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83164116697500856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4663568830516911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063044563725572073,
                                 0,
                                 0,
                                 0,
                                 0.46450695064402708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032051844949034181,
                                 0,
                                 0.041825625222688255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026510881935022317,
                                 0,
                                 0,
                                 0,
                                 -0.51260155752298386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096139844851562822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27818857762120208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18206181553559941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29720019704524736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16872869959774098,
                                 0,
                                 -0.22155425329065695,
                                 0,
                                 0,
                                 0,
                                 -0.10425050880699138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033574141534617158,
                                 0.13137717925912423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18382298839902314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34577761435073462,
                                 0.67957605085006034,
                                 0,
                                 0,
                                 -0.077277409382961959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22824428115309345,
                                 0,
                                 0.7076180673735587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60783445781340062,
                                 0,
                                 0,
                                 0,
                                 -0.33062862227854062,
                                 0,
                                 0.13715739185660261,
                                 0,
                                 0,
                                 0.24689310293758748,
                                 0,
                                 0,
                                 0.27484682966958812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28115350053583027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13742277981804668,
                                 0,
                                 -0.37414137874352021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072929599552745833,
                                 0,
                                 0,
                                 0,
                                 -0.42791100183998138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64488268757829359,
                                 0,
                                 0,
                                 0,
                                 -0.68014579198630432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19497673855869399,
                                 0.14281759573173441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5690359196060093,
                                 0,
                                 0,
                                 -0.095193599301621912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028422643850474862,
                                 0,
                                 0,
                                 0,
                                 -0.4902590631540158,
                                 0,
                                 0,
                                 0,
                                 -0.15975954978908749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24287487604787622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0878282042441827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29092971036078924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17924248786657573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27652514444370963,
                                 0,
                                 0,
                                 0,
                                 -0.83149729484181234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15897638649451445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.168669039331829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076992950178786032,
                                 0,
                                 0,
                                 0,
                                 -0.11504876109401255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20815254954819962,
                                 0,
                                 -0.18466346197554806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18586700169763323,
                                 0,
                                 0,
                                 0,
                                 -0.1186514540611836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30497826566626035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10511455178107623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35403699291684848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21415400064939361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65860480334205662,
                                 0,
                                 0.015530800442887608,
                                 0,
                                 0,
                                 0,
                                 -0.34215114028884508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55187760705538413,
                                 -0.60693913529363486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54310055478621522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029795248935908975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021770302700137537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17531707655540801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094835718659820933,
                                 0,
                                 0.47359373684586026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0517616297393158,
                                 0,
                                 0,
                                 0,
                                 0.23949202953479534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61601607987328266,
                                 0,
                                 0,
                                 0,
                                 -0.34445294174634133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22139529457418822,
                                 1.0451726173393543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12258038885247018,
                                 0,
                                 0,
                                 0.57158390860477826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28854578282625898,
                                 0,
                                 0,
                                 0,
                                 0.14922898695858589,
                                 0,
                                 0,
                                 0,
                                 -0.33878160264660562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7409908103224544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25738635490975026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21607479143376712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05381208672001344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64470684506370834,
                                 0,
                                 0,
                                 0,
                                 -0.26596990368136425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59398611332160778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23098906358279592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27923093780739466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32748270512556588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49907979532285468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17123889076982729,
                                 0,
                                 0,
                                 0,
                                 0.63077685418314866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064051391485385051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28468191615204541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22922024447383277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42504635028250082,
                                 0,
                                 0,
                                 0,
                                 -0.43726225421418946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0060985347106563507,
                                 0,
                                 -0.15340021792417666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31095405787366753,
                                 0,
                                 0,
                                 0,
                                 0.16462031784587142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054788341335768709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084189712330038011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032304731827334426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2738456683265057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29679709625845485,
                                 0,
                                 -0.43030076795190236,
                                 0,
                                 0,
                                 0,
                                 0.26241631717219505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30299652513849862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16984072254796378,
                                 0,
                                 0,
                                 -0.20718016160866945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68585613596399841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47407078526443641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93961764861451347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14897417486059406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37286729992857892,
                                 0,
                                 0,
                                 0,
                                 0.3180549800939142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32497471835269248,
                                 0,
                                 -0.3156181640854967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26848661571262034,
                                 0,
                                 0,
                                 0,
                                 -0.14646196418853086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12650902475374473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068138427424167744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12238157589534721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026611794484987621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16917603250148056,
                                 0,
                                 0.27120720581925667,
                                 0,
                                 0,
                                 0,
                                 0.54804328646977718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61279960729467087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87300239566097837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82444978741012132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19443907316340966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0029143543636645231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0080779545802724326,
                                 -0.44009289974477789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075531209384320105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34865111702084761,
                                 0,
                                 0,
                                 0,
                                 -0.32737280817330938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45199194549989147,
                                 0,
                                 0,
                                 -0.2262703723107285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49439982023098034,
                                 0,
                                 0,
                                 0,
                                 -0.87231317082344839,
                                 0,
                                 0,
                                 0,
                                 -0.71819701231246691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34581185667245451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13254521093478755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61518415208390931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59947063448815896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26151962470967122,
                                 0,
                                 0,
                                 0,
                                 -0.06983034977777916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28460286857383621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1707944521428848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10413855384344615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13660699525522965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24449911905575689,
                                 0.099703941455405481,
                                 0.017480008472992904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67224173793366304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14520110816587711,
                                 0,
                                 -0.02282907298697974,
                                 -0.41681091740343224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38693561513409014,
                                 0,
                                 0,
                                 0,
                                 -0.27264025010811038,
                                 0,
                                 0,
                                 0,
                                 0.42149604354824116,
                                 -0.12703550093508781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09891202642399774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20698364101573141,
                                 0.014042876374632446,
                                 0,
                                 0,
                                 0.064617917325182114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39913846226417854,
                                 0,
                                 0.15711151638573798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35461600026997464,
                                 0,
                                 0,
                                 0,
                                 -0.24813166200889297,
                                 0,
                                 0.80607626631109952,
                                 0,
                                 0,
                                 -0.50168768358068427,
                                 0,
                                 0,
                                 -0.50804279211419545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1771638259014752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046358420432773738,
                                 -0.69846966472830019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23916834212216992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2888753132595826,
                                 -0.17726947299813225,
                                 0,
                                 0,
                                 0.77787439682689052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15147893154635286,
                                 0,
                                 -0.36307095873506656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044840203358959226,
                                 0,
                                 0,
                                 0,
                                 -0.58042215028213184,
                                 0,
                                 -0.016727714799387054,
                                 0,
                                 0,
                                 0.058555313510612092,
                                 0,
                                 0,
                                 0.23954933076564286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76922606906635804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76491082266305388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.5237526336131915,
                                 0,
                                 0,
                                 0.049052571993757066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054537201597203974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34870469837663032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062998018875288386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72069349432361218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0068765160692804694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069846395718018983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36592872208810945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22516926876656748,
                                 0,
                                 0,
                                 0,
                                 0.4903093857539772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16729172584969798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15059959239470511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79640953485252208,
                                 0.3020972500615311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0093037177231446826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23928384734296457,
                                 -0.09397341741583376,
                                 0,
                                 0,
                                 0.23103630724642016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41283034342102748,
                                 0,
                                 0.13776008125684464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0076294956595779201,
                                 0,
                                 0,
                                 0,
                                 0.5043661625375192,
                                 0,
                                 0.63948320468538866,
                                 0,
                                 0,
                                 0.14568196144164861,
                                 0,
                                 0,
                                 -0.085677465781504078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33684370767870825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18193173983714034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083979214982720457,
                                 0,
                                 0,
                                 0.77108161790334651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19624650747717531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73965961936215963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56926382212907523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23016504256731363,
                                 0,
                                 0,
                                 -0.68939871469455705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059266881634160308,
                                 0,
                                 0,
                                 0,
                                 0.30480850204277943,
                                 0,
                                 0,
                                 0,
                                 -0.53783283164286055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44170252006247168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17067229999125988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51574707784501472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74718823222897401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49936751292355502,
                                 0,
                                 0,
                                 0,
                                 0.072463128093338589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37653078890379965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44247978009035621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25109374613306029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28575424521346643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16302689229534814,
                                 0.54490728953382106,
                                 -0.1523747752372562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24942649748717802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37557481530455156,
                                 0,
                                 0.12952619238467578,
                                 -0.24583280351953921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043913640564847117,
                                 0,
                                 0,
                                 0,
                                 -0.17429590675632115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03857921092167782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44921314071243601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57250932228991203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36622152622751197,
                                 -0.0034210626045192566,
                                 0.043023858919671351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035609385780889041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1444545714112922,
                                 0,
                                 -0.32412248985319897,
                                 -0.39691892648427185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21883776354482778,
                                 0,
                                 0,
                                 0,
                                 0.018605678387351235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038734175898989476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26733372997159105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28353926612309105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54486135376266964,
                                 -0.096581723025170235,
                                 0.15413545731284251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2913906166197206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34178237893244778,
                                 0,
                                 -0.14219554978057736,
                                 -0.47078650722464688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26932209346632158,
                                 0,
                                 0,
                                 0,
                                 -0.023676485410891276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064322642735497496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065214353644309345,
                                 0,
                                 0,
                                 0,
                                 0.207055587701405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35561040816517209,
                                 0,
                                 0.45095789703172612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016405189236006971,
                                 0,
                                 0,
                                 0,
                                 0.19718730009283797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25446134783266572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39557412999881902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057546325039540797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40462335897860341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090842553805492457,
                                 0,
                                 -0.10494036725270948,
                                 0,
                                 0,
                                 0,
                                 0.41501561197934256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18040191985772802,
                                 0,
                                 -0.0010288023100745423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0026085811923398,
                                 0,
                                 0,
                                 0,
                                 0.10136924133820041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47694848680688667,
                                 0,
                                 0,
                                 0,
                                 0.044488942703936024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35278090489259784,
                                 0.92760851826364932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0049862471199875365,
                                 0.2664324688657812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15438071258633979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13578521753213429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86346995292541073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37568269530258697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66770547679624048,
                                 0,
                                 0,
                                 0.056479006769568602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095475501323418532,
                                 0,
                                 0,
                                 0,
                                 -0.31071200191212889,
                                 0,
                                 0,
                                 0,
                                 0.43538190167985108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56501501243257946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92949675406151089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05081184603664167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070909454195251062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24400735382621813,
                                 0,
                                 0,
                                 0,
                                 0.63835232639572514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65343396672038301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20004328024552967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41660084418246113,
                                 0,
                                 0,
                                 0,
                                 0.14592417818823714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25849059586983675,
                                 0,
                                 -0.51868107824250198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091006795043088354,
                                 0,
                                 0,
                                 0,
                                 0.28932549852131523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24768572707031422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14232633844192374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48081694975170658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086560197350822904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11333447490075406,
                                 0,
                                 -0.062903438623912331,
                                 0,
                                 0,
                                 0,
                                 -0.014473017040720015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59787934080116767,
                                 0,
                                 0.72520411086421011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29353201753130165,
                                 0,
                                 0,
                                 0,
                                 -0.09582522703158608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52092019330339656,
                                 0,
                                 0,
                                 0,
                                 0.26745052888893939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071943621169041072,
                                 0.4931387117330876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024311069857670998,
                                 0.16777733310626941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92341863016459891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46394644815065605,
                                 -0.26511993738809475,
                                 0,
                                 0,
                                 0.1480221795527682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22483158509022924,
                                 0,
                                 -0.80481584227519154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3936717888562406,
                                 0,
                                 0,
                                 0,
                                 -0.42820440150991368,
                                 0,
                                 -0.014744971726538027,
                                 0,
                                 0,
                                 -0.37288757961943025,
                                 0,
                                 0,
                                 -0.071004830093942289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.341459995048011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087269660606836122,
                                 0.13321869957027518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11076584592949733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.9025296922175885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044992909100837586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38181606120508382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015579806618587138,
                                 -0.83006090267981592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039765815563799538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27604682805446384,
                                 -0.015072192778987654,
                                 0,
                                 0,
                                 -0.53744354484626389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39407087865364765,
                                 0,
                                 0.21115969808338197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019254152383997292,
                                 0,
                                 0,
                                 0,
                                 0.64094483779795841,
                                 0,
                                 0.091325127933327782,
                                 0,
                                 0,
                                 -0.47366709446566319,
                                 0,
                                 0,
                                 0.32640106840284933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15207041384105854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0403528471532157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69244334913274108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36003218674218196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079529620264227996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09176547339128846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0061851522748654145,
                                 -0.24835380750847968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89116304390910439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38818803063740764,
                                 0,
                                 0,
                                 0,
                                 -0.16854588976279392,
                                 0,
                                 0.001299311497093919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21766425278792612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.264666983025233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010189238297756299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34107744749464913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29602685358193542,
                                 -0.16438730777610727,
                                 0,
                                 0.36713360661312416,
                                 0,
                                 0,
                                 0.29940759866197492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65348852089144382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21949602804001012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28769580510718062,
                                 0,
                                 0,
                                 0,
                                 0.052952873016711866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07498300662728101,
                                 0,
                                 -0.20900915001794743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03459967801618305,
                                 0,
                                 0,
                                 0,
                                 0.25165412673066229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071155711931759805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72622629856789644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15471285077980818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12939562386710682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12365172271857618,
                                 0,
                                 0.25096025595918375,
                                 0,
                                 0,
                                 0,
                                 -0.31779951698719106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041707368501708433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0069676485853202436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59084170912859568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39999777937334857,
                                 0.021935144791296907,
                                 -0.13904334700493801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18651935887442744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35457343986531031,
                                 0,
                                 -0.33588739422046476,
                                 -0.012719152175777237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13703037967878556,
                                 0,
                                 0,
                                 0,
                                 0.42075450887303029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53986899627780138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21210180436389817,
                                 0,
                                 0,
                                 0.99536247942811873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85639864485063111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041361841153017956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26571065132105759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92316303652935749,
                                 0,
                                 0.031748868464261476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12684013289474469,
                                 0,
                                 0,
                                 0,
                                 -0.90760371077188706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37239209073670232,
                                 0,
                                 0,
                                 0,
                                 -0.70908033675297932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60161851878836814,
                                 -0.22359358646836183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56614873590583392,
                                 0,
                                 -1.1675726276178942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34519455644487962,
                                 0,
                                 0,
                                 0,
                                 -0.39004095238766978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0042642130806372185,
                                 0,
                                 0,
                                 0,
                                 0.6053315324170857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06869758024923367,
                                 0.43456948915955407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12857064206930033,
                                 -0.5276939170594741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61851237569050688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20849123076413917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01011658835667012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52809111178704615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5467441385324362,
                                 0.26811117015632763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59087056309211439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24498830278254435,
                                 0.35800400505944391,
                                 0,
                                 0,
                                 -0.17850209420355645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12008929006345877,
                                 0,
                                 -0.60406929577017088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50509695314313507,
                                 0,
                                 0,
                                 0,
                                 0.024533048001969267,
                                 0,
                                 0.20558178818992967,
                                 0,
                                 0,
                                 -0.43919081986898367,
                                 0,
                                 0,
                                 0.24570144107853004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12765792775788715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3318588129378353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53779939688277067,
                                 0,
                                 0,
                                 0.37873806558985501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11860317181091645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18694173465080788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6899822042114151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75566126062187278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35419994374306263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41947147209510083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041142082440783802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31269633477089187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88755005909643747,
                                 0.0047737775310133495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36510109092487797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38523525472369818,
                                 0,
                                 0,
                                 0,
                                 0.067581442853581156,
                                 0,
                                 0,
                                 -0.31067395245210822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013371175566842114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79174514445258204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43894890102299078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3234279836812613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11915090630800095,
                                 -0.60275636113407738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34988636804566714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57381833366784163,
                                 0,
                                 0,
                                 0,
                                 -0.19904044250363687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36119994109283604,
                                 0.44973162764024649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30433795708827843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077726469131065595,
                                 -0.56500106902232994,
                                 0,
                                 0,
                                 -0.68420977376094061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34949269572536129,
                                 0,
                                 0.093155424596698705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38328054940087347,
                                 0,
                                 0,
                                 0,
                                 -0.16911054611038684,
                                 0,
                                 0.56880429964146839,
                                 0,
                                 0,
                                 0.469152074707748,
                                 0,
                                 0,
                                 0.65691793206247118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0038866292249830903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014184016867518502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087086470472453187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10837294595381931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083863950893642736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48576474443003692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69133381876679145,
                                 0.48231370823586167,
                                 0,
                                 0.040389225160437817,
                                 0,
                                 0,
                                 0.076048267320996885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13959199520847812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50672801931794553,
                                 -0.34793231739855301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25482938273387901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25035414604832401,
                                 -0.32412657236128201,
                                 0,
                                 0,
                                 0.32209475714947577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072987368222647717,
                                 0,
                                 0.20492929573844129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18615165581008672,
                                 0,
                                 0,
                                 0,
                                 -0.23963466897507474,
                                 0,
                                 0.046943466296602711,
                                 0,
                                 0,
                                 -0.26474799174244668,
                                 0,
                                 0,
                                 0.49783582717367336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77918200579433927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51249882798167823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20495077685589225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50536022607969644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5119245971941524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028472305357657671,
                                 0,
                                 0,
                                 0,
                                 0.40610193280068252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10128911133844506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043536685625952934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20841480206714735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038116266380264503,
                                 0,
                                 0,
                                 0,
                                 -0.13807644707888897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13444555001944097,
                                 0,
                                 -0.26387132171239103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11789021617391279,
                                 0,
                                 0,
                                 0,
                                 -0.20275136529180404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62522754983515605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12714329502650684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091959636566535816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53801446615467363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14227916351847317,
                                 0,
                                 0.24277740223974187,
                                 0,
                                 0,
                                 0,
                                 0.095708626764273247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035573458451701317,
                                 -0.18446292018363128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05512796178158829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6756229690256258,
                                 -0.36438350583522661,
                                 0,
                                 0,
                                 -0.0872911338287118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33096610547109467,
                                 0,
                                 -0.048766437809399266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.93298549877462678,
                                 0,
                                 0,
                                 0,
                                 -0.15538099340192857,
                                 0,
                                 0.33607504498130075,
                                 0,
                                 0,
                                 -0.087292169637477476,
                                 0,
                                 0,
                                 -0.43459414287801335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090406481418939158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.091574615655361,
                                 0,
                                 0,
                                 -0.57517661740528514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022175326829716957,
                                 0,
                                 0,
                                 0,
                                 0.66106801672070736,
                                 0,
                                 0,
                                 0,
                                 -0.38716766869401276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20087558762156349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33034261076013877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20934787987767528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32251318557384889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47673275352729721,
                                 0,
                                 0,
                                 0,
                                 -0.19053660104729786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.542969833259349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31207136478519804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65222026489577445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19448102385907307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13747584572109511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22036235792132203,
                                 0,
                                 0,
                                 0,
                                 -0.028251630549312116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29633268723806216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53228463024899964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0019693029701548861,
                                 0.1110327820294878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46809506331096479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69355600895565106,
                                 0.30685245089572111,
                                 0,
                                 0,
                                 0.42090372493014855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47755105846884499,
                                 0,
                                 -0.090953593499410484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054307702568490296,
                                 0,
                                 0,
                                 0,
                                 0.1146205084012878,
                                 0,
                                 0.57787981568457103,
                                 0,
                                 0,
                                 -0.36687615017494574,
                                 0,
                                 0,
                                 0.62507037554442946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40374085078716332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062595571505491374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32142872333197209,
                                 0,
                                 0,
                                 0,
                                 0.24622351077820925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48323057792922625,
                                 0,
                                 -0.18945686743927917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40753707584176913,
                                 0,
                                 0,
                                 0,
                                 0.17349081406417943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33948208575753458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23748990084051699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15822183194228964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043229882250909055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26364518131586617,
                                 0,
                                 -0.31166531847357692,
                                 0,
                                 0,
                                 0,
                                 -0.036763615500434874,
                                 0,
                                 0,
                                 0,
                                 -0.45162484232481737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30990332657252201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53113897660271847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26465950528214743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035036838461983466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1515376280967074,
                                 0.062724568136958092,
                                 0,
                                 0.52696481167039622,
                                 0,
                                 0,
                                 -0.021493532115921532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20386803301009099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027966392656448597,
                                 0,
                                 0,
                                 0.088480419303019087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2868577217836255,
                                 0,
                                 0,
                                 0,
                                 -0.41798851277116078,
                                 0,
                                 0,
                                 0,
                                 -0.5558500485810125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56528403730567578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44103252456579378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0037236283265728518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10263838314184225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51975530208355536,
                                 0,
                                 0,
                                 0,
                                 0.28935839796761642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047561724788601448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53759364238613638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17896678102655939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087901323678009791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11633788712913565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13592802002389553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24416153541805266,
                                 -0.82065982552669015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14011102955360907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087393713081758514,
                                 0,
                                 0,
                                 0,
                                 0.71435677068613912,
                                 0,
                                 0,
                                 0,
                                 -0.058945301282207548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043978741162206632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38558564274416202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19960245888700184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36097953838623009,
                                 0,
                                 0,
                                 0,
                                 0.06366017676678265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7043003468717336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41913729069985423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3425887583078735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12597784718773583,
                                 0,
                                 0,
                                 0,
                                 -0.47709967855144386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20424007729756763,
                                 0,
                                 0.19067930110998954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55582956450041121,
                                 0,
                                 0,
                                 0,
                                 -0.17283968198446037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.104051818625629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11874611956835773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14796607268040082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21120659911205963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0976223604338229,
                                 0,
                                 0.34825585408862886,
                                 0,
                                 0,
                                 0,
                                 0.0019704641957823954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38816556768208388,
                                 0,
                                 0,
                                 0.16185078544336737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18167037558317742,
                                 0,
                                 0,
                                 0,
                                 -0.25394170905810254,
                                 0,
                                 0,
                                 0,
                                 -0.34336417937798369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15328731157967376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32864243899834372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65772092118273218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13555678474648997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8420293950086285,
                                 0,
                                 0,
                                 0,
                                 -0.64536190385181191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15243616906978749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35930194929895243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26546342644030568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10403945430863645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14364865306079774,
                                 0.1466082483867221,
                                 -0.27664731670264975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29185537985111942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54604232043911904,
                                 0,
                                 0.029642338279121973,
                                 0.35667956503245579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045065577875449583,
                                 0,
                                 0,
                                 0,
                                 -0.3968283677378987,
                                 0,
                                 0,
                                 0,
                                 -0.25919563537094892,
                                 0.3819425293983702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28772430411518429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2182252823294441,
                                 -0.46877448860861171,
                                 0,
                                 0,
                                 -0.053092769599005413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61164982737587381,
                                 0,
                                 0.4998457471682114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22629655372984167,
                                 0,
                                 0,
                                 0,
                                 -0.34500109330690948,
                                 0,
                                 -0.54447429622854915,
                                 0,
                                 0,
                                 -0.70770096052758047,
                                 0,
                                 0,
                                 -0.0061742776378623659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47748192448767363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41713001378831505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23013276186874679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11669497264963286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25529262343421738,
                                 0.070630297642423512,
                                 0.40341014797641611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37414809606136074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27572327718414447,
                                 0,
                                 -0.22439221107958812,
                                 0.16134544400720219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18979392666413042,
                                 0,
                                 0,
                                 0,
                                 0.44508983609317532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016310955281172081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29817447813668679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11821770209106955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33299152712936164,
                                 -0.2235723457463718,
                                 -0.12916341160874564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27718675159920275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18978804203492966,
                                 0,
                                 -0.20025939737871573,
                                 0.33981151230033224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67075489089365103,
                                 0,
                                 0,
                                 0,
                                 0.030976773032305175,
                                 0.57517714068579795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40191775283110831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20460142440690485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20035408638364532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03755142711675645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16107626210626447,
                                 -0.31558024643833266,
                                 0,
                                 0.2249379604715695,
                                 0,
                                 0,
                                 -0.4976665776065502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020351944116184698,
                                 0,
                                 0,
                                 0.49804726660955057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1321545384503148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28345880943241775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29654371391841633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.295991730369149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48342270623678069,
                                 0.27841189874695976,
                                 0,
                                 -0.29395981951127048,
                                 0,
                                 0,
                                 0.22904934244152547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16881720233515993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15458292909307556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11891654342604752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56326810017036077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45485213093511945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1774449551339698,
                                 0,
                                 0,
                                 0,
                                 -0.14072774342161884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60533939052305874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14168547016894359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18125556113287677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42068252251547111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38374711408968787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19432972728062184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049307646558597762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27413179506827745,
                                 0.56954148322354725,
                                 0,
                                 -0.087016326694489943,
                                 0,
                                 0,
                                 -0.44228323768649014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0018592182422329656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43493087836068711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062098472300154473,
                                 0,
                                 0,
                                 0.42602643085992331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43863560347533653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91684699130129776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1090230594491316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46924063599817661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29904601488493188,
                                 0,
                                 0,
                                 0,
                                 0.27075038541483826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13697181089774216,
                                 0,
                                 0.059234997262510594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34519888875798493,
                                 0,
                                 0,
                                 0,
                                 0.29964053770678672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1074233152461479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32950348321523115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059250487089572708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041551270321904581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036178233490764877,
                                 0,
                                 0.47938079655805765,
                                 0,
                                 0,
                                 0,
                                 -0.17145813980858429,
                                 0,
                                 0,
                                 0,
                                 -0.29999676073686316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32253724117857069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36817059278643194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31673100746811295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5131665773600157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22530720917685337,
                                 -0.1212324429380998,
                                 0,
                                 -0.24626076033096997,
                                 0,
                                 0,
                                 -0.39005586591205654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16886395310260699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085717268655426643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15735593531171979,
                                 0,
                                 0,
                                 0,
                                 0.13413191972523805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3883638381769885,
                                 0,
                                 0.32441431487818756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31340496267752743,
                                 0,
                                 0,
                                 0,
                                 0.2977987040532688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24007385499971212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012414060897934481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42440361587374043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15217149909060274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32861056018883256,
                                 0,
                                 -0.17786998844946028,
                                 0,
                                 0,
                                 0,
                                 -0.32593808951376113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58154265463688082,
                                 0,
                                 0,
                                 0.46042886944225792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0022412804102547035,
                                 0,
                                 0,
                                 0,
                                 0.080850002956926986,
                                 0,
                                 0,
                                 0,
                                 0.034334901585671943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67720263487987875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39845284073369075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85695343718841122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018346324434695895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31543649740903124,
                                 0,
                                 0,
                                 0,
                                 -0.22572845591175714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52335864139835109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6455174089439526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11938391083289195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054451985396594967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3803201572837553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41834822477055722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27270113860949763,
                                 0.34742085744728646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57499110017040256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18647049491393528,
                                 0,
                                 0,
                                 0,
                                 0.033252340634518963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20957394870804613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014050167336339526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24138844644315297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30328353819849063,
                                 0.45684580194430957,
                                 -0.39263083440591845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0067591285347642031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15080341599034852,
                                 0,
                                 0.28990997170259925,
                                 -0.070167255160490355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10565754163702983,
                                 0,
                                 0,
                                 0,
                                 0.56554654957377648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38388032661559696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15278329576524657,
                                 0,
                                 0,
                                 0,
                                 0.093796379260465149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34333215803711314,
                                 0,
                                 0.27027554215830163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10753751535651491,
                                 0,
                                 0,
                                 0,
                                 0.023551368595797414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34778781222204114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01248606793181499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15267913448767789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47918604502941331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39810658875302274,
                                 0,
                                 0.25891384243002136,
                                 0,
                                 0,
                                 0,
                                 0.13372693489043588,
                                 0,
                                 0,
                                 0,
                                 -0.18361914277426497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45477052299684922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32568679066156248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019353321837417916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32216794449291913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12923161272910305,
                                 -0.11349768783426582,
                                 0,
                                 -0.56073912828798911,
                                 0,
                                 0,
                                 0.13489169889722552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43246096400347067,
                                 0,
                                 0,
                                 0,
                                 -0.051394762386911923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69486727705399409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10612382487711187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14545959090348776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23850930352723126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65987150468504108,
                                 0.0042685404682073838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2942579151485849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81694956759940651,
                                 0,
                                 0,
                                 0,
                                 0.11628845556532015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11537817176565539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40285651519286048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1053738499157672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12989003033744023,
                                 0.52134213337463475,
                                 0.11521107936962255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18512463009291405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046641762166490602,
                                 0,
                                 -0.65006118302129023,
                                 0.1517888140056543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 5.7565588231715814e-05,
                                 0,
                                 0,
                                 0,
                                 -0.17112057997589414};

const double rot_6_30[900] = {0.29177495551391758,
                              -1.0879349593725665,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.19478386359285,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.8462085901100731,
                              0,
                              0,
                              -0.0098670746283779365,
                              -0.5272746877098512,
                              -0.72241468634403527,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.71658296549896305,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.10812166956062963,
                              0,
                              0,
                              1.0912640773069502,
                              0,
                              0,
                              0.99999547435136726,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.0030085339924743049,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.5137127959219987,
                              0,
                              0,
                              -0.52707932355813392,
                              0.49765061535181132,
                              0.040920186145696091,
                              0,
                              0,
                              0,
                              0,
                              0.22070039513185424,
                              0,
                              0,
                              0,
                              -0.64492928836945451,
                              0.77492528605494648,
                              0,
                              -0.21248459145735057,
                              0,
                              0,
                              0.081686597910256772,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.35735206202102887,
                              -0.031386143866036401,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.13579212708430582,
                              0,
                              0,
                              -0.0064855526208045799,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.16095216303276516,
                              0,
                              -0.78790298307796647,
                              0.45402218012292778,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.22455059896659302,
                              -0.68186813869587859,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.15562388981255784,
                              0,
                              0,
                              0.28144699545332102,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.13654986069320185,
                              0,
                              -0.39406062597279418,
                              -0.45527137204931611,
                              0,
                              0,
                              0,
                              0,
                              0.037981781061854049,
                              0,
                              0,
                              -0.55052458541591243,
                              0.23622161631072119,
                              0.4339481997941898,
                              0,
                              0,
                              0,
                              0,
                              0.8806729295669643,
                              0,
                              0,
                              0,
                              0.75633339671946265,
                              -0.33516671918704699,
                              0,
                              -0.038404002224453386,
                              0,
                              0,
                              0.53630916376533289,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.2846041875156583,
                              0,
                              0,
                              0.022273121093808579,
                              0.76292299475175707,
                              -0.28832749763686194,
                              0,
                              0,
                              0,
                              0,
                              -0.38750041439472904,
                              0,
                              0,
                              0,
                              1.1227448684297945,
                              0.24730194428186825,
                              0,
                              0.25018984481864492,
                              0,
                              0,
                              -0.3263589005004312,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.036529656733314646,
                              0,
                              0,
                              0.22395769213365846,
                              -0.57081984767243765,
                              0.63442485259073467,
                              0,
                              0,
                              0,
                              0,
                              -0.4282462636751217,
                              0,
                              0,
                              0,
                              -0.031396722309323076,
                              0.58366208976866196,
                              0,
                              -0.53160577474855153,
                              0,
                              0,
                              0.34037117035856934,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.1883621692679789,
                              -0.64660485355096586,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.66109732257383258,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.037950788991359424,
                              0,
                              0,
                              -1.0128123984337567,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.41806206021570624,
                              0,
                              0,
                              0,
                              0,
                              -0.75421289396042879,
                              0.50549838530349644,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.029298580982568129,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.45048968882062285,
                              -0.11853345467583452,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.12699788960775718,
                              0,
                              0,
                              -0.52644490917303621,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.67091775264078279,
                              0,
                              -0.016095765229640884,
                              -0.19835939494511615,
                              0,
                              0,
                              0,
                              0.0030085339924743049,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.99999547435136726,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.59446639188075834,
                              0,
                              0,
                              -0.40287636205789595,
                              -0.26596797004428097,
                              0.12861797685767601,
                              0,
                              0,
                              0,
                              0,
                              -0.64590663657717062,
                              0,
                              0,
                              0,
                              0.025570497582128593,
                              -0.03130586940542969,
                              0,
                              0.54171920846958643,
                              0,
                              0,
                              0.48233175083960722,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.51642251595319966,
                              0.487174428183624,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.13934016348002587,
                              0,
                              0,
                              -0.43045568669557632,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.022800812350230237,
                              0,
                              -0.44996437425819419,
                              -0.29710817395004036,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.89300609622705973,
                              0,
                              0,
                              0,
                              0,
                              0.31906096967318476,
                              -0.2512571976948712,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.19393305633396901,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.16643668666985911,
                              0,
                              0,
                              0,
                              0,
                              -0.15621118498121245,
                              -0.039037646923877539,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.97281702140729986,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.92602983686704954,
                              0,
                              0,
                              -0.55498387417429218,
                              0.041685278174507234,
                              -0.27196514984685183,
                              0,
                              0,
                              0,
                              0,
                              -0.26581285910916774,
                              0,
                              0,
                              0,
                              -0.20594265948150295,
                              0.059350392792370268,
                              0,
                              -0.067898768959105099,
                              0,
                              0,
                              0.52579206011719337,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.16570650822075245,
                              0,
                              0,
                              0.38218310858699311,
                              -0.60601895938569617,
                              -1.0700136861071206,
                              0,
                              0,
                              0,
                              0,
                              0.0181214475033535,
                              0,
                              0,
                              0,
                              0.2921555924740451,
                              0.37990051693722343,
                              0,
                              -0.17172185396503159,
                              0,
                              0,
                              0.28075839563974159,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.0560250695219593,
                              0,
                              -0.64601651007461292,
                              0,
                              0,
                              0.78186398556016856,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.49282429842708031,
                              0,
                              0,
                              -0.57314464868052539,
                              -0.36495376430664289,
                              0.067787936343953775,
                              0,
                              0,
                              0,
                              0,
                              -0.32169403075606728,
                              0,
                              0,
                              0,
                              -0.14060748626746961,
                              -0.13330645106870909,
                              0,
                              -1.0811926661405187,
                              0,
                              0,
                              -0.32012064363074472,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.2026251270010202,
                              0,
                              -1.0960060443169293,
                              0,
                              0,
                              -0.32641904578060077,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.0079407329551520467,
                              0,
                              0,
                              0,
                              0,
                              0.55223280770143301,
                              0.82451031842222899,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.12312028944736374,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.24020818442877784,
                              0,
                              0,
                              -0.83685702349014213,
                              -0.56583723094231664,
                              0.57119687037712286,
                              0,
                              0,
                              0,
                              0,
                              0.48235174793699714,
                              0,
                              0,
                              0,
                              0.0098857396467207995,
                              0.56119203136727835,
                              0,
                              0.40156468801427425,
                              0,
                              0,
                              -0.63019919011414893,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.74018758851188415,
                              0,
                              1.2990221600498988,
                              0,
                              0,
                              1.0533363648179153,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.23265197342464256,
                              -0.13016038170783514,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.67054927852201784,
                              0,
                              0,
                              -0.069182350102524187,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.37688234531025211,
                              0,
                              0.039173122099577545,
                              0.57526860343808017,
                              0,
                              0.52250849289759216,
                              0.35099088235844061,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.48694469507592447,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.85992139009265933,
                              0,
                              0,
                              0.34747837120303771,
                              0,
                              0,
                              0,
                              0,
                              -0.49369999162945544,
                              -0.025822039270006619,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.66502888216238709,
                              0,
                              0,
                              0.17673118991246822,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.43089785545660603,
                              0,
                              -0.019157014702142879,
                              0.30992944343121598,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.23318819670520224,
                              -0.51485254721407192,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.17290982904830443,
                              0,
                              0,
                              -0.64983772951495278,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.4208144066731711,
                              0,
                              0.13891211555350036,
                              0.17883482644790641,
                              0,
                              1.1309299146458263,
                              -0.90798922495014767,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.52399943506945168,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.39939947603926546,
                              0,
                              0,
                              -0.5334620766353616};

const double rot_6_2[4] = {-0.16799602211744422, 0.98578767315924321, -0.98578767315924321, -0.16799602211744516};

const double rot_2_50[2500] = {0.30316303673581579,
                               0,
                               0,
                               0,
                               0.43579091502287232,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23288084857352959,
                               0,
                               0,
                               0.0073038493345980449,
                               0,
                               -0.038082106081820222,
                               0,
                               0,
                               -0.5987671757315346,
                               0,
                               0,
                               0,
                               -1.1859158987913736,
                               0,
                               0.087784333568263068,
                               -0.17890177481605543,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.043109385740872162,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12177992369128743,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20372772724107596,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.055341362286673711,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.086287562321531716,
                               -0.43045186622064302,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.86479341140815746,
                               0,
                               0,
                               0.24623937511654648,
                               0.4533905044615465,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.65594247921453552,
                               0,
                               0,
                               -0.49753348152347721,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23664978202257694,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.87832343208912855,
                               0.10176589869709415,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41040968612754802,
                               0,
                               0,
                               0.10568282386627692,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19643492759151521,
                               0,
                               0,
                               0,
                               0.23296425149223912,
                               0,
                               0,
                               0,
                               -0.61834847010630523,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.43803717169752221,
                               0,
                               0,
                               0.63503666740533693,
                               0,
                               -0.68924466423028852,
                               0,
                               0,
                               -0.4688816671992343,
                               0,
                               0,
                               0,
                               -0.2600792969467044,
                               0,
                               -0.67267997777041644,
                               0.25667168682522801,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.65823165412864626,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15986068032396572,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.92028786318660849,
                               0,
                               0,
                               0,
                               0,
                               -0.72905025720206873,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.46426328228208169,
                               0,
                               0,
                               -0.4030630669893302,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.61463423553589891,
                               0,
                               0,
                               0,
                               0.064121108468878543,
                               0,
                               -0.19174408250474381,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44608525169961477,
                               0,
                               0,
                               0,
                               0,
                               -0.6864622276985477,
                               0,
                               0,
                               0,
                               0,
                               -0.44291918058395024,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17436674281717965,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22879835315601288,
                               -0.12180537104746234,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15180522612992836,
                               0,
                               0,
                               0.11386981657198368,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.372237531235176,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32927301734127712,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42785189674997898,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40709972958711321,
                               -0.55303319814843332,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31366438553679143,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.3910085751381436,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.031419896088356714,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.45577532311352548,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17207848058941577,
                               0,
                               0,
                               0,
                               -0.73295914729981804,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.074505983241070606,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11295495339963478,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.073817337142205522,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.53390639183181965,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0898559200436089,
                               0,
                               0,
                               -0.0230196337775503,
                               0,
                               0,
                               0,
                               0.84809706659406225,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1424412814587151,
                               0,
                               0,
                               0.0060316125280626791,
                               0,
                               0.60596417580587203,
                               0,
                               0,
                               -0.75088378745359785,
                               0,
                               0,
                               0,
                               0.53068571479460935,
                               0,
                               0.38254613344936134,
                               0.22448077938252681,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.73240149799726628,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.043503823688402082,
                               0,
                               0,
                               0,
                               0,
                               -0.30182671239060832,
                               0,
                               0,
                               0,
                               0,
                               0.12116197146775996,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38981137555430834,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.045588003815045498,
                               0.6593555108793967,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3146595048923691,
                               0,
                               0,
                               0.45225696382973252,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.97366064220799853,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.5856565080178292,
                               0,
                               0,
                               0,
                               0,
                               0.24507518701417164,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.073142434307231302,
                               0,
                               0,
                               -0.12192731079790781,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67960140985807294,
                               0,
                               0,
                               0,
                               0.38420525479826095,
                               0,
                               -0.6603931248074717,
                               0,
                               0,
                               0,
                               0,
                               0.7305817873887277,
                               0,
                               0,
                               0,
                               0.20957226534464704,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1344546786173368,
                               0,
                               0,
                               0.50577802857358878,
                               0,
                               0.095010774796736558,
                               0,
                               0,
                               0.50075942700452947,
                               0,
                               0,
                               0,
                               0.016515632380922123,
                               0,
                               -0.0011904954891537381,
                               -0.067588511999305864,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17801752524895562,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.65435332062856344,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63542067304949612,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40995402186550833,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22529111805681279,
                               0,
                               0,
                               0,
                               0.93953338075143145,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40709968741191804,
                               0,
                               0,
                               0.58449805629119334,
                               0,
                               -0.038720136393678689,
                               0,
                               0,
                               0.60218084472604905,
                               0,
                               0,
                               0,
                               0.12599948921099691,
                               0,
                               -0.58928502583571296,
                               0.12416011216960687,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.097677344899829571,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.014556393868913598,
                               0,
                               0,
                               0,
                               0,
                               0.018418450090978783,
                               0,
                               0,
                               0,
                               0,
                               -0.51074482146258859,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.47410691679845596,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.084011922602033592,
                               0.28568025372037631,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.025015898364967273,
                               0,
                               0,
                               -0.65154756174108586,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15251815186954465,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.47163238777872668,
                               0,
                               0,
                               0,
                               0,
                               0.098281460164428167,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.52616980211991249,
                               0,
                               0,
                               0.040413516474512523,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.062967428927771782,
                               0,
                               0,
                               0,
                               -1.2589163672618753,
                               0,
                               -0.93322477611671073,
                               0,
                               0,
                               0,
                               0,
                               -0.50919299108066784,
                               0,
                               0,
                               0,
                               -0.052215473526760134,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1146591670063095,
                               0,
                               0,
                               0.5336249963728148,
                               0,
                               0.52787737651559075,
                               0,
                               0,
                               -0.39265409753125324,
                               0,
                               0,
                               0,
                               -0.00030798120074622577,
                               0,
                               -0.17825248051710479,
                               1.1089082424557926,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41538594903274895,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46026856442843878,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10075354859739533,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1274545684522095,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.81111244591993303,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.064512918281885157,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.3840106531724121,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30349629380079346,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.64971610299792493,
                               0,
                               0,
                               0,
                               0.29119317533367023,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.52512239459912802,
                               0,
                               0,
                               0.41736133532320274,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61355792345431337,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25252461968883216,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30154834487964427,
                               0.50068374145755346,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20969476277457816,
                               -0.56702093216769411,
                               0,
                               0,
                               0,
                               -0.14526850965403898,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.85861820513601228,
                               0,
                               0,
                               0.51089564117515462,
                               0,
                               -0.88947879277379016,
                               0,
                               0,
                               0.026821444650211343,
                               0,
                               0,
                               0,
                               -0.056718873602306055,
                               0,
                               0.88982437932137959,
                               -0.26590268955809371,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11778128773495092,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.64111122604980653,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1786873384235822,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.74635596796703141,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29396831141779989,
                               0,
                               0,
                               0,
                               0.039423643988557688,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10611869558310263,
                               0,
                               0,
                               0.82864600724486792,
                               0,
                               0.28952851769189547,
                               0,
                               0,
                               -0.44427209790704136,
                               0,
                               0,
                               0,
                               0.43364619164109708,
                               0,
                               0.087312085942292963,
                               -0.64788236070691396,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.76256701038472008,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.45632486364139085,
                               0,
                               0,
                               0,
                               0.36776196819148232,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20334000345758999,
                               0,
                               0,
                               -0.63615712402829838,
                               0,
                               -0.6713243077817318,
                               0,
                               0,
                               -0.21967577873597974,
                               0,
                               0,
                               0,
                               0.63747475121869446,
                               0,
                               -0.37309015790062439,
                               0.079705606543890653,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42272487235900896,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.54721861231484659,
                               0,
                               0,
                               0,
                               0,
                               -0.010995701156021609,
                               0,
                               0,
                               0,
                               0,
                               0.49142183424820407,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5517536038650952,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.022583915336473429,
                               -0.17935584748582095,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34404766263528386,
                               0,
                               0,
                               -0.058788425002086239,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.93369950085447095,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.00069061492225952481,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.90841515386076277,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39171163928931019,
                               0,
                               0,
                               0,
                               0.3995470289428899,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28986223477635897,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.011872031319482862,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40755605475445533,
                               0,
                               0,
                               0,
                               0,
                               -0.6977853145358005,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25504028290849079,
                               0,
                               0,
                               0.4832734180735469,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.6415271256316315,
                               0,
                               0,
                               0,
                               -0.32738966435859457,
                               0,
                               0.59172776107981528,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.014071680232252942,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32493469150422943,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.52438109878035521,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.71820936960168313,
                               0.32068211000052566,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.02412846983056088,
                               0,
                               0.4218898529115212,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15117153514724921,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.68909152638140292,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40538784545358097,
                               -0.36573187679290342,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16189464567091591,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29165641727259473,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.080431569362588717,
                               0,
                               0,
                               0,
                               0,
                               0.50040676564548991,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.82017650300655065,
                               0,
                               0,
                               -0.22574241397606912,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.048576483036822653,
                               0,
                               0,
                               0,
                               -0.60825777507620238,
                               0,
                               -0.19640757395263028,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63277271149966796,
                               0,
                               0,
                               0,
                               0,
                               -0.5386793597863786,
                               0,
                               0,
                               0,
                               0,
                               0.17149366028237178,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3034172089591271,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.008776635720882945,
                               -0.42177855903130418,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.020523727564361001,
                               0,
                               0,
                               -0.097753563237698682,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18158054851934302,
                               0,
                               0,
                               0,
                               0,
                               0.2178292582162191,
                               0,
                               0,
                               0,
                               0,
                               -0.27506816101586684,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33989752806064494,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.089071847059343651,
                               -0.50007446860840854,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.65314697621311812,
                               0,
                               0,
                               0.20922919310916996,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15588770439177213,
                               0.40296295870674825,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14374564649736937,
                               0,
                               0,
                               -0.16159037382273467,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.87552590922864726,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40099641845692702,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.75120663159241619,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.52429998000790623,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63794894689196924,
                               0,
                               0,
                               0,
                               -0.66275876254765698,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35400242772637047,
                               0,
                               0,
                               -0.40862919818054183,
                               0,
                               0.40439196399053845,
                               0,
                               0,
                               -0.19654803703660115,
                               0,
                               0,
                               0,
                               -0.12043768422582428,
                               0,
                               -0.66253487125256805,
                               -0.72666540265146495,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38367575798420439,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22071950359221654,
                               -0.7451664034032488,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50164368153664562,
                               0,
                               0,
                               -0.084634722999150216,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37040587523727309,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.044810551811466148,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39405767690202609,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32460055631167345,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40562141254698819,
                               0,
                               0,
                               0,
                               -0.95625036958730802,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.3364791157687719,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19009067310173999,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51990604708945687,
                               0,
                               0,
                               0,
                               0,
                               -0.034176438102441267,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10648172712106341,
                               0,
                               0,
                               -0.92911776592984874,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4472919240997506,
                               0,
                               0,
                               0,
                               -0.25046613679993007,
                               0,
                               0.72416390253913265,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.2615853048252592,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20944041301691224,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61978866841873237,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.48186738851738947,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.049698534928677977,
                               0,
                               0,
                               0,
                               0,
                               0.074895524302103611,
                               0,
                               0,
                               0,
                               0,
                               0.20022890611057229,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.027447207341862366,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.92988088137400848,
                               0.077272730220782113,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1042810982828353,
                               0,
                               0,
                               -0.26372651780319989,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32576762249734176,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16697956292001706,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.2308469365463821,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49838175089579001,
                               0,
                               0,
                               0,
                               0.46331222286401574,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.025775797805060952,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.55277227854514588,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43775347619300498,
                               0,
                               0,
                               0,
                               0,
                               -0.683076701261495,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37236900655252453,
                               0,
                               0,
                               -0.38126323597973771,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.035075827424758683,
                               0,
                               0,
                               0,
                               0.59986977267292896,
                               0,
                               -0.58828150116789124,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25221523126298606,
                               0,
                               0,
                               0,
                               0,
                               -0.3065546002388167,
                               0,
                               0,
                               0,
                               0,
                               0.37632765079147917,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28299865916356615,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25556943148975708,
                               0.051858775685364226,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.56661559859941379,
                               0,
                               0,
                               -0.48129274755497009,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.91525257929225645,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.077964910848995303,
                               0,
                               0,
                               0,
                               0,
                               -0.46673592375575979,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.083947668666997335,
                               0,
                               0,
                               0.35357339465637017,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.80685058131729359,
                               0,
                               0,
                               0,
                               -0.33457232264559278,
                               0,
                               -0.24213672383665141,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30805201369063595,
                               -0.25773753602424099,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35915756901670676,
                               0,
                               0,
                               -0.84143751417051971,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.040793011041639238,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37085733061627685,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.3716937646073573,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.47528483580290432,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46892916166423904,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13138935964913293,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0432706407703609,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21930338194836307,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.68267727797133604,
                               0,
                               0,
                               0,
                               -0.40903766286048721,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1844011949459877,
                               0,
                               0,
                               0.70301445655736994,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.58752496201341353,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.016992234401823101,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23606960548514455,
                               0.14691644658137712,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.2880677974757086};

const double rot_2_20[400] = {1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.24850675289475344,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.64258108247668877,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.78659458471673926,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.279084845233807,
                              0.29796748223589609,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.91286747597382523,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.051427321349106964,
                              -0.95391333386167976,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.29564265947212609,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.89433158582363781,
                              0,
                              0,
                              0,
                              0.085763411847174884,
                              0,
                              0,
                              0.36518883486618053,
                              0.24382938025511802,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.68235595703210572,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.1173881066071802,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.89080874625621476,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.22775691030163614,
                              0,
                              0,
                              0,
                              -0.28426452733012775,
                              0,
                              0,
                              0.86120141005397088,
                              -0.35447510439054281,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.19546898005126453,
                              0,
                              0,
                              0,
                              0.94588179970305342,
                              0,
                              0,
                              0.25900967778046108,
                              -0.0036722805302527584,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.33179765256214205,
                              0,
                              0,
                              0,
                              0.13094249379259473,
                              0,
                              0,
                              -0.24058934520505085,
                              -0.9027076758549395,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.9588883562645224,
                              0.035563056827234485,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.28154642460778206,
                              0,
                              0,
                              0,
                              0,
                              1.5292391326548171,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.085173845205653631,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.38498884870581462,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1};

const double rot_2_10[100] = {-0.013627060205049717,
                              0,
                              0,
                              -0.96121902188204134,
                              0,
                              0,
                              0.27544926066754971,
                              0,
                              0,
                              0,
                              0,
                              1.0187099017661225,
                              0,
                              0,
                              0.53967855359271233,
                              0,
                              0,
                              0,
                              -0.08717441909298522,
                              0,
                              0,
                              0,
                              0.26058100765645231,
                              0,
                              0,
                              0.17899279377065161,
                              0,
                              0.82141514208382516,
                              0,
                              -0.47469598964214416,
                              -0.57007114692758154,
                              0,
                              0,
                              -0.21885020763174318,
                              0,
                              0,
                              -0.79191127915961379,
                              0,
                              0,
                              0,
                              0,
                              0.24382105614271932,
                              0,
                              0,
                              -0.88537614465493131,
                              0,
                              0,
                              0,
                              0.6388979239016348,
                              0,
                              0,
                              0,
                              -0.92218426126838593,
                              0,
                              0,
                              0.013384353981380909,
                              0,
                              0.069950764482454755,
                              0,
                              -0.38013673577503904,
                              -0.82148231306026276,
                              0,
                              0,
                              0.16781709862726921,
                              0,
                              0,
                              0.54498094529761731,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.036688476595634983,
                              0,
                              0,
                              0.95292399623672275,
                              0,
                              -0.28124192120177316,
                              0,
                              -0.10720445345255791,
                              0,
                              -0.12847811456506475,
                              0,
                              0,
                              -1.5832234533457452,
                              0,
                              0,
                              0,
                              -0.94748444011200439,
                              0,
                              0,
                              0,
                              0.28342138663608296,
                              0,
                              0,
                              -0.2443732723579092,
                              0,
                              -0.49120976849251008,
                              0,
                              -0.78655386636383773};

const double rot_2_100[10000] = {-0.38489832062197055,
                                 0,
                                 0,
                                 0,
                                 -0.90402258683547942,
                                 0,
                                 0,
                                 0,
                                 0.67465793934755725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90018142614375773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26297218185119858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19879695467332686,
                                 0,
                                 0,
                                 -0.087838001606642305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52159409304255389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61694358120832871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19957632609432377,
                                 0,
                                 0,
                                 -0.60287314306151596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42664340499235615,
                                 -0.46784918553831339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16156236784922426,
                                 0,
                                 0,
                                 -0.73733497637082002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45360797667650482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72455648229392977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27935027030091508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14921495281769631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24690628487196137,
                                 0,
                                 0.48093461837951246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16773829619389016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14089363741257072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18565628070649709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78590290369397031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39107331446425564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32034183217776274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26317782923532718,
                                 0,
                                 0.015776839315501244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038273402377516336,
                                 0.82759455487123657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086339211896070439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04477576243707778,
                                 0,
                                 0.0027617356608155841,
                                 0.2488853397645161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041800614794154103,
                                 0,
                                 0.06793669488818907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25607722092368784,
                                 0,
                                 0,
                                 -0.65335172889237481,
                                 0,
                                 0,
                                 0,
                                 -0.48040253079864959,
                                 0,
                                 0,
                                 0,
                                 -0.43038318451367846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46744766959699058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83985662456378474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10130034254472438,
                                 0,
                                 0,
                                 0.025844335310949568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59518192919868163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18784560555324167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65974939823696921,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10121619143050646,
                                 0,
                                 -0.21808874904684694,
                                 0,
                                 0,
                                 -0.40460993510159887,
                                 -0.25189088177995728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49384229696462345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36889781934690552,
                                 0,
                                 0,
                                 0,
                                 0.14755212759504402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20557538867244224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029489281224251596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51977500934703658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49485100408891236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11760427816841279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0067550404445190261,
                                 0,
                                 0.45054249642067346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43960438778739863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58737171203111993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66417140725168033,
                                 0,
                                 0.29724701716072627,
                                 0,
                                 0,
                                 -0.22721599669589146,
                                 0.0044122484888501484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0081983337496138176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52129708342013148,
                                 0,
                                 0,
                                 0,
                                 -0.12930685868586705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012343701562098186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26965537752824364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2397278880880814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080875527939745478,
                                 0,
                                 0,
                                 0,
                                 0.60996075419552875,
                                 0,
                                 0,
                                 0,
                                 0.44382749384143644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094383076717092063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64736140966767874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19991199392927148,
                                 0,
                                 0,
                                 0.88918238237086422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045963759898479284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11170512658462589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66047317332086664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16576808302116197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46507797542703488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3710610386107166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5778047835780572,
                                 0.02609402829982807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17204742277970594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15847179312176254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25946502842997016,
                                 0,
                                 0,
                                 0,
                                 -0.32706964753343942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2191278496827157,
                                 0,
                                 0,
                                 0,
                                 -0.021675550952543095,
                                 0,
                                 0,
                                 0,
                                 0.08062713301905533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41981217812663185,
                                 0,
                                 0.584416775298502,
                                 0,
                                 0,
                                 -0.068755992994432177,
                                 -0.071467927350488653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55584919793999044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087766599492369979,
                                 0,
                                 0,
                                 0,
                                 0.038671043761680318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27737628944988713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25357518840472765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11390776113929087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19926132795037332,
                                 0,
                                 0.13994012720803828,
                                 0,
                                 0,
                                 0.36588911727228784,
                                 -0.26206491101153873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010359059007801364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45274786612939649,
                                 0,
                                 0,
                                 0,
                                 0.1795372025776073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084860578958655786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53809336876438596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45176485187719878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10548580487514519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49969892480880362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36051428243692013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23405300026260792,
                                 0,
                                 0.34222213450606875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058819561596768585,
                                 -0.1237173964951167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049190002421850787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84792716903073417,
                                 0,
                                 -0.28644880704927256,
                                 -0.28956680449503314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53139112332233018,
                                 0,
                                 0.29649029386494968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79796294829200454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26327869708920915,
                                 0.3083625965796753,
                                 0,
                                 0.056024176372659037,
                                 0,
                                 0.022958803002449367,
                                 0,
                                 0,
                                 0.031639619077583947,
                                 0,
                                 0.17455868389496582,
                                 0,
                                 0,
                                 0,
                                 -0.19441183848666288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19547688272896846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16473749573367177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20971009790224501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3617351685871103,
                                 0,
                                 0,
                                 0,
                                 0.35155085238176448,
                                 0,
                                 0,
                                 -0.12093035348934283,
                                 0,
                                 0,
                                 0,
                                 0.61989579399401817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27757496486095862,
                                 0.23883880105839825,
                                 0,
                                 -0.2204671624002664,
                                 0,
                                 -0.16900874982225489,
                                 0,
                                 0,
                                 -0.11503115646683351,
                                 0,
                                 -0.072709574104461647,
                                 0,
                                 0,
                                 0,
                                 -0.039539495957834792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35795419104106263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042756637413125492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50504191690130429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2266081670812681,
                                 0,
                                 0,
                                 0,
                                 -0.50503681505185993,
                                 0,
                                 0,
                                 0.17118714311326888,
                                 0,
                                 0,
                                 0,
                                 0.21888595945364775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64429682554526457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45677812208735041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16020399331934992,
                                 0,
                                 0.58896776596968836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047509297225146796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037813564035004854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18174146506070274,
                                 -0.38286780040212987,
                                 0,
                                 0.26307965026787911,
                                 0,
                                 -0.18402637381676382,
                                 0,
                                 0,
                                 0.26844614546173873,
                                 0,
                                 -0.096798689107244359,
                                 0,
                                 0,
                                 0,
                                 0.14793796313542679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0085443971054986224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15373014511763994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50377793160763285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25752096770453015,
                                 0,
                                 0,
                                 0,
                                 0.50610900753977195,
                                 0,
                                 0,
                                 0.10128109149502165,
                                 0,
                                 0,
                                 0,
                                 0.061378449437533081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40816761290193992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30996732096851998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72023355945753065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45684474032691136,
                                 0,
                                 0.04537164726178064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0036854670773636619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087508847743530127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012082851487874004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21426923137618636,
                                 -0.1162546760974594,
                                 0,
                                 -0.38421282657364136,
                                 0,
                                 0.7980767777326162,
                                 0,
                                 0,
                                 0.17460541046274403,
                                 0,
                                 0.12555582289421963,
                                 0,
                                 0,
                                 0,
                                 0.005430456903362621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1124580219483117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19498590784871186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13757465592358561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13258701985430946,
                                 0,
                                 0,
                                 0,
                                 0.12651270174866114,
                                 0,
                                 0,
                                 -0.074741965558276238,
                                 0,
                                 0,
                                 0,
                                 -0.031344277910724042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11631768723670985,
                                 0,
                                 0,
                                 0,
                                 0.51256192628942865,
                                 0,
                                 0,
                                 0,
                                 0.27172057807760336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38505335543943225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19641964350063351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.6293419143819219,
                                 0,
                                 0,
                                 -0.3045069734756185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45864914765076686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17250211837099608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024444609962345737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43948790919549674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28349754733945587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7215646152182722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3633018604442113,
                                 0,
                                 0,
                                 -0.55108763178651665,
                                 0,
                                 0,
                                 0,
                                 -0.41292541845601916,
                                 0,
                                 -0.10914972251014474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30271577746298495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12088107265609839,
                                 0.06852207244491787,
                                 0,
                                 -0.51291352767626663,
                                 0,
                                 -0.27001118591792428,
                                 0,
                                 0,
                                 0.44671185982961747,
                                 0,
                                 -0.20971740740033271,
                                 0,
                                 0,
                                 0,
                                 -0.11468078538074745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43395972971643654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21153378479014917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26584179202389185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23599350293010832,
                                 0,
                                 0,
                                 0,
                                 -0.027809728836569007,
                                 0,
                                 0,
                                 -0.024977312802075956,
                                 0,
                                 0,
                                 0,
                                 -0.16489990037860922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29164726954559589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33429344409561063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1236186269892502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064189142924211615,
                                 -0.16412907486226319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084444418606326038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30509807137434897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26057439608931782,
                                 0,
                                 0,
                                 0,
                                 -0.13507691384472775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6484204384791239,
                                 0,
                                 0,
                                 0,
                                 0.33400286609506907,
                                 0,
                                 0,
                                 0,
                                 0.19616864693340219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1090378377256655,
                                 0.061915365327555663,
                                 0,
                                 0.049589427044201134,
                                 0,
                                 0.12623076770729472,
                                 0,
                                 0,
                                 0.079047559706719644,
                                 0,
                                 0.21296443578105814,
                                 0,
                                 0,
                                 0,
                                 0.81039654945403283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26013162652097305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1613723100321213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15995028758930849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19285380062576957,
                                 0,
                                 0,
                                 0,
                                 -0.24635450877123946,
                                 0,
                                 0,
                                 -0.070603879676573972,
                                 0,
                                 0,
                                 0,
                                 0.18808871371039043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21046498884113668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49202832740144969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13841652090139303,
                                 0,
                                 0.61095635132443571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027052203986602436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56608656165288795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47689378673556587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0097189023597359647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020033502643995171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29717947746785522,
                                 0,
                                 0.73358597628142208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04836580267677263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043392623079159406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37601904320214152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40849703413953325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36305574182954786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72827484312196711,
                                 0,
                                 -0.062073395475976567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039117504808863959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40688225408720807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093118657274807143,
                                 -0.17422342950322106,
                                 0,
                                 -0.09266290223367038,
                                 0,
                                 -0.11711835781331578,
                                 0,
                                 0,
                                 -0.0052825119900897291,
                                 0,
                                 0.64614627208632558,
                                 0,
                                 0,
                                 0,
                                 -0.12538898276815194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23644076500372957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1415481962898289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086403407507263968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021607317955503913,
                                 0,
                                 0,
                                 0,
                                 -0.017696744080370565,
                                 0,
                                 0,
                                 0.63571530950188737,
                                 0,
                                 0,
                                 0,
                                 0.13075549891277141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23084237195926791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30112800616268176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34758824426203261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14422572530322642,
                                 -0.13731599217340265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027451153969934174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13213847138475529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0655910594068361,
                                 0,
                                 0,
                                 0,
                                 0.67861328133943144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27201750895992183,
                                 0,
                                 0,
                                 0,
                                 0.35936932583098297,
                                 0,
                                 0,
                                 0,
                                 0.09688778266736417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24432531710946181,
                                 0,
                                 0,
                                 0,
                                 0.26809219770049986,
                                 0,
                                 0,
                                 0,
                                 -0.69456858433103996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1501873182162565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51604480013167997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35746011963621471,
                                 0,
                                 0,
                                 0.022137475940371409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18667352245367957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35021510547065382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15325677329323603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64659689898836881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010349229957821393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072441183661764386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063212925840862313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83943919125591848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066134515567819463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39575676835325768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10008749128866834,
                                 0,
                                 0,
                                 0,
                                 0.12776569785661285,
                                 0,
                                 0.032149592070285671,
                                 -0.41302335081791275,
                                 0,
                                 0,
                                 0.43596117576003496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086965480305619708,
                                 0,
                                 -0.53552023365650914,
                                 0,
                                 0,
                                 0.37963353064805672,
                                 -0.1971997851138127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2987020988390352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35734303988148858,
                                 0,
                                 0,
                                 0,
                                 0.012743685877146638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17951565124919064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51613692480805695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083325410364348304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67512970158208219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0426356808669624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60552218708396022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37521908367007856,
                                 0,
                                 0,
                                 -0.56454821978944147,
                                 0,
                                 0,
                                 0,
                                 -0.54678095528346893,
                                 0,
                                 0.65407789132265293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46943676630400483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057868743444470544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53449923942315358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17766995386758061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12498710460272282,
                                 0.030889936414263269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24261830295171638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67411226824842463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23626489655371108,
                                 0,
                                 0,
                                 0,
                                 -0.11335637658278552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10597334549999501,
                                 0,
                                 0,
                                 0,
                                 0.18654315883921474,
                                 0,
                                 0,
                                 0,
                                 -0.18662458021486911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11815255967265004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38422222235331316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18318250279380033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29000128996293462,
                                 -0.11328122433696018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21941771774413707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053007981822406236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36381957808306581,
                                 0,
                                 0,
                                 0,
                                 0.25483635149050538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38713462899741763,
                                 0,
                                 0,
                                 0,
                                 -0.13394394234789297,
                                 0,
                                 0,
                                 0,
                                 0.54023107102452528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22580001495544846,
                                 0.20235375776256009,
                                 0,
                                 0.18612521766673989,
                                 0,
                                 -0.051570717203439261,
                                 0,
                                 0,
                                 -0.0098032074515877199,
                                 0,
                                 0.51112216211389561,
                                 0,
                                 0,
                                 0,
                                 -0.28478283853673303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30025625146526524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14649295804806131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23174700016675531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14070803260330506,
                                 0,
                                 0,
                                 0,
                                 -0.066112114410535106,
                                 0,
                                 0,
                                 -0.55182840881029471,
                                 0,
                                 0,
                                 0,
                                 -0.18524878290234789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32760343613864756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20990254182054191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16469362706006854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52088474569514953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48026086013052555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3208357894514714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44741395643806109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58973724732743282,
                                 0,
                                 0,
                                 0,
                                 0.9009321711196262,
                                 0,
                                 0.59146932910717376,
                                 0.12364583816241434,
                                 0,
                                 0,
                                 -0.24610451158914748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35552625393122406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12095154868382541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76444313987233914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073533802417954652,
                                 0,
                                 0,
                                 -0.11077567485543749,
                                 0,
                                 0,
                                 0,
                                 -0.86876683115946762,
                                 0,
                                 0.58468689967477583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83674927559120016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13450894695524618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72099485790443885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30462138851648135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24666635201846057,
                                 0,
                                 -0.16582610983461182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025219256833879409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52912180590303903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018195697412223311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11707813551509409,
                                 0,
                                 0.18007384261747661,
                                 0,
                                 0,
                                 0.39277988582167173,
                                 -0.30189645794017095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.067200867223434255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31968512808303529,
                                 0,
                                 0,
                                 0,
                                 -0.7647549132313215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062934158525630071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00010353559054903641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11368059356344518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22053767851988731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061530276004188145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57624071207121763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70388625015071438,
                                 0,
                                 0.0032859140943334864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23988165179112161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16051200619849809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19170247222451103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054230196385059326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12163729379257837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55278713238147825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15680558038041892,
                                 -0.19394439461275689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67551352979854928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10486100056306363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11940185408567597,
                                 0,
                                 0,
                                 0,
                                 0.32825218720435401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.009224331811614625,
                                 0,
                                 0,
                                 0,
                                 0.15832859947707892,
                                 0,
                                 0,
                                 0,
                                 0.0037053122546416226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20617905649310644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58909870103169604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63971348456688448,
                                 0,
                                 -0.09951610029756458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22405715477153779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37565211558957423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17040794816100546,
                                 0,
                                 0.29882378345146166,
                                 0,
                                 0,
                                 -0.10911961795554317,
                                 0.11338538018714069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051572938710840538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044539528338150058,
                                 0,
                                 0,
                                 0,
                                 -0.025562767149290858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90983199854679775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06555966431397961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13968827568394387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19902337876640575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21449099620446482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28171590297766586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17086979367068378,
                                 0,
                                 0.6042495964520096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070892386699017415,
                                 0.38827442973809601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0171831664446781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.94606414193991373,
                                 0,
                                 -0.15429518991314362,
                                 -0.32625967058493993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58740582092094951,
                                 0,
                                 0.023940684213840817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82518667139052981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11073566792184976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068080899798394115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0571037293375058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016376812838619328,
                                 0,
                                 -0.32066231777430221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46316011272749091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14533221541179631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8006937630148685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38570037155516762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0059373602345158261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0024231511409222029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11798022118939945,
                                 -0.48059855643376992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15077466455935301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3431367915828325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46021807514987639,
                                 0,
                                 0,
                                 0,
                                 -0.055407456426017319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027178772231100386,
                                 0,
                                 0,
                                 0,
                                 0.28591508733340709,
                                 0,
                                 0,
                                 0,
                                 -0.4104475014885734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019614354505667314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29804062245098845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084766349593071305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88222789940170832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12356540789905074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15700594542009377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14208604317258239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84537492710979523,
                                 0,
                                 0,
                                 0,
                                 0.31506542125446918,
                                 0,
                                 -0.60781007539282439,
                                 -0.10372093328810031,
                                 0,
                                 0,
                                 -0.033310858134785376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14214267839123712,
                                 0.016870593022046222,
                                 0,
                                 0.18282103502979663,
                                 0,
                                 -0.14302299982280373,
                                 0,
                                 0,
                                 -0.020012659553844826,
                                 0,
                                 0.23721779790563821,
                                 0,
                                 0,
                                 0,
                                 0.22202942413522014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39573194866968475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59038033527791256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2053118562169452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12444041737020617,
                                 0,
                                 0,
                                 0,
                                 0.0047873600651429388,
                                 0,
                                 0,
                                 -0.019579306818069766,
                                 0,
                                 0,
                                 0,
                                 -0.50642325977839875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5462502436864094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21609013624591544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056771737690173872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10880769076448975,
                                 0,
                                 -0.36064453811372277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39713418521699917,
                                 0.97885166368481769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28568818489209474,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18574883588974475,
                                 0,
                                 -0.39976859807606802,
                                 -0.23625591370776081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24173719094711488,
                                 0,
                                 -0.084483219648821661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23953874217454549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020704659581999147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046529170658877073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16992575164124091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26637301370677208,
                                 0,
                                 -0.30355336720760873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81923997125806736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22851929102642007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2864562204353529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23568221832830424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32035318704961824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21306778410474536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24598035240419081,
                                 0,
                                 0.7077362114838518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52326416161995126,
                                 0.12042687617329426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085319195676422876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56670377482353751,
                                 0,
                                 0.43231303277474642,
                                 -0.34887839269279541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.006440840843527168,
                                 0,
                                 0.72889073361918622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36206605406888626,
                                 0,
                                 0,
                                 -1.2294041135255001,
                                 0,
                                 0,
                                 0,
                                 0.32942601995932486,
                                 0,
                                 0,
                                 0,
                                 0.20232794638792381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11359570588401376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15825163587256105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10422321036690012,
                                 0,
                                 0,
                                 -0.18909318605153252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3562570337831511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073903590636790667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10233983938500998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059983845483275448,
                                 -0.1020230734314838,
                                 0,
                                 0.5909108482373886,
                                 0,
                                 0.28475793196136173,
                                 0,
                                 0,
                                 0.38214601704272844,
                                 0,
                                 -0.18056404175536706,
                                 0,
                                 0,
                                 0,
                                 -0.26431679789847246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11426321263943695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15482678131553326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090509786145117566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22138373524707194,
                                 0,
                                 0,
                                 0,
                                 -0.429839450135998,
                                 0,
                                 0,
                                 0.15302519652417532,
                                 0,
                                 0,
                                 0,
                                 0.069421480547888048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087070641113447825,
                                 0,
                                 -0.18233745730684592,
                                 0,
                                 0,
                                 0.045937916983458615,
                                 0.65623024105025884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51669893769807906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15578070111933295,
                                 0,
                                 0,
                                 0,
                                 -0.29281470024136425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029882073964546119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37896101075252903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070235887417414378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46925344296999039,
                                 0,
                                 0,
                                 0,
                                 0.13577341662631173,
                                 0,
                                 0,
                                 0,
                                 -0.82555722474068571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46225145655832123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10136864349673469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19334330834483715,
                                 0,
                                 0,
                                 0.13169235466852275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48740761843327374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75072995714649648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15476759699788009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.837648963365202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012861718558482789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45636503828196856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20034187391743286,
                                 0,
                                 0,
                                 -0.24186430054734065,
                                 0,
                                 0,
                                 0,
                                 -0.61918236376992364,
                                 0,
                                 -1.2262092772513602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38453155446098597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45313331574718818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25603314956167444,
                                 -0.32615967827115028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051500658774795371,
                                 0,
                                 0,
                                 0.48473939561476087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0804769341252316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7933595066500182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92211017668062933,
                                 -0.92505318310780171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59327485429894034,
                                 0,
                                 0,
                                 -0.075439226923977476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13521603366647345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6167032191074111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35864174388207515,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44831392624092081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1362098666715944,
                                 0,
                                 0,
                                 -0.11882936716207905,
                                 0,
                                 0,
                                 0,
                                 0.97609966819092309,
                                 0,
                                 0.021056469138779236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3307674372686675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020546800081037625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78069838748706255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.089460280400804643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70950820526860214,
                                 0,
                                 -0.400252748506916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7699620894598227,
                                 0.045230827721838729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096767478062255635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25863131261364125,
                                 0,
                                 0.8312847718961951,
                                 0.035413608079371522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16577796698903391,
                                 0,
                                 0.27476432199552442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14343652058844875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21536510180308233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32369287720615303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28475666644010827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83100584841035785,
                                 0,
                                 0.260774943512253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85382822315534224,
                                 0.013648362572459577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031881972386913759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40812331133138902,
                                 0,
                                 -0.11949187865312146,
                                 0.2445603284174189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46890532088583692,
                                 0,
                                 0.23415538999031044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26839407710187663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45634776825722956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76231983607979459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.223986735097366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016225384550665231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032776399534980821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82080912751710888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12271026293344516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044799995790431243,
                                 0,
                                 0,
                                 0,
                                 0.29479033438682906,
                                 0,
                                 -0.1975160861988241,
                                 -0.31020644729188407,
                                 0,
                                 0,
                                 0.20000960011271651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091598529105157825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42241203624238283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70964734365678517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046653272135001894,
                                 0,
                                 0,
                                 -0.76833235214077633,
                                 0,
                                 0,
                                 0,
                                 0.56233325365395759,
                                 0,
                                 0.27927850340366417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0039580534868305789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55262248173365269,
                                 -0.13423768523094526,
                                 0,
                                 -0.079654304055710348,
                                 0,
                                 -0.036947333639124329,
                                 0,
                                 0,
                                 -0.15194300901553079,
                                 0,
                                 0.0053492172680498452,
                                 0,
                                 0,
                                 0,
                                 -0.011213506954275605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13887434220640982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24028708385029604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034704297480701411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73197583231656449,
                                 0,
                                 0,
                                 0,
                                 0.089189531497006522,
                                 0,
                                 0,
                                 0.023439519461045055,
                                 0,
                                 0,
                                 0,
                                 -0.15204121654185945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5212549822325272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73014370397826678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44333310673399562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92170500831077906,
                                 0,
                                 0,
                                 -1.0028077275183001,
                                 0,
                                 0,
                                 0,
                                 -0.13024566561314582,
                                 0,
                                 -0.24495660231011701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025967705911422612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29381787314492436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2378746618300013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12454849350212661,
                                 0,
                                 -0.25120550491517391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86719504114582924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16261282347527281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060338529815554341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31973566904794454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1153332843873669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078421819824155886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16773679226050864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41308885133061712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51177036842518542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066456183467329372,
                                 0,
                                 0,
                                 0,
                                 0.38714488226262916,
                                 0,
                                 -0.80453043289037485,
                                 0.37976325078243228,
                                 0,
                                 0,
                                 0.36815247928184847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075843332176670747,
                                 -0.56375790892140043,
                                 0,
                                 -0.14499870539477103,
                                 0,
                                 -0.2679302188938264,
                                 0,
                                 0,
                                 0.25369012337018004,
                                 0,
                                 0.14605888433734476,
                                 0,
                                 0,
                                 0,
                                 0.014400611803246248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24341149495303332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14999105164273946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25582021112394776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012177950448579349,
                                 0,
                                 0,
                                 0,
                                 -0.24942394185331562,
                                 0,
                                 0,
                                 -0.43055119988971646,
                                 0,
                                 0,
                                 0,
                                 0.32060713572780303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16959268430684152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087751996085635442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55564241811956239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64371917183962957,
                                 0,
                                 0.34166714152679656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23327633159770905,
                                 0.2374287988396829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6679093896852204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21010293091022278,
                                 0,
                                 -0.31523874934960022,
                                 0.47022800760941852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058883341826074909,
                                 0,
                                 -0.67685920147880496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1283799161301091,
                                 0,
                                 0,
                                 0,
                                 -0.4607429612665721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65798059882293503,
                                 -0.52963381386752151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74267857110723878,
                                 0,
                                 0,
                                 0.50809511698058307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21813364425232587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52762447330849405,
                                 -0.16648305390065951,
                                 0,
                                 -0.10727059466632258,
                                 0,
                                 0.089797884376999842,
                                 0,
                                 0,
                                 0.21668377011033818,
                                 0,
                                 0.22437400122145351,
                                 0,
                                 0,
                                 0,
                                 -0.18529176199522449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31939498032248925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5716711837513434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14572345699318989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10797052807433771,
                                 0,
                                 0,
                                 0,
                                 -0.12287068669579754,
                                 0,
                                 0,
                                 0.085668339835568263,
                                 0,
                                 0,
                                 0,
                                 -0.24196333391177621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14411634340922269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5690366657905489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12763598586366173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32861594838742492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58216501952087152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058348829332146135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.581761011327527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54214319432690117,
                                 0,
                                 0,
                                 0,
                                 0.44481209531667942,
                                 0,
                                 0.52942398768783194,
                                 -0.40873980692154799,
                                 0,
                                 0,
                                 0.47965650312010422,
                                 0,
                                 -0.91866876925168173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85025570224191749,
                                 -0.50210991761610546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58922238770806357,
                                 0,
                                 0,
                                 0.41370824023977504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94854253586596615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27119718002928428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10206360775302095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10916523058050714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51276082503332043,
                                 -0.15005414084035623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12496082808307413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16893387140078334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23680627949677718,
                                 0,
                                 0,
                                 0,
                                 -0.19297902082410018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39202560923950469,
                                 0,
                                 0,
                                 0,
                                 0.14634726592000002,
                                 0,
                                 0,
                                 0,
                                 0.55326718191652768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27423162127878098,
                                 -0.48340803947705424,
                                 0,
                                 -0.034367726308253868,
                                 0,
                                 0.11019149057029667,
                                 0,
                                 0,
                                 -0.62964996399235329,
                                 0,
                                 -0.10218150695683278,
                                 0,
                                 0,
                                 0,
                                 -0.13483705067467555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26207243419791793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13241566912754923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36411330460330155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.093049229422519128,
                                 0,
                                 0,
                                 0,
                                 -0.11402174496788083,
                                 0,
                                 0,
                                 -0.094373714382674667,
                                 0,
                                 0,
                                 0,
                                 0.057873380113744211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14401696662193283,
                                 0,
                                 0,
                                 0,
                                 -0.11153978865377057,
                                 0,
                                 0,
                                 0,
                                 0.66990958800576317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1294744823527057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061378582106857565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.199108072636968,
                                 0,
                                 0,
                                 0.94795278422277585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53843399217595711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20309158363864532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83843563374167973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41438625026774556,
                                 0,
                                 -0.24685036053020415,
                                 0,
                                 0,
                                 -0.5673766917800257,
                                 -0.19653562739752004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1635147007097193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34372183997536637,
                                 0,
                                 0,
                                 0,
                                 -0.49872366995910972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073058762267036864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088527298341152624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0049645730996863355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1443318970200185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1437583267402936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13053291336529049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15886580703630804,
                                 0.60789434401796494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15827496071646413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4120527840496056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06350939641882733,
                                 0,
                                 0,
                                 0,
                                 -0.11571935689176879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043549871094841916,
                                 0,
                                 0,
                                 0,
                                 0.53495879829470405,
                                 0,
                                 0,
                                 0,
                                 0.21528759188217389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13112531897363638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25712504868600156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34668100132591695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19520410332546359,
                                 0,
                                 -0.34506981573218071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21645069836073752,
                                 0.046307739786440011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49599434399748132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20701142598602618,
                                 0,
                                 0.060766635694103122,
                                 -0.60037231641658473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96235090081922792,
                                 0,
                                 0.1945018871942632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31363269578071085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28349083057747437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81752609347420413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26385693884694278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049803640202167675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27877882755633532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86199340629520482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077464639070748159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10298665179431213,
                                 0,
                                 0,
                                 0,
                                 -0.39125764321995482,
                                 0,
                                 0.22447594609844523,
                                 0.050238495503443378,
                                 0,
                                 0,
                                 -0.88932512548224374,
                                 0,
                                 0,
                                 0,
                                 0.16814830734625305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24212157452452648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67053739935723755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1906233853366818,
                                 0,
                                 -0.14433291063541959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33064796690347786,
                                 -0.2247058790846406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71442618904261834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34267107041378797,
                                 0,
                                 0.16830040890450654,
                                 0.53179873827846158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16184626172157232,
                                 0,
                                 -0.22705497320811488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11727552696776335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33527829454121993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0034411930873661789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45068910928688433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40207395086309594,
                                 0,
                                 -0.18384022897767335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14709986996500565,
                                 -0.12345535970372462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087003525029819312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22425521500375981,
                                 0,
                                 -0.74724098340228218,
                                 0.089650280937219121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5929021121138629,
                                 0,
                                 0.80967897417145429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45116778063894036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39675033919273728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0010218315157271996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49272904923269234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1133829169491378,
                                 0.32344413737721778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48335160830617069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25612232764765358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18012318118525833,
                                 0,
                                 0,
                                 0,
                                 0.31268204783549325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.079584434067134766,
                                 0,
                                 0,
                                 0,
                                 0.10982178322918382,
                                 0,
                                 0,
                                 0,
                                 -0.18573653050848141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1323125216367918,
                                 0,
                                 0,
                                 0,
                                 -0.33867285127867658,
                                 0,
                                 0,
                                 0,
                                 -0.072889169630784151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34351040173554748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.556509965724167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54007563707766526,
                                 0,
                                 0,
                                 0.85102878517745106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.093998221792646386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90689547748481758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89135477791897433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10044268734721711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0260252849408042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81371834249261588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28472659871413436,
                                 0,
                                 0,
                                 0.37966401592461307,
                                 0,
                                 0,
                                 0,
                                 -0.3985493071797101,
                                 0,
                                 -0.067878053082397569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37899363939671549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18360514432467956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24412156522350253,
                                 0.99293694731962023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2043861786884988,
                                 0,
                                 0,
                                 0.26504431328859868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88224727627458144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5318690107607088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22323654370879706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23590634486565532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017509041055781521,
                                 0.26683963484837497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31759102645827875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027863817167859517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32181267780881662,
                                 0,
                                 0,
                                 0,
                                 0.27328375834349228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051866745482034154,
                                 0,
                                 0,
                                 0,
                                 -0.50687447604563785,
                                 0,
                                 0,
                                 0,
                                 0.024885373867904723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039608387752300411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54347925141809272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040175003340590376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12038107450503438,
                                 0,
                                 -0.077568403066950814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16018861427664813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76911101665616932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25248136498596074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18861781143306725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57550844777969012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3712742789098703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23947468326676835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090527000352702031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21179924699883934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2692634126568218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36389081670312795,
                                 0,
                                 0,
                                 0,
                                 0.38091360933826074,
                                 0,
                                 0.78760083775035095,
                                 0.90200275244868666,
                                 0,
                                 0,
                                 0.1071734411733862,
                                 0,
                                 0,
                                 0,
                                 0.86706934174358219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50462935802762021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15906597287638019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28780837985790708,
                                 0,
                                 0.41508512086079652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0074884770938068446,
                                 -0.12489301293110619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38410113776689597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25818264215886572,
                                 0,
                                 0.14973333841178896,
                                 -0.73429258073792081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25330262895952488,
                                 0,
                                 -0.27844786106541269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058915900513561707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36122710207451253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22848680970388974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16769918713939974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4490726203293996,
                                 0.32136826656721057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036013127352845425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11689401060557103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5001149991903977,
                                 0,
                                 0,
                                 0,
                                 0.050665777035750564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36195101793992812,
                                 0,
                                 0,
                                 0,
                                 0.15063278046615639,
                                 0,
                                 0,
                                 0,
                                 -0.25079871947698157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020324811937744686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012265397936232741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60408063368096987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46833093035177087,
                                 0,
                                 -0.13088550936676144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33141440310850462,
                                 0.69366634945171435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3681455641630948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78204580664437273,
                                 0,
                                 0.49605903151718561,
                                 0.24829536462165971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52983169906258887,
                                 0,
                                 0.4233132058406851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24881087652359027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2413590106306055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19782467591674507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0031148646311139755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35836623896930764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96579056937401409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19620578660101717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053200083001405399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.015793236566167,
                                 0,
                                 0,
                                 0,
                                 -0.10356035048405114,
                                 0,
                                 0.39703667154751127,
                                 -0.47581917501147591,
                                 0,
                                 0,
                                 0.025948509529248334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32105742216909056,
                                 0,
                                 -0.016403964067294101,
                                 0,
                                 0,
                                 -0.10830562607013204,
                                 -0.50059562563487459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23846050850857226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072051470883726154,
                                 0,
                                 0,
                                 0,
                                 0.087449228947580421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0568867715106956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38784993786672023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64106245974590637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91114489300405954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13069116455040314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26070139781930235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043622622540316999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24830489570840814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09415348766006279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69914310408347746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29763733881596116,
                                 0,
                                 0,
                                 0,
                                 -0.46466511052330628,
                                 0,
                                 0.61005719889554832,
                                 0.33625006904287136,
                                 0,
                                 0,
                                 0.27867165497061941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14708689835430541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50559298512429829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0041445185174498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41844477258264778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10743830944017588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76091651794825899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22960075677305272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.061494925586772921,
                                 0,
                                 0,
                                 0,
                                 0.0084588047600457888,
                                 0,
                                 0.13947402167979955,
                                 0.63805100599526599,
                                 0,
                                 0,
                                 0.38961587890046256,
                                 0,
                                 0,
                                 0,
                                 -0.057129624657479949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42569063376667021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20918759336916368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8078178234396497,
                                 0,
                                 0.44282446595436353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0050578149050817429,
                                 -0.027748156516142614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0155528819816372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31504769165894519,
                                 0,
                                 -0.56608964690846908,
                                 0.42312849271315484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39748070445137257,
                                 0,
                                 0.21887883742084352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023339790150976279,
                                 0,
                                 0,
                                 0.41828518646230706,
                                 0,
                                 0,
                                 0,
                                 -0.45379112457774018,
                                 0,
                                 0,
                                 0,
                                 -0.45149416449525992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31646303953238447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9107318125021564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.553944868853398,
                                 0,
                                 0,
                                 -0.091472944707721174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.9671907006136975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5691554596522852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28450165073334233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17257509017206227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12780087439967291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0022231726318070119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61895337523593519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37160598338166512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00070844691493665568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95786708875705373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23179814678148497,
                                 0,
                                 0,
                                 0,
                                 -0.4478672870385384,
                                 0,
                                 0.55199681372137621,
                                 -0.43340505884431507,
                                 0,
                                 0,
                                 0.039592228616288777};

const double rot_2_30[900] = {0.26062299757653773,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.96544065231075704,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.35423524808949269,
                              0,
                              -0.28077775815426198,
                              0,
                              0,
                              0,
                              0.88604632166581343,
                              0,
                              0,
                              0.29234630128273531,
                              0,
                              0,
                              0.18435048402522122,
                              0,
                              0,
                              0,
                              0,
                              -0.47090133280174939,
                              0.79361243540581505,
                              0,
                              0,
                              0,
                              0,
                              -0.26886899784755047,
                              0.41945793261489828,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.60658329183894799,
                              0,
                              0,
                              0,
                              -0.81188739041244795,
                              0,
                              0,
                              0,
                              0,
                              -0.75098209555971662,
                              0,
                              0,
                              0,
                              0,
                              0.34936871800468172,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.79749494201250082,
                              0,
                              0,
                              0,
                              0.17545164296316923,
                              0,
                              -0.68586627762940078,
                              0,
                              0,
                              0,
                              -0.27361688841099696,
                              0,
                              0,
                              -0.06858419840925381,
                              0,
                              0,
                              0.57255674036777682,
                              0,
                              0,
                              0,
                              0,
                              0.64968720756024423,
                              0.54853649287118866,
                              0,
                              0,
                              0,
                              0,
                              -0.067786715222545799,
                              0.66700039457312732,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.36391563316296305,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.36061687522348851,
                              0,
                              0,
                              0,
                              0,
                              -0.46721711542190314,
                              0,
                              0,
                              0.7205754979878809,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.50128118752078166,
                              0,
                              0,
                              0,
                              -0.1753897086018244,
                              0,
                              0,
                              0,
                              0,
                              -0.22565977640262042,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.17502386040897891,
                              0,
                              0,
                              0,
                              0,
                              -0.7341885125664438,
                              0,
                              0.27813919529761733,
                              0.14144168696134016,
                              0,
                              0,
                              -1.1639643180135606,
                              0,
                              0,
                              0,
                              0.26140304647548707,
                              0,
                              0,
                              0,
                              0,
                              -0.58916306507495497,
                              0,
                              0,
                              0,
                              0,
                              -0.62061621823657642,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.088366438159217769,
                              0,
                              0,
                              0,
                              0.75121896272784816,
                              0,
                              -0.083215636441067817,
                              0,
                              0,
                              0,
                              -0.19680918646247642,
                              0,
                              0,
                              0.73430832738416285,
                              0,
                              0,
                              -0.24855121888154741,
                              0,
                              0,
                              0,
                              0,
                              -0.048669612998846444,
                              -0.73423668684210308,
                              0,
                              0,
                              0,
                              0,
                              0.75872081189038465,
                              0.1214185449541836,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.42771773593401013,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.83545608302729946,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.0799385520881508,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.37547440664544751,
                              0,
                              0,
                              0,
                              -0.59897862991104189,
                              0,
                              0,
                              0,
                              0,
                              -0.31915939573410851,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.17696447530467571,
                              0,
                              0,
                              0,
                              0,
                              0.0064452596682912644,
                              0,
                              0.39986863646925969,
                              -0.45511312621693401,
                              0,
                              -0.034934525401051464,
                              0,
                              -0.40759671036432094,
                              0,
                              0,
                              0,
                              -0.28316835234197041,
                              0,
                              0,
                              0.47645954686366054,
                              0,
                              0,
                              -0.78134501414227553,
                              0,
                              0,
                              0,
                              0,
                              -0.14522341133246439,
                              -0.35927818768264097,
                              0,
                              0,
                              0,
                              0,
                              -0.52474442316504455,
                              0.28013526057271587,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.0070033602118309,
                              0,
                              0,
                              0,
                              1.5485642582144634,
                              0,
                              0,
                              0,
                              0,
                              -0.23651485677407894,
                              0,
                              0,
                              0,
                              0,
                              -0.045247960378913321,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.21163298478836207,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.0018952486205603032,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.78731520090590279,
                              0,
                              0,
                              0,
                              0,
                              0.61651157750657981,
                              0,
                              0,
                              0.0066826084364366989,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.20635074313294194,
                              0,
                              1.0466725705363784,
                              0,
                              0,
                              0,
                              -0.057271990221188396,
                              0,
                              0,
                              0.27728309155465147,
                              0,
                              0,
                              -0.47815296165118204,
                              0,
                              0,
                              0,
                              0,
                              0.13910369257001745,
                              0.50107040779368617,
                              0,
                              0,
                              0,
                              0,
                              0.16570870852645192,
                              0.31230256199358591,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.58289576963799328,
                              0,
                              0,
                              0,
                              0.38419130121636369,
                              0,
                              0,
                              0,
                              0,
                              -0.3165991536402315,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.57891613970052791,
                              0,
                              0,
                              0,
                              0,
                              -0.1585233958762633,
                              0,
                              0.18557271778915993,
                              0.13298024021923696,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.2444848628872653,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.58918316061332809,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.86788622598102072,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.052878622868016784,
                              0,
                              0,
                              0,
                              0.47195330265035562,
                              0,
                              0,
                              0,
                              0,
                              0.82058902428075131,
                              0,
                              0,
                              0,
                              0,
                              0.49665214930863355,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.69732180391528931,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.79617583144504844,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.13019765981287348,
                              0,
                              0,
                              0,
                              0,
                              0.15764842621947173,
                              0,
                              0,
                              0.56947307970839067,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.31986267336704621,
                              0,
                              0.24915290160169451,
                              0,
                              0,
                              0,
                              -0.38325474018231187,
                              0,
                              0,
                              0.86515470225305846,
                              0,
                              0,
                              0.53749399971950229,
                              0,
                              0,
                              0,
                              0,
                              0.078036171172988153,
                              -0.10740161067146287,
                              0,
                              0,
                              0,
                              0,
                              -0.52657571001544523,
                              -0.39767220190562658,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.14808003830285302,
                              0,
                              -0.30068807007495313,
                              0,
                              0,
                              0,
                              -1.0423523424961036,
                              0,
                              0,
                              -0.3574009814575646,
                              0,
                              0,
                              0.74444649364819415,
                              0,
                              0,
                              0,
                              0,
                              -0.8026439501239796,
                              0.31611835433141067,
                              0,
                              0,
                              0,
                              0,
                              0.0029103990440954852,
                              0.088052146204522119,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.48338997237742903,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.48284450199396323,
                              0,
                              0,
                              0,
                              0,
                              0.61381480559506574,
                              0,
                              0,
                              0.3955081616495944,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.16931346437603029,
                              0,
                              0,
                              0,
                              -0.40650325564567813,
                              0,
                              0,
                              0,
                              0,
                              0.64153583696643568,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.50761045307053931,
                              0,
                              0,
                              0,
                              0,
                              -0.2190923156358805,
                              0,
                              -0.23556027047947159,
                              -0.1826509456661784,
                              0.96544065231075704,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.26062299757653784,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.1131624153763264,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.44849680887362342,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.227377641321306,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.11176437250723731,
                              0,
                              0.43146067253435644,
                              0,
                              0,
                              0,
                              -0.019925316756085276,
                              0,
                              0,
                              -0.20819047071196123,
                              0,
                              0,
                              0.59860490571032776,
                              0,
                              0,
                              0,
                              0,
                              0.11692501470876621,
                              -0.6513600219253739,
                              0,
                              0,
                              0,
                              0,
                              -0.69824198327820286,
                              0.88065247491831178,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.99641955339422161,
                              0,
                              0.157403466103301,
                              0,
                              0,
                              0,
                              0.0048801014307423562,
                              0,
                              0,
                              0.081457559982800937,
                              0,
                              0,
                              0.032066065563420287,
                              0,
                              0,
                              0,
                              0,
                              0.31549975168957289,
                              0.6242606412350683,
                              0,
                              0,
                              0,
                              0,
                              -0.75441253338787129,
                              -0.67944405110989048,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.33151673092169387,
                              0,
                              0,
                              0,
                              0.099784824727397844,
                              0,
                              0,
                              0,
                              0,
                              0.51074350915017142,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.43013389838966914,
                              0,
                              0,
                              0,
                              0,
                              -0.25607476758438136,
                              0,
                              0.4811544328237205,
                              0.37038043734868697,
                              0,
                              0,
                              -0.74331246480589552,
                              0,
                              0,
                              0,
                              0.74933395402832792,
                              0,
                              0,
                              0,
                              0,
                              -0.69918702657778065,
                              0,
                              0,
                              0,
                              0,
                              0.6279423822594431,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.61586877676888341,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.24823341098750129,
                              0,
                              0,
                              0,
                              0.27599065765047903,
                              0,
                              0,
                              0,
                              0,
                              -0.07334612212951841,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.38084456017164581,
                              0,
                              0,
                              0,
                              0,
                              -0.56431529411835957,
                              0,
                              -0.48718289304282064,
                              -0.39495338391487328,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.26034293595107588,
                              0,
                              0,
                              0,
                              -0.45987753140306653,
                              0,
                              0,
                              0,
                              0,
                              -0.26300780494151349,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.12320797189797567,
                              0,
                              0,
                              0,
                              0,
                              -0.061388427762572209,
                              0,
                              -0.45162044627308645,
                              0.65471469775517521};

const double rot_2_2[4] = {0.72137260749413434, 0.69254715446467152, -0.69254715446467152, 0.72137260749413412};

const double rot_1_50[2500] = {0.03540565378111786,
                               0.33704638302909085,
                               0,
                               0.19550718957508173,
                               0,
                               0,
                               0,
                               0,
                               -0.54552645778216058,
                               0,
                               0,
                               0,
                               -0.02228251696325587,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0266602460688503,
                               0,
                               0,
                               0,
                               -0.26546000192270847,
                               0,
                               0,
                               0,
                               0,
                               0.73191757173666894,
                               0,
                               0,
                               0,
                               -0.068798178788404787,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12622255564222043,
                               0,
                               0.76350135390403617,
                               -0.18889878648440458,
                               0,
                               0.60268880857255447,
                               0,
                               0,
                               0,
                               0,
                               -0.023131163922498098,
                               0,
                               0,
                               0,
                               0.75736133896596891,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.26598337340029032,
                               0,
                               0,
                               0,
                               -0.38085102131255744,
                               0,
                               0,
                               0,
                               0,
                               -0.10095032692245152,
                               0,
                               0,
                               0,
                               -0.37169366959875899,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.54215157079573739,
                               0,
                               0,
                               0,
                               -0.52930442929857147,
                               0,
                               0,
                               0,
                               -0.09210351153043117,
                               0,
                               0,
                               0.47520180172913706,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29163304681458052,
                               0,
                               0,
                               -0.33920819746375369,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41405966755306045,
                               0,
                               0,
                               0,
                               0,
                               0.33605541770690994,
                               0.032346941691270115,
                               0,
                               0,
                               0,
                               0.58198331138559301,
                               -1.1317384831639254,
                               0,
                               -0.092150209389062709,
                               0,
                               0,
                               0,
                               0,
                               -0.43097922493883267,
                               0,
                               0,
                               0,
                               -0.20836229712367677,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.59195720658281648,
                               0,
                               0,
                               0,
                               -0.15723387650115958,
                               0,
                               0,
                               0,
                               0,
                               0.43423273685651109,
                               0,
                               0,
                               0,
                               0.48547011699994763,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11107272231916385,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.052283531812817668,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.60334432129574256,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13717368992128914,
                               -0.34053676682062761,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.64224081412490608,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29323520963599697,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.2917933427132116,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.66780104968065135,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51588294421596159,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.043424724869489811,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14073794621008232,
                               0,
                               0,
                               0,
                               -0.17685323063434483,
                               0,
                               0,
                               -0.34290116830756595,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.34359766757309917,
                               0,
                               0,
                               -0.43341900708541831,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.48518322968988314,
                               0,
                               0,
                               0,
                               0,
                               -0.50413883822722894,
                               -0.18937905543665001,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.070303774031405628,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.047273920934714886,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.88512566996766417,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21890244877363763,
                               0,
                               0,
                               0,
                               -0.40181690113980739,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26432295167405667,
                               -0.5172078885466902,
                               0,
                               0.34275045242262242,
                               0,
                               0,
                               0,
                               0,
                               0.78180182440213186,
                               0,
                               0,
                               0,
                               -0.44832956851084443,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36658616585333542,
                               0,
                               0,
                               0,
                               0.148201181055373,
                               0,
                               0,
                               0,
                               0,
                               0.15201465761498834,
                               0,
                               0,
                               0,
                               -0.50590121015972689,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37906040411484798,
                               0,
                               0,
                               0,
                               0.37862966642131524,
                               0,
                               0,
                               0,
                               -0.60046073503656139,
                               0,
                               0,
                               0.025226684654730956,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51069276121160745,
                               0,
                               0,
                               -0.18057222288322344,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0093949528073059563,
                               0,
                               0,
                               0,
                               0,
                               -0.25347480753461382,
                               0.37107806259935716,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12796161471761344,
                               -0.37098144776219505,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.74152233851095284,
                               0.090318196635332554,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22922317654472985,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17056152594471943,
                               0,
                               -0.2608703838378188,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.69372275189245869,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.42557618399733788,
                               0.65676622967927889,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41468171642568763,
                               0.43588098953945031,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11502134398970508,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10102314434768044,
                               0,
                               0.39766115511429634,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13523202504366269,
                               0,
                               0,
                               -0.17501685470899375,
                               0.067953087953894126,
                               0,
                               -0.11565078049360493,
                               0,
                               0,
                               0,
                               0,
                               0.0015788655209593438,
                               0,
                               0,
                               0,
                               0.40193858743244204,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.38043856344098698,
                               0,
                               0,
                               0,
                               1.1301515254091703,
                               0,
                               0,
                               0,
                               0,
                               0.24208643984515249,
                               0,
                               0,
                               0,
                               0.32253521382073341,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51659421717867327,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.87457668692953572,
                               0,
                               -0.35827661880777972,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.9582286861959044,
                               0,
                               0,
                               0.19468150405891249,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14276144872834506,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.394273640999521,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26404978673865598,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1607281789728967,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0941783630277227,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0012654547288296469,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.58803426024339622,
                               0,
                               0.13975714338962142,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19376193435241668,
                               0,
                               0,
                               -0.74767327480264334,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25449220779348031,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.72076936343238385,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39656347836919237,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34449242252568196,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.85091854983077819,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14024690616721588,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.57422161797257176,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39234901039494718,
                               -0.20526451635728482,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.62187593553918719,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26038316367895553,
                               0.56391629029188306,
                               0.77299167675090297,
                               0,
                               0.3238759449182696,
                               0,
                               0,
                               0,
                               0,
                               0.30515585126704076,
                               0,
                               0,
                               0,
                               -0.42694063726538611,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.63921040416587327,
                               0,
                               0,
                               0,
                               -0.19801456225586078,
                               0,
                               0,
                               0,
                               0,
                               0.24962425700353447,
                               0,
                               0,
                               0,
                               0.53796625100697737,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33033897900816195,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.49954974752614195,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.60233652535781013,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16165857583170909,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58857826331777185,
                               0,
                               0,
                               0,
                               0.12281242924210695,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.018971752199252123,
                               0,
                               0,
                               0,
                               -0.56449321798761254,
                               0,
                               0,
                               -0.12187011347668988,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.093409135737653456,
                               0,
                               0,
                               0.20649494876129171,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.061812829752164816,
                               0,
                               0,
                               0,
                               0,
                               0.26214745910913867,
                               -0.7363610582880673,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1753843072597816,
                               0,
                               0.82887590210051043,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.38573938912057321,
                               0,
                               0,
                               0.056685024870890666,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29326057033306097,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10761005236432497,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.62701212301249987,
                               -0.023548815422501486,
                               0,
                               -0.6577787576390145,
                               0,
                               0,
                               0,
                               0,
                               0.11477150893348864,
                               0,
                               0,
                               0,
                               0.23948511307102963,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14428943538139041,
                               0,
                               0,
                               0,
                               -0.50791611975105388,
                               0,
                               0,
                               0,
                               0,
                               0.47317014402522445,
                               0,
                               0,
                               0,
                               0.04656654966001058,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35544408553216905,
                               0,
                               0,
                               0,
                               0.19056345915705725,
                               0,
                               0,
                               0,
                               0.30512039172382099,
                               0,
                               0,
                               -0.51575676014251304,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44575474322526898,
                               0,
                               0,
                               0.1994192025693737,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.55245139183240455,
                               0,
                               0,
                               0,
                               0,
                               0.24680757114468926,
                               0.00050197864838627537,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.75631502982019905,
                               0,
                               0.19151997343797195,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13928830897691508,
                               0,
                               0,
                               -0.55310743406115126,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1579210152329074,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11305943897046181,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.99391706417668801,
                               0.65639864117241264,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1983856239767727,
                               -0.38530164555863444,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57898131191404145,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.45081851323745054,
                               0,
                               0.19475193712572059,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11623940508941627,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.45396511885829971,
                               0.058076979840033953,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57486989375830588,
                               -0.11555327430049346,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.020259324430710997,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29670210073094122,
                               0,
                               0.98135325663016693,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.67315901278981272,
                               0,
                               0,
                               -0.41201567791973137,
                               0.034536986520170676,
                               0,
                               -0.0066896859837071998,
                               0,
                               0,
                               0,
                               0,
                               0.53054958521262474,
                               0,
                               0,
                               0,
                               0.23754824997410873,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36860150160607147,
                               0,
                               0,
                               0,
                               -0.13177805062020581,
                               0,
                               0,
                               0,
                               0,
                               -0.22045059183735594,
                               0,
                               0,
                               0,
                               1.3034435795069321,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29533629227501185,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.26569589304778518,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.06728046484351291,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3616579506566221,
                               -0.68930797479719397,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41936988565591166,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37824062854322049,
                               0,
                               0,
                               0,
                               0,
                               -0.85222337363168688,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17356956449982522,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46356603573953692,
                               -0.1385654529967846,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.025158304206407786,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.094138903696358078,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1781526997476223,
                               0,
                               0.46506272408243515,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.60216515269821813,
                               0,
                               0,
                               -0.84839648034227855,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12608855975923272,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.68091180104818472,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12562609680094386,
                               0.27665166516863687,
                               0,
                               -0.40388633054063883,
                               0,
                               0,
                               0,
                               0,
                               -0.3959616952122208,
                               0,
                               0,
                               0,
                               -0.30960669917251282,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37050155153874698,
                               0,
                               0,
                               0,
                               -0.16528901839358126,
                               0,
                               0,
                               0,
                               0,
                               -0.60130383764220352,
                               0,
                               0,
                               0,
                               0.64158635689744892,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.72232033947259811,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.125023095423552,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16240284560926505,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.43208747455883995,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32396264568329103,
                               0,
                               0,
                               0,
                               0.81629845024964554,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.68219923715211483,
                               -0.16820634731215534,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23787820597218334,
                               0.85323054917902252,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54674281953205384,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3413645040946191,
                               0,
                               0.23207347862331262,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.05837297287585308,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40339464585499829,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.76723977526309617,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.49861396585911388,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.07430521334032586,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21409834136590095,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25530821636708034,
                               0.47377199113661533,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14853016337052327,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.79808348005321517,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29666673845032587,
                               0,
                               -0.84837809303188416,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37643185031443682,
                               0,
                               0,
                               -0.75403322436631925,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.67810372579933509,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10630674333766056,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17277125368399204,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2852728717673923,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.4702066384975601,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.71284771076135112,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.020536078884944124,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.67205894792049237,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.045635191046088201,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.64112571240887672,
                               0,
                               0,
                               0,
                               0.36713797162705675,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37000921363327233,
                               -0.14741665167430168,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28372841241935076,
                               -0.52118013668008079,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.85557142217641491,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.34883468715142618,
                               0,
                               0.30171431061797849,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.042098655879732619,
                               0,
                               0,
                               0,
                               0,
                               0.11574721903333242,
                               0,
                               0,
                               0,
                               -0.33281670786327211,
                               0,
                               0,
                               0.2168859684384529,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.45696926767842827,
                               0,
                               0,
                               0.53843047223490537,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46761298488048797,
                               0,
                               0,
                               0,
                               0,
                               0.1182504096117788,
                               0.31212617466620762,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11317461845036814,
                               -0.33941066837351519,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0546335019126456,
                               -0.063313420633158257,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25157261051547963,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38129229209259241,
                               0,
                               0.23522565380703706,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67309686005973235,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.85408133346786885,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39612873270863913,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.040458582425836297,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29943842599244574,
                               0,
                               0,
                               0,
                               -0.14942166874871987,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.614771174683308,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49883900317547758,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.2054323458516637,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.6278793509624656,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.82462728994331003,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54098807572498364,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16529287523705333,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.69604445493524847,
                               0,
                               0,
                               0,
                               -0.21487758859676412,
                               0,
                               0,
                               -0.45458184264641327,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.098069334520321211,
                               0,
                               0,
                               0.28814948710940341,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21646626120511964,
                               0,
                               0,
                               0,
                               0,
                               -0.072980552563736312,
                               0.34332719441026421,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14872648055976528,
                               0,
                               0,
                               0,
                               0.17605793916633439,
                               0,
                               0,
                               0.34845963270829816,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3319979650045109,
                               0,
                               0,
                               0.45731143963785131,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13609058772302479,
                               0,
                               0,
                               0,
                               0,
                               -0.64785547929182852,
                               -0.26051132164184665,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19978570328793088,
                               -0.47111394195988887,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0065954582886910001,
                               0.096338967891649585,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.023106345051478325,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.85732483781420388,
                               0,
                               0.43949127785359293,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27165361959292039,
                               0,
                               0,
                               -0.57675600275488126,
                               0.36895330827621919,
                               0,
                               0.90771246432293096,
                               0,
                               0,
                               0,
                               0,
                               -0.51998413586217818,
                               0,
                               0,
                               0,
                               -0.11666439982157065,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32180744701497899,
                               0,
                               0,
                               0,
                               0.074411615826292632,
                               0,
                               0,
                               0,
                               0,
                               -0.12568822954771519,
                               0,
                               0,
                               0,
                               -0.20465760753711376,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39786431579197323,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41856539122999309,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.47513577950654734,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.6452700246614006,
                               -0.3508495693302161,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.04724200221169278,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23947520226214863};

const double rot_1_20[400] = {1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.32086435622667026,
                              0,
                              0,
                              0,
                              0,
                              -1.0660538213398671,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.93701787318378438,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.63821033834832064,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.26883888388221872,
                              0,
                              0.72139671370077996,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.13412817248518452,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.29225174652473573,
                              0,
                              0,
                              0.66249255975156762,
                              0,
                              0,
                              -0.67653688611401086,
                              0,
                              0,
                              0.79077682113332415,
                              0,
                              0,
                              0,
                              0,
                              0.97155841526795128,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.027311249731451603,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.80750740500737161,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.51300605965741175,
                              0,
                              0,
                              -0.11801689439123086,
                              0,
                              0,
                              0.26613640534748928,
                              0,
                              0,
                              -1.29907785612312,
                              0,
                              0,
                              0,
                              0,
                              1.0409581496198352,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.0112733601125523,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.51640277250531152,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.63617332504897006,
                              0,
                              0,
                              -0.31380590633596189,
                              0,
                              0,
                              -0.47972651604182992,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.6261122872290622,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.36399185016822011,
                              0,
                              0.68956024884842937,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.25153449217328144,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.49668621875803709,
                              0,
                              0,
                              -0.66985182993011994,
                              0,
                              0,
                              -0.49125525471209258,
                              0,
                              0,
                              0,
                              -0.44796313219517758,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.89175982614383276,
                              0,
                              0.063980033368287156};

const double rot_1_10[100] = {0.14706067109255289,
                              0,
                              0,
                              0,
                              0,
                              0.72108895223116487,
                              0,
                              0,
                              0,
                              0.67705530201599484,
                              0,
                              0.072941502719915285,
                              0,
                              0.2092150871412958,
                              0.62061855531072463,
                              0,
                              0.75215769177576675,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.5496811871885281,
                              0,
                              0,
                              0,
                              0,
                              -0.81229197100396366,
                              0.060250467086048698,
                              0,
                              0,
                              0.078901263307616931,
                              0,
                              -0.97435640105158472,
                              0.086088842787621078,
                              0,
                              0.19233539852495646,
                              0,
                              0,
                              0,
                              0,
                              -0.73324450973659616,
                              0,
                              -0.0086107411514143029,
                              -0.48652561771558123,
                              0,
                              0.4749433307084483,
                              0,
                              0,
                              0,
                              0.63630161012185094,
                              0,
                              0,
                              0,
                              0,
                              -0.59303080782382001,
                              0,
                              0,
                              0,
                              0.49339104362378627,
                              0,
                              -0.67142134071725867,
                              0,
                              -0.082368113849273727,
                              0.60886299218953166,
                              0,
                              -0.41436063253205141,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.62341758268453229,
                              0,
                              0,
                              0,
                              0,
                              0.76203276049238078,
                              -0.37312504578122746,
                              0,
                              0,
                              0,
                              -0.82018395711782821,
                              0,
                              0,
                              0,
                              0,
                              0.031720405222993742,
                              1.1677931426505948,
                              0,
                              0.75729348338286129,
                              0,
                              0,
                              0,
                              0,
                              0.35825296082794383,
                              0,
                              0,
                              0,
                              -0.54604156992289632};

const double rot_1_100[10000] = {-0.41783071606993155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4903028656751971,
                                 0.061484691138583833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48293833281720799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33255634182326116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78046288079258863,
                                 -0.91908292109930978,
                                 0.01169028648622273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83000306711918481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55792735590272091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45774516711055108,
                                 0,
                                 0,
                                 0,
                                 -0.61361234416938992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18528031965282099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23864522833767257,
                                 0,
                                 0.51120178432356422,
                                 -0.3001314688892841,
                                 0,
                                 0,
                                 0,
                                 0.60805944646648247,
                                 -0.51575347384011849,
                                 0,
                                 -0.27592347935657036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017093613107987349,
                                 0,
                                 0.20229930805937252,
                                 0.18181572776237101,
                                 0,
                                 0,
                                 0.58501080156574936,
                                 0,
                                 0,
                                 0,
                                 0.41926957703391282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19136518927192728,
                                 0,
                                 -0.0263323842092823,
                                 0.046473387498264893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39675213373679352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040307665410410261,
                                 0.12222072706196045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12752536583699586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50225888681581232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041279801943825994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06620360129628855,
                                 0,
                                 0,
                                 0.0079173331687278914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58616131373989111,
                                 0.20733747958696638,
                                 0,
                                 0,
                                 0,
                                 0.18337233557028512,
                                 0.12887189170783772,
                                 0,
                                 0,
                                 -0.38259712994929984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78819239554414933,
                                 -0.030733802123444343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50446643004965375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48220241710524703,
                                 0.36518016660504027,
                                 0,
                                 0,
                                 -0.17024974781421831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21885252905724151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00026435609503860924,
                                 0,
                                 -0.21312863691817857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38408861998743399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48856710002125209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34745793038035289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61272309774746259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1558884140724717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019902705881653646,
                                 0,
                                 0,
                                 0,
                                 0.032703405725579671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3306627033877555,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82050121348405425,
                                 0,
                                 0.52345099961376518,
                                 0.52596584913322408,
                                 0,
                                 0,
                                 0,
                                 0.24256274162126942,
                                 0.21358951924103953,
                                 0,
                                 0.019574804055003101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44334123008163318,
                                 0,
                                 0.43058473485940685,
                                 -0.8700080216203413,
                                 0,
                                 0,
                                 -0.19536137977268772,
                                 0,
                                 0,
                                 0,
                                 -0.48762277124728248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17113149827591173,
                                 0,
                                 -0.12622055711959818,
                                 0.59615005221578232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022264703114533074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056476739495531246,
                                 -0.15289711906097492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071767963771029258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53965910722047683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43523958973949284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0016186740189862645,
                                 0,
                                 0,
                                 0.34993311864139209,
                                 0,
                                 0.53187058136240917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092848292451881045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13908701159450393,
                                 -0.13425031809606286,
                                 0,
                                 0,
                                 0,
                                 0.2217353406421913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028470980894945652,
                                 0,
                                 0,
                                 0,
                                 -0.13229301349173275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49972573061848463,
                                 0,
                                 0.20501419745665689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43323966051557999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0070585375379902896,
                                 0.2414426853046385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24270790102307399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089352457066210395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090210509284519388,
                                 -0.063069450593067067,
                                 -0.40850253364251854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68963885409353065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90641152919090817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27466509720233989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27630703664206602,
                                 0.12647050696811557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018090774463880334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78870565308342089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35824597641518863,
                                 0.078757673642819243,
                                 0.76560116246998866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45582478703325452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17740030298161513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10758547532418347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62251896000310014,
                                 0,
                                 0,
                                 1.0010922270275908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66588783467167201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17134474549158885,
                                 -0.59614870927056995,
                                 0,
                                 0,
                                 0,
                                 0.37970864064079701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37065980800330378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42815717433047257,
                                 0,
                                 0.17617558680750867,
                                 0,
                                 0,
                                 -0.37430528430205201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051396953783100573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074950344687699733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13297585465898759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0022367947557235365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3219606144079874,
                                 -0.043262932706924058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45518431606285031,
                                 0,
                                 0,
                                 0,
                                 -0.0054312405500773261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29116746810167499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26645480959372514,
                                 -0.38866840629207106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21413724990816146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4484075066639539,
                                 0,
                                 0,
                                 -0.10004192103306769,
                                 0,
                                 0.25362127573430299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0035680601459888994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54743104211916294,
                                 0.42754144789142995,
                                 0,
                                 0,
                                 0,
                                 0.26084717926785034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019349717926897977,
                                 0,
                                 0,
                                 0,
                                 0.15478471973900124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046332933341546256,
                                 0,
                                 0.31896383715647125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28715378229847444,
                                 0,
                                 -0.068552812153115789,
                                 0,
                                 0,
                                 0.095723777216653025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26837321178168733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13612043866611562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67614182422743629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1211390902575869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095424538284829011,
                                 0.19873614400939352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37171205316598777,
                                 0,
                                 0,
                                 0,
                                 -0.21814211758884661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11955804577940191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26337471285451247,
                                 0.15253418761327409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34126843059501266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59289417684055301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16227636577035986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65049242412335706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63327149024309781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039245270464871293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30255916743192496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3209538431160886,
                                 0,
                                 0,
                                 0.20648105301342615,
                                 0,
                                 -0.41451820315721832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1444029592765935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1919332232678469,
                                 0.10461521827761325,
                                 0,
                                 0,
                                 0,
                                 0.4555456371209553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32067848343969851,
                                 0,
                                 0,
                                 0,
                                 0.067772796433125684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16970478441079556,
                                 0,
                                 0.42261390301692014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.369252270217518,
                                 0,
                                 -0.15259881183314991,
                                 0,
                                 0,
                                 0.63569630524775866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1510920641842137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11715589931492715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090621052769099139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36560302142271361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12672403779009195,
                                 -0.3073808887417861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11590407863801637,
                                 0,
                                 0,
                                 0,
                                 0.24537451368811009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09639962276118566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20938884307923633,
                                 -0.14319055546320708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64665994833166129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024387731700974361,
                                 0,
                                 0,
                                 0.079475462369722472,
                                 0,
                                 0.50495411838888304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07718904629987465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39799031464056833,
                                 -0.10500033090500488,
                                 0,
                                 0,
                                 0,
                                 0.073080668767656246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23270185644209618,
                                 0,
                                 0,
                                 0,
                                 -0.11707566515195905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25860088225185196,
                                 0,
                                 0.067004210699939698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1489892457387354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31895486596287886,
                                 1.0043715698457072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72290790980559505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24101813232449187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62943979828647934,
                                 -0.59607473575686232,
                                 -0.50042661303291469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13108303054597809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66403639772015421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27717818070490241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033814386707678043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41033255627524667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65374075498884976,
                                 0,
                                 0.42340929297170332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38341052743128645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24124408986676499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037820453392055739,
                                 0,
                                 0.17831107789571518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40656469127310541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062180816831994626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44834948534477409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11138715492605297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72525195652677066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40418045531451557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59054769067566337,
                                 0,
                                 0,
                                 -0.29887661649951924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75017566216218978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30229149135522188,
                                 0.39452742492439935,
                                 0,
                                 0,
                                 0,
                                 0.37126273697386236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38370852243811021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24450859657975946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20944652075382475,
                                 0,
                                 -0.51655412382155741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61244443983186769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47167814930956387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044592927552893818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095983336151772944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14404770002339234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25636652012327038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23104048069355354,
                                 0,
                                 0,
                                 0.077807424801311892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27552781243372926,
                                 0.70493326658622102,
                                 0,
                                 0,
                                 0,
                                 0.37055141523430812,
                                 0.47983239026579855,
                                 0,
                                 0,
                                 0.10276335093654856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091069819874730493,
                                 0.20716569695509937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31417883902459998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5407360955940016,
                                 0.5277495609309959,
                                 0,
                                 0,
                                 -0.74702867125132422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13656876796560616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50260962418716648,
                                 0,
                                 0,
                                 -0.56399455881722138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51386553771292109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30372510633295502,
                                 -0.31572648060133734,
                                 0,
                                 0,
                                 0,
                                 0.585541690691322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8351095694026236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.252661182557036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021550540965592248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49030630665496644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055678379504980044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21033653403108721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57774646120089324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15281602188259297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18984166199970212,
                                 0,
                                 0,
                                 0.21728764231122266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.072504195268510055,
                                 -0.34519484586972604,
                                 0,
                                 0,
                                 0,
                                 -0.21613473346396153,
                                 0.64785209593715953,
                                 0,
                                 0,
                                 -0.2994714786826792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18174190120770481,
                                 -0.82946206731826622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18854603253705182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40695906810915522,
                                 0.51912493556875239,
                                 0,
                                 0,
                                 0.097487551452327237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067830653482009881,
                                 0,
                                 0.15990027769499038,
                                 0,
                                 0,
                                 0.030645535122135942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1216405039115768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16115919841745679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40144764307603742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49509662654988557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29661430131037836,
                                 -0.10327345784980989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14603857516781313,
                                 0,
                                 0,
                                 0,
                                 -0.070943381579473247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12044598717222513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53326632754601044,
                                 -0.31297968632830842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31680729661145612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3999012481998907,
                                 -0.30400445367138507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13668472723699873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84824384568147826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67793292334785915,
                                 -0.56131977741738481,
                                 0.39345124765618944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24298088116279659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3063998233433694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10173582524941374,
                                 0,
                                 0,
                                 0,
                                 0.14794077557367852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43646082135365105,
                                 0,
                                 0.57348514730490019,
                                 -0.042597493437165498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2880316114699959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030057355460229987,
                                 0.11136091579766744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33998410126103307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48446820646921002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067050471851735585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24590263578257957,
                                 0,
                                 0,
                                 0.12988391123288082,
                                 0,
                                 0.0039502083274032609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3268687962648309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18675905729316417,
                                 -0.10826196661735685,
                                 0,
                                 0,
                                 0,
                                 -0.56484360015407287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11696155156268875,
                                 0,
                                 0,
                                 0,
                                 0.3203025550567391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17791372069225697,
                                 0,
                                 0.54564875933401802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13854980195384961,
                                 0,
                                 0,
                                 0,
                                 0.12118504919812779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33261390919680028,
                                 0,
                                 -0.20661658536663779,
                                 -0.16573418938523909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45116077296266566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25182531473653186,
                                 -0.41478561108232109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56570214815269437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16217223242755172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18649001930139295,
                                 0,
                                 0,
                                 0,
                                 -0.088846940572853667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20002901954900915,
                                 0,
                                 0.50289766724652607,
                                 0.3515653349936978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15829337817902794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46317414031891835,
                                 -0.10093915187731067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47445080445051058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2567732085672082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81847502685648732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26111406339752447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64861064833068593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27048376307749644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013825385015186688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36696366173158529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2253158382296595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75321623212647126,
                                 0,
                                 0,
                                 -0.24955317279646375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29277187106300478,
                                 -0.097881744578167826,
                                 0,
                                 0,
                                 0,
                                 0.38182905987875132,
                                 0.3509140936162185,
                                 0,
                                 0,
                                 -0.095669415155487686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20250209421570006,
                                 0.11196315239048361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71362218176216696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50533056719762437,
                                 0.29583984340281572,
                                 0,
                                 0,
                                 0.43706070688683579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1398385006433005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83488301052590064,
                                 0,
                                 0,
                                 0.020649190526774143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098362873676154344,
                                 0.19140628346435459,
                                 0,
                                 0,
                                 0,
                                 0.29792373381558895,
                                 -0.34669619939267682,
                                 0,
                                 0,
                                 -0.45022435119502585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61275089516305792,
                                 0.10997870648837903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79927302116147148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55803147590506197,
                                 -0.15418237280332001,
                                 0,
                                 0,
                                 0.26328228943740362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60635809230260362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42149497532571234,
                                 0,
                                 0.60031530819904422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00098110553644016607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18963498233457413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057432832442182197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22800088676017041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055209208628154718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27851893699618602,
                                 0,
                                 0,
                                 0,
                                 -0.52301193006289226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26547548820333611,
                                 0,
                                 -0.0236032947854595,
                                 -0.4275563464206793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37961174864307601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10812963789913237,
                                 -0.41317386682095114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23263451408562469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12007657287161122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2070615269236577,
                                 0,
                                 -0.13648995867658048,
                                 0,
                                 0,
                                 0.039922051953197549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32290990641277306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41997815229297764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2466164803161417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12829884746948264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20038741311666139,
                                 -0.44598809612029333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23145630490940639,
                                 0,
                                 0,
                                 0,
                                 0.20641119950472508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2334366765333854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38426346044981019,
                                 0.2039125198711613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77471906664240808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54100857131798563,
                                 0,
                                 0,
                                 0.64254446752973482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22144259042757827,
                                 0.046008660841409532,
                                 0,
                                 0,
                                 0,
                                 0.041973391109807037,
                                 -0.46933564801958477,
                                 0,
                                 0,
                                 0.076677298212278394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27768578189719201,
                                 -0.68475352527345268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39272190227437948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2393437959928231,
                                 0.24377713135108769,
                                 0,
                                 0,
                                 -0.1822439111856709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31667284845526522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24415316182816085,
                                 0,
                                 0,
                                 -0.77453886922125437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79522696237291213,
                                 0.29706864342085793,
                                 0,
                                 0,
                                 0,
                                 -0.85066512490671009,
                                 0.58928618363206497,
                                 0,
                                 0,
                                 -0.11716940471163044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67076093081698551,
                                 0.20885823570820056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25295391896395258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17845268510247497,
                                 0.2089689755588964,
                                 0,
                                 0,
                                 -0.25258904399013193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044993809569026322,
                                 0,
                                 0,
                                 0,
                                 -0.48263457323498055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097986560091324004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31132860840839638,
                                 0,
                                 0.22022963773507129,
                                 -0.30244696945766242,
                                 0,
                                 0,
                                 0,
                                 -1.00283998595681,
                                 -0.28685440627432313,
                                 0,
                                 -0.28976925960696964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38150819513709494,
                                 0,
                                 -0.35261673732152582,
                                 -0.61387739896280258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33535425137004254,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22528511305546367,
                                 0,
                                 -0.10491982042193632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034889904288695248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20671393782618644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79386889121875703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28995338072674542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25986003589163686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13242129575912101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055839808377784322,
                                 0,
                                 0,
                                 0.054437963327123751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4585198981539883,
                                 -0.37271567949811485,
                                 0,
                                 0,
                                 0,
                                 0.6389481962101915,
                                 -0.055454805791594147,
                                 0,
                                 0,
                                 -0.10136183866006512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34322867906541743,
                                 0.63370816814958675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35377292281784073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5195470782160192,
                                 -0.0100921905396592,
                                 0,
                                 0,
                                 -0.23672331893980497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0478445668324821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42862764433093448,
                                 0.56941246374749988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31114206882909418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47380203338284704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40103473271029677,
                                 -0.032127007020617271,
                                 0.087673555609390011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70097817700287457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.093052653901517068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14098176364573259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41280768053767192,
                                 0.31823105490864406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60445799575734094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.001033657984858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48906535524744987,
                                 -0.14094832923552603,
                                 -0.27573308549900227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33634004073330981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27058065772463419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3554898379733597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39108393891106646,
                                 0.18075287526333986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17645089864914859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46921213597363304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38870654280555195,
                                 1.2362904389101752,
                                 -0.49769398546498611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79867655233653645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7349410669342058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20806801521145823,
                                 0,
                                 -0.012266230590915941,
                                 0,
                                 0,
                                 -0.33807124002347266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11329790337770274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54219049130285635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031850791894366119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17439463976194158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034193841438091885,
                                 -0.20714982890814557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11457406616169981,
                                 0,
                                 0,
                                 0,
                                 0.11238594449442504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64303620099916003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038145472392230595,
                                 0.13871355299995641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084579149654587946,
                                 0,
                                 0,
                                 0,
                                 -0.40448299296451062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31387438988479038,
                                 0,
                                 -0.046049095512742111,
                                 -0.11318731308397399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087927358860165977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28412027665221323,
                                 0.73061187004579586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30524030592266854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019234217615592256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35116144194329824,
                                 0,
                                 0,
                                 0,
                                 0.30832853197020138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58783161068317613,
                                 0,
                                 -0.44174308288199149,
                                 0.21117400782470303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39636098287376775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19026351152270687,
                                 0.0031881774993136602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034334685221913845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.043017148272843246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10694729974933913,
                                 0,
                                 0,
                                 0,
                                 -0.27980435820686678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55666544191273359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58704133194775099,
                                 0,
                                 -0.53970301748624228,
                                 -0.8566516241260772,
                                 0,
                                 0,
                                 0,
                                 -0.018744730786642315,
                                 0.79004975434346847,
                                 0,
                                 -0.013972570973145748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23963230286132062,
                                 0,
                                 0.58062814897004444,
                                 -0.051198315389235541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066376836978476295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53187194744269262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13101881795134501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20154768157969183,
                                 0,
                                 -0.76448734001534036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26547703363003594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28375553164830114,
                                 0,
                                 0,
                                 0,
                                 0.23170592128019712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78754530849770976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032483878904898844,
                                 0,
                                 0.36927362307968425,
                                 -0.47534198600168326,
                                 0,
                                 0,
                                 0,
                                 0.11130954098017837,
                                 0.06501943911950922,
                                 0,
                                 -0.33713984833181937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50491064084744386,
                                 0,
                                 0.07716572574694737,
                                 0.31354432527519771,
                                 0,
                                 0.18108350481114566,
                                 0,
                                 0,
                                 0,
                                 0.2862457207502801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6231465294300883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5766856143499588,
                                 0,
                                 -0.21855680802599972,
                                 -0.01957143698134679,
                                 0,
                                 0,
                                 0,
                                 -0.068910298035377932,
                                 -0.14764809971016332,
                                 0,
                                 -0.63859885509623426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11358259018219496,
                                 0,
                                 -0.30585462643580497,
                                 0.21924058969816737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28384969881007704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022890516074058936,
                                 0,
                                 0,
                                 -0.22059439749238047,
                                 0,
                                 0.093068326517612154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082515838627944982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13255283566557235,
                                 -0.019396261847210688,
                                 0,
                                 0,
                                 0,
                                 -0.13912991343618797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026370259893616931,
                                 0,
                                 0,
                                 0,
                                 0.60375889314300002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59607895170587089,
                                 0,
                                 -0.31135028051492752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022635981600764368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23983840060718659,
                                 0,
                                 0,
                                 0.36169100401709109,
                                 0,
                                 -0.39866445134881168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36035278440187613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.094362305337330282,
                                 0.011520324403761911,
                                 0,
                                 0,
                                 0,
                                 -0.020948066324453202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67132062231280631,
                                 0,
                                 0,
                                 0,
                                 0.11665287492575635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18939517761843755,
                                 0,
                                 0.11283487513675095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10449484907919449,
                                 0,
                                 -0.44119075238393812,
                                 0,
                                 0,
                                 0.12824237551401252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24425006442666924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30508685513640721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22749431991170366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53786144584103279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014156582071861932,
                                 -0.13292580350828073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14178051760786634,
                                 0,
                                 0,
                                 0,
                                 0.23676552205539986,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42503741268308093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080017392208156304,
                                 -0.055784093502203931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52740912254106087,
                                 0,
                                 0,
                                 0,
                                 0.15622304096861836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2377898451484397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34672880734605099,
                                 0,
                                 -0.081715703870339496,
                                 0.3442202129760516,
                                 0,
                                 0,
                                 0,
                                 -0.31347173378299609,
                                 -0.40634265447049289,
                                 0,
                                 -0.85106975548620689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083195405610839809,
                                 0,
                                 0.410270195284892,
                                 0.21861195851433896,
                                 0,
                                 -0.47324614125371978,
                                 0,
                                 0,
                                 0,
                                 0.68172126563240343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35971417383938709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22501794570388461,
                                 0,
                                 -0.21953155043413555,
                                 -0.40044814860171013,
                                 0,
                                 0,
                                 0,
                                 0.071605956467502174,
                                 -0.73641124394647661,
                                 0,
                                 0.50519907118232799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51100574998665294,
                                 0,
                                 0.29576409999461756,
                                 -0.22156620067904614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1503916708451622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13782615416234556,
                                 0,
                                 0,
                                 -0.42983094248713982,
                                 0,
                                 -0.092430199789386408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20975028874114027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3159090114287525,
                                 -0.55935103368582217,
                                 0,
                                 0,
                                 0,
                                 -0.015864419905376709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31207454596288464,
                                 0,
                                 0,
                                 0,
                                 -0.24152603492532027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22344703961559706,
                                 0,
                                 0.32018032807441449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60313733876210918,
                                 0,
                                 0,
                                 0,
                                 -0.011999462723086114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3203042150101974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11923220872858641,
                                 0,
                                 -0.27911878054998351,
                                 0.15340816184555292,
                                 0,
                                 0,
                                 0,
                                 0.40692346129734891,
                                 0.63583405476332733,
                                 0,
                                 0.01645841942652896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74664242110666212,
                                 0,
                                 -0.42344785338030089,
                                 0.12671811385169482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18883100395030755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79455862463235938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19007619056205996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23633640386874544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60270393900051411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37765720113385809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30194364296337006,
                                 0,
                                 -0.068174679610480321,
                                 0,
                                 0,
                                 0.33868341877727232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16343421186970761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14971666956786783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27348492434354305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25300156187597433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046706178283437205,
                                 0.52308471810180901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20242509094831349,
                                 0,
                                 0,
                                 0,
                                 -0.19250247024981082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41964502278106186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25137526734815419,
                                 -0.091774159707588773,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33967506491196731,
                                 0,
                                 0.44923132529809462,
                                 0,
                                 0,
                                 0.3591171080200265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12674734528703172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51674162038260507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018674282253303087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051865710354668623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18929979256044396,
                                 -0.10401548067486827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35623821065695127,
                                 0,
                                 0,
                                 0,
                                 -0.16774511539713124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080262310001543505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23449504950546579,
                                 0.067776928741362541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15131121052453869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41946811314543703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30386220142916825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47215040641118344,
                                 0,
                                 -0.33977654418734948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60864199322120482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52083990094199584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65820367163665416,
                                 0,
                                 0,
                                 0.40168735197092054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30230772153827618,
                                 0.70316795798313092,
                                 0,
                                 0,
                                 0,
                                 -0.080497069590590803,
                                 -0.007159940466366161,
                                 0,
                                 0,
                                 -0.19488909379812913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29713724225601285,
                                 -0.083331307571656604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0029016427847035065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46886320762549127,
                                 -0.25328931489628881,
                                 0,
                                 0,
                                 0.19481159859785391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08050514187264482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014496564774351794,
                                 0,
                                 0,
                                 -0.37547658888358942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56645180384423166,
                                 0.062818984678774809,
                                 0,
                                 0,
                                 0,
                                 0.6543749459411643,
                                 -0.066393084142217049,
                                 0,
                                 0,
                                 -0.067875361606663104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017630850884295893,
                                 -0.75411751292016727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069409890354834858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37262546616686687,
                                 -0.41006955570201103,
                                 0,
                                 0,
                                 0.54058739584207416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16694534274879011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037453426129422832,
                                 0,
                                 0,
                                 -0.45800748594091406,
                                 0,
                                 0.07267544411519769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71972171555862863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23795235412783516,
                                 -0.010614129800698341,
                                 0,
                                 0,
                                 0,
                                 -0.019957986022486301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19912930511915478,
                                 0,
                                 0,
                                 0,
                                 0.068847909194463444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0512487948317977,
                                 0,
                                 0.36540841627125781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55384785561631833,
                                 0,
                                 0,
                                 0,
                                 -0.085671674402086354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18690693926064375,
                                 0,
                                 -0.3568910632199267,
                                 0.29673418343073438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43692840286312479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30100007148781582,
                                 0.14691366130687974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34050704616736571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12853078166573284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44428214459759374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13128949682234362,
                                 0,
                                 0,
                                 -0.01697197572807476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.819501293034548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3015191148787519,
                                 0.23644539880465515,
                                 0,
                                 0,
                                 0,
                                 -0.1717442719264029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18102191471928819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94551575228405427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13837756992106309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10864298331414508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11573305413297513,
                                 0,
                                 -0.13555236446830196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2080378070692179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33824090825931874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051311583933405285,
                                 0,
                                 0,
                                 -0.38422473919798306,
                                 0,
                                 0.0083363943636868467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33150364961048018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31097636902149228,
                                 0.15338249904135667,
                                 0,
                                 0,
                                 0,
                                 0.40838189767179306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40449656842144138,
                                 0,
                                 0,
                                 0,
                                 0.31060489924695317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27756433553054588,
                                 0,
                                 0.034989839081094827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03493053141180448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71597160177740427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14563997345861085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0046659836029081247,
                                 0,
                                 0.31785976312426401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60323869333636604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56547444588130791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57043368422237628,
                                 0,
                                 0.22812047880861974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059046917209696154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047052259723624978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19870104965237936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33341961104487988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38269297402552088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15435123924954708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51791841639153724,
                                 0,
                                 0,
                                 -0.08142136597113124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44711453683304991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42437106752162385,
                                 0.19660762711007068,
                                 0,
                                 0,
                                 0,
                                 -0.99346037347654437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27703388397468387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065165733890228145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58099735983122514,
                                 0,
                                 0,
                                 -0.14405429531997038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62914027741038869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010723359341976491,
                                 -0.89064151085506349,
                                 0,
                                 0,
                                 0,
                                 -0.64585623974387496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056490057659491603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14611998289891048,
                                 0,
                                 -0.26221961543039246,
                                 0,
                                 0,
                                 0.069102640506426546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61591399907262601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084625218221335952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13854036708151682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10880055340280471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39478917180091072,
                                 -0.092765579728355585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.049355271915320909,
                                 0,
                                 0,
                                 0,
                                 -0.079263644240528147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048483273865285823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44265726122086441,
                                 -0.34072493823868172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12812567221447718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1662028328547408,
                                 0,
                                 0,
                                 -0.041303787247469748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14622862535350079,
                                 0.63758107723548108,
                                 0,
                                 0,
                                 0,
                                 -0.16223574663424326,
                                 -0.25080724204112759,
                                 0,
                                 0,
                                 0.63930552570472121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25689031399438023,
                                 0.28889164903930453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19931890694389373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19995737242136236,
                                 0.74322853877553152,
                                 0,
                                 0,
                                 0.63347872747446399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42698922160495006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62359447188040307,
                                 0.19976643770268065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67004572270409413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24409635463892093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5136077895560992,
                                 -0.21523567859513576,
                                 0.25788270755601311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4046206435490709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75921141303635897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.4636372578580419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22674735026299381,
                                 0,
                                 0,
                                 -0.27010126694248338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044544941906637991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23695874529643773,
                                 -0.37986375842615883,
                                 0,
                                 0,
                                 0,
                                 0.25182172357601507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17190803197085724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081048936167014307,
                                 0,
                                 0.46741016197045526,
                                 0,
                                 0,
                                 0.22065789834972288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42692052684133414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12975741009457445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11745768242839001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39795698227944792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32106638971949131,
                                 0.11677059733962152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23682613684815515,
                                 0,
                                 0,
                                 0,
                                 0.30258072532753566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11741729224931616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073087706246237144,
                                 0.2674235721496307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067121676809745109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43911441330524098,
                                 0,
                                 0,
                                 0.28167605005351642,
                                 0,
                                 0.17372941444557732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21837017185661353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40351866316473067,
                                 -0.31465013650632601,
                                 0,
                                 0,
                                 0,
                                 0.10365052991507948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042693205154905906,
                                 0,
                                 0,
                                 0,
                                 0.53287830380366696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29293996180249537,
                                 0,
                                 0.035959755651329584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13458946938420968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61834313267409691,
                                 0,
                                 -0.4695028237810942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18488177460127414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.509013091731219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056339601033177283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19602905519300118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.210303124582852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0046000603981450755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60079469210237335,
                                 0,
                                 0,
                                 0.027203078311681672,
                                 0,
                                 -0.11957759618183855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.038407864576992135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09182875501089989,
                                 -0.57399392394368121,
                                 0,
                                 0,
                                 0,
                                 0.39104490979633716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27258060974816195,
                                 0,
                                 0,
                                 0,
                                 0.12650855507746192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11919975354815937,
                                 0,
                                 -0.16486283187296061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0014947190623322837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4046407236183111,
                                 0,
                                 0,
                                 0.39807123813824241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27931303099433741,
                                 -0.0046597949175124932,
                                 0,
                                 0,
                                 0,
                                 0.018577333008208949,
                                 0.74294083039717529,
                                 0,
                                 0,
                                 0.72370409434869121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20648465846059708,
                                 0.19114394297588594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38284931319186816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12533304662431533,
                                 -0.21725468441327334,
                                 0,
                                 0,
                                 -0.21225974866493852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69025539792016977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10835946441284028,
                                 0,
                                 0,
                                 -0.48836610980794798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16713777423162035,
                                 -0.020194240224997696,
                                 0,
                                 0,
                                 0,
                                 0.10803225130919104,
                                 -0.40653879195982734,
                                 0,
                                 0,
                                 0.43666126969632957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22325186329666338,
                                 -0.19352785337152739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26658293312999076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22013251389374408,
                                 0.2782119060236759,
                                 0,
                                 0,
                                 -0.54872535078563556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69396136897219018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19905019717564237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56617235095782081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58208649098294862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86599700250619849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72355510556847902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20120463211560935,
                                 0,
                                 0,
                                 0,
                                 -0.049161943125519955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20851170441640321,
                                 0,
                                 -0.183595937454445,
                                 -0.40162588604968008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17516341915983455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7050662060656302,
                                 0.2023545366909473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23121545031244678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31048885094251621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29190252174232101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24101378680913368,
                                 0,
                                 0,
                                 -0.36630229014508725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93298465483219462,
                                 0.35061019817793321,
                                 0,
                                 0,
                                 0,
                                 -0.2827499565335716,
                                 0.2634303086694823,
                                 0,
                                 0,
                                 0.32029350113805605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16961949944674604,
                                 -0.023076879278226159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00014524951587255308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42880538977267046,
                                 -0.21649822538665564,
                                 0,
                                 0,
                                 0.27114617803058561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34930352326592484,
                                 0,
                                 -0.1217033152565324,
                                 0,
                                 0,
                                 -0.089553152098974492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19156999424011337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091501866347266467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021671805027985006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0260105644200684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43579261805333575,
                                 -0.0027418520479854085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42728561934525933,
                                 0,
                                 0,
                                 0,
                                 0.0096449421018719728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16240914302121678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057705791334469132,
                                 0.63768509203653179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62123926411983699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43750244148400402,
                                 -1.2686130559923119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76591104464377002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35595979993475374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28098243503789722,
                                 -0.16048211392439735,
                                 -0.23521850982969483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17901435870789661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12279787236623904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02551684505302082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090838507365251397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8301293426047841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54374593315287045,
                                 0,
                                 -0.037766454363801077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069975608959428226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47451258313331512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31315565885213015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5319291197978413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7304050292766725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45867477520406252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59493082843616363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12693353221860462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13618914844886154,
                                 0,
                                 0.10997585381450782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52269189291986395,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44153724298559183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0091973884540595269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56329132029344831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4095144081485696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17078714105539328,
                                 0,
                                 0.020841367698579191,
                                 0,
                                 0,
                                 0.085205401570192268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10528829434962239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098163305621653457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18647914936462454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14219279452465447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22693085765518367,
                                 -0.46335231915420233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16503203214711251,
                                 0,
                                 0,
                                 0,
                                 -0.75802082550510752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057622407758675914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035200194017679265,
                                 0.12181535631929516,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33247505587243192,
                                 0,
                                 0.43936876630774885,
                                 0,
                                 0,
                                 -0.030580465753806726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24242962378319666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20317896313058123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31434508101382574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11208281063664424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45088905108211019,
                                 -0.26947650358915054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31122772995931425,
                                 0,
                                 0,
                                 0,
                                 0.195260759831029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010183941241003316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22774752514744528,
                                 -0.14550060177906107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078873834991236985,
                                 0,
                                 0,
                                 0,
                                 0.30186304634313826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16416251426697531,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55351951646625763,
                                 0,
                                 0.11717189620432364,
                                 -0.28057948294313789,
                                 0,
                                 0,
                                 0,
                                 0.3972290165329555,
                                 -0.35329585332899238,
                                 0,
                                 -0.26347787498427561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47762667494528005,
                                 0,
                                 -0.38204767957878832,
                                 -0.73044616592704692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65048762712461128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077500701694948798,
                                 0,
                                 0,
                                 -0.65008417535113061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0019622062032048082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31550962733948673,
                                 -0.092410035639176047,
                                 0,
                                 0,
                                 0,
                                 0.13509816406217812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80972804808158816,
                                 0,
                                 0,
                                 0,
                                 -0.86062751975942231,
                                 0,
                                 0,
                                 0,
                                 0.51843209123614209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26672492272084414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27474062627132878,
                                 0,
                                 0.64465863958351666,
                                 0.025246118560922008,
                                 0,
                                 0,
                                 0,
                                 -0.49842081933575022,
                                 0.37304395150199343,
                                 0,
                                 0.081030146774732054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60091077518702052,
                                 0,
                                 -0.055220763161225386,
                                 0.22794850489655166,
                                 0,
                                 0.022191688045544319,
                                 0,
                                 0,
                                 0,
                                 -0.16578003997718049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68793413271219983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42169279675873783,
                                 0,
                                 -0.48191415267701548,
                                 0.15017856516115227,
                                 0,
                                 0,
                                 0,
                                 -0.17106808013820499,
                                 -0.67060414504942822,
                                 0,
                                 0.28673258389343675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20412895999258349,
                                 0,
                                 -0.5844764088175054,
                                 0.15150230958990202};

const double rot_1_30[900] = {-0.93715008602208283,
                              0,
                              -0.34892651987030598,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.81333303427283044,
                              0,
                              0,
                              0.70236701466529394,
                              0,
                              0,
                              0,
                              0,
                              0.95818206278251494,
                              0,
                              0,
                              0,
                              -0.23486133798109662,
                              0,
                              0,
                              0,
                              0,
                              0.27498213766540947,
                              0,
                              0,
                              -0.7436002284000427,
                              -0.08348807640862535,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.2261280383240184,
                              0.11398412173082312,
                              0.34892651987030621,
                              0,
                              -0.93715008602208261,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.31342397989780479,
                              0,
                              0.70605937233938876,
                              0.34294982549003961,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.4553662339955305,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.090681957495456822,
                              0,
                              0,
                              -0.050012989263227559,
                              0,
                              0,
                              0.25990010615534009,
                              0,
                              0,
                              0,
                              0,
                              0.024958782181346284,
                              0,
                              0,
                              0.40086038495813997,
                              0,
                              0,
                              0,
                              0,
                              -0.87860272682670459,
                              0,
                              0,
                              0,
                              0.52829592399771874,
                              0,
                              0,
                              0,
                              0,
                              -0.25118758287167542,
                              0,
                              0,
                              -0.19001750891540181,
                              0.49109995392927192,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.6603934101768435,
                              -0.20012198274166371,
                              0,
                              0,
                              0,
                              -0.17739641615118673,
                              0,
                              0.25971067355747451,
                              0.54510295139832377,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.47453122241081075,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.14052999654226528,
                              0,
                              0,
                              0.4983805142061708,
                              0,
                              0,
                              -0.33261381817747787,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.071405507386134437,
                              0,
                              0.098570367017261365,
                              -0.43433840768970544,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.28339130492530751,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.74483912723521817,
                              0,
                              0,
                              0.24612575853643551,
                              0,
                              0,
                              -0.31758689784633087,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.61586485231771126,
                              -0.38594805855099684,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.69140256560687408,
                              0.45369415541791919,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.22703743729426279,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.10331590022299617,
                              0.31937846987871554,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.23900298532681158,
                              -0.7767142724115591,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.57702318442897671,
                              0,
                              0,
                              0,
                              -0.7342940544497274,
                              0,
                              0,
                              -0.6186420166862856,
                              0,
                              0,
                              0,
                              0,
                              -0.14117397267504581,
                              0,
                              0,
                              0,
                              0.022429892475441207,
                              0,
                              0,
                              0,
                              0,
                              0.51596500103779863,
                              0,
                              0,
                              0.45219854288908828,
                              -0.40971250096017831,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.46287524208126746,
                              -0.55240009473022866,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.67122690542883934,
                              0.25450633592421212,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.8093321983120717,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.8087844313647645,
                              -0.091269536233615584,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.76471771860994997,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.19728081309032558,
                              0,
                              0,
                              0,
                              0,
                              -0.28733316610324527,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.85591441395164836,
                              -0.38200844026449376,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.7020808767147475,
                              0,
                              0,
                              0.20584367695120492,
                              0,
                              0,
                              0,
                              0,
                              -0.2324574568414296,
                              0,
                              0,
                              0,
                              -0.36676256055993561,
                              0,
                              0,
                              0,
                              0,
                              -0.98361527137132132,
                              0,
                              0,
                              0.83344457377973591,
                              -0.29793225225489717,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.2297565545871624,
                              0.039658565088955974,
                              0,
                              0,
                              0,
                              -0.84124525900872982,
                              0,
                              0.15966620170630605,
                              0.01926755613345843,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.41937169221498738,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.2906360605775552,
                              0,
                              0,
                              0.029193554585683526,
                              0,
                              0,
                              -0.072440872026847902,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.6946890931483467,
                              0.90251973390664453,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.68961977531730845,
                              -0.041192934480319743,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.027739188229422229,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.067000534416115365,
                              1.1670410491947885,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.97092795863497505,
                              -0.083813272736762576,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.2460634731373783,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.28120037863114905,
                              0,
                              0,
                              0,
                              0,
                              0.41544588708004776,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.28922065945901015,
                              -0.81528060942724867,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.30748651140237959,
                              0,
                              0,
                              0.39408488197113195,
                              0,
                              0,
                              0,
                              0,
                              -0.57318525659594266,
                              0,
                              0,
                              0,
                              -0.53842723186186636,
                              0,
                              0,
                              0,
                              0,
                              0.65008346396828098,
                              0,
                              0,
                              -0.4856742570684669,
                              -0.57774470860110183,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.95360578153876441,
                              0.14889854067005812,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.1363509969398625,
                              -0.97508479358303846,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.22280724855206774,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.2911752322593873,
                              0,
                              -0.01510883397102826,
                              -0.28085692798298206,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.22020199752580158,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.47258740877110728,
                              0,
                              0,
                              0.7510178025439016,
                              0,
                              0,
                              -0.01589260448999813,
                              0,
                              0,
                              0,
                              0,
                              0.00061675543996964066,
                              0,
                              0,
                              0.39937461984672551,
                              0,
                              0,
                              0,
                              0,
                              0.041826500659327907,
                              0,
                              0,
                              0,
                              -0.74515152257811401,
                              0,
                              0,
                              0,
                              0,
                              0.55284832798553096,
                              0,
                              0,
                              -0.02692301123043922,
                              1.0500981481158602,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.097362166252667692,
                              -0.85067783706434064,
                              0,
                              0.12702714282784588,
                              0,
                              0,
                              0.3657315336196279,
                              0,
                              0,
                              0,
                              0,
                              0.025198913578171077,
                              0,
                              0,
                              0,
                              0.058895632058663328,
                              0,
                              0,
                              0,
                              0,
                              0.48876840879895372,
                              0,
                              0,
                              0.56180641065800052,
                              0.48281278136708172,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.20194749025470585,
                              0.49888450989027849,
                              0,
                              0,
                              0,
                              0.26491933208936236,
                              0,
                              -0.22352395532720382,
                              0.30246100196657372,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.37586065975471417,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.16093893380790156,
                              0,
                              0,
                              -0.22158010436867509,
                              0,
                              0,
                              -0.75637412207919907,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.51840300842015019,
                              0,
                              0,
                              0,
                              0,
                              0.75301220182444228,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.40034463823781152,
                              0.062889708209525511,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.78311234743493641,
                              0,
                              0,
                              0,
                              0,
                              0.42168351932327458,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.15325174310962153,
                              0.43061811859226695,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.050381739509630818,
                              0,
                              -0.59044888015958996,
                              0.47525133009044901,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.34859476285494628,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.28902120708323054,
                              0,
                              0,
                              0.27305664051650907,
                              0,
                              0,
                              0.37862445473796663,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.61447825272836432,
                              -0.81468007990075075,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.27637733440960888,
                              -0.56196884832055649,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.8975329145948675,
                              0,
                              0,
                              0,
                              -0.015510631080704369,
                              0,
                              0,
                              -0.33753938200774264,
                              0,
                              0,
                              0,
                              0,
                              -0.1441766207410225,
                              0,
                              0,
                              0,
                              -0.9703654088502619,
                              0,
                              0,
                              0,
                              0,
                              -0.38224092288357336,
                              0,
                              0,
                              -0.18352349519047573,
                              0.32222338379272708,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.39696327945888521,
                              0.6276263782957493,
                              0,
                              -0.47451361981460205,
                              0,
                              0,
                              -0.8349787908113,
                              0,
                              0,
                              0,
                              0,
                              0.045188040079992213,
                              0,
                              0,
                              0,
                              0.31916844280376,
                              0,
                              0,
                              0,
                              0,
                              0.15019174735583521,
                              0,
                              0,
                              -0.097049265694085396,
                              0.92675593197788553,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.5209565479032483,
                              0.28274895627279129};

const double rot_1_2[4] = {-0.42362265501400681, -0.90583875284671056, 0.90583875284671056, -0.42362265501400698};

const double rot_3_50[2500] = {-0.21948641519302203,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22949001546891717,
                               0,
                               0,
                               0.21458343435976959,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.68605293009502577,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.49537593599616597,
                               0,
                               0,
                               0,
                               0,
                               -0.27027058989892316,
                               0.22368892630652812,
                               0,
                               -0.11817414129847929,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0559483546601229,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33349152933700182,
                               0,
                               -0.027413216737707469,
                               0,
                               0,
                               0,
                               -1.2220109231796492,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63350115093182424,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.099835467817784573,
                               0,
                               0,
                               0,
                               -0.60871248762920682,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10300763809068869,
                               0,
                               0,
                               0,
                               -0.23981731861367556,
                               0,
                               0.38736979583576936,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19291906636348066,
                               0,
                               0.12035765072246662,
                               0.40907891451535683,
                               0,
                               -0.12531495088630712,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.66135485090401969,
                               0,
                               0,
                               -0.010153025211673661,
                               0,
                               0,
                               -0.36418768555902542,
                               0,
                               0.080395991090215946,
                               0,
                               0,
                               -0.90665665684963404,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.89490000079085807,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25939842370911737,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17194735483116416,
                               0,
                               0,
                               0.95034023641209209,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56283076032924906,
                               0,
                               0.24823150576037606,
                               -0.19576851146378851,
                               0,
                               0.59347753038364026,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.55094192090372651,
                               0,
                               0,
                               0.42473912910788403,
                               0,
                               0,
                               -0.22769814289276166,
                               0,
                               0.50470332676486085,
                               0,
                               0,
                               0.51360488026333151,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10645245380956228,
                               0,
                               0,
                               0,
                               0,
                               -1.071325848481383,
                               0,
                               -0.55565387302646307,
                               0.30840786480064941,
                               0,
                               0.2509470255698163,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3362272652583122,
                               0,
                               0,
                               0.5146510099655498,
                               0,
                               0,
                               -0.34487557430015897,
                               0,
                               0.22446527530428081,
                               0,
                               0,
                               -0.22885925203861174,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26309493124130778,
                               0,
                               0.20685732663606451,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50419109913943205,
                               0,
                               0,
                               -0.35211389676067545,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20901270153461418,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16216923898583946,
                               0,
                               0,
                               0,
                               0,
                               -0.60364416378963848,
                               -0.30145385152259746,
                               0,
                               0.23188642289366901,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.62816810798156686,
                               0,
                               -0.35731087868921113,
                               -0.059981189001242163,
                               0,
                               0.54491535123441381,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51251304044492585,
                               0,
                               0,
                               0.47668894859556815,
                               0,
                               0,
                               -0.050609444616162923,
                               0,
                               -0.46761812954377452,
                               0,
                               0,
                               -0.53972410086383937,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33665494350229902,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41219566973518507,
                               0,
                               -0.12965782029124578,
                               0.46027396491431499,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12244056354890169,
                               0,
                               0,
                               -0.93630187461360626,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.012058955490127754,
                               0,
                               0,
                               0,
                               0,
                               0.28580553258680363,
                               0,
                               0,
                               -0.54762607387522766,
                               0,
                               0,
                               0.31354125569596764,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13182661603680632,
                               0,
                               0,
                               -0.45860228568190409,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56001547250249162,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.53913992192853877,
                               0,
                               0,
                               0,
                               0,
                               -0.15340466577609871,
                               0.20606714942263613,
                               0,
                               0.060923898725094155,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.71089208668766246,
                               0,
                               0.2231205650563593,
                               0.21923056819785033,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.99415141837197529,
                               0,
                               0,
                               0.35913559369264236,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10874888827614529,
                               0,
                               0,
                               0,
                               0,
                               0.42190310473553705,
                               0,
                               0,
                               0.020874923521450983,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29900650081127378,
                               0,
                               -0.032398124018372665,
                               -0.24664247183057753,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61392577661342629,
                               0,
                               0,
                               -0.078948044433346326,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43943166339480189,
                               0,
                               0,
                               0,
                               0,
                               -0.98384773974821649,
                               0,
                               0,
                               -0.015501334696717939,
                               0,
                               0,
                               0,
                               -0.86081632848541512,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.039163772774018168,
                               0,
                               -0.85759551370431619,
                               0,
                               0,
                               0,
                               0.3083556351426997,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61510513570852254,
                               0,
                               0.057453581931517783,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.59643967698867817,
                               0,
                               0,
                               0,
                               -0.35214666131148603,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37228644695859769,
                               0,
                               0.17973399841401433,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0214433385174111,
                               0,
                               -0.054440988835237736,
                               0,
                               0,
                               0,
                               -0.12416621381095277,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44797569068495952,
                               0,
                               -0.082638099871383097,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.80192758117673391,
                               0,
                               0,
                               0,
                               0.2579107799314439,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28789391995692931,
                               0,
                               0,
                               0.17501008851601871,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.54559494288952581,
                               0,
                               0,
                               0,
                               -0.31726683375290077,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25837931148106258,
                               0,
                               0,
                               0,
                               -0.60242767627544869,
                               0,
                               -0.37597926760306299,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30306951017799155,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21258027744625438,
                               -0.95214506641141783,
                               0,
                               0,
                               0,
                               0,
                               -0.56907375035818952,
                               -1.3139616808394028,
                               0,
                               0,
                               0,
                               0,
                               -0.36443458429761744,
                               0,
                               0,
                               0,
                               0,
                               0.46391649562045567,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.45133169883595803,
                               0,
                               -0.76705014018076167,
                               0,
                               0,
                               0,
                               -1.2636232198125439,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0941213346351088,
                               0,
                               0.30891297923898581,
                               0.50112388446752765,
                               0,
                               -0.026894121296196144,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0069604315297459585,
                               0,
                               0,
                               -0.62267511553353216,
                               0,
                               0,
                               -1.0240708355476538,
                               0,
                               -0.38077752820063543,
                               0,
                               0,
                               0.44359399222929041,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27793100715821417,
                               0,
                               0,
                               0,
                               0.034477110080920706,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50246895391180346,
                               0,
                               0,
                               0,
                               0.21003421807780762,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.50958394866131795,
                               0,
                               0,
                               0,
                               -0.61311189977092773,
                               0,
                               -0.25814705905299823,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.94251548267007279,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16956822247468889,
                               0,
                               0,
                               0.28794302015151224,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.092154201593011242,
                               0,
                               0.79752023744910594,
                               -0.52080390445585301,
                               0,
                               0.79830359864612188,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.79370153669382582,
                               0,
                               0,
                               -0.24542987746468856,
                               0,
                               0,
                               -0.27485496247238039,
                               0,
                               0.55070058504129449,
                               0,
                               0,
                               0.095856653367297817,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44560921227342659,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58932749967729958,
                               0,
                               -0.21951103945297612,
                               -0.25485227866314691,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.082089889412002404,
                               0,
                               0,
                               -0.8361825330991155,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.70341496686207194,
                               0,
                               0,
                               0,
                               0,
                               0.40699840815926519,
                               0,
                               0,
                               0.69072708549454964,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21065854529172323,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.97040235216807902,
                               0,
                               0,
                               0.11807731451144567,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54053238745212795,
                               0,
                               0.55646044108648129,
                               -0.14228105512638978,
                               0,
                               0.18929921659221755,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54603107529587802,
                               0,
                               0,
                               -0.42665348563887662,
                               0,
                               0,
                               0.32085522342546707,
                               0,
                               0.16452510249910843,
                               0,
                               0,
                               -0.36501899325161163,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.81898563626911236,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12485424421615345,
                               0,
                               1.1456532301262921,
                               0.32857536493054873,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32824245160248061,
                               0,
                               0,
                               0.15053238743076042,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.68757946251551005,
                               0,
                               0,
                               0,
                               0,
                               -0.537606502355086,
                               0,
                               0,
                               0.29583412749281918,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.48216547657384629,
                               0,
                               0.24657237381741309,
                               0.018504355909429143,
                               0,
                               0.77446922017985953,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23736600527924745,
                               0,
                               0,
                               -0.27051172132258117,
                               0,
                               0,
                               0.45915977378213485,
                               0,
                               -0.51622672440815243,
                               0,
                               0,
                               0.46890135559102852,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.60126583482394769,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61513471355567073,
                               0,
                               0.11447339441438555,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0061316534951389723,
                               0,
                               0,
                               0,
                               0.34116916215808901,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.7014778198687347,
                               -0.46413099587227657,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16530675842800596,
                               0,
                               0,
                               -0.42241461284457527,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20836015178511819,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12973766401232073,
                               0,
                               0,
                               0,
                               0,
                               -0.10705886507207998,
                               0.21928534773249775,
                               0,
                               -0.67751642822003,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.028707624938983101,
                               0,
                               0.65912370697157496,
                               0.92626219113024488,
                               0,
                               -0.2453499264218042,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39875494490790403,
                               0,
                               0,
                               0.57979643088923694,
                               0,
                               0,
                               0.1880726048895176,
                               0,
                               -0.24414943280999266,
                               0,
                               0,
                               -0.40225229020631648,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.062435131891659612,
                               0,
                               0,
                               0,
                               -0.67579959155469249,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.326487966577374,
                               0,
                               0,
                               0,
                               0.27598076981552672,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21591012409824181,
                               0,
                               0,
                               0,
                               0.19030311984019935,
                               0,
                               -0.52697502342870106,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14819073201270325,
                               0,
                               0.0059857079735869817,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0060660854479770709,
                               0,
                               0,
                               0,
                               -0.83247893488314817,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.53380305715567944,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.52606633232316913,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37113337156382187,
                               -0.73639241649551312,
                               0,
                               0,
                               0,
                               0,
                               0.4131974203867253,
                               1.025352661689773,
                               0,
                               0,
                               0,
                               0,
                               -0.3100951442307342,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.76211148569368314,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.70197034243617262,
                               0.66232860667431004,
                               0,
                               0,
                               0,
                               0,
                               0.53319935839503274,
                               -0.56093734761903824,
                               0,
                               0,
                               0,
                               0,
                               -0.7095423674423611,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.087614868543903976,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44397235824299364,
                               0,
                               0,
                               0,
                               -0.553476671229023,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1128737745553679,
                               0,
                               0,
                               0,
                               0.33852494149479601,
                               0,
                               -0.60127874512159374,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25227943986671714,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.03101815411769376,
                               0,
                               0,
                               0.16746724661087511,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29369454514740267,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29709244302359838,
                               0,
                               0,
                               0,
                               0,
                               -0.068452056767166231,
                               -0.82231012046909113,
                               0,
                               -0.22792028386175306,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32012128393888939,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36902322529900955,
                               0,
                               0,
                               0,
                               0.31967902642867579,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.77691446536268993,
                               0,
                               0,
                               0,
                               -0.2298867840364599,
                               0,
                               -0.052014640789182442,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49934075077838347,
                               0,
                               0.36675518906495014,
                               -1.0397208889092426,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16335441771584636,
                               0,
                               0,
                               -0.6932870476458608,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0691958424745782,
                               0,
                               0,
                               0,
                               0,
                               0.17914809753289829,
                               0,
                               0,
                               -0.17170414143618848,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16180279710089374,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.77730550958073152,
                               -0.060668299242036761,
                               0,
                               0,
                               0,
                               0,
                               1.0301285545923791,
                               -0.67032156379228058,
                               0,
                               0,
                               0,
                               0,
                               0.50650050927904977,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17021112430641805,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.5325194213876685,
                               0.86100678966671984,
                               0,
                               0,
                               0,
                               0,
                               0.073241918235223857,
                               -0.21638372318876348,
                               0,
                               0,
                               0,
                               0,
                               -0.97282026271862532,
                               0,
                               0,
                               0,
                               0.16444452726808201,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4275559023138914,
                               0,
                               0,
                               0.42556561548064592,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19793514856144123,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13977455128982569,
                               0,
                               0,
                               0,
                               0,
                               -0.68601065516171134,
                               0.15472036534701847,
                               0,
                               -0.2361855120363705,
                               0,
                               0,
                               0,
                               0,
                               -0.45401773562163611,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61993913502050124,
                               0,
                               0,
                               -0.40390179456044256,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0054939946286683208,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28703605601865584,
                               0,
                               0,
                               0,
                               0,
                               -0.17670168132800687,
                               -0.10344988775724973,
                               0,
                               0.3493729526867112,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11197678052690296,
                               0,
                               -0.50518817796009374,
                               0.33367776633876117,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0045869728615226257,
                               0,
                               0,
                               -0.39318167402309223,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46071419395249613,
                               0,
                               0,
                               0,
                               0,
                               -0.56215785527140338,
                               0,
                               0,
                               0.5749079706890019,
                               0,
                               0,
                               -0.5463433325510757,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28342614673433886,
                               0,
                               0,
                               0.26254820588433941,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.056114102940043264,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.48021824282032693,
                               0,
                               0,
                               0,
                               0,
                               -0.14509704487272557,
                               0.2402184441143041,
                               0,
                               0.48962293175618266,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.82307619536817944,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1099162460876142,
                               -0.4247287212608733,
                               0,
                               0,
                               0,
                               0,
                               0.47702631447554023,
                               0.15194571091973508,
                               0,
                               0,
                               0,
                               0,
                               0.17971878056652452,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.81259787409091555,
                               0,
                               -0.39661835335001688,
                               0.20820737076889637,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.48415347027240552,
                               0,
                               0,
                               0.43763988771480777,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33750149831799747,
                               0,
                               0,
                               0,
                               0,
                               0.85804292755900125,
                               0,
                               0,
                               -0.18579371879577367,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27665256863510423,
                               0,
                               -0.65466620209412296,
                               0.80834448239575085,
                               0,
                               0.068048198389290215,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19390238624910991,
                               0,
                               0,
                               -0.85622873360621099,
                               0,
                               0,
                               0.41885338809298112,
                               0,
                               0.60808737786644729,
                               0,
                               0,
                               -0.14147915341892012,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.023761131894271828,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14356964757446541,
                               0,
                               0.98829653629069725,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.033128110335891858,
                               0,
                               0,
                               0,
                               0.0075620295221566726,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.03876927477053746};

const double rot_3_20[400] = {-0.31910503467043794,
                              0,
                              -0.010788105539490958,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.81012145049162743,
                              0,
                              0,
                              0,
                              0.49168976914329815,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.5064011030102424,
                              0,
                              0,
                              0,
                              -0.59694947278887378,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.57841377082198564,
                              -0.38916811389938988,
                              0,
                              -0.83766210636900962,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.30515782227655802,
                              0,
                              0,
                              0,
                              0.23183847433257157,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.304478099521582,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.39586068210380793,
                              0,
                              0.86636447715498677,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.41306087151203841,
                              0,
                              0,
                              0,
                              -1.0715285918140882,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.4605907572594206,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.72471990384019458,
                              0,
                              -0.10678301845360333,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.12237640278535988,
                              0,
                              0,
                              0,
                              0.66962860153155912,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.47063915790107103,
                              0,
                              -0.53554010055479573,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.48539257822723825,
                              0,
                              0,
                              0,
                              -0.50605299006116367,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.82238592854553949,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.34966665925305407,
                              0,
                              0.44879239291358231,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.48059803520407407,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.84913340987804509,
                              0,
                              -0.21908441475118023,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0.084236912068315961,
                              0,
                              0,
                              0,
                              1.1021663905673424,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.38011164186186869};

const double rot_3_10[100] = {0.024378524090529322,
                              0.64609984943181764,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.7628634688640884,
                              0,
                              -0.81269698018404468,
                              0.45719354616329289,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.36124462590655582,
                              0,
                              0,
                              0,
                              0.3649339363264793,
                              0,
                              0,
                              0,
                              -1.0468105535798147,
                              0,
                              0,
                              0.38902546225238965,
                              0,
                              0,
                              0,
                              0.34948151999324262,
                              -0.35033074860894803,
                              -0.34267289570683135,
                              0,
                              0.79856516347146123,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.46640973888194182,
                              0.15246052554356676,
                              0.84202289101122485,
                              0,
                              0.22408747095756307,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.80668000911936288,
                              -0.17382123144683306,
                              0.36317282482480151,
                              0,
                              0.43261881800756813,
                              0,
                              0,
                              0,
                              0,
                              -1.3707915442771446,
                              0,
                              0,
                              0,
                              -0.13519734693004892,
                              0,
                              0,
                              -0.75055721077740478,
                              0,
                              0,
                              0,
                              -0.097938682584952211,
                              0.90763998051451034,
                              -0.20415248435854944,
                              0,
                              0.35343944793327142,
                              0,
                              0,
                              -0.5821763529746824,
                              -0.61117022662333254,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.53622910040978056,
                              0,
                              0,
                              0,
                              1.1806908577463824,
                              0,
                              0,
                              0,
                              0.1083534260463539,
                              0,
                              0,
                              -1.5665929281456061};

const double rot_3_100[10000] = {-0.0035896719434892407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44884917807865204,
                                 0,
                                 -0.12535029229834072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41280140280679462,
                                 0,
                                 0,
                                 0,
                                 0.11527329512911888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17297553799272275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12135734358924305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076863486131722059,
                                 0,
                                 0,
                                 0,
                                 0.13284193827806934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33343674244354704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26231330951123177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59238876751183489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1761155212883313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13199987185171658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63522486088328967,
                                 0,
                                 0,
                                 -0.066768977677582247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031963638721276284,
                                 0,
                                 0,
                                 -0.20193207324057186,
                                 0,
                                 0,
                                 -0.08651010084374719,
                                 0,
                                 0,
                                 -0.45296283531426079,
                                 0,
                                 0,
                                 0.038316999248019817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26295402523710498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0079066233868752625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10793131414239202,
                                 -0.45445606054387944,
                                 0,
                                 0,
                                 0,
                                 -0.01667532758228274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34658666082899103,
                                 0,
                                 0,
                                 0,
                                 -0.28062074761325889,
                                 0.56597947786722358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45285747316506991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020272754286203648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3147852779144249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54331041325779417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48978360908598545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24917499675445767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33068935852914061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53852243415807388,
                                 0,
                                 0,
                                 0,
                                 0.38083885263688222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7387530959554045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22478562743099462,
                                 0,
                                 0.10639486939900542,
                                 -0.75300863526942441,
                                 0,
                                 0,
                                 0,
                                 0.050895210767298228,
                                 0,
                                 -0.52875752120963204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.036539462139816889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013684431526391559,
                                 0.24339754051478199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27204920195114846,
                                 0,
                                 0,
                                 0,
                                 -0.31288941689239347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33022556892515015,
                                 0,
                                 -0.66931251372078671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28967417158156394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1896606098814641,
                                 0.300689617062042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91310382814820656,
                                 0,
                                 0,
                                 0.51181100144718394,
                                 0,
                                 0.41426745008771115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88243901831372507,
                                 0,
                                 -0.19081876056020197,
                                 0,
                                 0,
                                 -0.28789449666046363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81245093690750836,
                                 0,
                                 -0.021463098697109724,
                                 0,
                                 0,
                                 -0.21529599535412786,
                                 0,
                                 0,
                                 0,
                                 0.065818208860632207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5858437921907953,
                                 0,
                                 0,
                                 0.08022375881556866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31294680723999868,
                                 0,
                                 0,
                                 0,
                                 -0.81714447383676636,
                                 -0.14957805346982647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6632093027539655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064488005144449051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75613925822950989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1742531883115874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38284163059804321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082505693565801619,
                                 0,
                                 0,
                                 0,
                                 -0.11918844971972709,
                                 -0.04828623900157402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29567328448979563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.94211122317323548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10758474781632626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58502753953589781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42518937726035366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8932737283608716,
                                 0,
                                 0,
                                 -0.33690470795599575,
                                 0,
                                 0.082475041276305699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51953087053859337,
                                 0,
                                 0.38726060132010875,
                                 0,
                                 0,
                                 -0.37466411573688502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39405011503312215,
                                 0,
                                 -0.34114300591168989,
                                 0,
                                 0,
                                 -0.40364080214223491,
                                 0,
                                 0,
                                 0,
                                 0.60217832512496217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14961347735244646,
                                 0,
                                 0,
                                 -0.14436786211418878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37643880574232935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29762690772673617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36872749621354239,
                                 0,
                                 0,
                                 -0.42347513513324653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30753001784797235,
                                 0,
                                 0,
                                 -0.083698134325050827,
                                 0,
                                 0,
                                 0.11392329741576067,
                                 0,
                                 0,
                                 -0.017620402799858048,
                                 0,
                                 0,
                                 0.17699472589861354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30887677456090901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26520580441742347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36463634496170694,
                                 0.068757363597875598,
                                 0,
                                 0,
                                 0,
                                 -0.069270875991066405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64729954691755354,
                                 0,
                                 0,
                                 -0.74761126990568738,
                                 0,
                                 0.091845879747674705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28827115839523143,
                                 0,
                                 0.61406717301206271,
                                 0,
                                 0,
                                 0.78061588670494897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31650052571373277,
                                 0,
                                 -0.67569354589333797,
                                 0,
                                 0,
                                 0.3642553979538638,
                                 0,
                                 0,
                                 0,
                                 0.7386040716609571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16982883244854524,
                                 0,
                                 0,
                                 0.058636765418888202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10615306971161531,
                                 0,
                                 0,
                                 -0.19874114769968215,
                                 0,
                                 0,
                                 0,
                                 -0.46128159176110672,
                                 0.71936122054545737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59188404448685528,
                                 -0.073116203720513556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41117978050343074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10894464432530185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11127820921803384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81502159856528389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4225660984777927,
                                 0.16154232853576991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011314458737414157,
                                 0,
                                 0,
                                 0,
                                 0.34745687581467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75571273994805033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045423892758814602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17159837476662454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24437126619789934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57760128726777504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06362672101990581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14104415157366404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070894726591807677,
                                 0,
                                 -0.14889746741818455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40536386144524028,
                                 0,
                                 0,
                                 0,
                                 0.093145753066059295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51311446513659154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55863032564033455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11866470549622335,
                                 0,
                                 0,
                                 0,
                                 -0.0269916742672879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23622073090100656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023506218207073437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36523568266976802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010373915436324554,
                                 0,
                                 0,
                                 -0.42473649717802947,
                                 0,
                                 0,
                                 0,
                                 -0.044745428564678197,
                                 -0.52742757784787364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73287198285342625,
                                 0.39078941377923782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34711971368064493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00032511591580947768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05469813989649211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088352603232067561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10572875729771694,
                                 -0.10995722485095222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70805040997627966,
                                 0,
                                 0,
                                 0,
                                 0.21177184431909463,
                                 0,
                                 0,
                                 0.38918804282477792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033443187089992228,
                                 0,
                                 -0.12009321404115499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20234713188803416,
                                 0,
                                 0,
                                 0,
                                 0.19657079770663841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59272125150922506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17540139226339593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021640814751504547,
                                 0,
                                 0,
                                 0,
                                 0.101609832034008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4550709085235467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21768893923744587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32565684535712558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059985344861631484,
                                 0,
                                 0,
                                 0,
                                 -0.33150405165719177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33284546988175845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062599783873298856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.036027401276202679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49676042851880764,
                                 0.6508371191647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31645557303892113,
                                 0,
                                 0,
                                 0.17159093772484943,
                                 0,
                                 0,
                                 0,
                                 0.64866975581566877,
                                 0.035228992608117751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12513612417788092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67300256131366365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59669321049554702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38744754561269723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41139013381497674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13861302154658822,
                                 0,
                                 0,
                                 0.38771548568171271,
                                 0,
                                 0,
                                 0,
                                 -0.0016964373133424859,
                                 0.022184657241923575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14798475507015621,
                                 0.16740969845223522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050962658665610477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84717499090119275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20011131879873276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40287353245282664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14813172694133026,
                                 0.063796958132140605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45631115642819703,
                                 0,
                                 0,
                                 0,
                                 -1.2829575773089568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19506581323795535,
                                 0,
                                 0,
                                 -0.55560407527449174,
                                 0,
                                 0,
                                 0,
                                 -0.6456514335765331,
                                 0.45363079203303236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46469643606124678,
                                 0.54359811390387913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56721659063826424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46385660611114821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22563659714546386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19029194499184698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.265434898050879,
                                 -0.25317617422498467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25941326921826408,
                                 0,
                                 0,
                                 0,
                                 -0.48664386653281538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75674750009390768,
                                 0,
                                 0,
                                 0,
                                 -0.43733870888688975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.081390387894017494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19918210524962299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22962654281462444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33805351320597987,
                                 0.022738128794593596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14914630086119396,
                                 0.012339950414115154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025689356292671821,
                                 0,
                                 0.38206750831958314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37632994354638294,
                                 0,
                                 0,
                                 0,
                                 -0.046331157073525885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13701649673681648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41309674426583348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043388548536836602,
                                 0,
                                 0,
                                 0,
                                 -0.51359039117257366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18802528763071166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46444675281181258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057419575251572263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55466628042383648,
                                 0,
                                 0,
                                 0,
                                 0.7621924917105084,
                                 0.37779939771966725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0251525554506282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0045791283771869917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0079839188764786601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16393528572594876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4038870854915898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32356423251623756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88251338078578345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36710236120817308,
                                 0,
                                 0,
                                 0,
                                 0.99582260135828016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32446541244019089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31726531424852378,
                                 0,
                                 0.77661624457048162,
                                 0.27415200715491439,
                                 0,
                                 0,
                                 0,
                                 0.023191838030621734,
                                 0,
                                 0.017991996041478053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16096821139554413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3000372589426441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20898941023568804,
                                 0,
                                 0,
                                 -0.024533323271379123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42003590483550118,
                                 0,
                                 0,
                                 0.13770888221219091,
                                 0,
                                 0,
                                 -0.067020221512274172,
                                 0,
                                 0,
                                 -0.12543292149889942,
                                 0,
                                 0,
                                 -0.43400900383718422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16681455569326226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3091952214830993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057337106967829565,
                                 0.43206578520743844,
                                 0,
                                 0,
                                 0,
                                 -0.34986913578260581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25114294265615378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17188713725825419,
                                 0,
                                 -0.56605210343152657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10148600396157549,
                                 0,
                                 0,
                                 0,
                                 -0.053257313619256237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34519395347320347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40902664265252342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20495323209512459,
                                 0,
                                 0,
                                 0,
                                 -0.060724153748771284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47051675027716178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0018793597532016371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14243189864852834,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21418778173500191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67866895673779537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24526388043509642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91815701112326276,
                                 0,
                                 0,
                                 -0.2794495675483824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35418108255623382,
                                 0,
                                 0,
                                 0.039500292674825591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13019712180455092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16304119758896032,
                                 0,
                                 0,
                                 0.27294039436485329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35083903218503587,
                                 0,
                                 0,
                                 0.51801141667871542,
                                 0,
                                 0,
                                 -0.46883391051362899,
                                 0,
                                 0,
                                 0.0096770348029827265,
                                 0,
                                 0,
                                 0.29259051957960414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030553931738202259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037378050772240455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088734216677820069,
                                 -0.3953246163752126,
                                 0,
                                 0,
                                 0,
                                 -0.13035192099595463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0029319156162492194,
                                 0,
                                 0,
                                 0.24292963662076797,
                                 0,
                                 0,
                                 0,
                                 0.16275917892658631,
                                 0.72790380694812817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39405688235768588,
                                 0.0079882588861073175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17555075325384034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39461615178504489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0771933975060566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.850919771617351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46199918496228981,
                                 -0.44576591164220403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31199766406705554,
                                 0,
                                 0,
                                 0,
                                 -0.11335523731351821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.99467187941860402,
                                 0,
                                 0,
                                 0.13715966427106066,
                                 0,
                                 0,
                                 0,
                                 0.28844040053629805,
                                 0.13684454333114657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1393974209745556,
                                 0.75054678656604457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41269966332274216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32150735027862132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33018951879562009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13076445078339499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4058894592381152,
                                 -0.55732705556500828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091048244464247141,
                                 0,
                                 0,
                                 0,
                                 0.30030348147188313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3034292847659155,
                                 0,
                                 0,
                                 0,
                                 0.34304635901641217,
                                 0.13136983278536607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24108222319932826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20808305695534496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49054688106614475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042937802686205201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60616414238415672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8772578286093089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25158954918329535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10203751701647051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78591138327133014,
                                 0,
                                 0,
                                 0.49313852142458575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14550421036259892,
                                 0,
                                 0.7134973336652104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31359063045443486,
                                 0,
                                 0.01398085498628443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27348928471699735,
                                 0,
                                 0,
                                 0,
                                 -0.089743884846095301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2960493535348066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056570318984446616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11732294050727408,
                                 0,
                                 0,
                                 0,
                                 0.10759326008981493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19776301311148167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15724070150839908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35988248504921955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15645587319264909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1081018219106122,
                                 0.0050276449131151646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29828143966621956,
                                 0,
                                 0,
                                 0,
                                 -0.46425550206182203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27348910839355051,
                                 0,
                                 -0.049782872631614669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54278073210263222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32619397283355922,
                                 -0.42546119953947314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22755477905591587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.213510776832399,
                                 0.34816175199220251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16256487552167018,
                                 0,
                                 0,
                                 0,
                                 0.27458241058554594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37268062191419865,
                                 0,
                                 0.074852875750203107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52006353102134917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49685482970824002,
                                 0.13329639581544001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40616234455421052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.079050382946706785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066215739310412774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24821318566777356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49239961914384495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72134006697079589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059156214875570635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089531589651511062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051483021927010111,
                                 0,
                                 0,
                                 -0.52485148330172715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029537656762671088,
                                 0,
                                 0,
                                 0.21604943713996952,
                                 0,
                                 0,
                                 0.13852527835190889,
                                 0,
                                 0,
                                 -0.013583843026794405,
                                 0,
                                 0,
                                 -0.16270406065850149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56519964080657836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29743619349641681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17117475361939477,
                                 -0.38709813444688962,
                                 0,
                                 0,
                                 0,
                                 -0.17292817336316663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2371762225785867,
                                 0,
                                 0,
                                 -0.35407874615860696,
                                 0,
                                 0,
                                 0,
                                 0.29230505867681245,
                                 0.28169669670854286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27427786884397198,
                                 0.43478365034867078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36882458635042786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29495826283763182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7165305542721484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23223403648548865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96683204130834033,
                                 -0.23243557830105069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2321270339380665,
                                 0,
                                 0,
                                 0,
                                 0.013261482634321017,
                                 0,
                                 0,
                                 -0.069847984081753522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49275124637298884,
                                 0,
                                 -0.051504813745754351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37195414168811392,
                                 0,
                                 0,
                                 0,
                                 -0.28783463368790113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087634885754400607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088299802842809805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026392572869746486,
                                 0,
                                 0,
                                 0,
                                 0.61549233032949013,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23297219005693989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28039828928480137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023721628427621592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28391620038025595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058907750564138092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20035371823146081,
                                 0,
                                 0,
                                 -0.046421164089456485,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10356223105099649,
                                 0,
                                 0,
                                 -0.092842017021355486,
                                 0,
                                 0,
                                 0.27336491850511119,
                                 0,
                                 0,
                                 -0.18136235347538446,
                                 0,
                                 0,
                                 0.20404037938258235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060483696076287036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16433298101523491,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71796840435977416,
                                 -0.069881622650468406,
                                 0,
                                 0,
                                 0,
                                 -0.39243001929777593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089555598001675188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69626816066321839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13358399107697297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63771623955134316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088330832090802974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27360815513395864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56903448672506785,
                                 0,
                                 0,
                                 -0.60468802669972999,
                                 0,
                                 -0.097257469922431505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15549956852817254,
                                 0,
                                 -0.23577524631961672,
                                 0,
                                 0,
                                 -0.20740903855760873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34434641082229339,
                                 0,
                                 -0.077340647295421172,
                                 0,
                                 0,
                                 -0.90496776351652464,
                                 0,
                                 0,
                                 0,
                                 -0.16007859321856494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043452245188214798,
                                 0,
                                 0,
                                 0.34665251208788911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52723900056015682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49676383732009627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037274250840931999,
                                 0,
                                 0,
                                 0.15318054508032913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12931672913042727,
                                 0,
                                 0,
                                 0.054378089190919326,
                                 0,
                                 0,
                                 -0.13998044672301607,
                                 0,
                                 0,
                                 -0.26149308876492744,
                                 0,
                                 0,
                                 0.16226317086970771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26233799063339186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27209673400207229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27237837138332588,
                                 0.28025670974202838,
                                 0,
                                 0,
                                 0,
                                 -0.14428143311293459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22793441221267532,
                                 0,
                                 0,
                                 0.41900041290981127,
                                 0,
                                 -0.30094144051601762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8095299910995023,
                                 0,
                                 0.51318441194962772,
                                 0,
                                 0,
                                 -0.32045808941253073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49652681598097936,
                                 0,
                                 -0.76022494855887424,
                                 0,
                                 0,
                                 0.095135708637446567,
                                 0,
                                 0,
                                 0,
                                 -0.18922403585399053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.036183191000748974,
                                 0,
                                 0,
                                 0.012799819730148399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46067838495790453,
                                 0,
                                 0,
                                 0,
                                 -0.2937181947454936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52254372974280239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11930590686539917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50575193108732508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22105948786800825,
                                 0.13681342712064129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30141163213454641,
                                 0,
                                 0.51466997850007556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42843500058874512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36630562346073414,
                                 0,
                                 0,
                                 -0.0055926658460546163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078066114855336668,
                                 0,
                                 0,
                                 -0.2379516679091227,
                                 0,
                                 0,
                                 0.015183302794794299,
                                 0,
                                 0,
                                 -0.39864191607834759,
                                 0,
                                 0,
                                 -0.050809918036778014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21017594376197396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01583487772584791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17020380944576846,
                                 -0.17192056470837175,
                                 0,
                                 0,
                                 0,
                                 -0.29992268261018024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15621897010984709,
                                 0,
                                 0,
                                 0.19139532836233042,
                                 0,
                                 0.25704318797888431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14619067730990337,
                                 0,
                                 1.0796705586484872,
                                 0,
                                 0,
                                 -0.20352761710345091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47228473420602185,
                                 0,
                                 0.15307660370633092,
                                 0,
                                 0,
                                 0.058371946686694001,
                                 0,
                                 0,
                                 0,
                                 -0.2359202635091118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55991985089449081,
                                 0,
                                 0,
                                 -0.074209625862268036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42808194366360164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56971442599951905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069749489801758588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39674834398174219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27091549571106321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50646014326993039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0077954972076501802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1883543806209394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10445290792003481,
                                 0,
                                 0,
                                 0.10560560570849251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14591775413944655,
                                 0,
                                 0,
                                 0.54266777540455036,
                                 0,
                                 0,
                                 0.55792876094711885,
                                 0,
                                 0,
                                 0.14574345186382109,
                                 0,
                                 0,
                                 0.05172645194441524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44159346689517653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20426715914809801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21132476362028552,
                                 -0.088181881838902312,
                                 0,
                                 0,
                                 0,
                                 -0.047468452259142119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49878097582714598,
                                 0,
                                 0,
                                 -0.27580927065127758,
                                 0,
                                 0,
                                 0,
                                 0.24103742809153281,
                                 0.71970339757950796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11431690372790058,
                                 0.49969516955828819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4826509479519866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21984200728781478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031319889106517992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22589178543181077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50835732353007501,
                                 0.084181709071068644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52984841806965599,
                                 0,
                                 0,
                                 0,
                                 -0.24526704800568563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23380247528236608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4616868596021233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63581708342755305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43848452582225628,
                                 0,
                                 0,
                                 -0.44394393792421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3219502886333305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27928421652008217,
                                 0,
                                 0,
                                 0,
                                 -0.01982250618632031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45038926797696421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11802697056876277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29333326713146479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41236550130126759,
                                 0.24017843907153025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62534082011051495,
                                 0.23013349274357664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0064585370687698564,
                                 0,
                                 0.34682476590883948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097986219485577952,
                                 0,
                                 0,
                                 0,
                                 -0.69668821306637252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17998682324296328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.089204522727053565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085122184886449487,
                                 0,
                                 0,
                                 0,
                                 -0.016810003840911494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18195779856378447,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30111816801756869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4000897668782547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37699972115727221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15301616449832128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30640096082937307,
                                 0,
                                 0,
                                 0.035526766751191749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034944350439702697,
                                 0,
                                 0,
                                 0.046327675132930131,
                                 0,
                                 0,
                                 -0.17470114974853973,
                                 0,
                                 0,
                                 -0.014308278679596808,
                                 0,
                                 0,
                                 -0.6998286532833925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22308137536759665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088871598933579085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12237407081075047,
                                 -0.26961514464734221,
                                 0,
                                 0,
                                 0,
                                 0.2648200134131436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17762037307119655,
                                 0,
                                 0,
                                 0.59037922175990287,
                                 0,
                                 0,
                                 0,
                                 -0.34746321539346908,
                                 -0.033329876271601638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045603569989353672,
                                 0.77865600404502344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29687858120902533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28785506848137044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01244561524065383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21781342856933589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025801009444203903,
                                 0.91690513915244998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24043753301861434,
                                 0,
                                 0,
                                 0,
                                 0.25790061102271145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18580309156540156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28102276594429382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2377596496704439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16394422129146358,
                                 0,
                                 0,
                                 -0.16496881161397614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70673169397262869,
                                 0,
                                 0.37250752068232507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5153803402651953,
                                 0,
                                 0.43421920986830365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060478010149783844,
                                 0,
                                 0,
                                 0,
                                 0.38236563923985234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.120073896690401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19206241642862287,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17439870295263202,
                                 0,
                                 0,
                                 0,
                                 -0.0026557293619669589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39593336206125751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.106488093532284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085925803362593228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043435359053558747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70871941497022795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05621421951328591,
                                 0,
                                 0,
                                 0,
                                 -0.29680953210336675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29446769192712252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.16966208572974,
                                 0,
                                 -0.11560159100697069,
                                 0.24860073337426122,
                                 0,
                                 0,
                                 0,
                                 0.46300110151501067,
                                 0,
                                 0.067245729975352678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75233453830155606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28998498209735268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52325873558597114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19823808842685431,
                                 0,
                                 0,
                                 -1.1011027965901639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43991354458753057,
                                 0,
                                 0,
                                 -0.03899471614693098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50605890728754099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32488502339772918,
                                 0,
                                 0,
                                 -0.31557120652597387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39607107725899476,
                                 0,
                                 0,
                                 -0.0063503552227130774,
                                 0,
                                 0,
                                 0.0097072199718643767,
                                 0,
                                 0,
                                 0.38923098605708772,
                                 0,
                                 0,
                                 -0.079939796477702149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030763166890475719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35089658528897577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2431185912594345,
                                 -0.092600289671932387,
                                 0,
                                 0,
                                 0,
                                 -0.17491167383355916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14076954637002462,
                                 0,
                                 0,
                                 0,
                                 0.27454467697656171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31100748696066532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78479713927191996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23965832196142367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28679209067285921,
                                 0.046061507038858918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22443144034441995,
                                 0,
                                 0,
                                 0,
                                 -0.49883378586419702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92343499176047072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13580243823536067,
                                 0,
                                 0,
                                 0,
                                 -0.26550194242178954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19016900541948145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031847065388922659,
                                 0,
                                 -0.12062407448146049,
                                 -0.13164593627301896,
                                 0,
                                 0,
                                 0,
                                 -1.0826776449982503,
                                 0,
                                 0.31528871527651348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23017677818578183,
                                 0,
                                 0,
                                 0.064813142945506289,
                                 0,
                                 -0.49588679025806404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34371982468977053,
                                 0,
                                 0.14107935493202939,
                                 0,
                                 0,
                                 0.025252425173530185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27120737398511136,
                                 0,
                                 0.5787003179393112,
                                 0,
                                 0,
                                 -0.10728336001708626,
                                 0,
                                 0,
                                 0,
                                 0.33538082104009659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.94653712365618325,
                                 0,
                                 0,
                                 0.083664697891227463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18358815604767026,
                                 0,
                                 0,
                                 0,
                                 0.17073787500236121,
                                 -1.0107776771907409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.004332908382096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16685410896986613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20528287304232135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24698731550028935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015705770812300762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033277977045378299,
                                 0,
                                 0,
                                 -0.54751007582517686,
                                 0,
                                 0.0014906973191396375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17200509737510172,
                                 0,
                                 0.34201591442656587,
                                 0,
                                 0,
                                 0.48997698664442496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20350772216072421,
                                 0,
                                 0.63066302425388976,
                                 0,
                                 0,
                                 -0.089673887931147694,
                                 0,
                                 0,
                                 0,
                                 -0.83070946772679966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33393245749144673,
                                 0,
                                 0,
                                 0.66970288410936585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.416099983232815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034400366913219127,
                                 -0.16778809832298794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48358605114875242,
                                 0,
                                 0,
                                 0,
                                 -0.4632322034518091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14341031613919838,
                                 0,
                                 -0.085371007292230169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18851849980772378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41734380524969594,
                                 -0.33393895456998507,
                                 0,
                                 0,
                                 0,
                                 -0.2440266856385363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11545465447188479,
                                 0,
                                 0.22332236846077061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05034071025529975,
                                 0,
                                 0,
                                 0,
                                 0.058762359518606033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16679329358740635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1043172375789595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84284735724104853,
                                 0,
                                 0,
                                 0,
                                 0.20128530557672164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11400527074912323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26191233045946549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0075043920777415757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42120013917567578,
                                 0,
                                 0,
                                 -0.84800335371956614,
                                 0,
                                 0.72948374724815213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66444602945698517,
                                 0,
                                 -0.16875583439697478,
                                 0,
                                 0,
                                 -0.17892841992547129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4660497950938241,
                                 0,
                                 0.22268438759830453,
                                 0,
                                 0,
                                 0.1576236188685336,
                                 0,
                                 0,
                                 0,
                                 0.25440829842678547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27479586052584926,
                                 0,
                                 0,
                                 -0.27082824156978469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43359402472011682,
                                 0,
                                 0,
                                 -0.68333562286258542,
                                 0,
                                 0,
                                 0,
                                 -0.78913266784201008,
                                 0.17859008814625787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43708185752943118,
                                 -0.31003491592739635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61658031114269818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29909431828459088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69410447033004208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02416516121042684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020030481022454222,
                                 0.51289905686189585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05362958703858299,
                                 0,
                                 0,
                                 0,
                                 -0.07295377056683737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70043782239784824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034526117800798374,
                                 -0.39580774300758476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025441901981888563,
                                 0,
                                 0,
                                 0,
                                 0.041093150340786547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.245680335010592,
                                 0,
                                 -0.090716421727052618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.095492725879670462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40072866366914034,
                                 -0.33302324029136271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0377018572292592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32363768359704337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29465230920384244,
                                 0,
                                 0,
                                 0,
                                 0.49373585980144802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030782117875501759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15308028192091488,
                                 0,
                                 -0.5338471738362206,
                                 -0.60499506010759196,
                                 0,
                                 0,
                                 0,
                                 1.0041590721189129,
                                 0,
                                 1.2177405584567793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5150676323913338,
                                 0,
                                 0,
                                 -0.49052740273949014,
                                 0,
                                 0.37119914928992992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13021849950797021,
                                 0,
                                 -0.1392877792403841,
                                 0,
                                 0,
                                 0.30601935542701075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28312207911309445,
                                 0,
                                 -0.71323631426611622,
                                 0,
                                 0,
                                 -0.33020586603822533,
                                 0,
                                 0,
                                 0,
                                 -0.30873026986209051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75223867590505078,
                                 0,
                                 0,
                                 -0.29387806557903801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028192303221002094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015440105030646158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030179248405967141,
                                 0,
                                 0,
                                 0.027721202911351741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12746639042283286,
                                 0,
                                 0,
                                 0.41837998297333101,
                                 0,
                                 0,
                                 0.15887552326238669,
                                 0,
                                 0,
                                 -0.4865603994787448,
                                 0,
                                 0,
                                 -0.20895036847722295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21563589900063007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64904672188075696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073446162063005346,
                                 0.16142080530189601,
                                 0,
                                 0,
                                 0,
                                 -0.033820707897701231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14948218436599375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10775378326070879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016584187545949813,
                                 0,
                                 0,
                                 -0.22063299313529622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41197006446458267,
                                 0,
                                 0,
                                 0.10314624339856075,
                                 0,
                                 0,
                                 0.17571730286664128,
                                 0,
                                 0,
                                 -0.32511674314456634,
                                 0,
                                 0,
                                 0.18589149500060356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0022830297113472509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2043267224911558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24955228204091615,
                                 0.069641896465864633,
                                 0,
                                 0,
                                 0,
                                 0.67580891692440748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90334020999647047,
                                 0,
                                 0,
                                 0.19283365911982087,
                                 0,
                                 0,
                                 0,
                                 0.027882191175084094,
                                 0.19604245062390935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83579458853498256,
                                 -0.29388432049218161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40857850073084656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38969422708440082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30925241128414599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5320289819316284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10779662684243101,
                                 0.027717816269289802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12146445615724608,
                                 0,
                                 0,
                                 0,
                                 -0.41808453676936685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32150387734144698,
                                 0,
                                 0,
                                 -0.050083318439862849,
                                 0,
                                 0,
                                 0,
                                 -0.69453575631905351,
                                 -0.31986976343539664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016125523091230186,
                                 -0.015397251528167705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23721045944241603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33444769921164419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20422108656218188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084045703568939173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22701055252535085,
                                 -0.69504504777561749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71467619790880155,
                                 0,
                                 0,
                                 0,
                                 -0.053375393605486376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76375786540687107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29097166882696052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2165072692644314,
                                 0,
                                 0,
                                 0,
                                 -0.39052935839128816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071517784449978777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24651560508739323,
                                 0,
                                 0.56764648439753229,
                                 -0.079569571327761157,
                                 0,
                                 0,
                                 0,
                                 0.77640223028975364,
                                 0,
                                 -0.20568256203222426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077344790342682171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13552678825730755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.019520525869152885,
                                 0,
                                 0,
                                 -0.52777414218903329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4528998464710387,
                                 0,
                                 0,
                                 0.2601685437607168,
                                 0,
                                 0,
                                 -0.49343755725005389,
                                 0,
                                 0,
                                 -0.05410851628154361,
                                 0,
                                 0,
                                 0.13846851483177275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27993767922148638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.08414787819776115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.099399315375806416,
                                 0.2509999080526249,
                                 0,
                                 0,
                                 0,
                                 0.0029501610723920574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24100136374293768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32612475425266563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051130872973542033,
                                 0,
                                 0,
                                 0,
                                 0.075945585535041521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16426752602754349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.99749340440551848,
                                 0,
                                 0.87742363733923567,
                                 -0.65399445154617808,
                                 0,
                                 0,
                                 0,
                                 -0.046337738981920978,
                                 0,
                                 -0.055345046624379252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30882215975024763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20811322483427835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91225426907993479,
                                 0,
                                 0,
                                 0,
                                 -0.027129410075608415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48855969612044392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21162959118675492,
                                 0,
                                 0.38537047892685783,
                                 0.71865525786404372,
                                 0,
                                 0,
                                 0,
                                 -0.084033558484934059,
                                 0,
                                 0.28923922227709026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34986223626910634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52559671192366186,
                                 0.46894393227233361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38314708415407939,
                                 0,
                                 0,
                                 0,
                                 -0.17923936960381937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15728522400541414,
                                 0,
                                 0.074019785589962916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16714605244209371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31959138116287372,
                                 -0.20545957415326957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61318381442622294,
                                 0,
                                 0,
                                 0,
                                 -0.089134626791878196,
                                 -0.56780593695364123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25075396830383467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21813085756514922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2336159379914031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40314492394602325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51975310917359829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015377922944227546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64274763338366359,
                                 -0.39753209115598037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29729795565625555,
                                 0,
                                 0,
                                 0,
                                 -0.34104954736511522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.007908136623185763,
                                 0,
                                 0.28832884372803907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044327272973810589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10097337239514617,
                                 0.35853839091357109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0457280268460285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39632647050309799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015703089218963975,
                                 0,
                                 0,
                                 0,
                                 -0.96608102976149612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025016562339129411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49680274976640348,
                                 0,
                                 0.82845595792095239,
                                 -0.45671203866214355,
                                 0,
                                 0,
                                 0,
                                 0.067956285409085854,
                                 0,
                                 0.33938360260043421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0088800951927069799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27568503095050623,
                                 0,
                                 -0.10193945172797708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49322545459745465,
                                 0,
                                 0,
                                 0,
                                 0.28643869271921457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03104632405730548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051456807910453761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17068844868325869,
                                 0,
                                 0,
                                 0,
                                 -0.22191271304488977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22743383752799107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61367559575882002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2790939245589778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11646311554501351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36316493456640214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40759730619720319,
                                 0,
                                 0,
                                 0,
                                 -0.47223807150658031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0169673054490687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46865723836761064,
                                 0,
                                 -0.35564439353739508,
                                 -0.67368607692642679,
                                 0,
                                 0,
                                 0,
                                 0.49000822703231389,
                                 0,
                                 -0.69059418802872563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26634614907454607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42206057230718019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45239270466498605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49673654246566634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41859109024488023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35256169600461829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22926816224186555,
                                 0,
                                 0,
                                 0,
                                 0.67554341012492924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092679896954410215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2676334914909132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15330949880067571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28612170979065932,
                                 0.48378279814820629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26729147149089405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21521696706340607,
                                 0,
                                 0,
                                 0,
                                 -0.094408919131317465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12272536848230658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33454386264482461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25968066925735883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49501735998589036,
                                 0.50714275914180895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49811392888648526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18146892788213231,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22327809037095522,
                                 0.18378483075970975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086905672397138783,
                                 0,
                                 0,
                                 0,
                                 -0.020678152062061896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73572157896981238,
                                 0,
                                 -0.40591543273388442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3920124233683322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11459693473485774,
                                 -0.05098135805983367,
                                 0,
                                 0,
                                 0,
                                 0.0096402278472784361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25700443510180981,
                                 0,
                                 0.33069233580566632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014015955741090526,
                                 0,
                                 0,
                                 0,
                                 0.35557293335935458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21591705324102176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48488640681451334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37948099487354492,
                                 0,
                                 0,
                                 0,
                                 0.47263053683049178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14563372432007304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13031071792555771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10275841258532137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053534009454287157,
                                 0,
                                 0,
                                 0.24209909330465218,
                                 0,
                                 -0.16339275269002634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1311269853292753,
                                 0,
                                 0.095119570541061516,
                                 0,
                                 0,
                                 0.69502981424469956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1753174317419301,
                                 0,
                                 0.019712888752282609,
                                 0,
                                 0,
                                 -0.84311159577354511,
                                 0,
                                 0,
                                 0,
                                 0.01753039344110624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39503672269519358,
                                 0,
                                 0,
                                 -1.0708929702754748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041421948232204339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064720178314400356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85953513041135687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26045048561480055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40927170127799473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14126959824521029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25179959181920475,
                                 0,
                                 0,
                                 -0.58148067117023028,
                                 0,
                                 0,
                                 0,
                                 0.41837097977283866,
                                 0.1293294031438153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25307875970333232,
                                 -0.12358054498865094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1030801078374624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74922396607857722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40059426002716719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49319549051554901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48009591451738581,
                                 0.097418751335619683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51172054803809786,
                                 0,
                                 0,
                                 0,
                                 0.3241795783463528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48162234749110688,
                                 0,
                                 0,
                                 -0.7245573610726509,
                                 0,
                                 -0.57924056971334259,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57690914273461291,
                                 0,
                                 -0.10442465760423333,
                                 0,
                                 0,
                                 -0.79834957565874731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31323280776468654,
                                 0,
                                 -0.18947697132395297,
                                 0,
                                 0,
                                 0.38184732586966696,
                                 0,
                                 0,
                                 0,
                                 -0.63378514089197757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19708365428326863,
                                 0,
                                 0,
                                 -0.5496245426708497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29009535219215377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41075474600168704,
                                 0.38693516703593622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062556690906240539,
                                 0,
                                 0,
                                 0,
                                 -0.45859776857182932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16134261568632682,
                                 0,
                                 0.48607274923603916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029317396114785406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.271519500015587,
                                 0.21517584222728031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13757383783119931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17948663389733488,
                                 0.27067189828962895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57396308110175043,
                                 0,
                                 0,
                                 0,
                                 0.18899146910286235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064959431710282789,
                                 0,
                                 0.19691441450140273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34916733759939961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27715111489927891,
                                 -0.51837991132826056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33004652243768184,
                                 0,
                                 0,
                                 0.76043192359057654,
                                 0,
                                 0,
                                 0,
                                 -0.54463981764396208,
                                 0.66391260713379108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59602685029580216,
                                 0.16414522615241961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45081529050321695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034455828362321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26621710343248906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04513472055087725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17059106420743386,
                                 -0.25516273972419401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37911917459643907,
                                 0,
                                 0,
                                 0,
                                 0.22827584344087412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043036525264360748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61985582361446045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96365487677591877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65673413246997581,
                                 0,
                                 0,
                                 1.1494260747601701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60137087200821771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12170634011355494,
                                 0,
                                 0,
                                 0,
                                 -0.26745071534215226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53507973183547286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3588727618563527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67510761519470297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10430135307633395,
                                 0.078289137281082499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16055980085923538};

const double rot_3_30[900] = {-0.3733390490537104,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.34647352160112899,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.124403809384948,
                              0,
                              0.82999289134635656,
                              0,
                              0,
                              0,
                              -0.28605721641962911,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.32930549174882123,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.34762186690833419,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.44431877324578795,
                              0,
                              0,
                              0,
                              0,
                              -0.33173647113824695,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.64043950277870521,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.32975908724655395,
                              0,
                              0,
                              -0.10000136304871567,
                              0.39141591308018414,
                              0.10208447234026227,
                              0,
                              0,
                              0,
                              0,
                              -0.34140002417675186,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.93991809403379067,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.016474182231782819,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.0087379107674432,
                              0,
                              0,
                              -0.48934866569864832,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.88773974796263788,
                              0,
                              0,
                              0,
                              0,
                              0.95421832400730766,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.17790677043733588,
                              0,
                              0,
                              0,
                              -0.89869769041859737,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.081954428970131374,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.39239662822330146,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.1649925752431138,
                              0,
                              0.29107430810892465,
                              0.53082750028511216,
                              0,
                              0.32662825244660398,
                              -0.5401765910977897,
                              0,
                              0,
                              -0.16347992968614922,
                              0,
                              0,
                              0.067090023078252958,
                              0.29325436537909638,
                              0,
                              -0.45677812149209729,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.067416107803276087,
                              0,
                              0,
                              0,
                              0,
                              0.30909500859730676,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.42163742856284808,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.11120399634596909,
                              0,
                              0,
                              0.53483669433019099,
                              -0.1066426726516696,
                              -0.64214324326286087,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.2404841008970473,
                              0,
                              0.31194830350427205,
                              -0.11294229266837698,
                              0,
                              -0.13156437085165471,
                              -0.39322667769304037,
                              0,
                              0,
                              -0.61512500034245898,
                              0,
                              0,
                              -0.43437790348064481,
                              -0.46664880801428527,
                              0,
                              -0.33321060647273598,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.14013006115659773,
                              0,
                              0.78110377486438642,
                              0.82508778998919052,
                              0,
                              0.60484749980434072,
                              0.17127311958657068,
                              0,
                              0,
                              0.10713313361026444,
                              0,
                              0,
                              0.23195751491104238,
                              0.0088853130931818569,
                              0,
                              -0.29125795147682404,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.95150623062017725,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.57138683028350268,
                              0,
                              0,
                              -0.31650418528304741,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.0901341542461265,
                              0,
                              0,
                              0,
                              0,
                              -0.47090899501105254,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.51806610797447927,
                              0,
                              0.69963022782804718,
                              -0.72409529070718648,
                              0,
                              0.48192057255562193,
                              0.88169309465810197,
                              0,
                              0,
                              -0.066039326405607612,
                              0,
                              0,
                              -0.076609303811833396,
                              -0.50805307536215738,
                              0,
                              -0.25108942900472037,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.47765222679889779,
                              0,
                              0.64851280858563565,
                              0.53428459800485539,
                              0,
                              -1.1760772306101956,
                              0.29224061666193862,
                              0,
                              0,
                              -0.14632435419822454,
                              0,
                              0,
                              0.63535012369333588,
                              0.28030411574942687,
                              0,
                              0.54652398600644048,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.13031766301975345,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.27195969815819782,
                              0,
                              0,
                              0.46341139753892596,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.50468384523538323,
                              0,
                              0,
                              0,
                              0,
                              1.1936275190284249,
                              0,
                              0,
                              0,
                              0,
                              0.85811416998863499,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.76249513232705934,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.16791293984346384,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.0079729178077528953,
                              0,
                              0.11241736807970379,
                              -0.080881473156149158,
                              0,
                              -0.22834610899953098,
                              0.17410207069193198,
                              0,
                              0,
                              0.68694261756947339,
                              0,
                              0,
                              -0.50386378961515144,
                              -0.35552466924921833,
                              0,
                              -0.60854851465451709,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.51870229435546067,
                              0,
                              0,
                              0,
                              -0.20149748440144896,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.32521361884041144,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.76458014343232339,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.38322344877363401,
                              0,
                              0,
                              0,
                              0,
                              0.13892319334221703,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.51324726336327464,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.10025543840657544,
                              0,
                              0,
                              0.072234634322761476,
                              0.69527680052050689,
                              -0.26784054331613516,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.35397900889873335,
                              0,
                              0.84243646321904353,
                              -0.17388708012038356,
                              0,
                              0.24488583055455701,
                              -0.51309356723617261,
                              0,
                              0,
                              0.34354076005470396,
                              0,
                              0,
                              -0.49153747992998287,
                              0.16811284254822353,
                              0,
                              0.70881620252623545,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.22911108588254478,
                              0,
                              -0.23687500700684605,
                              0.67264726816743836,
                              0,
                              -0.054987228141329156,
                              0.35036525469158597,
                              0,
                              0,
                              -0.72990810352782576,
                              0,
                              0,
                              -1.1740138181682092,
                              0.46571189832333709,
                              0,
                              0.052380945012116348,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.0097714260670350717,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.68868443827390391,
                              0,
                              0,
                              1.1097386523791273,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.1176110880518933,
                              0,
                              0,
                              0,
                              0,
                              0.077206770727900081,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.42286391334660367,
                              0,
                              0.6628451596288738,
                              -0.84937293206588271,
                              0,
                              -0.054510031648718399,
                              -0.26902127710958634,
                              0,
                              0,
                              0.040761932931976337,
                              0,
                              0,
                              -0.36828732348678089,
                              1.3225376435642608,
                              0,
                              -0.28093515886083054,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.93991809403379045,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.34140002417675136,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.046318463565825169,
                              0,
                              0,
                              0,
                              0,
                              -0.38028633983960092,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.1759098169178237,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.27147139749921756,
                              0,
                              0,
                              -0.46356261613996075,
                              -0.25571922458741558,
                              -0.68433419862662603,
                              0,
                              0,
                              0.10202407155888843,
                              0,
                              0,
                              0,
                              -0.26440970850258211,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.88265365053171907,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.37496816941596017,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.91328252788131792,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.52318400765080586,
                              0,
                              0,
                              -0.80391596510849239,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.079497404701373,
                              0,
                              0,
                              0,
                              0,
                              0.13294085530777067,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.49715510740087576,
                              0,
                              0,
                              0,
                              0,
                              0.4976795427484228,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.086010842892180944,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.59373997263429823,
                              0,
                              0,
                              -0.2006687500655413,
                              0.31436281138547967,
                              -0.078325776607034756,
                              0,
                              0,
                              0,
                              0.62858812826922572,
                              0,
                              0,
                              0,
                              0,
                              -0.48871183300047027,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.14317192888324248,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.36243470989545512,
                              0,
                              0,
                              0.068718455000661677,
                              0.42933404504113848,
                              -0.1585264673109717,
                              0,
                              0,
                              0,
                              -0.082122156432805224,
                              0,
                              0,
                              0,
                              0,
                              0.3794333307381097,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.29965987179191927,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.55790560934978295,
                              0,
                              0,
                              -0.66245839340862755,
                              0.058881854404594945,
                              -0.076898605096869035,
                              0,
                              1.2969651743633115,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.380587255797604,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.029922494099444669};

const double rot_3_2[4] = {-0.48399914524701787, 0.87506847012114208, 0.87506847012114197, 0.48399914524701787};

const double rot_4_50[2500] = {-0.25999824622788881,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.073776894354176531,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51875061419969437,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.48780095015319275,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.045651226262257288,
                               0,
                               -0.64639142990583398,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67147094264035978,
                               0,
                               0.38923720514187421,
                               0,
                               0,
                               0,
                               0,
                               0.13153170138254613,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.26456425740446871,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30159450553957601,
                               0.31695696252009931,
                               0,
                               0,
                               -0.29523642702928732,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17815955447798837,
                               0,
                               0,
                               0.053027349408195507,
                               0,
                               0,
                               0.55128994851306468,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20433714562481453,
                               0,
                               0,
                               -0.35056940614711851,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.72705908650863127,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.021311273820594473,
                               0,
                               0.5750534717046738,
                               0,
                               0,
                               0,
                               0,
                               -0.038741622176390628,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44732875839702757,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.56197329568087717,
                               -0.28083800949212578,
                               0,
                               0,
                               0.22994133999815886,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14035102577676201,
                               0,
                               0,
                               0,
                               0,
                               0.33916274458849871,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.75967218574008089,
                               0,
                               0,
                               0,
                               0,
                               -0.12551275697289849,
                               0.76133679212736804,
                               0,
                               -0.69807108431749987,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61486403433754955,
                               0,
                               0.15892058544731907,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41577219260379833,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38583805025074991,
                               0,
                               0,
                               0.033840348238727141,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.71212932042064747,
                               0,
                               0,
                               0.42188201804913988,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40604337656683109,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.2651237024317461,
                               0,
                               0,
                               -1.2199425154547687,
                               0,
                               0,
                               0,
                               0,
                               -0.0092248087776007626,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.34133080480248085,
                               0,
                               -0.010249950110681832,
                               0.15694754666091518,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.52626406222203603,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50382776410534325,
                               0,
                               0,
                               0.15087954664704875,
                               -0.22066462896062713,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.59654566289269229,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.76586118283640769,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23997900055699772,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43303414224423675,
                               0,
                               0.075173047996819176,
                               0,
                               0,
                               0,
                               0,
                               0.69945652554826065,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34992640102688394,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30701053673780088,
                               0.10527665239909986,
                               0,
                               0,
                               -0.014553476674601828,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29931936179653129,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.083109208702088183,
                               0,
                               0,
                               0.42538103616209721,
                               0,
                               0,
                               0,
                               0,
                               0.59578727377097607,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11682457460344343,
                               0,
                               -0.27002518723748303,
                               0.42756873266085788,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.89189953112628018,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5528608366313934,
                               0,
                               0,
                               0.34036475359805174,
                               -0.64400444339493668,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24538801804808358,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37788454965180068,
                               0,
                               0,
                               0,
                               0,
                               -0.24359827562167091,
                               0.77210455850643844,
                               0,
                               1.0785428249557065,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.61928945623346099,
                               0,
                               -0.61221595519142835,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42445114578565973,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.94954329777530855,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.82377456508014768,
                               0,
                               0,
                               0,
                               0.98789449625262971,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17610419867551741,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.92318362164573453,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2284607282360008,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18657688804969993,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24319200001608413,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.037025672045479664,
                               0,
                               -0.014612048534961591,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.01881376589820119,
                               0,
                               0,
                               0,
                               0.62647101060024324,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4183842715064261,
                               0,
                               0,
                               0,
                               0,
                               1.0600851530163728,
                               0,
                               0,
                               0,
                               0,
                               0.73229298126641185,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.56291085013450681,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.78574713791207218,
                               0,
                               0,
                               -0.29472692388746358,
                               0,
                               0,
                               0,
                               0,
                               0.12335452534364791,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3868135378326315,
                               0,
                               -0.3959301823150313,
                               -0.45544730544816459,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.26095213143012624,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0683004300626278,
                               0,
                               0,
                               0.35941441467697405,
                               -0.34441461530885042,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.65378605025486447,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17189604201469666,
                               0,
                               0,
                               0,
                               0,
                               0.37731088074176733,
                               -0.06190749616392488,
                               0,
                               -0.68261947511351861,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57199917084433238,
                               0,
                               -0.26340346987357832,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36076158840700451,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28385103944602341,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.83496919697374483,
                               0,
                               0,
                               0,
                               0,
                               0.14822771712721416,
                               -1.0543034633469659,
                               0,
                               -0.21840863812992467,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.983357558356873,
                               0,
                               -0.32514910993814428,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16546108883262631,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.87258045470508527,
                               0,
                               0,
                               0,
                               -0.4557119870756024,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56907569574552452,
                               0,
                               0,
                               0,
                               0,
                               -0.40113921598352931,
                               0,
                               0,
                               0,
                               0,
                               0.59348699975102726,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.084727024926598421,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.85133741294135334,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21809390667100315,
                               0,
                               0,
                               0,
                               0,
                               -0.42586541872081979,
                               -0.0074056210854189924,
                               0,
                               0.60578974101548944,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0056170021830512507,
                               0,
                               0.53914836766175744,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.095461616264322799,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22824934810663283,
                               0,
                               0,
                               0.47844508738833363,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31211499618286948,
                               0,
                               0,
                               0.78331025227263362,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.089452843919109487,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13038321686064352,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.69201296117105193,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42236065536199391,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51214577484489976,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2428619341494194,
                               0,
                               0.066742350754603094,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.74330798536705123,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41444009123571646,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.52510251348294834,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.68503567030322743,
                               0,
                               0,
                               -0.32020722397992418,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58909238007560483,
                               0,
                               0,
                               0.18519052411467796,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21649041927593118,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33523446551730002,
                               0,
                               0,
                               0,
                               -0.22707275893781237,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57844962376270692,
                               0,
                               0,
                               0,
                               0,
                               -0.31751952051110366,
                               0,
                               0,
                               0,
                               0,
                               0.97600977805753286,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.83478767191253744,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4581132763549316,
                               0,
                               0,
                               0.32171867324076525,
                               0,
                               0,
                               0,
                               0,
                               -0.28658420620821023,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.50603333817986351,
                               0,
                               -0.4745099487844599,
                               0.37999862626674619,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.9632582798951107,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22039325806481702,
                               0,
                               0,
                               0.55430156827537613,
                               -0.56839224888594708,
                               0,
                               0,
                               -0.37376112760514213,
                               0,
                               -0.12842191142309631,
                               0,
                               0,
                               0,
                               0,
                               0.045577481641923503,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.054319130050007262,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43722627369707767,
                               -0.4048581552896196,
                               0,
                               0,
                               0.68320719961405829,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13012893419808838,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32416368126042394,
                               0,
                               0,
                               -0.33229813261320545,
                               0,
                               0,
                               0,
                               0,
                               0.13833701120326225,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44794517385734911,
                               0,
                               -0.74896993013613689,
                               0.29497267534699922,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28954826400598588,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34831849254854758,
                               0,
                               0,
                               -0.64665950810653339,
                               0.02936188394871421,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.59782212863135975,
                               0,
                               0,
                               0.20036721937311658,
                               0,
                               0,
                               0,
                               0,
                               -0.080940381913585463,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46844743555050766,
                               0,
                               0.12458794769177442,
                               1.0602051803423518,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23067856148243571,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.68503899092990683,
                               0,
                               0,
                               -0.52153213257203201,
                               -0.30061696044484015,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.98442046869043731,
                               0,
                               0,
                               0,
                               0.80958089134492783,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.3148398947428412,
                               0,
                               0,
                               0,
                               0,
                               0.047344707709033013,
                               0,
                               0,
                               0,
                               0,
                               0.39721351589513465,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46223984479728075,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.030668257145623094,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11216024525715075,
                               0,
                               0,
                               0,
                               0,
                               -1.0911640314172484,
                               -0.072374620226611647,
                               0,
                               -0.57011832859018285,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44053060113352543,
                               0,
                               0.19836967080089682,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.90010128085684737,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.49247510604916395,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.78135269261934337,
                               0,
                               0,
                               0,
                               -0.41138255296546505,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.59244961437619814,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16792743950088779,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31215427451968192,
                               0,
                               0,
                               0,
                               0,
                               -0.67704760803380937,
                               -0.02964180656383833,
                               0,
                               0.30568574700033546,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32289902362206452,
                               0,
                               -0.38361678866635257,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.72665979899596078,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30269871320092079,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.49162593442672575,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.81650317184047339,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39103029529948263,
                               0,
                               0,
                               0,
                               -0.61202826539173627,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16766993355956994,
                               0,
                               0,
                               0,
                               0,
                               0.21799657869834727,
                               0,
                               0,
                               0,
                               0,
                               0.34687228017734278,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1571198878259077,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1573189064669731,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.050620548609624672,
                               0,
                               0,
                               0,
                               0.73603363834893554,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39575005671373303,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29475683459342844,
                               0,
                               -0.077620915954043967,
                               0,
                               0,
                               0,
                               0,
                               -0.2796321310671474,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.45944762404946582,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12002956442244274,
                               0.40233481219500949,
                               0,
                               0,
                               0.39251087652938799,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5361547987883355,
                               0,
                               -0.059548349360497251,
                               0,
                               0.17445620363432726,
                               0,
                               0,
                               0,
                               0,
                               -0.12672774602910647,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27803240606338864,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.079340061121510763,
                               0.66740317579546227,
                               0,
                               0,
                               0.376388216263495,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.52845733315403631,
                               -0.084200095962033344,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.43516689717662282,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10536692669725882,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13306834897793091,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.86542769626648908,
                               0,
                               0.1605168004764482,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42843939351779392,
                               0,
                               0,
                               -0.22206863197722726,
                               0,
                               0,
                               0,
                               0,
                               0.26053298097053501,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0033960922478597499,
                               0,
                               0.52865052007420443,
                               -0.69873551682508472,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23591040951676548,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36002979287424119,
                               0,
                               0,
                               -0.70911797473742122,
                               -0.7459553461640247,
                               0,
                               0,
                               -0.35645180427602169,
                               0,
                               -0.66119683852042566,
                               0,
                               0,
                               0,
                               0,
                               0.24392381572031968,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34753664711619719,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.45849008294733729,
                               0.17944168313260236,
                               0,
                               0,
                               0.014972824415329629,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11332980065783442,
                               0,
                               0,
                               0.57179145209992954,
                               0,
                               0,
                               -0.60290285748583439,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.081685731983966017,
                               0,
                               0,
                               0.22637617538768412,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50164125443184682,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.55940101570490131,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.095702514853478998,
                               0,
                               0,
                               0,
                               0,
                               0.075651199711949807,
                               0.24621728505645496,
                               0,
                               0.40184903219745871,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.77743498997056171,
                               0,
                               0.69463815676891993,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.08107052065394077,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.99095627867164215,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.330773938949466,
                               0,
                               0,
                               0,
                               0.47837613523873201,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0098652340908043,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22514106514399573,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12265648660470715,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18425256148560376,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.59654700405994376,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27952954146360937,
                               0,
                               0.68287098932511459,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.46986710092316192,
                               0,
                               0,
                               -0.44161759183568905,
                               0,
                               0,
                               0,
                               0,
                               0.17624939145656129,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.75585899737637574,
                               0,
                               0.75184907806472634,
                               0.35456598610863749,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19667650527476871,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18990279896146486,
                               0,
                               0,
                               0.28630144247458111,
                               0.10150340925074569,
                               0,
                               0.07317768833715263,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.50898515202318095,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.68749337906607111,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25891905282101102,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33235716341844973,
                               0,
                               0.29228690477097391,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36637028682641937,
                               0,
                               0,
                               0,
                               -1.1566527947697416,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.83902174929994033,
                               0,
                               0,
                               0,
                               0,
                               0.95511877706682891,
                               0,
                               0,
                               0,
                               0,
                               -0.67402506109552796,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16911216937292337,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24519145873828097,
                               0,
                               0,
                               -0.058644278812852224,
                               0,
                               0,
                               0,
                               0,
                               -1.4671871680989423,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.536436864346584,
                               0,
                               -0.076223145667370124,
                               -0.04884136371979618,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58238713795233754,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3563937160205437,
                               0,
                               0,
                               -0.11846496638920617,
                               -0.29745509558528954,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.616340088885173,
                               0,
                               0,
                               -0.50198791931825404,
                               0,
                               0,
                               0,
                               0,
                               -0.12217430392441263,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30009145881732724,
                               0,
                               -0.815506972515747,
                               -0.39526791906321096,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43067082729780343,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42072933862860107,
                               0,
                               0,
                               0.25235108572592374,
                               0.34841379451258003,
                               0,
                               0,
                               -0.06301720175645055,
                               0,
                               0.14840315187218578,
                               0,
                               0,
                               0,
                               0,
                               0.57976623053033738,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44195907325804956,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27728935662153453,
                               0.078583580208189618,
                               0,
                               0,
                               0.31148272507503916,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51231082157672514};

const double rot_4_20[400] = {1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.31121533887855302,
                              0,
                              0,
                              0,
                              -0.94614503678970419,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.089188464528308475,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.47673221292571821,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.80532407364503678,
                              0,
                              0.37614064082599108,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.7976258423476722,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.58347063585448555,
                              -0.084223378717281291,
                              -0.12752041088458732,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.20781482606289708,
                              0,
                              0,
                              0,
                              -0.023823280738228259,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.97787803399161932,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.4804588731865767,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.67883374858626722,
                              0,
                              -0.87670773981563377,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.33084016049690307,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.80386883839767787,
                              0,
                              1.6937182610338686,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.51715193786533731,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.78705094459898906,
                              0.051643352810182119,
                              0.33232160308726377,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.063549808137966651,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.10599296071716413,
                              0.86601614396238535,
                              -0.48450278901215571,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.30382282775808728,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.16993622327158975,
                              0.49015857126494139,
                              0.79909820696130929,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.92733921027591371,
                              0,
                              0,
                              0,
                              0.32286532897336262,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.18920879586257916,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1};

const double rot_4_10[100] = {0.49486165317263708,
                              0.52159385115875545,
                              0,
                              -0.56764096685906185,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.40104305429209475,
                              -0.67389136285405937,
                              0.7302433056669424,
                              0,
                              0.0042195750267911697,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.11223787589716876,
                              0,
                              0,
                              -0.31043049192799277,
                              0,
                              -0.91622277458988965,
                              0,
                              0.25331548907272083,
                              0,
                              0,
                              0,
                              -0.24681788026340967,
                              -0.29283831804729771,
                              0,
                              -0.80472328531023185,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.45359352678914477,
                              0,
                              0,
                              0.90743375229824774,
                              0,
                              -0.36500665713259439,
                              0,
                              -0.20816850251372948,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.22795969356670981,
                              0,
                              0.67129343512794737,
                              -1.8445417724317212,
                              0,
                              0,
                              0,
                              0.28319056282169297,
                              0,
                              0.16524517412527467,
                              0,
                              0.94472066641787811,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.88761131305229535,
                              0,
                              0.89274865898440992,
                              0.070006143811027655,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.79199735823045536,
                              0,
                              -0.6786196251939699,
                              -0.10358503241945155,
                              0,
                              -0.48996255905142455,
                              -0.33004588839315069,
                              0,
                              -0.1737422286302609,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.78792134142511017};

const double rot_4_100[10000] = {-0.26580690766714765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026056245004190126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.283180717442713,
                                 0,
                                 0,
                                 0.40989787849436299,
                                 -0.63626190599129062,
                                 0,
                                 -0.59354861667809955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84780766620829295,
                                 0.014242591331444621,
                                 0,
                                 0,
                                 0,
                                 1.0117125233840758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20885128273787082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076659715414189838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25466543866764707,
                                 0,
                                 -0.31733299776708207,
                                 0.32876247827535249,
                                 0,
                                 0,
                                 0,
                                 0.14535352304065696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46760865789462885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39047206177742633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20423162230240707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10265034076666274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5888237586677002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19171263876901798,
                                 -0.2774094933263993,
                                 0,
                                 0,
                                 0,
                                 0.25587165774994014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057934861913482849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84772073326439767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063761910728433929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13875479912405131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27479913853190641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10318204708559205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18599964222718759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34130214141013343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23458716769499427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23656401201677577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10178435696871725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23970416232078526,
                                 0,
                                 -0.20220655518900665,
                                 0,
                                 0,
                                 0.55244838214955949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24119772101154202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053236045795031384,
                                 0,
                                 -0.50235596108660019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61569834125122125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30584328030082386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15733769238722345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22452120491739325,
                                 0,
                                 0,
                                 0,
                                 0.06999075558586304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15086935719107064,
                                 0,
                                 0,
                                 -0.063160629103657218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3914664107729508,
                                 0,
                                 0,
                                 0,
                                 -0.019233998692119635,
                                 0,
                                 -0.0056924376890121545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32093472502240938,
                                 0,
                                 0,
                                 0,
                                 -0.27228438248528714,
                                 0,
                                 0,
                                 0.29960477342016689,
                                 0,
                                 0,
                                 0.0034324122423544101,
                                 0,
                                 0.050112496995903297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23388202254705731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66660819427263629,
                                 0,
                                 0,
                                 -0.31003814186606266,
                                 -0.40432994007839268,
                                 0,
                                 0.84429426095490878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74313280652115377,
                                 -0.52592086839175511,
                                 0,
                                 0,
                                 0,
                                 -0.15037252560030789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23718352560342118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39086455845760354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3300891936564827,
                                 0,
                                 -0.2556220215616829,
                                 -0.71415584973020541,
                                 0,
                                 0,
                                 0,
                                 -0.22018758693615237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27326269324963226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015188545680627635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2265975954698331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1639516634803464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47225673237706634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52640154941002182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26122907092508818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59023486361879129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63849145758360759,
                                 0,
                                 1.3751324571735708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010110647675497075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52491592540529941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41142330438060348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10401243616468066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02525441895708206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38638370770785602,
                                 0,
                                 0,
                                 0,
                                 0.16637188125188437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42749508383192558,
                                 0,
                                 0.26455208673865804,
                                 0,
                                 0,
                                 0,
                                 -0.095726490331755509,
                                 -0.32382460779226885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2618856614717775,
                                 -0.49551671403219694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21422417379501793,
                                 0.072950844140820162,
                                 0.27129554131872746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49083628340360275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72498690291815082,
                                 0,
                                 0,
                                 0,
                                 -0.92480482696561583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35586062961430998,
                                 0,
                                 0,
                                 -0.35316495812346105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27439293807636461,
                                 0.16384292785599841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2490803008877589,
                                 0.28781799315279577,
                                 0.77581875600809602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.511175189336601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70805325534679786,
                                 0,
                                 0,
                                 0,
                                 -0.54901398011059277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66877808848265774,
                                 0,
                                 0,
                                 0.40484945521601257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24158456525645344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40934672180767723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097629076151258432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16856600576206571,
                                 0,
                                 0,
                                 0,
                                 -0.35603441071012637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18611810964389514,
                                 0,
                                 0,
                                 0.65640827943485469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092577111965680095,
                                 0,
                                 0,
                                 0,
                                 0.1169647607499348,
                                 0,
                                 0.22406516276025529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13372223904446523,
                                 0,
                                 0,
                                 0,
                                 0.039097321171980309,
                                 0,
                                 0,
                                 -0.0034093697881161372,
                                 0,
                                 0,
                                 0.22798159374929383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086483065301784998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61937708783970291,
                                 0.26004747884206669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45182160842116009,
                                 -0.076258983146988479,
                                 -0.15287440200287616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64688810795591767,
                                 0,
                                 -0.16341827119712099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36095938290123142,
                                 0,
                                 0,
                                 -0.21302620779557421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18353165285831805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070634180931041679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41190838570508415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.039914251682807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11273866364545729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21479633378475527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37866653648479237,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080713842331204058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41968345264728901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4673786889007906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11418210762823973,
                                 0,
                                 -0.22895063709128258,
                                 0,
                                 0,
                                 -0.18672461964061185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10112176221310602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22640037153465392,
                                 0,
                                 -0.48463145659280149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23064848815073599,
                                 0,
                                 0,
                                 0.12132447461526348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59200076992740547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6029283055521838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40268626441511346,
                                 0,
                                 0,
                                 -0.23651208424484832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1835687667523285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29401323358089032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26554470921789425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40436243994146664,
                                 0,
                                 -0.41413757721203903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40360029936878994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33541356887623247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38557580655716489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18626424281145662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47201364459703987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28603885339027801,
                                 0,
                                 0,
                                 0,
                                 -0.23715866947610845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12186714223846787,
                                 0,
                                 -0.0774781276655261,
                                 0,
                                 0,
                                 0,
                                 0.46126309064398718,
                                 0.33114532580836403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26766305308807337,
                                 0,
                                 0,
                                 0.57281913106915805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43640017316656465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28532130728897953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2031742241403236,
                                 0,
                                 0,
                                 0.53581863368571359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50799412015671663,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028527832072588181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28870818397281828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14659636888281083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16376696777074382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12146475773442811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12192972859237686,
                                 0,
                                 0.28366255693364151,
                                 0,
                                 0,
                                 0.45054278575645668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38475844943737764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2973454725948293,
                                 0,
                                 0.24482323728069197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33169019327930022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015710157309591216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010050137045818711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.056350893627661852,
                                 0,
                                 0,
                                 0,
                                 -0.52276700415111033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22353265963974106,
                                 0,
                                 0,
                                 -0.3121926612499682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20387097964375672,
                                 0,
                                 0,
                                 0,
                                 0.45650499263955702,
                                 0,
                                 0.055400446750960258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26970934076978192,
                                 0,
                                 0,
                                 0,
                                 0.30753131159742852,
                                 0,
                                 0,
                                 -0.11478425828302684,
                                 0,
                                 0,
                                 -0.17949505194423993,
                                 0,
                                 -0.18675277747694752,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33055377739403674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21866887042641467,
                                 0,
                                 0,
                                 0.21557849866341683,
                                 0.25789021463888367,
                                 0,
                                 0.12236505018293709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33871387234542483,
                                 -0.0030676215150818587,
                                 0,
                                 0,
                                 0,
                                 0.071606861853348219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13215757588803831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57756219386572027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86296893758892756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066867699561324573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39056751121971756,
                                 0.57473951435697157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051961447840493571,
                                 0.25305294843583509,
                                 0.28739024390915058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01231243568016626,
                                 0,
                                 0.66045367290366641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46458323285407382,
                                 0,
                                 0,
                                 -0.2156064490952575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27305831014368293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.387474998004949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.232430347398702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45458616793857182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3289881102038153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09704933972167698,
                                 -0.080201941283558911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56492949600964915,
                                 -0.087379861346672708,
                                 -0.4557335995906342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41218239263320544,
                                 0,
                                 0.18567206060077218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28507287977297097,
                                 0,
                                 0,
                                 0.1773812437691614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17407324701748755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3896660545525672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64204398309293653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53054983458582028,
                                 0,
                                 0,
                                 0.41434040663964966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26469407873531836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45793826049452646,
                                 0,
                                 0,
                                 0.29186327904337261,
                                 -0.017233549734041842,
                                 0,
                                 0.44482025732059494,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57548734383064537,
                                 0.67669728463883128,
                                 0,
                                 0,
                                 0,
                                 0.55312512309461348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1444268341744546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073735710165183987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29407635306215391,
                                 -0.010122920847614333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0272395089132278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080035373810407678,
                                 0,
                                 0,
                                 -0.30857794929095522,
                                 0.29960260484898532,
                                 0,
                                 0.15954446072242665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1707902848419881,
                                 -0.48272501950918695,
                                 0,
                                 0,
                                 0,
                                 0.43793709357471056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25759917909362828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44874179833640282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12389716609512851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67864615890765667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63543649058548157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46398881707038103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20766123117945395,
                                 0.21199577904914585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15627992357515458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73151581476019034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08569697680727574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48656282076342044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71676938914486277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12217003019790165,
                                 0,
                                 0,
                                 -0.16469969911285751,
                                 -1.0921437738670932,
                                 0,
                                 0.20812082357078926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40251732479350449,
                                 0.61087255498294646,
                                 0,
                                 0,
                                 0,
                                 -0.32877614304320912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37500884644977639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5009707689223768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41268941285664085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85435980702564907,
                                 0,
                                 0,
                                 0.38394677011628825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26916996032895507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089386333801959011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037195305775188398,
                                 0,
                                 0,
                                 0.20206019615602139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44121432441775665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27032312865776703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058439762389252116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29477832133871695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63971476943831185,
                                 0,
                                 0,
                                 0,
                                 -0.19281341424021148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16114631094683207,
                                 0,
                                 -0.010027227552899302,
                                 0,
                                 0,
                                 0,
                                 0.40819255205468047,
                                 -0.053329392986630086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25385994355489672,
                                 0.11107831970979801,
                                 0,
                                 0,
                                 0,
                                 0.32034230575460987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3276502966775835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.049864250097346796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80509603090079418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24790291457667207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0334799748230101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34814423836262781,
                                 0.58525995464240832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34600028239482089,
                                 0.016811303797724261,
                                 0.64858807412101138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83949885921179346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22700778813685085,
                                 0,
                                 0,
                                 0,
                                 0.38749839157824412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23417864520031967,
                                 0,
                                 0,
                                 -0.62907131138802563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098377315700251822,
                                 -0.31933476882621464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05767681694725986,
                                 -0.311022343900551,
                                 0.8368854003200551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31018356643131251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6757983091362354,
                                 0,
                                 0,
                                 0,
                                 -0.47916852847749863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35650911525959078,
                                 0,
                                 0,
                                 -0.58622819118488712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45964105886997031,
                                 -0.25899290132371866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027544737410725828,
                                 0.36967486800419447,
                                 -0.32721500180651275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6855307702508755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80134861449996309,
                                 0,
                                 0,
                                 0,
                                 -0.038602047779989206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66476893611931209,
                                 0,
                                 0,
                                 -0.93853981767969852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27022825933179984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.097658401850414162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3453343615388057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076686446819632909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46393797110819718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34273419881836398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35650555232421305,
                                 0,
                                 -0.26387421258479277,
                                 0,
                                 0,
                                 -0.079403607898460127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29547275300419612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22606370782276092,
                                 0,
                                 0.34374122582351979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039865512330557989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24899335487025859,
                                 0.51911956151798244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58090351055994938,
                                 -0.43450540720151559,
                                 -0.47107742118549073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4056683966593691,
                                 0,
                                 0.14105273521832434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27753614776106866,
                                 0,
                                 0,
                                 0.47206996444530058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35139438942969914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.097489757405701816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0482714265544536,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69219543254964788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31562913351453908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35694472660352594,
                                 -0.34227924684770794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20667527161723034,
                                 0.18996929645884952,
                                 -0.36580289817045136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13783965268959886,
                                 0,
                                 -0.3489545355175443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85520922096503471,
                                 0,
                                 0,
                                 -0.33928632457273272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23234025135735681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.089843881775408793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25562267475572542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021112774362657877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58131134508052196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41244533101383701,
                                 -0.43271144363379932,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044166133728051629,
                                 -0.063378154928758743,
                                 0.33114858902779976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34672200263127423,
                                 0,
                                 0.65871202666878537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35210325808089332,
                                 0,
                                 0,
                                 -0.23238414235609636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1641371259814631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25743730276051008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40244942764979091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36625673619050719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18369476705490587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13737177164019088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18318503420390433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10234027229677513,
                                 -1.2532378284694281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41597970428288239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37440314448416545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2719602346211078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35787551435556769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28242461890423581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10924090461355732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38060574408408271,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24743371888163185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28192096175682846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12245612623324292,
                                 0,
                                 -0.067427687759971766,
                                 0,
                                 0,
                                 0.49809898896245808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07275545632389141,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43159338871061814,
                                 0,
                                 0.18829089445778732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08578330746236601,
                                 0,
                                 0,
                                 -0.24024501400224169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22841485876883974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70705715603686337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61806855384403181,
                                 0,
                                 0,
                                 -0.028489481351878267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13617943660217952,
                                 -0.3996771209826932,
                                 0,
                                 0,
                                 0,
                                 0.62851097986780868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14025904495841765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20586575778223845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27260739159994696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53842514654321916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020434526919920787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3877898849762188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075997918908666542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46467564887295665,
                                 0,
                                 0,
                                 0.4378812167245143,
                                 0.2736628278581773,
                                 0,
                                 0.098892176619397448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77033123627567979,
                                 -0.48981657116642607,
                                 0,
                                 0,
                                 0,
                                 -0.45227920881123806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3179927401313587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094163078261803992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22572170600484759,
                                 -0.030419859208279498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32427269863653868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42226611930324304,
                                 0,
                                 0,
                                 -1.0036338422992337,
                                 0.089061357441880762,
                                 0,
                                 -0.084482047946612085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49637835329602487,
                                 -0.01999106777285703,
                                 0,
                                 0,
                                 0,
                                 0.14342339705536924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5274494196351196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92241081685440829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.075693422369822155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62689362744031907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37074394916659514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68592127839518779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075903881987111038,
                                 -0.15096073471975049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064184783623552899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68140986058730779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.337789261742655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023961915115456565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065023023624702872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49631163801929462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41662949411724776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30998793743585795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082661236111527606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098368428340925518,
                                 0,
                                 0.34719798504031307,
                                 0,
                                 0,
                                 0.26004850350423142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49124285551358138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14331126372609357,
                                 0,
                                 -0.1125227986706458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53449422060041085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25668475969917415,
                                 -0.12221373380799126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19478924831755579,
                                 0.2558718897438198,
                                 -0.74295534166692256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.068910505386684903,
                                 0,
                                 0.32302815691469117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21142233940386565,
                                 0,
                                 0,
                                 -0.7808856536603066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2480584501258675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2182752012118685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14313810262892318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078563425402007447,
                                 0,
                                 0,
                                 0.49850333494269805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56496101163027912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41082953069260109,
                                 0,
                                 0,
                                 -0.90335433816938437,
                                 0.46442202035270236,
                                 0,
                                 -0.24591479525543197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11702447592015362,
                                 0.63045636985642273,
                                 0,
                                 0,
                                 0,
                                 0.23921295439478898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22756858954337766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21483470602898785,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59992009039939842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59267085371037764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1547371964110949,
                                 -0.073850339753245065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24205231646326542,
                                 -0.043507115404908286,
                                 0.043432306422993464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86666915414737966,
                                 0,
                                 0.47609729326922623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065261833299551028,
                                 0,
                                 0,
                                 -0.20921621296563078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80464049819045469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059442050751531916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71592674637604059,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.018295203530289628,
                                 0,
                                 0,
                                 0,
                                 0.074200534449814365,
                                 0.16723254694249057,
                                 0,
                                 0,
                                 0,
                                 0.58392722261690566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24526967050321027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17979599090481749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17898061648990632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6452380510843273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29104388218442878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68268651499035538,
                                 -0.61026729473434549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015640157168970093,
                                 0.019239981354889218,
                                 -0.17081157473336248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52954162379613168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06215174496712017,
                                 0,
                                 0,
                                 0,
                                 0.61277409040305553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86548728176243162,
                                 0,
                                 0,
                                 -0.79274602183776732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68350905206875612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0398929248700792,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10340391640310007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73404006982555936,
                                 0.42068445725675258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31023788109621359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29381672266572167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027015038869127685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40139386107287245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38462359088292775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71495887467034658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.97524160462765663,
                                 -0.23247502397008171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26796628892807256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041361839256247757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21062848470365705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25957616749051238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16569118567443097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23197833052810862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65436814826057521,
                                 0,
                                 0,
                                 0,
                                 0.3239722091876473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38335555645427932,
                                 0,
                                 0,
                                 0.17842124492275718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13994818189207558,
                                 0,
                                 0,
                                 0,
                                 0.044653392133923359,
                                 0,
                                 0.025345739569913178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13097991309306239,
                                 0,
                                 0,
                                 0,
                                 0.13252415263216122,
                                 0,
                                 0,
                                 -0.14276595023085023,
                                 0,
                                 0,
                                 -0.24915673494752572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56771252518977822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15895541338495167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21242327341285608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13586183785678072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051022062526297818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11482591741271872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036383322100686635,
                                 0,
                                 0.5387574760446292,
                                 0,
                                 0,
                                 -0.1095004642887473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32711541988680221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22167317509453974,
                                 0,
                                 -0.33667213541690189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52872237105579045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32348130791786772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.99027997957955227,
                                 0,
                                 0,
                                 0.71404000870387252,
                                 -0.024248635458746087,
                                 0,
                                 0.20945217113069703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1848392480054234,
                                 -0.20742861214544506,
                                 0,
                                 0,
                                 0,
                                 0.29320720234795683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40318635007851078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096710038032790741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29573098329129527,
                                 0,
                                 0,
                                 0,
                                 -0.19612262471060055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75120724765449887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023281934118263927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12191198398230405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077292248407818148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19502774163163203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080182223267636604,
                                 0,
                                 -0.033590636529637084,
                                 0,
                                 0,
                                 0.15158669304249303,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20759272578248711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48737325083796923,
                                 0,
                                 -0.16323487511858595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068128676304758884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47866745422798723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035230997917155116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062217627536731566,
                                 0,
                                 0,
                                 0,
                                 -0.098719515655600637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036476985311130208,
                                 0,
                                 0,
                                 0.25890857238618353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15348297770473002,
                                 0,
                                 0,
                                 0,
                                 -0.17870046685397095,
                                 0,
                                 0.16711123826362825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53142004515073216,
                                 0,
                                 0,
                                 0,
                                 -0.29498796252600357,
                                 0,
                                 0,
                                 -0.37855358979127918,
                                 0,
                                 0,
                                 0.29473531046273116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53618979698073899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72918224434960865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40663592151945749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23440960416151757,
                                 -0.59259896354520547,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84982484107826806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29818704773242122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52603834467619592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24175158469369629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028229987814672397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30466272113370513,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31474415567270592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13063323005893729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51477435187571718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51257265226927751,
                                 0,
                                 0.20236438152478767,
                                 0,
                                 0,
                                 0.1089173364041077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20449184801791942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090128140454161551,
                                 0,
                                 0.31832885075265804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37531917065311232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48433056207065617,
                                 0.13360346750022542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27726048775754347,
                                 0.16417573629295981,
                                 0.00081771702574828103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19386102068198574,
                                 0,
                                 -0.14141641886081421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1873334270019012,
                                 0,
                                 0,
                                 -0.22863903306700514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59622588490666695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87505739706499652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37012822942931611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3843300676600192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29119140247634878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54478738910418278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21873341814275227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91156947337750627,
                                 0,
                                 0.58414155811219026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69487721259239066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012476584937465613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22122471728054424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57111585577218293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2443331097047135,
                                 0,
                                 0,
                                 0,
                                 -0.17272967183331683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057430826325762747,
                                 0,
                                 0,
                                 -0.086459265438359148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13397364796980291,
                                 0,
                                 0,
                                 0,
                                 0.062375727504361204,
                                 0,
                                 -0.24226346363323392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0973558187353631,
                                 0,
                                 0,
                                 0,
                                 -0.615690437544541,
                                 0,
                                 0,
                                 -0.10939886594852231,
                                 0,
                                 0,
                                 -0.20825630462475248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41464047778763241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09677174411953185,
                                 -0.38230109397766343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52231618833235993,
                                 -0.80825116895981841,
                                 0.22320906494344114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12003914269217386,
                                 0,
                                 -0.20348020033618353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11990003242565023,
                                 0,
                                 0,
                                 -0.50827247265777697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46165464136773049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33923873341527577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28316730154915221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014405879875900723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4356682431082104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2889973698158414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39200054902586884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33807973270537128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046763873239632096,
                                 0,
                                 0,
                                 0,
                                 -0.31138519374966722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22683882527780952,
                                 0,
                                 0.15586434930595999,
                                 0,
                                 0,
                                 0,
                                 0.0015822824300341584,
                                 0.53273981989450292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47860661992203046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078401661959816293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32319169759899047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21077253709130767,
                                 0,
                                 0,
                                 0,
                                 0.30132621854117819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50889488812721795,
                                 0,
                                 0,
                                 0.040012761111049649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33140800537210141,
                                 0,
                                 0,
                                 0,
                                 -0.099289762272302892,
                                 0,
                                 -0.049162658439457885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16312918919539199,
                                 0,
                                 0,
                                 0,
                                 0.061531206722439766,
                                 0,
                                 0,
                                 0.27260907880270657,
                                 0,
                                 0,
                                 0.19421330353581157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41200123744547557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89763025671976715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51328906638036176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28370636559282186,
                                 0.22939600508030664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50656955557647587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58114565476697266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90265456393406218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048903792489894182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063821179049040472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30407552721913439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013770273388784275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25558174310755649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21550068449165583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63310170067732252,
                                 0,
                                 0.44651045003759404,
                                 0,
                                 0,
                                 -0.091575050334647898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16788930948050973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38712453064602054,
                                 0,
                                 0.049935952709434087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13935359002215877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.361713262938643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76398225108439455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00048396114257504008,
                                 0,
                                 0.33912220422805212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33361204948752599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54301706973235564,
                                 0.032331685075730733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31707129931950651,
                                 1.0165243456152437,
                                 0.18055548752901171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068344762048747926,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28222061104357271,
                                 0,
                                 0,
                                 0,
                                 0.18461017038629679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76209192066483455,
                                 0,
                                 0,
                                 0.34039894051386577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037984530655879034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090908786310077844,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22665694856842711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95818185975534742,
                                 0,
                                 -0.029554075384296996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.724955506914021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17742948854428012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061097954675294407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37959548570318824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1103869728585974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25945886090534281,
                                 0,
                                 0,
                                 0,
                                 0.45319101800834971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65611471041357938,
                                 0,
                                 -0.059418493776179603,
                                 0,
                                 0,
                                 0,
                                 -0.25053198376123909,
                                 0.19754355258896944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21141332852307462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21394089954488421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26164799103086434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19778257832144119,
                                 0,
                                 0,
                                 0,
                                 -0.14064373067610209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36719177807909731,
                                 0,
                                 0,
                                 -0.22253468807060722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35547212482342444,
                                 0,
                                 0,
                                 0,
                                 -0.10991896547938614,
                                 0,
                                 -0.50690240904225292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39590385371570297,
                                 0,
                                 0,
                                 0,
                                 -0.15100986368419894,
                                 0,
                                 0,
                                 0.032284123025073351,
                                 0,
                                 0,
                                 0.14780108442406142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1957347448264371,
                                 0.13899089716190532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.7747809460027171,
                                 -0.23338802703573247,
                                 0.2701501646184809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13745901971774441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20750142078705067,
                                 0,
                                 0,
                                 0,
                                 0.16208111643291628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027571213955366349,
                                 0,
                                 0,
                                 0.011856847035604658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67959211531236852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33208101414854163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72886836838683078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1635604192821989,
                                 0.058440010095602367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26249835656548676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056119230355822808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33868262274047817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13603987006951593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05404841440699349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32066724643054001,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075119894053541206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18665968353804463,
                                 0,
                                 0,
                                 0,
                                 -0.57223414064985656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15896481888438341,
                                 0,
                                 -0.15568348514530195,
                                 0,
                                 0,
                                 0,
                                 -0.65714725535264573,
                                 0.16265920092137173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1236943984759671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18008025274512657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3852488804410969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47193706214137382,
                                 0,
                                 0,
                                 0,
                                 0.39662226911752124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22840620422516358,
                                 0,
                                 0,
                                 0.12795850661587529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1564982177392828,
                                 0,
                                 0,
                                 0,
                                 0.29576652063233166,
                                 0,
                                 -0.042139906490248777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15413890283633727,
                                 0,
                                 0,
                                 0,
                                 0.15102058433944338,
                                 0,
                                 0,
                                 -0.24080324879884235,
                                 0,
                                 0,
                                 -0.37010807672069068,
                                 0,
                                 0,
                                 0.71164672626751047,
                                 0.034762632076822342,
                                 0,
                                 0,
                                 0,
                                 -0.15882868782561019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14890477645200895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082028364877299587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29072325003122895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29454788009227584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51666642764662996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021755605594411878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53202380550085415,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14114440132178774,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2874850320146552,
                                 0,
                                 0,
                                 0,
                                 -0.28701220385787402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13490634588140124,
                                 0,
                                 0,
                                 0.18925252982039634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25820524058844918,
                                 0,
                                 0,
                                 0,
                                 0.02806693533386681,
                                 0,
                                 -0.45994967814331461,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.335613995657148,
                                 0,
                                 0,
                                 0,
                                 0.28327960650343031,
                                 0,
                                 0,
                                 -0.031639255190780577,
                                 0,
                                 0,
                                 0.067964648322346569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30181218423198147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39315673589490885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11468020322740473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13781168942142563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43894309419392957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17595015676144887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25704274238493047,
                                 0,
                                 0.29691612020971647,
                                 0,
                                 0,
                                 -0.23644302283996685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3550586812771836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38908726551225736,
                                 0,
                                 -0.1047523454355038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23695504003353249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45244266773584596,
                                 -0.72301017042765658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14197352020958787,
                                 0.6002640784312665,
                                 0.10251775068697616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5141946424844388,
                                 0,
                                 0.33977375416125188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32011474012703139,
                                 0,
                                 0,
                                 0.33583318278978563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91207798697088927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27966966689860484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095499199348821645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033454194377815299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065003570045749012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27550419598429499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18750707701524216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66413509588825292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29136538873721346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39881315355425756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15967795415108682,
                                 0,
                                 0.10787529118611401,
                                 0,
                                 0,
                                 0.15424001914494953,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32167109889908602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059410666871186762,
                                 0,
                                 -0.17822987670969886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14746646445283812,
                                 0,
                                 0,
                                 -0.66739838320582012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040389310646787462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13023589894407006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38609300817543984,
                                 0,
                                 0,
                                 0.60429507958098183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22286762526450887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77948664999260941,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.096674449126176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11299387787556725,
                                 0,
                                 -0.87730340129883833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20029604878256699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38459781225443535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.003178510438615334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35904998101958641,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35792598419548877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23204962857133826,
                                 0,
                                 0,
                                 0,
                                 0.27625610518372168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18383934966063351,
                                 0,
                                 0.48132784020564823,
                                 0,
                                 0,
                                 0,
                                 -0.20035833509899123,
                                 0.39908043849871661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34076671064973996,
                                 0,
                                 0,
                                 -0.081272529178653477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57691668861383116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17374717846232129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51391046701916454,
                                 0,
                                 0,
                                 -0.50014788730658333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14713118583642362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31447488050851569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61181209433667172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0018316244585140327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41849343233967229,
                                 0,
                                 0,
                                 0,
                                 0.05011639944648251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077085890103858426,
                                 0,
                                 -0.45423437946821615,
                                 0,
                                 0,
                                 0,
                                 -0.24786717294227992,
                                 -0.23191145354951598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86248389250635826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77424227531792189,
                                 -0.01778385922983617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.809162901075136,
                                 -0.31332898035277329,
                                 -0.061868404336716351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12445920793464581,
                                 0,
                                 0.37533547703096354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26982621818656,
                                 0,
                                 0,
                                 -0.2857431093497817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26973665834631455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38337403047889906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5905311775699944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42574881375185247,
                                 0,
                                 0,
                                 -0.26981591793129606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63454239271122348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1233314209606402,
                                 0,
                                 0,
                                 -0.078331916604085616,
                                 0.378765558459006,
                                 0,
                                 -0.031568029622546949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28446550100284079,
                                 0.94523169391536188,
                                 0,
                                 0,
                                 0,
                                 0.1653750123465563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59545080967069364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015531478889934794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23323671741040108,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23452220065345519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025507611471162508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14885234928715058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01769091935049882,
                                 0,
                                 0,
                                 0,
                                 -0.1947498826716389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19778573553330944,
                                 0,
                                 0,
                                 -0.33390459889729568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3291920416355425,
                                 0,
                                 0,
                                 0,
                                 -0.52773250976774344,
                                 0,
                                 0.45918757398577392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17538430019148016,
                                 0,
                                 0,
                                 0,
                                 0.082120416793473539,
                                 0,
                                 0,
                                 -0.24711878072822321,
                                 0,
                                 0,
                                 -0.19247435116042658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031769973740254726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06172993535930385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15556480169285655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44097506082592974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055949385139333042,
                                 0,
                                 0,
                                 0,
                                 0.41044674983474277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47826104215228515,
                                 0,
                                 -0.40455020804643976,
                                 0,
                                 0,
                                 0,
                                 0.01109351920059987,
                                 0.46087551732140952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083208455241225263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64505717489087644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15184155503733429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48473860760161963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15229150994522039,
                                 0,
                                 0,
                                 0,
                                 0.042529717847033965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027263061375933928,
                                 0,
                                 -0.51978933755007872,
                                 0,
                                 0,
                                 0,
                                 0.12302716345821627,
                                 0.088819056322315307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72028068210596907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4217290211538004,
                                 0.028949145343353425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10169464386687144,
                                 -1.0235050185652139,
                                 -0.071112589897858194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40921576496755485,
                                 0,
                                 0.079734557076507562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33928227508475378,
                                 0,
                                 0,
                                 -0.017937203373688627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080763199421593712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57300793503534597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11271658166433429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52105800648102396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02001232441804264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16178875181481489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37101666034799374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10176172597607863,
                                 0,
                                 0,
                                 0,
                                 -0.010562639243839156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14901015516698185,
                                 0,
                                 0,
                                 0.036429813761175135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5411066014142164,
                                 0,
                                 0,
                                 0,
                                 0.44213571039157679,
                                 0,
                                 0.23664857551778729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12824698084065811,
                                 0,
                                 0,
                                 0,
                                 -0.45666986233078799,
                                 0,
                                 0,
                                 -0.050206262119458694,
                                 0,
                                 0,
                                 -0.17313047017419647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94777634417392786,
                                 -0.33612871696490232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0084974152598431309,
                                 0.67150812745124777,
                                 0.33884335721498016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19106512499540695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091536247765774889,
                                 0,
                                 0,
                                 0,
                                 1.0274378700833557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05467489730156086,
                                 0,
                                 0,
                                 -0.30884661817103481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44974095048390017,
                                 -0.32200197001640296,
                                 0,
                                 0,
                                 0,
                                 0.032812750557382156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70282005875649534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21153730354264935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25264384972593884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29813046738456278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.039450931502210747,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088090103257946917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11164660771355313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051698222637845598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031164175513882349,
                                 0,
                                 0,
                                 0,
                                 -0.24854678641274808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082869601461456194,
                                 0,
                                 0,
                                 0.32527158667717843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022063063999955314,
                                 0,
                                 0,
                                 0,
                                 -0.29339247174528199,
                                 0,
                                 -0.011949586809928794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29364989947075559,
                                 0,
                                 0,
                                 0,
                                 -0.033356853979063315,
                                 0,
                                 0,
                                 0.48609122465391386,
                                 0,
                                 0,
                                 -0.62558008272786791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57300510025938756,
                                 0.75392504588467224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31199464347519734,
                                 0.63934543970241664,
                                 -0.088132537459236424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.04472709275533035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45533171295892833,
                                 0,
                                 0,
                                 0,
                                 -0.40529736586269682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24795682256977461,
                                 0,
                                 0,
                                 -0.73037939495244053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47360721127702232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032948115733838136,
                                 -0.36719630060876107,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68519302605431975,
                                 -0.053293804002314434,
                                 -0.50000294735788686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47323764566248594,
                                 0,
                                 0.64072777522641833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.082124567867386658,
                                 0,
                                 0,
                                 0.34430575071156444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24406823549510925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4454323773973089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037825786134886914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11920611272906284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1663206930523865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16261889281105152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2839891584994656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1602437631483441,
                                 0,
                                 0,
                                 0,
                                 0.020938185170224249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45681261339334556,
                                 0,
                                 0,
                                 0.19848936572814696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080776393135611663,
                                 0,
                                 0,
                                 0,
                                 -0.26355838417970556,
                                 0,
                                 -0.34603173953694732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21012193028602838,
                                 0,
                                 0,
                                 0,
                                 -0.0073086633866743383,
                                 0,
                                 0,
                                 -0.53589049296987301,
                                 0,
                                 0,
                                 -0.2528662539766135,
                                 0,
                                 -1.0660189413388423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82742932306934636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25527345583432898,
                                 0,
                                 0,
                                 -0.28894639458135429,
                                 -0.25412160336565548,
                                 0,
                                 0.46210214893421608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10628629408237254,
                                 -0.13638545459888782,
                                 0,
                                 0,
                                 0,
                                 0.56295766133716374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32807815908306392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046722432892014554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.052509886520463539};

const double rot_4_30[900] = {-0.33060888078289674,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.10294873566075054,
                              0,
                              0,
                              0,
                              0,
                              -0.24969401887490039,
                              0,
                              0,
                              -0.84091105238111252,
                              0,
                              0,
                              0,
                              0,
                              -0.036203430904140438,
                              0,
                              0,
                              0,
                              0.2605032699105212,
                              0,
                              0,
                              -0.20358826746996403,
                              0,
                              0,
                              0,
                              0.77643386671441184,
                              0,
                              0,
                              0,
                              0,
                              -0.2955145577769735,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.42673162954820709,
                              0,
                              0,
                              0.35738174702118886,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.33631211067236144,
                              -1.3049090480026315,
                              0,
                              0,
                              0,
                              0,
                              0.76172787826473454,
                              -0.37790321522419557,
                              0,
                              0,
                              0,
                              -0.022796060631525929,
                              -0.3016039442709455,
                              0,
                              -0.39898400109429577,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.18837759988053027,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.18192696144980408,
                              0,
                              0,
                              0.91694430281301043,
                              -0.09378516858789758,
                              0,
                              0,
                              0,
                              0,
                              0.045958673449634863,
                              0.1955439276707564,
                              0,
                              0,
                              0,
                              -0.17110234688087156,
                              0.32543382434472923,
                              0,
                              0.26932485221569247,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.81219112573119001,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.56050856306595465,
                              0,
                              0,
                              0,
                              0,
                              0.034489258389344801,
                              -1.3169204816030522,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.11356416367966191,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.10174578227163678,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.22660691025812713,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.45130334804554639,
                              -0.59979206396826112,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.1260915835829761,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.81038363248039658,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.44418336266761382,
                              0,
                              0,
                              -0.44383601257127242,
                              0,
                              0,
                              0,
                              0,
                              0.33576752906738816,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.46147931482358717,
                              0,
                              0,
                              0.69087379626004564,
                              0,
                              0,
                              0,
                              0,
                              0.038241126482201571,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.17719161697012734,
                              0,
                              0,
                              0,
                              0,
                              -0.76661001839185594,
                              0,
                              0,
                              0.304643586635793,
                              0,
                              0,
                              0,
                              0,
                              -0.32340757292796862,
                              0,
                              0,
                              0,
                              -0.011131286009701924,
                              0,
                              0,
                              -0.42652754681077076,
                              0,
                              0,
                              0,
                              0,
                              0.28809015173900476,
                              0.1795403612667773,
                              0,
                              0,
                              0,
                              0,
                              0.83078621079764725,
                              -0.39181773161495043,
                              0,
                              0,
                              0,
                              0.17470896832212818,
                              0.30131120680394263,
                              0,
                              0.52595092571154067,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.20977765678825466,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.26355964026965267,
                              0,
                              0,
                              -0.72937979174558409,
                              -0.0085979714178930633,
                              0,
                              0,
                              0,
                              0,
                              -0.071162602757111115,
                              -0.55450987508300198,
                              0,
                              0,
                              0,
                              0.12165123889234525,
                              -0.60762317375043551,
                              0,
                              0.40494850230447571,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.47765691388016523,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.18627586720761355,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.46351295827817024,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.88609014073525227,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.2176154511927719,
                              -0.28288626674338563,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.63503267290889309,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.38347818990454891,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.118147533048917,
                              0,
                              0.35668554117502305,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.22601432753595729,
                              0,
                              0,
                              0,
                              0,
                              -0.34118035816829712,
                              0,
                              0,
                              -0.24328369528850499,
                              0,
                              0,
                              0,
                              0,
                              0.67792750132000079,
                              0,
                              0,
                              0,
                              -0.42733669924517481,
                              0,
                              0,
                              0.062446806998681548,
                              0,
                              0,
                              0,
                              0,
                              0.0061773569095771586,
                              0.40101978628705648,
                              0,
                              0,
                              0,
                              0,
                              0.36415641542420268,
                              -0.28652363580274842,
                              0,
                              0,
                              0,
                              -0.45954302697627464,
                              0.14220303872227469,
                              0,
                              -0.10092074074263371,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.5357394904801035,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.82059970248308889,
                              0,
                              0,
                              0.64471871215752286,
                              0.11946362538328234,
                              0,
                              0,
                              0,
                              0,
                              -0.69631553365539045,
                              -0.32905317488307745,
                              0,
                              0,
                              0,
                              0.64100309144387435,
                              -0.12059674043128071,
                              0,
                              -0.053535975476473041,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.11598471259969109,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.26784153830687008,
                              0.58049295285927505,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.55181744942837618,
                              0,
                              0,
                              0,
                              0,
                              -0.14282351406962934,
                              0,
                              0,
                              -0.22437434764534431,
                              0,
                              0,
                              0,
                              0,
                              -0.42755941137207115,
                              0,
                              0,
                              0,
                              -0.207480990134147,
                              0,
                              0,
                              0.24885260419519648,
                              0,
                              0,
                              0,
                              0,
                              0.0053733894816027084,
                              -0.19748822765407811,
                              0,
                              0,
                              0,
                              0,
                              -0.17399275741910808,
                              -0.88569617068203887,
                              0,
                              0,
                              0,
                              -0.065142809047635017,
                              0.35163790894367047,
                              0,
                              -0.77949725399912972,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.76694162015039935,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.40202851645379206,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.46022852125830976,
                              0,
                              0,
                              0,
                              0.003664594026695292,
                              0,
                              0,
                              0,
                              0,
                              -1.6371977508362163,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.1307583640907204,
                              -0.10671811237188172,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.22415349949616437,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.0031121995366960673,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.2174359379515123,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.88609014073525227,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.46351295827817035,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.41358619300736144,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.68628745850671391,
                              0,
                              0,
                              0,
                              0,
                              0.32118465034809857,
                              0,
                              0,
                              -0.28663756735942936,
                              0,
                              0,
                              0,
                              0,
                              -0.37749060650486066,
                              0,
                              0,
                              0,
                              -0.0092505882005852261,
                              0,
                              0,
                              -0.1733510289200724,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.1651763143066289,
                              0,
                              0,
                              0,
                              -0.24381915492681983,
                              0,
                              0,
                              0,
                              0,
                              -0.12360981209395894,
                              0,
                              0,
                              0,
                              0,
                              0.25740396835917562,
                              0,
                              0,
                              0,
                              0,
                              0.24924496878313959,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.75531036286556164,
                              0,
                              0,
                              0.54874985043928226,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.051950571725401962,
                              -0.25842244237948353,
                              0,
                              0,
                              0,
                              0,
                              -0.26693967432499027,
                              -0.0048426077662616779,
                              0,
                              0,
                              0,
                              0.28787317127344481,
                              1.2747583363603032,
                              0,
                              0.22507719698045789,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.18814165100938934,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.51808607577977417,
                              0.38799476861819776,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.075083265519944542,
                              0,
                              0,
                              0,
                              0,
                              -0.18205309963213862,
                              0,
                              0,
                              0.075483382041905106,
                              0,
                              0,
                              0,
                              0,
                              0.20506898298706591,
                              0,
                              0,
                              0,
                              0.83070171581360364,
                              0,
                              0,
                              0.26993121767331985,
                              0,
                              0,
                              0,
                              0.3659279186351978,
                              0,
                              0,
                              0,
                              0,
                              0.85895765792159606,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.18558883070103441,
                              0,
                              0,
                              -0.30634178001079426,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.47952459257470537,
                              0,
                              0,
                              0,
                              -1.1462205967903478,
                              0,
                              0,
                              0,
                              0,
                              0.62181376473201744,
                              0,
                              0,
                              0,
                              0.32162907373065786,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.3546713161385513,
                              0,
                              0,
                              0,
                              0,
                              0.27723000011433696,
                              0,
                              0,
                              0.051684106302137003,
                              0,
                              0,
                              0,
                              0,
                              0.25913637390771987,
                              0,
                              0,
                              0,
                              0.12727219260767861,
                              0,
                              0,
                              -0.77967006184594134,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.57523251035664302,
                              -0.41677822958628968,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.90108576500772208,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.775860621074699,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.79721454600170483,
                              0,
                              0,
                              0,
                              0.099787684545855973,
                              -0.57077836481489697,
                              0,
                              0,
                              0,
                              0,
                              -0.099624504375883133,
                              -0.4591600213230374,
                              0,
                              0,
                              0,
                              -0.90701588834558511,
                              0.22800692025200237,
                              0,
                              0.52746095728936149,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.34187594668766974,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.036276197871595049};

const double rot_4_2[4] = {0.88076609621788271, 0.47355156398549814, -0.47355156398549791, 0.88076609621788293};

const double rot_5_50[2500] = {-0.048122315054742251,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1053316919856522,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.006070361112375619,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.38017306917807209,
                               0,
                               -0.16106863072676242,
                               0.40987183474981459,
                               0,
                               0,
                               0.11332558980882702,
                               0,
                               0,
                               -0.37628644875608863,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.52038274650785565,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.55635647066352334,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29012634269670101,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.58366921032294716,
                               0,
                               1.0854839584833529,
                               0,
                               0,
                               0,
                               0,
                               -1.4626049126391294,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41741058638236767,
                               0,
                               0,
                               -0.9053834470650417,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.048965856528801477,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.07229787916257216,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.99162118299568047,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11410774573261456,
                               0,
                               0,
                               0,
                               -0.27256348972855959,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57908075799918668,
                               0,
                               -0.76835839279731744,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.42032503266461868,
                               0,
                               0,
                               0,
                               0.81859671132004752,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.2487696296016623,
                               0,
                               -0.033778271384026212,
                               0.2519072962723849,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16352891177521342,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.99659765918073273,
                               0,
                               0,
                               0.052090198337587809,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28402440875034063,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.59760344520565611,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18377247685954379,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16186503429807544,
                               0.68531206185893989,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.050666933010092619,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24202372067433789,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.4079706133197758,
                               0,
                               -0.17258327756563432,
                               1.137433630615581,
                               0,
                               0,
                               0.54981758824925719,
                               0,
                               0,
                               0.24264875912796086,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.015686946996386231,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.84806251830433932,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42569189103162608,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25755391651282949,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.74238055075783871,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34569123737947149,
                               0,
                               0.14854554643035672,
                               -0.20163744995951302,
                               0,
                               0,
                               -0.11025464427926268,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.083315983332998583,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.64467381223921594,
                               0,
                               0,
                               0,
                               0.066301631979038572,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30030951063641304,
                               0,
                               -0.3506453509169043,
                               0.59388791159860277,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11899140123808481,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.9908062414833233,
                               0.31541838755551516,
                               0,
                               0,
                               0,
                               0.18701601740593132,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23810159281495166,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.34861328436324374,
                               0,
                               0,
                               1.0907693176587445,
                               0,
                               0,
                               0.41766998951820244,
                               0,
                               0.18408252035058995,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14997417298407123,
                               0.49772858670749598,
                               0,
                               0,
                               0,
                               0.94605570799906291,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54054861454632641,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.6805501139370087,
                               0,
                               0,
                               0.081509572758394516,
                               0,
                               0,
                               -0.32395527350927578,
                               0,
                               -0.37956140918470016,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.66834395369200561,
                               0,
                               0,
                               0,
                               0,
                               -0.34226084669943524,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.47328248871339179,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28705917612138987,
                               0,
                               0,
                               0,
                               0,
                               -0.36024240125461121,
                               0,
                               0,
                               0,
                               0,
                               -0.18042812019902355,
                               0,
                               0,
                               0.60060330872812018,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12663173030419866,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44464078830182407,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.77037106116858833,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.6467364291827119,
                               0.45093700127033498,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.019087665909070083,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.090994343349523929,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.2489887643995394,
                               0,
                               -0.041285425877156882,
                               -0.2692950939119016,
                               0,
                               0,
                               0.013559090303860901,
                               0,
                               0,
                               -0.54288972243080735,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10896630688812281,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15086082405682977,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.80398006003797395,
                               -0.0037758378378203172,
                               0,
                               0,
                               0,
                               -0.14646392989814511,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4598250882284996,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18719513290344181,
                               0,
                               0,
                               0.48661558695915386,
                               0,
                               0,
                               0.56772114147468367,
                               0,
                               -0.82552008709390845,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35067245293093346,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.072939808713515533,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2709092158044471,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2238065939202622,
                               0,
                               -0.073761606300786445,
                               -0.42810018894516777,
                               0,
                               0,
                               0.058897845772394215,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.74568620598391022,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.69519881673294948,
                               0,
                               0,
                               0,
                               0,
                               0.44414548684475291,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14257955558227534,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43022372153211574,
                               0,
                               0,
                               0,
                               0,
                               0.33765664733507211,
                               0,
                               0,
                               0,
                               -0.98182959185141405,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.80757256622339346,
                               0,
                               -0.5658323342033813,
                               0,
                               0,
                               0,
                               0,
                               0.21175068772913755,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.068642964068352796,
                               0,
                               0,
                               0.038812121334941427,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1150124389251259,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.42354673147436517,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1248191783786648,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18950905038076143,
                               0,
                               -0.032414753446740073,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.73224226122512348,
                               0,
                               -1.0884167842640446,
                               0,
                               0,
                               0,
                               0,
                               -0.80569831831816474,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15139102245013153,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1989079511592258,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1148965958077091,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14840369597391326,
                               0,
                               0.81279900632622959,
                               0.21791642144794776,
                               0,
                               0,
                               0.12721817117353576,
                               0,
                               0,
                               -0.33239083721217455,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.081628966104035069,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27254020090199282,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51113663414815669,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40792433017926777,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26666254415366197,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24094908942090049,
                               0,
                               0.521647399532293,
                               0.31392179833075756,
                               0,
                               0,
                               -0.26782054864636934,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.027945567608499394,
                               0,
                               0,
                               0,
                               0,
                               0.33683751844692617,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42230615743119704,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19469222843133963,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58736448528966012,
                               0,
                               -0.4865612280086215,
                               -0.85197968586364869,
                               0,
                               0,
                               0.56013551156104235,
                               0,
                               0,
                               -0.33724649470256773,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22232371286516223,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15666363703693351,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31955540716607589,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.6098385390211325,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.014434523771651192,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.063685050506689322,
                               0,
                               -0.46018852367132712,
                               0.071481665105196504,
                               0,
                               0,
                               0.20647084389052942,
                               0,
                               0,
                               -1.1192820887954642,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12550836673575938,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24104775345818602,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.6205926207870871,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.72269485421689428,
                               0,
                               0.22130814143509264,
                               0,
                               0,
                               0,
                               0,
                               0.66463712316495349,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.073791445265741329,
                               0,
                               0,
                               0,
                               -0.051351003758941638,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.61638431669384275,
                               0,
                               -0.49414383191084482,
                               0.21907388354711083,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56552345493751166,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.062561854631488292,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31441984021613273,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28648460778187007,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.017888165657143223,
                               0,
                               -0.7038040166338364,
                               -0.37416728033198338,
                               0,
                               0,
                               -0.67808625213031581,
                               0,
                               0,
                               0.45996464830407474,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.60784590975253749,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16191425740189749,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.45026208798323536,
                               0,
                               0,
                               0,
                               -0.49142858138589335,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17336009251699763,
                               0,
                               0.30083788193362104,
                               0.65273935652462378,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.095583372414010451,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44433812553489599,
                               0,
                               0,
                               0,
                               0.14637527738177397,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.059014170155693636,
                               0,
                               0.66767235892775367,
                               0.040511987854876585,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.57465436224940813,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10937670359447005,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23030549961123944,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16138178835705175,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27475974371110373,
                               0,
                               -0.32401668972726649,
                               0.069819106195718739,
                               0,
                               0,
                               0.30203526657715279,
                               0,
                               0,
                               0.58253966533548163,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.64838181840706066,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51845580145492109,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18364357703633075,
                               0.87433665511697889,
                               0,
                               0,
                               0,
                               -0.31019079973049279,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41506829915424998,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1344451681442044,
                               0,
                               0,
                               -0.75540402061127576,
                               0,
                               0,
                               1.0895335477204267,
                               0,
                               -0.36036187015568294,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13165526907214178,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.016476274692470344,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39007245415480052,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.69845633881863822,
                               0,
                               -0.13394295238240603,
                               -0.4804141442886346,
                               0,
                               0,
                               -0.30492529663883516,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.026071914309009663,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1821732201262203,
                               0,
                               0,
                               0.079311235653375306,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32849925920766271,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.54967955667568069,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.094345348237091647,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.2082558007515849,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24631943740282961,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.73265594574120274,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19993262681686197,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19066434590771097,
                               0,
                               -0.50329051527690849,
                               0.10770656644585007,
                               0,
                               0,
                               0.1801199985707852,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16991406873158338,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15941477978874818,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35307458980784789,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.028974441014457175,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49641855550756087,
                               0,
                               -0.029284564904631771,
                               0.40225856960560863,
                               0,
                               0,
                               0.62257350565978009,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22888217278831266,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.069848322278761282,
                               0,
                               0,
                               0,
                               0,
                               -0.71763548825523915,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33314834034318064,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.59870578836488186,
                               0,
                               0,
                               0,
                               0,
                               -0.1033638243123596,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.045880798327286108,
                               0,
                               0,
                               0,
                               -0.24482405885517947,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.65913720073014181,
                               0,
                               -0.30893191736153852,
                               -0.32884131032040431,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.54764837827409152,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35109414304037628,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17631005574966693,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1622163703471762,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.036930046950039271,
                               0,
                               -0.051924836623207592,
                               0.47743924181096775,
                               0,
                               0,
                               -0.55305331943552449,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.53052548983994918,
                               0,
                               0,
                               0,
                               0,
                               -0.63483019207369995,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19716348915225132,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0011234636551371233,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35756039747607221,
                               0,
                               0.26966427332476317,
                               -0.19324886449457485,
                               0,
                               0,
                               0.92995027817248976,
                               0,
                               0,
                               0.28759022033484316,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.57879964711558329,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.45839764238189379,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67684153225267318,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.68297963410014828,
                               0,
                               -0.27463495702892726,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36471889935756285,
                               -0.96967939776678969,
                               0,
                               0,
                               0,
                               -0.19216641176858285,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.77432629202375103,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.65748958010813741,
                               0,
                               0,
                               -0.35831615275903128,
                               0,
                               0,
                               0.34515055599299072,
                               0,
                               -0.024863950655428426,
                               0,
                               0,
                               0,
                               0,
                               -0.68380895305987532,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44520140961088045,
                               0,
                               0.57810122002608033,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0096424532360535921,
                               0,
                               0,
                               0,
                               0,
                               -0.39136001597959891,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28800598267172928,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15936178341558666,
                               0,
                               0,
                               0,
                               0,
                               0.85930247114734681,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.60048883702766176,
                               -0.4752927347850095,
                               0,
                               0,
                               0,
                               0.84038070088028072,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.63300139376336972,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35510167200414477,
                               0,
                               0,
                               0.03690025964459584,
                               0,
                               0,
                               -0.010183048347078692,
                               0,
                               -0.0053547924995366192,
                               0,
                               1.0179282562192684,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.78591470950117892,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14090228182185255,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.55781275729078739,
                               0,
                               0.19281657710932099,
                               0.17939766369038662,
                               0,
                               0,
                               0.092847091879172214,
                               0,
                               0,
                               -0.017872607070378327,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31187276817574061,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19264688863827859,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.45592547799805849,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.26294562376549463,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29169703186226015,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.019035560611728369,
                               0,
                               -0.65236615866568293,
                               0.21299537694842552,
                               0,
                               0,
                               -0.30620045133441653,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26987903682713293,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57875105320381159,
                               -0.19964920204600523,
                               0,
                               0,
                               0,
                               -0.72569948777035553,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22914841364977412,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20384927455956675,
                               0,
                               0,
                               -0.1477615019980239,
                               0,
                               0,
                               -0.57040288759785973,
                               0,
                               -0.83333960561364262,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25503568328153231,
                               0,
                               0,
                               0,
                               0,
                               -0.13201872299464079,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.74949282416784668,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.59047419909810972,
                               0,
                               0,
                               0,
                               0,
                               0.084430940728723355,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22186549778313933,
                               0.31047438824352636,
                               0,
                               0,
                               0,
                               -0.74102117630284947,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22077358106930262,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.79441919867136568,
                               0,
                               0,
                               -0.12523789283446929,
                               0,
                               0,
                               -0.48802262630959303,
                               0,
                               0.56419033296581211,
                               0,
                               0,
                               0,
                               -0.38133041018998437,
                               0,
                               0,
                               -0.54699437330784706,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.070547970270155066,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37216773935987035,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51194553338924653,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49096349477800655};

const double rot_5_20[400] = {1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.057981128268158197,
                              0,
                              -0.34036243228801016,
                              0,
                              0,
                              0,
                              0,
                              0.97432453679418374,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.11886106796505881,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.10981539467828408,
                              -0.93072548827852541,
                              0,
                              0,
                              -0.3279675152855217,
                              0,
                              0,
                              0,
                              1.2544916730567257,
                              0,
                              0.39167433009114616,
                              0,
                              0,
                              0,
                              0,
                              0.47330605658058889,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.68029176865190422,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.3781505921410605,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.62785765836519758,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.0620595039330103,
                              0,
                              1.608407400392365,
                              0,
                              0,
                              0,
                              0,
                              0.36969152310017672,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.72713259361226501,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.24056997579358019,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.64296522305127579,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.87408410098391243,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.31147249671625782,
                              0.055041209260815654,
                              0,
                              0,
                              -0.36869002356938563,
                              0,
                              0,
                              0,
                              0,
                              -0.26861068794564014,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.94377379922486382,
                              0.084652084776363296,
                              0,
                              0,
                              0.17312809928215467,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.386907391052072,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.014713217787434656,
                              0.35150327920920282,
                              0,
                              0,
                              -0.85236825180012155,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.092093978148219499,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.89393971631762847,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.43862339515670407};

const double rot_5_10[100] = {0.30131126885309906,
                              0,
                              0.12272791314188405,
                              0,
                              -0.94559472217117069,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.16420499659730364,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.8349915228696054,
                              0,
                              0.097952096735994754,
                              0.92936988448421198,
                              0,
                              -0.259601108429657,
                              0,
                              0.26244786590082153,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.17716123396301883,
                              0,
                              -0.21031213171569482,
                              -0.010901140445304401,
                              0,
                              -0.96138643092717424,
                              0,
                              -0.21326775911032067,
                              0,
                              -0.9578857571954662,
                              0,
                              -0.19228036583627223,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.11365811832801878,
                              0,
                              0.14277146997825008,
                              0.98116814233227512,
                              0,
                              -0.063302574755028526,
                              0,
                              0,
                              0,
                              0,
                              -0.56808397692926749,
                              0,
                              0.8176314411860871,
                              -0.057911872402842388,
                              0,
                              -0.073523034315692223,
                              0,
                              0,
                              -0.4663045107795088,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.20369018715873097,
                              0,
                              1.5026479236956229,
                              0,
                              0,
                              0,
                              -0.79559809230230327,
                              0,
                              -0.51658875423049189,
                              0.18394688538820197,
                              0,
                              0.25753306172898682,
                              0,
                              0,
                              0.97570142635345058,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.71054236998908782,
                              0,
                              0.34644565244373349};

const double rot_5_100[10000] = {0.46032851417582443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74141265275443535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41938008471531874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17538273064176643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06160170690232588,
                                 0,
                                 -0.78701879103828865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14549211068620935,
                                 0,
                                 0,
                                 -0.26325884276885819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54478024803540626,
                                 0,
                                 0,
                                 0.36309589442230267,
                                 0,
                                 0,
                                 -0.16594535058347082,
                                 0,
                                 0,
                                 0.147664918963504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03170586225531994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10170705580941028,
                                 0.36134800240605286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70416501765242467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36979846636588071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42968071450146861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.049925001080023512,
                                 0,
                                 0,
                                 0.13262411005827196,
                                 0,
                                 0,
                                 0.051491226371486051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13461141605772375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27289807092442409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23183731387899043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37452296010236974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59694841233418094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37244342414859549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68193950125368408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14490379943750903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72300665126005992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037623567060879076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30149669827947184,
                                 0,
                                 0.20438991987561275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14399862299169627,
                                 0,
                                 0.1187238924671242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13162827494096224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28711937251594083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38192308055273777,
                                 0,
                                 0,
                                 0,
                                 -0.044138949362861897,
                                 0,
                                 0,
                                 0,
                                 -0.19941226318870439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0321795501160238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48634478150882521,
                                 0.62690802594494432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42807254445703402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36375006827105327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36464942065082734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25569399452200758,
                                 0.59447029602196255,
                                 0,
                                 0,
                                 0,
                                 -0.21484559053706451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090071434044038973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031791329361998077,
                                 0,
                                 0,
                                 0,
                                 0.24894056082876176,
                                 -0.074227949323385251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0633743556144029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22516820390964504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61317496338764133,
                                 0,
                                 -0.60588558440105411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18144177826215496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15193720246359363,
                                 0,
                                 0,
                                 0,
                                 0.32277975333702691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016905966092195912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088682755555855919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088487649889090247,
                                 0.23884753959847554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092939275213047956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4177699774082505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65533499372356285,
                                 0,
                                 0.12648459873275925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27217431303331024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54524248982336199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33955770811587221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65324532487285603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4049001969601338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60888501375605864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2835289389181423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015222506204541585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037262665558842389,
                                 0,
                                 0,
                                 0.59677136416819054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012491240631746003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10552560382429729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20245346678554149,
                                 0,
                                 0,
                                 1.2273508013740124,
                                 0,
                                 0,
                                 -0.26429960149397386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.97805365975961733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33102963223980958,
                                 0,
                                 0,
                                 0,
                                 0.22976626033909661,
                                 0.15993772242971213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12551892606878351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41089108568489835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38538183620733646,
                                 0,
                                 0.11776603430726179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35271734380667913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038791102693555013,
                                 0,
                                 0,
                                 0,
                                 -0.43244970332048949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90561992475683628,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41190456728206054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29025962978652503,
                                 -0.018345708961073549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30392544959379303,
                                 0,
                                 0,
                                 0,
                                 0.1981600670320014,
                                 0.09822747610911732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18807180024735043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34328606255327176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28958578888363606,
                                 0,
                                 0.4425924468343308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62035347472183444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07625951441173158,
                                 0,
                                 0,
                                 0,
                                 0.014878588846113927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20231763015723822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026560905905106992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61294173747823943,
                                 0.67822646142759768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30219173640737773,
                                 0,
                                 0,
                                 0.13466836398119902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85355374559886332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8728610317106209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23691385607715382,
                                 0,
                                 0,
                                 0.090336835393353243,
                                 0,
                                 0,
                                 0.30636410570535816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88435103264156012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22483335656598497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34320136714077387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22235313140877155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23728207431379672,
                                 0,
                                 -0.025114686314119224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54780549695512781,
                                 0,
                                 -0.015202620403678369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15339792090815055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56770353003310148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27397589037450076,
                                 0,
                                 0,
                                 0,
                                 -0.0098038156296293144,
                                 0,
                                 0,
                                 0,
                                 -0.063160370815839473,
                                 0,
                                 0,
                                 0,
                                 0.49208671479393873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2727641025621559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66091277113513014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50290605480706241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010197766414529113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2684107314621767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14368824018208368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51096091843507607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.008146220956262766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068913646697219777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47738849968966651,
                                 0,
                                 0.066288637821909885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39406051231739431,
                                 0,
                                 0,
                                 -0.51283713294792377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025435448256200758,
                                 0,
                                 0,
                                 0.77405357815185027,
                                 0,
                                 0,
                                 0.11039286701943057,
                                 0,
                                 0,
                                 0.64572812088315468,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35612850799803486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065789615154486641,
                                 0,
                                 0,
                                 0,
                                 -0.12673457548753453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17906790305300974,
                                 0,
                                 0,
                                 0,
                                 0.13752465016702267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10790122276416268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035188784452720792,
                                 0,
                                 0,
                                 0,
                                 -0.037230970237150288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51528583050215027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61988224978288109,
                                 0,
                                 0,
                                 0,
                                 -0.28386294111399285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027625161739940875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020272912195460194,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23666716343291319,
                                 0,
                                 0.40269647926753815,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.049210471155031105,
                                 -0.64249435859465909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32496722853440779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13005731540000975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0072748223790826405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27108726210806566,
                                 0,
                                 0,
                                 -0.46465961830128993,
                                 0,
                                 0,
                                 -0.10173116320026916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017241003857114679,
                                 0,
                                 0,
                                 0,
                                 0.19939958166591798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041515723496946211,
                                 0.39029211418439724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011389014352117588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42133565862906253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70725342270085878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.034751586767845066,
                                 0,
                                 0,
                                 -0.26709126370848485,
                                 0,
                                 0,
                                 -0.081474828268793903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2216842411254546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59448953808019089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20763408631086172,
                                 0.84993750227938503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23970790693932997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44375482525394183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77272678251711469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90444543529602073,
                                 -0.19431897418132146,
                                 0,
                                 0,
                                 0,
                                 -0.41574714015712161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34711293682752214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.486027777403581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90473919668072211,
                                 0.027747010607067135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0519343034624606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10715817258580784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041993028946598988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1654528619547912,
                                 -0.43676469744930646,
                                 0,
                                 0,
                                 0,
                                 0.14370873449415872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1638257973661873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26667501526109344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4443189867430225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16700043838950657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16766140287153047,
                                 0,
                                 0,
                                 0,
                                 0.81439102067047409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028811714524107773,
                                 0,
                                 0,
                                 0.048359554162752977,
                                 0,
                                 0,
                                 0.095205493006784533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04668182019901862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.691305931697345,
                                 0,
                                 0,
                                 0,
                                 0.095933964831770385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13297565973445197,
                                 0,
                                 0,
                                 0,
                                 0.32023628124286602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30880081747154031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098664622449081474,
                                 0,
                                 0,
                                 0,
                                 -0.47068070465242828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031931106952324269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19836556757085735,
                                 0,
                                 0,
                                 0,
                                 -0.048818941090301493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.084662702426267458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083333531513415854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083563011958845884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35495909661682601,
                                 0,
                                 0,
                                 0,
                                 -0.55891448738566052,
                                 0.7032728545141802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12222480929947832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3837231066338529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37825695528857428,
                                 0,
                                 0.16168578571650152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085247610892492498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0322172493662439,
                                 0,
                                 0,
                                 0,
                                 0.47516026308689385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22366643257156821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58191011632674017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69255037232702465,
                                 -0.37700319944348559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32431970838157037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11170937044181732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0018023141130922987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1618057055576145,
                                 0,
                                 -0.14273201563724294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091515129777978169,
                                 0,
                                 -0.53794370330160746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33493108438761726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.005556278629633646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06064365526959227,
                                 0,
                                 0,
                                 0,
                                 -0.6469328097078193,
                                 0,
                                 0,
                                 0,
                                 0.060109206561400376,
                                 0,
                                 0,
                                 0.49251574843735008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49297737317569112,
                                 0.066433478229943804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39990389915838281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022478049723680976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34851396461404333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05877209043874311,
                                 0,
                                 0,
                                 0.035223401489512904,
                                 0,
                                 0,
                                 -0.31016606199193036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35665099550848522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27133138912745652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17733471782350102,
                                 0,
                                 0,
                                 0,
                                 0.34183849858889542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47321069593097237,
                                 0,
                                 0,
                                 0,
                                 -0.51277124389156936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13678421194591511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29180191960796864,
                                 0,
                                 0,
                                 0,
                                 0.20559589737927425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12181559908670307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23022050817980469,
                                 0,
                                 0,
                                 0,
                                 -0.0064008326591351306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24776213570622632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075835237854565266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10034390038992576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58584010637036787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37919823302806122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044749829209321829,
                                 0,
                                 0.51096276855138489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49359020294550943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079267164277555716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051176561154006248,
                                 0,
                                 0,
                                 0,
                                 0.93363782629949943,
                                 0.024309148482491973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11981913895372305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2348638391480489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27569554257369366,
                                 0,
                                 0.023097203923460999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18204274595515602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86144113050040683,
                                 0,
                                 0,
                                 0,
                                 -0.13301534694317305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1503878624719435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032698964628313711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22250359468514533,
                                 -0.70773912554158924,
                                 0,
                                 0,
                                 0,
                                 -0.53198332701054452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062129145341991904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42606364652648987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014385848164949498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6073247730860758,
                                 0,
                                 0.48142089989400472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18450781295692187,
                                 0,
                                 0,
                                 -0.49790253530208994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10167993834296782,
                                 0,
                                 0,
                                 -0.46040948687787353,
                                 0,
                                 0,
                                 -0.094164064929314881,
                                 0,
                                 0,
                                 -0.15489576589833967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40966075777584188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20460239299870556,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1403816950771849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60460621837298945,
                                 0,
                                 0,
                                 0,
                                 -0.052275073128465993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35993124561977541,
                                 0,
                                 0,
                                 -0.47807595771588135,
                                 0,
                                 0,
                                 -0.21028651530649772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26856121925311111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16269613909037267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33254558998586004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41344346630457751,
                                 0,
                                 0.10660856181758097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40296715061842081,
                                 0,
                                 -0.28380340668491627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14302461574758032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35866716968890922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079031236689954126,
                                 0,
                                 0,
                                 0,
                                 0.080210237175790192,
                                 0,
                                 0,
                                 0,
                                 -0.4514561852163938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0423590435204994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28375394523526487,
                                 0,
                                 0,
                                 0,
                                 0.28620510846907199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25495120421617917,
                                 0,
                                 0,
                                 0,
                                 0.001385923413125433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54160532743303269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14420236159632971,
                                 0,
                                 0,
                                 0,
                                 0.072289170655840729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39972890525757049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20645951392049372,
                                 0,
                                 0,
                                 0,
                                 -0.079055767648894409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1098070552521706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10692776270619686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.468260561838168,
                                 0,
                                 0,
                                 0,
                                 0.1544990053830495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26358130435199112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044411388157010796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46683448455265142,
                                 0,
                                 -0.67498193722995048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15241208417787716,
                                 0,
                                 0.023054156195569532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14798884090237835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.045825741046544008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33710182775335962,
                                 0,
                                 0,
                                 0,
                                 -0.062196155684332337,
                                 0,
                                 0,
                                 0,
                                 0.25667078763951445,
                                 0,
                                 0,
                                 0,
                                 1.1166662516765136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086918894770968286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.108529131629457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10102275472445175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13780357466907289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1171426721331956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.07998544853241038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10373589746969472,
                                 0.50717172862199544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15675737908333096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0052871401611665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067802397478556126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51259572129018538,
                                 0.58190430069804155,
                                 0,
                                 0,
                                 0,
                                 0.11724086073516674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95396009386084313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61104904784422909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16560948871521905,
                                 0,
                                 0,
                                 0,
                                 -0.12677796041318035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45343123052513751,
                                 0,
                                 0,
                                 0,
                                 0.019293377161354843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13490439654499659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076969968267042846,
                                 0,
                                 0,
                                 0,
                                 0.33745995146799057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1448367449242767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15918687929191849,
                                 0,
                                 0,
                                 0,
                                 0.13011851866523888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020611766636981204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41764668785906328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032286621419257436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14424003298794441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14325348795146356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45975853898925756,
                                 0,
                                 0.61746644601925371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47650448088986624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37279217351236327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54837600370718365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33464837253684165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062631798869544605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17302996087005731,
                                 0,
                                 0,
                                 0,
                                 -0.073184066712570439,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68351775812871673,
                                 0,
                                 0,
                                 -0.11827198843608067,
                                 0,
                                 0,
                                 0.25863375491558893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49791808993537567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21218947082316714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56126582673505043,
                                 0,
                                 -0.56543313421543129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076361213807455169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25785308158615639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076284466544833104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.016010383227924131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1254332789922793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40341741694257399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35154834328526852,
                                 0,
                                 0.025192905464165923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050960610553718297,
                                 0,
                                 0,
                                 0.53716583500060222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54791660988896895,
                                 0,
                                 0,
                                 -0.39450787907733903,
                                 0,
                                 0,
                                 -0.74729911228282808,
                                 0,
                                 0,
                                 0.49855339342665578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11546284093504093,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014552877944279063,
                                 0,
                                 0,
                                 0,
                                 0.50461125939538387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19747111656633182,
                                 0,
                                 0,
                                 0,
                                 -0.24122126660307944,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13758332186269481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083387059652589551,
                                 0,
                                 0,
                                 0,
                                 -0.46384611502580841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029461899480759664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36448869239436904,
                                 0,
                                 0,
                                 0,
                                 0.25550510465550069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.010141519835573546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43975279814750501,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033428255253086833,
                                 0,
                                 0,
                                 0,
                                 -0.05071692854650918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048831863014655183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12190547040395577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29903161553355889,
                                 0,
                                 -0.58335990320706765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24081167305138718,
                                 0,
                                 -0.10439831014497301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32002108235798132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15362482753824078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46473339486142906,
                                 0,
                                 0,
                                 0,
                                 0.11769872744009112,
                                 0,
                                 0,
                                 0,
                                 -0.35457036857503904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49703412417178872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40514283439385229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034089105580424078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38774583822480019,
                                 0,
                                 0,
                                 0,
                                 -0.069612550192993644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23284594660882257,
                                 0,
                                 0,
                                 -0.28471384764285979,
                                 0,
                                 0,
                                 0.54514433311929233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56352308653638561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0085405872663707593,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30701148830653796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062536605542270043,
                                 0,
                                 -0.11086669570990308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16136954283259144,
                                 0,
                                 0.024050738690930152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.094126987662042874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40428146502314133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43267769053789967,
                                 0,
                                 0,
                                 0,
                                 0.39450142175954683,
                                 0,
                                 0,
                                 0,
                                 -0.17362939928016866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074231801128081226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1794001911251453,
                                 0.8921617298404072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71466998316411312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80016708420902982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82718831948040217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32500125643113809,
                                 -0.21306478130864165,
                                 0,
                                 0,
                                 0,
                                 0.54362835743012161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56769436167638165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072106114777684027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10744856938863491,
                                 0,
                                 0,
                                 0,
                                 0.11298746837583444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05620012164073579,
                                 0,
                                 0,
                                 0,
                                 0.16307181325683898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093599786311100608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37490413786744703,
                                 0,
                                 0,
                                 0,
                                 0.095378963354804613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16501839028586901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034368910298895654,
                                 0,
                                 0,
                                 0,
                                 0.46540223950574139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68153161900718429,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.075980112429068838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25895450390472324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37982612524179082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23263552075148564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0085731397688662975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15572751453384776,
                                 0,
                                 0,
                                 0,
                                 -0.29765517722585028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26031281951337093,
                                 0,
                                 0,
                                 0.76515744277291164,
                                 0,
                                 0,
                                 0.18831088868399667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50662331140146011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96562973282700393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74757756407654463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80838091217587915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029264130523654702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037240764903925694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45283791625876413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14343122929710045,
                                 -0.18977234998020115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14124855208781745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05091743211551876,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33092239818273073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084551692786186627,
                                 0,
                                 0,
                                 0.70436661831794356,
                                 0,
                                 0,
                                 0.30769330068110379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091333992723871896,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18571328438234971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43141218435032297,
                                 0,
                                 0,
                                 0,
                                 0.035731893965543576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35916094858334946,
                                 0,
                                 0,
                                 0,
                                 -0.14466832869099552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.055114417477247275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39107567100087054,
                                 0,
                                 0,
                                 0,
                                 -0.50089997420373444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28587724953767252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24433483744405621,
                                 0,
                                 0,
                                 0,
                                 -0.26139826359674728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037004646139413094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088366979306050267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048793701920953017,
                                 0.40052269911029664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57156530797041305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31891248494808089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18697512527627352,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60417221109525077,
                                 0,
                                 -0.11015583397673029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02230730362694229,
                                 0,
                                 0,
                                 -0.068532706616768191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42356748037942316,
                                 0,
                                 0,
                                 -0.17915756718823023,
                                 0,
                                 0,
                                 0.14326877257375711,
                                 0,
                                 0,
                                 -0.63119363529230776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23649462895226642,
                                 0,
                                 0,
                                 0,
                                 -0.029740795980377523,
                                 0.68969388694153699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26306165293036338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79015082494868627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48807408459578355,
                                 0,
                                 0.720999145744328,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20259095358946522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19547692999684382,
                                 0,
                                 0,
                                 0,
                                 -0.060190450369770616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24325527917088993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56106931327597132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16703166255737512,
                                 0.32261419132417035,
                                 0,
                                 0,
                                 0,
                                 0.89445539355819759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38852833581208435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43524122472954258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044360355853631225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095905703953449842,
                                 0,
                                 0.14844978860497729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0092296296775517817,
                                 0,
                                 0,
                                 -0.44955474964357267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42481011326941515,
                                 0,
                                 0,
                                 -0.4585906725664079,
                                 0,
                                 0,
                                 0.037110917752708944,
                                 0,
                                 0,
                                 0.49024148289765901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50798827849238903,
                                 0,
                                 0,
                                 0,
                                 -0.30099661923343846,
                                 -0.47630537246606958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0014170024110862836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88227813441033165,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16852727546128032,
                                 0,
                                 0.47658641016100262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4056282171416411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15516565557054665,
                                 0,
                                 0,
                                 0,
                                 0.044500269864255135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37452290636033825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38015233807007542,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53144111888639567,
                                 -0.099109232034579248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57752792012999188,
                                 0,
                                 0,
                                 1.1737925658548558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24858935077743233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085006685572878105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3619189077350306,
                                 0,
                                 0,
                                 -0.73441053028809056,
                                 0,
                                 0,
                                 0.43123882381518008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16102055440229679,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32554117936240684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.096547518716475919,
                                 0,
                                 0,
                                 0,
                                 0.11674292528820654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13349908443124431,
                                 0,
                                 0,
                                 0,
                                 -0.15870856263559149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16508069145580354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073167193809677761,
                                 0,
                                 0,
                                 0,
                                 0.04791346039190178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076668779202497317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43654697344088411,
                                 0,
                                 0,
                                 0,
                                 -0.23256324497893938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29366610867045795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51870377469308371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43281752117453814,
                                 0,
                                 0,
                                 0,
                                 0.44156035844357683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13076058153377354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64481781556215345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.031764311962750286,
                                 0,
                                 0.10292906628869113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18450854024441932,
                                 0,
                                 -0.48943349891711535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068953221430065242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064745263216052257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11881575081822812,
                                 0,
                                 0,
                                 0,
                                 0.15483626206023104,
                                 0,
                                 0,
                                 0,
                                 0.19976546966152797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16849289539349857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17625563660814469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72577685836191297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3507191912971811,
                                 0,
                                 0,
                                 0,
                                 0.32223331969044361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11564555531975278,
                                 0,
                                 0,
                                 0.14230814072649325,
                                 0,
                                 0,
                                 0.39157155385313736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12230656679045918,
                                 0,
                                 0,
                                 0,
                                 0.43563426307870085,
                                 0.29065438537116484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29872199013797973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27458013998559527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10257448386143644,
                                 0,
                                 -0.7029844788953401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67449716956431094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078674221830687507,
                                 0,
                                 0,
                                 0,
                                 -0.47074212051774811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58105150191932264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69467041064066426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58958510661535046,
                                 0.37186794050255034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51558788768606112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21298190267221345,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72747323911939132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036132520126177348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63054451093504871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90600234672308178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.07813894831104902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62640499999672772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18548250633301716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12751980389754591,
                                 0,
                                 0,
                                 0,
                                 0.36118143208024567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49950401466377559,
                                 0,
                                 0,
                                 0.25235636342240292,
                                 0,
                                 0,
                                 -0.32742327114874348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36733491783416206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058656831378278804,
                                 -0.2872747212792236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098772285380412606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34104317961318964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71998695749133301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028072675443719861,
                                 0.78696869279866422,
                                 0,
                                 0,
                                 0,
                                 0.47172539928905188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14304955029002478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20442840365524867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59895885988209741,
                                 -0.098008661889743831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048368359627291989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13487087719525595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040728538999549445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5002373106129695,
                                 0,
                                 0,
                                 0.26416853571002696,
                                 0,
                                 0,
                                 -0.49677532773005711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029241068636665313,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18584913581584198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083783592213804992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62136118071641711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51238507195214122,
                                 0,
                                 0,
                                 0,
                                 -0.030786745332150339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13253189755630701,
                                 0,
                                 0,
                                 0.068214665427809767,
                                 0,
                                 0,
                                 -0.53539374426126818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37269748874871123,
                                 0,
                                 0,
                                 0.16836799321677748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20867805400390393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60037136556684945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81989784055947867,
                                 0,
                                 0,
                                 0.28545326105743291,
                                 0,
                                 0,
                                 0.54475951217356033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20390138868619326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21735166997506439,
                                 0,
                                 0,
                                 0,
                                 0.10877708411786563,
                                 -0.76766827035652696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10249069956838737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41717842930759746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84402071779389909,
                                 0,
                                 0.42974934424946648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27935997849214994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065020280478484696,
                                 0,
                                 0,
                                 0,
                                 0.48453664170980326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027559540056664722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15990197404804965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72198015386611625,
                                 0.28227357014710086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59314054218778511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66286232210279517,
                                 0.38701415775469417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8221842202768963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.75711506141771689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64551446254640643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36828886594104443,
                                 -0.14758993215670391,
                                 0,
                                 0,
                                 0,
                                 0.44142205466578927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35851318120685005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7042443156591609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15116966762301065,
                                 -0.71844635160225434,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49558669016624246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33902773692207017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22881989617256054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1030861614298861,
                                 0.080944995985606116,
                                 0,
                                 0,
                                 0,
                                 -0.36096391294840424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45223058311044378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16775152992071563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14794752264731284,
                                 0,
                                 0,
                                 0,
                                 -0.45522978202707842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26572841416442261,
                                 0,
                                 0,
                                 0,
                                 -0.63804773852835384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15224310313512956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080023587381980524,
                                 0,
                                 0,
                                 0,
                                 -0.13166696695687552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083251493171420138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026205055413773933,
                                 0,
                                 0,
                                 0,
                                 -0.0062764710575340943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098449804201046626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.029863404896030905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44705846302458307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25453205357208308,
                                 0,
                                 0,
                                 0,
                                 0.52668502909302939,
                                 -0.079985198121823892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41326588191904423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1528346393830699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26500880217963357,
                                 0,
                                 -0.11623432860365288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86774546690323673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28353164287901506,
                                 0,
                                 0,
                                 0,
                                 0.2515093882004687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30277153163560416,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2041602022419437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26627377765017629,
                                 0.58881952417418071,
                                 0,
                                 0,
                                 0,
                                 -0.22708241717159725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11332111634420533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21299448139573302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63238000293522123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50329528478889218,
                                 0,
                                 -0.28085938995206033,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46259631272182489,
                                 0,
                                 0,
                                 -0.10831722769056176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17778892483126885,
                                 0,
                                 0,
                                 -0.21072303501017839,
                                 0,
                                 0,
                                 0.68282901531205875,
                                 0,
                                 0,
                                 -0.096130535506436202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065188782766360212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87859706727543818,
                                 -0.2528421434504699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067530173871039656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083826285005373549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49797476173070376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034718383925535889,
                                 -1.015476303975424,
                                 0,
                                 0,
                                 0,
                                 0.55421508793936436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50446608527116565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46593078200207383,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059679432840283646,
                                 0,
                                 0,
                                 0,
                                 -0.25617614584563692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090144867027251552,
                                 0,
                                 0,
                                 0,
                                 -0.20973085238481315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50576544045853544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26541223649103934,
                                 0,
                                 0,
                                 0,
                                 -0.06941286274368845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054926887848003036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12805629709823846,
                                 0,
                                 0,
                                 0,
                                 0.26960213083621842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1240265087003808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18233119689629937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43568235851447362,
                                 -0.21066279357879211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.085487058103920863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37614779379502911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62395751094802065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74337197431710933,
                                 0,
                                 0.22203687256047369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22086136471592743,
                                 0,
                                 0,
                                 0.0038345691608218622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86062443543512257,
                                 0,
                                 0,
                                 -0.45406774651136683,
                                 0,
                                 0,
                                 -0.33217989276267962,
                                 0,
                                 0,
                                 0.018182574836788437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61249911728453232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61666246492900056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20167654259425491,
                                 0,
                                 0.14052984570851657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42569001152578767,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054205021842076914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26151942552632745,
                                 0,
                                 0,
                                 0.59263097565833622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36933661472877355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87315636005341402,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54115983085126718,
                                 0,
                                 0,
                                 0.38819621147483174,
                                 0,
                                 0,
                                 -0.041748870978157812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0170657470158804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81208735360636786,
                                 0,
                                 0,
                                 0,
                                 0.17282306419155277,
                                 -0.010184510446566042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27447192458864061,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55540705971640247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11199916453344508,
                                 0,
                                 0.10406505505998509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20242579716982784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26261523667009251,
                                 0,
                                 0,
                                 0,
                                 0.37223191216250273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54785219661538864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090088228437071538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20475341747299322,
                                 -0.14991211405240004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02197411622159428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053960563599865813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5322841984288702,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3672797185132668,
                                 0,
                                 -0.053105888454927766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09142059830449896,
                                 0,
                                 -0.44600627936121873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01545968058744665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0052449264109048765,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089177920481044864,
                                 0,
                                 0,
                                 0,
                                 0.49072809504352527,
                                 0,
                                 0,
                                 0,
                                 0.34532839169136825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86130385640239104,
                                 0,
                                 0,
                                 -0.2640251994203604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13868933903569836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40464324292801168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52743503502054823,
                                 0,
                                 0,
                                 -0.2862596020676158,
                                 0,
                                 0,
                                 -0.95971855460453293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45015788743096696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06535197636831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48565256825627651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038246941318021838,
                                 0,
                                 0.04680402412743892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51787094307941728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69858925217195222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21769573099764405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4618432396109115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92303745623324907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34683670002385042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15766496355895221,
                                 0,
                                 0.39115138565141705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50767351663266258,
                                 0,
                                 0,
                                 0.64793876037597486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.040127881175278046,
                                 0,
                                 0,
                                 0.10859257819652762,
                                 0,
                                 0,
                                 -0.11747998918908334,
                                 0,
                                 0,
                                 0.035490678126780167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22218776751471903,
                                 0,
                                 0,
                                 0.28682098309746856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0806912429673103,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2314904361053472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25117252585841171,
                                 0,
                                 0,
                                 -0.095147339456846142,
                                 0,
                                 0,
                                 -0.21033412125490072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50755119263750992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24235083028242305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53726424790352434,
                                 0.15697768585437649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11111048771941541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22894391894076155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12951488733643435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21621282444721984,
                                 0,
                                 0,
                                 -0.078072730938778395,
                                 0,
                                 0,
                                 0.42774925407691378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55733605970893019,
                                 0,
                                 0,
                                 0.63285103523488739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21549953107447209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14580928164584966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33038287600207572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16477970240173645,
                                 0,
                                 1.0008521944032169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42650255797795128,
                                 0,
                                 0,
                                 0.18126621692212458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52220548798849564,
                                 0,
                                 0,
                                 0.35138349622663612,
                                 0,
                                 0,
                                 -0.091256857947566189,
                                 0,
                                 0,
                                 0.25202682170905527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25391742533392514,
                                 0,
                                 0,
                                 0,
                                 0.3767702715374463,
                                 0.15606908419852486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39573612311970591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095734684471295781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080027896615961699,
                                 0,
                                 0.58005842314888512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0053513367541390411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91994685029161694,
                                 0,
                                 0,
                                 0,
                                 -0.24090418583284376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41843556712736113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33336821493048818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017740864001159859,
                                 -0.64789543215250234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015436928256631427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24803970789615282,
                                 0.043969275028485744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41632216484837886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59366687558928299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17857402057683419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5074872315174227,
                                 0,
                                 0,
                                 0.16598158193598384,
                                 0,
                                 0,
                                 -0.008737901050894387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30574825568649927,
                                 0,
                                 0,
                                 -0.084909691805633083,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31395018779031048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098954624428924554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63905499621443784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32919139267374015,
                                 0,
                                 -0.043156603281303857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13400978709811096,
                                 0,
                                 0,
                                 0.35130206460521163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027416154932674346,
                                 0,
                                 0,
                                 -0.34890156463638888,
                                 0,
                                 0,
                                 0.85433275600303971,
                                 0,
                                 0,
                                 0.36089594097376354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12515284313954045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31115302163986719,
                                 0,
                                 0,
                                 0,
                                 -0.12396617774802475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0025420313856429344,
                                 0,
                                 0,
                                 0,
                                 0.13203164122663072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20265350025538595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62514747186837838,
                                 0,
                                 0,
                                 0,
                                 -0.12488787196473186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38693732248667384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014876829037103571,
                                 0,
                                 0,
                                 0,
                                 0.41636670736311654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.053388657775965118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2294610567180263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16862259138785796,
                                 0,
                                 0.081911881723843435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087718682680105076,
                                 0.30956474793182809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17268728045836956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46552479542690511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11700470803499963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54948378363399097,
                                 0,
                                 0,
                                 0.087009935673285618,
                                 0,
                                 0,
                                 -0.55443260308182907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11243905346816301,
                                 0,
                                 0,
                                 -0.56982676075656502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61292554957322143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30879530311654851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015732959991389118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18656172899478249,
                                 0,
                                 -0.27483955257671622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68046176183855578,
                                 0,
                                 0,
                                 -0.069481923691267933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26588034378858544,
                                 0,
                                 0,
                                 -0.10311240307882209,
                                 0,
                                 0,
                                 0.29245133926769495,
                                 0,
                                 0,
                                 0.11994132899791551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23713539477760406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43852688686715591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1289702285925084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20001131642621575,
                                 0,
                                 -0.085226448425391496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35134214011800907,
                                 0,
                                 -0.13133116321257909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18402046528993612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0023799337234890476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45987251850552857,
                                 0,
                                 0,
                                 0,
                                 -0.16740333365193011,
                                 0,
                                 0,
                                 0,
                                 -0.52296711272066843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015346545497815566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42350414869848219,
                                 0.0014294030035031935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27788962514161053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26622784436970243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6333392273984606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65673715596704463,
                                 0.1849277767024716,
                                 0,
                                 0,
                                 0,
                                 -0.6225902409389269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89566626475501943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7819199428380289,
                                 0,
                                 0,
                                 -0.050515352058401158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23503289827936308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39349453695878966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62064721179717752,
                                 0,
                                 0,
                                 -0.34575281823210979,
                                 0,
                                 0,
                                 -0.92253850792532999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14448986888306162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.048005137556921186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22096923575793576,
                                 0,
                                 0,
                                 0,
                                 0.21604477484668255,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033260091970744525,
                                 0,
                                 0,
                                 0,
                                 -0.12274907233299993,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12853687112541817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31837686151917255,
                                 0,
                                 0,
                                 0,
                                 0.093616065559895781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18050489786095028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077468145958282691,
                                 0,
                                 0,
                                 0,
                                 0.40731099805524618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56833751917505493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4491670963739634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17356691040449296,
                                 0,
                                 0,
                                 0,
                                 0.0095994315597181523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050427243600517119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.091443587629165379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1596335253121986,
                                 0,
                                 -0.14128193332358657,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27699391765711706,
                                 0,
                                 -0.052533904003741111,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66334174316489469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49889551880902827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.035254671006392631,
                                 0,
                                 0,
                                 0,
                                 0.31938582540888832,
                                 0,
                                 0,
                                 0,
                                 -0.26815093046504995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29667628438242699,
                                 0,
                                 0,
                                 0,
                                 0.17585550328050387,
                                 0.094889651125776159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39254361708186325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38085756723143394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.010977539114397559,
                                 0,
                                 -0.74867056568623691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51255764396630599,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33025736905803077,
                                 0,
                                 0,
                                 0,
                                 0.56489925531533469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21229152043664318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54211294571526059,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29067397896937641,
                                 -0.053003443268987635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5616848871453699,
                                 0,
                                 0,
                                 0,
                                 0.28022897038410455,
                                 0.22623232522617248,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34882864889095438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072815641206976089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69912185763828871,
                                 0,
                                 0.36026057177196819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10955591828610795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16371029924514482,
                                 0,
                                 0,
                                 0,
                                 0.64229964632621095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40290900825535414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41450011380748381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75904668556855692,
                                 -0.10221621190973836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49189775113746481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.072721311442931424,
                                 0.36312864403636574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026718086494009918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16110070848635377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14188318087297724,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23610866020710994,
                                 0,
                                 0,
                                 -0.2946023410727569,
                                 0,
                                 0,
                                 0.22859595408516489,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61586826571795561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39415767645987115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18366758210733067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05790192215614446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37818573428710806,
                                 0,
                                 -0.2775186889189763,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39823121290521668,
                                 0,
                                 0.38113296921071788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46309262007374508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15600066280320421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13239380282286992,
                                 0,
                                 0,
                                 0,
                                 -0.069481357406390234,
                                 0,
                                 0,
                                 0,
                                 0.15005013061494452,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00032190279715959419,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0094255672627466536,
                                 0,
                                 0,
                                 0,
                                 -0.37774031716415801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43232109485342407,
                                 0,
                                 0,
                                 0,
                                 0.027168105872301833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41013143982104966,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.048365628048793435,
                                 0,
                                 0,
                                 0,
                                 -0.30288080188272859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47948695160860683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21866839430742388,
                                 0,
                                 0,
                                 0,
                                 0.27844554647179631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1227616325342559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1909802888639143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022370646456241705};

const double rot_5_30[900] = {0.22930023572863489,
                              0,
                              -0.23078582192693892,
                              0,
                              0.095872935124524356,
                              0,
                              0,
                              -0.16535737823219807,
                              0.75764620792450621,
                              0.53415542714132536,
                              0,
                              0,
                              0,
                              0,
                              0.12080665900547671,
                              0,
                              0,
                              0,
                              0.29670633983854533,
                              0,
                              0.50564455492193316,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.0393754346179565,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.38925517870053483,
                              -1.0858260582201529,
                              0,
                              0,
                              0,
                              0,
                              -0.53440755695186382,
                              0,
                              0.71929036687221548,
                              0,
                              -0.069933045143069139,
                              0,
                              0,
                              0.24064794978087301,
                              0.43040952121596554,
                              0.048083193665085421,
                              0,
                              0,
                              0,
                              0,
                              0.57046647888149526,
                              0,
                              0,
                              0,
                              0.40009441739925589,
                              0,
                              0.019430282113450659,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.34376713709276197,
                              0,
                              0.37787409587088838,
                              0,
                              0,
                              0,
                              0,
                              0.78396595301289052,
                              0,
                              0.32200115270542462,
                              0,
                              0,
                              0.088324665667687832,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.091884986635019664,
                              0.06711086323054466,
                              0.22305461694539858,
                              0,
                              -0.10816182013148129,
                              0,
                              0.24599203199759551,
                              0,
                              0,
                              1.078150910637071,
                              -0.16748309436445713,
                              0.82134757940139802,
                              0,
                              0,
                              0,
                              0,
                              0.3407015117182986,
                              0,
                              0,
                              0,
                              -0.17504445981394331,
                              0,
                              0.1464768046485459,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.25502566264524829,
                              0,
                              -0.24272552648159884,
                              0,
                              0,
                              0,
                              0,
                              0.48669701995126974,
                              0,
                              -0.4294240396561087,
                              0,
                              0,
                              0.020789647478366657,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.67135180543324224,
                              -0.060181218181617951,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.73570975489826274,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.26815437054758096,
                              0,
                              0.21407517153604369,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.73425743101962493,
                              0.76549845779687653,
                              0,
                              0,
                              -0.075485150695475373,
                              0,
                              -0.20111121624761361,
                              0,
                              0.19931147590886888,
                              0,
                              0,
                              0.88266091727829876,
                              0.88870599839813469,
                              -0.21614546931650747,
                              0,
                              0,
                              0,
                              0,
                              -0.30115271891857776,
                              0,
                              0,
                              0,
                              -0.25615146949780127,
                              0,
                              -0.059011111559047896,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.31243682186040905,
                              0,
                              -0.0077024121299735376,
                              0,
                              0.5372904730185859,
                              0,
                              0,
                              0.18016990795619525,
                              -0.0265448425546259,
                              -0.56660647229144567,
                              0,
                              0,
                              0,
                              0,
                              0.32586262920452408,
                              0,
                              0,
                              0,
                              -0.35796406376159307,
                              0,
                              0.86962787102356709,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.59587038139443738,
                              0,
                              -0.33273292888853212,
                              0,
                              0.74956376382229373,
                              0,
                              0,
                              -0.18409586724319774,
                              -0.14792578974127729,
                              0.13614245547612824,
                              0,
                              0,
                              0,
                              0,
                              0.10796944745749179,
                              0,
                              0,
                              0,
                              0.66766045874112501,
                              0,
                              -0.53890033336950804,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.017435167862581202,
                              0,
                              0.30353522564774893,
                              0,
                              0,
                              0,
                              0,
                              -0.088219230076307317,
                              0,
                              -0.028859230027763111,
                              0,
                              0,
                              0.37813571078720815,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.059145252124155889,
                              -0.86744574318981338,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.88293582449000185,
                              0,
                              -0.17549470795061708,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.093403467339944979,
                              0.42532543963694897,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.72713293749320762,
                              0,
                              0.20025742970567403,
                              0,
                              0,
                              0,
                              0,
                              0.20562159033865568,
                              0,
                              -0.21110428829775105,
                              0,
                              0,
                              0.29103971712681337,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.48214909465203543,
                              0.16479541161710498,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.10496205721202112,
                              0,
                              -0.82360951848721708,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.23202278966824985,
                              -0.50676992084933181,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.34061132227120505,
                              0,
                              0.046169914500554632,
                              0,
                              0.5202212546520022,
                              0,
                              0,
                              0.072587609863477454,
                              0.63689045564105051,
                              0.45507169904425615,
                              0,
                              0,
                              0,
                              0,
                              0.74972057233170786,
                              0,
                              0,
                              0,
                              -0.23854014410064281,
                              0,
                              -1.1263592875473194,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.52733009428845312,
                              0,
                              -0.034168205263386153,
                              0,
                              0,
                              0,
                              0,
                              0.0012276981903478063,
                              0,
                              0.76318025698188008,
                              0,
                              0,
                              -0.22934490614328121,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.27199517669979695,
                              -0.10830249948738029,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.78448970123226824,
                              0,
                              0,
                              0,
                              0,
                              0.62014184559704244,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.072554452486286225,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.90832176712213286,
                              0,
                              -0.31602091463621096,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.51996317160680539,
                              -0.88396573975679638,
                              0,
                              0,
                              -0.55230557095834609,
                              0,
                              0.21374562886760196,
                              0,
                              0.34633330943465562,
                              0,
                              0,
                              -0.25354215785254253,
                              0.1094310074260991,
                              0.27358310503437272,
                              0,
                              0,
                              0,
                              0,
                              -0.17241233284118382,
                              0,
                              0,
                              0,
                              -0.7853856696182292,
                              0,
                              0.10798691082007444,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.96058824200564663,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.65753208068417468,
                              0,
                              -0.6514331351935998,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.37336367707435841,
                              0.36280629034695022,
                              0,
                              0,
                              0.38151798581982665,
                              0,
                              0.691960546786897,
                              0,
                              0.44638712562216848,
                              0,
                              0,
                              -0.22898089368190061,
                              -0.21876436493651849,
                              0.0035310871264497001,
                              0,
                              0,
                              0,
                              0,
                              -0.64891543882516711,
                              0,
                              0,
                              0,
                              0.32054555641230587,
                              0,
                              -0.23448008080883176,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.62014184559704255,
                              0,
                              0,
                              0,
                              0,
                              0.78448970123226847,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.2468879399783746,
                              0,
                              0.37908783512809452,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.87668808084749594,
                              -0.163574959119858,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.38529682255530623,
                              0,
                              -0.38361619073818642,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.41092484259700485,
                              0.73179624928591624,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.3028673214866564,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -1.3797499464057805,
                              0.065988420794660399,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.58003295755624551,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.22808122662428332,
                              -0.95205507546142376,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.38653552936814917,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              1.0104830177771382,
                              0,
                              0.26958983499520583,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.29968252037703691,
                              0.40533917625320326,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.72970447881574341,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.86005394138825342,
                              0,
                              1.0056397251261571,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.32045532306312718,
                              -0.83414641297401415,
                              0,
                              0,
                              0,
                              0,
                              0,
                              -0.08947539939618826,
                              0,
                              -0.31403768386879427,
                              0,
                              0,
                              0,
                              0,
                              -0.099901207106212475,
                              0,
                              0.27821788451369073,
                              0,
                              0,
                              0.84035545551452373,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.16874810284154762,
                              0.26705023823808965,
                              0,
                              0,
                              0,
                              0.040949939464441032,
                              0,
                              0.7525102537255105,
                              0,
                              0,
                              0,
                              0,
                              -0.2974538046392442,
                              0,
                              -0.081627692703587329,
                              0,
                              0,
                              0.072659711585726927,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0,
                              0.44991187347015815,
                              0.35945715573375792};

const double rot_5_2[4] = {0.35328979353670842, -0.93551393457435461, -0.93551393457435461, -0.35328979353670847};

const double rot_12_50[2500] = {-0.56855417135328778,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30892231341798704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19473690126033935,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47198427107239849,
                                0,
                                0,
                                0,
                                0,
                                -0.0094118189797463003,
                                0,
                                0,
                                0,
                                -0.56615630643889037,
                                0,
                                -0.13071474245100567,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.8400102316344125,
                                0.36334963970388789,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36527630589289517,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.014822421676728981,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71059722975711404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70344287108275716,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12891043144328168,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26375941701299832,
                                0.64572886080063596,
                                0,
                                0.27821503088643884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65588952865666927,
                                0,
                                0,
                                0.33072657076626899,
                                0.75313860378337827,
                                0,
                                0,
                                0,
                                0,
                                -0.25409115417909939,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74197507571490051,
                                0,
                                0.13530038908289557,
                                0,
                                -0.020051747870570749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72539675760968902,
                                0,
                                -1.0995584948154498,
                                -0.068880934074177266,
                                0,
                                0.19879233102155353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36201673320472283,
                                0,
                                0.24806629026254615,
                                0,
                                0,
                                -0.60511944096980164,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3807465914215496,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45366897407515649,
                                0,
                                0,
                                -0.16168284059449584,
                                0.47205328730567864,
                                0,
                                0,
                                0.4073467141507594,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40573179661756653,
                                0,
                                0,
                                0,
                                0,
                                0.24301715941330523,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10312066716746254,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44919019356713324,
                                0,
                                -0.70289352528355586,
                                0,
                                -0.12822247959115537,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16773017376465607,
                                0,
                                -0.17338855894003036,
                                0.087279896618675745,
                                0,
                                -0.1269900629596788,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15918455433103457,
                                0,
                                -0.79233823169508755,
                                0,
                                0,
                                -0.042996174079447065,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61798816515070798,
                                0,
                                0,
                                -0.02844387350683858,
                                0,
                                0,
                                -0.5476450659213522,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.02714741550002453,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56269838581362175,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.08458041114194649,
                                0,
                                0.25774550492687776,
                                0,
                                0.59481659233708539,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19890186715655034,
                                0,
                                0.17784854317781171,
                                0.63750674895293624,
                                0,
                                -0.88413983503689775,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.092327597401587636,
                                0,
                                -0.090128799613605703,
                                0,
                                0,
                                -0.50546102047204278,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.96447392737564053,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19574301665999896,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17741114632810207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0030699412439570417,
                                0,
                                0,
                                -0.92041615386997389,
                                0,
                                0,
                                0.30372468440769268,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0067764393131718378,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24602860627911891,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.031295645598769455,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33642698715992458,
                                0,
                                0,
                                0.45920746570734405,
                                -0.44667819251654756,
                                0,
                                0,
                                0.60686209629588839,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30342833149004544,
                                0,
                                0,
                                0,
                                0,
                                0.10821210736233632,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.058175116627695832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13949420654628694,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31451086695836095,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58895354266908062,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3535864715246036,
                                0,
                                0,
                                0,
                                0,
                                -0.61559937345159155,
                                0,
                                0,
                                0,
                                -0.17541956573726353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5172272706102109,
                                0,
                                0,
                                -0.16462078981324207,
                                0,
                                0,
                                -0.55123195213211851,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63137568837460178,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.053703083491425024,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2240882784899797,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.010273433747576582,
                                0,
                                0,
                                -0.64347436153989079,
                                -0.20776394854579128,
                                0,
                                0,
                                0.38446357013734661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11305012557165245,
                                0,
                                0,
                                0,
                                0,
                                -0.27196016058175448,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50783746526810414,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.066867389511315184,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70435997410592632,
                                0,
                                0,
                                0.30538757225313773,
                                0.25801805899304975,
                                0,
                                0,
                                0.33857626164107651,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13776907238480623,
                                0,
                                0,
                                0,
                                0,
                                0.26952951169411388,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36511714711770682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52907809277194595,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19102211007915759,
                                1.2294996672351299,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.153535456461408,
                                0,
                                0,
                                0,
                                0,
                                0.85606706849245562,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30738071034357506,
                                0.9748031489521829,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35811975663271833,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35374552574345963,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32386607258392808,
                                0,
                                0,
                                0.086513717131202289,
                                -0.065631274880385282,
                                0,
                                0,
                                -0.36033885666651633,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20703626238261799,
                                0,
                                0,
                                0,
                                0,
                                0.59641707098479135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47933428254307847,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7993371116858351,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72500088558542175,
                                0,
                                0,
                                -0.47822202420342252,
                                0,
                                0,
                                -0.53785229751702013,
                                0.19963329529061491,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16857061671168877,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.011647394383575592,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64886260650705485,
                                -0.13350802530964839,
                                0,
                                -0.80617767834817211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.83475525887612978,
                                0,
                                0,
                                -0.11730462046889191,
                                0.28735177252526845,
                                0,
                                0,
                                0,
                                0,
                                0.11425756510583884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4055434484943552,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43987142689717967,
                                -0.49526090310029003,
                                0,
                                -0.04267366315212516,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.02822551271442347,
                                0,
                                0,
                                0.84094551488922376,
                                0.50294439052223072,
                                0,
                                0,
                                0,
                                0,
                                -0.29081398261914104,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2637618987424929,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67582264573655615,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68825388649930352,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0023864630454424,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.015493486031980482,
                                0.33748608881647107,
                                0,
                                -0.053503236163238835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37322724084957326,
                                0,
                                0,
                                0.21340898312052528,
                                0.20505259740777346,
                                0,
                                0,
                                0,
                                0,
                                0.59408573396765918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23822718724268502,
                                0,
                                0.72369564385950613,
                                0,
                                -0.6052234908542522,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16826396299020557,
                                0,
                                -0.31788160597221538,
                                0.12000836114233221,
                                0,
                                -0.39940911786612604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29791712359791911,
                                0,
                                -0.058736166163728148,
                                0,
                                0,
                                0.32448121927502421,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51728545968098094,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17481233883447062,
                                0,
                                0,
                                -0.015761216020477375,
                                -0.24182850215323115,
                                0,
                                0,
                                0.19919371950895812,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53445072006449978,
                                0,
                                0,
                                0,
                                0,
                                0.13792144900001541,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54661588235817138,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16090815993422714,
                                0,
                                -0.25328166147104775,
                                0,
                                -0.35598164178420971,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25476792402234549,
                                0,
                                0.3763030767784093,
                                0.084502768952063712,
                                0,
                                -0.33624345445440934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73076117432906518,
                                0,
                                0.64501501661541916,
                                0,
                                0,
                                -0.29128290616840785,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.93088732610794411,
                                0,
                                0.23566391569034095,
                                0,
                                -0.10649046080486255,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12753190308826198,
                                0,
                                -0.5483288316375875,
                                -0.69361057764400991,
                                0,
                                -0.00011946494695658011,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37116996481476838,
                                0,
                                0.3927687486783093,
                                0,
                                0,
                                -0.24358385634068083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77951759727127823,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38676141843970169,
                                0,
                                0,
                                0.048285646363042223,
                                0,
                                0,
                                -0.41651665183757741,
                                0.92355115530220111,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.036034955628629517,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.09610749583425103,
                                0,
                                0.645304733036135,
                                0,
                                0.84212119502654514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57422532497527157,
                                0,
                                -0.033664457838333058,
                                0.068246349430083744,
                                0,
                                -0.69489141305445445,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54906931181548579,
                                0,
                                0.29721503518372316,
                                0,
                                0,
                                0.51824192095903054,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29088672356808837,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.082008262243688512,
                                0,
                                0,
                                0.38598015676833886,
                                -0.28168026119711048,
                                0,
                                0,
                                -0.16133165280119749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61767644514632014,
                                0,
                                0,
                                0,
                                0,
                                -0.46383242278408932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24008852221426688,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2628068734130589,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0934206568544502,
                                0,
                                0,
                                0.34436223473924243,
                                0,
                                0,
                                -0.22745796716734723,
                                0.37420475582218254,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.071705976298007526,
                                0,
                                0,
                                -0.62223945470069408,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58539029432760281,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11638586068696437,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16302841947272001,
                                0,
                                0,
                                0,
                                0,
                                -0.25594595907806572,
                                0,
                                0,
                                0,
                                0.40559092227121696,
                                0,
                                0,
                                0,
                                -0.22430827623504676,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.9287667521808427,
                                0.34808592289184959,
                                0,
                                0.1293683187621707,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12801198452497356,
                                0,
                                0,
                                0.28450802028675126,
                                0.024529976882898569,
                                0,
                                0,
                                0,
                                0,
                                0.5738506911758714,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.079828249958937253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43191844817141156,
                                0,
                                0,
                                0.78993049742517141,
                                0,
                                0,
                                -0.56995238830543205,
                                -0.47679488909419454,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.056435337315008063,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54585232512930915,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35741135386967615,
                                0,
                                0,
                                0.4164753949025039,
                                0,
                                0,
                                0.4574747670354693,
                                0.34535020008372008,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70603464847450637,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0064100148411628879,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00043199623945230914,
                                -0.042544148107159813,
                                0,
                                0.19172192197915416,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6745417384817467,
                                0,
                                0,
                                0.47873314519922949,
                                -0.74313426488814516,
                                0,
                                0,
                                0,
                                0,
                                0.019120353208231022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11300862575520658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0011991011156562426,
                                -0.77487085817058632,
                                0,
                                0.87518732093576468,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.072718929279231237,
                                0,
                                0,
                                -0.63391366554818018,
                                -0.16826341177452397,
                                0,
                                0,
                                0,
                                0,
                                -0.021192356005220736,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24426637901973358,
                                0,
                                0,
                                -0.26105821429664605,
                                0,
                                0,
                                -0.53223258984813626,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70757778078777789,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29706009369793002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59591612249589665,
                                0,
                                0.22843687401601048,
                                0,
                                0.16329188751449183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084205792217378964,
                                0,
                                -0.050726714859934449,
                                0.30790957994416329,
                                0,
                                0.8423633638355783,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43972133141725095,
                                0,
                                -0.63238202581676206,
                                0,
                                0,
                                -0.69615136839821301,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14888742657099699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50213745380379604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12614775676492243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59204809522392188,
                                0,
                                0,
                                0,
                                0,
                                -0.16108067446320123,
                                0,
                                0,
                                0,
                                0.57732947648278776,
                                0,
                                0,
                                0,
                                0,
                                0.053853767848385067,
                                0,
                                -0.15407324614795398,
                                0,
                                0.35233100097783565,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.84868246401412717,
                                0,
                                -0.12397184140015274,
                                -0.51911897668067797,
                                0,
                                -0.11376950733525429,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29469895552430725,
                                0,
                                -0.014291619315563452,
                                0,
                                0,
                                0.017942157657994486,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34264206158717958,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33091087745457787,
                                0.21157462303505642,
                                0,
                                0.090891099124900399,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36357725562560544,
                                0,
                                0,
                                -0.40145980419555111,
                                -0.55921665760669659,
                                0,
                                0,
                                0,
                                0,
                                -0.67921109465860185,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56747738423809357,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2063949753571519,
                                0,
                                0,
                                -0.31456735153045945,
                                -0.57076514517619292,
                                0,
                                0,
                                -0.08826549229013636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0390708543250773,
                                0,
                                0,
                                0,
                                0,
                                0.43903091958434126,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.092626053530662861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42721093452604636,
                                0,
                                -0.27159725285428687,
                                0,
                                0.28459057670048049,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23827780555133754,
                                0,
                                -0.70562049110349934,
                                0.77647956321512768,
                                0,
                                0.28680124311854116,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22276009902556637,
                                0,
                                0.42812042987313592,
                                0,
                                0,
                                -0.043712615348788786,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38367919267056483,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42154220129657699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52556813338522734,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51224833377723611,
                                0,
                                0,
                                0,
                                0,
                                -0.011505573610320959,
                                0,
                                0,
                                0,
                                0.36924226887777972,
                                0,
                                -0.50315229241648984,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30655883290165309,
                                0.87738616166685102,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8056055739970216,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42956543922165091,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61025193501959352,
                                0,
                                0,
                                -0.3298799578041911,
                                0,
                                0,
                                -0.58631229440779364,
                                -0.11478223641015996,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.92544558123699128,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53934320224891918,
                                0,
                                0,
                                -0.23827222680086438,
                                0,
                                0,
                                -0.14390275572623262,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31609416629676362,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72918566294928522,
                                0,
                                -0.31737736672817607,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18201173631966194,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55635463144505237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11273813437979247,
                                0,
                                0,
                                0,
                                0,
                                0.72757208109677141,
                                0,
                                0,
                                0,
                                0.12058954708143782};

const double rot_12_20[400] = {0.7085763316776339,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5506885557595862,
                               0,
                               0.44120482402359229,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.5556969288379088,
                               0,
                               0,
                               -0.56448310803906776,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.001842289473085,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.69183852541601687,
                               0,
                               0,
                               0.25470216413002977,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43981353007508017,
                               0,
                               0.51288431551429703,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58022556817102788,
                               0,
                               0,
                               0.31732317962459367,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.80428359936639893,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11744605692736347,
                               0,
                               0,
                               -0.12477484815558354,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.79348159670175278,
                               0,
                               0.58397313009726393,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.76427123867618718,
                               0,
                               0,
                               -0.82864986509772642,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.059322381242044864,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67604205289028008,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35062134591902977,
                               0,
                               0.64809861480319797,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.71057951455396928,
                               0,
                               0,
                               0.29340815945936538,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27397299618576243,
                               0,
                               0.57786434638235984,
                               0,
                               0.20220466095064032,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.75750035402060933,
                               0,
                               0.62073060883807496,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.051406536147178022,
                               0,
                               0,
                               -0.91294561547657271,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31920183555162912,
                               0,
                               0.24899369350231154,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1};

const double rot_12_10[100] = {1.7662796105923451,
                               0,
                               -0.022549988713477492,
                               -0.73494152281550362,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19779213972020557,
                               0,
                               0,
                               0,
                               0,
                               0.41075730842914066,
                               -0.55185283360334592,
                               0.69829446015338581,
                               0,
                               -0.16275396357566074,
                               0,
                               1.0214832803171436,
                               0.15766059008540306,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.80746251183686502,
                               0,
                               -0.17872800079469781,
                               0.82161522145389465,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.68408709914794963,
                               0.45620045897827816,
                               0,
                               0,
                               0,
                               -0.56912738644994998,
                               0,
                               0,
                               0,
                               0,
                               -0.10028251617067044,
                               0.71403305061191435,
                               0,
                               0,
                               0,
                               0.69289264650761018,
                               0,
                               0.10368093280307239,
                               0,
                               0,
                               0,
                               0,
                               -0.68821098270342485,
                               0.2847203176469536,
                               0.65920425376243574,
                               0,
                               0,
                               -0.92645599266390755,
                               0,
                               0,
                               0,
                               0,
                               0.030618213047182333,
                               0.37482335137189876,
                               0.015788411993261225,
                               0,
                               0,
                               -0.30299806483725389,
                               0,
                               0,
                               0,
                               0,
                               -0.59724919580375457,
                               -0.68840412987525967,
                               -0.2785414238265706,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.72247370729309046,
                               -0.53107244690517652,
                               0,
                               0,
                               0,
                               0.44271186838431353};

const double rot_12_100[10000] = {-0.28284251233994068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.81057530376062825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063341024378555627,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1050720928395696,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46896388075316098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53562887988633501,
                                  0,
                                  0,
                                  -0.25920172310584638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28038842502166456,
                                  0,
                                  0,
                                  0,
                                  0.42521149365405975,
                                  -0.61609963413593372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28530607475964798,
                                  0.27984043877155079,
                                  0,
                                  0,
                                  0,
                                  -0.19908982651751564,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65246906791438186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61178371763394312,
                                  0,
                                  0,
                                  0,
                                  -0.35916818643849768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.018216635148453453,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3556459953359421,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70026614195631831,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.78936513353659787,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12508362167111148,
                                  -0.25408189776056939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41617167186305382,
                                  0,
                                  0,
                                  0.15733074155511698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12285058767156608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41107486803696069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39265401312707876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53016446524783223,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21837139885923001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36747212302638327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24701577934695293,
                                  0,
                                  0,
                                  0,
                                  0.59855763082710067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.9648409347311504,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024756643071670636,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31350415266212894,
                                  0.24493649227033157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0970160099451172,
                                  0,
                                  0,
                                  0.1546085294363167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26687430241568433,
                                  0,
                                  -0.24615041493655307,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24472996606736874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20108388911610262,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070586446174742828,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022663538005846917,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.048610635701987315,
                                  0,
                                  0,
                                  0,
                                  0.20908139194590333,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29527456428679882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10950022671478502,
                                  0,
                                  0.41975993999596489,
                                  0,
                                  -0.15518078884830844,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44887615843057593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047412778040697587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30405894416027002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20592657323080177,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49064830110918056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23240658060403477,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14532277162603038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0015719295283167893,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25908007652603582,
                                  0,
                                  0,
                                  0.49883108809821686,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57026264472671939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24674119589652915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30705107075218147,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16947492007595835,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40214581275757161,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11506952015016866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.010428999816593565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17992526783949536,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33055510496353835,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43618272978503481,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41724893800673279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.031392166396960186,
                                  0,
                                  0,
                                  0.44506915684059378,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35221596513905168,
                                  0,
                                  0,
                                  0,
                                  -0.48401421186059873,
                                  -0.6712193469123624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35575982030127057,
                                  -0.32979135029093454,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13632917981954398,
                                  0,
                                  0,
                                  0,
                                  0.22052956967027629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23317054767972265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.014716626257233866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45680184635009669,
                                  0.57003421100169527,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27607130469106195,
                                  0,
                                  0,
                                  -0.51096065886129716,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56268414742575334,
                                  0,
                                  0.45091312992694155,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41196646187149344,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29979647352539668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19146431012950707,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54054034369381476,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047645200914253068,
                                  0,
                                  0,
                                  0,
                                  -0.0066248571712046126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20717278019428836,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58004386608851177,
                                  0,
                                  -0.1543972606305338,
                                  0,
                                  -0.35141020118932742,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14737890342821636,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29741441209035763,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07968064423948075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3366192725755518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36461879767043431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14324896401375978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29566292892846852,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.016304624747264549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043121300497702075,
                                  0,
                                  0,
                                  0,
                                  0.0025448238048065295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021394274927239082,
                                  0,
                                  0,
                                  -0.14428745501621859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040053684266748074,
                                  0,
                                  0.067125543471458368,
                                  0,
                                  0,
                                  0.083811379825836932,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10285351021796817,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087141285725021736,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.040338870617923725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29190335653648924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.92666917870498766,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4793824812627655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.84505990614553972,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65381387311852346,
                                  0,
                                  0.11747264841953522,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11588754371160301,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49305509606568881,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.92381152880492401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11979508509086137,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47092649761415362,
                                  0,
                                  0,
                                  -0.43844919934347637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13748366777520593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36856343294087479,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31207483756103882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18493153342204879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42777012504032913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34157299990521306,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59466480068592997,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.91096764824827325,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25568297448210292,
                                  0,
                                  0,
                                  0,
                                  -0.28732138620344422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59049838724744674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70981396634719707,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31991889343712093,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41178445688678206,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29589074756688438,
                                  -0.46606039559469259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063842075241005922,
                                  0,
                                  0,
                                  0,
                                  0.052521887728019016,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36555009234893571,
                                  0,
                                  0,
                                  0.51004709265712778,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0084126626949481507,
                                  0,
                                  -0.042677767792694589,
                                  0,
                                  0,
                                  0.16841305380456167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.73474894086124209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058557523686229671,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049099675846276059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14719951404216769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.042096885460989053,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22779786336811528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.79150363140762825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14384453718232615,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.103264144426943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17647963053050644,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50904846578675433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48205215788023098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18398666695920449,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44791811932464104,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.074793229670059802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24242886721073509,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49062389844762749,
                                  0,
                                  -0.17487797863946661,
                                  0,
                                  0,
                                  0.0097895869727474411,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4235288641066835,
                                  0,
                                  0.13420710524337193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19875925612044937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68513103215544668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48585351729834692,
                                  0,
                                  0.032759382445756172,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.95231206691380388,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11043973979782218,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13278564013804883,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026607530257037257,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2566113403504503,
                                  0,
                                  0,
                                  0.17825591429693821,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20109138961291007,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52243026846639418,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5460997167221826,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19636813494077304,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26986479588197299,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42354688471856999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13614574254701201,
                                  0,
                                  0,
                                  0,
                                  -0.058009743289137564,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32961922107110914,
                                  0,
                                  0,
                                  0.093370278407570409,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09104763471546716,
                                  0,
                                  -0.18818257877954364,
                                  0,
                                  0,
                                  -0.17259807193979981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.041118474200611002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10487122492826742,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53388644315871014,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.66391911798513426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22074393614693122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21719226188388729,
                                  0,
                                  0,
                                  0,
                                  0.51161452627663873,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42720268013635765,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16259865449023025,
                                  0,
                                  -0.27692327814524414,
                                  0,
                                  -0.1887873965131194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2839651269426996,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16292456783265716,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.215184969552142,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26134885771598088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12119384701752915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17434837948904369,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24217041294010597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21045247182979246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.85279925970309256,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67720692708838937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56540643460986617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22771290104463923,
                                  0,
                                  0,
                                  0,
                                  0.16374383321392799,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1246523620165926,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46365375951737042,
                                  0,
                                  0,
                                  0,
                                  -0.27130480981397426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45702036457779116,
                                  0,
                                  0,
                                  0.13233469347271076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10533720145141812,
                                  0,
                                  -0.36233947383879395,
                                  0,
                                  0,
                                  -0.0049663539655071479,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10500565995382587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41427607513342524,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39868289522838535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0044635676447468131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.031772508629876794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40235734586480476,
                                  0,
                                  0,
                                  0,
                                  -0.0021402886234130718,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2136752506305179,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.038836550250213556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46910948134744612,
                                  -0.5312449519108573,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23022923678193094,
                                  0,
                                  0,
                                  0.041199872216988634,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44955430500451643,
                                  0,
                                  -0.048385818986020353,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11158912568098125,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.74963809349594013,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085896322381753723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14789867035478907,
                                  0,
                                  0,
                                  -0.80875085485839371,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35573375127008861,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34960143090792872,
                                  0,
                                  0,
                                  0,
                                  -0.45097100256582157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.80968242997314088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043439727662287264,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33752850052108208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17827162786725606,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10437405368316205,
                                  0.4975160637744912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10644807058177065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2349480632239824,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32605895830995274,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13438539052516796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10551584878957687,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51847250891327179,
                                  0,
                                  -0.051303799815443897,
                                  0,
                                  0,
                                  0.25066132234883343,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42034400558936358,
                                  0,
                                  -0.53571890026324143,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27512488884396036,
                                  0,
                                  0,
                                  -0.28472919067215119,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51366857317639436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32275184929994422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0025451231239096428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24831532341197501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5472884747238117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33766813910072813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38860294943374857,
                                  0,
                                  0,
                                  0,
                                  0.39628196269341565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1339559752347555,
                                  0,
                                  0,
                                  0.38662190535216584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35652493230442545,
                                  0,
                                  -0.24164033763469667,
                                  0,
                                  0,
                                  -0.31404687265125725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.02352424684220112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24177052454090625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14179000243710868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35635520755558098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18520885215689548,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5260269333161548,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075222619322306158,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28574353527028873,
                                  0,
                                  0,
                                  0,
                                  -0.53919237944048959,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60744247981741695,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1742961676437958,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26832048387777424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16323074190616066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54626788539544735,
                                  0.88414705041957686,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.08956912478096718,
                                  0,
                                  0,
                                  0,
                                  0.27658473734804451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38481447242412947,
                                  0,
                                  0,
                                  -0.12032323673732352,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1733063662584855,
                                  0,
                                  0.17371224730126841,
                                  0,
                                  0,
                                  -0.54734989362570852,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045721698054420973,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46371142310482522,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30238759709768404,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27666373280338769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.089529941626851836,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33099386583649543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39977788396651315,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24541914751360208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52853230595806944,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44568710612210033,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43864193973982901,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.011228863735060659,
                                  0,
                                  0,
                                  0,
                                  0.30261682505215065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.72688336839774692,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33469791384455555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16722550882709339,
                                  -0.52333946815652654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39734842460842779,
                                  0,
                                  0,
                                  -0.4548507679037227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59304515243028799,
                                  0,
                                  -0.087202747611846362,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.011147895216861286,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63051872279527799,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22261687120755558,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063724260168940047,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092155878586074991,
                                  0,
                                  0,
                                  0,
                                  0.079442551144855683,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2688073610880824,
                                  0,
                                  0,
                                  0.3915458010705391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14145517221164297,
                                  0,
                                  -0.47354253163720328,
                                  0,
                                  0,
                                  0.043932200750842136,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54091540937373384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3224098440736381,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20361434721830038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24885690329131271,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11628577625237729,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5918396782017713,
                                  0,
                                  0,
                                  -0.012973423048380842,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42715704518791586,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0076166807168307725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24379416436747592,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4749658894140667,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.061848989607029919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42211709550748588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42926138732734442,
                                  0,
                                  0,
                                  0,
                                  0.091451405088231227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26975038746014096,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3329029383979199,
                                  0,
                                  0.011140527720439927,
                                  0,
                                  0.32094641146501302,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18222392436247969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.099181921889717542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069338105613201709,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5784775914974426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2441754001824793,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12045991935556931,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25182980072384487,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.024774539059702769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070137962807735335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40150442328152797,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26796226389340039,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10120489931045665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053142623503905362,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34580263960521646,
                                  0,
                                  0,
                                  0.14839208687446859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27765060749578208,
                                  0,
                                  0,
                                  0,
                                  0.28707022875178212,
                                  -0.69490918240685795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.97824726369234272,
                                  0.52175219435295661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23848558103395562,
                                  0,
                                  0,
                                  0,
                                  0.52132209164434229,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4164413618873522,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17620826929770295,
                                  0,
                                  -0.1141413220673476,
                                  0,
                                  -0.13081990126307508,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.164437471476856,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10982221013678384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059917403491792767,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2917505227602456,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0085805492351369861,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2362169376499216,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35176717905816873,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35959946609483001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19731839528250633,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60547738208806046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21898112550804105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38095228363752098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33135816990286016,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30612743961195182,
                                  0,
                                  -0.11525347913727216,
                                  0,
                                  0,
                                  0.17059075929983841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.185573516614123,
                                  0,
                                  0.34792365139567638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6996081634415221,
                                  0,
                                  0,
                                  0,
                                  -0.4266087797625121,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068342120984071525,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024074991966674356,
                                  0,
                                  0.12768467973001046,
                                  0,
                                  0.039337357380602983,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25691164463916616,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35319573436680318,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10585894811076069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26106957633152655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069512349336981985,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16660861095175372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.048706957977796866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019372315222056641,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.73829927111634364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13692966274888024,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14203422858351122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17477892621671168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50094407482828263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36673981578799181,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.82631027057126438,
                                  0,
                                  0,
                                  0,
                                  -0.12294740617441685,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24215651646738492,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.57314169437858209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.069286133387696125,
                                  -0.079879024449847708,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.032645710370262669,
                                  0,
                                  0,
                                  -0.39585046761863663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35465715980596035,
                                  0,
                                  -0.086329136216898625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39867125241069873,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39614053102248881,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15221904409892131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37573636747316536,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21969187439077176,
                                  0,
                                  0,
                                  0,
                                  0.62053222993712076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.090692433604225992,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11336183485764807,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45156900519664472,
                                  -0.10521019602296278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27929019451567877,
                                  0,
                                  0,
                                  -0.27145510002588624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41938881753462731,
                                  0,
                                  -0.026415554687640556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.093633528605262362,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43173348329456834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.087996252174163764,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68595927935362244,
                                  0,
                                  0,
                                  -0.92818221772025267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.7450759847713665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.89565867929212384,
                                  0,
                                  0,
                                  0,
                                  -0.041556842001163677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30956407701155242,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15558951277230762,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080227489001443192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41030695898047675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13926717720911741,
                                  -0.01579190464584225,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20611924153957947,
                                  0,
                                  0,
                                  0,
                                  -0.73386830909990519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18395972844473307,
                                  0,
                                  0,
                                  0.11473187230521435,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31363907047710005,
                                  0,
                                  0.086698163490456268,
                                  0,
                                  0,
                                  -0.47320748303981808,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0038844017742481374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17211124987499821,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.077282792341937107,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028126018713880624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075730740358069495,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06777392383738691,
                                  0,
                                  0,
                                  0,
                                  0.089418150268933266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28064696406042494,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053199293618012192,
                                  0,
                                  0.61761032389789583,
                                  0,
                                  -0.37569775400625516,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047926478092164937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079642358539379163,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21231244463073551,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28419294601194039,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19898475862573267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030079131039457609,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41550265850542034,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.188686743104027,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067120951555483616,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10346798331920141,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.067856047608445338,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.026920451492312557,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56550112120120166,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20060808855221654,
                                  0,
                                  -0.40559941024732082,
                                  0,
                                  0,
                                  0.61360639768612391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23453744426535456,
                                  0,
                                  -0.15294891786254483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.90249708144472907,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14578197859607497,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095757686085907623,
                                  0,
                                  0.82623747489683441,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28877747154792582,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27844122530166682,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.9706173131602962,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053518498154609781,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.8084616489651969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.78744805192088119,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38154795888607496,
                                  0,
                                  0,
                                  0,
                                  0.47257484165761598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12758463676433235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0589900940997283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39583155391169905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41906263743284272,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19208171518035577,
                                  -0.05942121890776042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20550580854277628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19035666955719824,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66807872344914843,
                                  0,
                                  0.49975669469380507,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.071090584077351762,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17262917178486234,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.025788862344597041,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.0355906733637568,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13078466197246058,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14856899540514595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67786905915818363,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083731724222795095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19217967391681595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41535255445256691,
                                  0,
                                  0,
                                  0.43643931744761977,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7979977265001017,
                                  0,
                                  0,
                                  0,
                                  0.80447477308332771,
                                  0.12679601366156446,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098675546822145091,
                                  -0.0042980408271823117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054373122917972125,
                                  0,
                                  0,
                                  0,
                                  -0.072951346611929563,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27892715325595546,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11468961947340628,
                                  0,
                                  0.14463385094781966,
                                  0,
                                  0.29512132828731935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34862390902495788,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3369481763181712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11009159935257484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10760792604588695,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34581473095702131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31463457729052302,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23003493843532105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51232890012634036,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60792844116200817,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12430302543805652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.061951474094761594,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3574841215508725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08045306530446919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46043642090784681,
                                  0,
                                  -0.41135675374486319,
                                  0,
                                  0,
                                  0.092998330800501267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030172462937207024,
                                  0,
                                  0.29341275819493984,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60581783650429366,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28168363399272256,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.87997743789056393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.1573048197604241,
                                  0,
                                  0,
                                  0,
                                  -0.017619067043159006,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.065726122923878999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3740451369005855,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2882490704590569,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.71965668139037764,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032273706884693484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044273703201320264,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50605851135956792,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.81952839311357983,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080876728405811518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65501267800127905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.055111950306103802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48018795516713358,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16092974963422274,
                                  0,
                                  0,
                                  0.19348068590706941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29084891253436651,
                                  0,
                                  0,
                                  0,
                                  0.70335534453492077,
                                  0.023709039448865488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17075324670410574,
                                  -0.40689092140028588,
                                  0,
                                  0,
                                  0,
                                  -0.1092366088281079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30853512945209527,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27940212535247916,
                                  0,
                                  0,
                                  0,
                                  0.16737669478649297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37992289838634891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.023343646825124201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40721922747809558,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1437146341328068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.84343440970925609,
                                  -0.12817950755938032,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21460237959083894,
                                  0,
                                  0,
                                  0.15342930473584526,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14068663203640774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1331281162745821,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45512336121479102,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48132415818364371,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4462178038630279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50494444811946226,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59898264083510466,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.69144019306234883,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.8441947224939842,
                                  0,
                                  0.36399203324388374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.014880821206678212,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.036295230154507,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23880635981758822,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58224877203197289,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61193663790566499,
                                  0,
                                  0,
                                  0,
                                  0.4456471408672818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15479348740448334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0079707633707164303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15573702194378744,
                                  0.054229408277268874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18377013609854351,
                                  0,
                                  0,
                                  0.60798056130195777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62332170095621087,
                                  0,
                                  -0.7964786898443067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52882552709788688,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13349445824485051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2170367856800578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11206844289915584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17912613435691882,
                                  0,
                                  0,
                                  0,
                                  -0.15258697235604218,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23673940546858996,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29409808025469503,
                                  0,
                                  0.14127797337102083,
                                  0,
                                  -0.12218510357866044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097212870236969173,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43524797749698169,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52978045393412876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0046638526618127951,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2455761603947344,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27677462324022073,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36695033100647345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12672228948816899,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57239893869891711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.1261910126199963,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30830209133638098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72953343664384529,
                                  0,
                                  0,
                                  0,
                                  -0.62816498708929869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54992066254486227,
                                  0,
                                  0,
                                  0,
                                  0.15980464420174836,
                                  0,
                                  0,
                                  0,
                                  0.32626404275183973,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51150366796840452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2826826607852389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51329459862381654,
                                  0.48236096974960485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0010294647025987091,
                                  0,
                                  0,
                                  0.039953975718382939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24481456260698128,
                                  0,
                                  0.07050041589810796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56137264968536649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11870243033022261,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.70038019118953587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.02972116633623699,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22350512369946574,
                                  0,
                                  0,
                                  0,
                                  0.019281436054203533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26956495890958077,
                                  0,
                                  0,
                                  -0.11245959812091175,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62291740538429641,
                                  0,
                                  -0.23931160956502989,
                                  0,
                                  0,
                                  -0.36986643391279023,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29477393111041417,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33543970174721383,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20805231571615845,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19041040930011363,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057537676945619287,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015524388041913292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.478770529750638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66818156538336271,
                                  0,
                                  -0.19102797567041119,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61363008794405127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.90969287679272415,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31673864542113084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11785069745994936,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2187524585570777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10885498815150954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23174036631966136,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.69495687710100562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.67550814475562249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38661710771332231,
                                  0,
                                  0,
                                  0.34921620400223136,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34029389090669399,
                                  0,
                                  0,
                                  0,
                                  0.43610547602007055,
                                  0.20447625582580908,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16155215137812592,
                                  -0.18992605486261407,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097510091034897384,
                                  0,
                                  0,
                                  0,
                                  -0.23213773886810729,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022149246700797605,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053324446862084846,
                                  0,
                                  0.012999391435037852,
                                  0,
                                  -0.53799262928933067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38392295323084169,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10127331566929651,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43399833997629289,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38821049899780191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.069572448731822362,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.013515944961707087,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3648570446853151,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.093840154859143599,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11314536761656019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025035624068852541,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027441810089758184,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67361659296278353,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0013417727900298937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.079910706388932468,
                                  0,
                                  0.14488301522738617,
                                  0,
                                  0,
                                  0.37975198510237979,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19433315421886194,
                                  0,
                                  0.56806990906892663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30598223985881767,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37149412590826419,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.96739230448326441,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20572771599238568,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65434234119836565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47977476663213786,
                                  0,
                                  0,
                                  -0.35613147455894639,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31809820339458028,
                                  0,
                                  0,
                                  0,
                                  0.31277621444980591,
                                  -0.35402671547146691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31444224797642056,
                                  -0.68927445025664158,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019979270601446213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14022338667622161,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084564976587996402,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36732696558173905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30644086672722914,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29813387651284223,
                                  0,
                                  -0.74005678863527158,
                                  0,
                                  0,
                                  -0.22388890935260283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21053454882570374,
                                  0,
                                  -0.11372331403835521,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34868285951629197,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14219435671663863,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34924722854555595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45193606616870674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.71877323427218309,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12387990773563874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.96824856055854813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31728285519350996,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50993154625149084,
                                  0,
                                  -1.0036053740728468,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2440704378805279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39444241367487787,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015521854796457513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39360666130335437,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21458273785144646,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26516650166692152,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55188805593749712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30247793549312496,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13282243193350179,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043465809471285977,
                                  0,
                                  0.026319175532970265,
                                  0,
                                  0,
                                  0.1361746860700879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.6608062580400883,
                                  0,
                                  0.11016087079158918,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28291435583203217,
                                  0,
                                  0,
                                  0,
                                  0.41837527500248733,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12872042356135685,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56245932132050225,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39458295074113453,
                                  0.028138427051111643,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11617801300944426,
                                  0,
                                  0,
                                  0.65904849849017288,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35044061235087864,
                                  0,
                                  0.51509965758634213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17887942784323774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38894847757541989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50527764596514757,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11322739921047728,
                                  0,
                                  0,
                                  -0.6042769722812189,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.57713655702055966,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37161748786904197,
                                  0,
                                  0,
                                  0,
                                  0.89202048844892201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2211598648722552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51398231740534517,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47872498435464128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42440553583688534,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.087726017652244914,
                                  0.73559984490268504,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39598573511863761,
                                  0,
                                  0,
                                  0,
                                  -0.34897971869346434,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29072083391861381,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27433646816209178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.64578763620861257,
                                  -0.26013819784031761,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27336749129667831,
                                  0,
                                  0,
                                  -0.27773575198708733,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0030799086960857647,
                                  0,
                                  0.2594854001895156,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4461990597365329,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25867993180277388,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65183462332111675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62525725084787998,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48148023002692542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47303594572135138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46347267743275133,
                                  0,
                                  -0.45235140560411841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60276271950571825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41486918421959929,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61334354879271447,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40129531813253372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0059512060087358459,
                                  0,
                                  0,
                                  0.6305728654513747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3664116134897642,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48929947906207699,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29891054669840789,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31387534720091814,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17977232529815859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092128477365836126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17881800673638282,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30272619760553099,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50894508873809041,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68858887946642422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026035633994702576,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37752267115654026,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14530645901288528,
                                  0,
                                  0,
                                  0,
                                  0.052328244559873394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.020843393187967518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13097323614120776,
                                  0,
                                  0.27786399563072167,
                                  0,
                                  0.16317311707883167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35659534244376573,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29861684710021186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33734545803829163,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1314202845763989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.091513852722433342,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.63337169347470723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30230411902611465,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.079985682239366612,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.076637441823848684,
                                  0,
                                  0,
                                  0,
                                  -0.21462036018512209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080546677850283382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42910933958866687,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36364208889021421,
                                  0.47160352339643707,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24023019409355159,
                                  0,
                                  0,
                                  -0.32987414350477146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.05837570525377947,
                                  0,
                                  -0.27460469943336518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45810039445635659,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20928906803088046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63405362555504796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13130478884573127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35741517233922265,
                                  0,
                                  0,
                                  0,
                                  0.20658115196533031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16589621611637184,
                                  0,
                                  0,
                                  -0.47131224143989126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41067611387053871,
                                  0,
                                  -0.42603318962919345,
                                  0,
                                  0,
                                  -0.24332318332651076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21635460361002579,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31234658838123031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16004800098513861,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022351153772285581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0084779476918413615,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6940531904533066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23676790255999677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1864805373175418,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30926316283226668,
                                  0,
                                  0,
                                  0,
                                  -0.47786922962114753,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2802757967019498,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51893432739954681,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56488401911675079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55464784121863908,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12801509660847343,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017401416079676782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083561546434746128,
                                  0,
                                  0.11888834552617239,
                                  0,
                                  0,
                                  -0.0685610660461521,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.04944761963851612,
                                  0,
                                  -0.24295194828055536,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21976978967229152,
                                  0,
                                  0,
                                  0,
                                  0.25099653941337219,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19358183562883602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17335878718530423,
                                  0,
                                  0.35832449715276832,
                                  0,
                                  0.35360039394213466,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40087342332671694,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25298993672299019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25826096633728124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068837921622516896,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12964042249716776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14551751318496053,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10316425928766471,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47220699987568188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.121400706422534,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32938120580856034,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12861108100348798,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078314168274917759,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61820691243142689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2009323210515053,
                                  0,
                                  -0.19045921244330238,
                                  0,
                                  0,
                                  -0.55247477650092991,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17993984842742289,
                                  0,
                                  0.24012693951997191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.071780846366935103,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14315569288550944,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19118076638625042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.97978916951677153,
                                  0,
                                  0,
                                  0,
                                  -1.2199394551878191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57969649193609407,
                                  -0.06995848032390467,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062180273798581057,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17813626833445143,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56674235603177459,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72063095748814887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16810048134848679,
                                  0,
                                  0,
                                  0.32441486285464982,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19107457098480196,
                                  0,
                                  0,
                                  0,
                                  -0.25538920066465054,
                                  -0.16931945563675657,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16889724500533954,
                                  -0.82751969819311011,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057778494520561524,
                                  0,
                                  0,
                                  0,
                                  0.30942054204790381,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40188958190417912,
                                  0,
                                  0,
                                  0.092080881352346267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34858481412221126,
                                  0,
                                  0.3696724883505243,
                                  0,
                                  0,
                                  -0.063109986654484751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.02719579288943276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39568439514210885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44187959031039092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33610988043619716,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056932253695975321,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.6087723549647458,
                                  0,
                                  0,
                                  0,
                                  -0.65431205218188604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41941721656993453,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62393486118129315,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061985433235855703,
                                  0.5310674525427046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47580775702085693,
                                  0,
                                  0,
                                  0.13793933143328255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.05890115495423201,
                                  0,
                                  -0.49479877096582592,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064317883819399402,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.00050121429237664702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14091189008043328,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063839877486161836,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29805256248909989,
                                  0,
                                  0,
                                  0,
                                  -0.010893733347810242,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087003936716592303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16827959559569927,
                                  0,
                                  0.20214754026851045,
                                  0,
                                  -0.1028932666765813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033751535091959738,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49738651966265751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27632095554463942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14783741899106539,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033923419206327576,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44186233444222234,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17190783519336819,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50101948379770556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47685726994402999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.69170301261234146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3952455615570184,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30697124729121028,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.091602088429705755,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21694100608781025,
                                  0,
                                  0,
                                  -0.30629999018923237,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59424001111194502,
                                  0,
                                  0,
                                  0,
                                  0.38244724273065589,
                                  -0.014462582453274031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2986450607790252,
                                  -0.28921845719978861,
                                  0,
                                  0,
                                  -0.89129852158861167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31660612615595618,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.73414698655798516,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25476767684193358,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.074758994370321324,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5381227344125229,
                                  0,
                                  0,
                                  -0.43463486487558628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.6629680768692231,
                                  0,
                                  0,
                                  0,
                                  0.25121929058023706,
                                  -0.050409716193046974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043682514164037366,
                                  0.18050361365549134,
                                  0,
                                  0,
                                  0,
                                  -0.19636867923866605,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41365441015864074,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.9053503964819567,
                                  0,
                                  0,
                                  0,
                                  -0.066747498500574154,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50193090651415151,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45080815717436185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29256521003310987,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038254400717342381,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42164216977979491,
                                  -0.17392353427863488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030815257157179223,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.027243410366229168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70769882793124539,
                                  0,
                                  0,
                                  0,
                                  -0.48295915176146809,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056126488396732163,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25040087857766019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61502415290886558,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70754678337648458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.3277797171486676,
                                  -0.030954290743856777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21559944892651151,
                                  0,
                                  0,
                                  0,
                                  -0.12897191428918961,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050112857808971095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.76216299037882118,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38984895201669939,
                                  -0.40920768454480116,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51087242425542967,
                                  0,
                                  0,
                                  -0.15137604877837646,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21529083867831272,
                                  0,
                                  -0.023908028354553357,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67341291572128625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11779490468958657,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35559277112939741,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15993080083160205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60786761935747813,
                                  0,
                                  0,
                                  0,
                                  -0.055340781962092994,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12071434155126694,
                                  0,
                                  0,
                                  -0.3451313357311665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15881699656980777,
                                  0,
                                  -0.36223337788481857,
                                  0,
                                  0,
                                  0.33276870552084958,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08461207444689392,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1807118889602366,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35895182842647949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19062523135581702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14688604524386678,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10104444733724702,
                                  0,
                                  0,
                                  0,
                                  0.27570296643416675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42184552429768768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5493822298244142,
                                  0,
                                  0.15767834404162567,
                                  0,
                                  -0.016273916665271254,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014932072986108044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12634768828495924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22851262356963647,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.033561567114607949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54446234820633721,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052327617920235742,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13554616138610295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14763068606146415,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.042134664905701308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.63384337984560291,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37799207081708724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15545052312290317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032371701292198546,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7219307223184761,
                                  0,
                                  0,
                                  -0.75551266871482814,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19231607431224979,
                                  0,
                                  0,
                                  0,
                                  0.17935236658778284,
                                  -0.49177056331575075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086661381673064447,
                                  -0.83747397562951098,
                                  0,
                                  0,
                                  0.32824770142619691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.071769117299404231,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38894076674741251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.69828581949728885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18874482051963978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54528992030801138,
                                  0,
                                  0,
                                  -0.39734170972612221,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45904714290942483,
                                  0,
                                  0,
                                  0,
                                  0.41298830380702178,
                                  -0.57918797066082539,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.75548318642827827,
                                  0.071262007895635804,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38796202073054781,
                                  0,
                                  0,
                                  0,
                                  -0.39415036380571894,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29047404612968597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45937375818580184,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13015350156386241,
                                  0.32879950593918283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20444422067322993,
                                  0,
                                  0,
                                  0.25847767895004425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.018140380663886763,
                                  0,
                                  0.82814751100620509,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14300318210238808,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32624782459880686,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.08612088774222551,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39929864925259856,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22298520007859904,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32200632884566571,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12307551796534821,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50581276020311794,
                                  0,
                                  0,
                                  0,
                                  0.29455775678771939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.3623251094247286};

const double rot_12_30[900] = {-0.4677948973505488,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16485236835903291,
                               0,
                               0,
                               0.36502162739157207,
                               0,
                               0.53308520912356616,
                               -0.065109710140743848,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21031336720970642,
                               0,
                               -0.53674949019780416,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18720838401908826,
                               0,
                               0.47361265692622051,
                               0,
                               0,
                               0,
                               0.33243042799642586,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.91706492818972274,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.224476109113255,
                               0,
                               0,
                               0.40682196661287645,
                               0,
                               0,
                               0.16969959466124246,
                               0,
                               0,
                               0,
                               0,
                               0.6114095199257763,
                               0,
                               0,
                               0.047018983730248307,
                               0,
                               0.63728484236920979,
                               0,
                               -0.71165435633913454,
                               0,
                               0,
                               -0.57016522334327624,
                               0,
                               0,
                               0.2109102140460129,
                               0,
                               0.55354610095508083,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.68676992696340022,
                               0,
                               -0.87681108910746342,
                               0,
                               0,
                               0,
                               0.25826165520992933,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.60080617171767481,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.093557589206387709,
                               0,
                               0,
                               0,
                               0,
                               0.24410416994719047,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.3265322047529464,
                               -0.74416488627733846,
                               0,
                               0,
                               0,
                               -0.58594392096790071,
                               0,
                               0,
                               -0.48864270552488664,
                               0,
                               0,
                               0,
                               0,
                               -0.096168448914055404,
                               0,
                               0,
                               -0.043701952395592658,
                               0,
                               0.60619518640505876,
                               0,
                               0.32714363547683462,
                               0,
                               0,
                               -0.19400221768249504,
                               0,
                               0,
                               -0.62901974437369579,
                               0,
                               0.46333785910920788,
                               0,
                               0,
                               0,
                               0,
                               0.54312675800065213,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33347514916225962,
                               0,
                               0,
                               0.6421722088087396,
                               0,
                               0.056552861640764757,
                               -0.39773802672547093,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14006835236106255,
                               0,
                               0.020238489870558145,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13337969129116201,
                               0,
                               -0.36824140395254346,
                               0,
                               0,
                               0,
                               1.4550971832018129,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40157211188797787,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.58039343552564848,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.87454920902884004,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.48493678040238469,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25780593438417282,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.45616586915047003,
                               0,
                               0,
                               -0.2190686568705123,
                               0,
                               0.46638707174764676,
                               -0.09680432302909503,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3742874714002758,
                               0,
                               0.55720609714698177,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13177135552181476,
                               0,
                               0,
                               -1.0352168574102083,
                               0,
                               0,
                               0,
                               0,
                               0.68925549386181961,
                               0,
                               0,
                               0.083779800325668619,
                               0,
                               -0.45087530285372657,
                               0,
                               -0.35900166903390052,
                               0,
                               0,
                               -0.15119601465373647,
                               0,
                               0,
                               0.51446521413705715,
                               0,
                               -0.069612284537842323,
                               0,
                               0,
                               0,
                               0,
                               0.22787755225371359,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22273225703655278,
                               0,
                               0,
                               -0.49512031286989006,
                               0,
                               0.30357113190992208,
                               -0.70731904602096551,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19204666720044528,
                               0,
                               -0.15485622771462457,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4581770911610395,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19089374973139794,
                               0,
                               0,
                               -0.37620159084374705,
                               0,
                               0.094748775263532231,
                               0.35113007039610766,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51880708552233912,
                               0,
                               -0.4589937295397733,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.73302134263755492,
                               0,
                               0,
                               0.52014332646193417,
                               0,
                               0,
                               0,
                               0,
                               0.098490901466520342,
                               0,
                               0,
                               0.15947542427033812,
                               0,
                               -0.43927199126276084,
                               0,
                               -0.65891634419296685,
                               0,
                               0,
                               0.51130115480692051,
                               0,
                               0,
                               0.22064647673289856,
                               0,
                               0.27127585155792133,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.48493678040238458,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.87454920902883981,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11973853224885046,
                               0,
                               0,
                               -0.083197885358071738,
                               0,
                               0,
                               0,
                               0,
                               0.068062693876142444,
                               0,
                               0,
                               0.21597462542931728,
                               0,
                               0.55354237994621436,
                               0,
                               0.017016799221378998,
                               0,
                               0,
                               1.2556069480823822,
                               0,
                               0,
                               0.39033900902993268,
                               0,
                               -0.6382064211243067,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.77872955690195811,
                               0,
                               0,
                               0.47360430085312188,
                               0,
                               0.25859196391005651,
                               0,
                               0,
                               0,
                               0,
                               -0.32001474906923405,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3709610084131762,
                               0,
                               0,
                               -0.29821846436544791,
                               0,
                               0,
                               0,
                               0,
                               -0.5437421492878497,
                               0,
                               0,
                               0.41791473807289575,
                               0,
                               -0.21056463071178472,
                               0,
                               -0.61903194675577544,
                               0,
                               0,
                               -0.63959266835871298,
                               0,
                               0,
                               -0.53408742634740458,
                               0,
                               -0.75915325988457172,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2627508954459094,
                               0,
                               0.81113717660405793,
                               0,
                               0,
                               0,
                               -0.38219651804481525,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.816864488406015,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.60978507226051815,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26764165197896589,
                               0,
                               0,
                               0.72537414952012769,
                               0,
                               0.21557581306363177,
                               0,
                               0,
                               0,
                               0,
                               0.59642883746166564,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11611848404079106,
                               0,
                               0,
                               -0.60946264010586249,
                               0,
                               0,
                               0,
                               0,
                               -0.56980816817213453,
                               0,
                               0,
                               -1.2111128833977518,
                               0,
                               0.44904203374627,
                               0,
                               -0.14660914951591092,
                               0,
                               0,
                               0.3036081815362438,
                               0,
                               0,
                               0.38585447783759708,
                               0,
                               -0.068100113729839901,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36719471909922086,
                               0,
                               0,
                               -0.10069975999558411,
                               0,
                               0.85528674768161639,
                               0,
                               0,
                               0,
                               0,
                               -0.35144299088569048,
                               0,
                               0,
                               0,
                               0.39341733825450392,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35711822400174659,
                               0,
                               0,
                               0.11813612600676043,
                               0,
                               0.60086140122601517,
                               0.42917676723431702,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28148970057180767,
                               0,
                               0.28154867293897629,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.039139247091559103,
                               0,
                               0,
                               0.041035747762032906,
                               0,
                               0,
                               0,
                               0,
                               -0.96826622004511342,
                               0,
                               0,
                               0.58640981627904698,
                               0,
                               0.078347352405494369,
                               0,
                               -0.16664429733352212,
                               0,
                               0,
                               -0.47821954878692718,
                               0,
                               0,
                               1.2319461440169721,
                               0,
                               0.55567603969712809,
                               0,
                               0,
                               0,
                               0,
                               -0.055549358480542946,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.66328516750682043,
                               0,
                               0,
                               -0.075862269340125882,
                               0,
                               0.18148786993702515,
                               0.14285956058560553,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.64092032819498879,
                               0,
                               -0.29510405512268384,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36444963002229047,
                               0,
                               0,
                               0.36791858492626039,
                               0,
                               0,
                               0,
                               0,
                               0.35894379134771565,
                               0,
                               0,
                               0.013974401306580994,
                               0,
                               0.37779651315228202,
                               0,
                               0.55675469198146676,
                               0,
                               0,
                               -0.73856040871871564,
                               0,
                               0,
                               0.59097882146900438,
                               0,
                               -0.7220126113233678,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43256937200742124,
                               0,
                               0,
                               -0.48927586059216932,
                               0,
                               0.39388049490079585,
                               0,
                               0,
                               0,
                               0,
                               0.64680060789984006,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.97837669781974035,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21734452337853374,
                               -1.5114240846004618,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.9025737429322811,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.7989370810732378,
                               0.79056819402261913,
                               0,
                               0,
                               -0.83924446626262772,
                               0,
                               0.94679924556419925,
                               0,
                               0,
                               0,
                               0.29778687440042506,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.74906286323660487,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.78894694961030887};

const double rot_12_2[4] = {-0.89164556957838559, 0.45273411430025529, 0.4527341143002554, 0.89164556957838537};

const double rot_13_50[2500] = {-0.17087247393561861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14184379903794025,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55616305678411304,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23449995651969299,
                                0,
                                0,
                                -0.28355877829828308,
                                0,
                                0,
                                -0.3737866256393142,
                                0,
                                0,
                                0,
                                0.25225178101746981,
                                0,
                                0,
                                0.55011123938990192,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1770494413772696,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.98948290293748409,
                                0.40245543719769084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55680111292669576,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.033722023606360584,
                                0,
                                0,
                                0,
                                -0.53910691182636206,
                                0,
                                0,
                                0,
                                -0.11564175906679004,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3992834836623953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73172825965606536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33042353314216799,
                                0,
                                0,
                                0,
                                0,
                                0.93143506228553496,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30286359097410287,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.014166519649041281,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37191801093873239,
                                0,
                                0,
                                -0.83686556112338917,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.032812266863704559,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34442504499072274,
                                -0.86960829466682554,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.054702323414724752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32979257220696989,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11099852477938404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53778605882457009,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60189982812522758,
                                -0.090167905826135028,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66550264014769234,
                                0,
                                0,
                                0,
                                0,
                                0.53833757438298158,
                                0,
                                0.05094426318780397,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0078935719862053243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.91766825412209319,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.85754160858684914,
                                0,
                                0,
                                0,
                                0.3334228246775538,
                                0,
                                0,
                                0,
                                -0.29161747326590143,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.036489976209964775,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25899679621285854,
                                0,
                                0,
                                0,
                                0.045968184332631876,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33646503991951848,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49002855381638771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59315009837383703,
                                0,
                                0,
                                0.37750371944089695,
                                0,
                                0,
                                0.25265329144051862,
                                0,
                                0,
                                0,
                                0.28318741649996015,
                                0,
                                0,
                                -0.07864682735802922,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73678829136509061,
                                0,
                                0,
                                0,
                                0,
                                0.27468705644493568,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47508627315471258,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53652310051074681,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.89417396173160757,
                                0,
                                0,
                                -0.17531958320861579,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17226457105367143,
                                0,
                                0,
                                0,
                                0,
                                0.24248240263764267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15680768155301816,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21912279049532968,
                                -0.68113577812833104,
                                0,
                                0.377512624474306,
                                -1.0426136942599844,
                                0.64975627686669801,
                                -0.40404015644369201,
                                0.062389471515294934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38333674547483632,
                                0,
                                0,
                                0,
                                0.5131294722581824,
                                0,
                                0,
                                0,
                                0.064295219124787056,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45224619651726827,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61732534923017601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.096041654831269266,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46051241745397847,
                                0.032963485910214932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76858144060515132,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42683791994526515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068627121160081447,
                                0,
                                0,
                                0,
                                0,
                                -0.28714668334362081,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53152377550277918,
                                0.40162563947135921,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1481048534997414,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23938431343616245,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62808136964072458,
                                0.4148205896177809,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25200432998382949,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24501474152327468,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49061919324879377,
                                0,
                                0,
                                0.47609320939615318,
                                0,
                                0,
                                0.06846755905522578,
                                0,
                                0,
                                0,
                                0.442305107353411,
                                0,
                                0,
                                0.19155135364627282,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2649621104493759,
                                0,
                                0,
                                0,
                                0,
                                -0.65405947252868968,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53691994822452271,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28807382699099182,
                                0.19815520297422934,
                                0,
                                0.64996627553931097,
                                -0.43310227822783626,
                                0.35953438727787057,
                                0.92694448294470089,
                                0.097616648620597435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51590154220755413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40028232450654566,
                                -0.48292542057000754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22795309293627558,
                                0,
                                0,
                                0,
                                0,
                                -0.074087276534615332,
                                0,
                                -1.2837794408348369,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38985635245734102,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54541771029511799,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21018070732040722,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3921202951466437,
                                0.35715229241239099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54792078272127864,
                                0,
                                0,
                                0,
                                0,
                                -0.09912598668600664,
                                0,
                                -0.46978068961828157,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87387946154945317,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.99180108644138376,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42307644935726307,
                                0,
                                0,
                                0,
                                0,
                                -1.0097251293671241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.89976981066977246,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0101899585469944,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37573096354610502,
                                0,
                                0,
                                -0.39643085747476131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67053621598958157,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42385012080058593,
                                0.83684614208771002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.038367817261234394,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39341493956743367,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.78088905663087826,
                                0.6648960079141838,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43199101588106448,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31141716051381729,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13503584129553092,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16940593821994546,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.028024239180432856,
                                0,
                                0,
                                0.12985126041532633,
                                0,
                                0,
                                0.54215333717622605,
                                0,
                                0,
                                0,
                                -0.35215340563939912,
                                0,
                                0,
                                0.64845765618974949,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35409818943030197,
                                0,
                                0,
                                0,
                                0,
                                0.46585178813986899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.016587034439416337,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11186678972130171,
                                -0.49945698359940061,
                                0,
                                0.80804041379096125,
                                0.58764861159776283,
                                -0.52022036219116941,
                                0.093290702860848923,
                                0.085059532356051237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31928142880914373,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71514976628049653,
                                1.0163268738037539,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14870243723083693,
                                0,
                                0,
                                0,
                                0,
                                0.68980156814575189,
                                0,
                                0.18684303581977546,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24766440031233744,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69663731198651602,
                                0,
                                0,
                                0,
                                0,
                                -0.0088105965671626853,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18928498725502071,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.087849128332922993,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25731332889221248,
                                0,
                                0,
                                -0.57897230034402336,
                                0,
                                0,
                                0.63089583185111853,
                                0,
                                0,
                                0,
                                0.30082387294824153,
                                0,
                                0,
                                -0.25774497214340897,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46993034920192367,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38816850655775798,
                                -0.035871362759645128,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47473552061200108,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23864774764385688,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58726259949294446,
                                0,
                                0,
                                0,
                                -0.47493959758796972,
                                0,
                                0,
                                0,
                                0,
                                0.51701929907323518,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1281031402305934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68804764171192212,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42402908004511219,
                                0,
                                0,
                                0.29946787167945887,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7625241656959787,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21137379088176075,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21944251974998288,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.023936692640186677,
                                0,
                                0,
                                -0.21043524188840509,
                                0,
                                0,
                                0.02737971202852639,
                                0,
                                0,
                                0,
                                -0.51606077616831048,
                                0,
                                0,
                                0.11746773246435875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21954811315749745,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69828266936510375,
                                -0.45934148026667015,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.86188142152932357,
                                0,
                                0,
                                0,
                                0,
                                0.14598963713801266,
                                0,
                                0.64837025695749384,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.07615779086941861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19040131349618941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19647440393137611,
                                0,
                                0,
                                0,
                                -0.21612544628335123,
                                0,
                                0,
                                0,
                                -0.8800117072387057,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35725124891299576,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11242126285341242,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.031753482814247856,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39738387754911014,
                                0.21799865458621848,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56046706320136896,
                                0,
                                0,
                                0,
                                0,
                                -1.0555846983725297,
                                0,
                                -0.055096704001976859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32561199886857778,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27133923596660708,
                                0,
                                0,
                                0,
                                0,
                                0.22689026751394392,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.8341494022133138,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31679054097485687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.055707239236503517,
                                0,
                                0,
                                0.12558797795984217,
                                0,
                                0,
                                0.30537595843489551,
                                0,
                                0,
                                0,
                                0.12619085785323692,
                                0,
                                0,
                                0.15590089523899006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3018062574267637,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48109657206874756,
                                -0.78877291076403355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1773687632660561,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.81939755934799485,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.081431858511963509,
                                0.56741210081724291,
                                0,
                                -0.25813335869698212,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.092832331311681365,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45342622285334988,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53085192798193315,
                                0,
                                0,
                                0.37188037242017813,
                                0,
                                0,
                                0.076145583557013452,
                                0,
                                0,
                                0,
                                -0.40471006557101674,
                                0,
                                0,
                                -0.35981498011722224,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.054561112553497215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.086492270956865486,
                                0.247182936532549,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33776235429747714,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.77028028458521691,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47013577097210713,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.015604606706529996,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71536487658994896,
                                0.49900945905169775,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26070732968710408,
                                0,
                                0,
                                0,
                                0,
                                0.31502238617716066,
                                0,
                                0.43101265213252005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58876949164681036,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67583741570261191,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67866448338290775,
                                0,
                                0,
                                0,
                                0,
                                0.29427159649036266,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43664385865826161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2418132655784741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56621708831081885,
                                0,
                                0,
                                0.75917028175862811,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.024500728099072167,
                                0,
                                0,
                                0,
                                0,
                                0.91021454808028845,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38435179809540121,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.294930847578065,
                                -0.059496088410413955,
                                0,
                                0.049874601425799435,
                                0.28943841422058625,
                                0.33455602429634435,
                                0.16904837813286275,
                                0.25133097144218558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52622100050546239,
                                0,
                                0,
                                0,
                                0,
                                0.10441036466290787,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83968122092813402,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.049714081340797814,
                                0.6639682949535789,
                                0,
                                0.25515910106013995,
                                0.27185318239617634,
                                0.55543753669424545,
                                -0.32003362734176449,
                                0.25547987229989128,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.8541165297346458,
                                0,
                                0,
                                0,
                                0,
                                0.65300628740010058,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43423652298823656,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.81544535827418962,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.052311224714419111,
                                0,
                                0,
                                0.64169738513811037,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33962179653290581,
                                0,
                                0,
                                0,
                                0,
                                0.45428160633252568,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47241654380998649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.06790260818214236,
                                0.84476139786296423,
                                0,
                                0.28135210188142779,
                                -0.6828461096131222,
                                -0.25060518724177139,
                                0.15869825290205605,
                                0.89252671196275213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1943028883166939,
                                0,
                                0,
                                0,
                                0,
                                0.28584299049578593,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15593462431789681,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60045596426120929,
                                0.053241970384765358,
                                0,
                                0.33703945598917651,
                                -0.55394258139011543,
                                -0.27564760366308649,
                                -0.49299005613298114,
                                -0.96912098557490234,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.014758450620532354,
                                0,
                                0,
                                0,
                                0,
                                0.67549811763973577,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51776557254651046,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63912718376368971,
                                0.063131311124215744,
                                0,
                                0.26841516231130563,
                                0.070392023423122507,
                                0.29043612749284364,
                                0.26448167709619924,
                                -1.1072244971147955,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.94826131605436492,
                                0,
                                0,
                                0,
                                0,
                                0.067564687927123834,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.97479745569815257,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0069509029654713922,
                                -0.16972382142264436,
                                0,
                                0.026146825916607424,
                                -0.26028900368182328,
                                -0.14597317419152533,
                                0.74929390382885774,
                                0.11224561176687353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5739600544630159,
                                0,
                                0,
                                0,
                                0,
                                -0.13768909778805086,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17932436023019005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35635602660577659,
                                -0.48592593318105981,
                                0,
                                -0.68455535916152488,
                                -0.52428128659301054,
                                -0.38661945592632302,
                                0.90535257411012737,
                                -0.086589930161281442,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2615203739051597,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12454220312555794,
                                -0.48427667107533973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13871642248898652,
                                0,
                                0,
                                0,
                                0,
                                0.19694892550395851,
                                0,
                                0.01704673880532941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36142933109116687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41425165648417417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27917013241882105,
                                0,
                                0,
                                0,
                                0.53682482596648329,
                                0,
                                0,
                                0,
                                -0.35075882421752963,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71209978528039675,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.061361929797440415,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45371528353298057,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5128204666574685,
                                0.72880560540229333,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35032853327003832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85462507650811637,
                                -0.38325695998945625,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.82670108855690871,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47814900963041401,
                                -0.13786047070656324,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21189137506949079,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.038169826020541753,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15026122233485031};

const double rot_13_20[400] = {1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18093709138868252,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.79979453892359942,
                               1.0624999468866663,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.45418841067051874,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.65037694477888863,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.60887003318661193,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44306265142088053,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.045997244546024746,
                               0,
                               0,
                               0.37280041997814861,
                               0,
                               -0.81400220348239138,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15399627447142514,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.73045321291291876,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.66537451949568638,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.54033165507836478,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.77740185353993185,
                               0,
                               0,
                               -0.11252072724472251,
                               0,
                               -0.30170705423186894,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.80894251736130285,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5900406509174303,
                               -0.4191737515868641,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.4076234802003644,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.3097263955355891,
                               -0.019133974414974858,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1514723187881204,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39710182710443143,
                               0,
                               0,
                               -0.77869663720393445,
                               0,
                               -0.46151687158602944,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.69913755876588812,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.48563437946378313,
                               0,
                               0,
                               -0.49192527889072574,
                               0,
                               0.18268947258663698,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.87749531911088063,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20844167876237191,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43191901034015479,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1};

const double rot_13_10[100] = {-0.62396637207290295,
                               -0.58761524443470692,
                               0,
                               0.49193414847016148,
                               0.15288912518245631,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.042801306938229283,
                               0.30216464667442977,
                               0,
                               0.63561483014612574,
                               -0.70912506804005104,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.64468776826505236,
                               0,
                               0,
                               0,
                               0,
                               0.54977142074084395,
                               0,
                               -0.53115823102538895,
                               -0.74946741116832216,
                               0.62630895477634529,
                               0,
                               -0.21225043567587604,
                               0.031391803373096383,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21710047038920022,
                               -0.41369305526563854,
                               0,
                               -0.55582761160511762,
                               -0.68759079979237747,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28056632301206613,
                               -0.83180618365723846,
                               0,
                               1.4825897730325361,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.75653814374806805,
                               -0.23635980852934668,
                               0,
                               -0.92604774481726948,
                               0,
                               0,
                               0,
                               0.52808913429763016,
                               0,
                               0,
                               0,
                               0,
                               -0.1820924035540622,
                               0,
                               -0.82943608723317741,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.86494786159807802,
                               -0.76753044393491743,
                               0,
                               -0.90600802249912282,
                               0,
                               0,
                               0,
                               -0.55272013504684769,
                               0,
                               0,
                               0,
                               0,
                               -0.81522619039411315,
                               0,
                               -0.17293556837532387};

const double rot_13_100[10000] = {-0.54002352073894411,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2875745003949578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62582326675995081,
                                  0,
                                  0,
                                  0,
                                  0.1457047110481812,
                                  0.57077298408790711,
                                  0,
                                  0.12073226623205872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27437924130639596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.68575629593256071,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55267394456472285,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60035871793407602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65756321120254146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085248374261590931,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.90828478553504144,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31484950196529987,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22846832698225586,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48969183903132751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10344485980778378,
                                  0,
                                  -0.54114923986437879,
                                  -0.0034766375335361852,
                                  0,
                                  0.19945731873388134,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13036056243222827,
                                  0,
                                  0,
                                  0,
                                  -0.16547926690126386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098880353503229393,
                                  0,
                                  0.59548484061142759,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039361452377484701,
                                  0,
                                  0,
                                  0,
                                  -0.098854090458436294,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27815973367825708,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55820000821746174,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043196638469091699,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15854016704379853,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18166864457492427,
                                  0,
                                  0,
                                  0.34774386501218169,
                                  0,
                                  0,
                                  0.41337064477717023,
                                  0,
                                  0,
                                  0,
                                  0.49790856798446198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47694737920609848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18977760077243305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31422012824594941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48717159122910697,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46657527063626553,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30761930467622689,
                                  0,
                                  -0.17386241198808186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24059292037960528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.075685727056595375,
                                  -0.12862034842964015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27705315728883417,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62591149424903847,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29283983110997225,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65073009720501984,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16756463065941712,
                                  0.93697598135986648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.051672911517689095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10863967032603984,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27881810743742297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.042259911481605031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39315868491881445,
                                  0,
                                  0,
                                  0,
                                  -0.17292668774575837,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53496962302760109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074577297456933186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11350576354910127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23452011064458067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6663083006383933,
                                  0,
                                  0,
                                  0.027446736895756246,
                                  0,
                                  0,
                                  -0.012223048520902058,
                                  0,
                                  0,
                                  0,
                                  -0.10495532308230607,
                                  0,
                                  0.31362513452166285,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19934598256143615,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059367829495728344,
                                  0,
                                  0,
                                  0,
                                  0.13896127981860509,
                                  -0.072492160735695615,
                                  0,
                                  0.59370649951324128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.86618007154950649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20976274935811512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66934336564347485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50322804773439644,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028222556796810339,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4379253242777516,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25243867465444925,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37485422948356556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13039111575056772,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40248512431531602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14499008402951308,
                                  0,
                                  0.1536172817236286,
                                  -0.58053125047452914,
                                  0,
                                  0.26568606192403871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5786460276133466,
                                  0,
                                  0,
                                  0,
                                  -0.026551962401774917,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21397484380611262,
                                  0,
                                  0.021774729363477154,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23817175653239403,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.036807691501429082,
                                  0,
                                  0,
                                  0,
                                  0.19061494550053604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26549621128344075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20513287694134238,
                                  0,
                                  -0.10422103884016104,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20007863187115688,
                                  0,
                                  -0.68337463388376551,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29451270250976136,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0021717119699646865,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38643896686449908,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1975998934524747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27416827939751937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.80484757193414247,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.2267553493111705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27102641282486373,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.8091313695083473,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61052779784157296,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50583226326575603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41342608158113664,
                                  0,
                                  0,
                                  1.314378288330063,
                                  0,
                                  0,
                                  0.55981521462516148,
                                  0,
                                  0,
                                  -0.72735443450712178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.045332283070527529,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48583888511293916,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47509584207156891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10255581235145092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29953395046608372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39214017576056914,
                                  0,
                                  0.16357844714397779,
                                  0,
                                  0,
                                  0,
                                  -0.50488905607833345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48553428631232276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27849752320044785,
                                  0,
                                  0.41146753270434805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61805647646358275,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078376297621596425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.70591967765714181,
                                  0,
                                  0,
                                  0.056133222714187761,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1556089471933883,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.63683641012773962,
                                  0,
                                  0.24664507369066924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1293119365019344,
                                  0,
                                  -0.096152413894279018,
                                  0,
                                  0,
                                  0,
                                  0.10236143442204255,
                                  0,
                                  -0.24703391970716451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19972532242762706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31576429151613605,
                                  0,
                                  0,
                                  0.20343195680892415,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060610913006947778,
                                  0,
                                  0.40499159691224323,
                                  0,
                                  0,
                                  0,
                                  -0.24915831348160011,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03416680789931921,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40369395381469148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10325177506660818,
                                  0,
                                  0,
                                  0,
                                  -0.36764924598235221,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28358397855195444,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085998378532662456,
                                  0,
                                  -0.25833294808115548,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.073190821425397928,
                                  0,
                                  -0.072185502323691073,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23094287110385617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28913809946386382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36513704169611794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50579109905301001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21215146439562352,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25758065096078481,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41301945371738563,
                                  0,
                                  0,
                                  0,
                                  -0.042660857485847609,
                                  -0.38546833928551161,
                                  0,
                                  0.7493202585619948,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45451297402350316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10591368178838931,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.95710534207364084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33599906662819823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26705511158695383,
                                  0,
                                  0,
                                  0,
                                  -0.12745312185075741,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28710148959238707,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46374840164606462,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29424999283745601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025047480371316204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12853302835293998,
                                  0,
                                  0,
                                  0.091331156902881377,
                                  0,
                                  0,
                                  -0.15363067798866453,
                                  0,
                                  0,
                                  0,
                                  -0.69229508475395107,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.071094707425463602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.084972721770513016,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.82401366412233867,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40965919339321322,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25183766210940767,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25107235250483234,
                                  0,
                                  0.012630226774894084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1195280254236268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079031387654179386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.73675980822024412,
                                  0,
                                  0,
                                  0,
                                  -0.34878499555282949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19931285589218439,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18391225863488714,
                                  0,
                                  0.40912350848913825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.054440242998467871,
                                  0,
                                  0.015897370823827389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.055252601510191533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056062422502608317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25884062396163537,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10929726792190958,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12028395262676247,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24917971582760684,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11154184681910263,
                                  0,
                                  0,
                                  0,
                                  1.4141664188959941,
                                  -0.69974303516092429,
                                  0,
                                  -0.0088339355342095111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34089811266220438,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42729384841720863,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26234765538882865,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43893247596476226,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58951717449335128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.99497876891178194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.74000175056877504,
                                  0,
                                  0,
                                  0,
                                  0.09287143269732262,
                                  0.15892856868944547,
                                  0,
                                  0.47143292869924758,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43692463733988379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2535485891720865,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19417750550488444,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0049066687136053166,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66159078113550562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086361571584761154,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23970447526288541,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.74162954964155958,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27893495298347348,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31642105281664845,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.061737589311199936,
                                  0,
                                  -0.037589715821736966,
                                  -0.21786627981041345,
                                  0,
                                  0.63182593339980109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72658498869848731,
                                  0,
                                  0,
                                  0,
                                  0.1315487861990004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28699524562760964,
                                  0,
                                  0.17379420745020746,
                                  0,
                                  0,
                                  -0.45909232999582961,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63113980758260557,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.099223054983834463,
                                  0,
                                  0,
                                  0,
                                  -0.83227768131659108,
                                  -0.49697141299980663,
                                  0,
                                  0.32371998881868969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1366466428572124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.92535873352497988,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070348668224049254,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37672275889451634,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23713722668048887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52398381687881435,
                                  0,
                                  -0.33325897193420789,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26224535658458875,
                                  0,
                                  -0.13720690504224631,
                                  0,
                                  0,
                                  0,
                                  -0.36101030559446873,
                                  0,
                                  -0.01623789596391256,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.016458594904952044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10781083341819875,
                                  0,
                                  0,
                                  -0.4419741341328865,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15214129396765957,
                                  0,
                                  -0.1437672031420337,
                                  0,
                                  0,
                                  0,
                                  0.15193669187737049,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25655203056174192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0061468977621296078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.065732843539110575,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38138340134983695,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16752022270598149,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48643555354079004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.2528398727827594,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10938304879541852,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15488918604024329,
                                  0,
                                  0.5487603117095623,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54911388899109137,
                                  0,
                                  0.19465320651328152,
                                  0,
                                  0,
                                  0,
                                  0.36106744433448862,
                                  0,
                                  0.21040002804791452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21398505989778321,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.011635863429117051,
                                  0,
                                  0,
                                  -0.14395202308931163,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.045531376384696384,
                                  0,
                                  -0.18640855341565729,
                                  0,
                                  0,
                                  0,
                                  0.18274044794236347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10950111169262791,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57498443132632449,
                                  0.26875108731905628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53914445636741115,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34004852640039795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27354508944158673,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34063043859991249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38204909995173431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54013305579462378,
                                  0,
                                  0,
                                  0.14647442968294683,
                                  0,
                                  0,
                                  0.69863144663744214,
                                  0,
                                  0,
                                  1.2223525856553243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067104184367902525,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35129836597664449,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064952128097794798,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47880617378863821,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39342771217191386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.75017991523738425,
                                  0,
                                  0,
                                  0,
                                  0.068970869224450088,
                                  0.23771235095208193,
                                  0,
                                  0.2484304845081107,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58867800124173841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53284991887431554,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45875076333348552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.88649970640144804,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.79479859162870281,
                                  0,
                                  0,
                                  0,
                                  0.11471218839085807,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19199100352382467,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27910222671253143,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2872253349041628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24698495004553428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27467815477926194,
                                  0,
                                  0,
                                  -0.063316034210811195,
                                  0,
                                  0,
                                  -0.13021497924989331,
                                  0,
                                  0,
                                  0,
                                  0.021559357774612636,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.076290989065705361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35936852761152804,
                                  0,
                                  0,
                                  0.57679159727601359,
                                  0,
                                  0,
                                  -0.8096486562959001,
                                  0,
                                  0,
                                  -0.10609406722169301,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53099358572035871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.92781727548319071,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39837845101051272,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.076317286643101154,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4995614342735652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17868055005078909,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095067026302681781,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4619461164491388,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52886154800919694,
                                  0,
                                  0.38016320265340303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25697617510708748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051906431097100081,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38249463148394552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29302238837569189,
                                  0,
                                  -0.30040576870505625,
                                  0,
                                  0,
                                  0,
                                  -0.23301365872265661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16072068867636902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58792493081201758,
                                  0,
                                  -0.87368702949042243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53135965796785367,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55215774138474627,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30954876719189917,
                                  0,
                                  0,
                                  0.23082131608407561,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10631736979270345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.76996511458608596,
                                  0,
                                  0,
                                  -0.57976813922566017,
                                  0,
                                  0,
                                  -0.57938272176416628,
                                  0,
                                  0,
                                  -0.13223762889651314,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24610402689434624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33456224325994788,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16320369739682647,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34811590897810296,
                                  -0.1593741028918802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52648894735064222,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46608120724893964,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58847228976067445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11266441316836198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.81694227783084783,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36045653154102808,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.92419067552552392,
                                  0,
                                  0,
                                  0,
                                  -0.016145514883807055,
                                  0.22992392945970874,
                                  0,
                                  -0.19846683259736392,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.57876610102510717,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.76144562546430472,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40301000941145404,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19314903493390079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19840799133605777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030518380493659431,
                                  0,
                                  0,
                                  -0.32671865470259942,
                                  0,
                                  0,
                                  -0.25002956052319686,
                                  0,
                                  0,
                                  -0.6429944312033653,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032668928901528685,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.0909611718807151,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.66959604512813609,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54286507824739105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42417997367077542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34408983856954933,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21250977357131259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34065304179219358,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24594571614518818,
                                  0,
                                  -0.08671146103252067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42161352947827097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50002816968987607,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0044481187260214661,
                                  0,
                                  -0.29745794043108353,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0028072115393073215,
                                  0,
                                  -0.15380815657690786,
                                  0,
                                  0,
                                  0,
                                  0.21072115812301337,
                                  0,
                                  -0.2697621752389025,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23084343285806427,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062223770728689148,
                                  0,
                                  0,
                                  0.074419488132895173,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23296537729595129,
                                  0,
                                  0.26705521984336084,
                                  0,
                                  0,
                                  0,
                                  0.3937829302021128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4210413855670278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028895223905423775,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019054741929220631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27082275759462865,
                                  0,
                                  -0.73304541411485158,
                                  0,
                                  0,
                                  0,
                                  -0.47728562724203483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.038167306585501118,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16410340804816126,
                                  0,
                                  -0.2218170218600666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46113239806300332,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70404715742406643,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.066229652972767658,
                                  0,
                                  0,
                                  0.68184309475545923,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11678797433930654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11389855232141123,
                                  0,
                                  -0.0081739759978648602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23118538387149101,
                                  0,
                                  -0.021426923103453933,
                                  0,
                                  0,
                                  0,
                                  0.0046621140957867346,
                                  0,
                                  0.45412263121830748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17308719490491178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17030955068916359,
                                  0,
                                  0,
                                  0.3353391089164921,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28892660424840888,
                                  0,
                                  -0.17606179353628448,
                                  0,
                                  0,
                                  0,
                                  -0.3458147543955758,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55469357351148829,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14057718968334199,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59453369563044045,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20094435857736268,
                                  0,
                                  0.039841401014347605,
                                  0,
                                  0,
                                  0,
                                  -0.14426171210287636,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1390946635082963,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66851157000435901,
                                  0,
                                  0.18276231209056309,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10028705060744196,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26740653959280886,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62937807407765356,
                                  0,
                                  0,
                                  0.51610369666085754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19999624456832057,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1802030659253292,
                                  0,
                                  0,
                                  0,
                                  -0.450698472570838,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.73486877334028022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030698920537267457,
                                  0,
                                  -0.0214397477533039,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12827984245726631,
                                  0,
                                  -0.0024217183828477503,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12913411411346795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.087149686029004025,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3593999418969312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11429984836532596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53863454489499951,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13748505601899622,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20757393296248688,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0149045548162574,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021282369126574725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37257927017668074,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15847613650392955,
                                  0,
                                  -0.2818737926233329,
                                  0.69549370955303114,
                                  0,
                                  0.26721698783697728,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15770613426931557,
                                  0,
                                  0,
                                  0,
                                  -0.049335677803039976,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23986339085246747,
                                  0,
                                  -0.19983042406605514,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40665792211921725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43418353275053873,
                                  0,
                                  -0.14572878843569334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24880837102542114,
                                  0,
                                  -0.34825689707812973,
                                  0,
                                  0,
                                  0,
                                  0.16428875200520413,
                                  0,
                                  0.0098714592612462876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31327926286588398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48743244736540314,
                                  0,
                                  0,
                                  -0.055088812920555862,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1115079152035913,
                                  0,
                                  0.036770677136140295,
                                  0,
                                  0,
                                  0,
                                  -0.11111183081730872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22293362576275549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40135997878490531,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3807515066400658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26705949152439307,
                                  0,
                                  -0.79469733107710816,
                                  0,
                                  0,
                                  0,
                                  0.45417854383442724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59300166034790203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3206641303195028,
                                  0,
                                  -0.030566520526859497,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33192278017303578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17804556471542898,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.075725218730854638,
                                  0,
                                  0,
                                  -0.55920903028241675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23749732540822305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060901449728708354,
                                  0,
                                  0.27286697741642124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.086199114309601338,
                                  0,
                                  -0.044909569233499036,
                                  0,
                                  0,
                                  0,
                                  -0.0087153573901731854,
                                  0,
                                  -4.3002173641115693e-06,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61188454680337268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35165617935196652,
                                  0,
                                  0,
                                  -0.3335551495445771,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25172853080293045,
                                  0,
                                  0.23351977289441586,
                                  0,
                                  0,
                                  0,
                                  -0.023297322106220274,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35796818942471653,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15731751033065514,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10439373597058689,
                                  0,
                                  0,
                                  0,
                                  0.24093043415053617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.034616745142397848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19238570694427332,
                                  0,
                                  0.70894120753960654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26062570430999876,
                                  0,
                                  -0.099899801854428164,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061495346484124976,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.035694037461809484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.023043668128265193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53104140983271098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3257015040067881,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55264356535789827,
                                  0,
                                  0,
                                  -0.47746619026410653,
                                  0,
                                  0,
                                  0.1329197143464611,
                                  0,
                                  0,
                                  -0.14737903025707394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.1462858459982372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029371255998783041,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17117923108378158,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028273278347154138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.058309674097880917,
                                  0,
                                  0,
                                  0,
                                  0.072997427054520322,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11492645876055346,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097446136549250079,
                                  0,
                                  0.17778337451858059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53662940349325039,
                                  0,
                                  -0.57024424845700694,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34307921366789945,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26714939046988567,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35709331315139864,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08014869310240047,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1099748072528814,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1849195110278144,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.97152636762973155,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.09768941199328432,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.99798686951678828,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52228046911408588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.64511054966761205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62843250497003034,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43979837234231878,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.09123124281938251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.035716164097446948,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085058202175814668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.1285376818379442,
                                  0,
                                  0.18612342787868313,
                                  0.020859588026743703,
                                  0,
                                  0.026805068346209632,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.010392260671393674,
                                  0,
                                  0,
                                  0,
                                  -0.079081613209087187,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.8148608777617572,
                                  0,
                                  0.37723953652180209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.73844841218345902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55373576099008015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35883670747841456,
                                  0,
                                  0.33703143030057903,
                                  0,
                                  0,
                                  0,
                                  0.30354736419818562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084811329765458937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35083206089111879,
                                  0,
                                  -0.2587590340626631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25797495773043266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064272844634237103,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16118090186776859,
                                  0,
                                  0,
                                  0.63480958073944282,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06094657893294958,
                                  0.0084337764242210927,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55643991289740624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50446551618880375,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18093577383497511,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63195395242805164,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3598521275306531,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11089419749645751,
                                  0,
                                  -0.10283474722278935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14815179465956346,
                                  0,
                                  -0.1874764836694906,
                                  0,
                                  0,
                                  0,
                                  0.49945251525900125,
                                  0,
                                  0.33421359850401156,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.224634464492104,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24139658151951457,
                                  0,
                                  0,
                                  0.06793923348225045,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22886253315099231,
                                  0,
                                  0.28086038938979313,
                                  0,
                                  0,
                                  0,
                                  0.41508982948928647,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11170108243164288,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.076286401157918099,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5272619075209628,
                                  0,
                                  0,
                                  0.64255745798304864,
                                  0,
                                  0,
                                  -1.1071124003549024,
                                  0,
                                  0,
                                  0.77816090370241231,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19375263932884446,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41660911391395139,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50432165300789455,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1578791526281243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.05270814635022348,
                                  0,
                                  0,
                                  0,
                                  -0.085322640658537896,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19736310595692177,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13515312858723702,
                                  0,
                                  -0.17749705352711151,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32465012435331198,
                                  0,
                                  -0.31856266934009358,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41132998051200237,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6632421178970539,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17655219308376713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17076091312460445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.090459071641501382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37158885126175639,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36421121401174261,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10733061952704862,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62944394301107176,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22455462400191756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41721884527579983,
                                  0,
                                  -0.040924560323604892,
                                  0.31446239351555877,
                                  0,
                                  -0.67002049083671877,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.81339626694944989,
                                  0,
                                  0,
                                  0,
                                  -0.18230315895881677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13768686611935943,
                                  0,
                                  0.34645361235458016,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58786388552610835,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13370010915791841,
                                  0,
                                  0,
                                  0,
                                  -0.26566880887484962,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25353520248021993,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50529161469079353,
                                  0,
                                  0.0014674008374538595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070824815081193621,
                                  0,
                                  -0.16963935526050797,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.075387977474899712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.015096974695537188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44418903312669994,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.096693953432258603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15583822935840347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39245160733568041,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59643410552921683,
                                  0,
                                  0.22693081731902331,
                                  0,
                                  0,
                                  0,
                                  0.13756980049383372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1938642643246882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68688084043308639,
                                  0,
                                  0.19309834035863879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14536077896441768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.74207825080191192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18665567177750544,
                                  0,
                                  0,
                                  0.41160278606148426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36760080608066015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036685823494935987,
                                  0,
                                  0.37889590084701008,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28744030568062573,
                                  0,
                                  -0.21285439187760968,
                                  0,
                                  0,
                                  0,
                                  -0.13592598865474517,
                                  0,
                                  -0.18377202873387719,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13932941702134918,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036578741791995772,
                                  0,
                                  0,
                                  0.16935333361031879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38922926880182201,
                                  0,
                                  -0.35645038669396012,
                                  0,
                                  0,
                                  0,
                                  0.31855214110894026,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33214714926022937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7483008414544956,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044261250329634821,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.8849171694970358,
                                  0,
                                  -0.38511631799602747,
                                  0,
                                  0,
                                  0,
                                  0.30404659330889616,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2463778604100077,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14063448496869582,
                                  0,
                                  0.030572898442581292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28962787053754069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10305150291353193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16315308486582422,
                                  0,
                                  0,
                                  0.35446570500350727,
                                  0,
                                  0.20412390056002566,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10486807499798166,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40921379475220332,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08528131605414406,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62264419382129188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14634505763301309,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19423049715916424,
                                  0,
                                  0.35187548422683534,
                                  0.63135674059869773,
                                  0,
                                  0.66815734122951242,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26605321792175368,
                                  0,
                                  0,
                                  0,
                                  -0.1317973271654545,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0068513305960888624,
                                  0,
                                  -0.53553330513823905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08205849785004668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18384952107109162,
                                  0,
                                  0.28781602271700429,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34095346986708946,
                                  0,
                                  0.25637936711530168,
                                  0,
                                  0,
                                  0,
                                  -0.29282770196042462,
                                  0,
                                  -0.046634886199571873,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48815841402130578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072233585889408675,
                                  0,
                                  0,
                                  -0.23382989253449854,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37365791632083589,
                                  0,
                                  0.26392147927928855,
                                  0,
                                  0,
                                  0,
                                  0.31443296558952977,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019736950124460001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2905409553456953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044287438482088923,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058675243385002379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42875568777512524,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.89209533614427483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13248137433789192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42754189489066019,
                                  0,
                                  0.41862455250989372,
                                  0.4163950607027217,
                                  0,
                                  0.3417191246622604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45842148178614311,
                                  0,
                                  0,
                                  0,
                                  -0.32535921126253176,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22415905133226474,
                                  0,
                                  -0.0024204074527530051,
                                  0,
                                  0,
                                  0,
                                  0.19877562600613438,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030543656016116732,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16327278784890126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15668964624404955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39725514037883647,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.69266948199654588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20570460279640079,
                                  0,
                                  1.004262430791363,
                                  0.23401012321441386,
                                  0,
                                  -0.82782252058331629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21262063203550519,
                                  0,
                                  0,
                                  0,
                                  0.22164697162814628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12554801606252877,
                                  0,
                                  -0.27021241844032573,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18809896907324844,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.67304793601687907,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084017628469709532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67174657971298601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65388791647317523,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.011040583010529598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42322233991320773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56825192253558754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28214941525781401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24594826008300197,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19866976219097568,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09423862541444461,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15355712011225503,
                                  0,
                                  0.11321070103808949,
                                  -0.086016409766445964,
                                  0,
                                  -0.33828480401978001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.096387274116687127,
                                  0,
                                  0,
                                  0,
                                  -1.0699959371934102,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45329457871179907,
                                  0,
                                  0.078376873476739412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047647528772354286,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017047982064741583,
                                  0,
                                  -0.019050791243983043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069795060526088817,
                                  0,
                                  -0.010944129656570236,
                                  0,
                                  0,
                                  0,
                                  -0.41383498296121585,
                                  0,
                                  0.64857992444966717,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.016467579560796079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27367674820577553,
                                  0,
                                  0,
                                  0.093716704372908882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42647458788756792,
                                  0,
                                  0.30638218474209539,
                                  0,
                                  0,
                                  0,
                                  0.19498271959444602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049475935036125483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49623713607234365,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14350463048833775,
                                  0,
                                  0,
                                  0,
                                  -0.021516206358384832,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1227640413287098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.69466186210683245,
                                  0,
                                  -0.0300013911258213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18403897048792223,
                                  0,
                                  0.03191056327666518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19689240859255691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11615287265686863,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053832203617904001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37963316432501065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25603866720420737,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20491865727119235,
                                  0,
                                  -0.13115204478165354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31555943773948542,
                                  0,
                                  -0.06113328552769464,
                                  0,
                                  0,
                                  0,
                                  0.12205204709649245,
                                  0,
                                  0.1042914816784716,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10912957648443791,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53889046940548413,
                                  0,
                                  0,
                                  -0.0066597382270293468,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18919866866680538,
                                  0,
                                  -0.50212701247938674,
                                  0,
                                  0,
                                  0,
                                  0.30525692150338618,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25039412462270866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.07740777828447154,
                                  0,
                                  0,
                                  0,
                                  -0.036072697511695132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15256074900572625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19699725183387579,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28180316647437509,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19447235596006154,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0086590606364464612,
                                  0,
                                  0,
                                  0.44181713483592783,
                                  0,
                                  0,
                                  -0.75856731317392923,
                                  0,
                                  0,
                                  0,
                                  0.20661521371553149,
                                  0,
                                  0.40540171991856255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3692532259367915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38405833594406874,
                                  0,
                                  0,
                                  0,
                                  -0.72448291619803284,
                                  -0.87398574387492678,
                                  0,
                                  -0.32635001139226055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30356156011278623,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32598346830006986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33388836468539002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30536701608868616,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61522573243234313,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.74072374902009019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.654403138738054,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47339316940872489,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24483404845686105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072975172412636485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26346319905840609,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.025407965464959933,
                                  0,
                                  0.26282473127368522,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09897597185205724,
                                  0,
                                  -0.75636990452040787,
                                  0,
                                  0,
                                  0,
                                  -0.047411920945253774,
                                  0,
                                  0.11264331965985293,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15691944318435327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25352380665997287,
                                  0,
                                  0,
                                  -0.2980605300253088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036639238948428979,
                                  0,
                                  -0.0062569612671820041,
                                  0,
                                  0,
                                  0,
                                  -0.16434188060848925,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24064227935916935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044906662537810754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63734048160398227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15389766523385978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45058096746005993,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16879690099638511,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12434299629841619,
                                  0,
                                  -0.046326040205959616,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56477705871540951,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11883994320488384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33761104116945212,
                                  0,
                                  0,
                                  0,
                                  -0.15245405737363882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067879039367635188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2594383404366255,
                                  0,
                                  0.30436498903951953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44682358671471567,
                                  0,
                                  0.020222694094388691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42644709786405854,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.357040122861014,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.090346426905570126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40809584864087955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53609334934686614,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19684942124493124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.042645275940296212,
                                  0,
                                  0.010869722687579034,
                                  0,
                                  0,
                                  0,
                                  -0.76700715601068148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092170781964666382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.012781602720251008,
                                  0,
                                  0.52081303236467513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.73301991551104961,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056112545071446862,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51815198922050554,
                                  0,
                                  0,
                                  0.52060899163792218,
                                  0,
                                  0,
                                  0.2426191795665904,
                                  0,
                                  0,
                                  0,
                                  -0.038434939931319335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10460987622903786,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1330125274984702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20112629276833519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.78280360185948583,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34039451246391084,
                                  0,
                                  0,
                                  0.31332720706988504,
                                  0,
                                  0,
                                  -0.078660519740796769,
                                  0,
                                  0,
                                  0,
                                  -0.19380409057642553,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11639349866296597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01734416845118732,
                                  0,
                                  0.13823782215907601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39385755491435248,
                                  0,
                                  -0.25394097912697672,
                                  0,
                                  0,
                                  0,
                                  -0.33948691486505578,
                                  0,
                                  -0.15322894880171739,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11523332039241993,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.00071919664287235091,
                                  0,
                                  0,
                                  0.56976114594695171,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44162954413514027,
                                  0,
                                  0.02702079283844544,
                                  0,
                                  0,
                                  0,
                                  0.25109447373646704,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10945115903017433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13019243221263477,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27283345009576038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.077866869127537541,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34536189218646868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29166842697820389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22154634626432576,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28341046653460128,
                                  0,
                                  -0.47269143903108946,
                                  -0.54238486172511768,
                                  0,
                                  -0.17613960781812121,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14507567263398199,
                                  0,
                                  0,
                                  0,
                                  -0.28734461818513601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046751162336809884,
                                  0,
                                  -1.0916702777536147,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019043513366683709,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27551314642986569,
                                  0,
                                  0,
                                  0,
                                  0.54378653558903689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32643442833058228,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11615813557446684,
                                  0,
                                  -0.058765225036695394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12197588183095126,
                                  0,
                                  0.22872646650276823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5649958125615876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0034463721231556927,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33320652328929273,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.084070858441066307,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.71462402523071444,
                                  0.088512350166545864,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20755414973495986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.095299917717898253,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61857981720507005,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21604693191143676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10087229870734954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.071391781585032787,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17103255087785926,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49941517123014068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52145699024638836,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48174223345021405,
                                  0,
                                  -0.16153328491472185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4194929938142356,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.72363830633800408,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.69074070277697575,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60714646830083263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025610028102568589,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12143665259332512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10619398818982689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42625168628220045,
                                  0,
                                  -0.24713120682497086,
                                  -0.22196483759420482,
                                  0,
                                  -0.39485554524522243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080185550970671191,
                                  0,
                                  0,
                                  0,
                                  0.35201391695357642,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63600990483814024,
                                  0,
                                  -0.21852944212182915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67074501712510859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29128696553523981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13782327864628319,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18611324481582447,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1775364983427109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4378242563930323,
                                  0,
                                  -0.035860978454660283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43257870055377756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27796782760353594,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40897662376191585,
                                  0,
                                  0,
                                  0,
                                  -0.20754502564942107,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15955389704657388,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17974586967780942,
                                  0,
                                  0.30307911845178276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46955476626613818,
                                  0,
                                  0.091479918869772983,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06320164862609659,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50191082548355581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20631260186249145,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18828177208053909,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1920383037993483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25318761910942117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68284122468110386,
                                  0,
                                  -0.053847747907550925,
                                  0,
                                  0,
                                  0,
                                  -0.45508931170563643,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48015501500831304,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0023586378736396574,
                                  0,
                                  0.050739545649431436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38687289918132811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17908507212611049,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36718893053904528,
                                  0,
                                  0,
                                  -0.51929775335775208,
                                  0,
                                  0,
                                  -0.020595194241797704,
                                  0,
                                  0,
                                  0,
                                  -0.44420165010384821,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037440905906298873,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31807653196803637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26740454206165215,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22151275384007832,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09212641332730169,
                                  0,
                                  0,
                                  -0.70357382152464787,
                                  0,
                                  0,
                                  -0.22820791694169471,
                                  0,
                                  0,
                                  0,
                                  0.15339781433915059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.96801246652041506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14536940194195347,
                                  0,
                                  0,
                                  0.54094772370727173,
                                  0,
                                  0,
                                  0.54917868994126195,
                                  0,
                                  0,
                                  0.21830086353894451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.69620804834159244,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57454584337748915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40108814502250939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58260324091109639,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56193595532459284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44431293709143632,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.071693831487555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60685919980024416,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33527381663553146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10571623113028533,
                                  0,
                                  0,
                                  0,
                                  -0.16362305335567767,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.66565028709341056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43832897607580268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10138056269735204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047312710548211186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46593679535369925,
                                  0,
                                  0,
                                  -0.025925923263109857,
                                  0,
                                  0,
                                  -0.26700262153096904,
                                  0,
                                  0,
                                  0,
                                  0.15891135004396148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069636281049882912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17642576303748905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0032795442477549426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23144800976982585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23982828165720838,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25084330814508043,
                                  0,
                                  0.88771858549372695,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044289331745854532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.016158229416176478,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.83228635911462068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017919734544539861,
                                  0,
                                  0,
                                  0,
                                  0.40844849266924865,
                                  -0.23742705327870756,
                                  0,
                                  -0.52764483448885202,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67289080325883743,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25854872802380802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31339625430061357,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.89215075259733712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.055276599319602368,
                                  0,
                                  0,
                                  0,
                                  0.83907979982504233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087780528963140314,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19871143514844236,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1195748624370372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25849846239482188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24270879168999762,
                                  0,
                                  0,
                                  -0.27501261009666317,
                                  0,
                                  0,
                                  -0.1683884094114437,
                                  0,
                                  0,
                                  0,
                                  0.041038748545580025,
                                  0,
                                  0,
                                  0.51555299581095559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082978749375146973,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14985849664653109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29454795009496954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14013564786164956,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2345776611930312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59900226034802972,
                                  0,
                                  -0.0046333023750838925,
                                  0.0077008841793653141,
                                  0,
                                  -0.37215426545053421,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.7329021389636835,
                                  0,
                                  0,
                                  0,
                                  -0.66486066436529767,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62691905265027725,
                                  0,
                                  -0.0079206605135549741,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0047144147029599751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11989905899366807,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42214757880309167,
                                  0,
                                  0.10063443400949137,
                                  0,
                                  0,
                                  0,
                                  -0.43131167933662562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.91928406851109679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17878663518806565,
                                  0,
                                  -0.39795004201337542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18808871394618984,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12301200258769729,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54554880633581326,
                                  0,
                                  0,
                                  -0.03436484341671367,
                                  0,
                                  0.32405198043350741,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46253265122235687,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46872265257183449,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26518222461828433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.080288119112317077,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2257115599508332,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59574156586659166,
                                  0,
                                  -0.38232461567149778,
                                  0.70888609330349384,
                                  0,
                                  -0.23630074923734895,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12839031424235034,
                                  0,
                                  0,
                                  0,
                                  0.23705245104252706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38227670385510898,
                                  0,
                                  -0.038642653938446569,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24767332162520297,
                                  0,
                                  0,
                                  0,
                                  0.00020223216430641927,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17530344687991697,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024472207256670195,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.77474052117974701,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2991781530200176,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17500168479438463,
                                  0,
                                  0,
                                  -0.035693832827207311,
                                  0,
                                  0,
                                  -0.2346938972701586,
                                  0,
                                  0,
                                  0,
                                  0.36140889618316885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16657335629987649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62698874763357637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53533319413029001,
                                  0,
                                  0.34842767590612322,
                                  0,
                                  0,
                                  0,
                                  -0.10873061539139012,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.095738285165183928,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19880095054753227,
                                  0,
                                  -0.5194681505477452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.64028085415593705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24162533846487608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38615683925167155,
                                  0,
                                  0,
                                  -0.29095801271287686};

const double rot_13_30[900] = {-0.58655584290907536,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23352865802860634,
                               0,
                               0.095399248709724396,
                               -0.30701140365960439,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24680490645900496,
                               0,
                               0,
                               0,
                               0.64047884437325275,
                               0.16411513780034895,
                               0,
                               0,
                               0,
                               0.76169753661594219,
                               0,
                               0,
                               0.26203844834561624,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.59217717668499892,
                               0,
                               -0.021883914531236413,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.010285539493417831,
                               0,
                               0,
                               0,
                               0,
                               0.50127026970165955,
                               0,
                               0,
                               1.0028058785946437,
                               0,
                               0.64044041537916996,
                               0,
                               0,
                               0,
                               0,
                               -0.068529824343555479,
                               0,
                               0,
                               -0.02642844503207431,
                               -0.57297474654792413,
                               0,
                               0.2927989678039386,
                               0,
                               0.21348769026895792,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.67857488353052553,
                               0,
                               1.5576122961352383,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58359983588135078,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28016963794037741,
                               0,
                               0,
                               -0.50816513285146458,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10566730010362096,
                               0,
                               0.80753179096505079,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.97339665663786257,
                               0,
                               0.0039057726125075187,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37418747810740316,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20097104282217007,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20563058567939724,
                               0,
                               -0.28159963396667431,
                               -0.25099622445353431,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.099890379278349942,
                               0,
                               0,
                               0,
                               0.4162653316142288,
                               -0.76926869783174301,
                               0,
                               0,
                               0,
                               0,
                               0.74318111579154267,
                               0,
                               0,
                               0,
                               0,
                               0.77013623498316852,
                               0,
                               0,
                               0.46784380413151344,
                               0,
                               0.17884423523596116,
                               0,
                               0,
                               0,
                               0,
                               0.24703056647234561,
                               0,
                               0,
                               0.53611095823318766,
                               0.47990973888101501,
                               0,
                               -0.011593274345249604,
                               0,
                               0.3321146695994483,
                               0,
                               0,
                               0,
                               0,
                               -0.30699798118325605,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.064372302420022676,
                               0,
                               -0.57369769657301328,
                               0.73560497956457915,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.087862992483430338,
                               0,
                               0,
                               0,
                               0.1521776689726059,
                               -0.022062747677581235,
                               0,
                               0,
                               -0.17593438088719762,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20406671588162742,
                               0,
                               0.67440095137432388,
                               0.38474141395997458,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37086010218085497,
                               0,
                               0,
                               0,
                               -0.035206851515036601,
                               -0.43102729899324677,
                               0,
                               0,
                               0,
                               0,
                               0.7189545466580054,
                               0,
                               0,
                               0,
                               0,
                               0.3680268145573356,
                               0,
                               0,
                               -0.10706338750280178,
                               0,
                               -0.222282138885249,
                               0,
                               0,
                               0,
                               0,
                               -0.60069219764305259,
                               0,
                               0,
                               0.58178939998720969,
                               -0.69319924402877831,
                               0,
                               -0.65304019629554033,
                               0,
                               -0.38270634840461315,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.69440836987680599,
                               0,
                               -0.19005103648785104,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.4133270773933873,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.55762129218395284,
                               0,
                               0,
                               0,
                               0,
                               -0.13529337964669885,
                               0,
                               0,
                               -0.26714250010488949,
                               0,
                               0.12656783061771101,
                               0,
                               0,
                               0,
                               0,
                               0.12257070311591686,
                               0,
                               0,
                               -1.2094724280173974,
                               -0.058152063856655375,
                               0,
                               -0.40673984856922046,
                               0,
                               0.15175468615131119,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56649198914100951,
                               0,
                               0,
                               -0.29415235348929147,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61557757731459462,
                               0,
                               -0.46219634949149907,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29528489342703357,
                               0,
                               0.25934665515766814,
                               0,
                               -0.098309954153819434,
                               -1.559144563604778,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36429157862624056,
                               0,
                               0.14285889166805701,
                               0,
                               0,
                               0.76588409193518714,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.50914129611502668,
                               0,
                               0.36577046816589609,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.45868600372838619,
                               0,
                               -0.56430780517406509,
                               0,
                               -0.41908802953796986,
                               -0.49814552819084412,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.59900470109217407,
                               0,
                               0,
                               0.021750324186519388,
                               0,
                               0,
                               0,
                               0,
                               0.11300595943261246,
                               0,
                               0,
                               0.19002247441109915,
                               0,
                               -1.1055427630145851,
                               0,
                               0,
                               0,
                               0,
                               -0.041031757933459458,
                               0,
                               0,
                               -0.45253829376265842,
                               0.12264915776568243,
                               0,
                               0.40711348637139455,
                               0,
                               -0.29657921212145277,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.2138550505003622,
                               0,
                               -0.54048074171537586,
                               0,
                               1.1552829274268992,
                               -0.66102609019066327,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1134864637142378,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2937310270117397,
                               0,
                               0.27426599007774838,
                               0,
                               -0.78349620165435863,
                               -0.35825378569169136,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.96985365257216627,
                               0,
                               0,
                               -0.074067233463479654,
                               0,
                               0,
                               0,
                               0,
                               0.20682270274890358,
                               0,
                               0,
                               -0.64664672141173996,
                               0,
                               -0.47134800814042055,
                               0,
                               0,
                               0,
                               0,
                               0.89590783678270758,
                               0,
                               0,
                               0.041398534396125147,
                               -0.92015753683478563,
                               0,
                               -0.26363383955924841,
                               0,
                               0.5699366759065676,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.56470865690667593,
                               0,
                               0,
                               0,
                               0,
                               0.93618446329581839,
                               0,
                               0,
                               -0.7147117411621372,
                               0,
                               0.52861274239181932,
                               0,
                               0,
                               0,
                               0,
                               -0.080227751780040935,
                               0,
                               0,
                               -0.13328239618038296,
                               -0.40364253767395808,
                               0,
                               0.38248275057949266,
                               0,
                               -0.13851979295215724,
                               0,
                               0,
                               0,
                               0,
                               -0.25945406176032171,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.77735534310666776,
                               0,
                               0.001511317508157875,
                               0.040188538259019004,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25311128812377692,
                               0,
                               0,
                               0,
                               -0.29752583691270917,
                               -0.41737023119203981,
                               0,
                               0,
                               0,
                               0,
                               0.46996666381853425,
                               0,
                               0,
                               0,
                               0,
                               -0.057179923951730077,
                               0,
                               0,
                               0.56839784080751365,
                               0,
                               -0.031627719023573184,
                               0,
                               0,
                               0,
                               0,
                               1.1424050757656299,
                               0,
                               0,
                               0.073181504049039156,
                               -0.02257849919316518,
                               0,
                               -0.3526015698582991,
                               0,
                               -1.045143958083864,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.77845458312563987,
                               0,
                               0,
                               0,
                               0.62770093357480861,
                               0,
                               0,
                               0,
                               -0.74354033269847153,
                               0,
                               0,
                               0,
                               0,
                               0.59860952816016699,
                               0,
                               0,
                               0.24595574560151884,
                               0,
                               -0.38709564510183625,
                               0,
                               0,
                               0,
                               0,
                               0.14032974999219597,
                               0,
                               0,
                               0.10090777308444196,
                               0.043791005052290388,
                               0,
                               -0.67410518621745896,
                               0,
                               -0.028040813114760789,
                               0,
                               0,
                               0,
                               0,
                               0.61163035346982397,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44616693203694885,
                               0,
                               0.198221482734808,
                               0.3483289948198417,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0060179439626688869,
                               0,
                               0,
                               0,
                               0.5006908997989904,
                               0.12446261217838436,
                               0,
                               0,
                               -0.22125577239449731,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23248042834438953,
                               0,
                               0.29725561210763485,
                               0.17508867615384766,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.848381158213946,
                               0,
                               0,
                               0,
                               0.22999882066378174,
                               0.073018785616888959,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.6277009335748085,
                               0,
                               0,
                               0,
                               0.77845458312563987,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.71976185511969815,
                               0,
                               1.1690156035917123,
                               0,
                               0.19705847916709332,
                               0.40868838680786107,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61528637383678053};

const double rot_13_2[4] = {-0.71864875009322182, -0.6953732623486828, 0.6953732623486828, -0.71864875009322182};

const double rot_14_50[2500] = {-0.61534800789716781,
                                0,
                                -1.2705419961335753,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39141378407391197,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.026026076438673267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41524200704042291,
                                0,
                                -1.214194694527184,
                                0,
                                0,
                                0,
                                0,
                                -0.32931910916171281,
                                -0.29001041917913462,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.75845810336737152,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51968664656137531,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32453408439369852,
                                0,
                                0,
                                0,
                                0,
                                -0.446879777699557,
                                0,
                                0,
                                -0.72545511043465227,
                                0,
                                0.61228587247522193,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.058633210443667982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83345869185121124,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24737195436677445,
                                0,
                                0.80452531671924699,
                                0,
                                0,
                                0,
                                0,
                                -0.19532476264705562,
                                -0.50249240426302211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21485333463479331,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34169683278919799,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14380132123992892,
                                0,
                                0,
                                0,
                                0,
                                -0.85778767177415882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.024603528594214424,
                                0,
                                -0.33674779909126118,
                                0,
                                0,
                                0,
                                0.25918860322063408,
                                0,
                                0.026620785686419936,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.89135356420648559,
                                0,
                                0,
                                0,
                                0,
                                0.15361318789177503,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40578234590782858,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.89339147634003502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19285320259854077,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70945103672337628,
                                0,
                                -0.55178387526816097,
                                0,
                                0,
                                0,
                                -0.14398262612986201,
                                0,
                                -0.18618016777743471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12033706827776144,
                                0,
                                0,
                                0,
                                0,
                                -0.34976952409208928,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.07767194141835429,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0758804959907511,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0691153943107987,
                                0,
                                0,
                                0,
                                0.82902687213471404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18708651475176569,
                                0,
                                0,
                                0.53717461012012813,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47369671485267972,
                                0,
                                -0.16967224597926725,
                                0,
                                0,
                                0,
                                0,
                                -0.44102733146142931,
                                -0.34126945985546187,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47570028804193965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.00082494891103575274,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.348698009627944,
                                0,
                                0,
                                0,
                                0,
                                -0.54772947891045054,
                                0,
                                0,
                                0,
                                -0.12921643907350502,
                                0,
                                0.50080086245847577,
                                0,
                                0,
                                0,
                                0,
                                0.45684740535318569,
                                0.63001489113833864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59948697042025023,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.049631108874486657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57132328395962384,
                                0,
                                0,
                                0,
                                0,
                                -0.061514263674671527,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4067490730855603,
                                0,
                                0.23670012221369927,
                                0,
                                0,
                                0,
                                0.16633702899744876,
                                0,
                                0.86242206140079913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.018237236536224014,
                                0,
                                0,
                                0,
                                0,
                                -0.082193842135999673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18706378663517506,
                                0,
                                0,
                                -0.05216701294148833,
                                0,
                                0,
                                0,
                                0.11370708210585435,
                                -0.54113700943624632,
                                0.32367976390167863,
                                0,
                                0.12238429757586923,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64228981168483334,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35248329171907811,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49136598685553295,
                                0,
                                0.31193823791377329,
                                0,
                                0,
                                0,
                                -0.33402838295470799,
                                0,
                                -0.18680825839179283,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084199177860806412,
                                0,
                                0,
                                0,
                                0,
                                0.71252523822920977,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54567565763754999,
                                0,
                                0,
                                0,
                                -0.83238831234253607,
                                0,
                                0,
                                0,
                                -0.095965216251742286,
                                0,
                                0,
                                0.50040737886532172,
                                0,
                                -0.60083294095985795,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.024191325310251647,
                                0.52450662500348677,
                                0,
                                0.5141583871286155,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49454890840936827,
                                0,
                                0,
                                0,
                                -0.23934620608974533,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29818627560297295,
                                0,
                                0,
                                0.11566657077575895,
                                0,
                                0,
                                0,
                                -0.75573054895465419,
                                -0.30397744859250286,
                                0.084687181791926719,
                                0,
                                0.19154566756851638,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28602276472131705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32940029463851372,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0600012163886594,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.95966064903752168,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38196382511646682,
                                0,
                                0,
                                0,
                                0.47066460841026203,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46428421258590696,
                                0,
                                0,
                                -0.35110600207155296,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54376337585638634,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17225900168055042,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58582360062534478,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49145753630616223,
                                0,
                                0.29988068689984115,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31838973995849462,
                                0,
                                0,
                                0,
                                -0.76124089349104707,
                                0,
                                0,
                                0,
                                0.95355461567024191,
                                0,
                                0,
                                -0.19598815372863368,
                                0,
                                -0.087076200013657207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80444876245378505,
                                -0.15919583800922676,
                                0,
                                0.4421962428104167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.037289359192857724,
                                0,
                                0,
                                0,
                                0.40570716990712863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.024129689809799605,
                                0,
                                0,
                                0.44637876180038349,
                                0,
                                0,
                                0,
                                -0.36221579736335291,
                                0.3799728128837942,
                                0.50182599267754358,
                                0,
                                -0.23329801140219736,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36508198552298426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29161960065883785,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32351844696796173,
                                0,
                                0,
                                0.15405794743894005,
                                0,
                                0,
                                0,
                                0.36969673589191659,
                                0.38053897059873915,
                                0.32960452046576472,
                                0,
                                -0.07216869190193051,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15900054573305183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67155621140984356,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5217545882391279,
                                0,
                                0,
                                -0.62871514717303267,
                                0,
                                0,
                                0,
                                -0.27928080691288726,
                                0.25414306435840178,
                                0.27221455960773455,
                                0,
                                -0.21850180200454261,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15154604931589211,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21235097854801116,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29220574856164988,
                                0,
                                0,
                                0,
                                -0.49637106118690077,
                                0,
                                0,
                                0,
                                0.37377213762493,
                                0,
                                0,
                                0.55430001700529563,
                                0,
                                -0.1622665206875086,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60744156549011452,
                                0.10882320208324013,
                                0,
                                -0.35068328779890662,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.89049372419601314,
                                0,
                                0,
                                0,
                                -0.016302301036266842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15048588914943967,
                                0,
                                0,
                                0.22189509051055636,
                                0,
                                0,
                                0,
                                0.20898386624826212,
                                -0.50057220377482814,
                                0.36175718373177179,
                                0,
                                -0.49058121219881512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48797175428660905,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15561220936868286,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26919252540765809,
                                0,
                                0.46811268154631697,
                                0,
                                0,
                                0,
                                0,
                                -0.55180389390925699,
                                -0.15277108715918603,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19233588928459688,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0906773350796146,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30203925313203117,
                                0,
                                0,
                                0,
                                0,
                                0.30063918542151236,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18586139035266672,
                                0,
                                0,
                                0,
                                0.39458639706644039,
                                0,
                                0,
                                0,
                                0.4686518231718817,
                                0,
                                0,
                                0.8754873885095944,
                                0,
                                0.32412887417014002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19179029968846839,
                                -0.48492515976061701,
                                0,
                                0.14885279207358101,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35632583357569853,
                                0,
                                0,
                                0,
                                -0.68469793292142422,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.058688407780193658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65555266961851699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28280533273966718,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.078936159665336583,
                                0,
                                0.69325074440605949,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0474744207959867,
                                0,
                                0,
                                0,
                                -0.091195645447809379,
                                0,
                                0,
                                0,
                                0.21322885995181953,
                                0,
                                0,
                                -0.42596260090187638,
                                0,
                                0.061520705732292451,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54110717378459205,
                                -0.57435344649886344,
                                0,
                                0.21536481319485057,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084584457790958051,
                                0,
                                0,
                                0,
                                -0.081583866666047278,
                                0.73903946683832444,
                                0,
                                0.29692422847041561,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77038987744448972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41975630167673683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.060732031397051717,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53421303422117505,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1141412166251086,
                                0,
                                0,
                                0,
                                0.40382934393391112,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0115585688148989,
                                0,
                                0,
                                -0.88487549403553467,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51485424648527978,
                                0,
                                0,
                                0.32395972852867322,
                                0,
                                0,
                                0,
                                0.10373801199985308,
                                0.092878722239465861,
                                0.20568936421165598,
                                0,
                                0.6975866663885476,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28424037877797548,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.029313860006090653,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65430966193211382,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43128372171686846,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62118694262221674,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2082111255262275,
                                0,
                                0.31798022744399229,
                                0,
                                0,
                                0,
                                0,
                                0.18500416154170257,
                                -0.9795451072192245,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.77823837633537707,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15132017947566165,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14080884882779293,
                                0,
                                0,
                                0,
                                0,
                                0.6238206510333677,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13688961453750637,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71218234459996388,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.72557852054786443,
                                0,
                                0,
                                0,
                                1.2430971906118273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17030096104332879,
                                0,
                                0,
                                0.10505705809643737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63173551730724042,
                                0,
                                0,
                                0,
                                0.15586118382147973,
                                0,
                                0,
                                0,
                                -0.14844406231212082,
                                0,
                                0,
                                -0.33228973507854537,
                                0,
                                -0.18236756684285882,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41805238491649688,
                                0.07574081145774117,
                                0,
                                0.55738631942529859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76953768593988792,
                                0,
                                0,
                                0,
                                -0.80123532143756637,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.012519364732907129,
                                0,
                                0,
                                0,
                                0.63012738032938653,
                                0,
                                0,
                                0,
                                -0.0057291158029591227,
                                0,
                                0,
                                0.29931321927953203,
                                0,
                                0.528882071312472,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58329178330393816,
                                0.23578537397960725,
                                0,
                                0.74390712248611002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17345974058287772,
                                0,
                                0,
                                0,
                                0.64121818357858018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1903605946085013,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67858903804627135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48607809824016696,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29208761468082906,
                                0,
                                -0.42625423074149149,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2603720819272996,
                                0,
                                0,
                                0,
                                -0.34352149878990335,
                                0,
                                0,
                                0,
                                -0.69840934497789375,
                                0,
                                0,
                                -0.47566218051791759,
                                0,
                                0.75511759332022022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40011117794997386,
                                -0.38622669503207174,
                                0,
                                0.45435413726627849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12076436767848037,
                                0,
                                0,
                                0,
                                -0.67371825319751255,
                                0.87045104423802278,
                                0,
                                -0.034643156309157014,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.82978841500974376,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3069819553516224,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.98772990116670156,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52479538447578111,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80903650971874652,
                                0,
                                0,
                                0,
                                0.74376608202219097,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40427335207749759,
                                0,
                                0,
                                -0.46047308438421863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29477418421185997,
                                0,
                                -0.56370329902788729,
                                0,
                                0,
                                0,
                                -0.53930243753760065,
                                0,
                                0.43110988734221106,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11673182855150203,
                                0,
                                0,
                                0,
                                0,
                                0.32406418668547632,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63813756671412492,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12588098102977796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7595619952072028,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66201460347691188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40822924169120983,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15661413832959661,
                                0,
                                0,
                                0,
                                -0.32040333429805468,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74975030197743742,
                                0,
                                0,
                                -1.1054325694411666,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1396950257125056,
                                0,
                                -0.12507148465940984,
                                0,
                                0,
                                0,
                                0,
                                -0.44553797830935926,
                                -0.33623909636645305,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37712476417817098,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00062682240321679239,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35773268473915631,
                                0,
                                0,
                                0,
                                0,
                                -0.046071312813436627,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45923513477003719,
                                0,
                                0,
                                -0.45982814596795624,
                                0,
                                0,
                                0,
                                0.12502989990916538,
                                -0.042326300241275705,
                                0.52944677149705532,
                                0,
                                0.33712896399265224,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.072204675732046933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40131513576742056,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.047924228742891428,
                                0,
                                -0.33322913038566859,
                                0,
                                0,
                                0,
                                0.69426233108548618,
                                0,
                                -0.010168900501625652,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41226131934589377,
                                0,
                                0,
                                0,
                                0,
                                0.48435382586630316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64625334989967531,
                                0,
                                0,
                                0,
                                0.42764232815287329,
                                0,
                                0,
                                0,
                                0.30743364002174878,
                                0,
                                0,
                                -0.13451066858471264,
                                0,
                                -0.81445423096395508,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6968507456581986,
                                0.17303859876320571,
                                0,
                                0.52607760640863033,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.039181312043576236,
                                0,
                                0,
                                0,
                                -0.3226710940513825,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10317774729782206,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25442580475625864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38484242938663499,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73258432714129218,
                                0,
                                -0.48973295836344322,
                                0,
                                0,
                                -0.46277330965958258,
                                0,
                                -0.53040073417523559,
                                0,
                                0,
                                0,
                                0,
                                1.0530155755577348,
                                -0.28712518206993809,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29129263202323463,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37459644796196745,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26437556776804583,
                                0,
                                0,
                                0,
                                0,
                                -0.86722865320823006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80869911484577295,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12394337825644859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43869834702147997,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36089278419243731,
                                0,
                                -0.089128779148452075,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17123460531419524,
                                0,
                                0,
                                0,
                                -0.084939976463563646,
                                0,
                                0,
                                0,
                                -0.66848360882929581,
                                0,
                                0,
                                0.47594767375596397,
                                0,
                                -0.34150239931684784,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15598443339461815,
                                -0.67744127672707399,
                                0,
                                0.35672612487526284,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34616084437375255,
                                0,
                                0,
                                0,
                                0.30015234038190941};

const double rot_14_20[400] = {0.71473664605728326,
                               -0.66320647748736139,
                               0,
                               0,
                               -0.15753763163446555,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15649469518355519,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.019962799923474647,
                               -0.10335500070470152,
                               0,
                               0,
                               -0.38510380788140086,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.91685019910768029,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.83737046466589915,
                               0,
                               0,
                               0,
                               0,
                               0.54193700004309064,
                               0,
                               0,
                               0,
                               -0.071519178473408052,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.56324384001370276,
                               -0.72209429839352968,
                               0,
                               0,
                               0.39031740253629515,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.09480783823868176,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33095357346195342,
                               0,
                               0,
                               0,
                               0,
                               -0.39848641448294925,
                               0,
                               0,
                               0,
                               0.85538196712655024,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51551370011178577,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.4619480981826416,
                               1.0345603143473099,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.43506371615888551,
                               0,
                               0,
                               0,
                               0,
                               0.739941122966428,
                               0,
                               0,
                               0,
                               0.51303674081414674,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41413692190943313,
                               0.16749548135903003,
                               0,
                               0,
                               0.82129731343257661,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35483319543712633,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.84304775432612022,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.74164873619556038,
                               -0.077779809100694819,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.68301226716708963,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.91318990414031631,
                               0.8607927538588791,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1};

const double rot_14_10[100] = {-0.86683364458127121,
                               0,
                               0.1701549435302194,
                               0,
                               0,
                               0,
                               0,
                               -0.46614191933022275,
                               0,
                               -0.048563760741056589,
                               0,
                               -0.91888092026992374,
                               0,
                               0,
                               -1.1779019167476488,
                               0,
                               -1.0741455839688239,
                               0,
                               0,
                               0,
                               -0.3950368740782304,
                               0,
                               -0.66641784244045454,
                               0,
                               0,
                               0,
                               0,
                               0.52764871301221306,
                               0,
                               -0.34845367418361617,
                               0,
                               0,
                               0,
                               -0.54612597009231645,
                               0,
                               0.44090307294809017,
                               0,
                               0,
                               -0.71228569061553937,
                               0,
                               0,
                               -0.66990480889386284,
                               0,
                               0,
                               0.76182360325173082,
                               0,
                               0.80719167235547573,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.6440195001468727,
                               0,
                               -0.76473663885457677,
                               0,
                               0,
                               0.02041461789936657,
                               0,
                               0,
                               -0.12132434595463344,
                               0,
                               0,
                               -0.7497121047279256,
                               0,
                               1.0561584855081989,
                               0,
                               0,
                               0,
                               -0.29621995656848266,
                               0,
                               0.22976925694832193,
                               0,
                               0,
                               0,
                               0,
                               0.55755573202800224,
                               0,
                               0.74066958326550969,
                               0,
                               0,
                               0,
                               -0.53571009718064722,
                               0,
                               0.46987482743634568,
                               0,
                               0,
                               0.70159271541284329,
                               0,
                               0.069275089830448389,
                               0,
                               -0.6885787122984941,
                               0,
                               0,
                               0,
                               0,
                               -0.43980694899286066,
                               0,
                               0.57238987282788534};

const double rot_14_100[10000] = {-0.26853746630928349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24151215604726511,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24358842380937334,
                                  0,
                                  0,
                                  0.64447222744234633,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53135036485525167,
                                  0,
                                  0,
                                  0,
                                  -0.15704544917960878,
                                  0,
                                  0,
                                  -0.10929608752110585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27556780912128087,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56108995971610698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.276964917450092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10502680221522416,
                                  -0.23127839936049935,
                                  0,
                                  -0.48768629568702604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50824083425282651,
                                  -0.17517444965483431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23526219807355042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39979814003856828,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43465370343615317,
                                  0,
                                  0,
                                  -0.42858082687064419,
                                  0.14355184159531631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0083845741671367338,
                                  -0.61199166311185083,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12668527867742355,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23661419341661416,
                                  0,
                                  0.30929991702411963,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25650314977822941,
                                  0,
                                  0.04344107114285542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33351597521457088,
                                  0,
                                  0,
                                  0.087658365029624805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.026327786415061546,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38360824380575809,
                                  -0.53317821888003547,
                                  0,
                                  0,
                                  0,
                                  -0.42753728906982091,
                                  0,
                                  0,
                                  -0.17545556158585232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.70888039674828285,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10783085182239718,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.1281500915582854,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084413888922147573,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.69886990096892587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13096316339988384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.062128916249820101,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46654676149864788,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12916444272196162,
                                  -0.77562383158679471,
                                  0,
                                  -0.17134626045914975,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28717556455869525,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.010556838517409916,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10454227823040259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.090730036308430656,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23939289104703004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36391153417841593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24674245175982001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54682699570599502,
                                  -0.072923207643615595,
                                  0,
                                  0.30039409032227044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27842817466750641,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1829217049732024,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27109836770648654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26108853710772556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24491710118871382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46142042162643004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28264552592217901,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.018244297015724636,
                                  0,
                                  0,
                                  0,
                                  -0.48140789092685632,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40678716224955785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12165568648569089,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.74498444001349062,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18065400879081339,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.096816537678004855,
                                  0.20312017027537144,
                                  0,
                                  -0.52974238521561712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22437867656241958,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15031911559374045,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16756214686610793,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.69180817037176157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.011325425224291974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038529989498240713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29582374778555276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059805924136442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40830423585624143,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67940283899756049,
                                  -0.76851966366112889,
                                  0,
                                  -0.071118088674128235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32851182117903033,
                                  -0.017338427360495089,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.74409288009457319,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.79683524572830411,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046212958333838108,
                                  0,
                                  0,
                                  0.81172476304768104,
                                  0.35739845981019669,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19984366034193379,
                                  -0.15383289220420004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077466007167481962,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27523686853350715,
                                  0,
                                  0.37052410626932941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25284757062622654,
                                  0,
                                  -0.2053340659114285,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2453142383292809,
                                  0,
                                  0,
                                  -0.030139434165533233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30544280018579117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.67482466253005735,
                                  -0.15980432098761985,
                                  0,
                                  0,
                                  0,
                                  0.024330572388230144,
                                  0,
                                  0,
                                  -0.19738568815726615,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56720718023880634,
                                  0,
                                  0,
                                  0,
                                  -0.2082478806444405,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35685933156390132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26217346645056311,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40065009420299386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52754604336762345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13217033589179392,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25248529971273764,
                                  0,
                                  -0.096292769598915529,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48527972003293074,
                                  0,
                                  0.052798330691158094,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32444094976653359,
                                  0,
                                  0,
                                  0.62520792894320831,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2020953006253278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3125188156303968,
                                  -0.17195182128096259,
                                  0,
                                  0,
                                  0,
                                  0.068000180649627845,
                                  0,
                                  0,
                                  -0.048753969030412549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23663230341977265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.2807157172035744,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.79356622615646144,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0038152756524683,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.02818458266723213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33462664421865368,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.308271841977107,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10034896051659004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46767808761803853,
                                  -0.26650428399234483,
                                  0,
                                  0.87376326850468866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40525564236250683,
                                  0.49607931303902297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18716820801365594,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18310880264843718,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1827053962126379,
                                  0,
                                  0,
                                  -0.082654973515591063,
                                  -0.58205836488136131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17633893944899615,
                                  0.1902020008439787,
                                  0,
                                  0,
                                  0,
                                  0.25080593598250261,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45685449819366142,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.77883857744172014,
                                  -0.27503568219658486,
                                  0,
                                  -0.51121110708606698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29319908062609817,
                                  -0.0050401148855856587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11212693607229561,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098317020803373845,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40189340747449842,
                                  0,
                                  0,
                                  -0.56768726419163851,
                                  0.38006014938851285,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15799936602998432,
                                  0.59136562432193718,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015522933992294943,
                                  0,
                                  0,
                                  0.21951459226158679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38686543855839867,
                                  0,
                                  0,
                                  0,
                                  -0.62402629134443721,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.078288283644632473,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35111432089612887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16244202653855824,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.263571372448206,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088381325601536762,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1526218180139528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.041050790189285535,
                                  0,
                                  -0.011987514623525142,
                                  0,
                                  0.23432322759937921,
                                  0,
                                  -0.31526208063497829,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.74490439042342549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56559230313772368,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.02115897022894599,
                                  -0.18973526980548358,
                                  0,
                                  -0.24304488291804074,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44901041704121958,
                                  -0.64220415161261268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22674660716427639,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6096130550269252,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34472573816774671,
                                  0,
                                  0,
                                  -0.10441174585519863,
                                  -0.44710200657813071,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18759707772726228,
                                  0.27231810367105658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19099119256351174,
                                  0.24278652783251636,
                                  0,
                                  -0.0050581248279670532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3453997787911493,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4287635597414724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.64989216374077607,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14057467012573549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19936624894466559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15464479792352581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3092398861281781,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23782318554951262,
                                  0,
                                  0,
                                  0.15484153565056263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39632555816306148,
                                  0,
                                  0,
                                  0,
                                  0.15750290753290308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20081981936423729,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085025727203617202,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52477072993471829,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31699045491731759,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.035481895636232427,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19625956147569512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.011087191239880376,
                                  0,
                                  -0.52155148745441204,
                                  0,
                                  0.011826484737316236,
                                  0,
                                  0.045851386802036834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28144042605815889,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12492776628567034,
                                  0,
                                  0,
                                  0,
                                  -0.18657382651376536,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61459292666248955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.9126898712194017,
                                  0,
                                  0.36591483212616249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46772367687797106,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10290576149134284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67531626778511,
                                  0,
                                  0,
                                  0,
                                  -0.35320234223980551,
                                  0,
                                  0,
                                  0,
                                  0.21153166553502012,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20957795776135685,
                                  0,
                                  0.26587022888147471,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.039947103917698359,
                                  0,
                                  -0.57262852720742097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12811750831302837,
                                  0,
                                  0,
                                  0.28943707904981097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022198124140064723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39504201776714615,
                                  -0.046302386129885478,
                                  0,
                                  0,
                                  0,
                                  0.41847191760720959,
                                  0,
                                  0,
                                  -0.27774759447860059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.1863100780749796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52419274963515561,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.95568486444184386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29319676206905748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082419057581395005,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15721321403228708,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33405161029113178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060352377499672961,
                                  0,
                                  -0.088390722667811991,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40216609090779176,
                                  0,
                                  0.050022687098997654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.73606664637620578,
                                  0,
                                  0,
                                  0.14046548184407609,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069552865863270502,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13603436094902283,
                                  -0.25188110732904212,
                                  0,
                                  0,
                                  0,
                                  -0.24384360771103453,
                                  0,
                                  0,
                                  -0.070306138999372422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1121866886158549,
                                  0,
                                  0,
                                  0,
                                  0.41160792370842431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16507074206621986,
                                  0,
                                  0,
                                  0,
                                  -0.20156005563461565,
                                  0,
                                  0,
                                  -0.56379788229577354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22767607846988194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10706877137669918,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36990139378682391,
                                  0.15383884066357312,
                                  0,
                                  0,
                                  0.43565361519611701,
                                  0,
                                  0,
                                  0,
                                  -0.1693692621279792,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.048774573238651822,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.096513093145156076,
                                  0,
                                  0,
                                  -0.11596837082205919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31071081412842644,
                                  0,
                                  0,
                                  0,
                                  0.3445929266513762,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1001828699761238,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39970545596937701,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.048742530731280542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45698121428136207,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2395072036803596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29333598902902736,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31436808143059608,
                                  0,
                                  -0.12020522101946864,
                                  0,
                                  -0.09004029311810334,
                                  0,
                                  -0.34080610027919689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025676967920354787,
                                  0.15554701076783234,
                                  0,
                                  -0.287117141785386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62482953765263138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18140378405816796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17017879033802413,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064263837974939841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049137969735084691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65197607441014338,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.093873747307978858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.058096036207454682,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47505151373879989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2458799805392109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10895690107315611,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59497351409430987,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23510890798153372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44500944234081685,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.3721955218578237,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33494650999770192,
                                  0,
                                  0,
                                  0,
                                  0.85870077549637014,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60982771466392016,
                                  0,
                                  0,
                                  0,
                                  0.050484085080322982,
                                  0,
                                  0,
                                  0.5553303124389567,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25789384612623123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13145539442588586,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021850247197342923,
                                  0.52372595997084082,
                                  0,
                                  0,
                                  0.62229964772944457,
                                  0,
                                  0,
                                  0,
                                  -0.7373062118531426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29773755357708603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035984600524984298,
                                  0,
                                  0,
                                  -0.50685699502843162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1398203610689025,
                                  0,
                                  0,
                                  0,
                                  -0.16719851079501913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34386784072676951,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23177639053209251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.040839053523264182,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38925933088678905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1452787803823623,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15277786211643768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44028613546205631,
                                  0,
                                  0.075325849223411706,
                                  0,
                                  0.097885923077011924,
                                  0,
                                  0.33997861683461528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30483974992084523,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4909445720409894,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26006843262443469,
                                  0.33304105835469056,
                                  0,
                                  0.073659876211492448,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60871484626959038,
                                  -0.12774450634258125,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38566373791238717,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55736124647742658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.87127359222807343,
                                  0,
                                  0,
                                  0.22084261087366533,
                                  0.64364055244124607,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48396500264920489,
                                  0.028127291480510089,
                                  0,
                                  0,
                                  0,
                                  0.39646694979474306,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.036556087456752276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26944613733312228,
                                  0.56638817804572261,
                                  0,
                                  0.42320050785346286,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52800244028583387,
                                  -0.38264489907530252,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28074211724843912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11585209216220489,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.79412484710042563,
                                  0,
                                  0,
                                  -0.060478331383309492,
                                  -0.17986892305395358,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084063695708146785,
                                  0.2833670624895866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34103266722149722,
                                  0,
                                  0,
                                  0,
                                  -0.3340677561868477,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49088831104118646,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62248284114474528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2343914842172255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29782522534872535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35712422147771883,
                                  0.2829206699223335,
                                  0,
                                  -0.088965275440370417,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47382077814273255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56363277576395976,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081906974331449375,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38267774858726333,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26547410179516628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13657145748988181,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0060046300860879531,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19134315864358345,
                                  0,
                                  0,
                                  0.27041951915233953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4169494514359805,
                                  0,
                                  0,
                                  0,
                                  -0.23999156882179859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21391500712424213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11645716862314941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48857507611472989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2598068612866275,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35553639178904461,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.058013021755803695,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0071864492785191081,
                                  0,
                                  0.17988402861017419,
                                  0,
                                  0.35626770510920924,
                                  0,
                                  -0.064675694731007857,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55515851903750801,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46791740016075767,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23411527029277687,
                                  0,
                                  0,
                                  -0.4257031688881186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.026829852188711423,
                                  0,
                                  0,
                                  0,
                                  -0.44907459883481687,
                                  0,
                                  0,
                                  -0.146245509880713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.114208546675995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20910886850892546,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.92306097175014679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29453298999364469,
                                  0.54363670373939765,
                                  0,
                                  -0.12559288050856227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047267042748324994,
                                  0.48015995857106336,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52520843172943033,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064223899609862314,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15982565420914513,
                                  0,
                                  0,
                                  0.42128399198090671,
                                  0.25419688458243533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14592122291353485,
                                  -0.71463961753217398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37676814444381246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26736214687640258,
                                  0,
                                  0,
                                  0,
                                  0.26810805266810822,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45520262592320948,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50740264375025834,
                                  0,
                                  0.22920463561821969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49797505942743903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34931941341291406,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57725049943096651,
                                  0,
                                  0,
                                  0,
                                  -0.32435257573897391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.57043292669780032,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.018259127881217474,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53954079263884669,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14898997535258834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.2834597690421199,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66634733561545711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10741151642904248,
                                  0,
                                  0,
                                  -0.28890662991092297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.013886979803700725,
                                  0,
                                  0,
                                  0,
                                  0.14029640021497711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.211275576501952,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29443762920189265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25059702128308581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.038795868955253575,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.099659864277707136,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20222188101505245,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27366802893892267,
                                  0,
                                  -0.053516982645685579,
                                  0,
                                  0.67690939910051329,
                                  0,
                                  -0.3204599104034952,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31989587452484874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.57312301895409457,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.042328329382632826,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1821866676787269,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11635516881165642,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13824057182929653,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40350495168695111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3442810764044022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31407016439676233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063199885425495983,
                                  0,
                                  0,
                                  0,
                                  1.1177164648975042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051874400400717349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14457703051856327,
                                  0,
                                  -0.40566994850284294,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5787026610895124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.417370639997108,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34139196317614168,
                                  0,
                                  0,
                                  0,
                                  0.314211425599359,
                                  0,
                                  -0.029341727638036656,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59494738051781426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14698291585679812,
                                  0,
                                  0,
                                  -0.43961278183819374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54770269320024623,
                                  0,
                                  0,
                                  0,
                                  -0.1456850658272347,
                                  0,
                                  0,
                                  -0.30289072196339412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13178821620133196,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30802640811532578,
                                  0,
                                  0,
                                  0,
                                  -0.52707556604070027,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051816353784788605,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58962289549622271,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29542868582788473,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43553745850793929,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36488692608725271,
                                  0,
                                  0,
                                  0,
                                  -0.21732258332265869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27419826083202514,
                                  0,
                                  0,
                                  0,
                                  0.94323075183835647,
                                  0,
                                  0,
                                  -0.36327483780063485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27207930499874794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43980226283397245,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66559277608460632,
                                  0.37321214083272464,
                                  0,
                                  0,
                                  -0.068235416013284783,
                                  0,
                                  0,
                                  0,
                                  -0.56202871343144345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66177804191561496,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14280843883728023,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20933086436839674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0090112032354398991,
                                  0,
                                  0,
                                  0.094984636160543603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11268181981408026,
                                  0,
                                  0,
                                  0,
                                  -0.64179578214588262,
                                  0,
                                  0,
                                  0.67808320101704744,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20563854242566976,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46809102256625795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.72173663040266434,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16576050131973502,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2828901770404747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092413668812412211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.84624072816030971,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12259407448875728,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61661484649691978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60412148085496631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60510437626020785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63208556872101607,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0036109271225295211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14440632330704506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.83139506658553397,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37167786164380057,
                                  0,
                                  0,
                                  0,
                                  -0.19844300146304528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35662915846785398,
                                  0,
                                  0,
                                  0,
                                  0.11987523461864866,
                                  0,
                                  0,
                                  -0.45224895011474447,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33855831358477934,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15960089058996618,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41808287986910608,
                                  0.15376520990717502,
                                  0,
                                  0,
                                  0.45806239583436503,
                                  0,
                                  0,
                                  0,
                                  -0.52119246834335697,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.84258099099554251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11669675034142324,
                                  0,
                                  0,
                                  -0.17942027602876046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044818980122614427,
                                  0,
                                  0,
                                  0,
                                  0.037006131829280364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39735008611995559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12028108115932301,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10774987583003981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37947552991353589,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14991540655290364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.64627472209189507,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11891595607217048,
                                  0,
                                  -0.4104234075301586,
                                  0,
                                  -5.7464257574739441e-05,
                                  0,
                                  0.01056732568508013,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085219691382540319,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23964878322927904,
                                  0,
                                  -0.5318613925476422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41726632251484103,
                                  0,
                                  -0.07013599845686519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073395937276346232,
                                  0,
                                  0,
                                  0.31954596693030579,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053570274002424326,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10982184197293435,
                                  0.1058040043648826,
                                  0,
                                  0,
                                  0,
                                  -0.32690671539572197,
                                  0,
                                  0,
                                  -0.48260708044793488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4147228984915603,
                                  0,
                                  0,
                                  0,
                                  0.69707335308289142,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098403457211205553,
                                  0,
                                  0,
                                  0,
                                  0.31475716197162207,
                                  0,
                                  0,
                                  -0.30175246107343096,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41800611911896401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48671542847662491,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43543633832187062,
                                  -0.060140476054659137,
                                  0,
                                  0,
                                  0.74613296651480254,
                                  0,
                                  0,
                                  0,
                                  0.81377824638206497,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20718358049330216,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021508062477419841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072323276086366295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.8854242846442949,
                                  0,
                                  0,
                                  0.12356812960092774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36615035925579925,
                                  0,
                                  0,
                                  0,
                                  0.22064964510928925,
                                  0,
                                  0,
                                  0.10387970716617823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03896351450692645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37352394013994339,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.028073604691775975,
                                  0,
                                  0.15553408997702267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31030450214290606,
                                  0,
                                  -0.30489170417092493,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12456622893582188,
                                  0,
                                  0,
                                  0.20440394457483255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65375429461456724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12454328652978004,
                                  0.073021435452879674,
                                  0,
                                  0,
                                  0,
                                  -0.056589206063568515,
                                  0,
                                  0,
                                  0.37083036043503675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.77474132657518058,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29233319684710019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.94901428841511637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1018818671257389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3230095758830549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12605312194467794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27260308436257213,
                                  -0.2801450563632501,
                                  0,
                                  -0.62842882195173855,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.03628097702556797,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.029984358417763535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057167942915139797,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22713457350567218,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2877082966954021,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29631196096712648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47395466039446355,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70484673499400474,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5458617031534525,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064304973571991247,
                                  0,
                                  0,
                                  0.2609656558562346,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35601520368030964,
                                  0,
                                  0,
                                  0,
                                  0.057435890561818595,
                                  0,
                                  0,
                                  0.048974975929842166,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.023315724150107724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.68806402862940852,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.80956225472190257,
                                  0,
                                  0,
                                  0,
                                  -0.2333310950638898,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1931300781389097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12478231981637558,
                                  0,
                                  0.56463277277833135,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37448043935766917,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38242236709830812,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2953418202795155,
                                  0,
                                  0,
                                  0,
                                  0.34940189604760225,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24450130079661653,
                                  0,
                                  0,
                                  0,
                                  0.21755631158262823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20594205123107379,
                                  0,
                                  0,
                                  0,
                                  0.33547572358322797,
                                  0,
                                  0,
                                  -0.89462697902887134,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.012522131224464675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6718450465068726,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43183998127798401,
                                  0.021046136491598311,
                                  0,
                                  0,
                                  -0.51613125851505215,
                                  0,
                                  0,
                                  0,
                                  0.16219910522850178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.89927991153574904,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23579646029205786,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12540974448859607,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15502918476199523,
                                  0,
                                  0,
                                  -0.33881296800417704,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098280190935049763,
                                  0,
                                  0,
                                  0,
                                  0.3311324168088785,
                                  0,
                                  0,
                                  0.60299067580738819,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55402050628356925,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.87867216006179072,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.74196514758527554,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44242015654971112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045483131249999642,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.69822638327582887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52899766411088711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50158317851635092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34193900456022547,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33858974622666843,
                                  0,
                                  0,
                                  0,
                                  0.39259888556505812,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58271568838122545,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15722077038618731,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11375982808357349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59498391254822924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22338755024056978,
                                  0,
                                  0,
                                  0.18574000868801208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0300294775806218,
                                  0,
                                  0,
                                  0,
                                  0.19446100812136483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47305842664122066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040092954812045861,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31995106784930194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0022934574849405205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41680891375367557,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.091782043467348168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39905426818879025,
                                  0,
                                  -0.27919964907494088,
                                  0,
                                  0.32046830120190278,
                                  0,
                                  0.16451696992627551,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.058890402178248216,
                                  0,
                                  0,
                                  0,
                                  0.88180149255453699,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31475652716256752,
                                  0,
                                  0,
                                  0,
                                  0.53104498917940235,
                                  0,
                                  0,
                                  0.2023521470586028,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38685370879549319,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24272725951313334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.439956315444337,
                                  0.78931111419164668,
                                  0,
                                  0,
                                  -0.70048808453026279,
                                  0,
                                  0,
                                  0,
                                  0.019424595234935248,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31535374609117361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25425792182765433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31154885748285671,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2991218000227322,
                                  -0.12011643623155602,
                                  0,
                                  0.69415435075466747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49552576406854965,
                                  -0.30646162737113897,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35898724499602019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15366394790778992,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59960181653692513,
                                  0,
                                  0,
                                  -0.48820476231117432,
                                  0.15928652669596327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068304871814578422,
                                  -0.82350191346844093,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1412273251391937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1631407788995751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43441383280891027,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57007466542833851,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19250581556179222,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58691722380007805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62065336640824631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34124584929865076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22669309454475278,
                                  0.27672638278970657,
                                  0,
                                  -0.2426500378933604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1666808726933246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035505709852126185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50184341858691506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25674195195251126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68119830189344166,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043284256291182169,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021039018363681931,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.069479042412223843,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34864446272901206,
                                  0,
                                  0,
                                  0,
                                  0.52193927671029572,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17502583800646482,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30508851125389447,
                                  0,
                                  0.91455288387668632,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022192337126998286,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25430856942945984,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.80466258760968923,
                                  0,
                                  0,
                                  0,
                                  0.066859282391431712,
                                  0,
                                  0,
                                  0,
                                  -0.77553481322811191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17212873116776906,
                                  0,
                                  0.020496700882013691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082866509552292245,
                                  0,
                                  0.026962359896418289,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27815345383421342,
                                  0,
                                  0,
                                  -0.057701754938308689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.09289621638151345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12719952055766101,
                                  0.051841657145167114,
                                  0,
                                  0,
                                  0,
                                  0.30001652890369856,
                                  0,
                                  0,
                                  -0.40335812238289243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47465417411559846,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1699495294067665,
                                  0,
                                  0,
                                  0,
                                  -0.025962836188710509,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.91058977424861398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3581656719307979,
                                  0,
                                  0.50427802942762601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33019446824751797,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53321425738061623,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20781182357045544,
                                  0,
                                  0,
                                  0,
                                  -0.17489011722522663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37337479143767283,
                                  0,
                                  0,
                                  -0.55987986681500324,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13362148456320758,
                                  0,
                                  0,
                                  0,
                                  -0.1971477336051537,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47837132864440696,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19553782130427588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24552080013557653,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2051903895990933,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0028249719436494077,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.012252203627276637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30273050873965429,
                                  0,
                                  -0.034581506987484051,
                                  0,
                                  0.03098250627411174,
                                  0,
                                  0.16427564864141139,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53188201884026653,
                                  -0.10462569211793259,
                                  0,
                                  0.18632651093464631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16046765275503735,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5169584634271297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40574717446514325,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19231425782610689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17945275169074132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26940219107281432,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26841221921263286,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051301402758271081,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.76607188382703306,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087809120677568936,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046351194188280834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.79385650845260747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.83132837683634886,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18176690338488061,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.038881528052557179,
                                  0,
                                  0.15533765636136321,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17148909056102657,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098770361219623598,
                                  0.17482240055545814,
                                  0,
                                  -0.27526810350811265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26883443350373715,
                                  0.49549246928397106,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0095260607181523391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.000769924326983,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60956110728903667,
                                  0,
                                  0,
                                  -0.54622372812219255,
                                  -0.060085869771840675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35743512205317007,
                                  -0.33582595798715914,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59339413196750346,
                                  0,
                                  0,
                                  0,
                                  -0.42583501473304142,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35208206455696206,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39573545504690477,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35960938722976749,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23803508654440267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44928142681446315,
                                  0,
                                  0,
                                  0.14207555691966717,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26376843421065033,
                                  0,
                                  0,
                                  0,
                                  0.4458997244816098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16782583196994691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.486806407672497,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12330793703957887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10211942529812423,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11924002148975277,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13333084148667351,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08168773035285129,
                                  0,
                                  0.42317753052631868,
                                  0,
                                  0.018584319058501556,
                                  0,
                                  -0.026237208605118408,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41060429567800488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33318821197172238,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29124189398654382,
                                  -0.48141916002238661,
                                  0,
                                  -0.14072095834864526,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46377446632653835,
                                  -0.31066366177931293,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.023506664414706606,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24824541859401691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24462002424320667,
                                  0,
                                  0,
                                  0.07366714017604814,
                                  0.15189413983674097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.1000029242308953,
                                  -0.10809366745355317,
                                  0,
                                  0,
                                  0,
                                  -0.23127243774757103,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11404960200845479,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.66366600682936361,
                                  -0.19576540262097036,
                                  0,
                                  0.27564665386393666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28030901428472332,
                                  0.5607295380274091,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0342930107721318,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1469646609557389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17243633641879524,
                                  0,
                                  0,
                                  -0.39486101860821982,
                                  -0.30426739851138296,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24174012911381601,
                                  0.33492688991807651,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19300611795015815,
                                  0,
                                  0,
                                  0,
                                  -0.68749910469324194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.037005649102049953,
                                  0,
                                  0,
                                  0,
                                  0.19966608820134596,
                                  0,
                                  0,
                                  -0.049617868753926112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.041093073597181631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5370354329777729,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25394509823042788,
                                  1.3687909786054011,
                                  0,
                                  0,
                                  0.17405476924076885,
                                  0,
                                  0,
                                  0,
                                  0.30432032539069903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047543768625646507,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11652769169506744,
                                  0,
                                  0,
                                  0,
                                  0.13490175334183302,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32992100645297601,
                                  0,
                                  0,
                                  0,
                                  -0.37018730941508449,
                                  0,
                                  0,
                                  0.32803091148782137,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53339846798844748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.013457442849048859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.96040533893276936,
                                  0.43029290919400703,
                                  0,
                                  0,
                                  0.23677823977283469,
                                  0,
                                  0,
                                  0,
                                  0.048196090248229267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42244414998053204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42947499214011431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48050283873205779,
                                  0,
                                  0,
                                  0,
                                  0.24413635120499186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7472402665381791,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50909877688408911,
                                  0,
                                  0.46960098825792745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12819362980869906,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16523019707628048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23481443248173595,
                                  0,
                                  0,
                                  0,
                                  1.0260974735659794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45147718278630472,
                                  0,
                                  0,
                                  -0.14314984958097346,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25966776022021953,
                                  0,
                                  0,
                                  0,
                                  0.28188058544938233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22176718596319164,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021033147146204974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42938866141755661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029277960726034589,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16090282946823062,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27511748862806074,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30857780019339975,
                                  0,
                                  0.26127934372580547,
                                  0,
                                  0.35408640432855454,
                                  0,
                                  -0.059109011240816564,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064778037657281282,
                                  0,
                                  0,
                                  0,
                                  -0.54010954416289447,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.78631378714728295,
                                  0,
                                  0,
                                  0,
                                  0.43986121594755861,
                                  0,
                                  0,
                                  0.40844332736685801,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.87850214022784112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56879813134523793,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61501454281673018,
                                  0.089827343777921287,
                                  0,
                                  0,
                                  0.047100460276979728,
                                  0,
                                  0,
                                  0,
                                  -0.57436262666122939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60336479155912237,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33120062147143003,
                                  0,
                                  0,
                                  0.19104867964961691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18271729168272013,
                                  0,
                                  0,
                                  0,
                                  0.056485393552640262,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11935992191288056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1979631527627998,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11925173996274142,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0088891546995601128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13805094928420122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.066095899075945708,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49921961125095082,
                                  0,
                                  -0.014205613096135904,
                                  0,
                                  0.26940293408427601,
                                  0,
                                  0.63566300312589419,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5225530929881449,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45814139675035259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53572965408931306,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.69639069816180954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.91891912452099989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45227025291404105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072855844649670515,
                                  0,
                                  0,
                                  -0.19898174049014442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46037324971496396,
                                  0,
                                  0,
                                  0,
                                  -0.012526196138336478,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18053540781512953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19625179300299922,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.065902122840804586,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13220849034837784,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.71647889146337795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073831605183535834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056288614590108949,
                                  0,
                                  0.20497706545482131,
                                  0,
                                  -0.20034875198750537,
                                  0,
                                  -0.21436218884783104,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42703234043996552,
                                  0,
                                  0,
                                  0,
                                  0.07705924072536445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.8080832575428053,
                                  0,
                                  0,
                                  0,
                                  0.12713504632904102,
                                  0,
                                  0,
                                  -0.3064720808651647,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39525099457802604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45072889367201735,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.014153884969543375,
                                  -0.20142982248468885,
                                  0,
                                  0,
                                  0.32169562249340411,
                                  0,
                                  0,
                                  0,
                                  -0.48162945116240868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65542316274217127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40102858657088325,
                                  0,
                                  0,
                                  0.062959376905100506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0059216376581030829,
                                  0,
                                  0,
                                  0,
                                  -0.046074519441655831,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.012927987750317761,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4316384505720347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.016655699267799084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43096878062778021,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.086033059628462027,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50498603117072427,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.106085121736226,
                                  0,
                                  0.36787976677351902,
                                  0,
                                  -0.005555683267948041,
                                  0,
                                  0.22700408566070993,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063932888905101556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39996796113195054,
                                  0,
                                  -0.57911110105272678,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21301467890912193,
                                  0,
                                  -0.17859240386433972,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.020052853402860324,
                                  0,
                                  0,
                                  -0.15371174290163428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027766838161974335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078652253670690522,
                                  -0.42874509910418013,
                                  0,
                                  0,
                                  0,
                                  0.43835395603229832,
                                  0,
                                  0,
                                  0.12780808406916203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.079035789886122004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080523351816131183,
                                  0,
                                  0.12614126636605091,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38084673350535203,
                                  0,
                                  0.53729150583655994,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16653654013946265,
                                  0,
                                  0,
                                  0.51467812934855361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25346484350787157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15483752469987253,
                                  0.13847796497427298,
                                  0,
                                  0,
                                  0,
                                  0.33126358374742437,
                                  0,
                                  0,
                                  0.16695067325869256,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58633170983333516,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.012428678470522148,
                                  0,
                                  0,
                                  0,
                                  -0.25641638976919268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21380608989555147,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55864351287296798,
                                  0,
                                  0.023418295080358947,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0060119127279095741,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56293799005779133,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.076302600524399855,
                                  0,
                                  0,
                                  0,
                                  0.47668191023685302,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35622410873689064,
                                  0,
                                  0,
                                  0,
                                  0.057781258282939452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50606938627586684,
                                  0,
                                  0,
                                  0,
                                  0.9886919736757358,
                                  0,
                                  0,
                                  0.57347889617380532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29757934917589962,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51547114577749631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16818036828030863,
                                  -0.55727257102921168,
                                  0,
                                  0,
                                  0.41913821250882,
                                  0,
                                  0,
                                  0,
                                  0.34328583209035568,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14522565647049201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31882284574224162,
                                  -0.150474313342885,
                                  0,
                                  0.14450191361308701,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024379866024987464,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37416462614519752,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098612151115288538,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34666646153913111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4369553425852441,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15258966534004345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60837451985365709,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13797906111184322,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62307683153638549,
                                  0,
                                  0.064101113286999412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058761172446596135,
                                  0,
                                  0.29196878641150614,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067405588893086607,
                                  0,
                                  0,
                                  -0.069340395510642722,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22220613569431802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20876700160237596,
                                  -0.60043765715330011,
                                  0,
                                  0,
                                  0,
                                  0.18586497742765218,
                                  0,
                                  0,
                                  0.050472158889452168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21344782377630422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.077589493488630201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22808813882436285,
                                  0,
                                  0,
                                  0.054630554772049533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36578628921734324,
                                  0,
                                  0,
                                  0,
                                  -0.42297629048779994,
                                  0,
                                  0,
                                  -0.19580526601796611,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.73645294930748573,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36209281734930726,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40331538237139936,
                                  0,
                                  0,
                                  0,
                                  -0.40079312628895325,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34814564397882697,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19237299715117828,
                                  0,
                                  0.70410742495942136,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.89723445352726316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17970328328991164,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36107888027295909,
                                  0,
                                  0,
                                  0,
                                  0.15126122368777078,
                                  0,
                                  0,
                                  0,
                                  -0.16289772401828417,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33825012706442376,
                                  0,
                                  -0.12804493009726703,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017470206616187617,
                                  0,
                                  -0.34399022077725377,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18483717860653495,
                                  0,
                                  0,
                                  0.23763257261826878,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55367275997587684,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087913335719372127,
                                  -0.11086059789362587,
                                  0,
                                  0,
                                  0,
                                  -0.20224147778492732,
                                  0,
                                  0,
                                  0.5156677316008591,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51869526791006426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22508619678963715,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.014312435091218111,
                                  0.68571524047013455,
                                  0,
                                  -0.53140094916547931,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2722028241815897,
                                  0.28889851232959174,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.09455399076781662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36194083648831532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50742031521980324,
                                  0,
                                  0,
                                  -0.15572292961915579,
                                  -0.24949563748240414,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5119050974594167,
                                  0.32238864491059699,
                                  0,
                                  0,
                                  0,
                                  0.88529170554461289,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59123613477639325,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58674209586860548,
                                  0.12176970153185944,
                                  0,
                                  -0.58404250100303323,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37811769735897016,
                                  -0.093046692037983519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37386169158363503,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36312777122509249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097759191996640127,
                                  0,
                                  0,
                                  0.084680671070826774,
                                  -0.81576395828121118,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.059194544936954904,
                                  -0.12341472650176546,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.74128290896016269,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52116370148662738,
                                  0,
                                  0,
                                  0,
                                  -0.47933059502057224,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39016080834832939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53512748981348623,
                                  0,
                                  0.06761081647278766,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43497241272268888,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36090096697037966,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18023926204245705,
                                  0,
                                  0,
                                  0,
                                  -0.16057201084162884,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.90315063412081975,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52392602206555894,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24098527361776625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17080028326413341,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45021700416044114,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43227285906190693,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0626798168428857,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26540367606007936};

const double rot_14_30[900] = {0.30772943194078645,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.78245358419086997,
                               0.41059381682625695,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35281964640352598,
                               0,
                               0,
                               0,
                               0,
                               0.95927087304188685,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.2784843978182223,
                               -0.010413613557323509,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28585265725685249,
                               0,
                               0.56882886688391121,
                               0,
                               0,
                               -0.32033167928801032,
                               0,
                               0,
                               0,
                               -0.98299606740439049,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0393370856048179,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17849421870831481,
                               -0.034077927446473713,
                               -0.085101617683806738,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.8727667598072858,
                               0,
                               0,
                               0,
                               -0.017062449832738993,
                               0.27054393736539656,
                               0,
                               0,
                               0,
                               0.35288703171452107,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41634089345216485,
                               0.66564760093678965,
                               -0.17771617092372879,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.024669233399824436,
                               0,
                               0,
                               0,
                               0.37046022641716381,
                               -0.16053726348549713,
                               0,
                               0,
                               0,
                               0.4340148972071749,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15742987577182513,
                               -0.21754619041302287,
                               0.64939915747334487,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.032308581876319215,
                               0,
                               0,
                               0,
                               0.68788849171435074,
                               -0.13719898414204407,
                               0,
                               0,
                               0,
                               0.11450869302653824,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1143709825085593,
                               0,
                               0,
                               0,
                               0.59252049146627284,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.49732875457162828,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.5612902063820755,
                               -0.16315046466421695,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.83556479589093047,
                               0.83789369766160271,
                               0.082968307047445899,
                               0,
                               0,
                               0,
                               -0.36725391420440334,
                               0,
                               0,
                               0,
                               0.00019627404540889515,
                               -0.48079580160124002,
                               0,
                               0,
                               0.29923985142304121,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0402630616873858,
                               -0.44391300590599708,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.46984827464465312,
                               -0.69055442943220324,
                               -0.028106744262297048,
                               0,
                               0,
                               0,
                               -0.31851416221054524,
                               0,
                               0,
                               0,
                               0.63235774941626932,
                               -0.64867277792969813,
                               0,
                               0,
                               -0.027614452558479587,
                               0,
                               0,
                               0.18913768144756793,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29990628782181628,
                               -1.1495866611707619,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.79343057023451635,
                               0,
                               0.68071536583574965,
                               0,
                               -1.1207773512989303,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40172595346794654,
                               0.44793947604362871,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.511861394184146,
                               0,
                               0.71134698146800401,
                               0.63286998280669982,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.063540085346118477,
                               -0.75029745580953389,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18025529180079883,
                               0,
                               0,
                               0,
                               -0.44215956572281334,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.61932500637104337,
                               -0.43594761469656063,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.48050091796343253,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57276457201637654,
                               0.032905195569030626,
                               -0.085188783684677138,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.46029402972832456,
                               0,
                               0,
                               0,
                               -0.05853084660825076,
                               0.29969014801513538,
                               0,
                               0,
                               0,
                               0.59874053283223982,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43081071334765508,
                               0.585209028004823,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0078680181014714745,
                               0.4419221512908868,
                               -0.78315535982573881,
                               0,
                               0,
                               0,
                               -0.15945314219156953,
                               0,
                               0,
                               0,
                               0.7662025347484247,
                               -0.20338545545499168,
                               0,
                               0,
                               -0.2517192289588196,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28861052804906751,
                               -0.28162170703156419,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31128062531714201,
                               0.47896760384902454,
                               0.74471354193338535,
                               0,
                               0,
                               0,
                               1.022437205060043,
                               0,
                               0,
                               0,
                               0.12450803122728935,
                               0.34400178235707107,
                               0,
                               0,
                               -0.584048396038092,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20205003474996694,
                               -0.37092034094387943,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.78035363176061945,
                               0.15670952128414908,
                               -0.061152698354280423,
                               0,
                               0,
                               0,
                               -0.1836172264776762,
                               0,
                               0,
                               0,
                               0.44041480114535791,
                               1.1381177944864789,
                               0,
                               0,
                               0.499308868273656,
                               0,
                               0,
                               0,
                               0,
                               0.45194819428765026,
                               0.076354837227087136,
                               0.6246366882331299,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.06934750483887718,
                               0,
                               0,
                               0,
                               -0.4076817661355967,
                               0.43046811487893166,
                               0,
                               0,
                               0,
                               0.20838781017868294,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14265102209885583,
                               0.02194112331636526,
                               0.23849471979121975,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.098753944394479307,
                               0,
                               0,
                               0,
                               -0.46233712479002387,
                               -0.77446021505454055,
                               0,
                               0,
                               0,
                               0.31463146447641932,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.90406763642522159,
                               0,
                               -0.42738941115628193,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.69210830368499554,
                               0.66658364160229511,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.029400132236217874,
                               0.44758673343397931,
                               0.5878596455322298,
                               0,
                               0,
                               0,
                               -0.24593887420585897,
                               0,
                               0,
                               0,
                               -0.28068101516136845,
                               -0.15020646140886043,
                               0,
                               0,
                               0.22015473969210977,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42738941115628204,
                               0,
                               -0.90406763642522137,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46620828945741694,
                               0.70783571208934881,
                               0.29180054662713972,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10096413061930554,
                               0,
                               0,
                               0,
                               -0.076756869480070183,
                               0.085466930977585454,
                               0,
                               0,
                               0,
                               -0.41602993587653819,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67374803541535877,
                               0,
                               0,
                               0,
                               0.0082143039598097656,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.5610019098723855,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27057156798492688,
                               -0.089849050928233712,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.066558046473740556,
                               0.32715926365746723,
                               1.0181266682895043,
                               0,
                               0,
                               0,
                               0.069721725874191912,
                               0,
                               0,
                               0,
                               0.94239460470707559,
                               -0.5820035184751422,
                               0,
                               0,
                               0.76132653675257078,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.75270880384963479,
                               0.37402267406546674,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33571560625780761,
                               -0.37511914239037952,
                               0.3051428198935055,
                               0,
                               0,
                               0,
                               -0.50787071013346918,
                               0,
                               0,
                               0,
                               0.40084745709192282,
                               0.41131812388927386,
                               0,
                               0,
                               -0.47826563711372161,
                               0,
                               -0.55612327771768422,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.012867891224931538,
                               -0.2800287889310078,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.78239708251360307,
                               0,
                               0,
                               0,
                               0,
                               0.039827026160618215,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37879628260925818,
                               -0.87205906277431144,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.2098405837076134,
                               0,
                               -0.5729322835277133,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.052063508524904371,
                               -0.67245126961920321,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5777168413239181,
                               0.76283280327598613,
                               0.055824580814355533,
                               0,
                               0,
                               0,
                               -0.34970764968289392,
                               0,
                               0,
                               0,
                               -0.038907870548462238,
                               0.32932225638925855,
                               0,
                               0,
                               -0.68332250568716091,
                               0,
                               0,
                               -0.88779452789539348,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.65155175307480639,
                               -0.33256362141257462,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.45816247652972258,
                               0,
                               -0.8830644543663031};

const double rot_14_2[4] = {-0.95971040321954759, 0.28099099977076469, -0.28099099977076425, -0.95971040321954715};

const double rot_15_50[2500] = {-0.73876202286946435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.034297653352819743,
                                0,
                                0,
                                0,
                                0.47344860269490524,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.038093849067645902,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25582937550868323,
                                0,
                                0,
                                0.40249342160661111,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12623863701757815,
                                0.4292305588352095,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.069695955426376133,
                                -0.18798256575073885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46169946910545101,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58889621522867708,
                                0,
                                0,
                                0,
                                0,
                                -0.44405923468447756,
                                0.049761497821630668,
                                0,
                                -0.63519613394165853,
                                0.19451692054828856,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54411749452578051,
                                -0.35218024614213828,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16458035193788675,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11485875046639912,
                                0,
                                0,
                                0,
                                0,
                                0.074719709849145749,
                                -0.30451930247783926,
                                0,
                                0,
                                0,
                                -0.84873702809170637,
                                0.32493648949778581,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36395406579596823,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0146243048298069,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32204611799418159,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79985951334550986,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17318761274164446,
                                -0.53666164384478243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17345286487028413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0594066788938188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36346178955603431,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.272639615650142,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33291195365315612,
                                0,
                                0,
                                0.024767742204784074,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2768997329215361,
                                0,
                                0,
                                -0.087731044885720949,
                                0,
                                0,
                                -0.05699716148042018,
                                0,
                                0,
                                0,
                                0,
                                -0.80019637140326305,
                                0,
                                -0.65778022673536618,
                                0,
                                0.41840786953022807,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14439946544169494,
                                0,
                                0,
                                0,
                                0,
                                0.11941768945887957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.78150788167757912,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.033226942204830454,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20256423174746527,
                                0,
                                0.78990197977614918,
                                0,
                                0,
                                0,
                                0,
                                -0.48476632759768129,
                                0,
                                0,
                                0.60447140893251627,
                                0,
                                0,
                                0,
                                0.033997402696749598,
                                -0.13592712751121894,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43525182072263036,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62364941062588786,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64932061817226927,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52229968528989179,
                                0,
                                0,
                                -0.0077294543640103186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.094246042505776992,
                                0,
                                0,
                                -0.29122726912839036,
                                0,
                                0,
                                -0.22617766868186304,
                                0,
                                0,
                                0,
                                0,
                                -0.34068053956507349,
                                0,
                                0.39202641006352945,
                                0,
                                -0.17264586188440323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43919769717370694,
                                0,
                                0,
                                0,
                                0,
                                1.1393325398069627,
                                0,
                                0,
                                0,
                                0,
                                0.33520865868820993,
                                0.021844510801931991,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31688078663601571,
                                -0.13903666063513387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.081187885376430693,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59315216403344762,
                                0,
                                0,
                                0,
                                0,
                                0.63925017445687038,
                                0.018750962003261481,
                                0,
                                0.012093221000568527,
                                -0.54220228061960651,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11252041560426335,
                                -0.74263873195760022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13502472336561233,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.082317555674295148,
                                0,
                                0,
                                0,
                                0,
                                -0.19531059411394067,
                                0.28025564525998181,
                                0,
                                0,
                                0,
                                -0.031834119922836857,
                                -0.17767852612784091,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80845582203355015,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55854403581480594,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79638359385468527,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47723428379205324,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65146788396914246,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21677892117846081,
                                0,
                                0,
                                0,
                                0.3120439559158642,
                                0.36904077508417688,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54317029686012741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12491740832079215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80237726587175118,
                                0,
                                0,
                                0,
                                0.2666485125469944,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28042744931044444,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31928782974975861,
                                0,
                                0,
                                -0.29816214131574825,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28980974083760241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2173624752594816,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49155434518838226,
                                0,
                                0.21754604328145616,
                                0,
                                0,
                                0,
                                0,
                                0.0078689257668469459,
                                0,
                                0,
                                0.13240632050089546,
                                0,
                                0,
                                0,
                                0.14956517101336581,
                                0.30412650113085143,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1897786936332666,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20957656717244272,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21562177046830749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.86840487185308501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31331730786424949,
                                0,
                                0,
                                0.33752802775590207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64252777442381448,
                                0,
                                0,
                                -0.1966998794443241,
                                0,
                                0,
                                0.91773490390755552,
                                0,
                                0,
                                0,
                                0,
                                0.25647157138884119,
                                0,
                                -0.39757637356784692,
                                0,
                                -0.58561052576229422,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59852665354245216,
                                0,
                                0,
                                0,
                                0,
                                -0.21291492679410484,
                                0,
                                0,
                                0,
                                -0.4590172490610695,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2213246266494823,
                                0,
                                0,
                                0,
                                -0.56412982838425363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56071776918442218,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31467565527481306,
                                0,
                                0,
                                0.09301035817714326,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3792247604755758,
                                -0.30988820928738731,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39985690561340609,
                                -0.041898931593432734,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55930990708134609,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.016498959482080217,
                                0,
                                0,
                                0,
                                0,
                                0.46213393581920059,
                                -0.26804710573408358,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18788736020671321,
                                0,
                                0,
                                -0.62709625639185096,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57199329196492121,
                                0,
                                0,
                                0.42696352481287486,
                                0,
                                0,
                                0.05289621859893421,
                                0,
                                0,
                                0,
                                0,
                                0.20044557345529998,
                                0,
                                -1.0553265769935734,
                                0,
                                0.19815019589350671,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18376703474452327,
                                0,
                                0,
                                0,
                                0,
                                0.2679309131540899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.084732672799996633,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40037108648962527,
                                0,
                                0,
                                0,
                                -0.35023798932276462,
                                0.7564858162254563,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37092577148014128,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44073883770154437,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71300230752528604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.91988422810984893,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67057031006887302,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33638565951882538,
                                0,
                                0,
                                0.18156455355826179,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.030080539667985434,
                                0,
                                0,
                                -0.358025655097508,
                                0,
                                0,
                                0.66643070789951997,
                                0,
                                0,
                                0,
                                0,
                                0.48345845702420359,
                                0,
                                -0.17930183295627591,
                                0,
                                -0.51211044680932072,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3736130455050248,
                                0,
                                0,
                                0,
                                0,
                                0.14115704252002564,
                                0,
                                0,
                                0,
                                -0.076664316911551331,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18256061979285254,
                                0,
                                0,
                                0,
                                -0.28352147449082588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64140935105054198,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5192256438893128,
                                0,
                                0,
                                0.44655184607001003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18829976292310824,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4207329765642735,
                                0,
                                0,
                                0,
                                -0.61544052756667578,
                                0.21233868327436417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60305240429686413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6394803702048617,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58169066646113521,
                                0,
                                0,
                                0,
                                -0.21802405187213744,
                                0.058298823805630305,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44918546795593223,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0816510385489133,
                                -0.31409419385568671,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30599139620432297,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26008278533920598,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1100071878233846,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47564382269162092,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23593353858619343,
                                0,
                                0,
                                -0.97728689589024642,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22103083340495114,
                                0,
                                0,
                                -0.092636563296773278,
                                0,
                                0,
                                1.0766125227070464,
                                0,
                                0,
                                0,
                                0,
                                -0.27405045466888778,
                                0,
                                0.39481993161970963,
                                0,
                                0.55743010678372462,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00081669450334893867,
                                0,
                                0,
                                0,
                                0,
                                -0.44787592038826313,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24371679102538032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30212845954921769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.6346111309395157,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.051599540491034324,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0097041045481791113,
                                0,
                                0,
                                0.51061882686333759,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.82329105142051284,
                                0,
                                0,
                                -1.2803299193273279,
                                0,
                                0,
                                0.084610295021778359,
                                0,
                                0,
                                0,
                                0,
                                -0.33532657168649799,
                                0,
                                -0.50040437302584873,
                                0,
                                0.58976741993042037,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36858721537586903,
                                0,
                                0,
                                0,
                                0,
                                -0.038987136624703753,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69255960968877872,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.023395816900754082,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00080513533060118381,
                                0,
                                0.07809975983329577,
                                0,
                                0,
                                0,
                                0,
                                -1.0254352607833539,
                                0,
                                0,
                                -0.44077484608516815,
                                0,
                                0,
                                0,
                                -0.31842201329033992,
                                0.50129789652033874,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44540239814208016,
                                0,
                                0,
                                -0.2246204439508428,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2757021682472659,
                                0,
                                0,
                                -0.2726003126029195,
                                0,
                                0,
                                -0.22966215229220729,
                                0,
                                0,
                                0,
                                0,
                                -0.37914198378751962,
                                0,
                                -0.61530841862347641,
                                0,
                                -0.65060597073001991,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28121495475374442,
                                0,
                                0,
                                0,
                                0,
                                -0.59138449777988711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20391483646480113,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52024717071536219,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46285645643158763,
                                0,
                                -0.20985748687913963,
                                0,
                                0,
                                0,
                                0,
                                -0.2731352978040068,
                                0,
                                0,
                                1.0989857005551007,
                                0,
                                0,
                                0,
                                0.13496674609925857,
                                -0.52034326452259339,
                                0,
                                0,
                                0,
                                0,
                                -0.10392519846528311,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45856333132418342,
                                0,
                                0,
                                0,
                                0.44837298922732161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23959002277123023,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64395991781353656,
                                0,
                                0,
                                -0.3252585618523206,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35216193110938482,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52662094851912877,
                                0,
                                0,
                                0,
                                0.59469352631858396,
                                0.49300268447865969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.04404899215333842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48342540068204476,
                                1.1307765995445012,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47393473979267797,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31181958914075791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22900910612696845,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67886468767382147,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45962116505343659,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24984214034235092,
                                0,
                                0,
                                0,
                                -0.32416009026987591,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36972361708538315,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22204999291872374,
                                0,
                                0,
                                -0.65973159166012052,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27019328006727644,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0077671502999113046,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11666317914139561,
                                0,
                                -0.13626378308871717,
                                0,
                                0,
                                0,
                                0,
                                -0.45250515642316536,
                                0,
                                0,
                                0.5157632555082603,
                                0,
                                0,
                                0,
                                1.0333937043553278,
                                0.33304456062426963,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8048227515283265,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59276455997821853,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.029841498893367291,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50374386372253432,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67300992276410576,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2501853468268278,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65191780675729316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16572841048128964,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14149063313701488,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31874055393255407,
                                0,
                                -0.43084877841073888,
                                0,
                                0,
                                0,
                                0,
                                0.20034036781787828,
                                0,
                                0,
                                0.58391036695748111,
                                0,
                                0,
                                0,
                                -0.54014278934816962,
                                0.78834037589796058,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69425230832760609,
                                0,
                                0,
                                -0.22749267854800109,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43518099189257686,
                                0,
                                0,
                                -0.30658840364932127,
                                0,
                                0,
                                -0.18348283105081686,
                                0,
                                0,
                                0,
                                0,
                                0.37703487586169854,
                                0,
                                -0.043019725136516258,
                                0,
                                0.93541378508000639,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53144326146114551,
                                0,
                                0,
                                0,
                                0,
                                -0.095594212949108526,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0993753773397728,
                                -0.62650486802637706,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64579613139292447,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29136478676399707,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90638258352492418,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.78268686212515381,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42735143473759241,
                                0.44292757960021878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.040053809987836031,
                                -0.48886632872533037,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31261061954371933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49846715704586686,
                                0,
                                0,
                                0,
                                0,
                                0.1780449299064959,
                                -0.051926989427299459,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49664020604799219,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.028361631338310829,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48797925233439127,
                                0,
                                0.55406342029882694,
                                0,
                                0,
                                0,
                                0,
                                0.72990867771786705,
                                0,
                                0,
                                0.092461538607260682,
                                0,
                                0,
                                0,
                                -0.055617006682134582,
                                0.49276416301623055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65870325242590733,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31718454576256444,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1453607171904001,
                                0,
                                0.20971765870393233,
                                0,
                                0,
                                0,
                                0,
                                0.26444414058718813,
                                0,
                                0,
                                -0.0040398018148850023,
                                0,
                                0,
                                0,
                                -0.5103897112462501,
                                -0.17443648187122174,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45147427997309497,
                                0,
                                0,
                                0.95591354564639341,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15857267769353089,
                                0,
                                0,
                                0.34259119844237917,
                                0,
                                0,
                                0.61835097095465563,
                                0,
                                0,
                                0,
                                0,
                                -0.41025398497752347,
                                0,
                                0.37958789188989334,
                                0,
                                0.11007613550959003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.365387677523629,
                                0,
                                0,
                                0,
                                0,
                                0.0906868148763047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40350488371271148,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5095994398150494,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75992908863931485,
                                0,
                                0,
                                0,
                                0.072475514808891167,
                                -0.33019033928611313,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63656255845396892,
                                0.16780451322282139,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56695218674132897,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15815378840741159,
                                0,
                                0,
                                0,
                                0,
                                -0.096137455860128951,
                                0.31090445615051526,
                                0,
                                0.36930369497061211,
                                -0.2867448273943502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13893381731833077,
                                -0.029731927432781267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.054184921059852925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.087456859970428957,
                                0,
                                0,
                                0,
                                0,
                                -0.30972756612029823,
                                -0.80912898755338913};

const double rot_15_20[400] = {1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.62015325241700048,
                               0,
                               0,
                               0,
                               -0.18573574750762564,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20166211462626552,
                               0,
                               0,
                               0.7350133108582878,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.71782258022517542,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0123985469172645,
                               0,
                               0,
                               0,
                               0,
                               0.39256182288931096,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.69179018934109204,
                               0,
                               0,
                               0,
                               -0.12528231840332521,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.53495005534794426,
                               0,
                               0,
                               -0.46857135306176667,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19984001337025717,
                               0,
                               -0.90735730208686516,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36981981478257953,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61568423423384,
                               0,
                               0.17733045335513239,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.76778045952521712,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34180125077728873,
                               0,
                               0,
                               0,
                               -0.81298161009322045,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42685698080923556,
                               0,
                               0,
                               0.20006480088146611,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1985592666470337,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.3379662361772671,
                               0,
                               0,
                               0,
                               0,
                               -0.19509464394997933,
                               0,
                               -0.14145028248509389,
                               0,
                               0,
                               0,
                               -0.53746392850451563,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.70068105992820895,
                               0,
                               0,
                               -0.44740406278806011,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.76223152176491982,
                               0,
                               0.38112548676585328,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.52320786554239129,
                               0,
                               0,
                               0,
                               0,
                               0.5877844471528193,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.09966475933536556,
                               0,
                               0,
                               0,
                               0,
                               1.7607285366584502};

const double rot_15_10[100] = {1.742723746261136,
                               0,
                               0,
                               0,
                               0.51724072459066428,
                               0,
                               -0.55896710682127471,
                               0,
                               0,
                               0,
                               0,
                               0.72808571316803616,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11942100161754804,
                               -0.014974824002898346,
                               0.67483744212909103,
                               0,
                               0,
                               0.66576219493512934,
                               -0.10467689026693028,
                               0,
                               0.73878511655230583,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67964841466309178,
                               -0.49371327891412897,
                               0,
                               0.54251749342284383,
                               0,
                               0,
                               0,
                               0,
                               0.16856968841455383,
                               0,
                               0,
                               0,
                               -0.099860663269896288,
                               0,
                               -1.2649790637080076,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30795897817908285,
                               -0.86330177045335921,
                               0,
                               -0.39983911876027156,
                               0,
                               0,
                               0,
                               0,
                               -0.65010614124320509,
                               0,
                               0,
                               0,
                               1.1486414942249616,
                               0,
                               -0.5413711363033803,
                               0,
                               0,
                               0,
                               0,
                               -0.036287978045161602,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.60262351567148698,
                               0.79564096686800556,
                               -0.049835056440986986,
                               0,
                               -0.014459067004756243,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.78512422220855393,
                               -0.60388212063384972,
                               -0.13673798104963628,
                               0,
                               -0.68437220305279611,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.078507824029278334,
                               -0.045360675327779321,
                               0.72347330178014091};

const double rot_15_100[10000] = {-0.059451874758096275,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.442969980225487,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30932956476448603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.77887515826129705,
                                  0,
                                  0,
                                  0.31294701694013194,
                                  0,
                                  0,
                                  -0.47173465118207758,
                                  0,
                                  0,
                                  0,
                                  -0.24018133309376868,
                                  0,
                                  0,
                                  -0.26168871272385541,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5755770619774212,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19444590064638015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2765663175208713,
                                  0.10083423100338305,
                                  0,
                                  0,
                                  -0.3081286216279398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18230506041224209,
                                  0,
                                  0.46209739646144776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48972978168058728,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015082460358357266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13583864568938936,
                                  0,
                                  0,
                                  0.176613026331152,
                                  0,
                                  0,
                                  -0.16589841085758666,
                                  0,
                                  0,
                                  0,
                                  -0.21350291859905612,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42801466703268731,
                                  0.25697952142988978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25560854220666018,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32829771328207946,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036097559135168655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19332976267659649,
                                  0,
                                  0,
                                  0,
                                  -0.38714088181000211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035004547599997757,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35190972619070443,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26183061870047475,
                                  0,
                                  0,
                                  0.055779931315368105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30408933563407098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12762688377927348,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.023654062119124755,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19058804729415371,
                                  0,
                                  0,
                                  0.28702974408831161,
                                  0,
                                  0,
                                  0.20366916077213379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47870186114971847,
                                  -0.34256117159264216,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058896170029522008,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.05126638412410775,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.83935739388840958,
                                  0,
                                  0,
                                  0,
                                  -0.12935698263621126,
                                  0,
                                  0,
                                  -0.95402801078105581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.71151106421836596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40438814289072811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030498297738938002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15541433355468903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28835993159359341,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.75451410747711589,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58502941948445164,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37785662904757533,
                                  0.33177025545489325,
                                  0.38174913508533126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.093216955246705646,
                                  0,
                                  0,
                                  0,
                                  0.27430803287196293,
                                  0,
                                  0,
                                  0,
                                  1.017928765847006,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.050185580572132765,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24318121755885735,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51838304103047561,
                                  0,
                                  -0.39949096983165711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053888072914194535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31968618067800658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19699408449681183,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65404597693841171,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.013785563179066252,
                                  0,
                                  0,
                                  0,
                                  0.060287418719644797,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65898174564363021,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0069031685977859573,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39002286215945442,
                                  0,
                                  0,
                                  0.47727462622174283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024828249665000881,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18642459063509803,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13553877215182719,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18734009783195102,
                                  0,
                                  0,
                                  -0.27000131159459323,
                                  0,
                                  0,
                                  -0.12872380840171657,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.034582354063902948,
                                  0.049576016477139558,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59139369924672502,
                                  0,
                                  0.038333090765223281,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43294997304240074,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057943961895812746,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62952440195950443,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24835440826284791,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.70965114684826758,
                                  -0.20055920505659622,
                                  0.082124423248158246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13367829654573507,
                                  0,
                                  -0.12869661508854735,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34620556668633501,
                                  0,
                                  -0.26323584658620386,
                                  0,
                                  0,
                                  -0.14430293419598325,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24983957890616407,
                                  0,
                                  0,
                                  0.37762358388930384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18189062441205561,
                                  -0.30630065290503949,
                                  0.21812801298216317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48301178799632566,
                                  0,
                                  0.26763942276428243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053196626185096879,
                                  0,
                                  -0.24234469134919912,
                                  0,
                                  0,
                                  -0.62682828543178337,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12903398193160739,
                                  0,
                                  0,
                                  -0.22239679493934034,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22212261120828497,
                                  0.34577337816954556,
                                  0.17573730148411193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1430777346811252,
                                  0,
                                  0.41987966512789188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01667795852533141,
                                  0,
                                  -0.32434000068266006,
                                  0,
                                  0,
                                  -0.011274061942418118,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.70414383305474681,
                                  0,
                                  0,
                                  0.045036802859542341,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36804460873030886,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62083776450573669,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72046236708713352,
                                  0,
                                  0,
                                  -0.36545418863295798,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.2978970936101857,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.027181635060163925,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11048917454454366,
                                  0,
                                  0,
                                  -0.0056603013911542543,
                                  0,
                                  0,
                                  0.27269128242602969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047368193153333266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38889719135590967,
                                  0,
                                  0,
                                  -0.82519045031295812,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36168630413489666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63378048495407202,
                                  -0.66443134996327724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20954849018426147,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41541613274173045,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098043756916533331,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094220526731830762,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42719605050710507,
                                  0,
                                  0,
                                  0.29236563727308917,
                                  0,
                                  0,
                                  0.69390330468197225,
                                  0,
                                  0,
                                  0,
                                  0.05540550374613798,
                                  0,
                                  0,
                                  0.41917164983539201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16755815018135159,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12024925721553442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30284044356397349,
                                  -0.63028610151069042,
                                  0,
                                  0,
                                  -0.077889865314535067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092042325117971724,
                                  0,
                                  0,
                                  0.28203888857355219,
                                  0,
                                  0,
                                  0,
                                  -0.44473258137762428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16529174095459614,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17870908822175119,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29736269585310404,
                                  0,
                                  0,
                                  -0.2053771902618298,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51197845499983274,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017041930888127221,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21442396661052227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3477751199272473,
                                  0,
                                  0,
                                  0.082020101620340485,
                                  0,
                                  0,
                                  -0.20847893418994451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10289714090727244,
                                  0.20661126160056872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65882593348006735,
                                  0,
                                  0,
                                  -0.41342265387592447,
                                  0,
                                  0,
                                  -0.24196136256336953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38713830570443064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085431014431708613,
                                  0,
                                  0,
                                  0.65947345533572455,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33280683110340836,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23475343874355259,
                                  -1.0229086197629376,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16316363100402206,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53508497533346677,
                                  0,
                                  0.010398705425229263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65523969097672941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40719356731111844,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13933299892139522,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31466902869298735,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17974076289267291,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46955311429947555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32051527587849926,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26112361075073404,
                                  0,
                                  0,
                                  -0.31526436316902146,
                                  0,
                                  0,
                                  0.2206692845956427,
                                  0,
                                  0,
                                  0,
                                  0.17973048697533561,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068281064721598547,
                                  0.33833948188437513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51817230852280871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080123205051693652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043008963459071237,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13166399153038169,
                                  0,
                                  0,
                                  -1.0158081627815889,
                                  0,
                                  0,
                                  -0.35451904010970425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038748464837455088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18506265557464263,
                                  0,
                                  0,
                                  -0.46469984850842128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58106979583405138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14181337538068989,
                                  -0.30797700789215132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16497919361602467,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46137126195732486,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030649957609372988,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35805791541411403,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087179368390126993,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17137953316276566,
                                  0,
                                  0,
                                  0.68129853503018811,
                                  0,
                                  -0.37414369441317391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12988180543994571,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0065281245742792038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23490651684730973,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.74196384504221591,
                                  0,
                                  0,
                                  0,
                                  -0.14780030700366653,
                                  0,
                                  0,
                                  -0.78070045130437726,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51423923639918623,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021360216511193145,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.74626433407548576,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55017400692965102,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48523239419475672,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.010281926799309518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097900223280719539,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1723111348828503,
                                  0.31202402687774772,
                                  -0.94376370831011092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077182156130319202,
                                  0,
                                  0,
                                  0,
                                  0.22113565827987275,
                                  0,
                                  0,
                                  0,
                                  0.18287312208485676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.034306797347722823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13067946025022281,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024636834379150277,
                                  0,
                                  0,
                                  0,
                                  -0.46684640834509122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0076682973576331255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.075127693400757284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18705949821270981,
                                  0,
                                  0,
                                  0.25140823024945974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29167451024614277,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25758294739927029,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33321088860669806,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17666724427774894,
                                  0,
                                  0,
                                  -0.4524768802382419,
                                  0,
                                  0,
                                  0.03122264397601399,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039340327332158025,
                                  -0.42026834521726042,
                                  0,
                                  0,
                                  -0.1522471505361821,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17475137080064265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36811410960206586,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20385183243959287,
                                  0,
                                  0,
                                  -0.12397722477358261,
                                  0,
                                  0,
                                  -0.0036520778284579395,
                                  0,
                                  0,
                                  0,
                                  0.063101822737818516,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72961954380903282,
                                  -0.43049655339734727,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073938412510362192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025508656895104891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16144387475437777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25523695929188484,
                                  0,
                                  0.87578314486607078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1050867370081459,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17293369112395499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31775628748883944,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16105786450981605,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19923844923049203,
                                  0.64737285316036686,
                                  -0.29929563235961398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4467776996942045,
                                  0,
                                  -0.28079780813113175,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28860715629581352,
                                  0,
                                  0.0719131892104828,
                                  0,
                                  0,
                                  -0.25329575410427041,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11890035829236045,
                                  0,
                                  0,
                                  -0.080094944269409912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17017595578284375,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1590562752960992,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.87675442055593666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34332247478830241,
                                  0,
                                  0,
                                  -0.23161730182561949,
                                  0,
                                  0,
                                  0.57481705924636961,
                                  0,
                                  0,
                                  0,
                                  0.41949180625262128,
                                  0,
                                  0,
                                  0.12622405115096572,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6174849963312391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52981129587515452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37803962841567224,
                                  0.2619017492418812,
                                  0,
                                  0,
                                  -0.63102543789476162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069737204389322099,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19901099520927998,
                                  -0.38657472160705891,
                                  -0.42760685583972674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073935704441164582,
                                  0,
                                  -0.26040512843615798,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52645170145086906,
                                  0,
                                  -0.41175540490066964,
                                  0,
                                  0,
                                  -0.001154296727990306,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17918129897529259,
                                  0,
                                  0,
                                  0.27573263898783984,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.010362297409265947,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37285103494338512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37729913909743912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1505868907848211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36612948272576362,
                                  0,
                                  0,
                                  0.098549268211066507,
                                  0,
                                  0.45018413298123044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59111349715609307,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36330690645183705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29838158040905582,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15055871660687886,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25563770866682012,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.80303999670050397,
                                  -1.0236673749119136,
                                  -0.26937395466661079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34724518725932485,
                                  0,
                                  0,
                                  0,
                                  0.39978414879107865,
                                  0,
                                  0,
                                  0,
                                  0.084720166114241227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077055801229309162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34122947984137186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46769480531305496,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49645896961350755,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0090269651397155912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54417620850507387,
                                  0,
                                  0,
                                  -0.20619795548280775,
                                  0,
                                  0,
                                  -0.18417743441590745,
                                  0,
                                  0,
                                  0,
                                  -0.06566662132934814,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040792888536393207,
                                  0.2767142557071256,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15962055341504366,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21661673336480286,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084814090267503722,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.98845326645336884,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12809269111641658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.020368079955985559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31598485976548957,
                                  0,
                                  0,
                                  -0.39217488015870272,
                                  0,
                                  0,
                                  0.36972285742431943,
                                  0,
                                  0,
                                  0,
                                  -0.12453111721298403,
                                  0,
                                  0,
                                  -0.40515951308046655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14006189811286801,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13796863652524805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50919389427719886,
                                  -0.25379028455829178,
                                  0,
                                  0,
                                  -0.070104148520291246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.084214190681001971,
                                  0,
                                  0,
                                  -0.4932556756351073,
                                  0,
                                  0,
                                  0,
                                  0.13258246354268327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12685998657518149,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079075058686778818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.074546749026673895,
                                  0,
                                  0,
                                  0.17736859627988177,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24995839532538178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29511581844825191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65542501115152629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11221171945461252,
                                  0,
                                  0,
                                  -0.0094931757744955297,
                                  0,
                                  0,
                                  0.23993484924264136,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072407633812713923,
                                  -0.15846101210739988,
                                  0,
                                  0,
                                  -0.11342725115078306,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11563649279956612,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026556069738217947,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45303409901841024,
                                  0,
                                  0,
                                  0.18149001755980179,
                                  0,
                                  0,
                                  -0.51559853381002296,
                                  0,
                                  0,
                                  0,
                                  0.012511329737733147,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28999236622439323,
                                  0.2875949420903689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4790525963424952,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.089800223519750144,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25400480155353772,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27499747720857909,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045363686910764339,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38319909726837958,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20899328384735616,
                                  0,
                                  0,
                                  0.18701059408154214,
                                  0,
                                  0,
                                  0.002812229784712128,
                                  0,
                                  0,
                                  0,
                                  -0.55985235471665373,
                                  0,
                                  0,
                                  -0.28961939643858936,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.73046711642443418,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40911617949094137,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19867877646640617,
                                  0.39055152257368048,
                                  0,
                                  0,
                                  -0.2626709905089421,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28371241161899319,
                                  0,
                                  0,
                                  0.43564590321472518,
                                  0,
                                  0,
                                  0,
                                  0.2591160565201639,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18820376778453071,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12022645260798262,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42864976862425885,
                                  0,
                                  0,
                                  0.17935689587563358,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18586505609420612,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22891285430915259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049524373225289492,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3386369721040744,
                                  0,
                                  0,
                                  0.12753769017257444,
                                  0,
                                  0,
                                  0.29301406229134375,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40986397778689715,
                                  0.05568463113403304,
                                  0,
                                  0,
                                  0.10170323545752159,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15294379998444738,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29066447752836549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.093108677936057996,
                                  0,
                                  0,
                                  0.27917856069019048,
                                  0,
                                  0,
                                  0.073637243164239544,
                                  0,
                                  0,
                                  0,
                                  -0.46477212957444997,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070215856937420079,
                                  0.078253638957994989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12914399757704001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54950082514712795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49401428041882445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081580248587657625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6454221871125877,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52199653950459346,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41892995108569275,
                                  0,
                                  0,
                                  0.0024177439457875177,
                                  0,
                                  0,
                                  -0.72304282824162835,
                                  0,
                                  0,
                                  0,
                                  0.050424848865560756,
                                  0,
                                  0,
                                  0.33753192766770679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15055045911626252,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28446310828320126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67471527469094705,
                                  0.024002211163495352,
                                  0,
                                  0,
                                  -0.11717486880931141,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060633892232499556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086350406607101429,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65413816666431934,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0079951208768076956,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.095199505735710011,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55076242900704842,
                                  0,
                                  0,
                                  -0.035164803455293284,
                                  0,
                                  0.44362338532000545,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23268535349501029,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0037905298495582718,
                                  0,
                                  0,
                                  0.4186240230428957,
                                  0,
                                  0,
                                  -0.35910784258704997,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3853234154193253,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18385325490491841,
                                  0,
                                  0,
                                  0.65770079232590373,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44375956272271394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.88195706439058985,
                                  0.27584340608665603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53697276181866704,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2607492835239863,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.04037455543416614,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.039225547842152833,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097509690668103638,
                                  0,
                                  0,
                                  0.2300390453244448,
                                  0,
                                  0,
                                  -0.30807869145444017,
                                  0,
                                  0,
                                  0,
                                  0.061564008434873613,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3117268573262626,
                                  -0.45132961349827527,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44166768445995114,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43068152896095746,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29374032225336394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19531894481578796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56598118234149442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34886319438042035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.79732374872165124,
                                  0,
                                  0,
                                  0.45777023967880154,
                                  0,
                                  0,
                                  -0.2949572163392572,
                                  0,
                                  0,
                                  0,
                                  0.020654027515372146,
                                  0,
                                  0,
                                  0.048584807844323362,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51104469013404752,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54770524974520463,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21211136440601783,
                                  -0.32471703397525647,
                                  0,
                                  0,
                                  0.18027159321099517,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.73960301220586255,
                                  0,
                                  0,
                                  0,
                                  -0.89260201175523513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.1320476398326744,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0017900405654981549,
                                  0,
                                  0,
                                  0,
                                  -0.099470962095279697,
                                  0,
                                  0,
                                  -0.24106244036267707,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20251559598062352,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0441337322874484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03282155147363882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0018762345217507,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18239663679622259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14669830383699106,
                                  0,
                                  0,
                                  0.63464255950815485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.78486415162041445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.067375501058456577,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35397230216984604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35311638622967456,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12812455718726062,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14670725430189552,
                                  0,
                                  0,
                                  -0.32084719717266025,
                                  0,
                                  0,
                                  0.096109940767050817,
                                  0,
                                  0,
                                  0,
                                  -0.33739263505126993,
                                  0,
                                  0,
                                  -0.74864732253059685,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38214698168285677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01821080418777099,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22299669603738848,
                                  -0.18281495228341249,
                                  0,
                                  0,
                                  -0.51043017615527375,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57678684405866265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.89768934815933032,
                                  0,
                                  0,
                                  -0.28197688241788227,
                                  0,
                                  0,
                                  0.024685316118597117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.75083720301501344,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37002584877427208,
                                  0,
                                  0,
                                  0.34073842840645435,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16649465189093104,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39022791511465027,
                                  0.41232726648253398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.97820234903708458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48183887202848841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.080045191661684223,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.83134761933452417,
                                  0,
                                  0,
                                  0,
                                  -1.1164384158260365,
                                  0,
                                  0,
                                  -0.29977887403783887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080841721446268625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63808293704494434,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39058604365037503,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.04771249451427885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.69304255982721752,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67783761908553175,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30723790681603064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.91339592990170249,
                                  -0.55609902094730412,
                                  -0.22238856330336562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28825435268610872,
                                  0,
                                  0,
                                  0,
                                  -0.10084734306550966,
                                  0,
                                  0,
                                  0,
                                  0.39151774186680521,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42614524143580568,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029742818263487722,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.74063880745790567,
                                  0,
                                  0,
                                  -0.41648753568034269,
                                  0,
                                  0,
                                  0.67862990449035943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61041663638224641,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.80141206051934577,
                                  0,
                                  0,
                                  -0.46588868612639756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049372013886124611,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3575044293050042,
                                  0.068653264600219477,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54491381468887001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.97229374640296462,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63737978062008527,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12825574534631856,
                                  0,
                                  0,
                                  0,
                                  -0.0021412804006312736,
                                  0,
                                  0,
                                  0.1601097767794562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.99146717833963671,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2373364013050315,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36566496532194287,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068556748956515479,
                                  -0.072953876178483132,
                                  0.74204643608643284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11214183373791967,
                                  0,
                                  -0.50666561591955894,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30888706289427309,
                                  0,
                                  0.10743495894496247,
                                  0,
                                  0,
                                  0.13059194403781305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21390499207099919,
                                  0,
                                  0,
                                  -0.01720069992169318,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4854152074540492,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.89875907158496515,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66093116007373431,
                                  0,
                                  0,
                                  1.0161178067159304,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.9798241980842366,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.090937362110903378,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.188141064030169,
                                  0.23436479077910402,
                                  0.10344886496294334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.402417721662227,
                                  0,
                                  -0.027486950373574248,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17529865856947066,
                                  0,
                                  -0.55257827025772877,
                                  0,
                                  0,
                                  0.48307953818202437,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36479145733891338,
                                  0,
                                  0,
                                  0.18376030595044718,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015302019591260606,
                                  0,
                                  0,
                                  0,
                                  0.095360605507075702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31268763802132432,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51954467089448975,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0095758506461740764,
                                  0,
                                  0,
                                  -0.38177268563652217,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.150795090195913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35924856792437326,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.066051396099958998,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070636033583972829,
                                  0,
                                  0,
                                  0.1257008631534281,
                                  0,
                                  0,
                                  0.32950490021272377,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.02756337508239708,
                                  -0.43685815068054917,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27243638553354721,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.84102117049119818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30166410159854185,
                                  0,
                                  0,
                                  -0.60568454827837426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36780798530952152,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0081110884788393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32587703457094169,
                                  -0.24541461708925943,
                                  -0.057896675297631581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39802685680361649,
                                  0,
                                  0.45657406387817662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36232385489630198,
                                  0,
                                  0.19168954056146942,
                                  0,
                                  0,
                                  0.49028286729473564,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1619467357082876,
                                  0,
                                  0,
                                  -0.1694433638345198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23020517909390423,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46191641347059137,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030638859308730917,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21544557660670852,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.05201694513736721,
                                  0,
                                  0,
                                  -0.2803966752875181,
                                  0,
                                  -0.37056859451859503,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.68383779141582002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.04788213275128924,
                                  0,
                                  -0.00015270356113201598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39709577116373712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.83191437540700885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094398964874777253,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.372866643708477,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.118240886367869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21485516929592768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39281279744803604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080308421082180698,
                                  0,
                                  0,
                                  -0.28529538998405984,
                                  0,
                                  0,
                                  -0.27024954971404169,
                                  0,
                                  0,
                                  0,
                                  -0.29532991872133307,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22058737642207993,
                                  -0.37894609060300583,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11249146399038097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17460955111674764,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54959550406765245,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46532862786229445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26196498425699172,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45099462665536416,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39891910143742665,
                                  0,
                                  0,
                                  0.14559278311116494,
                                  0,
                                  0,
                                  0.47976923666822624,
                                  0,
                                  0,
                                  0,
                                  0.19895811538343866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.00758971148827884,
                                  0.073893757559403542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049686318661900451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16868365827443255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15782935015210328,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33593051936775947,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38350799040920452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.034764651050055412,
                                  0,
                                  0,
                                  0,
                                  -0.68016854548562011,
                                  0,
                                  0,
                                  0.45135419567788349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4302766188462992,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34382597337376913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.64756099310347859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14046836558251763,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.031782306752206488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32869136271471899,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.016371044352496172,
                                  0,
                                  0,
                                  0.36108170145286866,
                                  0,
                                  0,
                                  0.31307763935718352,
                                  0,
                                  0,
                                  0,
                                  -0.62951573274636052,
                                  0,
                                  0,
                                  -0.01150558428642902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47812253604371391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.048446182569992099,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19869950933077121,
                                  0.24110018382930298,
                                  0,
                                  0,
                                  0.72823588246331794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10667658320911121,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.0159844631423209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23810334436083871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6077877510511539,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3869715749140461,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26429310627792235,
                                  -0.40229758114627495,
                                  0.46228801303378719,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0697017896240964,
                                  0,
                                  0,
                                  0,
                                  0.54463807000275677,
                                  0,
                                  0,
                                  0,
                                  0.12461354004863009,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.083221479904523096,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50473576980147783,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54862963122822928,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08530397340487364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12056678725511022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10623791869995311,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.041826694025520569,
                                  0.034855990809507777,
                                  -0.55264436759601832,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.096616227906704322,
                                  0,
                                  0,
                                  0,
                                  0.78782935432005197,
                                  0,
                                  0,
                                  0,
                                  -0.58133778824112659,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18693862193281136,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.9677302026038429,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24894505642146839,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14689690093405858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16967494583634479,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.84262104320904785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23205605605820601,
                                  -0.040295249944406621,
                                  0.34419564109276513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72448876074334134,
                                  0,
                                  0,
                                  0,
                                  0.020952614660549821,
                                  0,
                                  0,
                                  0,
                                  -0.025465943082302517,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.96923606138308249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4227950856620783,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54157583743967186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14274160737180619,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45992268883044646,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20564440004318951,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27267856189107714,
                                  0,
                                  0,
                                  0.48429369762196661,
                                  0,
                                  -0.22980074247380256,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26608190833543399,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3477049350567657,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19604982890520667,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29945541220372479,
                                  0,
                                  0,
                                  0,
                                  -0.70960021486379266,
                                  0,
                                  0,
                                  -0.43861548883055279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.68068630907197358,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0550541762898218,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25710806539029524,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13705797683925719,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44814083256955872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3000779891665758,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32048326391857895,
                                  0,
                                  0,
                                  -0.60727318211316061,
                                  0,
                                  0,
                                  -0.29114210518247441,
                                  0,
                                  0,
                                  0,
                                  0.54370501701415641,
                                  0,
                                  0,
                                  -0.40293719313754384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017242724948494548,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0405049280314295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50454166216174656,
                                  -0.30744207846965133,
                                  0,
                                  0,
                                  0.72282770739717472,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.0062245222642701,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56847317370854866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2836806119221692,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56239338959320184,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28820733753816791,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3741918402550749,
                                  0,
                                  0,
                                  -0.20352434444162038,
                                  0,
                                  -0.12463018927844266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0062762210582725242,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44854819578334354,
                                  0,
                                  0,
                                  0.78526385107452168,
                                  0,
                                  0,
                                  0.17425249129870338,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30678740356679157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20969231295878352,
                                  0,
                                  0,
                                  -0.52344277847570686,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.87173048025401356,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45432341244753088,
                                  -0.29068322887156939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26254048757510939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29526380732467356,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30382842102054536,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13626918925430304,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51880270638014381,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53855315533666093,
                                  0,
                                  0,
                                  0.29086826861459769,
                                  0,
                                  0.37064614154683501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14408199583372577,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37402372666882189,
                                  0,
                                  0,
                                  0,
                                  0.35314110979427765,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26541171505301914,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1032069001384578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1299556296042928,
                                  0,
                                  0,
                                  -0.0067254377996848191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23897824865143949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24864876088683513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26186413435464811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046879774658057566,
                                  0,
                                  0,
                                  -0.32432363051287133,
                                  0,
                                  0,
                                  -0.070941320890566845,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5528208523068866,
                                  0.17841563200175153,
                                  0,
                                  0,
                                  -0.36168429138037367,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14909785534736228,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49308784600775268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30955474307915976,
                                  0,
                                  0,
                                  0.50806175363335371,
                                  0,
                                  0,
                                  -0.21738186821897598,
                                  0,
                                  0,
                                  0,
                                  0.098876091834501578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18215673035922092,
                                  0.22172699909705279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28297968513652338,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.139264408466796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10497819856984547,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021736991192616184,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55598866946831205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17886001936309276,
                                  0,
                                  0,
                                  0.83315202030664515,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37948499180773887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.84893755109884572,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13556330782094886,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18483177637267634,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32039137939218948,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67297981742385204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.014187074118328188,
                                  -0.043362696361419158,
                                  0.28313637147567511,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.85465470040300018,
                                  0,
                                  0,
                                  0,
                                  0.15853100439888118,
                                  0,
                                  0,
                                  0,
                                  -0.1985480424493013,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.8183623071072299,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25672000498771597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.69352954346597062,
                                  0,
                                  0,
                                  0.38238025364582479,
                                  0,
                                  0,
                                  0.26011966935825814,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5837401707756853,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.80819526674483411,
                                  0,
                                  0,
                                  0.34854947599870206,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14092966754446007,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052665988458530107,
                                  -0.77178408741738203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39861577345497745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070384837476743234,
                                  0,
                                  0,
                                  -0.23362206465900076,
                                  0,
                                  0,
                                  0.205665273974944,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56062340149718048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.77593800129588064,
                                  0,
                                  0,
                                  0.24971038049872146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3900551558793639,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23291360467373967,
                                  -0.011041784518804672,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61453077941228762,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23366698178072337,
                                  0,
                                  0,
                                  0,
                                  0.061287039578077324,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085386612757515953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24699404709462844,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33800815350389851,
                                  0,
                                  0,
                                  0.04854398080815818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0022139912390362008,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27295677446099409,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18351362997161658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68450487090262702,
                                  0,
                                  0,
                                  0.13421012390487033,
                                  0,
                                  0,
                                  0.11853467834567075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38130005107316867,
                                  0.050533633606012235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087305990353228002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35076812463947754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19495745974178655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55846882426940925,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06307489715944406,
                                  0.33168123864937726,
                                  0.18554864920867767,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.034407289013874576,
                                  0,
                                  0,
                                  0,
                                  0.37564935640540886,
                                  0,
                                  0,
                                  0,
                                  -0.91353084674575746,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55985188174812128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53451487321077007,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5838309203627603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.77611126044595857,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16231225655560572,
                                  0,
                                  0,
                                  0,
                                  -0.21265591136470177,
                                  0,
                                  0,
                                  -0.0046125599188232558,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.75175869024285535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24178665214865167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35640093726465227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15143154027092903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1600550100566614,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42667637723322765,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72092597876052034,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16161871535552516,
                                  0,
                                  0,
                                  0.2927363915929091,
                                  0,
                                  0.34279487092411753,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14261962339860723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18230052312432238,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13182257314895279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1931275114396396,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19939381709225873,
                                  0,
                                  0,
                                  0.28720405748537009,
                                  0,
                                  0,
                                  0.39923340218857273,
                                  0,
                                  0,
                                  0,
                                  -0.58870365053322471,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072344252007741777,
                                  -0.10251409746493816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29829615429594253,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20362499892354929,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37108107397879564,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56799639380943601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.96110106968588349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.082354926502062,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0076432486784695705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063434434735986173,
                                  0.30488576008009616,
                                  -0.19832845918732395,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25614340440823802,
                                  0,
                                  0,
                                  0,
                                  -0.54169812884476531,
                                  0,
                                  0,
                                  0,
                                  0.08857438239090501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44389535824045928,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21820778528404422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0076571519044163483,
                                  0,
                                  0,
                                  0,
                                  0.080845336238579826,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10145060531357207,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21321481119591851,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2720146482847835,
                                  0,
                                  0,
                                  -0.076276483094693218,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21392507847569919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10752340845242352,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20789755296130252,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070557884053062722,
                                  0,
                                  0,
                                  0.049045583054633191,
                                  0,
                                  0,
                                  -0.74579345736708436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28870770661134487,
                                  -0.33219275673272242,
                                  0,
                                  0.12762549985597182,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47995415362191823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11451961507017533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043086661101535806,
                                  0,
                                  0,
                                  -0.21958662509047217,
                                  0,
                                  0,
                                  -0.017224008125480028,
                                  0,
                                  0,
                                  0,
                                  -0.97639805545119029,
                                  0,
                                  0,
                                  0.46286820326325595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11634886047685564,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46126109061632625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2865463967581735,
                                  -0.42450636447133394,
                                  0,
                                  0,
                                  -0.27124586057184996,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22610559491519064,
                                  -0.46378964803655265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36886287929725498,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30301010824789187,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49577169972148799,
                                  0,
                                  0,
                                  0.03209800035462454,
                                  0,
                                  0,
                                  0.090483727343540502,
                                  0,
                                  0,
                                  0,
                                  0.18559509510977523,
                                  0,
                                  0,
                                  -0.34069769390907806,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17264079831905296,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53166634652549649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.91984486960358869,
                                  -0.23881211379946465,
                                  0,
                                  0,
                                  -0.025914176481517712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19763619836897492,
                                  0,
                                  0,
                                  -0.38243301456362855,
                                  0,
                                  0,
                                  0,
                                  -0.40506808011912038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37482380873694571,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10604601625559949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42718981879137846,
                                  0,
                                  0,
                                  -0.027514353261632672,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.03993341896489528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13154525053463972,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022509479632737424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17808080183805514,
                                  0,
                                  0,
                                  0.18320981281082399,
                                  0,
                                  0,
                                  0.012307145311445167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15905754889216714,
                                  0.49451302209918452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028841477193467732,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068176755962736785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.02447278196769901,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.57697236214316883,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23697572114968363,
                                  -0.429476930642534,
                                  -0.19675282848069842,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.13143704713936,
                                  0,
                                  0,
                                  0,
                                  0.16141823819613416,
                                  0,
                                  0,
                                  0,
                                  0.15313124927449279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37628594860751979,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40507216073346064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.099496121013977354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46473554577647164,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22681704630187854,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14260303124296725,
                                  0,
                                  0,
                                  0.51606709802799833,
                                  0,
                                  0,
                                  0.20375391734619297,
                                  0,
                                  0,
                                  0,
                                  0.0018421589955602558,
                                  0,
                                  0,
                                  0.044708004958572828,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037277427699747331,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62385393222261065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25678819022485955,
                                  0.054760396792568361,
                                  0,
                                  0,
                                  -0.24681784338281898,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.76424022981386253,
                                  0,
                                  0,
                                  0.25549890941744219,
                                  0,
                                  0,
                                  0,
                                  -0.059550507059307395,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.010327361737848782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36024963581847663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21936435213393596,
                                  0,
                                  0,
                                  -0.24478778621628117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.041905779373797289,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4302771805459597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47026623984679627,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2372855545528168,
                                  0,
                                  0,
                                  -0.4539498033812141,
                                  0,
                                  0,
                                  0.070470426366658498,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11674327433845519,
                                  -0.065046109429125892,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26288031249227867,
                                  -0.23580680772258375,
                                  -0.27674441028365143,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28943126315166784,
                                  0,
                                  -0.33227031926452599,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49675701569867614,
                                  0,
                                  0.066991435335768706,
                                  0,
                                  0,
                                  0.16677452695515205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40625841670262086,
                                  0,
                                  0,
                                  -0.40051538287766808,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40137248094994232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.6595547899107419,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.2547044068641311,
                                  0,
                                  0,
                                  0.56011898257538173,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41299115607848819,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52921865804977863,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16273138551212307,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26435884044688773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19128873443990418,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22603942344962469,
                                  0,
                                  0,
                                  -0.45224703355575308,
                                  0,
                                  0,
                                  -0.11754072352609818,
                                  0,
                                  0,
                                  0,
                                  -0.45902849085826153,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.069294807588871077,
                                  0.23732788862987747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09896998860556866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47214953011074123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30504230492592044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3453581794214593,
                                  -0.042222645533905367,
                                  -0.033054146646856387,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32645066669257577,
                                  0,
                                  0.11189337704159776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11136085415977162,
                                  0,
                                  0.48368144043698585,
                                  0,
                                  0,
                                  -0.058005680606423408,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.093636778333496207,
                                  0,
                                  0,
                                  0.70730527566870427,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29934775293074739,
                                  0,
                                  0,
                                  0.21730144964309384,
                                  0,
                                  0,
                                  -0.76860733349665822,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56342888597859786,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.69156342979530216,
                                  0,
                                  0,
                                  0.24147946361136446,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22995770048319042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26932090884693716,
                                  -0.024970293833688428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65390011730107922,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30805911397744096,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25694277630376561,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32012765532818088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47345795718111017,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43039846976791946,
                                  0.49809924312681009,
                                  0.034565336746362564,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19850529571932746,
                                  0,
                                  0,
                                  0,
                                  0.9963961643388396,
                                  0,
                                  0,
                                  0,
                                  0.62356701929749292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069275784668546753,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.71896553961751075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16666727456302863,
                                  0,
                                  -0.26801728666439129,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45998159749902368,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.081541721647148291,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.659998826221873,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49654625224405596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.084902309852142629,
                                  0,
                                  0,
                                  0,
                                  -0.16772931306615393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095849161208334047,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42817393460844316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.00073060647310226046,
                                  0,
                                  0,
                                  -0.08055446622960627,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.57523203583050364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17310242791670646,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10690413711400111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27616707868589851,
                                  0,
                                  0,
                                  -0.44220090761944586,
                                  0,
                                  0,
                                  0.25501735045045909,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094457911340434519,
                                  0.21816978548590776,
                                  0,
                                  0,
                                  0,
                                  0.1888444928416898,
                                  0,
                                  0,
                                  0,
                                  -0.07862311022296993,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3873458707991741,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3262209332342999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17543997852586157,
                                  0,
                                  0,
                                  0.61558571292921682,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053207013971046539,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48318105059551364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.095436993947093776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064471763869741877,
                                  0,
                                  0,
                                  0.20077937554249825,
                                  0,
                                  0,
                                  0.0082984864158486688,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.036313414353030586,
                                  -0.026733095717464815,
                                  0,
                                  0.059542790648292966,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10119789797009317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28192177870442681,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074812881229806782,
                                  0,
                                  0,
                                  0.76147120241322697,
                                  0,
                                  0,
                                  -0.10091233026675527,
                                  0,
                                  0,
                                  0,
                                  0.14252911498950199,
                                  0,
                                  0,
                                  -0.34614743500782014,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1318527489135192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082159247414755929,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37876378643439446,
                                  -0.91303151367243829,
                                  0,
                                  0,
                                  0.0014261753098101723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063246473707559009};

const double rot_15_30[900] = {-0.015480797493584116,
                               0,
                               0,
                               0,
                               0.4121238771143933,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.019592354438536658,
                               -0.04423723425638218,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.63500066028958679,
                               0,
                               0,
                               -0.36027978989885345,
                               0,
                               0,
                               0.54272101119847027,
                               0,
                               0.67752501040409185,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.48099184126477512,
                               0,
                               0,
                               -0.32712250928859937,
                               0,
                               0.21768306609393162,
                               -0.13379348483380574,
                               0,
                               0,
                               0.4904691621651292,
                               0,
                               -0.87040094850598226,
                               0,
                               0,
                               0.49113740320492127,
                               0.40775347280654656,
                               0,
                               0,
                               0,
                               -0.52193129030977137,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28219990262253164,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.67552507164391828,
                               0,
                               0,
                               0,
                               0,
                               0.43774058611909605,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.64635141173386035,
                               0,
                               1.4100868453935433,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.027166796128838044,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.71330827800465135,
                               0,
                               0,
                               0,
                               -0.42895275122529103,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.023252835189174745,
                               0.37325997940353756,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.36573898763112289,
                               0,
                               0,
                               0.1811539434591839,
                               0,
                               0,
                               0.02730151778524384,
                               0,
                               0,
                               0,
                               -0.57115928712918274,
                               0,
                               0.3166718261918709,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1319819222252494,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5045453431839334,
                               0,
                               -0.63988720032958735,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0382322751072686,
                               -0.21895577476461422,
                               0,
                               -0.58238818562141936,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.99881991892446664,
                               0,
                               0.04856716544870382,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.87494684738357853,
                               0,
                               0.26800865862012163,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40682190450494693,
                               0.79749494388229847,
                               0,
                               0.79438591547806103,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.048567165448704708,
                               0,
                               0.99881991892446675,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37722379589545696,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.66982846050106515,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.63253128093336342,
                               0,
                               0,
                               0,
                               0,
                               0.09453158177981813,
                               0,
                               0,
                               0,
                               0,
                               -0.36261194766839233,
                               0,
                               0,
                               0,
                               0.13444303655311735,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.087519288054130479,
                               -0.11671947758925835,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.028120462556985165,
                               0,
                               0,
                               -0.71635187755790408,
                               0,
                               0,
                               -0.56143014721793238,
                               0.34719640065058865,
                               0,
                               0,
                               0,
                               -0.0086520311680266665,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.59156236000820528,
                               0.66595205448544526,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.071941659791501023,
                               0,
                               0,
                               -0.21951510484434242,
                               0,
                               0,
                               -0.1804969623337207,
                               0,
                               -0.50572494325326023,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58474400197330045,
                               0,
                               0,
                               0.79309591693354942,
                               0,
                               -0.81431135134836152,
                               -0.13717163374956376,
                               0,
                               0,
                               -0.028220873320474321,
                               0,
                               0.030003238206854771,
                               0,
                               0,
                               0.019312265456238008,
                               0.55683249083372965,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.76735927640654256,
                               0,
                               0.10013891895318877,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44994088531929316,
                               -0.85637121781243242,
                               0,
                               0.53938821246470692,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.60559285041744815,
                               0,
                               -0.56642314540670968,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.7413609791005118,
                               0.26278276686067492,
                               0,
                               -0.047897252314067329,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25364348112702895,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.040699027182569292,
                               0,
                               0,
                               0.92771124082564005,
                               0,
                               0.80891471776821444,
                               0.69563555555043477,
                               0,
                               0,
                               0.57706097745431895,
                               0,
                               -0.1585886343367619,
                               0,
                               0,
                               0.19980006117469701,
                               -0.18627550902880288,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.72904753197377503,
                               0,
                               1.2561235774678732,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.71592812655883709,
                               0.32220312047304861,
                               0,
                               -0.54027721241891591,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.91308522563368633,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.11144458584350166,
                               0,
                               0,
                               0.29320948424734594,
                               0,
                               -0.6521938244568587,
                               -0.053952327401098121,
                               0,
                               0,
                               0.30888333768338516,
                               0,
                               0.78274954063356916,
                               0,
                               0,
                               0.060945625794710787,
                               -0.52145695229539424,
                               0,
                               0,
                               0.6373049922676931,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.99603794146286972,
                               0,
                               0,
                               0.61796820388303442,
                               0,
                               0.081863386595550272,
                               -0.39915618367691341,
                               0,
                               0,
                               -0.10790343534352928,
                               0,
                               -0.18550973885974556,
                               0,
                               0,
                               0.5459263884709894,
                               0.14440042206345571,
                               0,
                               0,
                               0,
                               -0.74954944026240455,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42303186034025397,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.076199021786327911,
                               0,
                               0,
                               0,
                               0,
                               -0.50340181844942355,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1033719972227756,
                               0,
                               1.2696498086918087,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.09366752510072282,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.59303650333878888,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15359533593556404,
                               0,
                               0,
                               0.40970478567834911,
                               0,
                               -0.072897657141325678,
                               -1.0250081859115514,
                               0,
                               0,
                               0.32306388751532289,
                               0,
                               -0.041386653387154054,
                               0,
                               0,
                               0.15907429185062458,
                               -0.65097733882324715,
                               0,
                               -0.26114750828977185,
                               0,
                               0,
                               0,
                               -0.23923096468266603,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.59345176521628129,
                               -0.31726222826741796,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40863487080707972,
                               0,
                               0,
                               -0.25763329534882168,
                               0,
                               0,
                               0.43401939221157482,
                               0,
                               0.3651393422493322,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37963140626551223,
                               0,
                               0,
                               0.13531628795098272,
                               0,
                               0.10916778599331983,
                               -0.1180812057621223,
                               0,
                               0,
                               -1.2047355732465976,
                               0,
                               -0.058163659253626432,
                               0,
                               0,
                               0.90794447223750208,
                               -0.30272922767293187,
                               0,
                               0,
                               0,
                               0.15318476624036709,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54105184002983564,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37116541501072614,
                               0,
                               0,
                               0,
                               0,
                               -0.73894084234945989,
                               0,
                               0,
                               0,
                               0,
                               0.16336316254552818,
                               0,
                               0,
                               0,
                               -0.37222997755692655,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.53469232426906799,
                               0.37475267849347166,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28008835834793344,
                               0,
                               0,
                               -0.43306799387165446,
                               0,
                               0,
                               0.3773916976600632,
                               0,
                               -0.28451159031612794,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.47419612108927361,
                               0,
                               0,
                               -0.23596191622264895,
                               0,
                               -0.37244813559306011,
                               0.48051552657510166,
                               0,
                               0,
                               0.040388850410393085,
                               0,
                               0.15846818080531602,
                               0,
                               0,
                               0.99054086902914484,
                               0.18532768727578261,
                               0,
                               0,
                               -0.099275916072568221,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25415585724842582,
                               0,
                               0,
                               0.55324601986391975,
                               0,
                               -0.65371378081002418,
                               0.63563947254959241,
                               0,
                               0,
                               -0.15913419894453201,
                               0,
                               -1.0257496227244038,
                               0,
                               0,
                               0.022102325965628056,
                               -0.81178589172389271,
                               0,
                               -0.37951724105708229,
                               0,
                               0,
                               0,
                               0.65743216285215977,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.058214383726552174,
                               0.40063647866324115,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46001178833679501,
                               0,
                               0,
                               0.14870112923497128,
                               0,
                               0,
                               0.16164232501122328};

const double rot_15_2[4] = {-0.62030278248056381, 0.78436245323630227, 0.78436245323630205, 0.6203027824805637};

const double rot_16_50[2500] = {0.090797604497200465,
                                0,
                                0.23770427897534965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.2587212106539523,
                                0,
                                0,
                                0.37511583241736685,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59311640460682047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1851976825870394,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61566406456663003,
                                0,
                                0.22441856443538855,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1552976110666773,
                                0,
                                0,
                                0,
                                0,
                                -0.029311818484401869,
                                0,
                                0,
                                -0.34794282479610372,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65157756829489144,
                                0,
                                0,
                                0,
                                0,
                                -0.30834318031775182,
                                0,
                                -0.69492689973348187,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5198835487178034,
                                0,
                                0,
                                -0.49851111606463339,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31431491687951474,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2595481445818273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29696158046030907,
                                0,
                                -0.23264468609695232,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75172041595368932,
                                0,
                                0,
                                0,
                                0,
                                0.33335978728457061,
                                0,
                                0,
                                -0.094881691188736045,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41530158065979939,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59652434742322868,
                                0,
                                0,
                                0,
                                -0.14726289417518618,
                                0.50688044770013507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35626375370939256,
                                0,
                                0,
                                0.55625606106839509,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.8452639606429373,
                                0,
                                0,
                                -0.5718656969568241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64792713770391708,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69437445206386517,
                                0,
                                1.3439794562176257,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51873728746237835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16680444478537942,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11213061345884048,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.99284826167226348,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.040976271422718341,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0304044633437468,
                                0,
                                -0.97157002360601918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30974398334613368,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.93638086065108561,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61519486488254371,
                                0,
                                0,
                                0,
                                -0.7612908321774452,
                                0.23006465262059816,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21849655526334666,
                                0,
                                0,
                                0.69017471936727059,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55742898956184972,
                                0,
                                0,
                                -0.69789477158443258,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71778940137934799,
                                0,
                                0,
                                0,
                                0,
                                0.13757294671558803,
                                0,
                                0,
                                0,
                                -0.59223121753766539,
                                0.56899810158886455,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.058665885585183909,
                                0,
                                0,
                                -0.70269274385563596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44449667302146861,
                                0,
                                0,
                                -0.68484422497368047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50158292073512978,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30671061040021186,
                                0,
                                -0.30952656035051207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28012655094529981,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41486851725400359,
                                0,
                                0,
                                0,
                                0,
                                -0.68883679331222958,
                                0,
                                0,
                                0,
                                0,
                                -0.044743720678960819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25894530290815709,
                                0,
                                0.12642919161884614,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16610728876866604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67572971829229678,
                                0,
                                0,
                                0,
                                0.68317135065723444,
                                0.15900585759681912,
                                0,
                                0,
                                -0.1542457757139748,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.055468197739188013,
                                0,
                                -0.61112695387501736,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.043734815843124483,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37505193142767462,
                                0,
                                0,
                                0,
                                0,
                                0.15637442466767199,
                                0,
                                0,
                                0,
                                0,
                                0.48161988723544796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30600625538548604,
                                0,
                                0.36169038568459311,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39243689869965293,
                                0,
                                -0.10076581846141464,
                                -0.41748347131090258,
                                0,
                                0,
                                0.12437935577940495,
                                0.10277137496769749,
                                -0.19494945830587174,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12391629903862358,
                                0,
                                0,
                                0,
                                -0.17782786695306266,
                                0,
                                0,
                                0,
                                0.077743852187767054,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1001361628958852,
                                0,
                                0.75926290662589435,
                                0,
                                0.37854203841126255,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12683957741361046,
                                0,
                                0,
                                -0.25874228498679347,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1338411157814969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.067375159307046406,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.034496162165596853,
                                0,
                                -0.026160739293467388,
                                0.647349801043412,
                                0,
                                0,
                                0.61029156411555374,
                                0.35752223719395182,
                                0.43456552329719722,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47894871124394045,
                                0,
                                0,
                                0,
                                -0.18337735219564819,
                                0,
                                0,
                                0,
                                0.49799289193946161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23084778140854179,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26383756617807302,
                                0,
                                -0.46931439554939902,
                                0.99934744480785254,
                                0,
                                0,
                                0.50855250090437465,
                                -0.41508146743513469,
                                -0.76335526686456934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63553394223400506,
                                0,
                                0,
                                0,
                                -0.36613517783199334,
                                0,
                                0,
                                0,
                                -0.0049908765614389283,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22988330405041402,
                                0,
                                -0.10751969633505809,
                                0,
                                -0.85926045186445466,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67845227233318472,
                                0,
                                0,
                                -1.0376345406035004,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0070457793726860229,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60312258202708691,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0073947854297669036,
                                0,
                                0.45058464142867916,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2458633583164756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46677358595335638,
                                0,
                                0,
                                0,
                                0,
                                0.23607791957604674,
                                0,
                                0,
                                0,
                                0,
                                0.63023630025135691,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15232689100836019,
                                0,
                                0.20605428061674419,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31135307503671633,
                                0,
                                -0.23270394867465524,
                                -0.22657075035657656,
                                0,
                                0,
                                -0.38093497172459101,
                                -0.48971193969294669,
                                -0.78651499288575355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34529213439137141,
                                0,
                                0,
                                0,
                                0.053820836471850181,
                                0,
                                0,
                                0,
                                1.1527664394179491,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29028324535316674,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25167971912380199,
                                0,
                                0.2842566952973421,
                                0.32826061699808029,
                                0,
                                0,
                                -1.0004544545540901,
                                -0.16317099612327368,
                                0.10592265128216705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15103402817102918,
                                0,
                                0,
                                0,
                                -0.34504613885075952,
                                0,
                                0,
                                0,
                                0.12756924973896047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18617433164504721,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70187176121398986,
                                0,
                                -0.59892785228209855,
                                -0.0081566563538367776,
                                0,
                                0,
                                -0.15614977153640955,
                                0.057758606579212737,
                                0.83664755109558386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32806364497887069,
                                0,
                                0,
                                0,
                                -0.1767682474766909,
                                0,
                                0,
                                0,
                                -0.24727545970948855,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47604282865211822,
                                0,
                                0,
                                -0.37154802608944038,
                                0,
                                0.0041739855365645062,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3616738383661201,
                                0,
                                0,
                                0,
                                0,
                                -0.68107674002490071,
                                0,
                                0,
                                -0.51523589196448827,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.042345325880318307,
                                0,
                                0,
                                0,
                                0,
                                0.77758876000027621,
                                0,
                                0.87852057940157413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14753480204546715,
                                0,
                                0,
                                -0.6546353788743704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74065484700193041,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.051017296354642715,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58579156031073287,
                                0,
                                0.27397110556046944,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60405378505128082,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2802834222785675,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10852210341553273,
                                0,
                                0,
                                0,
                                -0.40684869750285113,
                                0.48641263162950077,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2362739499775133,
                                0,
                                0,
                                0.46770624775494346,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31786458091965852,
                                0,
                                0,
                                -0.12213488844809259,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22653688378737563,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3336068718070534,
                                0,
                                -0.10743929892859964,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.025768837460155434,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.050154795036511525,
                                0,
                                0,
                                0,
                                0,
                                -0.30637304049745279,
                                0,
                                0,
                                0,
                                0,
                                0.47737844400167495,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.051359175510817048,
                                0,
                                -0.74134427362014199,
                                0,
                                0,
                                0,
                                0,
                                -0.44576800611608014,
                                0,
                                -0.26775330447535001,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42279917722033294,
                                0,
                                0,
                                0,
                                0,
                                0.13982474388634325,
                                0,
                                0,
                                0.38012678757857288,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62192650270747496,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.01105186209158282,
                                0,
                                0,
                                0,
                                -0.77093419107752204,
                                -0.29315667502294451,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12242864260429473,
                                0,
                                0,
                                -0.24417732746784096,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1785257063907866,
                                0,
                                0,
                                0.040848207816539549,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38699648220431326,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3656773957744931,
                                0,
                                0.75775171939440666,
                                0.26838687133884903,
                                0,
                                0,
                                0.40309330447292074,
                                -0.87385813817513691,
                                0.3006952101313467,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.02395522724454107,
                                0,
                                0,
                                0,
                                0.36920399357240968,
                                0,
                                0,
                                0,
                                -0.11117493547457878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.04180650338043073,
                                0,
                                0,
                                0.034534560889556087,
                                0,
                                -0.83398456297593604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31636612455620733,
                                0,
                                0,
                                0,
                                0,
                                0.11914716520618379,
                                0,
                                0,
                                -0.42034823381089093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11090943787920962,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.016010386550628364,
                                0,
                                0.33611549192264045,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17058823103739235,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20554403137015995,
                                0,
                                0,
                                0,
                                0,
                                -0.046173005384224003,
                                0,
                                0,
                                0,
                                0,
                                -0.15694976379112946,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.87048459052228666,
                                0,
                                -0.17582022948079698,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.95314675907605761,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1191229948910803,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27806648081167074,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22800956086238133,
                                0,
                                -0.39261049664976855,
                                -0.055467450426655962,
                                0,
                                0,
                                -0.19669465081360138,
                                -0.50998286632953327,
                                -0.041033061781098473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0590586488727074,
                                0,
                                0,
                                0,
                                -0.043946566264112016,
                                0,
                                0,
                                0,
                                -0.65058547295126923,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.066006506007931426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2683473884516494,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10741526073496616,
                                0,
                                0,
                                0,
                                0.0043662242158552765,
                                -0.19176650315211857,
                                0,
                                0,
                                -0.93790094638363819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.98539729804590559,
                                0,
                                -0.77412129065704038,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36414344211073668,
                                0,
                                0,
                                0.29735094825587877,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.010706675046718434,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.086111005526005258,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36990943234980184,
                                0,
                                0.023266691705136039,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.77858996611823306,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32221083804423556,
                                0,
                                0,
                                0,
                                0,
                                -0.26653090967986298,
                                0,
                                0,
                                0,
                                0,
                                0.072390015759218163,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.038102847439767072,
                                0,
                                0.27362866487846921,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.026033954892751055,
                                0,
                                -0.15148780512995952,
                                0.25238991842694281,
                                0,
                                0,
                                -0.15905512450604953,
                                0.17008015552597483,
                                -0.34384288054664763,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15792403527320259,
                                0,
                                0,
                                0,
                                0.97507455610296045,
                                0,
                                0,
                                0,
                                0.035238346670536089,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24193960971305883,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36501731705218404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46760772688052932,
                                0,
                                0,
                                0,
                                0.1494348476874808,
                                0.76367661572756673,
                                0,
                                0,
                                -0.206331347354587,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46322499692415886,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49198141040318227,
                                0,
                                0,
                                0,
                                0.68545409950184566,
                                -0.15358605354770752,
                                0,
                                0,
                                0.22347459737979855,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2086952887079128,
                                0,
                                0,
                                0,
                                -0.78641953139282028,
                                -0.44173818680883137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12226969723883387,
                                0,
                                0,
                                0.53109170851155663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35274134837929288,
                                0,
                                0,
                                0.75924953582455823,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24760626280085446,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28095903827453528,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0078766352298315495,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.95968743736140694,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74335927263049661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26673697748376035,
                                0,
                                0,
                                0,
                                0.20268138913082226,
                                -0.57545816204589517,
                                0,
                                0,
                                -0.063533730189936383,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18574937669573294,
                                0,
                                0,
                                0,
                                0.05276760117386195,
                                0.81819887962308691,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29964328773896043,
                                0,
                                0,
                                -0.29501089811101572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.014182705680990421,
                                0,
                                0,
                                0.72441098586749886,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.073471525438524588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65539289535952439,
                                0,
                                -0.29849710693721426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31029219324181884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38223513259789688,
                                0,
                                0,
                                0,
                                0,
                                0.29231123104762896,
                                0,
                                0,
                                0,
                                0,
                                -0.33327976599003356,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20433682853605512,
                                0,
                                -0.026455441260649953,
                                0,
                                0,
                                0,
                                0,
                                0.44138633017835172,
                                0,
                                -0.35815255474827912,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.033829481994396823,
                                0,
                                0,
                                0,
                                0,
                                -0.62481960415485172,
                                0,
                                0,
                                0.53223699484242071,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.045658129526318286,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47420932596529786,
                                0,
                                0.33694502064306531,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35625781717273003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41791770546092888,
                                0,
                                0,
                                0,
                                0,
                                -0.43913228006672861,
                                0,
                                0,
                                0,
                                0,
                                -0.001834549823891668,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11188148335353575,
                                0,
                                0.3932692921013875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6782924998932971,
                                0,
                                0.7154867476983553,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0847258149139909,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.94520145603445682,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6804515737082516,
                                0,
                                0.36570659566569536,
                                -0.2086942345998945,
                                0,
                                0,
                                0.0021428633972130906,
                                0.61466083810703709,
                                -0.33641088913452044,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56863813343335312,
                                0,
                                0,
                                0,
                                -0.27750091900962737,
                                0,
                                0,
                                0,
                                -0.64776417210763026,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62690891873206778,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7686007052103877,
                                0,
                                0,
                                0,
                                -0.57182089658036195,
                                0.049401576377641254,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26079563657045335,
                                0,
                                0,
                                0.49288454491831241,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.266059720109241,
                                0,
                                0,
                                0.91794526877886007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70434487491128572};

const double rot_16_20[400] = {1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.95294258632042017,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31399941198638848,
                               0,
                               0,
                               0,
                               0,
                               0.58903358180867726,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.76795466694934322,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63832676727891202,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.052769003079232935,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.53203381769993074,
                               -0.04088113155759196,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51714622778641106,
                               0,
                               0.66919991705953852,
                               0,
                               0,
                               0,
                               0,
                               -0.24289632183475918,
                               0.83763938208051636,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.30810899295745581,
                               0,
                               -0.38004011746874672,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.4212253574830398,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.98865611766818529,
                               0,
                               0,
                               0,
                               0,
                               0.9128123764857341,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.58296230863680709,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.662457702309866,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.47043037673940341,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19825597256620972,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.6502454132920217,
                               0,
                               0,
                               0,
                               0,
                               -0.23132697390212975,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26533106908081339,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39203154315129674,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.88085793006298529,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.79303778564453697,
                               -0.32331452129629124,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28069604749566052,
                               0,
                               -0.43332265089569633,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17038915517952416,
                               0.4383568397884211,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.74755491869516955,
                               0,
                               0.46901221769008794};

const double rot_16_10[100] = {-0.43421825269724679,
                               0,
                               -0.74600765239851408,
                               0.48738590911278667,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13184106790264916,
                               0,
                               -0.3941773490497319,
                               0,
                               0,
                               0,
                               0.17668771408566078,
                               0,
                               0,
                               0.90189005382436149,
                               0,
                               -0.31729449674900134,
                               0,
                               -0.32013000493717914,
                               -0.59193822674775398,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.66816922855399941,
                               -0.73438965263097922,
                               0,
                               0.58388868175915065,
                               0.29036193978534441,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.188243962310079,
                               0,
                               0,
                               0,
                               0,
                               -1.2505487099082957,
                               0,
                               -0.48563196583606894,
                               0.16412165886619889,
                               0,
                               0,
                               0,
                               -0.042915364929714345,
                               0,
                               0,
                               0,
                               -0.983813486659323,
                               0,
                               0,
                               0.17398073146235299,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.3306980540909588,
                               0,
                               -0.92141553899407369,
                               -0.73851305250913568,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28275837277063065,
                               0,
                               0.45409052882206302,
                               -1.231763194999026,
                               0,
                               0,
                               0,
                               0.91803185617334393,
                               0,
                               0,
                               0,
                               0.029874322727211383,
                               0,
                               0,
                               0.39537960985932891,
                               0,
                               0.41406587575637771,
                               0,
                               0.0079605160222132321,
                               0.57249808317331607,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.70762421205159742};

const double rot_16_100[10000] = {0.26823984239320675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40473724537166578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16782425869209089,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47687760720099215,
                                  0,
                                  0,
                                  0,
                                  0.55317685594970523,
                                  0,
                                  0,
                                  -0.45671030054982426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052087416115615709,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36797894255007951,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33495530646940219,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14319469099186488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55484561131586141,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14416643081807798,
                                  0,
                                  0.58150307976755011,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22394523734639021,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3670726573468574,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56897563484174918,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7425813888262367,
                                  0,
                                  0,
                                  0,
                                  -0.26389550367451819,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022639151721971559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38524217150568291,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17859972353362769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17804474225432354,
                                  0,
                                  -0.11775463687012282,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15980908957272097,
                                  0,
                                  0,
                                  0,
                                  0.4335088163594748,
                                  0,
                                  0,
                                  -0.10725835961002171,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14095624492750364,
                                  0,
                                  -0.23268792653996132,
                                  0,
                                  0,
                                  0,
                                  -0.26748993269360644,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0083406048448599057,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63038925647630517,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28933259760129731,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22685770440451991,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13914636409519199,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2948592824493329,
                                  -0.34878139125659319,
                                  0,
                                  0,
                                  -0.69789347479868169,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32865785757954041,
                                  0,
                                  0,
                                  0.48385638699463607,
                                  0,
                                  0.27958251171783977,
                                  0,
                                  -0.58786194372543665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28480615711175472,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12958174340598205,
                                  0,
                                  0,
                                  0,
                                  0.65024811564358465,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.96810485586090333,
                                  0.025837729949257898,
                                  0,
                                  0,
                                  0.50533195131509012,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47376265011954,
                                  0,
                                  0,
                                  -0.070536680578533739,
                                  0,
                                  0.44288333718830097,
                                  0,
                                  -0.36052489310791097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061019882590645655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037971317455908309,
                                  0,
                                  0,
                                  0,
                                  0.31562315550363895,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.271006478593137,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60251873718846927,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46903336019994829,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1283422368945055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22833094224626294,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37133354794426793,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24385822830631834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070485052975802043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14486295832843671,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2279889030896507,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060277505495203346,
                                  0,
                                  -0.084070931626603243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.73966839504132076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47588237341842826,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.0937328830697324,
                                  0,
                                  0,
                                  0.16273515174005274,
                                  0,
                                  0,
                                  0,
                                  0.044308878438088173,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31445991561948078,
                                  0.66266453771183476,
                                  -0.35565271104011709,
                                  0,
                                  0,
                                  0,
                                  -0.43217789497204606,
                                  -0.76204878289986144,
                                  0,
                                  0,
                                  0.48302958266911111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29154792113994482,
                                  0,
                                  0,
                                  0.39328860010722339,
                                  0,
                                  0.014757646012742161,
                                  0,
                                  -0.10775939717401037,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24963020285392512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40181685454259747,
                                  0,
                                  0,
                                  0,
                                  -0.24901292227678382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41754115544270176,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.041207030626790847,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024609734759855374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28645328103168011,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.83795033499894755,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19783700097525297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61297093555043425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1720182400335048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12624197283324459,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.66521490579334996,
                                  0,
                                  -0.51509420114453774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33314544547598995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0036462263583353152,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29490006667193763,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59570845098837044,
                                  0,
                                  0,
                                  0,
                                  -0.54507700389170877,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60921399157737754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.02379919730021389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17756520085711933,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60743909621365044,
                                  0,
                                  -0.3337692040298576,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.66048336093518401,
                                  0,
                                  0,
                                  0,
                                  -0.091174208813508642,
                                  0,
                                  0,
                                  -0.074671827867666615,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045293698443019184,
                                  0,
                                  0.11653228852291897,
                                  0,
                                  0,
                                  0,
                                  -0.037327688340354742,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087740469712045716,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.051308548369637656,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033826072543172027,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.034938777389833343,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.090769189490314692,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.77275278765201216,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31471245876135756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046572665132922658,
                                  0,
                                  0,
                                  0.1961363890435785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057600786843626017,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17289728820134495,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.086954013483800052,
                                  0.015722826269821848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18619035138181897,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43299460001813739,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046404789968415711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17861536249668652,
                                  0,
                                  -0.13111531051803471,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29993787045182646,
                                  0,
                                  0,
                                  0,
                                  0.57819921560034038,
                                  0,
                                  0,
                                  0.24684104216747008,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.018223170885928432,
                                  0,
                                  -0.32799217892933263,
                                  0,
                                  0,
                                  0,
                                  0.44876196580465322,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.089955446961452384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16689535702190675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15923627221381551,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10415485157698506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28652337159068186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50977392852649828,
                                  0.8688487375686279,
                                  0,
                                  0,
                                  0.72303343758996497,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33985697379048641,
                                  0,
                                  0,
                                  0.46446103188467036,
                                  0,
                                  0.74378388667277873,
                                  0,
                                  0.19235388825882743,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037198127200889664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053250965474569575,
                                  0,
                                  0,
                                  0,
                                  -0.21917438082943233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47468201431084622,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097876434306954585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21294975148978929,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.69510247391597058,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48402826167167418,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.047945645230693577,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11159272407199126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068263998697527237,
                                  0,
                                  -0.0069254107845665158,
                                  0,
                                  -0.25830942015646463,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28832658842851522,
                                  0,
                                  0,
                                  0.30203373905855468,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30824874832642196,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19881591005363816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43717723498337213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0065837598041471775,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14734999417022054,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62796051869309299,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.78970774679338529,
                                  -0.28040254826739475,
                                  0,
                                  0,
                                  -0.42177325735884991,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.016947667497274707,
                                  0,
                                  0,
                                  0.64656995109915094,
                                  0,
                                  -0.2698300349169756,
                                  0,
                                  0.25661146642137528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.77683141990603122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23816914392844873,
                                  0,
                                  0,
                                  0,
                                  0.59114882652784617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1554065872566581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13758670338084145,
                                  0,
                                  -0.038523311841327186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20907098204576052,
                                  0,
                                  0,
                                  0,
                                  0.12882211899678264,
                                  0,
                                  0,
                                  -0.46016984851520359,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13042631857500853,
                                  0,
                                  0.45099673347373176,
                                  0,
                                  0,
                                  0,
                                  0.10840434026006344,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017062283108734248,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033198728248700855,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13171308338087065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.023986765747105069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65718717674705085,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098268148191659951,
                                  0.45364274393317744,
                                  0,
                                  0,
                                  -0.15700520668601664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29776048204861194,
                                  0,
                                  0,
                                  -0.057728937467723222,
                                  0,
                                  -0.011265583137258148,
                                  0,
                                  -0.61695781867516697,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.69199091401484236,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049652163129683999,
                                  0,
                                  0,
                                  0,
                                  -0.48018678857995195,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42375613399111128,
                                  0,
                                  0,
                                  -0.33763095188028114,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28415216860238068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2235674486889884,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49631421337210913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06163279286938507,
                                  0,
                                  0,
                                  0.56386128119285683,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.087437270211718876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65779215698961413,
                                  -0.081246317875443008,
                                  0,
                                  0,
                                  0.15794866309907962,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16233042973816811,
                                  0,
                                  0,
                                  0.17178180968007672,
                                  0,
                                  -0.26672727375486505,
                                  0,
                                  0.035000474232389805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34631954337436877,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.78647603473883632,
                                  0,
                                  0,
                                  0,
                                  0.91368050189317851,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044100481426310276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046998540332236202,
                                  0,
                                  0.11395585187763278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15691326243350701,
                                  0,
                                  0,
                                  0,
                                  -0.42722130706988698,
                                  0,
                                  0,
                                  -0.17612240076888908,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30789342054446711,
                                  0,
                                  -0.44853165427415015,
                                  0,
                                  0,
                                  0,
                                  -0.019029349317677385,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57569010946938859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13363645142123606,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10446365431121676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13747634009476495,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26319215316883859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10739265810090906,
                                  0,
                                  0,
                                  0.049205788514630179,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3457925363687776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15377014947792428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65322800437077133,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24165191641145506,
                                  0,
                                  0,
                                  0.52169268117939405,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2925100721140465,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14640318709578842,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41716900800758605,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029655223490750317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064199146480806463,
                                  0,
                                  0.12925966372454439,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11093747339899565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29659354716532466,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42390283995987321,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40327842537258618,
                                  0,
                                  0,
                                  0,
                                  -0.0001078171319645869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.2611428608399042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19193448697767532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030601082307869332,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0030986365212738853,
                                  0,
                                  -0.29315268061106636,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18830923102713493,
                                  0,
                                  0,
                                  0,
                                  -0.25319674949284471,
                                  0,
                                  0,
                                  -0.23845354343162126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30002372447250036,
                                  0,
                                  -0.049021635679507229,
                                  0,
                                  0,
                                  0,
                                  0.5428420305574978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1465565230299877,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037038335052660527,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31979221854163276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43818109346648093,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22906595704462021,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20167631444218936,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0060295771777859157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36558217421118022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28670582063142519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070457426485453778,
                                  0,
                                  -0.6030619607393124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067836491031875709,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1424768039833276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47355146506375606,
                                  0,
                                  0,
                                  0.70476316514423587,
                                  0,
                                  0,
                                  0,
                                  -0.43323354609660847,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.80235312643746659,
                                  0.03923033639736994,
                                  0.11776797413528456,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49491750065979889,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086257270726725413,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65417013789105749,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5524731357601782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014606748530325384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11932249846410911,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68075039146515659,
                                  0,
                                  0,
                                  -0.17438542232711723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45094422320141647,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26966293419095244,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37616183773500544,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23778670525285445,
                                  0,
                                  0,
                                  -0.15301816959896164,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092978669026960559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62568454785288907,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.97573163319052103,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37634847813601163,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017846436217872963,
                                  0,
                                  -0.11146208550021379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37188379035480412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3326897121371285,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.192667895040584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17250182156779992,
                                  0,
                                  0,
                                  0,
                                  -0.018578662978173219,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021332414572032998,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18207985285859773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14712977321144549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35163778440950072,
                                  0,
                                  -0.70205602179337323,
                                  0,
                                  0.27812191877405845,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22602537810605833,
                                  0,
                                  0,
                                  0.070353531173768233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18648071796339336,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21409405406029824,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046538032363792545,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36550867802454323,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094493661908814572,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.055940965403021403,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.079057269785629131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22018553759821458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.87869380550871934,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32179239063322207,
                                  0,
                                  -0.22410936133548223,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55535934783198548,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5391125440014507,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063914639515039687,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019205850663313404,
                                  0,
                                  0,
                                  0,
                                  0.75496497917665606,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42068224481260236,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45474436824787057,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53678548206855814,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32799538647267934,
                                  0,
                                  -0.0578964248901363,
                                  0,
                                  -0.48642789608809944,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17682825852172249,
                                  0,
                                  0,
                                  -0.2868694613129153,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17929215346501004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22670498091656421,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14978738180220638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063339361998227664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36326924443050512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.093810738182906556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0007168308772268206,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46228145549449678,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63877121906071299,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.2838714024863853,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17881405324148048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59983306632238298,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.020733842209244714,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12327087106191395,
                                  0,
                                  -0.18819446227604344,
                                  0,
                                  -0.099799087510049761,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20306262894422453,
                                  0,
                                  0,
                                  0.42574636818033884,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14223627976741501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085250334953712537,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.634243660666436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34005213760033304,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21361031564483146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35422360468972935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.68861811763336445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030444594794897938,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27004196392291657,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59237421999219875,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.77862481359396507,
                                  0,
                                  -0.32031216268454932,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37629409723290019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44638669189337032,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33447410484888701,
                                  0,
                                  0,
                                  0.50557957215189664,
                                  0,
                                  0,
                                  0,
                                  -0.070447627330970528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23374577101359856,
                                  -0.29272541541179653,
                                  0.35968989417465957,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31134324802363117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20941641520972554,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37884897845949217,
                                  0,
                                  0,
                                  0.14780611367753879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20438625915911871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13389419716517853,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13345149187293323,
                                  0.41432062064726199,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51926691469997477,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41836174082282518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37459120700109733,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17788173325942405,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48683990410104122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34540623222210981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24326635815295566,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.6422946661136899,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34392658637909324,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.0013597270694614,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48147159850591881,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5208941986993092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35774683759839049,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.75136485839357148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3626571088563903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014455940497069738,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1966406833438108,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55240451255071688,
                                  0,
                                  -0.47579871514922156,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28925995654505782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52899463028429639,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16933901051936914,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55987530087472026,
                                  0,
                                  0,
                                  0,
                                  0.84082092761073357,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13111763100086657,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.71633143118800613,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022980579335530243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60720649833732121,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2130638327465755,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48522409797372645,
                                  0,
                                  0,
                                  0,
                                  0.011469652405846471,
                                  0,
                                  0,
                                  -0.64097515980440933,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33495411241951883,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38254565803274043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.418960528254402,
                                  0,
                                  0,
                                  -0.13462505303683131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45878602477952213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.71431206242725542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098625025564609906,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11782665151846103,
                                  0,
                                  0,
                                  -0.22836162479341376,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.099311553424496476,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16260286394543394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38917541904235942,
                                  0,
                                  -0.010131425941140066,
                                  0,
                                  -0.049703007299296761,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25912540090518976,
                                  0,
                                  0,
                                  0.28571763878193918,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29743088613091051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.006853857980059011,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22656009494196802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48067525433683544,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27778372843452409,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47190585998654622,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38125835088267773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17544592091911868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61822299201219555,
                                  0,
                                  0,
                                  -0.2561025252010195,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.039218349858567425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51232545135320295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11116918081823038,
                                  -0.12759218808617162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15016383936348665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24671775068187674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27832560245831761,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.74993130842722111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50182536990935545,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46103492256943279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1328424025263348,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40228821467647558,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21009581028113783,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27153082812065493,
                                  0,
                                  -0.17885272006132338,
                                  0,
                                  0.19030572570326965,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37953255273008585,
                                  0,
                                  0,
                                  0.24823109497772916,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51870095633809998,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12869010978854556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52614754948390552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.077864908751476655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17560387984451323,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094444815396632353,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082883337766405718,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38570804179955392,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26064606497540005,
                                  0,
                                  0,
                                  -0.22389132078182555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40329559896518308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37724973907995474,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28722355005449712,
                                  -0.40364778433848431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40913826554193578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092240102367371832,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32686640428714042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17695819550006645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19797792688016763,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0064083938390868678,
                                  0,
                                  0.027570155071171179,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20567912722100096,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58599364087779993,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41437110873278993,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63243721398487618,
                                  0,
                                  0,
                                  0,
                                  -0.19230846733913842,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20180371730711544,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55533978861431377,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18964418834296423,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11657468413823067,
                                  0,
                                  -0.16325881131410402,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.052781932856226815,
                                  0,
                                  0,
                                  0,
                                  0.14184602106970351,
                                  0,
                                  0,
                                  0.20990508677642175,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14044594759663245,
                                  0,
                                  0.58707410691913942,
                                  0,
                                  0,
                                  0,
                                  0.0027480950303938809,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57245833840662208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11321217893509675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19800852892304951,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20951476760369539,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26231208228336073,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12455733288506848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37373610315002587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33774977701867581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23042485352207723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.924482173957764,
                                  0,
                                  0.28245616188579881,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43298169840895784,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0010524600603344838,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083480023246444948,
                                  0,
                                  0,
                                  -0.052987583634164365,
                                  0,
                                  0,
                                  0,
                                  -0.0097745726282917056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36297040592464697,
                                  0.071135483679438838,
                                  -0.42901654667987477,
                                  0,
                                  0,
                                  -0.37676905771827707,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19302825002427046,
                                  0,
                                  -0.51564920280569526,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0377780661343061,
                                  0,
                                  0,
                                  0,
                                  -0.0055365199085841699,
                                  0,
                                  0,
                                  -0.0038267151254432891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46194022521988332,
                                  0,
                                  -0.060902705867952274,
                                  0,
                                  0,
                                  0,
                                  -0.29392671795104153,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12265740602069633,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28775084517932203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0083910593362291445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37613640430309914,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10263222177565913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085051202207793636,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.95341766924082583,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10081452014701552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.009379418427019847,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.052144537986854811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26606474245573014,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22982936239799664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11330021979858806,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35260562515690508,
                                  0,
                                  0,
                                  -0.086718261731877438,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4883549144647148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0069071483272896625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.011290065194799366,
                                  -0.41878824287217048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49205763659161794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38251893249248003,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22002315310325335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54490276984690289,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.90068400320648856,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24104662864751769,
                                  0,
                                  0.35237071353371691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23372547190407697,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61602808068285608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40363598851996457,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.05450899023442117,
                                  0,
                                  0,
                                  0,
                                  0.040698443058740874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.018845551588552424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044142777668978395,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.065109047579469267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098786587563775008,
                                  0,
                                  0.2651437025678654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16732108282960276,
                                  0,
                                  0,
                                  0,
                                  0.06323676680816491,
                                  0,
                                  0,
                                  0.21100457625453989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15025902827478271,
                                  0,
                                  0.17418841107051081,
                                  0,
                                  0,
                                  0,
                                  0.19875784847634359,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21972744657945412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17004935582810898,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48977058888270808,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.644077066823738,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12186542574685176,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12141318209208853,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.03112803076918641,
                                  0,
                                  -0.47137660471345488,
                                  0,
                                  -0.33378927874968961,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36089363324449497,
                                  0,
                                  0,
                                  -0.13232802420086434,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29579046016959276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36827089809420455,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079097578299481747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14167520161716679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47205824368239868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17504585840543155,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45589555490539629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2015805160055637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52813969296910179,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10078226062901718,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038012458809661587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6789631744157284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062770814418228335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49713183088260005,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.079890384446225565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23989139307042673,
                                  0,
                                  0,
                                  0,
                                  -0.69076021451070657,
                                  0,
                                  0,
                                  0.071382353002285015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33640592192404628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.78779862088656727,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57524871619455042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1153452849252814,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3100639632864311,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.076109531307300859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49044624915915297,
                                  0,
                                  0.14497334471247295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27935309101040051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29422177836011632,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19899340194810441,
                                  0,
                                  0,
                                  0.46567391946292619,
                                  0,
                                  0,
                                  0,
                                  0.62710970048887094,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.011214610050261167,
                                  -0.469867887214097,
                                  0.59915377491413857,
                                  0,
                                  0.13330767896677437,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62216393921889879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082693596675661465,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16240330193635977,
                                  0,
                                  0.56803541147936443,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.93334320960214667,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028768238584471924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12197188189844708,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30035211492385788,
                                  0,
                                  0,
                                  0,
                                  0.93577787653677036,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12909075800584177,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16326835631437625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14908237114645043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34806413190155439,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42885441961828963,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28600576618641549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44414490233091375,
                                  0,
                                  0.260659706790482,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18312895307937377,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.99261475280481082,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10310194070385226,
                                  0,
                                  0,
                                  0.068962690706526691,
                                  0,
                                  0,
                                  0,
                                  0.29890516761005187,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14287773960966099,
                                  0.44850980457910555,
                                  -0.21569113911726989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49428268507226097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2759516835877393,
                                  0,
                                  -0.25548992512954005,
                                  0,
                                  -0.53593812280125597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062148783967200742,
                                  0,
                                  0,
                                  0.16758316309740168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061571375784631857,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12346044153429903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10081331030011022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16940128363333851,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41497397810831915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25492528016831073,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26707973748073199,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46471607278261323,
                                  0,
                                  -0.11514931933501668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40308842292993574,
                                  0,
                                  0,
                                  0,
                                  -0.10142429765740822,
                                  0,
                                  0,
                                  -0.27768920376258693,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16041093341483773,
                                  0,
                                  0.099501819895056631,
                                  0,
                                  0,
                                  0,
                                  0.11103109390510854,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23084639307183452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55498598066975868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15126167195418536,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08393521433717066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10190519104542246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34222658248299453,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24743414229972061,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17327983721451057,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.66816380709444212,
                                  0,
                                  -0.94090546617586057,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72417642229696377,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46138799890047261,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43845131992403968,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49000955406354596,
                                  0,
                                  0,
                                  0,
                                  0.16275302336029662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27021305362684805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14428684152696974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11333064755833676,
                                  0,
                                  0,
                                  -0.13209439245865592,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.029944732364538078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057568670424903219,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34493878304336589,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.91689446217423198,
                                  0,
                                  0,
                                  0.074524317805118034,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.016257436347126814,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086383276500822476,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25911517724361866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30621824422645616,
                                  0,
                                  0,
                                  0.17724784931395168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65672336254410635,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21417244720563533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27634594422360942,
                                  0.47412365589391203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082121840597655232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12308984749342183,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.9282374102917148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08354898824557204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51831752323144964,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40147659974996625,
                                  0,
                                  0,
                                  0,
                                  -0.17112880337916364,
                                  0,
                                  0,
                                  0.1033270120382446,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7840247466989867,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.042297590437417903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32112768050044233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62849721935114988,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41412631437753727,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.080226848417283989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043462032781713233,
                                  0,
                                  0.62617719276124462,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29391739757685359,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025311797104902608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022533820512906269,
                                  0,
                                  0,
                                  0.39747362252197038,
                                  0,
                                  0,
                                  0,
                                  -0.14371635893427789,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22847909915174544,
                                  -0.41584854493172629,
                                  -0.28299688516755583,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56975686565834627,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.02793173092666304,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.2646501088184485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.065041965329027701,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37065198164310564,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1219018784210188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36281713760268469,
                                  0,
                                  0,
                                  0.88770688948737719,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17436096860275579,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094568702675824359,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053231424449702532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10782300287052086,
                                  0,
                                  0,
                                  0.050877797514600503,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15474909157621319,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60556995551826009,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.045528119570823852,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7618043730983618,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24379645507195569,
                                  0,
                                  0,
                                  0,
                                  0.86594592489721156,
                                  0,
                                  0,
                                  -0.062736584362419523,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30967118586692771,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22913794356422129,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20931965915549494,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14567489734386047,
                                  0,
                                  0.043620466030997895,
                                  0,
                                  -0.18804412963816097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38574051781451563,
                                  0,
                                  0,
                                  -0.23866841245574436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.284929757684108,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.71330519406341464,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097218186943268267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022232625588100498,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11382152184208971,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2811621162238907,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070877533876257892,
                                  0,
                                  0,
                                  0.16924015874802167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5881223214439284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48576638185425725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13090899334528128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017388066607221427,
                                  0,
                                  0,
                                  0.48087175202840066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36851071875905705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31370295826993061,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30100288015117305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20992318565682977,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074526924169972919,
                                  0,
                                  0,
                                  0,
                                  0.11460992302154149,
                                  0,
                                  0,
                                  0.98552400225067271,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38184471477228871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.71683691783982106,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27246067563392273,
                                  0.44427971659286802,
                                  0,
                                  0,
                                  -0.25589757621511378,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.93831821558629325,
                                  0,
                                  0,
                                  0.10709392445073433,
                                  0,
                                  -0.24413799734321029,
                                  0,
                                  0.34023192806732572,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44369204625859476,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15949628664881949,
                                  0,
                                  0,
                                  0,
                                  0.095932699234344943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1070505156492556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12726429545713974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11059960714803924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.9463364741259308,
                                  0,
                                  -0.3660144275124706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42843269501506753,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.012875092490705758,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17882849585007854,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51246382596165252,
                                  0,
                                  0,
                                  0,
                                  -0.28585075488812478,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068412178794725123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14014076095027078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12828499988250491,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14855946255679914,
                                  0,
                                  0.43025151382776938,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32316738700590231,
                                  0,
                                  0,
                                  0,
                                  0.24975868658424044,
                                  0,
                                  0,
                                  -0.4058364475899417,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26381126566687912,
                                  0,
                                  0.024090759772601743,
                                  0,
                                  0,
                                  0,
                                  -0.3354521658555028,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17589741421488814,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30503555559586087,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24054248208818807,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2643859138655506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10190585938407143,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13018685988836523,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29594397650976828,
                                  0,
                                  -0.07905889651090918,
                                  0,
                                  0.2710556579214401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53605695625019323,
                                  0,
                                  0,
                                  0.26092104352965345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025404747094227732,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37936207449106912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080484916053015665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21591670835089519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51246905843446067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0051814016903978053,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1200468749412377,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063070631787002868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14041053028384543,
                                  0,
                                  0,
                                  0.41469018738334967,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29923140097532569,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60135079682975068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21748093552144931,
                                  -0.23847946820408453,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11713126697372118,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46997384474640092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07857945406506528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13840115926023205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20817605568198497,
                                  0,
                                  0,
                                  0.01634836096742634,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027016474511591962,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.031469971136086961,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.86479695916426447,
                                  -0.29489063803450355,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30494830889526425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038959727823121945,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16750987215339647,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39591116430355655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.6596914327486002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33067765260887355,
                                  0,
                                  0,
                                  0,
                                  0.094453384745151622,
                                  0,
                                  0,
                                  -0.12898725032145697,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  1.1624972170724919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18113959268359048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081308118640780053,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17352609012715248,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.84085422253592512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34257973959145677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21033857051139948,
                                  0,
                                  0.26910766666797858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61062024021853112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13704117985823333,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20359463477540346,
                                  0,
                                  0,
                                  -0.14155928360362155,
                                  0,
                                  0,
                                  0,
                                  -0.65530892626115156,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32858334538003831,
                                  -0.15032610973970062,
                                  0.095529929526542379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17804296105951795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.89433147327251983,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.073245458125737392,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41609422030218263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35735604795894915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.82299723481966436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32142490406408808,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49679395186143033,
                                  0,
                                  0.36728945731555246,
                                  0,
                                  -0.19866139645105751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064986588642411344,
                                  0,
                                  0,
                                  0.38681274070030985,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42607449917195295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0026983130608675687,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.005998142530154349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37029730479806416,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.039010593248138575,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037972275368948406,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31071268065539104,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19412903224946698,
                                  0,
                                  -0.20272855041033666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12051887780121581,
                                  0,
                                  0,
                                  0,
                                  -0.021186824483034633,
                                  0,
                                  0,
                                  0.29515480607514577,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62504904792110627,
                                  0,
                                  -0.04789063031850864,
                                  0,
                                  0,
                                  0,
                                  -0.30740020322805506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20278758999830149,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10060684181737597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.034323672105277772,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073921837899149273,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42097605299108709,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26969553858555162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.75382636865277342,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20476410983642085,
                                  0,
                                  0,
                                  -0.092683176854667995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072629039599686043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29312992129364013,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087885762873267909,
                                  -0.16001922302407581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3834245030746678,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19221621596513494,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3994910507308625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39358795628781013,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19100952926364073,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50767122201763082,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3166236387981104,
                                  0,
                                  -0.23854871507959596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25904055894444078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058008039191109848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14618543828316982,
                                  0,
                                  0,
                                  -0.89814272520129368,
                                  0,
                                  0,
                                  0,
                                  -0.12873495695703338,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.62594977177019739,
                                  -0.39117182701156816,
                                  -0.029828990287016171,
                                  0,
                                  0,
                                  0,
                                  0.23172975503575199,
                                  0.14547188244477052,
                                  0,
                                  0,
                                  -0.001934524180281505,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028244120457138283,
                                  0,
                                  0,
                                  -0.70298323918172589,
                                  0,
                                  -0.11771834383248406,
                                  0,
                                  0.055167284697577257,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45358611051070419,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.86011584468011637,
                                  0,
                                  0,
                                  0,
                                  0.51396958830874562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39000803029830389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19864167488219261,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34345704589523174,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.694108002268774,
                                  0,
                                  0,
                                  0,
                                  -0.21387930703940111,
                                  0,
                                  0,
                                  -0.17379474109190723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61271923495835312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046461618014579653,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43363064726245532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13809616563099847,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.64833948082489545,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097621469898129434,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38248808106684024,
                                  0,
                                  -0.58078322698808871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41309292604383085,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54548988423931344,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30418590672781776,
                                  0,
                                  0,
                                  0.080816313581477672,
                                  0,
                                  0,
                                  0,
                                  0.074060915379209044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29092714267584391,
                                  -0.29091452353682801,
                                  -0.77592503514758726,
                                  0,
                                  0,
                                  -0.72771051420043953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45792787863389106,
                                  0,
                                  0.21666089317074044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098249523900367869,
                                  0,
                                  0,
                                  0,
                                  0.19755384338188953,
                                  0,
                                  0,
                                  -0.15498847788131076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13573973026706862,
                                  0,
                                  -0.071490007107631204,
                                  0,
                                  0,
                                  0,
                                  0.2683365251719495,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11039982763257539,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.042253695276812095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.066042419969507674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12815355896702485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10390662037189366,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.055833292925857328,
                                  0.26535894623122885,
                                  0,
                                  0,
                                  0.25670695020935053,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24160374531943193,
                                  0,
                                  0,
                                  0.40938984390875244,
                                  0,
                                  -0.83773714277694478,
                                  0,
                                  -0.53442270038025352,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092115671499532592,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25438279755723803,
                                  0,
                                  0,
                                  0,
                                  0.18681093682544622,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.009255306180877422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.078640156573270781,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28475837389358283,
                                  0,
                                  0,
                                  -0.77730675670694349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15938190393103191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23006151661934249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019584501894152645,
                                  0.28153860381815293,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056209043551332813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38379558634213001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17844529164505601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28943852184386798,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16129358666766627,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34660042712917405,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37159552278802233,
                                  0,
                                  -0.14717667580153046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.041948744678509474,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.090969716740102999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46470322298247269,
                                  0,
                                  0,
                                  0.43600318554887213,
                                  0,
                                  0,
                                  0,
                                  -0.057138822910735437,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15747287021607467,
                                  -0.88152449973435465,
                                  -0.42505661097878672,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14298531516620622,
                                  0,
                                  0,
                                  0.030582164545053941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.093077701676696059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30852252321447227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19179999723605182,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12147639095973416,
                                  0,
                                  0,
                                  -0.30814532926296678,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.85338914249689501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10726008527591857,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49224041608631502,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27975052397446981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.66071543737428662,
                                  0,
                                  -0.11280502689595767,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25900918140899964,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28864665735653749,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.64622037837830693,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052768266364631312,
                                  0,
                                  0,
                                  0,
                                  0.080624896801824816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.71837766359664079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.94367803512218518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42850620326725541,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30166402987739555,
                                  0,
                                  0.075390205560435353,
                                  0,
                                  -0.15402194234205374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087200691505916139,
                                  0,
                                  0,
                                  0.42042523315393837,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32505710851995112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18913482724377045,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14650375333188276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52592586835771216,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10779798129090276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24596257348684258,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10646233481668221,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01557188351762003,
                                  0,
                                  0.32843112198773311,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14547363913009104,
                                  0,
                                  0,
                                  0,
                                  -0.26444041235286569,
                                  0,
                                  0,
                                  0.42521024928919138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12566967064398488,
                                  0,
                                  0.14534031194111971,
                                  0,
                                  0,
                                  0,
                                  0.04020951896984587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31996343290350077,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11955121470672994,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62755452991449123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16107683274274756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18354349660152816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47758781258119398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21329378111903893,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.011810217964009176,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7687240869223706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.042708302606649456,
                                  0,
                                  0.2533792665576251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42103018858491748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.076811077467628303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13948282144268392,
                                  0,
                                  0,
                                  -0.052492155651254931,
                                  0,
                                  0,
                                  0,
                                  0.52238398067234015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.64341803670169129,
                                  -0.31483912518139817,
                                  -0.015563040952912777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18755986094010496,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.76538883609776243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33084326599830305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34790445560635064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4364563238860143,
                                  0,
                                  0.44122360410396777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44239428279566018,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12592687815889259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29266638785696375,
                                  0,
                                  0,
                                  0.20568488322220613,
                                  0,
                                  0,
                                  0,
                                  0.031921608581455832,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50022930933073095,
                                  0.10230451489837872,
                                  0.05731609233805629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50305348006403949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31216227947966463,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4766563975116126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38825374295364123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.035810180119175153,
                                  0,
                                  0.17536623387026001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.05421649642080071,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55334059903561483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.70975411581203063,
                                  0,
                                  0,
                                  -0.14261933870658458,
                                  0,
                                  0,
                                  0,
                                  0.54377304477342547,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083564379945594999,
                                  -0.16224399758547176,
                                  0.041658971468111747};

const double rot_16_30[900] = {0.36626365620119999,
                               0,
                               0,
                               0,
                               0,
                               0.39493123100172023,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51669429398511069,
                               -0.90081280909189931,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.94473193976337999,
                               0,
                               0,
                               -0.53500173645439175,
                               0,
                               -0.43294581475444055,
                               0,
                               0,
                               0,
                               0,
                               -0.081909727879358504,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.06874342943555431,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34557399208161299,
                               0,
                               0,
                               0,
                               0.58956663925607133,
                               0,
                               -0.21882868810703637,
                               0,
                               0,
                               -0.099513889591798813,
                               0,
                               0,
                               0,
                               0.064649954592412212,
                               0.15796516148798731,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.65402444710123908,
                               0,
                               0,
                               0,
                               0.13185765222103574,
                               -0.29495973428353461,
                               -0.66409762953204399,
                               0.52794153298608704,
                               0,
                               0,
                               0,
                               0.38746402023669158,
                               0,
                               0,
                               0,
                               0,
                               -0.67755774212033748,
                               0,
                               0.32556125124600932,
                               0,
                               0,
                               0,
                               0,
                               -0.13812812208594444,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46339498362200249,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.045638502522180616,
                               0,
                               0,
                               0,
                               -0.41469639747581843,
                               0,
                               0.16448438780324354,
                               0,
                               0,
                               0,
                               0,
                               0.43632864372790886,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44395943592676429,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.5382512487647255,
                               0,
                               0,
                               0,
                               0,
                               -0.67971549916226437,
                               0,
                               0,
                               0,
                               0,
                               1.176115140816854,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41519016701517736,
                               -0.050329032991215605,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.56069946783000513,
                               0,
                               0,
                               0,
                               -0.29274303267640622,
                               0,
                               0,
                               0,
                               -0.18691706431973376,
                               -0.51373353489121587,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28451159895654088,
                               0,
                               0,
                               0,
                               1.0749580892112203,
                               0.18236084203558406,
                               -0.347577324076353,
                               0.012614263086289934,
                               0,
                               0,
                               0,
                               0.051759076879901611,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0741427414402069,
                               0,
                               0,
                               0,
                               0.41483911274292179,
                               -0.057983582458650394,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42896543916488944,
                               0,
                               0,
                               0,
                               0.16799228010382433,
                               -0.10819727549252374,
                               0.41648854189389944,
                               -0.45868917049727642,
                               0,
                               0,
                               0,
                               0.64221320826971251,
                               0,
                               0,
                               0,
                               0,
                               0.073937298726828027,
                               0,
                               0.43770051326226894,
                               0,
                               0,
                               0,
                               0,
                               -0.16481880912330815,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22994883344531802,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2524878333400648,
                               0,
                               0,
                               0,
                               0.19420398305176628,
                               0,
                               -0.78831753607623567,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.88314515224496093,
                               0,
                               0,
                               0,
                               -0.43764411700415462,
                               0,
                               0,
                               0,
                               -0.15671652126479013,
                               -0.062945999718324985,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.976063675547307,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21748494494350923,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.68592173671978729,
                               0,
                               0,
                               0,
                               0,
                               -0.47783108120416184,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.040323109137900451,
                               -0.66038033497909254,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.80289526122155686,
                               0,
                               -0.32775141630301313,
                               0,
                               0,
                               0,
                               0,
                               0.21468433759530847,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.064968456780761297,
                               1.106818758248771,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.88394352883174221,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21298224637738078,
                               0,
                               0,
                               0,
                               0.67254776941900019,
                               0,
                               0,
                               0,
                               -0.70542875044944831,
                               0.068471443806227009,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.015530668915853259,
                               0,
                               0.48353076932703415,
                               0,
                               0,
                               0,
                               0,
                               -0.6254241580005333,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4169794437490727,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21302742012036874,
                               0,
                               0,
                               0,
                               0.28068549743362292,
                               0,
                               0.27706412493206384,
                               0,
                               0,
                               0.3558893762537067,
                               0,
                               0,
                               0,
                               -0.21955675107103945,
                               -0.45414855158330103,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29073369479286809,
                               0,
                               0,
                               0,
                               -0.0051486195775649057,
                               -0.74280948590687346,
                               -0.051784064602148419,
                               -0.74231496671356045,
                               0,
                               0,
                               0,
                               0.56544193650037067,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.3861175152651652,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.035968856312527553,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.091228440173503123,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27171576537210557,
                               0,
                               0,
                               0,
                               0.27813369430104212,
                               0,
                               0,
                               0,
                               0.42647351147434942,
                               0.81665937510901099,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31759053141194238,
                               0,
                               0,
                               0,
                               0.52800451967349227,
                               0,
                               0,
                               0,
                               0.54399499447396638,
                               -0.56957609460818381,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.55624640913911194,
                               0,
                               0,
                               0,
                               1.0548857759859602,
                               0.0048414295066853026,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17276264868432334,
                               0,
                               0,
                               0,
                               -0.22881461810133547,
                               0.86212688182793817,
                               -0.52701945942911776,
                               -0.08033235309498965,
                               0,
                               0,
                               0,
                               0.2509887525026917,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40591118709136842,
                               0,
                               0,
                               0,
                               0.5528901359571633,
                               0.43062725827096582,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22169786859224716,
                               0,
                               0,
                               0,
                               0.5542639070315567,
                               -0.38846808225689677,
                               0.28978125884219663,
                               -0.060695309121808386,
                               0,
                               0,
                               0,
                               -0.69493590322013221,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.4091911990140491,
                               0,
                               0,
                               0,
                               -0.021172512433045715,
                               -0.071158529629470044,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14034366740754076,
                               0,
                               0,
                               0,
                               -0.57416957816776959,
                               -0.22236334124775936,
                               -0.712782356811551,
                               -0.71877794710993714,
                               0,
                               0,
                               0,
                               -0.72398988343908355,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.48674283823212205,
                               0,
                               0,
                               0,
                               0.43863210282114579,
                               -0.30458411495724175,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.9667743151267052,
                               0,
                               0,
                               0,
                               -0.13382986375186873,
                               -0.82916381143196016,
                               -0.26863139296003113,
                               -0.0052497209927364653,
                               0,
                               0,
                               0,
                               0.55748472467657195,
                               0,
                               0,
                               0,
                               0,
                               -0.078227587963713902,
                               0,
                               0.16518279032072475,
                               0,
                               0,
                               0,
                               0,
                               0.27720424309586067,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41575624287183305,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.64175866210130927,
                               0,
                               0,
                               0,
                               -0.38562269340772742,
                               0,
                               -0.39539929480576291,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21748494494350917,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.97606367554730689,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58217073360583327,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.231615845152719,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.12322770104385494,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17330222621139968,
                               0,
                               0,
                               0,
                               -0.35423872150339614,
                               1.2322818484267524,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.072274421697160918,
                               0,
                               0,
                               0,
                               0.287324761854724,
                               -0.097012798170862752,
                               -0.28203642999485889,
                               -0.24461838169700906,
                               0,
                               0,
                               0,
                               0.29994638736022783,
                               0,
                               0,
                               0,
                               0,
                               -0.3349051706746668,
                               0,
                               -0.33638581169992754,
                               0,
                               0,
                               0,
                               0,
                               -0.3227653111294661,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51821366310465089,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.48997437019536816,
                               0,
                               0,
                               0,
                               -0.33233512578828561,
                               0,
                               -0.22680111632099489,
                               0.87425310875849493,
                               0,
                               0,
                               0,
                               0,
                               0.14863121199461665,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.367736278839947,
                               0.24499230509737993,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0064590592583693707,
                               0,
                               0,
                               0.3615241256131233,
                               0,
                               -0.37515767411388434,
                               0,
                               0,
                               0,
                               0,
                               -0.61226723140911965,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33524983733927655,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34268920547049664,
                               0,
                               0,
                               0,
                               -0.3237082680291043,
                               0,
                               -0.13809589321672136};

const double rot_16_2[4] = {-0.99322397047558009, -0.11621593897879867, -0.11621593897879863, 0.99322397047558009};

const double rot_17_50[2500] = {0.1150620143545289,
                                0.18683999116162558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11947160708061998,
                                0,
                                0,
                                0,
                                0,
                                -0.24972399102948656,
                                0,
                                0,
                                -0.030882683325739457,
                                0.1980308390048976,
                                0.15090440481044348,
                                0,
                                0,
                                0,
                                0,
                                0.53898753666666932,
                                0,
                                0.23298719873316326,
                                0,
                                -0.11914374632815494,
                                0,
                                0,
                                0,
                                0,
                                -0.29908840148714688,
                                0.29822990415160644,
                                0,
                                0,
                                0,
                                -0.20263446746312536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48314730037911985,
                                0,
                                0,
                                -0.020027496023133945,
                                -0.43235066908754782,
                                -0.34348634009060097,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21726753970222212,
                                0,
                                0,
                                0,
                                0,
                                0.25561739009880641,
                                0,
                                0,
                                -0.10628197206580617,
                                0.14872798680642529,
                                -0.26935423345059079,
                                0,
                                0,
                                0,
                                0,
                                0.42533124350078816,
                                0,
                                0.21284095708782205,
                                0,
                                -0.048839365946871043,
                                0,
                                0,
                                0,
                                0,
                                0.38658652177489039,
                                0.28937692425238593,
                                0,
                                0,
                                0,
                                -0.0013832553103723267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.094230509931229028,
                                0,
                                0,
                                -0.076904847539502733,
                                0,
                                0,
                                0.068000021117078924,
                                0.013998766818831127,
                                0,
                                0,
                                0,
                                0.24116520508864406,
                                0,
                                0,
                                0,
                                -0.11125457271468235,
                                0,
                                0,
                                0,
                                0,
                                0.00082071102830135736,
                                0,
                                0,
                                0,
                                0,
                                0.19318930459910436,
                                0.29065170443045046,
                                0,
                                0,
                                -0.38354253216912421,
                                0,
                                -0.3362960792660652,
                                0,
                                0.054037936558699762,
                                0.016667724640481114,
                                -0.1562725677994132,
                                -0.26549449034917744,
                                0,
                                0,
                                0,
                                -0.13998954992981438,
                                -0.20260828927048413,
                                0,
                                0,
                                0.18234642417342833,
                                0,
                                -0.072467334437748707,
                                0,
                                0.14263443092202965,
                                -0.55074672411046632,
                                0,
                                0,
                                0.14737320636372844,
                                0,
                                0,
                                0,
                                0.10480196180252407,
                                -0.093546740821746854,
                                0,
                                0,
                                0,
                                -0.23287482605712828,
                                0,
                                0,
                                0,
                                0.11269297905803667,
                                0,
                                0,
                                0,
                                0,
                                0.20184985860706095,
                                0,
                                0,
                                0,
                                0,
                                -0.25418417873073279,
                                0.19938992857441909,
                                0,
                                0,
                                0.088608689414522421,
                                0,
                                -0.29655595068530632,
                                0,
                                0.32804199830742053,
                                -0.37495017385047086,
                                -0.14335321122860206,
                                0.28654260699100442,
                                0,
                                0,
                                0,
                                0.29908951086646957,
                                -0.26874538518799596,
                                0,
                                0,
                                -0.15391778245854831,
                                0,
                                0.16694542445205671,
                                0,
                                -0.21846630027694103,
                                -0.10172753354058815,
                                0,
                                0,
                                0.22418037523217932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3033670310031884,
                                0.066877292933351457,
                                -0.20864285371555213,
                                0,
                                0.20435747912833852,
                                0,
                                -0.11082928423085597,
                                0,
                                -0.37265011186659963,
                                -0.41108149372523117,
                                0,
                                0.15642492028530763,
                                0,
                                0,
                                0,
                                0,
                                0.13430729743997244,
                                0,
                                0,
                                -0.35239523109855231,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42936398563510347,
                                0,
                                0,
                                0,
                                0.20228436184415535,
                                0,
                                0.26342819603109108,
                                0,
                                0.15815335634518676,
                                0,
                                0,
                                0,
                                -0.10813844542886862,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21969221449906706,
                                0.24332611933469556,
                                -0.37834609586092993,
                                0,
                                0.17061573122084403,
                                0,
                                -0.23528012410510263,
                                0,
                                0.53255611493392174,
                                -0.066708439143490103,
                                0,
                                -0.020505932422920172,
                                0,
                                0,
                                0,
                                0,
                                0.24566593862183453,
                                0,
                                0,
                                0.22625678043521047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37519529391584827,
                                0,
                                0,
                                0,
                                0.16486740868802516,
                                0,
                                -0.28660474382631052,
                                0,
                                0.11184959879529642,
                                0,
                                0,
                                0,
                                0.047746267126270059,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25132283358063573,
                                0.0024221696968591009,
                                0.28281358815637431,
                                0,
                                0.23087209947000698,
                                0,
                                0.34511394874383827,
                                0,
                                0.16513381485717066,
                                0.1200493638442241,
                                0,
                                -0.2476459598885189,
                                0,
                                0,
                                0,
                                0,
                                0.25418126898314419,
                                0,
                                0,
                                0.084850470900400779,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13646533733738661,
                                0,
                                0,
                                0,
                                0.65148197910792061,
                                0,
                                0.043980187159284242,
                                0,
                                0.04575744868715792,
                                0,
                                0,
                                0,
                                -0.25009008484190587,
                                0,
                                0,
                                0,
                                0,
                                0.023431864195979077,
                                -0.085231282863452551,
                                0,
                                0,
                                0,
                                0.34944944852200954,
                                0,
                                0,
                                0,
                                0.13962620017241023,
                                0,
                                0,
                                0,
                                0,
                                -0.18475102895112894,
                                0,
                                0,
                                0,
                                0,
                                0.0046035057926841977,
                                0.47579082489218549,
                                0,
                                0,
                                0.072104115262248261,
                                0,
                                0.16502609404853924,
                                0,
                                0.089931506349714765,
                                -0.25509957684662493,
                                0.26152876636244377,
                                -0.12131158693974341,
                                0,
                                0,
                                0,
                                -0.40404438348929761,
                                -0.2563397528121748,
                                0,
                                0,
                                -0.11426629726529944,
                                0,
                                -0.0081867294432961604,
                                0,
                                -0.19937656665041364,
                                0.33903630440370985,
                                0,
                                0,
                                0.067475065603879891,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33007356859093273,
                                0.29018606138259651,
                                -0.22925027235285719,
                                0,
                                -0.15785098096300498,
                                0,
                                -0.2947489429779967,
                                0,
                                0.15135518855538121,
                                -0.14188719832158017,
                                0,
                                -0.33419863547663953,
                                0,
                                0,
                                0,
                                0,
                                0.054034818436689669,
                                0,
                                0,
                                0.2831517584650951,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29730144143748033,
                                0,
                                0,
                                0,
                                -0.1633755341410929,
                                0,
                                0.50725392898359611,
                                0,
                                -0.091864845463200021,
                                0,
                                0,
                                0,
                                -0.15441742640470946,
                                0,
                                0,
                                -0.16213063146958082,
                                0.017660486155355506,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17963915825322355,
                                0,
                                0,
                                0,
                                0,
                                -0.070264237299482502,
                                0,
                                0,
                                0.18342129569840171,
                                -0.10379119607443772,
                                -0.14164679719914511,
                                0,
                                0,
                                0,
                                0,
                                0.11943750761070639,
                                0,
                                -0.098490844687408693,
                                0,
                                -0.2328210371107492,
                                0,
                                0,
                                0,
                                0,
                                0.26456211951025776,
                                -0.52319888402468262,
                                0,
                                0,
                                0,
                                -0.65333586127624677,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11501568771426741,
                                0,
                                0,
                                -0.098674883757676746,
                                0,
                                0,
                                0,
                                0,
                                -0.23324294157577782,
                                0.14482997998732833,
                                -0.062906336088400724,
                                0,
                                -0.07651054146397894,
                                0,
                                -0.11926553404959522,
                                0,
                                0.12483431636739874,
                                0.08032731944501946,
                                0,
                                0.0096378660709348848,
                                0,
                                0,
                                0,
                                0,
                                -0.70258641869130933,
                                0,
                                0,
                                -0.15107119495269111,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13708855029350572,
                                0,
                                0,
                                0,
                                0.41676295498191429,
                                0,
                                0.19676775281401385,
                                0,
                                -0.29960581315439372,
                                0,
                                0,
                                0,
                                -0.20258749071936946,
                                0,
                                0,
                                0,
                                0,
                                -0.22877011680520054,
                                0.10167035073355643,
                                0,
                                0,
                                0,
                                -0.054999300542198939,
                                0,
                                0,
                                0,
                                -0.088387195968421095,
                                0,
                                0,
                                0,
                                0,
                                -0.59626421415596187,
                                0,
                                0,
                                0,
                                0,
                                0.015960135869891423,
                                0.16324692416743353,
                                0,
                                0,
                                -0.11403989641426721,
                                0,
                                -0.099083484317793402,
                                0,
                                0.096102802231392531,
                                0.38955851863759511,
                                0.13139075872190634,
                                0.11983456893806893,
                                0,
                                0,
                                0,
                                0.17338571638002964,
                                0.12760609173578633,
                                0,
                                0,
                                -0.24608157041720591,
                                0,
                                0.32343102241753308,
                                0,
                                -0.073312763124236666,
                                -0.01968304455072227,
                                0,
                                0,
                                0.33368384452216726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22086182846072638,
                                -0.198642381797624,
                                0.39803187686756641,
                                0,
                                0.12226020095255952,
                                0,
                                -0.10540563583602983,
                                0,
                                0.2268415750479203,
                                0.21540638608343929,
                                0,
                                0.21175715703467621,
                                0,
                                0,
                                0,
                                0,
                                0.10070186756867681,
                                0,
                                0,
                                0.15525209876171836,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32726689839354739,
                                0,
                                0,
                                0,
                                -0.16451704216276375,
                                0,
                                0.60493539407499319,
                                0,
                                0.21299804700270392,
                                0,
                                0,
                                0,
                                -0.069622646505565655,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.030802504965686109,
                                -0.19233440024235884,
                                0.11092227415126189,
                                0,
                                0.70899273644971439,
                                0,
                                -0.47507537000234851,
                                0,
                                -0.19992711373986388,
                                -0.040031604959358008,
                                0,
                                -0.031673844599359818,
                                0,
                                0,
                                0,
                                0,
                                -0.20250242636943844,
                                0,
                                0,
                                0.26053881302340592,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20672138774580398,
                                0,
                                0,
                                0,
                                -0.00075769084995767726,
                                0,
                                -0.14915442406529708,
                                0,
                                -0.069283143773914077,
                                0,
                                0,
                                0,
                                -0.01190818448733792,
                                0,
                                0,
                                0.21571331296018847,
                                0.35050760108144141,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.067299112390809185,
                                0,
                                0,
                                0,
                                0,
                                -0.010619673850873979,
                                0,
                                0,
                                0.35639213400587078,
                                -0.2874170086991466,
                                -0.025879713671200136,
                                0,
                                0,
                                0,
                                0,
                                0.13478282528328348,
                                0,
                                -0.2478476330171436,
                                0,
                                -0.012038057856044795,
                                0,
                                0,
                                0,
                                0,
                                0.48530766465271141,
                                0.4466049884857401,
                                0,
                                0,
                                0,
                                -0.02655705909909363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.067755182321153767,
                                0,
                                0,
                                0.30929149566902414,
                                0,
                                0,
                                0,
                                0,
                                0.10720659594835616,
                                -0.062524604514051341,
                                0.0048474408955860721,
                                0,
                                -0.12985462538538609,
                                0,
                                -0.10940927745806334,
                                0,
                                0.073763359406176288,
                                -0.069730135948617836,
                                0,
                                0.70040567053026115,
                                0,
                                0,
                                0,
                                0,
                                0.2766923663060406,
                                0,
                                0,
                                0.1465007210073147,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14978522369043731,
                                0,
                                0,
                                0,
                                0.10752450146038595,
                                0,
                                -0.047392904517909729,
                                0,
                                -0.51022876219545232,
                                0,
                                0,
                                0,
                                -0.24550385780070244,
                                0,
                                0,
                                0,
                                0,
                                -0.11036337422267449,
                                0.12868997563202689,
                                0,
                                0,
                                0,
                                0.04942645866335426,
                                0,
                                0,
                                0,
                                0.081327560359642073,
                                0,
                                0,
                                0,
                                0,
                                0.40913757646393351,
                                0,
                                0,
                                0,
                                0,
                                -0.0026821394094240295,
                                0.22791882639989694,
                                0,
                                0,
                                -0.09612803025368391,
                                0,
                                0.13168142477440231,
                                0,
                                -0.10812784518101916,
                                0.3804111430170018,
                                -0.11636458634278959,
                                0.31060947527882277,
                                0,
                                0,
                                0,
                                -0.10286472876453366,
                                0.086531892205431934,
                                0,
                                0,
                                0.39508846097985401,
                                0,
                                -0.069571214354453348,
                                0,
                                -0.3344474580571119,
                                0.13371454788393372,
                                0,
                                0,
                                0.37564804060303719,
                                0,
                                -0.47639555387906701,
                                -0.015261319495364106,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34226874791130024,
                                0,
                                0,
                                0,
                                0,
                                -0.5199093525790448,
                                0,
                                0,
                                -0.013846937900088091,
                                -0.31179452440863176,
                                0.30010845364005223,
                                0,
                                0,
                                0,
                                0,
                                -0.091426168511580766,
                                0,
                                -0.20805983203357686,
                                0,
                                0.075542044863528487,
                                0,
                                0,
                                0,
                                0,
                                0.12267592216408466,
                                0.074670740118125384,
                                0,
                                0,
                                0,
                                0.11358706127265605,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25858108906794602,
                                0,
                                0,
                                -0.20035605963265218,
                                -0.042824459299413489,
                                0.33114061549926688,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37173310017943956,
                                0,
                                0,
                                0,
                                0,
                                0.12096875409786342,
                                0,
                                0,
                                -0.46698677217418727,
                                -0.20637985580049834,
                                -0.088202643558749239,
                                0,
                                0,
                                0,
                                0,
                                -0.063284078886424511,
                                0,
                                0.071603535205442465,
                                0,
                                0.33349512573314027,
                                0,
                                0,
                                0,
                                0,
                                -0.15073138866906022,
                                0.10208301360192636,
                                0,
                                0,
                                0,
                                -0.51021011322043508,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1250607702777177,
                                0,
                                0,
                                0.19441614065097318,
                                0.0087987581461239847,
                                0.4365614884827505,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.086544259974831936,
                                0,
                                0,
                                0,
                                0,
                                -0.2758445791139913,
                                0,
                                0,
                                -0.4482645338389627,
                                0.15278143195691871,
                                0.11577964785874566,
                                0,
                                0,
                                0,
                                0,
                                0.010097635826718894,
                                0,
                                0.23592603632865319,
                                0,
                                -0.39600577975640761,
                                0,
                                0,
                                0,
                                0,
                                0.32943964256595648,
                                -0.12220844874900666,
                                0,
                                0,
                                0,
                                0.18139128948854885,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33328958572937678,
                                0,
                                0,
                                -0.089635692642826212,
                                0,
                                0,
                                0,
                                0,
                                0.33288919053908034,
                                -0.10631551514881056,
                                0.064711126482138157,
                                0,
                                -0.1438128087415827,
                                0,
                                -0.061112130047214358,
                                0,
                                0.1407192259634521,
                                -0.10839538848909519,
                                0,
                                0.21278830384979058,
                                0,
                                0,
                                0,
                                0,
                                -0.19693836566603637,
                                0,
                                0,
                                0.19969056290537154,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.03007417783789644,
                                0,
                                0,
                                0,
                                0.31234188277300057,
                                0,
                                0.10409027540127752,
                                0,
                                0.11219587408566939,
                                0,
                                0,
                                0,
                                0.75624168123033353,
                                0,
                                0,
                                0,
                                0,
                                0.22177653394748184,
                                0.1739363594545538,
                                0,
                                0,
                                0,
                                0.16964658316538397,
                                0,
                                0,
                                0,
                                0.26644809917754536,
                                0,
                                0,
                                0,
                                0,
                                -0.12065283019220507,
                                0,
                                0,
                                0,
                                0,
                                -0.023111974446892586,
                                -0.2752201874079489,
                                0,
                                0,
                                -0.35912140531659881,
                                0,
                                -0.33985190144713345,
                                0,
                                0.083034537506423783,
                                -0.15594971225606,
                                0.30571899390278773,
                                0.1073156723590287,
                                0,
                                0,
                                0,
                                -0.034463958516394028,
                                0.29776315442125145,
                                0,
                                0,
                                0.18776097687130253,
                                0,
                                0.052299781159875214,
                                0,
                                -0.42245065920830344,
                                0.010992153582794997,
                                0,
                                0,
                                -0.20702786559092765,
                                0,
                                0,
                                0,
                                -0.303693602993378,
                                0.015208915746616911,
                                0,
                                0,
                                0,
                                -0.043335074732731342,
                                0,
                                0,
                                0,
                                -0.12704449881319874,
                                0,
                                0,
                                0,
                                0,
                                -0.070541945472655437,
                                0,
                                0,
                                0,
                                0,
                                0.29023998224723402,
                                0.021059523736411598,
                                0,
                                0,
                                0.14594585469091137,
                                0,
                                -0.27954227363806078,
                                0,
                                -0.10893951230142249,
                                -0.38950397566381978,
                                -0.31543217624078301,
                                0.12512470617558713,
                                0,
                                0,
                                0,
                                -0.2750910641251828,
                                0.24780588799062789,
                                0,
                                0,
                                0.25511140288514278,
                                0,
                                0.40218054776721712,
                                0,
                                0.12509884251311343,
                                0.20472281802534592,
                                0,
                                0,
                                0.014415940997751781,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19218195543155395,
                                -0.023411163095596876,
                                -0.024345547362419999,
                                0,
                                0.34644782656516399,
                                0,
                                0.47684323956892627,
                                0,
                                0.19074790811863387,
                                -0.15870151262206417,
                                0,
                                -0.12366474783981732,
                                0,
                                0,
                                0,
                                0,
                                -0.10517411134086974,
                                0,
                                0,
                                0.071171365586834776,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30533650905467691,
                                0,
                                0,
                                0,
                                -0.31446081520826447,
                                0,
                                0.078877399184998837,
                                0,
                                -0.54521395718897259,
                                0,
                                0,
                                0,
                                0.16103721136757157,
                                0,
                                0,
                                0.23223184945848985,
                                -0.049524562098548199,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24754100037681145,
                                0,
                                0,
                                0,
                                0,
                                0.057979535328175312,
                                0,
                                0,
                                -0.21240618158620647,
                                -0.43670734530248595,
                                -0.41370423227400593,
                                0,
                                0,
                                0,
                                0,
                                0.059165623118512339,
                                0,
                                0.084092389649435662,
                                0,
                                -0.33809552832580025,
                                0,
                                0,
                                0,
                                0,
                                0.0032265997527990108,
                                -0.20709201145739536,
                                0,
                                0,
                                0,
                                0.2968475838522861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42212753666261349,
                                0,
                                0,
                                0.19470049976806131,
                                0,
                                0,
                                0.26255759762502584,
                                0.1318709168268975,
                                0,
                                0,
                                0,
                                -0.18109977965242074,
                                0,
                                0,
                                0,
                                -0.045132991668071026,
                                0,
                                0,
                                0,
                                0,
                                0.12790195909895727,
                                0,
                                0,
                                0,
                                0,
                                0.30210571301085504,
                                -0.024521495861756878,
                                0,
                                0,
                                -0.25049433369653679,
                                0,
                                0.052369832318567594,
                                0,
                                -0.24172150525830699,
                                0.19091939999442753,
                                -0.044685879424051729,
                                0.10528447293035847,
                                0,
                                0,
                                0,
                                -0.078595662355442131,
                                -0.48238266362534887,
                                0,
                                0,
                                -0.16444824733032232,
                                0,
                                0.47187903840162537,
                                0,
                                -0.10278801473546569,
                                0.12243862493376874,
                                0,
                                0,
                                -0.28813235719697933,
                                0,
                                -0.12248883500011526,
                                0.054160858749725524,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35799003247143096,
                                0,
                                0,
                                0,
                                0,
                                0.27227138263454487,
                                0,
                                0,
                                -0.057829802931037899,
                                -0.45493895854584315,
                                -0.021069852911715647,
                                0,
                                0,
                                0,
                                0,
                                -0.24855137872868666,
                                0,
                                0.15686874121117075,
                                0,
                                -0.25739298430581936,
                                0,
                                0,
                                0,
                                0,
                                -0.1459444356812685,
                                0.3734816364798435,
                                0,
                                0,
                                0,
                                -0.098088014302845694,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0053649843349436732,
                                0,
                                0,
                                -0.49592514133677823,
                                0,
                                0,
                                0.19958064438502726,
                                0.294909603939358,
                                0,
                                0,
                                0,
                                0.12064803732325724,
                                0,
                                0,
                                0,
                                0.34409854391253097,
                                0,
                                0,
                                0,
                                0,
                                0.14267712704003949,
                                0,
                                0,
                                0,
                                0,
                                0.43598666130981012,
                                -0.10540968608235189,
                                0,
                                0,
                                0.1592245239301899,
                                0,
                                -0.057045099550716662,
                                0,
                                0.32097757194430931,
                                0.098952956069416453,
                                -0.25062962598562177,
                                -0.34962123180704702,
                                0,
                                0,
                                0,
                                0.14035604671925564,
                                0.1267538463912537,
                                0,
                                0,
                                -0.22159361843496678,
                                0,
                                -0.00093192710197162422,
                                0,
                                0.033091045594688381,
                                0.22674392630521553,
                                0,
                                0,
                                0.23415789949664823,
                                0,
                                -0.1812244873967776,
                                0.098135026657375862,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36163833416411123,
                                0,
                                0,
                                0,
                                0,
                                0.43007088779358316,
                                0,
                                0,
                                -0.29957111019085458,
                                -0.032557492631503523,
                                0.38563883770051954,
                                0,
                                0,
                                0,
                                0,
                                0.051092454878468675,
                                0,
                                -0.049522558054162606,
                                0,
                                0.2739743887787745,
                                0,
                                0,
                                0,
                                0,
                                0.27472343122608134,
                                -0.17898755978081196,
                                0,
                                0,
                                0,
                                0.15584457987442213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3994492245163111,
                                0,
                                0,
                                0.17544851165929617,
                                0,
                                0,
                                -0.10821591652154265,
                                0.30405384574240096,
                                0,
                                0,
                                0,
                                -0.22230275086415649,
                                0,
                                0,
                                0,
                                -0.13170211559152914,
                                0,
                                0,
                                0,
                                0,
                                -0.21608739427928583,
                                0,
                                0,
                                0,
                                0,
                                0.020152593990086846,
                                -0.26440177132352544,
                                0,
                                0,
                                -0.26321266085163786,
                                0,
                                0.38630414787262995,
                                0,
                                0.29355893194175497,
                                -0.27559484574149329,
                                0.011793771478515951,
                                -0.10811016263333931,
                                0,
                                0,
                                0,
                                0.075379959389197532,
                                -0.31419649196325933,
                                0,
                                0,
                                0.39048340825469863,
                                0,
                                -0.045842533313460734,
                                0,
                                0.016049630868998035,
                                0.10306782665173039,
                                0,
                                0,
                                0.2230232983906914,
                                0,
                                0,
                                0,
                                -0.43763489257852717,
                                0.2886398458555694,
                                0,
                                0,
                                0,
                                -0.21286209017624658,
                                0,
                                0,
                                0,
                                -0.06278285102984825,
                                0,
                                0,
                                0,
                                0,
                                0.02229055937022615,
                                0,
                                0,
                                0,
                                0,
                                -0.1087242907053331,
                                0.1698566834473359,
                                0,
                                0,
                                -0.15276521011692337,
                                0,
                                -0.10489258027265991,
                                0,
                                0.2366802578995103,
                                0.085495970757799286,
                                -0.29993919303834654,
                                -0.10568054062314573,
                                0,
                                0,
                                0,
                                -0.16136938545374468,
                                0.010637376142108034,
                                0,
                                0,
                                -0.23799470897311897,
                                0,
                                -0.2853250442996102,
                                0,
                                -0.26197065392024921,
                                0.065287671911712003,
                                0,
                                0,
                                -0.44592240151213802,
                                0,
                                0,
                                0,
                                -0.20661570596025325,
                                0.13668927515642709,
                                0,
                                0,
                                0,
                                -0.1316497743707338,
                                0,
                                0,
                                0,
                                -0.052144410969741081,
                                0,
                                0,
                                0,
                                0,
                                0.32790779621066191,
                                0,
                                0,
                                0,
                                0,
                                0.24001730463623297,
                                -0.080670828371740097,
                                0,
                                0,
                                0.15458756013944808,
                                0,
                                0.18605510718070573,
                                0,
                                0.28041294340516582,
                                -0.057384980172317412,
                                0.46406229130938143,
                                0.089394502542217119,
                                0,
                                0,
                                0,
                                -0.32059795577663508,
                                0.12691878818871996,
                                0,
                                0,
                                -0.18901246164498003,
                                0,
                                0.17774186106985251,
                                0,
                                -0.020964633195553816,
                                -0.44041365862998788,
                                0,
                                0,
                                0.05039051858502052,
                                0,
                                0,
                                0,
                                -0.027259162479220896,
                                0.041170900222870052,
                                0,
                                0,
                                0,
                                0.52918373653149209,
                                0,
                                0,
                                0,
                                -0.21854768054338738,
                                0,
                                0,
                                0,
                                0,
                                0.068753203402979343,
                                0,
                                0,
                                0,
                                0,
                                -0.16491364253101046,
                                -0.2821017099138946,
                                0,
                                0,
                                0.0063069727910513261,
                                0,
                                -0.10630365503774437,
                                0,
                                0.42304337722409796,
                                0.19768571797397499,
                                -0.090873363697090107,
                                0.39231807894247051,
                                0,
                                0,
                                0,
                                -0.13449333397450045,
                                -0.19663706903499753,
                                0,
                                0,
                                -0.043824848449569173,
                                0,
                                0.046777714341261267,
                                0,
                                0.27795643839022527,
                                0.14720688952532654,
                                0,
                                0,
                                -0.08311706262835572,
                                0,
                                0.32306858536995209,
                                -0.41932446642158228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1346482000938633,
                                0,
                                0,
                                0,
                                0,
                                -0.23992104434815201,
                                0,
                                0,
                                -0.37317956255431334,
                                0.21261039080035699,
                                -0.072612409536400385,
                                0,
                                0,
                                0,
                                0,
                                -0.36929685817055369,
                                0,
                                -0.13928416461848619,
                                0,
                                -0.0057239370986580662,
                                0,
                                0,
                                0,
                                0,
                                0.31619760282016285,
                                0.28247701230630989,
                                0,
                                0,
                                0,
                                -0.25443130847177819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23232897338207625,
                                0,
                                0,
                                0.0079667406337855795,
                                0.12470791473055967,
                                0.30715415174167088,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25593206655568579,
                                0,
                                0,
                                0,
                                0,
                                0.27845586738740852,
                                0,
                                0,
                                -0.088601495102695063,
                                0.31005299979388723,
                                -0.14006125662329125,
                                0,
                                0,
                                0,
                                0,
                                0.072579385254303422,
                                0,
                                -0.58695437368888637,
                                0,
                                -0.06794057091881156,
                                0,
                                0,
                                0,
                                0,
                                0.012104187469383854,
                                0.010258883072809921,
                                0,
                                0,
                                0,
                                0.058091416642862097,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16028232171044288,
                                0,
                                0,
                                -0.48964192075956642,
                                0,
                                0,
                                0,
                                0,
                                0.55379801231553316,
                                0.15477124936186165,
                                0.16190064207308402,
                                0,
                                -0.1578398604875372,
                                0,
                                -0.19935603684211192,
                                0,
                                -0.093742750935168373,
                                0.50112705246523892,
                                0,
                                -0.019350535474124207,
                                0,
                                0,
                                0,
                                0,
                                -0.11980804025919656,
                                0,
                                0,
                                0.12139301117751891,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42098898492330628,
                                0,
                                0,
                                0,
                                -0.11654867816313177,
                                0,
                                -0.27720419921489847,
                                0,
                                -0.0089304342443732171,
                                0,
                                0,
                                0,
                                -0.14617665186348144,
                                0,
                                0,
                                0,
                                0,
                                -0.3191524579777793,
                                -0.41379077607173981,
                                0,
                                0,
                                0,
                                -0.079790302382652792,
                                0,
                                0,
                                0,
                                0.29814437782233083,
                                0,
                                0,
                                0,
                                0,
                                -0.03378713837186971,
                                0,
                                0,
                                0,
                                0,
                                0.50044996773321471,
                                0.046143655129722114,
                                0,
                                0,
                                -0.08439283866854394,
                                0,
                                -0.10724805033867593,
                                0,
                                0.16294292081728493,
                                0.083293643041651627,
                                0.20345610736841005,
                                0.22649249188639725,
                                0,
                                0,
                                0,
                                0.24679057811485189,
                                -0.18793632080473291,
                                0,
                                0,
                                0.16018156168581538,
                                0,
                                -0.23761820516318449,
                                0,
                                0.11301997593994274,
                                0.10320071366328054,
                                0,
                                0,
                                -0.17710309718866976,
                                0,
                                0,
                                0,
                                0.14695396145583389,
                                -0.34911974080981217,
                                0,
                                0,
                                0,
                                -0.12598275103025885,
                                0,
                                0,
                                0,
                                0.11187854704123557,
                                0,
                                0,
                                0,
                                0,
                                0.11414113554555427,
                                0,
                                0,
                                0,
                                0,
                                -0.1218595577108294,
                                0.18462347484865343,
                                0,
                                0,
                                -0.50825289318470324,
                                0,
                                0.31870113939149303,
                                0,
                                0.3030851877942774,
                                -0.01259519959937435,
                                -0.14577441247042994,
                                -0.017738201259795985,
                                0,
                                0,
                                0,
                                -0.083605247866319579,
                                0.38849022042187881,
                                0,
                                0,
                                -0.065008060016325156,
                                0,
                                0.22935111450453988,
                                0,
                                0.25237343286518577,
                                0.099177370024428793,
                                0,
                                0,
                                -0.066492218901614553,
                                0,
                                0.26326916739950484,
                                0.14090065531950519,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0027686661654355597,
                                0,
                                0,
                                0,
                                0,
                                -0.13369606930742362,
                                0,
                                0,
                                0.14312887067970692,
                                -0.054471206783041744,
                                -0.22873489871719899,
                                0,
                                0,
                                0,
                                0,
                                0.0040913062232202507,
                                0,
                                0.42231745341427102,
                                0,
                                0.56801790249005735,
                                0,
                                0,
                                0,
                                0,
                                0.28176661793745578,
                                -0.1298159093742047,
                                0,
                                0,
                                0,
                                0.091944509191408036,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12392911023566339,
                                0,
                                0,
                                -0.44284476314635285,
                                0,
                                0,
                                0,
                                0,
                                0.1619585768353671,
                                -0.20937601886022916,
                                -0.57321575937281721,
                                0,
                                0.25307263368959299,
                                0,
                                0.087843183545569956,
                                0,
                                0.13254826657296806,
                                0.56694249523693852,
                                0,
                                0.16859470050481673,
                                0,
                                0,
                                0,
                                0,
                                0.0068733914729229295,
                                0,
                                0,
                                -0.28248543132223947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20443140729584217,
                                0,
                                0,
                                0,
                                -0.027272483298661505,
                                0,
                                0.17486849026805873,
                                0,
                                0.077494146602837183,
                                0,
                                0,
                                0,
                                0.056657046241674169,
                                0,
                                0,
                                0,
                                0,
                                -0.31710887180623182,
                                -0.11089545070521679,
                                0,
                                0,
                                0,
                                0.32230687464384988,
                                0,
                                0,
                                0,
                                0.46168412989885954,
                                0,
                                0,
                                0,
                                0,
                                -0.11267978404098049,
                                0,
                                0,
                                0,
                                0,
                                -0.055920001028775888,
                                -0.24650140508113871,
                                0,
                                0,
                                -0.035043985875143679,
                                0,
                                0.33208865567628643,
                                0,
                                -0.16887231621816046,
                                -0.099364937603823714,
                                -0.35594651020620899,
                                0.051538007374869792,
                                0,
                                0,
                                0,
                                0.01520837512250775,
                                -0.10694198820315481,
                                0,
                                0,
                                -0.12498829032875196,
                                0,
                                0.17624307576558823,
                                0,
                                -0.19063432392586477,
                                -0.34574886591206355,
                                0,
                                0,
                                -0.0056471225849645673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28581081650024232,
                                0.36728513329877649,
                                -0.16242002983354425,
                                0,
                                0.055773785874281612,
                                0,
                                0.15627302827688153,
                                0,
                                -0.55584074480505374,
                                0.30413547966537247,
                                0,
                                0.024624868750139826,
                                0,
                                0,
                                0,
                                0,
                                0.16526190287709608,
                                0,
                                0,
                                0.39817941154886366,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084440264834389656,
                                0,
                                0,
                                0,
                                0.15904711151608272,
                                0,
                                0.17989188266877348,
                                0,
                                -0.1564986916590369,
                                0,
                                0,
                                0,
                                0.22869291062645478,
                                0,
                                0,
                                0,
                                0,
                                -0.17833210609622915,
                                0.22022248069577616,
                                0,
                                0,
                                0,
                                0.31882211567689661,
                                0,
                                0,
                                0,
                                -0.26522933518771813,
                                0,
                                0,
                                0,
                                0,
                                0.22997636539445088,
                                0,
                                0,
                                0,
                                0,
                                0.15750837812134302,
                                0.12691395291780652,
                                0,
                                0,
                                -0.32177390218635421,
                                0,
                                0.10970649815267804,
                                0,
                                -0.2585297182744366,
                                -0.34065956769153549,
                                0.11668464181741894,
                                0.13092959355171616,
                                0,
                                0,
                                0,
                                0.42660306837914008,
                                0.13381101184814231,
                                0,
                                0,
                                -0.31000456003256516,
                                0,
                                -0.099861874677987322,
                                0,
                                0.065372219802565024,
                                0.10825386806248136,
                                0,
                                0,
                                0.05214225301433182,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.068970468682813077,
                                -0.23199001417230125,
                                -0.28569538780965636,
                                0,
                                -0.064357835663276491,
                                0,
                                0.35651745901367587,
                                0,
                                -0.074754174134555595,
                                -0.1723486754220333,
                                0,
                                0.18288208959123145,
                                0,
                                0,
                                0,
                                0,
                                -0.32945985914403703,
                                0,
                                0,
                                0.5387918552786739,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.043387847484357228,
                                0,
                                0,
                                0,
                                -0.034954638813719303,
                                0,
                                -0.048842138227577228,
                                0,
                                0.37006520915116731,
                                0,
                                0,
                                0,
                                -0.34429421244835573,
                                0,
                                0,
                                0,
                                0,
                                0.36517403141694937,
                                -0.11713171286127083,
                                0,
                                0,
                                0,
                                -0.075238478756020841,
                                0,
                                0,
                                0,
                                -0.23544405004640656,
                                0,
                                0,
                                0,
                                0,
                                -0.27754233018842961,
                                0,
                                0,
                                0,
                                0,
                                0.35105239172655056,
                                -0.051224687542427892,
                                0,
                                0,
                                0.02038271910901425,
                                0,
                                0.17613942478381353,
                                0,
                                0.036630853515055295,
                                -0.10616747729175982,
                                -0.27792573651061664,
                                0.40922348895754823,
                                0,
                                0,
                                0,
                                -0.18824542114625409,
                                0.12237659418485185,
                                0,
                                0,
                                -0.18756051586355499,
                                0,
                                -0.37576594243698719,
                                0,
                                -0.22206340649720388,
                                -0.13355932772282492,
                                0,
                                0,
                                0.078992211772978826,
                                0,
                                0,
                                0,
                                -0.0035687573263027796,
                                -0.30262574608704773,
                                0,
                                0,
                                0,
                                0.22142000337521869,
                                0,
                                0,
                                0,
                                -0.43973666740760348,
                                0,
                                0,
                                0,
                                0,
                                0.05874980237616087,
                                0,
                                0,
                                0,
                                0,
                                0.13324884703249432,
                                0.022314449185093486,
                                0,
                                0,
                                0.17228623233197199,
                                0,
                                0.14364472266107511,
                                0,
                                0.23606174741547087,
                                0.072582412115958742,
                                -0.05496149250994798,
                                -0.28089808377030928,
                                0,
                                0,
                                0,
                                0.30490368019800823,
                                0.072953642079644429,
                                0,
                                0,
                                0.19735475563271301,
                                0,
                                0.23318266968373244,
                                0,
                                -0.46564765275700448,
                                -0.039570444170634475,
                                0,
                                0,
                                -0.20264681079034039,
                                0,
                                0.23951096845971284,
                                -0.049730582894217917,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48481016634371693,
                                0,
                                0,
                                0,
                                0,
                                0.30088929850803037,
                                0,
                                0,
                                0.23067315650048575,
                                0.069191949052873125,
                                0.5154756065681817,
                                0,
                                0,
                                0,
                                0,
                                -0.19822850669416728,
                                0,
                                0.3306591349357651,
                                0,
                                -0.25746022368398142,
                                0,
                                0,
                                0,
                                0,
                                0.18156509689632211,
                                -0.018687377295188955,
                                0,
                                0,
                                0,
                                -0.16119616069658163,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11507636332757737,
                                0,
                                0,
                                -0.05844416644892575,
                                0,
                                0,
                                0,
                                0,
                                -0.069649822894428143,
                                -0.69455624648940228,
                                -0.19621128061540882,
                                0,
                                -0.27139462880078857,
                                0,
                                -0.18242413016963549,
                                0,
                                -0.13339859999359813,
                                0.031790726693606587,
                                0,
                                -0.37704839564168813,
                                0,
                                0,
                                0,
                                0,
                                0.18067832828759564,
                                0,
                                0,
                                0.11252920442923957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23372303226172042,
                                0,
                                0,
                                0,
                                0.17655560232369011,
                                0,
                                0.028995886744349691,
                                0,
                                -0.27259414134218996,
                                0,
                                0,
                                0,
                                0.0090870631469501112,
                                0,
                                0,
                                0,
                                0,
                                -0.18247479818261905,
                                -0.4082865340693877,
                                0,
                                0,
                                0,
                                -0.086394128021591896,
                                0,
                                0,
                                0,
                                -0.16717614824473465,
                                0,
                                0,
                                0,
                                0,
                                0.16208463990652108,
                                0,
                                0,
                                0,
                                0,
                                -0.019968308350617237,
                                -0.42641976376539703,
                                0,
                                0,
                                -0.24973546674232061,
                                0,
                                -0.2274384657726439,
                                0,
                                -0.098029975426085811,
                                0.011018958019292244,
                                0.033435559338975497,
                                -0.24252302242033222,
                                0,
                                0,
                                0,
                                -0.23065037658665155,
                                -0.094458264105101455,
                                0,
                                0,
                                -0.27270181684903466,
                                0,
                                -0.085105512086217208,
                                0,
                                -0.19840892374293556,
                                0.20738733213820026,
                                0,
                                0,
                                0.38238693011649838,
                                0,
                                0.38700385751094918,
                                -0.34051161714333467,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0017414793843181786,
                                0,
                                0,
                                0,
                                0,
                                -0.015979490574739352,
                                0,
                                0,
                                -0.22106444824092514,
                                -0.36646767426223648,
                                0.33084127543214475,
                                0,
                                0,
                                0,
                                0,
                                0.48460338956942861,
                                0,
                                -0.19868295335117081,
                                0,
                                0.078244920246405336,
                                0,
                                0,
                                0,
                                0,
                                -0.003410810639041556,
                                -0.1080888053398924,
                                0,
                                0,
                                0,
                                -0.026267395812573639,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31659960300421058,
                                0,
                                0,
                                -0.21986300974627682};

const double rot_17_20[400] = {0.14399596607835952,
                               0,
                               -0.5319295349359594,
                               0,
                               -0.063049275989638331,
                               0.64982274116601568,
                               0,
                               0,
                               0,
                               0,
                               0.32845654808116032,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40272524318595759,
                               0,
                               0,
                               0,
                               0.27435842627079682,
                               0,
                               -0.26420533286710246,
                               0,
                               0,
                               -0.19292748624105469,
                               -0.66393657491718538,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54674284220760827,
                               0,
                               -0.27921760340903656,
                               0,
                               0,
                               0,
                               0.43697370165852084,
                               0,
                               -0.37363590783197542,
                               0,
                               -0.011121985270900164,
                               -0.30660953078178887,
                               0,
                               0,
                               0,
                               0,
                               -0.65698160647341131,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37906761701634351,
                               0,
                               0,
                               0,
                               -0.19427443877405248,
                               0,
                               0.23979672577645722,
                               0,
                               0,
                               -0.27561834623953158,
                               0.0056871116106471317,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50860622157595081,
                               0,
                               0.75503434895232835,
                               0,
                               0,
                               0,
                               0.027153056541202508,
                               0,
                               -0.34625496735253763,
                               0,
                               -0.48339795118955314,
                               0.25022890760124489,
                               0,
                               0,
                               0,
                               0,
                               -0.299015201738556,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.70261798498185601,
                               0,
                               0,
                               0.57488518405226841,
                               0,
                               -0.049651984314422776,
                               0,
                               -0.37977911713858625,
                               -0.4368785876483699,
                               0,
                               0,
                               0,
                               0,
                               0.56910481941570346,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.089812760609558576,
                               0,
                               0,
                               0,
                               -0.36726734435178199,
                               0,
                               -0.10292480787691774,
                               0,
                               0,
                               -0.090730570776290986,
                               0.5670466065951395,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.55094286111458168,
                               0,
                               -0.47032887957121439,
                               0,
                               0,
                               0,
                               0,
                               -0.64099616429356199,
                               0,
                               0.37926903687668895,
                               0,
                               0,
                               -0.40327189343264463,
                               -0.39043314694139086,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24621375817845742,
                               0,
                               -0.26380189166854268,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.61894435296470729,
                               0.052813058770595889,
                               0,
                               0.097427621945197856,
                               0.10807815443951041,
                               0.44325444681947157,
                               0,
                               0.20505295259736386,
                               0,
                               0,
                               0.58854339435153491,
                               -0.089672151432265035,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.26377409137025304,
                               0.3051827128483145,
                               0,
                               0.49410818343477236,
                               -0.45517489406251643,
                               -0.11813951566064607,
                               0,
                               -0.11698133703793118,
                               0,
                               0,
                               -0.0829360206862612,
                               0.59282349605537932,
                               0.65760509334524964,
                               0,
                               0.52391066262231245,
                               0,
                               0.19112759910932714,
                               0.4630624469075183,
                               0,
                               0,
                               0,
                               0,
                               -0.15650624707290711,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13274925441226082,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35906420641509212,
                               -0.12253483629895648,
                               0,
                               0.22684247223366227,
                               -0.33738585981204477,
                               -0.050837001021681261,
                               0,
                               -0.52025913413315805,
                               0,
                               0,
                               0.59370808308400191,
                               -0.25500613465827021,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20962380005818068,
                               -0.5766216658690636,
                               0,
                               -0.2100314846895881,
                               0.04443634513845085,
                               0.26774238912875636,
                               0,
                               0.020402562627183381,
                               0,
                               0,
                               0.19424097942603158,
                               0.68384625025137358,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29261680213900793,
                               0.62418261130485686,
                               0,
                               -0.34150387902194701,
                               -0.057051427387967979,
                               0.5874473672587065,
                               0,
                               -0.21017392418682088,
                               0,
                               0,
                               -0.032065208099452763,
                               0.12081409197114527,
                               0,
                               -0.52658929783217701,
                               0,
                               -0.22348901589987225,
                               0,
                               0,
                               0.74655427328117874,
                               -0.28871685129108582,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13126186366828768,
                               0,
                               0.12176202672928159,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33199911883163752,
                               0.089253863607910475,
                               0,
                               -0.2072313291030054,
                               0.51397417700733339,
                               -0.27835023535283332,
                               0,
                               -0.67582709352304493,
                               0,
                               0,
                               0.057248156169692518,
                               0.19286676563964894,
                               0,
                               0.25283833355641272,
                               0,
                               0.81750058945159754,
                               0,
                               0,
                               0.3982586757477643,
                               -0.042644633281401695,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2469879512968757,
                               0,
                               -0.21525328728920853,
                               0,
                               0,
                               0,
                               -0.15698542510724242,
                               0,
                               0.42497879225844604,
                               0,
                               -0.76253890003767388,
                               0.1257647184878897,
                               0,
                               0,
                               0,
                               0,
                               -0.15068799903225466,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41804233146307845,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11066918830511226,
                               -0.18050436089115168,
                               0,
                               0.6436843386148301,
                               0.3870756112148811,
                               0.46793241090743121,
                               0,
                               -0.22934840874178775,
                               0,
                               0,
                               -0.33213152971630355,
                               -0.095606815039803755,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.4078801266749954,
                               0.35554880427361574,
                               0,
                               0.27729943896094411,
                               0.49807556894813287,
                               -0.27159557913775556,
                               0,
                               0.34592888122401272,
                               0,
                               0,
                               0.37669956390107245,
                               0.21658967633939349};

const double rot_17_10[100] = {0.38150258004694682,
                               -0.69287946881878126,
                               0,
                               -0.42219062515956007,
                               0,
                               0,
                               0,
                               0,
                               -0.44286442523004954,
                               0,
                               -0.08993826258026183,
                               -0.66190516530240084,
                               0,
                               0.67391374497691392,
                               0,
                               0,
                               0,
                               0,
                               0.31564683651391573,
                               0,
                               0,
                               0,
                               -0.96349837610127409,
                               0,
                               0,
                               -0.22476356512206513,
                               0,
                               0,
                               0,
                               -0.1454380247522184,
                               0.39414691932913642,
                               -0.066867314619663221,
                               0,
                               -0.39947797954975622,
                               0,
                               0,
                               0,
                               0,
                               0.82498140104714313,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29841129991203286,
                               0,
                               0.51255077781870839,
                               -0.80513501739909876,
                               0,
                               0,
                               0,
                               0,
                               -0.26675958296229274,
                               0,
                               0,
                               0.85187160432398845,
                               0,
                               0,
                               0,
                               0.45072618588701646,
                               0,
                               0,
                               0,
                               0,
                               -0.87887350362054151,
                               0,
                               0.47652956895227505,
                               -0.022381567146040615,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37219895314007034,
                               0,
                               0.71429074617525079,
                               0.59266910600253153,
                               0,
                               0,
                               0.83127317791741495,
                               0.27807976566258824,
                               0,
                               0.4560840758165271,
                               0,
                               0,
                               0,
                               0,
                               -0.15376561186009086,
                               0,
                               0,
                               0,
                               -0.022587699041547754,
                               0,
                               0,
                               -0.473070934998223,
                               0,
                               0,
                               0,
                               0.88073474231003046};

const double rot_17_100[10000] = {-0.027409636521250086,
                                  0,
                                  0.04082030054564266,
                                  0,
                                  0,
                                  0,
                                  -0.21996438481487837,
                                  0,
                                  -0.18309715208386212,
                                  0,
                                  0,
                                  -0.10862110098677136,
                                  -0.17602408509180398,
                                  0,
                                  0,
                                  -0.04786994085428227,
                                  0.14322685515606537,
                                  0,
                                  0.16580249597157135,
                                  0,
                                  0,
                                  0.090765072834156219,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.065269891407594885,
                                  0,
                                  -0.077226871724900642,
                                  -0.049834514099200991,
                                  0,
                                  0,
                                  -0.17325810903606054,
                                  -0.22808707152271041,
                                  0.067771094585647076,
                                  0,
                                  -0.078552513520024903,
                                  0,
                                  -0.24501420174704391,
                                  0,
                                  0,
                                  -0.30613171018505669,
                                  0.22451338977233809,
                                  0,
                                  0,
                                  0.059798455228139397,
                                  0,
                                  0,
                                  0,
                                  0.0082062445305526761,
                                  0,
                                  0,
                                  0.018185898084170225,
                                  -0.41775101017882849,
                                  0,
                                  0,
                                  0.21841062218229612,
                                  0,
                                  -0.024525865235107677,
                                  -0.13380364389725394,
                                  0,
                                  0,
                                  0.29615922402258921,
                                  -0.041269310761922466,
                                  -0.15323248823787053,
                                  0,
                                  0,
                                  0.19353904912750397,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074704373858004311,
                                  -0.12783189148328594,
                                  0,
                                  0.015907505340264871,
                                  -0.25372566653899969,
                                  0,
                                  0,
                                  0,
                                  0.050027959206069617,
                                  0.063585145385824729,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022221938962287559,
                                  0,
                                  0,
                                  0,
                                  0.0050721526214202459,
                                  0,
                                  0,
                                  0,
                                  0.1265796889632495,
                                  0,
                                  0.10784298950107014,
                                  0,
                                  -0.30957593789719828,
                                  0.23558074534379411,
                                  -0.068730467692829089,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0032050507384144,
                                  0,
                                  0,
                                  0.027218099972298376,
                                  0,
                                  -0.019901086041180537,
                                  0,
                                  0,
                                  -0.21873577364522331,
                                  0,
                                  -0.09066176313660583,
                                  0.41353963789809073,
                                  0,
                                  -0.31218403795948974,
                                  0,
                                  0,
                                  -0.17855114669357575,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08260121732716573,
                                  0,
                                  0.038828665270161017,
                                  0,
                                  0.14718761035298986,
                                  0,
                                  0,
                                  0,
                                  -0.18417393672774396,
                                  0,
                                  0,
                                  0.1607405759023425,
                                  0,
                                  0.34542437835386619,
                                  0,
                                  0.095984691663368205,
                                  0.028154586272226251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25243375763950293,
                                  0.097615128385597688,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0085632148110873461,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081665173419860557,
                                  0.15852001105956237,
                                  0.10327066520146361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.00018663306504067799,
                                  0,
                                  0.19090139178736584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32074092630424017,
                                  0.023712465674708777,
                                  0,
                                  -0.11288992905607617,
                                  0,
                                  0.17150244910940948,
                                  0,
                                  0,
                                  0,
                                  0.10284088390763295,
                                  0,
                                  0.013826288504474458,
                                  0,
                                  0,
                                  -0.072803467750953352,
                                  -0.20131178950938072,
                                  0,
                                  0,
                                  -0.31704763104755007,
                                  0.29498359881029973,
                                  0,
                                  -0.28868709103481915,
                                  0,
                                  0,
                                  -0.036701934950390418,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11142973030598712,
                                  0,
                                  -0.051037603138945134,
                                  -0.071964212802183861,
                                  0,
                                  0,
                                  -0.020290171173905892,
                                  -0.0016887440770608862,
                                  -0.2008485256929676,
                                  0,
                                  0.026620770080020673,
                                  0,
                                  -0.30929432343958047,
                                  0,
                                  0,
                                  0.010432387164237389,
                                  -0.20191014531755233,
                                  0,
                                  0,
                                  -0.085228481881280738,
                                  0,
                                  0,
                                  0,
                                  0.0059317898323769137,
                                  0,
                                  0,
                                  0.00039099369369980687,
                                  0.097132344258549261,
                                  0,
                                  0,
                                  0.056245913805174269,
                                  0,
                                  -0.099702610601710595,
                                  0.01521420844342463,
                                  0,
                                  0,
                                  0.003166696426978078,
                                  0.080092499378288093,
                                  -0.15752042111097467,
                                  0,
                                  0,
                                  0.065286735680195745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21371182473503694,
                                  -0.093370517797646602,
                                  0,
                                  -0.33354068054557023,
                                  0.13682000441246525,
                                  0,
                                  0,
                                  0,
                                  -0.4035021099776438,
                                  -0.10091594546226715,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.073006940064166498,
                                  0,
                                  0,
                                  0,
                                  -0.044751100119056551,
                                  0,
                                  0,
                                  0,
                                  0.02374063648705706,
                                  0,
                                  0.0075854708200133614,
                                  0,
                                  -0.28546634960399475,
                                  0.23965164404580244,
                                  0.20453677270715656,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33615354566940492,
                                  0,
                                  0,
                                  0.25601790951627607,
                                  0,
                                  -0.11906944286035832,
                                  0,
                                  0,
                                  0.054439577268605988,
                                  0,
                                  0.14832649312160517,
                                  -0.11000781849281518,
                                  0,
                                  -0.022086054563964664,
                                  0,
                                  0,
                                  0.16951863037384385,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17935035394719562,
                                  0,
                                  0.14186523192320027,
                                  0,
                                  0.060549283625955193,
                                  0,
                                  0,
                                  0,
                                  -0.013854682615469774,
                                  0,
                                  0,
                                  0.14509399825668917,
                                  0,
                                  -0.20632354451922449,
                                  0,
                                  -0.26766339988228055,
                                  0.0038758623092818266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18417870431059913,
                                  0.0084570611966283855,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17615900138568144,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0027769283426563327,
                                  -0.16865767782131164,
                                  0.17267455429601783,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39341452022016898,
                                  0,
                                  0.084730479273778331,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17784400270687145,
                                  -0.22773295852415715,
                                  0,
                                  0,
                                  0.043577612396019844,
                                  0,
                                  0.093798769780162633,
                                  -0.047783977257548682,
                                  -0.16518203485139291,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29161017119130361,
                                  0,
                                  0,
                                  0.17284990209422826,
                                  0,
                                  -0.29845963281548815,
                                  0,
                                  0,
                                  -0.040612249760451677,
                                  0,
                                  -0.082083322158529273,
                                  -0.059344176447811051,
                                  0,
                                  0.13438678069187904,
                                  0,
                                  0,
                                  -0.33198397728871398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0013733028582081641,
                                  0,
                                  -0.060523820758603672,
                                  0,
                                  -0.054476688091312259,
                                  0,
                                  0,
                                  0,
                                  -0.014277455424107174,
                                  0,
                                  0,
                                  0.03588651012532388,
                                  0,
                                  -0.11466510521012163,
                                  0,
                                  -0.015335611242049622,
                                  0.24570737087554437,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075509448820284791,
                                  0.48082333425235085,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16452500552357568,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20449538759197439,
                                  -0.10315141099610894,
                                  -0.08249915147154345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13083355938406074,
                                  0,
                                  0.030734893800719833,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17945608620166206,
                                  -0.40023549852357865,
                                  0,
                                  0,
                                  0.067881281705259366,
                                  0,
                                  -0.22388997826141563,
                                  -0.064669701098982846,
                                  0.37858910404753043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10471285820892484,
                                  0,
                                  0,
                                  0.26817077064104605,
                                  0,
                                  -0.1374693592516352,
                                  0,
                                  0,
                                  -0.15656308406343891,
                                  0,
                                  0.043301265836763893,
                                  -0.20624014100078689,
                                  0,
                                  -0.048522207016979006,
                                  0,
                                  0,
                                  -0.15826292040241335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16295410197712298,
                                  0,
                                  -0.1447958646574109,
                                  0,
                                  0.1216976902401621,
                                  0,
                                  0,
                                  0,
                                  -0.15985220747405465,
                                  0,
                                  0,
                                  0.26698709403993642,
                                  0,
                                  0.10938826431992295,
                                  0,
                                  -0.038425666576689541,
                                  0.28100863523789926,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2103266894684267,
                                  -0.16978976291485956,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18677186687737529,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097383630040442704,
                                  0.13125638510535889,
                                  -0.22007695838646502,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073244069186725727,
                                  0,
                                  -0.37578893498157506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039975468588707354,
                                  0.12962731856318105,
                                  0,
                                  -0.24693812673645985,
                                  0,
                                  -0.05150687532794352,
                                  0,
                                  0,
                                  0,
                                  -0.012332895230004087,
                                  0,
                                  -0.0052067373146705859,
                                  0,
                                  0,
                                  0.0785179054597899,
                                  0.028872820649656638,
                                  0,
                                  0,
                                  0.057661071118763507,
                                  -0.15086138131614596,
                                  0,
                                  -0.18177615369421238,
                                  0,
                                  0,
                                  0.23190226895192947,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17350602383111063,
                                  0,
                                  0.03396804749618388,
                                  -0.4068150979349075,
                                  0,
                                  0,
                                  0.22367849108803725,
                                  -0.00093357077000725175,
                                  -0.078332221782678527,
                                  0,
                                  -0.068642863974038876,
                                  0,
                                  0.08514096618977704,
                                  0,
                                  0,
                                  0.12260911633548674,
                                  -0.087232361408731265,
                                  0,
                                  0,
                                  -0.2617952680209929,
                                  0,
                                  0,
                                  0,
                                  0.30686082133339576,
                                  0,
                                  0,
                                  -0.0092297211079744902,
                                  -0.22510660082129491,
                                  0,
                                  0,
                                  0.13880427765155398,
                                  0,
                                  -0.094262009523484833,
                                  0.023744175684694523,
                                  0,
                                  0,
                                  -0.072401858039324432,
                                  -0.082545797017878508,
                                  0.10783692162968561,
                                  0,
                                  0,
                                  0.0045052828741902733,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22712544140033419,
                                  -0.35360979996451136,
                                  0,
                                  0.15512317742783555,
                                  -0.075958240578302236,
                                  0,
                                  0,
                                  0,
                                  0.17079516297935479,
                                  -0.16255052216596161,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0099735049764288139,
                                  0,
                                  0,
                                  0,
                                  -0.02260256378066931,
                                  0,
                                  0,
                                  0,
                                  0.014653946153979153,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17283336396873278,
                                  0,
                                  -0.071739085246421488,
                                  0.20514670776224986,
                                  0,
                                  0,
                                  0.040381425644208546,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078618597222003789,
                                  0,
                                  0,
                                  0.1230080530608499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16922012286098537,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058070276081990585,
                                  0,
                                  0,
                                  0,
                                  -0.14922044752566618,
                                  0,
                                  0,
                                  -0.081462458575262658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.060988152093954515,
                                  0.10146130636668563,
                                  0,
                                  0.030332820593329077,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14763820697926985,
                                  -0.26034587195601744,
                                  0,
                                  0.25314913483254198,
                                  0,
                                  0.081073075412545215,
                                  -0.06016280609451681,
                                  0.19192740915006445,
                                  0,
                                  0,
                                  -0.13363940571134514,
                                  0,
                                  0,
                                  -0.10055490650290833,
                                  -0.066672378838438018,
                                  -0.14848873172877639,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29753056084898871,
                                  -0.016795270135929012,
                                  0.083047785097838514,
                                  -0.49822877285590456,
                                  0,
                                  0,
                                  0,
                                  0.44769920930709606,
                                  -0.15352099972180094,
                                  0,
                                  0.03188038748975959,
                                  0,
                                  0,
                                  0,
                                  -0.030989642237467536,
                                  0,
                                  -0.0264380583537598,
                                  0,
                                  0,
                                  0,
                                  0.35190078776243644,
                                  0,
                                  0.064930448409709518,
                                  0,
                                  0,
                                  -0.22997384988972605,
                                  -0.23095558098152447,
                                  0,
                                  0,
                                  0.26281086153798261,
                                  -0.0072893709423590544,
                                  0,
                                  -0.10157502260560687,
                                  0,
                                  0,
                                  -0.09108667804765104,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074264092125358921,
                                  0,
                                  0.30021294588092906,
                                  0.11440016862382671,
                                  0,
                                  0,
                                  0.13872713808418202,
                                  -0.23152645761390306,
                                  -0.20032594765631079,
                                  0,
                                  -0.067578286317206707,
                                  0,
                                  -0.01546826787409614,
                                  0,
                                  0,
                                  -0.054477554096491312,
                                  0.17299128406058381,
                                  0,
                                  0,
                                  -0.32149444394569737,
                                  0,
                                  0,
                                  0,
                                  -0.27531363164854439,
                                  0,
                                  0,
                                  -0.048388281144530421,
                                  -0.023415396033385119,
                                  0,
                                  0,
                                  0.19167977957525259,
                                  0,
                                  0.12471365729334533,
                                  -0.21812761663296146,
                                  0,
                                  0,
                                  -0.0089987105460512112,
                                  -0.012336702643373778,
                                  -0.1480203775180331,
                                  0,
                                  0,
                                  -0.21891985678410558,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092967941950610949,
                                  0.078924169702714639,
                                  0,
                                  0.13869659915270474,
                                  -0.056124901365683003,
                                  0,
                                  0,
                                  0,
                                  -0.0023617469172818248,
                                  -0.053581339686894984,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13665146530294814,
                                  0,
                                  0,
                                  0,
                                  -0.0098058578472333541,
                                  0,
                                  0,
                                  0,
                                  -0.077589819212618288,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049000009793853626,
                                  0,
                                  -0.13360127831652455,
                                  0.24275169606069194,
                                  0,
                                  0,
                                  -0.22450529177876113,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15963368153044727,
                                  0,
                                  0,
                                  -0.14956887393560456,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30751036875265336,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092646640025536478,
                                  0,
                                  0,
                                  0,
                                  -0.1227427463481273,
                                  0,
                                  0,
                                  0.091863860302420788,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24000872204538901,
                                  -0.058609892649424379,
                                  0,
                                  0.24799182746990542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027501090398760763,
                                  0.25352098326322314,
                                  0,
                                  -0.3066752217989252,
                                  0,
                                  0.26645633437623167,
                                  0.004907714197493274,
                                  0.1860254829646911,
                                  0,
                                  0,
                                  0.12329724254549958,
                                  0,
                                  0,
                                  0.11393719426053298,
                                  -0.078649261936893908,
                                  0.1582132365119677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20812623612833772,
                                  -0.096854486725488062,
                                  0.066788324057427198,
                                  -0.076578242556860923,
                                  0,
                                  0,
                                  0,
                                  0.32812857302614717,
                                  -0.23004450340094637,
                                  0,
                                  -0.16017293255360612,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22868800746979887,
                                  0,
                                  -0.36149591837478001,
                                  0.051489674838242849,
                                  0,
                                  0,
                                  0.15989024556206288,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20544653026866691,
                                  0,
                                  0,
                                  0.15432510289429541,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056403664766287963,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38947636522938989,
                                  0,
                                  0,
                                  0,
                                  -0.037688583163960128,
                                  0,
                                  0,
                                  -0.0042865562482794009,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28918891422194554,
                                  -0.045658780474910989,
                                  0,
                                  0.15411000532326255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13621528202319932,
                                  -0.1360549963643759,
                                  0,
                                  -0.016481303591462361,
                                  0,
                                  -0.10021915985001822,
                                  -0.13822966793897709,
                                  -0.38129896985878253,
                                  0,
                                  0,
                                  0.092438725352046142,
                                  0,
                                  0,
                                  0.12184725888143277,
                                  0.10378126922221377,
                                  -0.093930232282193105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36222370896466155,
                                  0.18619610879431714,
                                  -0.054327391349327389,
                                  0.013406292031874351,
                                  0,
                                  0,
                                  0,
                                  0.072141293580054056,
                                  -0.039016532650230001,
                                  0,
                                  -0.16251045860466684,
                                  0,
                                  0,
                                  0,
                                  -0.12046113191828431,
                                  0,
                                  0.42406922596278074,
                                  0,
                                  0,
                                  0,
                                  0.069461463406868734,
                                  0,
                                  0.14709989623966616,
                                  0,
                                  0,
                                  0.1392476177290603,
                                  0.12250943841098164,
                                  0,
                                  0,
                                  0.29101518263688347,
                                  -0.16473305764889509,
                                  0,
                                  -0.090825734241336997,
                                  0,
                                  0,
                                  -0.046448025353031629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14318561531038518,
                                  0,
                                  0.069856777734364828,
                                  -0.15720237111778571,
                                  0,
                                  0,
                                  -0.0352669498792956,
                                  -0.016875714490923698,
                                  0.028017189365561503,
                                  0,
                                  -0.19540502218963499,
                                  0,
                                  -0.035307275193291451,
                                  0,
                                  0,
                                  -0.050290941507408891,
                                  0.12397327825618883,
                                  0,
                                  0,
                                  0.11938872009195768,
                                  0,
                                  0,
                                  0,
                                  0.15229673468743837,
                                  0,
                                  0,
                                  -0.081542888661199742,
                                  0.26141506202988407,
                                  0,
                                  0,
                                  0.067209858969651926,
                                  0,
                                  -0.32297632287261058,
                                  -0.24825495908740142,
                                  0,
                                  0,
                                  0.17074610597888382,
                                  0.1428706487176408,
                                  -0.051756261661185458,
                                  0,
                                  0,
                                  -0.1361586343835694,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1432729420122677,
                                  0.082961711890678858,
                                  0,
                                  -0.2660082695164061,
                                  -0.069679297300369009,
                                  0,
                                  0,
                                  0,
                                  0.095874364753391977,
                                  0.15707783341965986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.013772852499197887,
                                  0,
                                  0,
                                  0,
                                  -0.075440711632225987,
                                  0,
                                  0,
                                  0,
                                  0.12794673067449638,
                                  0.1232660788922141,
                                  0,
                                  0.11350891376550028,
                                  0,
                                  0,
                                  0,
                                  -0.2670998206951154,
                                  0,
                                  -0.10182455063684341,
                                  0,
                                  0,
                                  0.12371766650584774,
                                  -0.004743362157467102,
                                  0,
                                  0,
                                  0.23072230690301135,
                                  -0.018636801557594659,
                                  0,
                                  -0.21343108500685454,
                                  0,
                                  0,
                                  0.31273044785687637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.018927208825663913,
                                  0,
                                  0.24013575112682048,
                                  0.054221557225686952,
                                  0,
                                  0,
                                  0.050094724743747564,
                                  0.017264738045388545,
                                  -0.074864039264638055,
                                  0,
                                  0.078421316054549661,
                                  0,
                                  0.03654827815028442,
                                  0,
                                  0,
                                  -0.08630872162750608,
                                  -0.12215067714704488,
                                  0,
                                  0,
                                  0.018092364912202587,
                                  0,
                                  0,
                                  0,
                                  -0.27544903290157946,
                                  0,
                                  0,
                                  -0.32116730931045584,
                                  -0.046607478404876689,
                                  0,
                                  0,
                                  -0.011298182177517784,
                                  0,
                                  0.25413718678514552,
                                  0.1521976069015242,
                                  0,
                                  0,
                                  0.010803540578584486,
                                  0.0476468337994084,
                                  -0.070314868861604582,
                                  0,
                                  0,
                                  0.16510823805278982,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11966296713712468,
                                  -0.11967717784828259,
                                  0,
                                  -0.3825140282525154,
                                  0.04651379160784435,
                                  0,
                                  0,
                                  0,
                                  0.18539273225454961,
                                  -0.10657551314798036,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.041771700967784473,
                                  0,
                                  0,
                                  0,
                                  -0.082163122150222187,
                                  0,
                                  0,
                                  0,
                                  -0.20828161541149681,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19722500234731893,
                                  0,
                                  -0.25861781423891911,
                                  0.20252204018191,
                                  0,
                                  0,
                                  -0.18389452232618198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032343482369268324,
                                  0,
                                  0,
                                  -0.086389358711867051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.076297468833582405,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12157783220888438,
                                  0,
                                  0,
                                  0,
                                  -0.097272666114667949,
                                  0,
                                  0,
                                  0.2976999090804166,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18758896477391226,
                                  0.4124482101079604,
                                  0,
                                  -0.32556580119175071,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053679860546513788,
                                  0.11368782602275787,
                                  0,
                                  0.083580969777241151,
                                  0,
                                  0.09282300936029915,
                                  0.31589586584065582,
                                  0.24749726586522702,
                                  0,
                                  0,
                                  -0.048245885048607745,
                                  0,
                                  0,
                                  -0.095648271302772744,
                                  -0.1359782156899999,
                                  -0.078185667905420531,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17154078686142152,
                                  -0.067464442236269045,
                                  -0.28289223511810246,
                                  0.07189274935656241,
                                  0,
                                  0,
                                  0,
                                  -0.16263783077970267,
                                  0.036948487281363726,
                                  0,
                                  0.073268802514760936,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.015818677747404711,
                                  0,
                                  -0.20054913441008734,
                                  -0.04083722977204271,
                                  -0.0081135476088499379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42361881031920939,
                                  0,
                                  0,
                                  -0.013508821963706719,
                                  0,
                                  -0.002704914428703166,
                                  0,
                                  0,
                                  0.053277767898877795,
                                  0,
                                  -0.15628748623236327,
                                  -0.24038871590836658,
                                  0,
                                  0.25684535150418519,
                                  0,
                                  0,
                                  0.2412632352366649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22253870832066236,
                                  0,
                                  0.20391099017299077,
                                  0,
                                  -0.0056725106905168212,
                                  0,
                                  0,
                                  0,
                                  0.00054512085835325269,
                                  0,
                                  0,
                                  -0.030999689672474566,
                                  0,
                                  -0.080017236218132212,
                                  0,
                                  -0.16914368061903928,
                                  -0.061089813234741594,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40205734767020651,
                                  -0.10801608646477065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20298225374876652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22340634311377192,
                                  0.025481353025095806,
                                  -0.17127883664647536,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10506335782074493,
                                  0,
                                  0.20526805392206227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30051565309654449,
                                  -0.013627164795922547,
                                  0,
                                  0.11557522836474685,
                                  0,
                                  0.030704733394229956,
                                  0,
                                  0,
                                  0,
                                  -0.3062691649730353,
                                  0,
                                  -0.033202441800498562,
                                  0,
                                  0,
                                  0.10392689922609441,
                                  -0.15589478000921553,
                                  0,
                                  0,
                                  -0.18765646290902369,
                                  -0.18057674823687264,
                                  0,
                                  -0.049532622818362716,
                                  0,
                                  0,
                                  -0.16488746220096376,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027116547841781559,
                                  0,
                                  -0.21401963840830932,
                                  0.0066173630566919057,
                                  0,
                                  0,
                                  0.14515520756414663,
                                  -0.24959095846320023,
                                  -0.065002897207994154,
                                  0,
                                  -0.024432063132980814,
                                  0,
                                  -0.019618711879842231,
                                  0,
                                  0,
                                  0.050124922547121947,
                                  -0.11677016044568841,
                                  0,
                                  0,
                                  -0.14789343322772616,
                                  0,
                                  0,
                                  0,
                                  -0.021100915215296431,
                                  0,
                                  0,
                                  -0.12559684179276695,
                                  -0.00096613038533893388,
                                  0,
                                  0,
                                  -0.050775275838292555,
                                  0,
                                  -0.098540516470856501,
                                  0.034126073534697834,
                                  0,
                                  0,
                                  0.040194612530355237,
                                  -0.2229278498743561,
                                  0.058891270115635851,
                                  0,
                                  0,
                                  -0.32282585988507451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11357131691836055,
                                  0.14107465614781176,
                                  0,
                                  -0.18509089502322185,
                                  -0.10608828399538019,
                                  0,
                                  0,
                                  0,
                                  0.045190289088430133,
                                  -0.17413301000320255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39182907484404905,
                                  0,
                                  0,
                                  0,
                                  0.32183173978702967,
                                  0,
                                  0,
                                  0,
                                  0.16910538753641802,
                                  -0.17240812402387279,
                                  0,
                                  -0.18975447054561592,
                                  0,
                                  0,
                                  0,
                                  0.25984823216775599,
                                  0,
                                  -0.15485192495478295,
                                  0,
                                  0,
                                  0.23682270266392508,
                                  0.015228345868518152,
                                  0,
                                  0,
                                  -0.34305315292478961,
                                  -0.11016752167133573,
                                  0,
                                  -0.11902932894355361,
                                  0,
                                  0,
                                  -0.11667611468823241,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019225501253010476,
                                  0,
                                  -0.14427129141079395,
                                  -0.17858589843029296,
                                  0,
                                  0,
                                  -0.035226395386516424,
                                  0.062782979481059639,
                                  0.10613446852284458,
                                  0,
                                  0.049691127233199822,
                                  0,
                                  0.021507741426767903,
                                  0,
                                  0,
                                  0.12091257112093538,
                                  0.14686089958481466,
                                  0,
                                  0,
                                  -0.21652990035177852,
                                  0,
                                  0,
                                  0,
                                  -0.090520118906513194,
                                  0,
                                  0,
                                  -0.30499270440982507,
                                  0.15251440595582377,
                                  0,
                                  0,
                                  0.12006350023493395,
                                  0,
                                  0.31095501524083274,
                                  0.04904237487812365,
                                  0,
                                  0,
                                  0.16447134385975268,
                                  0.01505027087642917,
                                  -0.12497703151031782,
                                  0,
                                  0,
                                  0.10032658082453672,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20638144523793564,
                                  0.073061435563452307,
                                  0,
                                  -0.021339371708363166,
                                  -0.10344992961927971,
                                  0,
                                  0,
                                  0,
                                  0.1097821050738193,
                                  0.20464638483600356,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019718932799189709,
                                  0,
                                  0,
                                  0,
                                  -0.21985719620709701,
                                  0,
                                  0,
                                  0,
                                  0.14360275333951958,
                                  0,
                                  0.22693653293975938,
                                  0,
                                  -0.3279683446927511,
                                  -0.1307468103962538,
                                  0.015505608558988006,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22988943649902716,
                                  0,
                                  0,
                                  -0.038912105022245215,
                                  0,
                                  -0.02675146234580289,
                                  0,
                                  0,
                                  0.096844384423969809,
                                  0,
                                  -0.33763267348680981,
                                  -0.19155396698224086,
                                  0,
                                  0.072006361487742393,
                                  0,
                                  0,
                                  0.07037432062191612,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38318101098015933,
                                  0,
                                  0.11816378133621659,
                                  0,
                                  0.10098169801231302,
                                  0,
                                  0,
                                  0,
                                  -0.059093722280506147,
                                  0,
                                  0,
                                  -0.25780248695050439,
                                  0,
                                  -0.18778732871597376,
                                  0,
                                  0.31152567522311314,
                                  0.14009393180851187,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059276969508697153,
                                  0.1522981991988942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.214091765203718,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10074653192767119,
                                  0.048335888446555196,
                                  -0.226758372033907,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11704811377759174,
                                  0,
                                  -0.074214851215125555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11343720460022055,
                                  0.19212357886394846,
                                  0,
                                  0.046867492773630059,
                                  0,
                                  0.081944800753430802,
                                  0,
                                  0,
                                  0,
                                  -0.046578289934468477,
                                  0,
                                  0.064253668428804034,
                                  0,
                                  0,
                                  -0.14688624668232472,
                                  0.229181730073554,
                                  0,
                                  0,
                                  0.079607248387162113,
                                  0.14355954847776792,
                                  0,
                                  -0.29881534581203328,
                                  0,
                                  0,
                                  0.01391194658581309,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18860427902810117,
                                  0,
                                  -0.028198196616854319,
                                  -0.079501596851344836,
                                  0,
                                  0,
                                  -0.33875862783659799,
                                  -0.15491400421597887,
                                  0.28815091168354007,
                                  0,
                                  -0.26105287784212489,
                                  0,
                                  -0.0024082839310529004,
                                  0,
                                  0,
                                  0.13031361808871292,
                                  0.025006140164377411,
                                  0,
                                  0,
                                  -0.054314280413470209,
                                  0,
                                  0,
                                  0,
                                  -0.25248621124602499,
                                  0,
                                  0,
                                  0.12008520345760854,
                                  0.16725731259767551,
                                  0,
                                  0,
                                  -0.0034086363745422441,
                                  0,
                                  0.064037849231321692,
                                  0.18817320321684533,
                                  0,
                                  0,
                                  0.02344808414719278,
                                  -0.10840862345812557,
                                  -0.11736712425072134,
                                  0,
                                  0,
                                  0.16726280110926939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19139382003315922,
                                  -0.013511947159150337,
                                  0,
                                  0.18103887977906152,
                                  0.16338736963562164,
                                  0,
                                  0,
                                  0,
                                  0.1505635097225852,
                                  -0.0087429619332325004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21651418573423784,
                                  0,
                                  0,
                                  0,
                                  0.20440014885841193,
                                  0,
                                  0,
                                  0,
                                  0.18348204087290157,
                                  0,
                                  0.017676252507128391,
                                  0,
                                  -0.047867192042496461,
                                  0.037078734242837107,
                                  0.02418162964815268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33991119086838273,
                                  0,
                                  0,
                                  -0.035348193414012463,
                                  0,
                                  0.47679550269286858,
                                  0,
                                  0,
                                  -0.032374765484461672,
                                  0,
                                  -0.10969585689026373,
                                  0.15135086884481214,
                                  0,
                                  0.28098633387485678,
                                  0,
                                  0,
                                  0.12968196455107817,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4428923781420514,
                                  0,
                                  -0.025227035290688218,
                                  0,
                                  0.11698503076268146,
                                  0,
                                  0,
                                  0,
                                  -0.14445093946911974,
                                  0,
                                  0,
                                  0.10082484540547026,
                                  0,
                                  0.1645965867732318,
                                  0,
                                  -0.079060950213026809,
                                  -0.086096455145654796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.042210703112285398,
                                  0.11838434391055747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.058569112879450408,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13570730270221726,
                                  0.038602953898246604,
                                  -0.013764037296321627,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11062616898453301,
                                  0,
                                  -0.32310701515614193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22782414054992159,
                                  -0.17154818729991167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026584734770439031,
                                  0,
                                  0.20595364265137209,
                                  -0.066944230556302609,
                                  0,
                                  0,
                                  -0.22090573483503673,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22889069569004675,
                                  0,
                                  0,
                                  7.6170881567650447e-05,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27120320681492333,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2109276829930625,
                                  0,
                                  0,
                                  0,
                                  0.028030968630997001,
                                  0,
                                  0,
                                  0.24800197267631555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.099842278742475671,
                                  0.2804782729775801,
                                  0,
                                  0.1099902353781904,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.012246266027354314,
                                  -0.12888303521080272,
                                  0,
                                  -0.18184027192234745,
                                  0,
                                  -0.18581905967664189,
                                  -0.17584647815888474,
                                  -0.20300606976265487,
                                  0,
                                  0,
                                  -0.074764255024138318,
                                  0,
                                  0,
                                  0.010774223974173186,
                                  -0.2860094628407745,
                                  -0.019143384445737491,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15692530403113275,
                                  0.015784083823132931,
                                  0.015763428955523358,
                                  0.30888766145492458,
                                  0,
                                  0,
                                  0,
                                  0.42924138419015589,
                                  -0.14363808252195534,
                                  0,
                                  0.018984071973339095,
                                  0,
                                  0,
                                  0,
                                  -0.11746276930191395,
                                  0,
                                  0.13531642829955304,
                                  0,
                                  0,
                                  0,
                                  -0.01032187340020245,
                                  0,
                                  -0.48141223463666039,
                                  0,
                                  0,
                                  -0.074273470286631352,
                                  -0.16984999330125275,
                                  0,
                                  0,
                                  0.12651551920131793,
                                  0.0089265323426128175,
                                  0,
                                  -0.030556235951660966,
                                  0,
                                  0,
                                  -0.041278332922827399,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41540298183796365,
                                  0,
                                  -0.16802353462965247,
                                  0.013080273893569493,
                                  0,
                                  0,
                                  0.06981672177882918,
                                  0.12163041781033229,
                                  -0.12047915114948954,
                                  0,
                                  -0.25095581143673856,
                                  0,
                                  0.26576126697925956,
                                  0,
                                  0,
                                  0.086548262845611096,
                                  0.061725785203245252,
                                  0,
                                  0,
                                  0.098814431068794076,
                                  0,
                                  0,
                                  0,
                                  -0.18272311537208263,
                                  0,
                                  0,
                                  0.027672278765516665,
                                  0.23541346835433699,
                                  0,
                                  0,
                                  0.086501035924565581,
                                  0,
                                  -0.10886335499853945,
                                  0.038989328752802629,
                                  0,
                                  0,
                                  0.013874674048417811,
                                  0.10288397094555982,
                                  0.17346164478812234,
                                  0,
                                  0,
                                  0.18378431486845684,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059664325704528856,
                                  -0.19710854095876751,
                                  0,
                                  0.021296278442858464,
                                  -0.13553892462545822,
                                  0,
                                  0,
                                  0,
                                  -0.088406662395510621,
                                  -0.099530368274518638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0018151482736685418,
                                  0,
                                  0,
                                  0,
                                  0.051125959744718556,
                                  0,
                                  0,
                                  0,
                                  0.16270970659573519,
                                  0,
                                  -0.0091235707856397452,
                                  0,
                                  -0.25575558296013495,
                                  -0.071674033235872528,
                                  -0.24059471120216558,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16878818948492019,
                                  0,
                                  0,
                                  0.16736605593124015,
                                  0,
                                  0.018249338403626192,
                                  0,
                                  0,
                                  0.29316568486665673,
                                  0,
                                  0.079519065119889501,
                                  0.21445022883116396,
                                  0,
                                  0.19327861285392031,
                                  0,
                                  0,
                                  -0.30751822151563213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32131316089755996,
                                  0,
                                  0.13169383656152087,
                                  0,
                                  0.27131128210721872,
                                  0,
                                  0,
                                  0,
                                  0.026729417090252713,
                                  0,
                                  0,
                                  0.064048116212123835,
                                  0,
                                  -0.10897583751801015,
                                  0,
                                  0.072135810549125462,
                                  -0.41307251627134223,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046565981423798246,
                                  0.089168234386882747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044545146533887081,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098926625027969881,
                                  0.072580140866395165,
                                  -0.19136298924797801,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09545185363304047,
                                  0,
                                  -0.20156893337119286,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1698750734485539,
                                  -0.12397627751354298,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.059289126856857784,
                                  0,
                                  -0.057122183648786629,
                                  -0.034636916095524439,
                                  0,
                                  0,
                                  -0.46353512332889479,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.079321786253377449,
                                  0,
                                  0,
                                  -0.025104412087241748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15353524991197148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1671499445807379,
                                  0,
                                  0,
                                  0,
                                  0.1764161069206179,
                                  0,
                                  0,
                                  -0.10184927664301276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18569262915440587,
                                  0.13382161836818007,
                                  0,
                                  -0.032404982861407979,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19242217972540876,
                                  0.1040957834019981,
                                  0,
                                  0.39800054701637733,
                                  0,
                                  -0.014368281788789407,
                                  -0.45600947859457192,
                                  0.14454440539531591,
                                  0,
                                  0,
                                  0.076737946845271396,
                                  0,
                                  0,
                                  0.083374760560439021,
                                  0.15293658599184445,
                                  0.15294023829413361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14631225639954773,
                                  0.085378074274804136,
                                  0.26368776628697577,
                                  0.025451848855034449,
                                  0,
                                  0,
                                  0,
                                  -0.13789007855033214,
                                  -0.057876089948062898,
                                  0,
                                  0.087273906217123998,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044084979867418203,
                                  0,
                                  -0.18896573869477806,
                                  -0.088824272981624694,
                                  0.031524715206329039,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27894072475303011,
                                  0,
                                  0,
                                  0.062753153528362859,
                                  0,
                                  -0.023502321324372855,
                                  0,
                                  0,
                                  0.14877756481100426,
                                  0,
                                  0.23373931623787642,
                                  -0.026126270339301153,
                                  0,
                                  -0.057944499926460107,
                                  0,
                                  0,
                                  -0.077167971159949889,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052779633122885652,
                                  0,
                                  -0.024826439800103538,
                                  0,
                                  0.0086049489833958694,
                                  0,
                                  0,
                                  0,
                                  -0.53697910843477858,
                                  0,
                                  0,
                                  -0.024167671758302089,
                                  0,
                                  -0.22280729221661355,
                                  0,
                                  0.20155483153690409,
                                  -0.13130662527420878,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014715340298389563,
                                  -0.2448668276262691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.020431027047134349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.280879728393229,
                                  -0.37099058977824362,
                                  0.2229757936954499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20378860237399776,
                                  0,
                                  0.086803535427297435,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06527839788232305,
                                  0.065741133008218794,
                                  0,
                                  0,
                                  -0.13536599441967345,
                                  0,
                                  -0.048927351444271211,
                                  -0.11104791632350447,
                                  0.021773438168850072,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025578161454759274,
                                  0,
                                  0,
                                  0.025838653936379005,
                                  0,
                                  -0.18821639798417603,
                                  0,
                                  0,
                                  0.44943101753211528,
                                  0,
                                  0.15583277942939092,
                                  0.17451283345022311,
                                  0,
                                  -0.05660612206169454,
                                  0,
                                  0,
                                  0.26531506027057111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21500270465587201,
                                  0,
                                  -0.007901968381975568,
                                  0,
                                  -0.046892890827872354,
                                  0,
                                  0,
                                  0,
                                  0.17433225912697012,
                                  0,
                                  0,
                                  0.16843470264031613,
                                  0,
                                  0.10668452542111975,
                                  0,
                                  0.056000079535326902,
                                  0.10620605485669124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.086114151080889226,
                                  -0.31214008066943943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085753526508671712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13234660686646277,
                                  0.26885090251246613,
                                  -0.13222661563985455,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13382280699754545,
                                  0,
                                  -0.082324760651424772,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31007273314851957,
                                  -0.35503108420143381,
                                  0,
                                  0.023624479561498306,
                                  0,
                                  -0.25898288906217459,
                                  0,
                                  0,
                                  0,
                                  -0.16992240585476343,
                                  0,
                                  0.053378511021195368,
                                  0,
                                  0,
                                  0.096715796665227921,
                                  0.13326608100190032,
                                  0,
                                  0,
                                  0.15891163594253527,
                                  -0.052882007267831418,
                                  0,
                                  -0.13646744237050346,
                                  0,
                                  0,
                                  -0.19772345042247166,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28609042344360386,
                                  0,
                                  -0.0079909608718241754,
                                  0.14356747249452104,
                                  0,
                                  0,
                                  -0.10385011818998098,
                                  -0.097287433519189767,
                                  -0.036280764509808078,
                                  0,
                                  -0.017223669397802909,
                                  0,
                                  -0.038734310462878258,
                                  0,
                                  0,
                                  -0.15319481737426396,
                                  -0.16548727464557811,
                                  0,
                                  0,
                                  0.010924861715393263,
                                  0,
                                  0,
                                  0,
                                  0.18537464908865323,
                                  0,
                                  0,
                                  -0.40970133811869935,
                                  0.023477145699883434,
                                  0,
                                  0,
                                  0.13514562509619291,
                                  0,
                                  -0.25661981041172904,
                                  0.14492526351613458,
                                  0,
                                  0,
                                  0.04609885984361984,
                                  0.078858839765724581,
                                  -0.26115428832360915,
                                  0,
                                  0,
                                  -0.020337230445830343,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1389267314808097,
                                  -0.19458724224281806,
                                  0,
                                  0.21966076803354898,
                                  0.09106769249414573,
                                  0,
                                  0,
                                  0,
                                  -0.16854511330304708,
                                  0.26068227383599979,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.099131474376506545,
                                  0,
                                  0,
                                  0,
                                  -0.044483167154767661,
                                  0,
                                  0,
                                  0,
                                  -0.064633317894590661,
                                  0,
                                  0.030632875170516105,
                                  0,
                                  0.15523958170452357,
                                  -0.21785401476131167,
                                  -0.1085764471973803,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13153059049983057,
                                  0,
                                  0,
                                  0.16811527023945194,
                                  0,
                                  0.14100168300899149,
                                  0,
                                  0,
                                  0.20169141193405155,
                                  0,
                                  -0.16789144341632736,
                                  -0.26768184113609755,
                                  0,
                                  -0.20351418116229761,
                                  0,
                                  0,
                                  -0.097181876526058641,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13340845593113132,
                                  0,
                                  -0.24548925366612681,
                                  0,
                                  0.20582075474415751,
                                  0,
                                  0,
                                  0,
                                  -0.10821416493327068,
                                  0,
                                  0,
                                  0.15608183417284682,
                                  0,
                                  0.21798177055263718,
                                  0,
                                  -0.042932528347562199,
                                  0.087414814668077642,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21071175955644814,
                                  -0.063743279015379434,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14250326919654685,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.023785217504077284,
                                  -0.085859223241776875,
                                  -0.26615576039390648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12242871923309701,
                                  0,
                                  0.432929102662715,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27173409268596532,
                                  -0.14692241417921928,
                                  0,
                                  -0.071894551998485906,
                                  0,
                                  -0.016369590341425974,
                                  0,
                                  0,
                                  0,
                                  0.23797840914825974,
                                  0,
                                  -0.13513513010956393,
                                  0,
                                  0,
                                  0.28992807882262422,
                                  0.19425667938301694,
                                  0,
                                  0,
                                  0.19403074517679142,
                                  -0.042315730994498514,
                                  0,
                                  -0.099020725156730147,
                                  0,
                                  0,
                                  0.15963410754017407,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0020182262627452367,
                                  0,
                                  -0.17074117728488136,
                                  0.25469117074102449,
                                  0,
                                  0,
                                  -0.010914855913180154,
                                  0.22903679215227887,
                                  -0.1117186344530592,
                                  0,
                                  0.12923072979419717,
                                  0,
                                  -0.18152757498500355,
                                  0,
                                  0,
                                  -0.11453133589055468,
                                  -0.028727430215817251,
                                  0,
                                  0,
                                  -0.24614803056981693,
                                  0,
                                  0,
                                  0,
                                  -0.21199970619595476,
                                  0,
                                  0,
                                  0.0043746008433608301,
                                  -0.25424026287362067,
                                  0,
                                  0,
                                  -0.084172790864900038,
                                  0,
                                  -0.34100866170143185,
                                  0.012983209396425111,
                                  0,
                                  0,
                                  -0.022806780561751415,
                                  -0.17831454894003873,
                                  -0.039582905633597468,
                                  0,
                                  0,
                                  0.14554142501459025,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0039872544396745979,
                                  0.23584872501944298,
                                  0,
                                  0.02902468302631064,
                                  0.036903059239270224,
                                  0,
                                  0,
                                  0,
                                  0.018298309082821183,
                                  -0.072019832193122552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12000159267722404,
                                  0,
                                  0,
                                  0,
                                  0.13632763666505768,
                                  0,
                                  0,
                                  0,
                                  0.23520547839145833,
                                  -0.22985396873582348,
                                  0,
                                  0.032742681689811801,
                                  0,
                                  0,
                                  0,
                                  -0.27694823735598356,
                                  0,
                                  0.18934438557599012,
                                  0,
                                  0,
                                  -0.24556714065260099,
                                  -0.0032983934567448075,
                                  0,
                                  0,
                                  0.089198073825050739,
                                  0.10890481676883271,
                                  0,
                                  -0.0898962570418982,
                                  0,
                                  0,
                                  0.071440308526239046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0244315125321342,
                                  0,
                                  -0.10646267637981935,
                                  0.15012356092937451,
                                  0,
                                  0,
                                  0.13500821242880245,
                                  -0.064358263590667666,
                                  0.26881033778721031,
                                  0,
                                  0.034555185219942296,
                                  0,
                                  -0.031307155512240593,
                                  0,
                                  0,
                                  0.1256436721843589,
                                  -0.13026635233929126,
                                  0,
                                  0,
                                  -0.27974004033057193,
                                  0,
                                  0,
                                  0,
                                  0.074093429268992622,
                                  0,
                                  0,
                                  -0.15360464102281093,
                                  0.15342076256434747,
                                  0,
                                  0,
                                  0.076696537839047743,
                                  0,
                                  -0.038994411128833242,
                                  0.030189267963582862,
                                  0,
                                  0,
                                  0.050094029962879795,
                                  0.15783543793107463,
                                  0.055436590312608988,
                                  0,
                                  0,
                                  0.16389203128980184,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16287854314344744,
                                  0.3249063596218652,
                                  0,
                                  0.15282298063636576,
                                  -0.30740290417892435,
                                  0,
                                  0,
                                  0,
                                  -0.080566277900049471,
                                  -0.20169561277489115,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27014321739025626,
                                  0,
                                  0,
                                  0,
                                  -0.0096131597464154204,
                                  0,
                                  0,
                                  0,
                                  -0.097305718369164559,
                                  0,
                                  -0.23402889284247883,
                                  0,
                                  0.0083675042345510431,
                                  0.21380297734383352,
                                  0.0068176545694832412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2275787793928524,
                                  0,
                                  0,
                                  0.1947010284753016,
                                  0,
                                  0.16486206200926967,
                                  0,
                                  0,
                                  0.14815334001982583,
                                  0,
                                  0.034242949747923392,
                                  0.066713068388613295,
                                  0,
                                  -0.32751233605717495,
                                  0,
                                  0,
                                  0.058065945344263639,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049871759777313319,
                                  0,
                                  0.00442287091312237,
                                  0,
                                  0.20288660514134385,
                                  0,
                                  0,
                                  0,
                                  0.41240566449057897,
                                  0,
                                  0,
                                  0.12372075838845004,
                                  0,
                                  -0.34675664927240729,
                                  0,
                                  0.2015905455158748,
                                  0.18800752701469448,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14905871493526834,
                                  0.1950310154781007,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19151276536783729,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10250951590950458,
                                  -0.15818680050487055,
                                  -0.054460147077397637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049146921174225991,
                                  0,
                                  -0.080287052436501471,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0082242050135705232,
                                  0.27326516792209748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17283062550821079,
                                  0,
                                  0.29175120988701098,
                                  0.2158225580298726,
                                  0,
                                  0,
                                  -0.11872452322998577,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15938533924840931,
                                  0,
                                  0,
                                  0.31222034385593228,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13112920890332797,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06534110427134221,
                                  0,
                                  0,
                                  0,
                                  -0.21606890063850837,
                                  0,
                                  0,
                                  0.18484065848695458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22100363213181728,
                                  0.047792615011927789,
                                  0,
                                  0.14619002665562175,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16587721635832872,
                                  0.0017036178799341856,
                                  0,
                                  0.05722810974837355,
                                  0,
                                  -0.34171421954681563,
                                  -0.09197846020616679,
                                  0.09309582128486589,
                                  0,
                                  0,
                                  0.22247867184310893,
                                  0,
                                  0,
                                  0.016601820755287655,
                                  -0.14794095570310864,
                                  0.032340115323178459,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095272140563559024,
                                  0.31175443398267699,
                                  -0.080756022848388134,
                                  -0.27811096764460075,
                                  0,
                                  0,
                                  0,
                                  -0.17327188146602907,
                                  0.2490645486490129,
                                  0,
                                  -0.08397400006588622,
                                  0,
                                  0,
                                  0,
                                  0.26931065144450339,
                                  0,
                                  0.28880252944308288,
                                  0,
                                  0,
                                  0,
                                  0.11589061394674235,
                                  0,
                                  -0.050750917431559829,
                                  0,
                                  0,
                                  0.077849714803188683,
                                  0.19340082879049014,
                                  0,
                                  0,
                                  -0.11725012781997397,
                                  -0.0056117425710442087,
                                  0,
                                  -0.090588080381801023,
                                  0,
                                  0,
                                  -0.053197119254731307,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19284124933217697,
                                  0,
                                  -0.15123782147150422,
                                  -0.012796864318819438,
                                  0,
                                  0,
                                  0.13784103207241313,
                                  -0.25664164821997937,
                                  -0.26073566007420396,
                                  0,
                                  -0.024628729546719203,
                                  0,
                                  -0.15627916437131534,
                                  0,
                                  0,
                                  0.057216218368714447,
                                  -0.2803140426011293,
                                  0,
                                  0,
                                  -0.0078700032199470991,
                                  0,
                                  0,
                                  0,
                                  0.10707540133324674,
                                  0,
                                  0,
                                  0.1453591529949238,
                                  0.089926973519341702,
                                  0,
                                  0,
                                  -0.028089519019907458,
                                  0,
                                  0.12312901864934178,
                                  -0.225438951386187,
                                  0,
                                  0,
                                  -0.060218009997441771,
                                  -0.086280914211816287,
                                  -0.14242416885758147,
                                  0,
                                  0,
                                  0.28523982481388044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07507961803956599,
                                  -0.018166862767093978,
                                  0,
                                  0.18965309966164406,
                                  -0.15168642544571206,
                                  0,
                                  0,
                                  0,
                                  0.25514734478375334,
                                  0.14186610400122868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088141120649700519,
                                  0,
                                  0,
                                  0,
                                  0.074868700429820148,
                                  0,
                                  0,
                                  0,
                                  -0.23674843498022266,
                                  -0.23971852589299636,
                                  0,
                                  0.097181575868922732,
                                  0,
                                  0,
                                  0,
                                  -0.0041049045973669341,
                                  0,
                                  -0.18569848637855707,
                                  0,
                                  0,
                                  -0.35985438477948534,
                                  0.076342118091890593,
                                  0,
                                  0,
                                  0.0068099848486090422,
                                  -0.21908935478810854,
                                  0,
                                  -0.29896193981658908,
                                  0,
                                  0,
                                  -0.19786006703185885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044260230588696749,
                                  0,
                                  -0.019110185728793482,
                                  0.21619159829997761,
                                  0,
                                  0,
                                  -0.21049365401266679,
                                  -0.058340087894353646,
                                  0.046336127921753678,
                                  0,
                                  0.01466602506166987,
                                  0,
                                  -0.026223720810002658,
                                  0,
                                  0,
                                  0.0039344030139324832,
                                  -0.060609126041481963,
                                  0,
                                  0,
                                  0.01780094142198934,
                                  0,
                                  0,
                                  0,
                                  0.029428957819694013,
                                  0,
                                  0,
                                  -0.03075549384912964,
                                  -0.18531673814198965,
                                  0,
                                  0,
                                  -0.33046929198126362,
                                  0,
                                  0.077212419353634099,
                                  -0.014527827793563819,
                                  0,
                                  0,
                                  -0.22150799199287144,
                                  -0.2379637276322267,
                                  0.079407816949661147,
                                  0,
                                  0,
                                  -0.19458810040021737,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092416422193220882,
                                  -0.19616805109658872,
                                  0,
                                  -0.10806158203649832,
                                  -0.16594586362508904,
                                  0,
                                  0,
                                  0,
                                  0.023490915979628962,
                                  0.17647914684407701,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18796173213597869,
                                  0,
                                  0,
                                  0,
                                  -0.16661428862537586,
                                  0,
                                  0,
                                  0,
                                  0.020957385362906658,
                                  -0.12183101109497019,
                                  0,
                                  -0.15898664740441151,
                                  0,
                                  0,
                                  0,
                                  0.21514423623937562,
                                  0,
                                  0.28592301590410374,
                                  0,
                                  0,
                                  -0.058596180955612961,
                                  -0.086989508064030233,
                                  0,
                                  0,
                                  0.041252724065617433,
                                  -0.41624228971918015,
                                  0,
                                  -0.002492371068705217,
                                  0,
                                  0,
                                  0.17587328009580183,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021521951358614174,
                                  0,
                                  -0.24274051259190801,
                                  0.021334632512217476,
                                  0,
                                  0,
                                  0.12557544618898936,
                                  -0.08441187869021663,
                                  0.035170652437175223,
                                  0,
                                  -0.097488060617751199,
                                  0,
                                  0.031074380540342568,
                                  0,
                                  0,
                                  -0.24948717964887507,
                                  -0.14194472939711689,
                                  0,
                                  0,
                                  0.29345429963765796,
                                  0,
                                  0,
                                  0,
                                  -0.097875448438937113,
                                  0,
                                  0,
                                  0.19171730362585063,
                                  0.050652631704313979,
                                  0,
                                  0,
                                  0.031962620341034136,
                                  0,
                                  0.096300377424470521,
                                  0.2530401945848863,
                                  0,
                                  0,
                                  -0.088855077610154987,
                                  0.044549644472496722,
                                  -0.25475059525660443,
                                  0,
                                  0,
                                  0.12364297084847528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10999700844456561,
                                  0.024162151738221969,
                                  0,
                                  -0.14515488642388102,
                                  -0.29905732418271097,
                                  0,
                                  0,
                                  0,
                                  -0.090752982463285892,
                                  -0.025762176351140531,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07021840897620768,
                                  0,
                                  0,
                                  0,
                                  0.021921571549891761,
                                  0,
                                  0,
                                  0,
                                  0.034691476844942455,
                                  0,
                                  0.063139525916681385,
                                  0,
                                  0.12716161763707051,
                                  -0.001530398663002825,
                                  0.34776593488935859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058760227291809741,
                                  0,
                                  0,
                                  0.49173933547651544,
                                  0,
                                  0.02027172979440052,
                                  0,
                                  0,
                                  0.1147887422261791,
                                  0,
                                  -0.19520373231456284,
                                  0.13651592045023908,
                                  0,
                                  0.15588373511788378,
                                  0,
                                  0,
                                  0.20507559693174124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.066448948486391421,
                                  0,
                                  -0.013320864684619476,
                                  0,
                                  0.09907788112437832,
                                  0,
                                  0,
                                  0,
                                  0.041522589633914114,
                                  0,
                                  0,
                                  -0.10031945938560521,
                                  0,
                                  0.21738480443888797,
                                  0,
                                  -0.19205340091779446,
                                  -0.26124416759598873,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24645198748239072,
                                  0.22478024057187879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.015419385197354887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13567858894124071,
                                  -0.13736252659020801,
                                  0.061749866186110489,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18065125092859172,
                                  0,
                                  0.14715057152110617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25134304526474754,
                                  0.16826900452323071,
                                  0,
                                  0.076010065713380537,
                                  0,
                                  0.054705493531625175,
                                  0,
                                  0,
                                  0,
                                  -0.075896293818749919,
                                  0,
                                  -0.18251814944150044,
                                  0,
                                  0,
                                  0.022126809264132713,
                                  0.078671971320204523,
                                  0,
                                  0,
                                  -0.013018676791394405,
                                  -0.097486723410708978,
                                  0,
                                  -0.15207333137175141,
                                  0,
                                  0,
                                  -0.05812282959367171,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.054676243025687798,
                                  0,
                                  0.1607254357648043,
                                  -0.016422798581411619,
                                  0,
                                  0,
                                  0.2550903882760735,
                                  0.11070939802564686,
                                  0.17180453523373643,
                                  0,
                                  0.069930324634676716,
                                  0,
                                  -0.12431837902157325,
                                  0,
                                  0,
                                  -0.045144912350176453,
                                  0.020492901869290342,
                                  0,
                                  0,
                                  -0.23367562515488666,
                                  0,
                                  0,
                                  0,
                                  -0.11122792766276549,
                                  0,
                                  0,
                                  0.43787051064903093,
                                  -0.031875996363626265,
                                  0,
                                  0,
                                  -0.0063083899083495425,
                                  0,
                                  -0.13097196574113404,
                                  0.2720480843407278,
                                  0,
                                  0,
                                  0.23391029464363067,
                                  0.15031557495981523,
                                  0.10733566763373598,
                                  0,
                                  0,
                                  -0.038019094650903987,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086983961833717469,
                                  -0.041079377560198749,
                                  0,
                                  0.013389285573976594,
                                  -0.13395300163703336,
                                  0,
                                  0,
                                  0,
                                  -0.19409752543845685,
                                  0.35742276707230713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22006558585026695,
                                  0,
                                  0,
                                  0,
                                  -0.035832887357654129,
                                  0,
                                  0,
                                  0,
                                  -0.25854368005752537,
                                  0,
                                  0.21633642548625631,
                                  0,
                                  0.20598304224659053,
                                  -0.042627095852031963,
                                  0.30617861332856111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.066218807634875976,
                                  0,
                                  0,
                                  -0.039579061829012004,
                                  0,
                                  -0.07912780576361797,
                                  0,
                                  0,
                                  -0.15977181535304727,
                                  0,
                                  0.31368680433511587,
                                  -0.0097487882089673759,
                                  0,
                                  -0.1544631545339194,
                                  0,
                                  0,
                                  0.1792407100883957,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.055987633693576434,
                                  0,
                                  -0.088266685981327808,
                                  0,
                                  0.12846654720995321,
                                  0,
                                  0,
                                  0,
                                  -0.1572439584343269,
                                  0,
                                  0,
                                  -0.051907593330367215,
                                  0,
                                  -0.32195729307827853,
                                  0,
                                  0.10570664122256129,
                                  -0.24532403513733333,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.096666775424957718,
                                  0.2957013646391532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11179946397338433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.061022755989276256,
                                  0.45703546877610557,
                                  -0.09794678581391203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12225528788403252,
                                  0,
                                  0.12264220737118349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060023176029837755,
                                  -0.1674854884705026,
                                  0,
                                  -0.15645023220081844,
                                  0,
                                  -0.058732800875579291,
                                  0,
                                  0,
                                  0,
                                  -0.027587968882665927,
                                  0,
                                  0.018738045022138199,
                                  0,
                                  0,
                                  -0.11860030125384485,
                                  -0.17496936108318498,
                                  0,
                                  0,
                                  -0.10778384838445154,
                                  -0.14802617593927953,
                                  0,
                                  0.12788574438841541,
                                  0,
                                  0,
                                  0.12973910232704033,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29132848624263252,
                                  0,
                                  -0.079917827222216423,
                                  0.043372140549188885,
                                  0,
                                  0,
                                  -0.20709153682664705,
                                  0.023170871590650035,
                                  -0.22910646007605012,
                                  0,
                                  0.24723306025726111,
                                  0,
                                  -0.099459653427413988,
                                  0,
                                  0,
                                  0.12444556152184377,
                                  -0.094307326228683111,
                                  0,
                                  0,
                                  0.053457811909462465,
                                  0,
                                  0,
                                  0,
                                  -0.3122996961826876,
                                  0,
                                  0,
                                  -0.099682488082419085,
                                  0.19682601041889528,
                                  0,
                                  0,
                                  0.12634060614571957,
                                  0,
                                  -0.22918743396859176,
                                  -0.027583993127482061,
                                  0,
                                  0,
                                  -0.028216389089398473,
                                  0.21469217981055266,
                                  0.11297223881417533,
                                  0,
                                  0,
                                  -0.061413015386039257,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085084033050249405,
                                  -0.20124355157865287,
                                  0,
                                  0.16335086109561733,
                                  -0.0087186374483828356,
                                  0,
                                  0,
                                  0,
                                  0.21222335080193738,
                                  0.2214099013856663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057755134423126388,
                                  0,
                                  0,
                                  0,
                                  0.30885151038601399,
                                  0,
                                  0,
                                  0,
                                  -0.16152938356300584,
                                  0,
                                  -0.16383860306293158,
                                  0,
                                  0.14311308688067073,
                                  0.28537333329559078,
                                  -0.054112448977130724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14527779698285212,
                                  0,
                                  0,
                                  0.10330849951055757,
                                  0,
                                  0.099205666823159733,
                                  0,
                                  0,
                                  0.06331521040450698,
                                  0,
                                  0.15516227768719842,
                                  0.018282328406535927,
                                  0,
                                  -0.079632356511405447,
                                  0,
                                  0,
                                  0.16266123576584102,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19056047359297507,
                                  0,
                                  0.033001062971683745,
                                  0,
                                  -0.18115667402490984,
                                  0,
                                  0,
                                  0,
                                  -0.38209692816094243,
                                  0,
                                  0,
                                  -0.2606530528463134,
                                  0,
                                  0.11290441561566206,
                                  0,
                                  -0.12146090859815047,
                                  0.19279812488645987,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3014152136851812,
                                  0.12332474424410397,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19143017667837001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095770922602033404,
                                  -0.046242180389157686,
                                  -0.4029814519093628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1577483988930462,
                                  0,
                                  -0.27059343618799059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038076430727580199,
                                  0.026005708237712456,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11429225466468723,
                                  0,
                                  -0.026500788093059321,
                                  0.016974812782532329,
                                  0,
                                  0,
                                  -0.1061086784228624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16647925997432811,
                                  0,
                                  0,
                                  -0.29954046296150316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12825622242634965,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32840850175790959,
                                  0,
                                  0,
                                  0,
                                  -0.028265757231492612,
                                  0,
                                  0,
                                  -0.026572809732812841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085279882153529135,
                                  -0.064238383837760454,
                                  0,
                                  0.24225094984870948,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26410225356958827,
                                  -0.2046807842682638,
                                  0,
                                  0.11949573500579498,
                                  0,
                                  -0.04677739807762317,
                                  0.16200272275800845,
                                  -0.09134426635772433,
                                  0,
                                  0,
                                  0.13112499088078242,
                                  0,
                                  0,
                                  0.16549675417274617,
                                  -0.31105334901024861,
                                  0.47913053720632803,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1314811988630053,
                                  -0.12387602417990176,
                                  0.04851195717112701,
                                  -0.10523747835911437,
                                  0,
                                  0,
                                  0,
                                  -0.071771662400085853,
                                  0.16850837755843312,
                                  0,
                                  0.21942139655105508,
                                  0,
                                  0,
                                  0,
                                  -0.059817029835011755,
                                  0,
                                  0.062935288855886784,
                                  0,
                                  0,
                                  0,
                                  -0.022972859184622933,
                                  0,
                                  0.02611194090612369,
                                  0,
                                  0,
                                  0.35137868195249783,
                                  -0.23870259296494525,
                                  0,
                                  0,
                                  -0.086535207730047192,
                                  -0.26768016813292544,
                                  0,
                                  -0.018235113669621973,
                                  0,
                                  0,
                                  -0.19136697235248035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.020518858883520952,
                                  0,
                                  0.1052497793162555,
                                  0.1821558944305737,
                                  0,
                                  0,
                                  -0.015225372560046592,
                                  -0.36881950162694044,
                                  0.26234547574445954,
                                  0,
                                  0.050907415766646202,
                                  0,
                                  -0.16049667350362978,
                                  0,
                                  0,
                                  -0.0073170602354441922,
                                  0.17502921226677545,
                                  0,
                                  0,
                                  0.0025078838204302366,
                                  0,
                                  0,
                                  0,
                                  -0.084158708527072412,
                                  0,
                                  0,
                                  0.12987696425606521,
                                  0.092987017104953884,
                                  0,
                                  0,
                                  0.060223359720568664,
                                  0,
                                  -0.16847689810621233,
                                  0.049513828558285011,
                                  0,
                                  0,
                                  -0.17842121835337565,
                                  -0.019732383365219992,
                                  0.12554655345028118,
                                  0,
                                  0,
                                  0.2009823757249232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029646765592921103,
                                  -0.16081682533211167,
                                  0,
                                  0.071559202006047831,
                                  0.23166126187794667,
                                  0,
                                  0,
                                  0,
                                  0.056653108804046698,
                                  -0.26401729187133099,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13330750096715838,
                                  0,
                                  0,
                                  0,
                                  -0.21636978372569701,
                                  0,
                                  0,
                                  0,
                                  -0.086203973918211788,
                                  -0.2419839447379136,
                                  0,
                                  0.097019346322918559,
                                  0,
                                  0,
                                  0,
                                  -0.065933318877321748,
                                  0,
                                  -0.024270662600980753,
                                  0,
                                  0,
                                  0.080167842697564773,
                                  -0.096353694119346078,
                                  0,
                                  0,
                                  0.2871083286159794,
                                  -0.12167283553472819,
                                  0,
                                  0.23476458234732683,
                                  0,
                                  0,
                                  0.028173698690209067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.076840175548972045,
                                  0,
                                  -0.099642929143557699,
                                  -0.14353442338206507,
                                  0,
                                  0,
                                  0.11427566014876633,
                                  -0.10643479213180648,
                                  -0.073017408471006268,
                                  0,
                                  -0.023403031085197156,
                                  0,
                                  -0.28335455373559776,
                                  0,
                                  0,
                                  0.2546938867852524,
                                  -0.044959875371228877,
                                  0,
                                  0,
                                  0.094155647689081204,
                                  0,
                                  0,
                                  0,
                                  -0.097900919486361995,
                                  0,
                                  0,
                                  -0.1456015825595266,
                                  -0.026770668720710877,
                                  0,
                                  0,
                                  -0.4446892265714732,
                                  0,
                                  0.20955964514361314,
                                  -0.063359584263842583,
                                  0,
                                  0,
                                  0.21034546972620674,
                                  -0.058554658437958096,
                                  0.0096684616291622949,
                                  0,
                                  0,
                                  0.1222877178494953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064482856398454913,
                                  0.022383448289964858,
                                  0,
                                  0.21403183562783173,
                                  0.14466227352513342,
                                  0,
                                  0,
                                  0,
                                  -0.30072951971034512,
                                  0.07188935779507924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15316901062785757,
                                  0,
                                  0,
                                  0,
                                  -0.069924573295375658,
                                  0,
                                  0,
                                  0,
                                  -0.015481422039530939,
                                  0,
                                  0.0010646790765748912,
                                  0,
                                  0.03630440982388379,
                                  -0.23944548765128179,
                                  -0.38941175861633637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16583135587509545,
                                  0,
                                  0,
                                  0.15769059500645138,
                                  0,
                                  -0.011638939905505633,
                                  0,
                                  0,
                                  -0.17042269257615211,
                                  0,
                                  -0.1466749488628131,
                                  0.3404069617554672,
                                  0,
                                  0.069348273340329891,
                                  0,
                                  0,
                                  0.36736884383006135,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11574944962803886,
                                  0,
                                  -0.027676067858661748,
                                  0,
                                  0.070195633463939797,
                                  0,
                                  0,
                                  0,
                                  -0.26134940184893279,
                                  0,
                                  0,
                                  0.12290482118018478,
                                  0,
                                  -0.31478131131902559,
                                  0,
                                  -0.081698778649669984,
                                  0.23376993539419305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14819982788607269,
                                  -0.056287584080294169,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19747592848035597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16636009096705631,
                                  0.13097223447570497,
                                  -0.022838810650544002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1943067702547987,
                                  0,
                                  0.078587199311695277,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.012781318194407986,
                                  0.12048043155490649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0032095265408034618,
                                  0,
                                  -0.074937941535816219,
                                  -0.15861988866296409,
                                  0,
                                  0,
                                  -0.041495177673838986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17038788816186468,
                                  0,
                                  0,
                                  -0.20870203419497674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1690159387077097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16263121201350125,
                                  0,
                                  0,
                                  0,
                                  -0.08160546638858146,
                                  0,
                                  0,
                                  0.23490419898123208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10192571368013285,
                                  -0.19414246472112598,
                                  0,
                                  -0.23143495009755691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26977813130885675,
                                  0.26861928393306544,
                                  0,
                                  0.3407848175507654,
                                  0,
                                  0.018338581653478521,
                                  -0.023218866379589899,
                                  -0.34210861147176186,
                                  0,
                                  0,
                                  0.016496359912558343,
                                  0,
                                  0,
                                  -0.056616970730421101,
                                  0.052132126504565113,
                                  0.28391786711708178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078376591022420145,
                                  0.078724276217377376,
                                  -0.22761516904501408,
                                  -0.23292561460072805,
                                  0,
                                  0,
                                  0,
                                  0.27008774453909723,
                                  0.13865903926038214,
                                  0,
                                  -0.0063142855356462593,
                                  0,
                                  0,
                                  0,
                                  -0.1312688250747642,
                                  0,
                                  0.22324240122038033,
                                  0,
                                  0,
                                  0,
                                  0.17576720460964979,
                                  0,
                                  0.12320459785078805,
                                  0,
                                  0,
                                  -0.041703676853245442,
                                  0.091895119237670797,
                                  0,
                                  0,
                                  -0.098430790527270814,
                                  -0.051730535984082303,
                                  0,
                                  0.22001162306497155,
                                  0,
                                  0,
                                  -0.2335922838165721,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10661604192903382,
                                  0,
                                  0.22299930302282484,
                                  -0.083007839257969895,
                                  0,
                                  0,
                                  -0.039692421110316164,
                                  0.068203979108557786,
                                  0.065116205953385894,
                                  0,
                                  -0.10065394075394422,
                                  0,
                                  0.018968438688904524,
                                  0,
                                  0,
                                  0.084339694668578671,
                                  -0.31613644139307651,
                                  0,
                                  0,
                                  0.14570331544959744,
                                  0,
                                  0,
                                  0,
                                  -0.19209598259632341,
                                  0,
                                  0,
                                  -0.15444562138091705,
                                  -0.19976009700027048,
                                  0,
                                  0,
                                  0.31020752533227131,
                                  0,
                                  -0.056972221842470576,
                                  0.23915630390993137,
                                  0,
                                  0,
                                  0.26383400522646033,
                                  -0.36295039894425724,
                                  0.19647211134885528,
                                  0,
                                  0,
                                  0.025030991068852173,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058319082421478902,
                                  0.075990483215998855,
                                  0,
                                  -0.035139819705904345,
                                  -0.020788003974013796,
                                  0,
                                  0,
                                  0,
                                  0.0023558820301615817,
                                  -0.030070099141423289,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10572638144103955,
                                  0,
                                  0,
                                  0,
                                  0.03676904535583294,
                                  0,
                                  0,
                                  0,
                                  -0.14808513802338785,
                                  0,
                                  -0.12593471407275378,
                                  0,
                                  -0.11382190764799857,
                                  -0.095627192514702336,
                                  0.044121773087655192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24275564317040435,
                                  0,
                                  0,
                                  0.43080187204011627,
                                  0,
                                  -0.060578736531862326,
                                  0,
                                  0,
                                  -0.1354788962847043,
                                  0,
                                  -0.20023893187181044,
                                  0.18238967756704194,
                                  0,
                                  -0.098845250424099668,
                                  0,
                                  0,
                                  0.035472241383757167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0056132405552902298,
                                  0,
                                  0.026094116478309219,
                                  0,
                                  -0.50380633906982064,
                                  0,
                                  0,
                                  0,
                                  0.068065178362959916,
                                  0,
                                  0,
                                  -0.07532332537287445,
                                  0,
                                  -0.020092380146507459,
                                  0,
                                  0.22588915477709692,
                                  -0.10093186946471969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068454263317107369,
                                  -0.11887062727587361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2271131685163327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14132900269946538,
                                  0.13727103429563473,
                                  -0.044890310470126649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043985853331966564,
                                  0,
                                  0.10917032351203303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39605122516983937,
                                  -0.027632422015752649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21357821096175256,
                                  0,
                                  0.045283690597478762,
                                  -0.38276393942409581,
                                  0,
                                  0,
                                  0.0097111800870145655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0058314207819475071,
                                  0,
                                  0,
                                  0.29228928459097753,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23013153352778964,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1791386838814634,
                                  0,
                                  0,
                                  0,
                                  -0.18017524811646196,
                                  0,
                                  0,
                                  -0.10969500838119838,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2018322720082843,
                                  0.28896816520645746,
                                  0,
                                  -0.031111238075458601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33421491739808956,
                                  0.24987534938516306,
                                  0,
                                  0.0010509452629800043,
                                  0,
                                  -0.22258280484249079,
                                  0.11403786696885126,
                                  0.15203190250090401,
                                  0,
                                  0,
                                  0.084393176085807028,
                                  0,
                                  0,
                                  0.052293178842385483,
                                  0.2906481624709274,
                                  0.19053567157486254,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040431947437349597,
                                  -0.095111620779435552,
                                  -0.10897127327857418,
                                  -0.057127249332419999,
                                  0,
                                  0,
                                  0,
                                  0.11298872670302576,
                                  -0.13955448790744102,
                                  0,
                                  -0.13043053491289905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43527028518501415,
                                  0,
                                  -0.16431179238497817,
                                  0.092257228679723871,
                                  -0.11847289061459694,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.031826966324306379,
                                  0,
                                  0,
                                  0.12632221174855515,
                                  0,
                                  0.27135809173175951,
                                  0,
                                  0,
                                  0.21015380260954916,
                                  0,
                                  0.094497048857995453,
                                  0.042342476358625598,
                                  0,
                                  -0.14037342848531076,
                                  0,
                                  0,
                                  -0.1217139448059069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.013962696121789428,
                                  0,
                                  -0.44481015870895096,
                                  0,
                                  -0.34939642252375902,
                                  0,
                                  0,
                                  0,
                                  0.11215942514412333,
                                  0,
                                  0,
                                  -0.28094634570325988,
                                  0,
                                  -0.1131465072052672,
                                  0,
                                  -0.13956139692706701,
                                  -0.037386518080860659,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049347270124847298,
                                  -0.049456777579972327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21905339742146301,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025134128926853388,
                                  0.040134322735654537,
                                  -0.022035164260054457,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.220417456219586,
                                  0,
                                  -0.042460104434209056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16948328986328662,
                                  -0.030998978187416711,
                                  0,
                                  -0.0045016102761606322,
                                  0,
                                  0.015685104125764279,
                                  0,
                                  0,
                                  0,
                                  -0.042967888548539487,
                                  0,
                                  -0.02491942318015266,
                                  0,
                                  0,
                                  -0.029438780688586449,
                                  -0.0027739592930596949,
                                  0,
                                  0,
                                  0.012373000113834718,
                                  -0.14692123697038978,
                                  0,
                                  0.014547238515885741,
                                  0,
                                  0,
                                  0.042581910492431527,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15910460427228684,
                                  0,
                                  0.16296309750355084,
                                  -0.19866636586447758,
                                  0,
                                  0,
                                  -0.29560022570761191,
                                  0.022038777204235128,
                                  -0.35942766165139417,
                                  0,
                                  -0.17901927652537519,
                                  0,
                                  -0.25972123172489797,
                                  0,
                                  0,
                                  0.13803955472506482,
                                  0.34411659054986793,
                                  0,
                                  0,
                                  -0.049459031128315539,
                                  0,
                                  0,
                                  0,
                                  0.20660604745895111,
                                  0,
                                  0,
                                  0.018699330191589293,
                                  -0.013114365067752314,
                                  0,
                                  0,
                                  0.0090475889553642344,
                                  0,
                                  0.012387573566420462,
                                  0.4377784341827205,
                                  0,
                                  0,
                                  -0.21076463687117353,
                                  0.01388258248101322,
                                  -0.056025262422078483,
                                  0,
                                  0,
                                  0.025808882104045139,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1861503304516906,
                                  0.23175306657415184,
                                  0,
                                  0.0047006910581450165,
                                  -0.058211273843429195,
                                  0,
                                  0,
                                  0,
                                  -0.062165534880654232,
                                  -0.068228675419069615,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070215257184323449,
                                  0,
                                  0,
                                  0,
                                  0.13640726460053437,
                                  0,
                                  0,
                                  0,
                                  -0.13218821869360844,
                                  0,
                                  0.24878256501320745,
                                  0,
                                  0.066088927423729002,
                                  -0.080550713375347083,
                                  -0.090985879856914226,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.028277390358538858,
                                  0,
                                  0,
                                  0.13012833076536195,
                                  0,
                                  0.024031665969226665,
                                  0,
                                  0,
                                  -0.21934827791190306,
                                  0,
                                  0.29235315718555732,
                                  0.14413048228696806,
                                  0,
                                  0.36320435208042623,
                                  0,
                                  0,
                                  0.023156068488486246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11488547880207724,
                                  0,
                                  -0.26495451499330308,
                                  0,
                                  0.027612452165521582,
                                  0,
                                  0,
                                  0,
                                  0.18811700320039065,
                                  0,
                                  0,
                                  0.24563908393731909,
                                  0,
                                  -0.0958049040887963,
                                  0,
                                  -0.088251645585937483,
                                  0.15824382217510655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23896511693317724,
                                  -0.085941863710765398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2668286358247578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27197771914132191,
                                  -0.18751521233159513,
                                  -0.0034874117992716031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3599753420117669,
                                  0,
                                  -0.01022740453846277,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067438086054975796,
                                  0.11351510005208754,
                                  0,
                                  0,
                                  -0.31096927551353354,
                                  0,
                                  -0.072374738338083805,
                                  0.14667498377035976,
                                  -0.26174297335933616,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15927941471943957,
                                  0,
                                  0,
                                  0.14961347323102803,
                                  0,
                                  -0.16881709506896833,
                                  0,
                                  0,
                                  0.091646826483653451,
                                  0,
                                  0.039404524151854754,
                                  -0.1198879340954348,
                                  0,
                                  0.0058554661534915816,
                                  0,
                                  0,
                                  0.13029012212305832,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072016218533483028,
                                  0,
                                  -0.33774735563528691,
                                  0,
                                  0.32036729123905172,
                                  0,
                                  0,
                                  0,
                                  -0.11704196119137655,
                                  0,
                                  0,
                                  -0.35082761705166288,
                                  0,
                                  0.066580427117893151,
                                  0,
                                  -0.083938381595446976,
                                  0.069368494445935153,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13318439548899969,
                                  0.041348483246298327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.02877816295336412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40203815910378476,
                                  0.13895884046341689,
                                  0.32082211065045124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06325684784590721,
                                  0,
                                  -0.037899795365881825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.071123606640603645,
                                  -0.029005094460107655,
                                  0,
                                  0.15496334303477488,
                                  0,
                                  0.24961768792790537,
                                  0,
                                  0,
                                  0,
                                  0.093856439126899921,
                                  0,
                                  -0.069345055515587214,
                                  0,
                                  0,
                                  -0.0046399459644403673,
                                  0.27353185983882394,
                                  0,
                                  0,
                                  -0.20297529058787278,
                                  -0.019126754033796215,
                                  0,
                                  0.15503088784205754,
                                  0,
                                  0,
                                  0.10620852685926757,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15726312683279448,
                                  0,
                                  -0.028580567636435794,
                                  -0.070965317348560861,
                                  0,
                                  0,
                                  -0.075328629958010027,
                                  -0.03475236311868083,
                                  0.02930954197156584,
                                  0,
                                  0.10271930450887426,
                                  0,
                                  0.22966680233035158,
                                  0,
                                  0,
                                  -0.07582750937648719,
                                  0.19916481044240361,
                                  0,
                                  0,
                                  -0.040025327689585909,
                                  0,
                                  0,
                                  0,
                                  -0.15930080979784042,
                                  0,
                                  0,
                                  -0.21846059602711321,
                                  0.063143360637308646,
                                  0,
                                  0,
                                  -0.16158528603403099,
                                  0,
                                  -0.21455772083494351,
                                  0.019316178374731485,
                                  0,
                                  0,
                                  -0.058330670772399548,
                                  -0.071271489227213158,
                                  -0.22150072705943055,
                                  0,
                                  0,
                                  -0.07838107099452471,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.01015984329179867,
                                  -0.15588927357144905,
                                  0,
                                  0.18640525683222686,
                                  -0.27088351547037814,
                                  0,
                                  0,
                                  0,
                                  -0.29422319142238984,
                                  -0.29999989266554283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098841423433245104,
                                  0,
                                  0,
                                  0,
                                  -0.126238903184964,
                                  0,
                                  0,
                                  0,
                                  -0.22715361777369802,
                                  0.11731359104711774,
                                  0,
                                  0.0022923247611505645,
                                  0,
                                  0,
                                  0,
                                  -0.009496554324624434,
                                  0,
                                  0.27941006700259058,
                                  0,
                                  0,
                                  -0.082842763647693607,
                                  0.29203320596180432,
                                  0,
                                  0,
                                  0.0072231053577906552,
                                  0.056108929880376426,
                                  0,
                                  -0.058452114095822225,
                                  0,
                                  0,
                                  -0.057926215351146323,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1798342335354042,
                                  0,
                                  -0.30819812671127245,
                                  -0.1268313661482878,
                                  0,
                                  0,
                                  0.15584306075561999,
                                  -0.044927414999529992,
                                  0.024628134104509859,
                                  0,
                                  -0.028003594411904656,
                                  0,
                                  -0.21041691425045003,
                                  0,
                                  0,
                                  0.21403947450293687,
                                  0.22077766158899925,
                                  0,
                                  0,
                                  0.082712795102835746,
                                  0,
                                  0,
                                  0,
                                  -0.30498432093054301,
                                  0,
                                  0,
                                  -0.11793750427137914,
                                  -0.31790005522598858,
                                  0,
                                  0,
                                  0.16030019359799577,
                                  0,
                                  -0.024902481056228932,
                                  -0.067840743338703297,
                                  0,
                                  0,
                                  -0.26072876964675318,
                                  0.2510126611135724,
                                  0.25490094885249576,
                                  0,
                                  0,
                                  -0.03015282009284817,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.024286050482767878,
                                  -0.11050027141648705,
                                  0,
                                  -0.12536810718155925,
                                  -0.00065487366065000783,
                                  0,
                                  0,
                                  0,
                                  -0.053257482999461557,
                                  0.056112509312236325,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074288315399134011,
                                  0,
                                  0,
                                  0,
                                  -0.11375584480668578,
                                  0,
                                  0,
                                  0,
                                  0.020877651935344001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2938065731718793,
                                  0,
                                  -0.002723895973803854,
                                  0.11480611812090759,
                                  0,
                                  0,
                                  -0.077754494299912033,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21743251807553793,
                                  0,
                                  0,
                                  -0.11222598509320453,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19250660876869546,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.086147190938414317,
                                  0,
                                  0,
                                  0,
                                  -0.18012947635319798,
                                  0,
                                  0,
                                  0.096237614631435708,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0941386260062268,
                                  0.095728677923091171,
                                  0,
                                  0.075269895571204476,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082847713831140327,
                                  -0.059489038060931837,
                                  0,
                                  0.15542561176991831,
                                  0,
                                  -0.2778979511424946,
                                  0.0038770981642834608,
                                  -0.0630575537047149,
                                  0,
                                  0,
                                  0.029661443597254835,
                                  0,
                                  0,
                                  0.57504638222807858,
                                  0.11450617959517154,
                                  -0.31994164260679536,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21739745805765617,
                                  -0.22451186573035642,
                                  -0.24153001438310531,
                                  0.050560278399244388,
                                  0,
                                  0,
                                  0,
                                  0.029640345670837575,
                                  0.036899953190798696,
                                  0,
                                  0.032880581721996274,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30019654422769149,
                                  0,
                                  -0.025754405687207237,
                                  0.27558137880052552,
                                  0,
                                  0,
                                  -0.10442744745550168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2420921977887569,
                                  0,
                                  0,
                                  0.12233337864213614,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33897930545915411,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17191665527658267,
                                  0,
                                  0,
                                  0,
                                  0.4234012924224117,
                                  0,
                                  0,
                                  -0.0080515273241088224,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017323313341571299,
                                  0.08969434208309171,
                                  0,
                                  0.23027369301187955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070451755474263258,
                                  0.073378291426929532,
                                  0,
                                  -0.2380537235591659,
                                  0,
                                  0.069565623007272259,
                                  0.098344745233714156,
                                  -0.017635258554339759,
                                  0,
                                  0,
                                  -0.0067745174500390935,
                                  0,
                                  0,
                                  -0.0014117720522480266,
                                  0.15750073933096148,
                                  -0.046405499166504188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12304979180207666,
                                  0.17590592647969541,
                                  -0.13075272405720359,
                                  -0.23556034843928453,
                                  0,
                                  0,
                                  0,
                                  -0.054535439248877104,
                                  0.21464465352453399,
                                  0,
                                  0.29506726283000601,
                                  0,
                                  0,
                                  0,
                                  0.046482696764886602,
                                  0,
                                  0.26012704807095688,
                                  0,
                                  0,
                                  0,
                                  0.037263466016412131,
                                  0,
                                  0.082947850065135095,
                                  0,
                                  0,
                                  -0.21187228304419858,
                                  0.032596050249780475,
                                  0,
                                  0,
                                  -0.21288348951928918,
                                  -0.40410583547406936,
                                  0,
                                  -0.045654968656458413,
                                  0,
                                  0,
                                  0.17221399966022899,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21893331092341964,
                                  0,
                                  0.017168591935362416,
                                  0.1370990631799674,
                                  0,
                                  0,
                                  0.069529733045392741,
                                  0.06462799025775294,
                                  0.15367655431192873,
                                  0,
                                  0.130168491000548,
                                  0,
                                  0.098809903774121438,
                                  0,
                                  0,
                                  0.022985328690952524,
                                  0.24605076840402698,
                                  0,
                                  0,
                                  -0.12705207946422301,
                                  0,
                                  0,
                                  0,
                                  0.15642942015760369,
                                  0,
                                  0,
                                  -0.11852831592847685,
                                  -0.11022813168882536,
                                  0,
                                  0,
                                  -0.012899293769983815,
                                  0,
                                  0.11586792740292989,
                                  -0.096033426876572139,
                                  0,
                                  0,
                                  0.21102976103427992,
                                  0.096075134980155019,
                                  -0.060872785778723827,
                                  0,
                                  0,
                                  0.11836995173334922,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15050896672162778,
                                  -0.067139851288783511,
                                  0,
                                  -0.058295474702469839,
                                  0.3033509276769501,
                                  0,
                                  0,
                                  0,
                                  -0.095915910826645995,
                                  0.060833533594469677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.096262781171688933,
                                  0,
                                  0,
                                  0,
                                  0.37631266405069236,
                                  0,
                                  0,
                                  0,
                                  0.026386822003146196,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01519194133670046,
                                  0,
                                  -0.23092730587594679,
                                  0.38198104904820773,
                                  0,
                                  0,
                                  0.40657103795118227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41580471983547906,
                                  0,
                                  0,
                                  0.048346961771492787,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08095344765855203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40950981296891459,
                                  0,
                                  0,
                                  0,
                                  -0.017452454544405912,
                                  0,
                                  0,
                                  0.027865373136063819,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1528763003609841,
                                  0.059379389029643251,
                                  0,
                                  0.14330655818504234,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1853194564521731,
                                  0.048821324151395513,
                                  0,
                                  0.24989039654726994,
                                  0,
                                  -0.02700218355006993,
                                  0.076016147595714567,
                                  -0.09532906347997068,
                                  0,
                                  0,
                                  0.058126873316567428,
                                  0,
                                  0,
                                  0.05001397680947206,
                                  0.17877780767728538,
                                  0.18178729723628892,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14860365349933854,
                                  -0.072289451144590955,
                                  -0.015258710627539774,
                                  0.13657643527399974,
                                  0,
                                  0,
                                  0,
                                  0.014547218329177538,
                                  -0.071541074817993336,
                                  0,
                                  0.0073891009781604441,
                                  0,
                                  0,
                                  0,
                                  -0.087883907831703675,
                                  0,
                                  0.079218681628861587,
                                  0,
                                  0,
                                  0,
                                  -0.077799188939363439,
                                  0,
                                  0.094888216982145446,
                                  0,
                                  0,
                                  0.20985258918050556,
                                  -0.10393668852024897,
                                  0,
                                  0,
                                  -0.16020175219508193,
                                  0.14113961969002237,
                                  0,
                                  0.07192710600861979,
                                  0,
                                  0,
                                  -0.03140831525407313,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16118697334427146,
                                  0,
                                  -0.041235530587375516,
                                  0.037459040614809598,
                                  0,
                                  0,
                                  0.18749972550722704,
                                  -0.1080198668412192,
                                  -0.053026551376501904,
                                  0,
                                  -0.52475963298576644,
                                  0,
                                  0.28599126472685671,
                                  0,
                                  0,
                                  -0.17022354051525213,
                                  0.042554866951192996,
                                  0,
                                  0,
                                  -0.15430485442916864,
                                  0,
                                  0,
                                  0,
                                  -0.15774816145524104,
                                  0,
                                  0,
                                  -0.098109456247920293,
                                  -0.16451356830445496,
                                  0,
                                  0,
                                  -0.20003560698208747,
                                  0,
                                  -0.0051792252236866794,
                                  0.10368191671504301,
                                  0,
                                  0,
                                  -0.15488404237439887,
                                  0.10047740520180731,
                                  -0.032621123347012046,
                                  0,
                                  0,
                                  -0.0359142718799393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0020496163322358159,
                                  0.03727417750413721,
                                  0,
                                  0.028518636888863524,
                                  0.10336945576906154,
                                  0,
                                  0,
                                  0,
                                  -0.030589824157096358,
                                  0.2957530017732487,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29936204795068733,
                                  0,
                                  0,
                                  0,
                                  0.15669713467158036,
                                  0,
                                  0,
                                  0,
                                  -0.097994803567487812,
                                  0.011091550352158299,
                                  0,
                                  0.19692317935148951,
                                  0,
                                  0,
                                  0,
                                  -0.25759342178330574,
                                  0,
                                  0.21247113518095567,
                                  0,
                                  0,
                                  0.12585422122562293,
                                  -0.028038020123614452,
                                  0,
                                  0,
                                  -0.098644545674405698,
                                  -0.020058290472901703,
                                  0,
                                  0.037791051175124976,
                                  0,
                                  0,
                                  -0.11903177508995547,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046019161536891506,
                                  0,
                                  0.12063595321963259,
                                  0.20076825652538735,
                                  0,
                                  0,
                                  -0.056898846596794478,
                                  0.052696158982736802,
                                  -0.28328752032063198,
                                  0,
                                  0.19334370902130196,
                                  0,
                                  0.10628256233694056,
                                  0,
                                  0,
                                  0.080710263054357634,
                                  0.16745533009466115,
                                  0,
                                  0,
                                  -0.058464352839794495,
                                  0,
                                  0,
                                  0,
                                  -0.031519903547035003,
                                  0,
                                  0,
                                  0.014642652692811222,
                                  0.013217982501372632,
                                  0,
                                  0,
                                  -0.04271458782189537,
                                  0,
                                  0.056033640981990519,
                                  0.091403999281698373,
                                  0,
                                  0,
                                  0.012302271872208601,
                                  0.024291535400166528,
                                  0.092433131361886564,
                                  0,
                                  0,
                                  0.14260856517922113,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52736738379816384,
                                  0.11866466789999926,
                                  0,
                                  0.017029631647355541,
                                  -0.31300858705033568,
                                  0,
                                  0,
                                  0,
                                  0.12282166372508554,
                                  0.16688976460847316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054545984090498198,
                                  0,
                                  0,
                                  0,
                                  -0.2164599098772228,
                                  0,
                                  0,
                                  0,
                                  0.22314750835805003,
                                  0,
                                  0.10130123122114035,
                                  0,
                                  -0.25593357959033564,
                                  -0.12375957999494795,
                                  -0.23264114127505373,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035223373168994689,
                                  0,
                                  0,
                                  0.17012651734481643,
                                  0,
                                  -0.13123771838980258,
                                  0,
                                  0,
                                  -0.16585319915458169,
                                  0,
                                  0.33871636761392593,
                                  -0.22645337307260252,
                                  0,
                                  0.09250915592825408,
                                  0,
                                  0,
                                  0.07681839480700782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.076364225612544509,
                                  0,
                                  0.20796364329956896,
                                  0,
                                  -0.061568832258809783,
                                  0,
                                  0,
                                  0,
                                  0.21015328898454164,
                                  0,
                                  0,
                                  -0.19076451523760327,
                                  0,
                                  0.30229604184362341,
                                  0,
                                  -0.00077344422915250153,
                                  0.086966629503806098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12549868575337847,
                                  0.12355587334470441,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27379703299689295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39483722067760213,
                                  0.15570686976051579,
                                  0.14425303779751888,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17306565909912169,
                                  0,
                                  -0.0068987246209447663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14374588586165576,
                                  0.097201854834933654,
                                  0,
                                  0,
                                  0.32688720665247822,
                                  0,
                                  0.13460073765358471,
                                  -0.17014708093240474,
                                  0.15551588894198254,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0076241388650385711,
                                  0,
                                  0,
                                  0.0010592216402987992,
                                  0,
                                  0.090769068657957197,
                                  0,
                                  0,
                                  0.36171530963090587,
                                  0,
                                  -0.12312894925976153,
                                  0.082182180208818123,
                                  0,
                                  -0.021278671162371483,
                                  0,
                                  0,
                                  0.070916480013567526,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29444853241974145,
                                  0,
                                  0.15566442452706086,
                                  0,
                                  -0.0013563347237208548,
                                  0,
                                  0,
                                  0,
                                  -0.062619655877459324,
                                  0,
                                  0,
                                  0.0034226604993366459,
                                  0,
                                  0.071419517322432124,
                                  0,
                                  0.13086169532838923,
                                  0.38350073939992635,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21561162238663617,
                                  0.1262912712714391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0089098636908876566,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12026963836981161,
                                  0.062612322186208144,
                                  0.48295472811853624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051471414202137106,
                                  0,
                                  -0.15123681270514056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14951235857585604,
                                  -0.095767726439846435,
                                  0,
                                  -0.19814088225027129,
                                  0,
                                  -0.092060262260727541,
                                  0,
                                  0,
                                  0,
                                  -0.0049905451357329083,
                                  0,
                                  -0.25547183744971452,
                                  0,
                                  0,
                                  0.20267124223840974,
                                  0.19446817086725912,
                                  0,
                                  0,
                                  0.057879101580243619,
                                  0.056703659987429024,
                                  0,
                                  -0.23431514673137338,
                                  0,
                                  0,
                                  -0.23077587696230317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18819590957005167,
                                  0,
                                  -0.099918450786086466,
                                  0.11562007178609282,
                                  0,
                                  0,
                                  0.07148192613864178,
                                  -0.08921531322930934,
                                  -0.027219881582718642,
                                  0,
                                  0.074258354154667666,
                                  0,
                                  0.035863889818407026,
                                  0,
                                  0,
                                  0.11104328502776986,
                                  0.1932221417773346,
                                  0,
                                  0,
                                  0.34479221664461046,
                                  0,
                                  0,
                                  0,
                                  0.051031100871248146,
                                  0,
                                  0,
                                  0.024580315405353034,
                                  -0.1189538115947283,
                                  0,
                                  0,
                                  0.10052010071331256,
                                  0,
                                  0.14677222490695821,
                                  -0.030108880808721341,
                                  0,
                                  0,
                                  0.16200285290519353,
                                  0.16471535710470084,
                                  -0.069334432765818965,
                                  0,
                                  0,
                                  -0.15681016666749792,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24996414311654902,
                                  0.15675488627486903,
                                  0,
                                  -0.020297836232103999,
                                  -0.068629630343957776,
                                  0,
                                  0,
                                  0,
                                  0.01905221291529454,
                                  -0.19464440432695843,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11918291239426544,
                                  0,
                                  0,
                                  0,
                                  0.26192944723039552,
                                  0,
                                  0,
                                  0,
                                  -0.31544602366447422,
                                  -0.12564010858631514,
                                  0,
                                  -0.19439782466532413,
                                  0,
                                  0,
                                  0,
                                  -0.018719760260838259,
                                  0,
                                  -0.069572229666627808,
                                  0,
                                  0,
                                  -0.19372594813004729,
                                  0.28007982502898743,
                                  0,
                                  0,
                                  -0.34074727563943302,
                                  -0.12747294916449317,
                                  0,
                                  -0.02516823188196278,
                                  0,
                                  0,
                                  -0.0013763985004270826,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10063788127809448,
                                  0,
                                  0.29949862534907118,
                                  0.18021733202233148,
                                  0,
                                  0,
                                  0.16270232427664791,
                                  0.054128068603101744,
                                  -0.17879467876658217,
                                  0,
                                  -0.32789522701088225,
                                  0,
                                  -0.17494427493856918,
                                  0,
                                  0,
                                  -0.17354643998067532,
                                  -0.044361895968792892,
                                  0,
                                  0,
                                  0.13172155153260981,
                                  0,
                                  0,
                                  0,
                                  0.0003045086494142743,
                                  0,
                                  0,
                                  -0.10050425276165069,
                                  0.029209417407911779,
                                  0,
                                  0,
                                  -0.13489723722667457,
                                  0,
                                  -0.096944332035465056,
                                  -0.13729973875881415,
                                  0,
                                  0,
                                  0.086411905976952932,
                                  0.19843657914233401,
                                  0.16670094614518532,
                                  0,
                                  0,
                                  0.18834964638222557,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044608598948409149,
                                  0.091527443755560794,
                                  0,
                                  0.083151625492665276,
                                  0.06165764908017992,
                                  0,
                                  0,
                                  0,
                                  0.11635846836470436,
                                  -0.19850514468310809,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23286553267233212,
                                  0,
                                  0,
                                  0,
                                  -0.093444906599495295,
                                  0,
                                  0,
                                  0,
                                  0.080856341150117861,
                                  0.21461003082359548,
                                  0,
                                  -0.14127160330440608,
                                  0,
                                  0,
                                  0,
                                  0.055954947475516173,
                                  0,
                                  -0.060131073525863908,
                                  0,
                                  0,
                                  0.05233597891298427,
                                  0.041176704158109652,
                                  0,
                                  0,
                                  0.10675845098304439,
                                  -0.067980382309043116,
                                  0,
                                  0.0289817881909641,
                                  0,
                                  0,
                                  -0.28586915968539972,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.048107580423286306,
                                  0,
                                  0.26415151279790144,
                                  -0.33246088164673215,
                                  0,
                                  0,
                                  -0.003509247271898587,
                                  -0.0094566371431616808,
                                  0.15939473460490872,
                                  0,
                                  0.11142003791270051,
                                  0,
                                  -0.1548394112960782,
                                  0,
                                  0,
                                  -0.24685674910986435,
                                  -0.060857821856451541,
                                  0,
                                  0,
                                  -0.065721594282658669,
                                  0,
                                  0,
                                  0,
                                  -0.069209607712998944,
                                  0,
                                  0,
                                  -0.15855489268176487,
                                  0.10527881667919363,
                                  0,
                                  0,
                                  -0.16687915573805787,
                                  0,
                                  0.089241136606941246,
                                  -0.094421217333540391,
                                  0,
                                  0,
                                  -0.14795123851842071,
                                  0.11300891445804466,
                                  0.19762075223072983,
                                  0,
                                  0,
                                  0.1541641319141038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14104742641079285,
                                  -0.065075855961021389,
                                  0,
                                  -0.061945491309975051,
                                  -0.26788805558330175,
                                  0,
                                  0,
                                  0,
                                  -0.13269355236595071,
                                  -0.024904788851981413,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21911485787546398,
                                  0,
                                  0,
                                  0,
                                  0.36638645525167318,
                                  0,
                                  0,
                                  0,
                                  0.16526574049257561,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.035502075867886007,
                                  0,
                                  -0.0030773338691781169,
                                  0.24489726545753315,
                                  0,
                                  0,
                                  -0.088949417551774226,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30204283953409816,
                                  0,
                                  0,
                                  0.096986408404497543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16044648274077003,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.067389924366830042,
                                  0,
                                  0,
                                  0,
                                  0.33496349591515823,
                                  0,
                                  0,
                                  -0.12681940556174312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.013482873398959934,
                                  -0.050346501754770248,
                                  0,
                                  -0.24786294003496032,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095927350253693755,
                                  -0.18691003565783521,
                                  0,
                                  -0.017820262242655295,
                                  0,
                                  -0.32529453169566935,
                                  0.16344400158928021,
                                  -0.0068176404728835689,
                                  0,
                                  0,
                                  0.24706613055677887,
                                  0,
                                  0,
                                  -0.20162973867444656,
                                  -0.080821043872572704,
                                  0.27933522746310785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24145482794074952,
                                  0.0306029681935183,
                                  -0.18903638700743697,
                                  0.2303051049060616,
                                  0,
                                  0,
                                  0,
                                  0.16016801542076411,
                                  -0.07322123429431257,
                                  0,
                                  -0.25528564991293212,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17885133287729388,
                                  0,
                                  0.095670356223192948,
                                  0.19499824315686465,
                                  0,
                                  0,
                                  0.027512192875460681,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15280392236260701,
                                  0,
                                  0,
                                  0.081363626399028152,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040165753461440447,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15231840375899203,
                                  0,
                                  0,
                                  0,
                                  0.08387375251908176,
                                  0,
                                  0,
                                  -0.12004300511253035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18861614079351199,
                                  0.033824953962904428,
                                  0,
                                  -0.029477463728007702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18765255769548889,
                                  0.39181776678472363,
                                  0,
                                  0.096735616637270497,
                                  0,
                                  -0.17348668352277846,
                                  0.01586006497228875,
                                  -0.16684119502619835,
                                  0,
                                  0,
                                  -0.3875657035616169,
                                  0,
                                  0,
                                  0.0037282991007687267,
                                  -0.17619712454827302,
                                  -0.10701078309981153,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019646996387106527,
                                  -0.2734784074108233,
                                  0.27368740719299051,
                                  0.132585929156876,
                                  0,
                                  0,
                                  0,
                                  0.14549778882236389,
                                  0.41023464772915214,
                                  0,
                                  0.011955272981994235,
                                  0,
                                  0,
                                  0,
                                  0.028874699672349131,
                                  0,
                                  -0.063532490605439126,
                                  0,
                                  0,
                                  0,
                                  0.035929579469540777,
                                  0,
                                  0.3548339947812818,
                                  0,
                                  0,
                                  0.060301353589401592,
                                  0.071209351310348626,
                                  0,
                                  0,
                                  0.067679289232758733,
                                  0.073178414821255228,
                                  0,
                                  -0.066574191208776848,
                                  0,
                                  0,
                                  -0.18967557173780233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07968080009995715,
                                  0,
                                  -0.13008804192624077,
                                  0.065253008297393972,
                                  0,
                                  0,
                                  -0.08399483433893859,
                                  0.066921934398560881,
                                  -0.24201592125717647,
                                  0,
                                  -0.027025317130960177,
                                  0,
                                  0.0011063217677362955,
                                  0,
                                  0,
                                  -0.11159038181206825,
                                  0.065175482743919919,
                                  0,
                                  0,
                                  -0.13931566628951847,
                                  0,
                                  0,
                                  0,
                                  -0.040120776359776615,
                                  0,
                                  0,
                                  0.13985779006963256,
                                  0.048611944205154849,
                                  0,
                                  0,
                                  -0.2164429956225056,
                                  0,
                                  0.12057017998135632,
                                  0.14877991114148159,
                                  0,
                                  0,
                                  0.47813414611175464,
                                  0.079595082503963382,
                                  0.074605041154040319,
                                  0,
                                  0,
                                  -0.10248011747341011,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19764350635123457,
                                  -0.39402474723043479,
                                  0,
                                  0.029063911513002052,
                                  -0.030870910711541716,
                                  0,
                                  0,
                                  0,
                                  0.087971179044365341,
                                  -0.27895885408015647,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17658064128883472,
                                  0,
                                  0,
                                  0,
                                  0.027930205354927354,
                                  0,
                                  0,
                                  0,
                                  0.0519747223189286,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11363723217189553,
                                  0,
                                  0.071560558757203838,
                                  -0.017076203052467962,
                                  0,
                                  0,
                                  0.24298870951976537,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20229735203485241,
                                  0,
                                  0,
                                  -0.34057297365632988,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14808255592611194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.073286362609287503,
                                  0,
                                  0,
                                  0,
                                  -0.27423360975150851,
                                  0,
                                  0,
                                  -0.091659647072936667,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2462156513997692,
                                  0.090827862832123685,
                                  0,
                                  0.29182428695532431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11008672555392121,
                                  0.1365115003139559,
                                  0,
                                  -0.047883003451552039,
                                  0,
                                  -0.2337173026464765,
                                  -0.21865856460354777,
                                  0.16455041200920029,
                                  0,
                                  0,
                                  -0.013564153503467132,
                                  0,
                                  0,
                                  -0.50848835257592284,
                                  -0.016181642051198614,
                                  0.0057077108261651133,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052137025218067866,
                                  0.035365394190137962,
                                  -0.21417285425293114,
                                  0.050808694216127256,
                                  0,
                                  0,
                                  0,
                                  0.02134998155775816,
                                  0.11560394754208583,
                                  0,
                                  0.11375130975196603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16609362481379084,
                                  0,
                                  0.37724922335481037,
                                  -0.067725909392711003,
                                  -0.014963237754231768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11041132440780567,
                                  0,
                                  0,
                                  0.21693293993533161,
                                  0,
                                  -0.10585067587654934,
                                  0,
                                  0,
                                  0.025146010680726496,
                                  0,
                                  0.18747433933241109,
                                  0.20715872720633116,
                                  0,
                                  -0.029308851385072953,
                                  0,
                                  0,
                                  -0.23532490849516871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27890184400515916,
                                  0,
                                  0.41302934445092193,
                                  0,
                                  0.19789504292023988,
                                  0,
                                  0,
                                  0,
                                  -0.0061865030067942209,
                                  0,
                                  0,
                                  -0.33766702167357793,
                                  0,
                                  0.035910999147187525,
                                  0,
                                  -0.045794964772645413,
                                  0.084963302345618219,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.005636572588156483,
                                  -0.26984551684103575,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086605318295431513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18372480459463031,
                                  -0.065718578071738143,
                                  -0.13819496092145625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25133730355048417,
                                  0,
                                  -0.0029938372030441449,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.00070514701700221966,
                                  0.083634336694782721,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10044646606508249,
                                  0,
                                  -0.21636662851622046,
                                  0.11505755831916809,
                                  0,
                                  0,
                                  -0.15487745360779412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033616174331379617,
                                  0,
                                  0,
                                  0.10609649371173469,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31345837534049426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1149954784505122,
                                  0,
                                  0,
                                  0,
                                  -0.20700516036726185,
                                  0,
                                  0,
                                  0.1942518031382103,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.087204460841174863,
                                  -0.41535903502206661,
                                  0,
                                  -0.068502020219548515,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3061510360809423,
                                  0.10237609408246616,
                                  0,
                                  -0.24276769116621827,
                                  0,
                                  -0.015543119402443953,
                                  -0.39984562411228525,
                                  0.045881549896543181,
                                  0,
                                  0,
                                  0.024493566198584244,
                                  0,
                                  0,
                                  -0.015147540144121672,
                                  -0.032912170004259604,
                                  -0.027791259218177645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26233609748824283,
                                  -0.17584651932113171,
                                  -0.19439137670060266,
                                  0.1012875947840829,
                                  0,
                                  0,
                                  0,
                                  -0.19703540688589494,
                                  0.027654945996373633,
                                  0,
                                  -0.034177711968658535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.077292836253670782,
                                  0,
                                  -0.16603692962996239,
                                  -0.045494748040650207,
                                  0,
                                  0,
                                  0.1331687813357405,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10928150332640291,
                                  0,
                                  0,
                                  -0.16616359378841822,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15980736634709292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17579920248797748,
                                  0,
                                  0,
                                  0,
                                  0.076446901858678515,
                                  0,
                                  0,
                                  -0.32044145341671981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1539185815095131,
                                  0.096642961306423913,
                                  0,
                                  -0.034181509901966473,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0014155605366163379,
                                  0.25645167617077774,
                                  0,
                                  -0.060089586570783809,
                                  0,
                                  0.0088498179279175911,
                                  -0.058650242312088145,
                                  0.15359211558644861,
                                  0,
                                  0,
                                  -0.053425696432336509,
                                  0,
                                  0,
                                  0.30095983949009925,
                                  -0.3791490186983974,
                                  -0.011198223288020726,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.078195550956063647,
                                  0.32193104174672543,
                                  -0.058844712190417203,
                                  -0.093671090693988546,
                                  0,
                                  0,
                                  0,
                                  -0.035850100357482137,
                                  0.12475865754085087,
                                  0,
                                  -0.48506782029280887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43517184427491096,
                                  0,
                                  0.12837134574922501,
                                  -0.22417582307216768,
                                  0,
                                  0,
                                  0.2252245344488551,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.016976162129441304,
                                  0,
                                  0,
                                  -0.2159821315447373,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.025964588977036684,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035931508496131387,
                                  0,
                                  0,
                                  0,
                                  0.35582930286187991,
                                  0,
                                  0,
                                  0.13263162342046694,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052415100951565118,
                                  -0.22107161927666666,
                                  0,
                                  0.001047808662172859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18948600179602759,
                                  0.096669767535139686,
                                  0,
                                  -0.040313808554860303,
                                  0,
                                  -0.21541001147704725,
                                  0.044652192598501103,
                                  0.31559990703872848,
                                  0,
                                  0,
                                  0.13468276924808509,
                                  0,
                                  0,
                                  0.26794040471995745,
                                  -0.015670314702409427,
                                  -0.12784411267044968,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13017167284998227,
                                  0.013897187245326226,
                                  -0.15008817356596058,
                                  -0.081395851510723774,
                                  0,
                                  0,
                                  0,
                                  0.15866962654826103,
                                  -0.091587043496206583,
                                  0,
                                  0.25920682798158839,
                                  0,
                                  0,
                                  0,
                                  0.26357509640417853,
                                  0,
                                  0.11144723933115905,
                                  0,
                                  0,
                                  0,
                                  0.20436501129294604,
                                  0,
                                  0.071213700540083288,
                                  0,
                                  0,
                                  0.10585755727644197,
                                  -0.3707091662202206,
                                  0,
                                  0,
                                  -0.051735256166015015,
                                  -0.019011552208315338,
                                  0,
                                  -0.34326647082132228,
                                  0,
                                  0,
                                  0.023332293697648054,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030919421413041374,
                                  0,
                                  0.12038147668647914,
                                  0.0079920768437692219,
                                  0,
                                  0,
                                  -0.1493511043990231,
                                  0.064300684854309273,
                                  0.075537032585712705,
                                  0,
                                  -0.024997610118976672,
                                  0,
                                  0.12718806125104593,
                                  0,
                                  0,
                                  0.2041900793341444,
                                  -0.16956943534051283,
                                  0,
                                  0,
                                  0.23219885509649008,
                                  0,
                                  0,
                                  0,
                                  0.057718330074586627,
                                  0,
                                  0,
                                  -0.097549440072964663,
                                  -0.35225412884808871,
                                  0,
                                  0,
                                  -0.13406128853134644,
                                  0,
                                  -0.082378169763934056,
                                  0.022566053208774986,
                                  0,
                                  0,
                                  0.076469557330295007,
                                  0.29920408147288596,
                                  0.045511042882857095,
                                  0,
                                  0,
                                  0.01828298968058624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15508678542481863,
                                  0.096950601570766751,
                                  0,
                                  0.27293196986861057,
                                  -0.14116388309984393,
                                  0,
                                  0,
                                  0,
                                  -0.040849328009381417,
                                  -0.051147191023810587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082751161069660933,
                                  0,
                                  0,
                                  0,
                                  -0.011182652880939472,
                                  0,
                                  0,
                                  0,
                                  0.11532789136655987,
                                  -0.1344607918174594,
                                  0,
                                  0.2246717342247033,
                                  0,
                                  0,
                                  0,
                                  0.22268053780675479,
                                  0,
                                  0.0019118677092489005,
                                  0,
                                  0,
                                  -0.068086417701809579,
                                  -0.18944365948493963,
                                  0,
                                  0,
                                  0.049823305231315382,
                                  0.19057747154427071,
                                  0,
                                  0.1162714413568412,
                                  0,
                                  0,
                                  -0.17433490825783488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054915269755680264,
                                  0,
                                  -0.21140019402678947,
                                  0.027524655472291912,
                                  0,
                                  0,
                                  0.0048583585444337395,
                                  0.22437780725087506,
                                  0.19607900355673624,
                                  0,
                                  0.024564789924887684,
                                  0,
                                  -0.16496795770675116,
                                  0,
                                  0,
                                  -0.26027700171314033,
                                  0.057285151434286502,
                                  0,
                                  0,
                                  -0.089839431206268194,
                                  0,
                                  0,
                                  0,
                                  0.18338048276214025,
                                  0,
                                  0,
                                  -0.1841127474336062,
                                  -0.022148698841575543,
                                  0,
                                  0,
                                  -0.18311145780460666,
                                  0,
                                  -0.003299808450517968,
                                  0.17894694308804127,
                                  0,
                                  0,
                                  -0.12283218520796972,
                                  0.13746659301909206,
                                  0.054642571099206422,
                                  0,
                                  0,
                                  0.049679192496827423,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14051154814085717,
                                  -0.014366162377303045,
                                  0,
                                  -0.022569354546641395,
                                  -0.0039937023586701882,
                                  0,
                                  0,
                                  0,
                                  0.37094114245493631,
                                  -0.059539960429842706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32831548907650182,
                                  0,
                                  0,
                                  0,
                                  0.049037217949785127,
                                  0,
                                  0,
                                  0,
                                  -0.26379737674251608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16583107220278137,
                                  0,
                                  0.022225601698724756,
                                  0.18591471672216245,
                                  0,
                                  0,
                                  0.090563437177881012,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2378334925795727,
                                  0,
                                  0,
                                  -0.17218383946995758,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059892068547837955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41639444727293368,
                                  0,
                                  0,
                                  0,
                                  0.18427063339313413,
                                  0,
                                  0,
                                  0.19594253124917602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078230069475371936,
                                  0.043926121514881872,
                                  0,
                                  -0.15274743872301677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032540260562575404,
                                  -0.075104541555383597,
                                  0,
                                  -0.026517251371969978,
                                  0,
                                  0.0030772061442754842,
                                  -0.30953291939825311,
                                  0.18379006024514397,
                                  0,
                                  0,
                                  -0.34024003374258577,
                                  0,
                                  0,
                                  0.05449158372516906,
                                  0.33433105493400928,
                                  0.13139302927978919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16146538612522082,
                                  0.27382009099371335,
                                  -0.12065572739127002,
                                  0.098729113221553325,
                                  0,
                                  0,
                                  0,
                                  0.19111339410990807,
                                  0.11347383808107858,
                                  0,
                                  -0.052879564738046198,
                                  0,
                                  0,
                                  0,
                                  -0.23184390224857523,
                                  0,
                                  0.14014764777490729,
                                  0,
                                  0,
                                  0,
                                  -0.32807285230757632,
                                  0,
                                  0.14775383453747504,
                                  0,
                                  0,
                                  0.13858715191868051,
                                  -0.064885728305953405,
                                  0,
                                  0,
                                  -0.12450035047898171,
                                  -0.059139636460873314,
                                  0,
                                  -0.16079418515500818,
                                  0,
                                  0,
                                  -0.098337451572026793,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1991914757343772,
                                  0,
                                  0.096443198187768198,
                                  -0.16907869933023428,
                                  0,
                                  0,
                                  0.016896628197648002,
                                  0.46571482917842716,
                                  0.062791971358681364,
                                  0,
                                  0.0042947453371439005,
                                  0,
                                  -0.11870870383997333,
                                  0,
                                  0,
                                  -0.16342418502835174,
                                  -0.0049671489310445689,
                                  0,
                                  0,
                                  0.11057616974069139,
                                  0,
                                  0,
                                  0,
                                  -0.22289539332098637,
                                  0,
                                  0,
                                  0.12957820193256561,
                                  -0.0097077608558210557,
                                  0,
                                  0,
                                  0.053506638772466045,
                                  0,
                                  0.12597066980822128,
                                  -0.24313117677331816,
                                  0,
                                  0,
                                  -0.17258870519076985,
                                  -0.084567699727201573,
                                  -0.27738225489665497,
                                  0,
                                  0,
                                  -0.14102341434525248,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07321116610416406,
                                  -0.0084693809032483115,
                                  0,
                                  0.27096036464595386,
                                  0.0016362122411061855,
                                  0,
                                  0,
                                  0,
                                  0.0059972940608180054,
                                  -0.081604881537583274,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.016367630836831411,
                                  0,
                                  0,
                                  0,
                                  0.057406800388237089,
                                  0,
                                  0,
                                  0,
                                  -0.012623338310514199,
                                  -0.13187085002401178,
                                  0,
                                  0.083392367405346335,
                                  0,
                                  0,
                                  0,
                                  0.099484194215660043,
                                  0,
                                  0.052727186430260697,
                                  0,
                                  0,
                                  0.079676945308015529,
                                  0.070875499857370947,
                                  0,
                                  0,
                                  0.0062012947254845574,
                                  0.24234563706980744,
                                  0,
                                  0.1416840611793875,
                                  0,
                                  0,
                                  -0.028491078081342422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.071834204863650053,
                                  0,
                                  0.26655432918276895,
                                  0.31118837716933889,
                                  0,
                                  0,
                                  0.31237936746972611,
                                  0.020408812045681426,
                                  0.082809713403182411,
                                  0,
                                  0.048896835289366232,
                                  0,
                                  -0.10669497101231698,
                                  0,
                                  0,
                                  0.28309191609156514,
                                  0.082073829749671492,
                                  0,
                                  0,
                                  0.13065237143059918,
                                  0,
                                  0,
                                  0,
                                  0.12729604424557797,
                                  0,
                                  0,
                                  -0.037466220070957734,
                                  0.020028295621380192,
                                  0,
                                  0,
                                  0.049365192528739797,
                                  0,
                                  0.049922985545085743,
                                  0.16528767739295036,
                                  0,
                                  0,
                                  -0.16749905917170138,
                                  -0.052585843142730973,
                                  -0.23462401087404156,
                                  0,
                                  0,
                                  0.040287720504747743,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22813573522694958,
                                  -0.32585335368316054,
                                  0,
                                  -0.01301444347513217,
                                  -0.16218856670269327,
                                  0,
                                  0,
                                  0,
                                  -0.015124284826664745,
                                  0.051678630820072249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085031321390695663,
                                  0,
                                  0,
                                  0,
                                  0.25332701630901433,
                                  0,
                                  0,
                                  0,
                                  0.28207839707106042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16843487287484218,
                                  0,
                                  -0.1362903972871394,
                                  -0.035761010623680485,
                                  0,
                                  0,
                                  -0.13879388975993209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026681550836616625,
                                  0,
                                  0,
                                  0.13686824742459805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19221308225153186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.041836286008975938,
                                  0,
                                  0,
                                  0,
                                  -0.15619264835864216,
                                  0,
                                  0,
                                  -0.16223619445780274,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.004696906114725681,
                                  -0.14240516025752856,
                                  0,
                                  0.31973888460772865,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22440592453380079,
                                  0.099674704930293401,
                                  0,
                                  0.21076937677117855,
                                  0,
                                  0.10798284752141145,
                                  0.20226104624594832,
                                  0.23944928017904454,
                                  0,
                                  0,
                                  0.091153850334666969,
                                  0,
                                  0,
                                  0.039518010739726023,
                                  0.10608192564610003,
                                  -0.016978440072929056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18901690429289181,
                                  0.28188720541501955,
                                  -0.021341046495379292,
                                  0.50012901086076411,
                                  0,
                                  0,
                                  0,
                                  0.21324907471943721,
                                  0.15669393013652524,
                                  0,
                                  0.17112790621270943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33764739679860045,
                                  0,
                                  -0.17202539171433034,
                                  -0.1027072595347896,
                                  0,
                                  0,
                                  -0.045114414414922518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10788157306266601,
                                  0,
                                  0,
                                  0.057069815791457312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.037859709085963138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17618596823824356,
                                  0,
                                  0,
                                  0,
                                  -0.059700122938284396,
                                  0,
                                  0,
                                  -0.2218395841478645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.086191748680228233,
                                  0.15596095933764967,
                                  0,
                                  0.11302924111844512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27432464721109867,
                                  -0.23346274877281728,
                                  0,
                                  -0.22820583297583355,
                                  0,
                                  -0.13285524469747662,
                                  -0.067617769334551589,
                                  0.063550212070533241,
                                  0,
                                  0,
                                  -0.44860275476962536,
                                  0,
                                  0,
                                  0.16078501502398101,
                                  0.086298834644130296,
                                  0.40341293493372082,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059370146291867466,
                                  -0.16544469271969087,
                                  -0.19754780679039227,
                                  -0.060754200506518447,
                                  0,
                                  0,
                                  0,
                                  -0.11539074647341335,
                                  0.026403467222666926,
                                  0,
                                  0.078312529490698876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.033638521107716604,
                                  0,
                                  -0.51020957922173371,
                                  -0.15845518669536299,
                                  0,
                                  0,
                                  -0.095432867268335733,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20038397849350564,
                                  0,
                                  0,
                                  -0.15317507358843213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046312991114993873,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033717135858348166,
                                  0,
                                  0,
                                  0,
                                  0.18819991807811351,
                                  0,
                                  0,
                                  0.046133055670326995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15243482026474589,
                                  0.10279247126076994,
                                  0,
                                  0.073559307840559626,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25572783340411698,
                                  -0.077534856606477492,
                                  0,
                                  -0.079564945492921119,
                                  0,
                                  -0.31693652474994027,
                                  -0.044094512493934118,
                                  0.094117425160886753,
                                  0,
                                  0,
                                  0.25314634031606026,
                                  0,
                                  0,
                                  -0.2068855257261342,
                                  0.10345601539262181,
                                  -0.19493571080297223,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050899409416311693,
                                  -0.23919761638989193,
                                  0.24642527354688987,
                                  -0.11944948217596757,
                                  0,
                                  0,
                                  0,
                                  0.087751678373094652,
                                  0.25340038097065348,
                                  0,
                                  -0.096902587800195256,
                                  0,
                                  0,
                                  0,
                                  -0.18819750788281681,
                                  0,
                                  0.0064076630988750757,
                                  0,
                                  0,
                                  0,
                                  0.081864306310877516,
                                  0,
                                  0.02655250563491621,
                                  0,
                                  0,
                                  0.0076859311253403978,
                                  0.023439794816099549,
                                  0,
                                  0,
                                  -0.1556313091088837,
                                  0.2452740391043946,
                                  0,
                                  -0.17557347539926732,
                                  0,
                                  0,
                                  0.32931970971697322,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34532221684533282,
                                  0,
                                  0.13588322829681626,
                                  -0.19452882807311839,
                                  0,
                                  0,
                                  0.15345318730081725,
                                  -0.31395135263183105,
                                  0.043069007367568787,
                                  0,
                                  0.24004654868219252,
                                  0,
                                  -0.052449900514498674,
                                  0,
                                  0,
                                  -0.17135670486375418,
                                  0.11147597078422565,
                                  0,
                                  0,
                                  0.23202703775674036,
                                  0,
                                  0,
                                  0,
                                  -0.084684559519296015,
                                  0,
                                  0,
                                  -0.045250243945827801,
                                  0.10956278203944944,
                                  0,
                                  0,
                                  -0.23107213200242185,
                                  0,
                                  -0.12940312913035207,
                                  0.16808725046085629,
                                  0,
                                  0,
                                  0.098275075744664125,
                                  -0.075198272431853799,
                                  0.12204658974642171,
                                  0,
                                  0,
                                  -0.22370880593155015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057485411250810442,
                                  0.096390399381799774,
                                  0,
                                  0.10882905709770646,
                                  -0.007930569444551637,
                                  0,
                                  0,
                                  0,
                                  0.14587519501014659,
                                  0.10958361452780312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10037993541155914,
                                  0,
                                  0,
                                  0,
                                  0.015409433495455413,
                                  0,
                                  0,
                                  0,
                                  0.096810792972519405,
                                  0.31161091001421376,
                                  0,
                                  -0.17315665974709299,
                                  0,
                                  0,
                                  0,
                                  -0.0090726779845140514,
                                  0,
                                  -0.060220896092508108,
                                  0,
                                  0,
                                  -0.022476266108281497,
                                  -0.13755144339404826,
                                  0,
                                  0,
                                  -0.059801488229600262,
                                  -0.073795280083374937,
                                  0,
                                  0.054003374548897365,
                                  0,
                                  0,
                                  0.14270863702596673,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.058189245182040952,
                                  0,
                                  0.0030323396510993244,
                                  0.076061770259058109,
                                  0,
                                  0,
                                  0.10466514011265574,
                                  0.2058415128910541,
                                  0.20184639367960183,
                                  0,
                                  -0.30047256181900417,
                                  0,
                                  -0.33605756058580361,
                                  0,
                                  0,
                                  0.29057065825111394,
                                  0.061193652383389557,
                                  0,
                                  0,
                                  0.015590389667662723,
                                  0,
                                  0,
                                  0,
                                  -0.07147204833545108,
                                  0,
                                  0,
                                  -0.083184301366013472,
                                  0.10698374332382035,
                                  0,
                                  0,
                                  -0.13050062968425019,
                                  0,
                                  -0.14336232663719992,
                                  -0.020792433422849088,
                                  0,
                                  0,
                                  0.14148597965950271,
                                  -0.10279790552771582,
                                  -0.17960624863036032,
                                  0,
                                  0,
                                  -0.22798145029037981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28978549802962772,
                                  -0.072172384289149086,
                                  0,
                                  -0.067973568588089089,
                                  -0.15561348794643634,
                                  0,
                                  0,
                                  0,
                                  0.20956296193337873,
                                  -0.021913210961821208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25816121534326669,
                                  0,
                                  0,
                                  0,
                                  -0.094104883945199252,
                                  0,
                                  0,
                                  0,
                                  -0.091447175697597846,
                                  0,
                                  -0.11744622742092758,
                                  0,
                                  0.13243202270408883,
                                  0.29989993008417221,
                                  0.042391769150540555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085340080381388128,
                                  0,
                                  0,
                                  0.040686783987887262,
                                  0,
                                  -0.074458334994978295,
                                  0,
                                  0,
                                  0.28775910401392973,
                                  0,
                                  0.13553299569110669,
                                  -0.023030641767477517,
                                  0,
                                  0.47308760588744664,
                                  0,
                                  0,
                                  -0.1261616510323573,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10692297139778704,
                                  0,
                                  -0.093011707686515593,
                                  0,
                                  -0.19443455498687809,
                                  0,
                                  0,
                                  0,
                                  -0.1586875611019179,
                                  0,
                                  0,
                                  0.19070045660094243,
                                  0,
                                  0.068687037161649561,
                                  0,
                                  0.34114950415296469,
                                  0.07304958398077549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032810503983470525,
                                  0.081519030594563391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14561388950658211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.015092730895553595,
                                  0.22254534823630154,
                                  0.009328095204893784,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21681136697956319,
                                  0,
                                  0.23626021614356896,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021422883083159518,
                                  0.30510591189802572,
                                  0,
                                  0,
                                  0.081322398259881218,
                                  0,
                                  0.18689824380091652,
                                  0.09671846943090881,
                                  -0.15578636009320049,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15643719705419387,
                                  0,
                                  0,
                                  0.212960637524027,
                                  0,
                                  0.022142838759877367,
                                  0,
                                  0,
                                  -0.22601921521727666,
                                  0,
                                  -0.018109952010213367,
                                  -0.19550035589147316,
                                  0,
                                  -0.0051147274079618513,
                                  0,
                                  0,
                                  0.25023542193631093,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044005491385766836,
                                  0,
                                  -0.015539406537425329,
                                  0,
                                  -0.0018845359178934398,
                                  0,
                                  0,
                                  0,
                                  0.0036085232555611857,
                                  0,
                                  0,
                                  0.067398146960700053,
                                  0,
                                  0.13531457512239159,
                                  0,
                                  0.55985411104123073,
                                  -0.17551299892780428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.013835086858520623,
                                  -0.067239316964464335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19386917115230801,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14462158174892556,
                                  -0.26761402318186078,
                                  0.038085774835621443,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12292410693621593,
                                  0,
                                  -0.21711504822241018,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19217264727216476,
                                  -0.31223492973280442,
                                  0,
                                  0,
                                  0.091735598036766591,
                                  0,
                                  0.16521077817439975,
                                  0.43132209923477211,
                                  -0.046481663822622185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.067662430698738035,
                                  0,
                                  0,
                                  0.16508705169902352,
                                  0,
                                  0.042593649998357075,
                                  0,
                                  0,
                                  -0.11554243296833297,
                                  0,
                                  -0.34272759406854802,
                                  -0.15758491663427637,
                                  0,
                                  0.11441012000025098,
                                  0,
                                  0,
                                  -0.21993084722039663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022300121379175891,
                                  0,
                                  0.078874675036412545,
                                  0,
                                  0.070025013709521494,
                                  0,
                                  0,
                                  0,
                                  0.014927832074722432,
                                  0,
                                  0,
                                  -0.016525301331097416,
                                  0,
                                  -0.26316756811285774,
                                  0,
                                  -0.091006139521990936,
                                  0.019253823199880379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.071900328289554546,
                                  -0.35885890178479579,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043324730009210416,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23619608942548947,
                                  0.30271758937088777,
                                  0.16790506072936925,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31325664657518049,
                                  0,
                                  -0.06005783355995796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.041376655984060651,
                                  -0.14289272921611282,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14662287516274403,
                                  0,
                                  -0.02580379397548482,
                                  0.064473257759664337,
                                  0,
                                  0,
                                  -0.29288538371045553,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20978686895814846,
                                  0,
                                  0,
                                  -0.084197731747372995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.065052011166654392,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11989184562035564,
                                  0,
                                  0,
                                  0,
                                  -0.24697336103047693,
                                  0,
                                  0,
                                  -0.2388463855514581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13250144420950158,
                                  -0.39854430918176925,
                                  0,
                                  -0.25636343014884638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15437514351685924,
                                  -0.13658663395867013,
                                  0,
                                  -0.12624878116235913,
                                  0,
                                  -0.25411841988641543,
                                  0.2802257065488053,
                                  0.076669776339753956,
                                  0,
                                  0,
                                  -0.20065996933164965,
                                  0,
                                  0,
                                  -0.0079002778476667031,
                                  0.15416985419598328,
                                  -0.09045453558263776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32856284488691057,
                                  0.14469982230132644,
                                  0.070677969905698523,
                                  -0.080049443816827826,
                                  0,
                                  0,
                                  0,
                                  0.16039094556502934,
                                  0.10500997990764631,
                                  0,
                                  0.036057577862757872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14034922458283292,
                                  0,
                                  -0.022684863724399078,
                                  -0.14817261117135708,
                                  0,
                                  0,
                                  -0.10529284925838563,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11611014712789648,
                                  0,
                                  0,
                                  0.115693237287775,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1310700875625414,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067930718390765046,
                                  0,
                                  0,
                                  0,
                                  0.14467999984661456,
                                  0,
                                  0,
                                  -0.24865664799946235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28033271514879554,
                                  -0.061922929530163567,
                                  0,
                                  0.053097175891197966,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.093636718501544147,
                                  -0.24014305995619939,
                                  0,
                                  0.24706049961343202,
                                  0,
                                  0.26532340607960014,
                                  -0.17477576117505247,
                                  0.041621554688671958,
                                  0,
                                  0,
                                  0.0017787065921596769,
                                  0,
                                  0,
                                  -0.089558367829370822,
                                  -0.22490720636496997,
                                  -0.19707777756273942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27233944015142164,
                                  -0.16955462308855745,
                                  -0.50236252609489807,
                                  0.051117034651760013,
                                  0,
                                  0,
                                  0,
                                  0.098525693937817099,
                                  0.1814545805805064,
                                  0,
                                  -0.044197660427308813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13419754109985038,
                                  0,
                                  0.19922093813467687,
                                  0.32689505388545509,
                                  0,
                                  0,
                                  -0.030638886500948807,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18890132415593278,
                                  0,
                                  0,
                                  -0.16656271238340303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24526943704582063,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19118634023875464,
                                  0,
                                  0,
                                  0,
                                  -0.038833938061135824,
                                  0,
                                  0,
                                  -0.50751187727888081,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028479552698863136,
                                  0.076174715167623849,
                                  0,
                                  -0.18823125013665848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26651875788394341,
                                  0.1797919085813173,
                                  0,
                                  -0.070977052025351553,
                                  0,
                                  -0.031819502019759076,
                                  -0.17984817920926158,
                                  -0.11519011715103171,
                                  0,
                                  0,
                                  0.28833599750631389,
                                  0,
                                  0,
                                  0.023751159011784817,
                                  0.12064232746530451,
                                  -0.046239854792116217,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.042488861143196811,
                                  -0.19760174665961633,
                                  -0.13294740657838444,
                                  -0.029933490080094129,
                                  0,
                                  0,
                                  0,
                                  0.028753673679118068,
                                  -0.17403815616732213,
                                  0,
                                  0.16519890146570565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.04142196380552117,
                                  0,
                                  0.17107747986489294,
                                  0.0022087145348890017,
                                  0,
                                  0,
                                  -0.10269737483439262,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24278981518164014,
                                  0,
                                  0,
                                  0.2300125610849853,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049402178789847526,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028696112964763203,
                                  0,
                                  0,
                                  0,
                                  0.21429320340790703,
                                  0,
                                  0,
                                  0.10619669298161871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54607424536918414,
                                  -0.19378932551663247,
                                  0,
                                  0.25961837408757865,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12625561148802533,
                                  0.20028541649413995,
                                  0,
                                  0.053207197304510276,
                                  0,
                                  0.042649388691365656,
                                  0.10005489375504134,
                                  0.073623437722400931,
                                  0,
                                  0,
                                  -0.080392937215736177,
                                  0,
                                  0,
                                  -0.069981477095751865,
                                  0.15652473801587968,
                                  0.093182463079425473,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037549206214141297,
                                  -0.3561547032486776,
                                  -0.16233693627062373,
                                  -0.12937097139128145,
                                  0,
                                  0,
                                  0,
                                  0.070457972602503458,
                                  0.062264736483485336,
                                  0,
                                  -0.2865815997906816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38722152407650701,
                                  0,
                                  -0.10716562471503811,
                                  0.44978287969218506,
                                  -0.086212081107816238,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21030543633352144,
                                  0,
                                  0,
                                  -0.12723841426190421,
                                  0,
                                  -0.040833548443165939,
                                  0,
                                  0,
                                  0.043218218562518264,
                                  0,
                                  0.065941673529162526,
                                  0.069453645822668747,
                                  0,
                                  0.028252462429886348,
                                  0,
                                  0,
                                  0.2419422855974489,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20344692046705487,
                                  0,
                                  0.088739221237205901,
                                  0,
                                  0.14624788340842176,
                                  0,
                                  0,
                                  0,
                                  0.074904849916174757,
                                  0,
                                  0,
                                  -0.00061066759714919778,
                                  0,
                                  0.105169503329512,
                                  0,
                                  0.096903978259927553,
                                  0.13637823906359586,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37081271304934604,
                                  -0.060555319081750394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10030833950809569,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017627833084070905,
                                  -0.10961712760029134,
                                  -0.23279093653669494,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070154661178782649,
                                  0,
                                  0.25561940542381095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29212701456346257,
                                  -0.087824861993232139,
                                  0,
                                  -0.16171810955973631,
                                  0,
                                  0.070258150996918803,
                                  0,
                                  0,
                                  0,
                                  -0.013676749785839607,
                                  0,
                                  -0.15790175322659147,
                                  0,
                                  0,
                                  0.031352806400500796,
                                  0.16756030719485143,
                                  0,
                                  0,
                                  -0.040944255026421877,
                                  -0.063364460053301513,
                                  0,
                                  0.31186132936449057,
                                  0,
                                  0,
                                  -0.038779338756754003,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20562095347951084,
                                  0,
                                  0.11711108822649657,
                                  -0.081451067663626295,
                                  0,
                                  0,
                                  -0.16792144167741252,
                                  -0.17175079270841873,
                                  0.077943716076492794,
                                  0,
                                  0.049194938710244648,
                                  0,
                                  0.02561355006494331,
                                  0,
                                  0,
                                  0.13361451764783044,
                                  -0.30631186096354857,
                                  0,
                                  0,
                                  -0.18846813662579667,
                                  0,
                                  0,
                                  0,
                                  -0.095256636238940456,
                                  0,
                                  0,
                                  0.16796456776641519,
                                  -0.17304671060214324,
                                  0,
                                  0,
                                  -0.099154003334147103,
                                  0,
                                  0.0026192309686886186,
                                  0.04860697556277719,
                                  0,
                                  0,
                                  -0.025358280237080717,
                                  0.48192648364383034,
                                  -0.30241412981416099,
                                  0,
                                  0,
                                  -0.19934716689502571,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08347045163081715,
                                  0.024476228825972217,
                                  0,
                                  -0.11361099012763327,
                                  0.027567764104655914,
                                  0,
                                  0,
                                  0,
                                  0.15770380143796331,
                                  -0.12343772171413217,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.03780904376148278,
                                  0,
                                  0,
                                  0,
                                  -0.06092707642017036,
                                  0,
                                  0,
                                  0,
                                  0.15361442129217748,
                                  0,
                                  -0.019875947375477886,
                                  0,
                                  -0.042391370905032338,
                                  -0.034424101525904471,
                                  0.25484655014845092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.023839934547941831,
                                  0,
                                  0,
                                  -0.13069218688907713,
                                  0,
                                  -0.24885847611164072,
                                  0,
                                  0,
                                  -0.083753824397035687,
                                  0,
                                  -0.13195838685239794,
                                  0.23753381072424179,
                                  0,
                                  0.18275646208733431,
                                  0,
                                  0,
                                  0.019715851056247589,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13121326009034967,
                                  0,
                                  -0.39489208234525686,
                                  0,
                                  0.26446577549742661,
                                  0,
                                  0,
                                  0,
                                  0.15345652763834336,
                                  0,
                                  0,
                                  -0.34255131412228368,
                                  0,
                                  0.047385129822159658,
                                  0,
                                  0.19389778942698568,
                                  0.020350607096239041,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33109775025717297,
                                  -0.18393707132577641,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0252449164130258,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32509280222240339,
                                  -0.08082133425005375,
                                  -0.067296372746704372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19809131478245703,
                                  0,
                                  -0.021344036778033981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10737028384862156,
                                  -0.033866590626500118,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16081826306389491,
                                  0,
                                  -0.13985661631793189,
                                  0.06908623956654239,
                                  0,
                                  0,
                                  -0.092260029895820578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.016844536145119448,
                                  0,
                                  0,
                                  -0.018717507721135902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11249804182285056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16672613306464662,
                                  0,
                                  0,
                                  0,
                                  0.14954535212056319,
                                  0,
                                  0,
                                  0.00042789045203781712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15064267339727011,
                                  -0.19159408615834272,
                                  0,
                                  0.20034344834687101,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15903454937335582,
                                  0.14871159924660399,
                                  0,
                                  0.25859400608474586,
                                  0,
                                  -0.32716645735912531,
                                  0.06746773616629323,
                                  0.015413943878844975,
                                  0,
                                  0,
                                  -0.32976283995828409,
                                  0,
                                  0,
                                  -0.13612345185532776,
                                  -0.20376342259474262,
                                  -0.10023643011157096,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.033419806767519301,
                                  0.064190903907234698,
                                  -0.053792350432059578,
                                  -0.020570282277518698,
                                  0,
                                  0,
                                  0,
                                  -0.21731337271944343,
                                  -0.56311372396503867,
                                  0,
                                  0.021923816889975349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13406791012922128,
                                  0,
                                  -0.1751128118309353,
                                  -0.14849924568371156,
                                  0,
                                  0,
                                  -0.21324105432742238,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27325796520941387,
                                  0,
                                  0,
                                  0.049058677145259563,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39297731155667354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0083559171612848475,
                                  0,
                                  0,
                                  0,
                                  0.048792255607092494,
                                  0,
                                  0,
                                  -0.10739063012136035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0086537610291025427,
                                  0.13828180573741478,
                                  0,
                                  0.058114660252597435,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16990608908505106,
                                  0.25324368935834185,
                                  0,
                                  -0.17127099882446004,
                                  0,
                                  0.022190597302507949,
                                  0.072478893828143209,
                                  -0.39108393015241011,
                                  0,
                                  0,
                                  -0.035127198926042311,
                                  0,
                                  0,
                                  -0.07708851513506465,
                                  0.011638149986788695,
                                  -0.10163274509557081,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36511985434680622,
                                  0.23794800594588114,
                                  -0.21185566306400067,
                                  -0.13442514653658486,
                                  0,
                                  0,
                                  0,
                                  0.064932686067409567,
                                  -0.075295159614122809,
                                  0,
                                  0.23309737035719563,
                                  0,
                                  0,
                                  0,
                                  0.2204214009184754,
                                  0,
                                  0.16040708105818652,
                                  0,
                                  0,
                                  0,
                                  -0.073390277447656665,
                                  0,
                                  -0.16084106763537048,
                                  0,
                                  0,
                                  -0.2897106580348266,
                                  -0.030076001839452464,
                                  0,
                                  0,
                                  0.07788720948346424,
                                  -0.096995461027354249,
                                  0,
                                  0.00012914820885540079,
                                  0,
                                  0,
                                  -0.23916732128352652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24267053291110216,
                                  0,
                                  -0.11395016565376063,
                                  -0.14488582029670943,
                                  0,
                                  0,
                                  0.36240141252170405,
                                  0.038346566313288567,
                                  -0.11018905775183971,
                                  0,
                                  0.15735579292384805,
                                  0,
                                  -0.027706528167832378,
                                  0,
                                  0,
                                  -0.12014602854117537,
                                  0.019664753340005815,
                                  0,
                                  0,
                                  0.11022616719510767,
                                  0,
                                  0,
                                  0,
                                  -0.039104316914111356,
                                  0,
                                  0,
                                  -0.073971161817526096,
                                  0.0026726082066772915,
                                  0,
                                  0,
                                  0.093274362085468771,
                                  0,
                                  -0.020386992572732854,
                                  0.31219242435272448,
                                  0,
                                  0,
                                  0.00047834095641693941,
                                  0.056721582817911537,
                                  -0.18702788360619543,
                                  0,
                                  0,
                                  -0.05725246526263493,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046329490058403124,
                                  0.097315853603799685,
                                  0,
                                  0.20637186133243585,
                                  0.25668681712172003,
                                  0,
                                  0,
                                  0,
                                  0.14279151704527829,
                                  -0.062064255971425064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22756054861737202,
                                  0,
                                  0,
                                  0,
                                  -0.16464442080396319,
                                  0,
                                  0,
                                  0,
                                  0.26136788660001781,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28233768816076421,
                                  0,
                                  0.22758362616454292,
                                  0.030203961265979073,
                                  0,
                                  0,
                                  -0.23322437839929713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.020633534654282124,
                                  0,
                                  0,
                                  -0.43357124563513422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1674032796942001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061052598339365938,
                                  0,
                                  0,
                                  0,
                                  0.0079331922863010197,
                                  0,
                                  0,
                                  0.00067963383824090964,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22468389348399059,
                                  0.086799916374763891,
                                  0,
                                  0.26249750558358842,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19735421322216568,
                                  -0.13220247365697504,
                                  0,
                                  0.073823301248513828,
                                  0,
                                  0.070981005991578652,
                                  0.17412609910529769,
                                  -0.15974607569407434,
                                  0,
                                  0,
                                  -0.06265766046000848,
                                  0,
                                  0,
                                  -0.077647586766466173,
                                  0.31628864144065516,
                                  -0.16084502374475795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043602283728051527,
                                  0.04633795725471572,
                                  -0.058653526600628107,
                                  0.0041364613168850652,
                                  0,
                                  0,
                                  0,
                                  -0.15422058361080657,
                                  -0.00053636843853874239,
                                  0,
                                  -0.41967958952475942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057295979954180384,
                                  0,
                                  0.0041915461591977114,
                                  -0.13102090984405154,
                                  -0.027829173365336565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046314136005060971,
                                  0,
                                  0,
                                  0.16331010560791021,
                                  0,
                                  0.48079022282955997,
                                  0,
                                  0,
                                  -0.08548970783481144,
                                  0,
                                  0.2020129580697925,
                                  -0.20262783454803554,
                                  0,
                                  0.008516879127177978,
                                  0,
                                  0,
                                  -0.042850745332732663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22256464212783247,
                                  0,
                                  0.015099136848270356,
                                  0,
                                  0.22585614672093879,
                                  0,
                                  0,
                                  0,
                                  0.068878515120346401,
                                  0,
                                  0,
                                  -0.053067819728947654,
                                  0,
                                  0.037983805043960747,
                                  0,
                                  0.16471624267031823,
                                  0.041522933603434398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.069032221313964401,
                                  -0.10251875015213746,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50225720864672696,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15559225990012662,
                                  0.26566326029819481,
                                  0.042756417302942842,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26453948456595844,
                                  0,
                                  0.15620584283076996,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.168881387415662,
                                  0.044863461208095617,
                                  0,
                                  0,
                                  0.29153437856510545,
                                  0,
                                  0.19243913614495012,
                                  0.029042060417158885,
                                  -0.26231223580349844,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16668072501657072,
                                  0,
                                  0,
                                  0.014252396865961541,
                                  0,
                                  -0.32205306803863026,
                                  0,
                                  0,
                                  0.15449731673101511,
                                  0,
                                  -0.11917913963885142,
                                  -0.167997767028746,
                                  0,
                                  -0.19268256412372287,
                                  0,
                                  0,
                                  0.13135804066888288,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.034805033723516114,
                                  0,
                                  -0.096890770487708305,
                                  0,
                                  0.046889088367489007,
                                  0,
                                  0,
                                  0,
                                  -0.0059421407513223085,
                                  0,
                                  0,
                                  0.23374677133565147,
                                  0,
                                  0.095976042315734617,
                                  0,
                                  -0.088383116753862082,
                                  -0.32580878933969593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15359185980980558,
                                  -0.0075978064818960078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28912626827136334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14081816920883367,
                                  0.10072779775060788,
                                  0.022684233114682196,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18795654404232787,
                                  0,
                                  -0.24962856537686265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.048567145125665075,
                                  0.35716054913541384,
                                  0,
                                  -0.084125922443129858,
                                  0,
                                  -0.2428101814847877,
                                  0,
                                  0,
                                  0,
                                  -0.049791352848772487,
                                  0,
                                  0.11916891312696642,
                                  0,
                                  0,
                                  -0.17862207017840212,
                                  -0.09364352398911352,
                                  0,
                                  0,
                                  0.0093345418078731989,
                                  0.048493159400510757,
                                  0,
                                  -0.047851986116927696,
                                  0,
                                  0,
                                  -0.26408423781303519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068969605715495624,
                                  0,
                                  0.079341624370644764,
                                  -0.22414318129969588,
                                  0,
                                  0,
                                  0.1005754739400513,
                                  0.0035687112734546517,
                                  -0.041956929079572478,
                                  0,
                                  0.13976051256465996,
                                  0,
                                  0.24559075920090151,
                                  0,
                                  0,
                                  0.21042940144171912,
                                  0.13496697925842907,
                                  0,
                                  0,
                                  0.030614470854165597,
                                  0,
                                  0,
                                  0,
                                  -0.093568425751602333,
                                  0,
                                  0,
                                  0.06355308257818694,
                                  -0.11569837661443665,
                                  0,
                                  0,
                                  -0.25590191646381399,
                                  0,
                                  -0.36709720415885982,
                                  -0.098036898384532667,
                                  0,
                                  0,
                                  0.059565565528389201,
                                  -0.11362859517110944,
                                  -0.29357149771124547,
                                  0,
                                  0,
                                  0.37053220471492193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074016132102112261,
                                  0.048505476811183112,
                                  0,
                                  -0.22899538028745267,
                                  0.0301385042429675,
                                  0,
                                  0,
                                  0,
                                  0.15541268147184054,
                                  0.018153450023489955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038538220714066401,
                                  0,
                                  0,
                                  0,
                                  0.040106369384511842,
                                  0,
                                  0,
                                  0,
                                  -0.14473847738452555};

const double rot_17_30[900] = {0.54007011410457995,
                               -0.23759031929770996,
                               0,
                               0.36137859835065139,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18517480410787626,
                               0,
                               0,
                               0,
                               0.27449658999773791,
                               0,
                               0,
                               0,
                               0,
                               -0.079841000242246218,
                               -0.48768105706086295,
                               -0.17732618999888322,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.36876897685301047,
                               0,
                               0,
                               0,
                               -0.04087457404791385,
                               -0.11669667874085345,
                               0,
                               -0.015583460124129677,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18130309696980182,
                               0,
                               0,
                               0,
                               0.47993516866122421,
                               0,
                               0,
                               0,
                               0,
                               -0.19862046224829558,
                               0.70886513429676479,
                               -0.29407680987307255,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30469442774471422,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12177831641419559,
                               0,
                               0.16178045395177965,
                               0,
                               -0.16488719472820718,
                               0,
                               -0.62092208301045204,
                               0,
                               0,
                               0.41960796091760771,
                               0,
                               0,
                               0,
                               -0.087451412741338566,
                               -0.18217322741758565,
                               -0.20555759315504726,
                               0,
                               0,
                               0,
                               0,
                               -0.023525933750435213,
                               0,
                               0,
                               -0.47092171078526135,
                               0,
                               0,
                               -0.25436188901589862,
                               -0.0092091821730025669,
                               0.033505794997589461,
                               -0.16534988847752399,
                               0,
                               -0.29610193992741185,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.20073105835572172,
                               0,
                               0,
                               0,
                               0.25281946475746631,
                               0,
                               0,
                               0,
                               0,
                               -0.040914838490223565,
                               -0.010304235403701928,
                               0.78495363055602119,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40214098809421028,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18800012939375582,
                               0,
                               0.33565382771636398,
                               0,
                               0.8035420419474274,
                               0,
                               -0.13312668196285468,
                               0,
                               0,
                               0.13882375083088869,
                               0,
                               0,
                               0,
                               0.11524802145842357,
                               -0.12867079230112932,
                               -0.15659552022030496,
                               0,
                               0,
                               0,
                               0,
                               0.13392486728393768,
                               0,
                               0,
                               0.21139289561548322,
                               0,
                               0,
                               -0.075913438219012419,
                               0.21580497254360698,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35976950333725211,
                               0,
                               -0.27740539232441253,
                               0,
                               0,
                               0.27791712027265614,
                               0,
                               -0.22563775077615392,
                               0,
                               -0.20619529705662032,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.75527463727371857,
                               0,
                               -0.2270948539293261,
                               -0.025370182641774985,
                               0,
                               0,
                               -0.017024552157510694,
                               0,
                               0,
                               0,
                               0,
                               0.14336755816042515,
                               0,
                               -0.075873613197939796,
                               0,
                               0.19190166926618785,
                               0,
                               0.045833327523804951,
                               0,
                               0,
                               -0.13735035907905041,
                               0,
                               0,
                               0,
                               0.096554851693613192,
                               0.083048005762502097,
                               -0.43182748431786488,
                               0,
                               0,
                               0,
                               0,
                               0.46016435793278354,
                               0,
                               0,
                               -0.29096284443330639,
                               0,
                               0,
                               0.33002986862473516,
                               -0.55486192712542226,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51033675741014406,
                               0,
                               0.21892347047876581,
                               0,
                               0,
                               -0.10946839174171762,
                               0,
                               0.53943302526687908,
                               0,
                               0.44625484465373594,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.091717736788608784,
                               0,
                               -0.27280873697328606,
                               0.25485906943552472,
                               0,
                               0,
                               0.20426529002619673,
                               0,
                               0,
                               0,
                               0,
                               0.29704278690815772,
                               0,
                               0.15584532584599514,
                               0,
                               -0.001903655854098036,
                               0,
                               -0.29306575763179393,
                               0,
                               0,
                               -0.3468306334921879,
                               0,
                               0,
                               0,
                               0.4033716991867401,
                               0.46414598009614061,
                               0.1806222680186397,
                               0,
                               0,
                               0,
                               0,
                               0.13813694027210879,
                               0,
                               0,
                               0.12514702291107704,
                               0,
                               0,
                               -0.47151933786162875,
                               -0.11600201200916228,
                               -0.30912355418830217,
                               0.078420872665712349,
                               0,
                               0.049037082441475158,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0012834760258933139,
                               0,
                               0,
                               0,
                               0.27568832055279846,
                               0,
                               0,
                               0,
                               0,
                               0.85841839557600152,
                               -0.10351291255050799,
                               -0.12010169427079116,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24054309432482077,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.028667749366755035,
                               0,
                               -0.010687154708798302,
                               0,
                               0,
                               -0.27115636542863419,
                               0,
                               -0.24890851410589163,
                               0,
                               0.22991026047269039,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27899861824164685,
                               0,
                               0.63248248956080799,
                               0.57490624845362004,
                               0,
                               0,
                               -0.048295662332848495,
                               0,
                               0,
                               0,
                               0,
                               -0.050447731362335879,
                               0,
                               -0.19488272468396001,
                               0,
                               -0.16384299112385009,
                               0,
                               0.25027398662558642,
                               0,
                               0,
                               0.48794745804777007,
                               0,
                               0,
                               0,
                               0.75521767143377161,
                               -0.13170726262628574,
                               0.00047137627673959903,
                               0,
                               0,
                               0,
                               0,
                               0.18495633007186835,
                               0,
                               0,
                               0.012130965981363082,
                               0,
                               0,
                               -0.05612388632111448,
                               0.081821651339742729,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35080605845312612,
                               0,
                               0.091339112913955633,
                               0,
                               0,
                               -0.44708917450918068,
                               0,
                               -0.079393167512568891,
                               0,
                               -0.28149175217281069,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14515662431654694,
                               0,
                               -0.20779834008355583,
                               0.090549859379189204,
                               0,
                               0,
                               -0.71464172246961299,
                               0,
                               0,
                               -0.41187087628352564,
                               -0.20724206364365669,
                               0,
                               -0.28075983877943628,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.52560039144084414,
                               0,
                               0,
                               0,
                               0.39374650774069508,
                               0,
                               0,
                               0,
                               0,
                               -0.18981555924884735,
                               -0.3669601924722673,
                               0.027569819540289614,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32533845925778898,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24368479725112319,
                               0,
                               0.25265374478779279,
                               0,
                               0,
                               -0.70465962585531805,
                               0,
                               -0.091278006904499331,
                               0,
                               -0.028398687675782023,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38204532602043856,
                               0,
                               -0.1552422424190773,
                               -0.33306709160052839,
                               0,
                               0,
                               0.3001799194550821,
                               0,
                               0,
                               0,
                               0,
                               -0.043418368888113124,
                               0,
                               0.64789764967394481,
                               0,
                               -0.36184627106471062,
                               0,
                               0.089722091596408232,
                               0,
                               0,
                               0.050977366308919421,
                               0,
                               0,
                               0,
                               0.10912233534965268,
                               0.015665715336661831,
                               -0.41835060346325087,
                               0,
                               0,
                               0,
                               0,
                               -0.23697065824028932,
                               0,
                               0,
                               0.37121410476900418,
                               0,
                               0,
                               0.12223518598225433,
                               -0.20173061256231417,
                               0,
                               0,
                               -0.40290799890326195,
                               0,
                               0.089840699718564621,
                               0,
                               -0.21142169225890312,
                               0,
                               -0.32671978762272524,
                               0,
                               0,
                               0.15573725651981291,
                               0,
                               0,
                               0,
                               -0.14547263233706395,
                               -0.026459967456486364,
                               0.41016595421158886,
                               0,
                               0,
                               0,
                               0,
                               0.53341145806221124,
                               0,
                               0,
                               0.3156552389612361,
                               0,
                               0,
                               0.16774159487662577,
                               -0.22692061538126687,
                               0,
                               0,
                               -0.39499646675721611,
                               0,
                               0.40589208625819251,
                               0,
                               0.053895562111143241,
                               0,
                               0.091774082731300721,
                               0,
                               0,
                               -0.1718053338247591,
                               0,
                               0,
                               0,
                               0.26183029056598645,
                               0.063486725197620775,
                               0.37749714961000236,
                               0,
                               0,
                               0,
                               0,
                               -0.19962490453569726,
                               0,
                               0,
                               -0.58479149899316696,
                               0,
                               0,
                               0.18990639183022476,
                               -0.073482774810164547,
                               -0.35451049644151633,
                               -0.700806073139982,
                               0,
                               0.42879365608384479,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.42077952776837424,
                               0,
                               0,
                               0,
                               0.0062841033305691962,
                               0,
                               0,
                               0,
                               0,
                               -0.05010422550581177,
                               0.017790437776891259,
                               -0.011625464901654146,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13882424427131629,
                               0,
                               0,
                               0,
                               -0.49494206338125252,
                               0.08560313758651715,
                               0,
                               0.20769231052419804,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30698150101009553,
                               0,
                               0,
                               0,
                               -0.44615912379928391,
                               0,
                               0,
                               0,
                               0,
                               -0.22882043673037153,
                               -0.0946728751746444,
                               0.02371452548009443,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.59109105126922423,
                               0,
                               0,
                               0,
                               -0.17343076033292024,
                               0.5587287390996416,
                               0,
                               0.58929290342535245,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10897809879722746,
                               0,
                               0,
                               0,
                               0.40428550611807329,
                               0,
                               0,
                               0,
                               0,
                               -0.19782400646164625,
                               -0.027556708134324426,
                               0.26212121959369611,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16295275853865829,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35669725078543524,
                               0,
                               0.42032022072628894,
                               0,
                               0,
                               0.18012262698345899,
                               0,
                               -0.25548701920943284,
                               0,
                               -0.10801734103719317,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.023766476528845712,
                               0,
                               -0.49579876050113963,
                               0.58124510322373912,
                               0,
                               0,
                               0.049853117128099526,
                               0,
                               0,
                               0,
                               0,
                               -0.21160795996806461,
                               0,
                               -0.076509952886489083,
                               0,
                               -0.087803467066605023,
                               0,
                               -0.1306675170343887,
                               0,
                               0,
                               0.14586184899509611,
                               0,
                               0,
                               0,
                               -0.025359422722465289,
                               0.72037411104197069,
                               -0.26387132217669351,
                               0,
                               0,
                               0,
                               0,
                               0.079872454091750408,
                               0,
                               0,
                               -0.076707328061691421,
                               0,
                               0,
                               0.29031069217187078,
                               0.4664281451846875,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34625836430558427,
                               0,
                               0.30930564434509533,
                               0,
                               0,
                               0.23087717890760204,
                               0,
                               0.24122374997267246,
                               0,
                               0.37692341712575927,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.37152526399337515,
                               0,
                               0.078878281643590759,
                               -0.22999222179297843,
                               0,
                               0,
                               -0.57768633761762089,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.065415861214983453,
                               0,
                               0.42761757398030287,
                               0,
                               0,
                               0.11636162127498198,
                               0,
                               0.43437511949899393,
                               0,
                               -0.66771956851499781,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1434675526131427,
                               0,
                               0.36168807643545625,
                               0.055650291815977901,
                               0,
                               0,
                               0.10146242523095859,
                               0,
                               0,
                               0,
                               0,
                               -0.14482318510018058,
                               0,
                               -0.00034897754788971308,
                               0,
                               -0.2538469629566894,
                               0,
                               -0.16837671029951143,
                               0,
                               0,
                               -0.57655145218099912,
                               0,
                               0,
                               0,
                               0.17703283369983566,
                               -0.41737104457450436,
                               -0.24925881304296774,
                               0,
                               0,
                               0,
                               0,
                               0.28157353624529774,
                               0,
                               0,
                               -0.048755108905776043,
                               0,
                               0,
                               0.042321613987166384,
                               0.45022721395013476,
                               -0.19902850409808487,
                               0.20702217345972826,
                               0,
                               -0.35494980165364498,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57716533454621555,
                               0,
                               0,
                               0,
                               0.19186346080770061,
                               0,
                               0,
                               0,
                               0,
                               -0.29255025387124195,
                               -0.32273472022370631,
                               -0.42583150926377128,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22479518812400906,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41886306727151895,
                               0,
                               -0.58960320525921817,
                               0,
                               0,
                               -0.20379056230604953,
                               0,
                               0.51900381473974866,
                               0,
                               -0.16077581503696819,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.13076684406572228,
                               0,
                               -0.15437764705726165,
                               0.30151915763561582,
                               0,
                               0,
                               -0.091275120841268736,
                               0,
                               0,
                               0,
                               0,
                               -0.21326263594627839,
                               0,
                               -0.39786196282444275,
                               0,
                               0.1067173926466177,
                               0,
                               -0.4996553006893818,
                               0,
                               0,
                               -0.11356316111254106,
                               0,
                               0,
                               0,
                               0.30125329884256713,
                               -0.053104724616333809,
                               -0.070190579918870746,
                               0,
                               0,
                               0,
                               0,
                               -0.50014649507299258,
                               0,
                               0,
                               0.20581923127916685,
                               0,
                               0,
                               0.27305173225476453,
                               -0.23815665716002768,
                               0,
                               0,
                               -0.63797922440281662,
                               0,
                               -0.19078943342333904,
                               0,
                               -0.037216672924598175,
                               0,
                               0.16676108987949098,
                               0,
                               0,
                               -0.066738960254742602,
                               0,
                               0,
                               0,
                               -0.11100675268647742,
                               0.098223255980396093,
                               -0.3027905768000228,
                               0,
                               0,
                               0,
                               0,
                               -0.01122519537327632,
                               0,
                               0,
                               -0.055096296877271508,
                               0,
                               0,
                               -0.59612524023678026,
                               -0.22528675310087598};

const double rot_17_2[4] = {0.99780175096074486, -0.066269644481253887, 0.066269644481253998, 0.99780175096074464};

const double rot_18_50[2500] = {0.06471945969250964,
                                0,
                                0,
                                0.029023513057923594,
                                0,
                                -0.5427523556410162,
                                -0.13528289541504759,
                                0.09511020051552832,
                                0,
                                0,
                                0,
                                -0.25488773696045453,
                                -0.04321644490722245,
                                0,
                                0,
                                -0.19154702195268275,
                                0,
                                -0.1739899967235648,
                                0,
                                0,
                                0,
                                0.24669040678396539,
                                0,
                                0,
                                0,
                                0.36470035023897174,
                                -0.072510046652607102,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29561121207595292,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2431745424043967,
                                0,
                                0.31738360204891103,
                                0.2564191642775,
                                0.08254944349939064,
                                0.11411909766629366,
                                0,
                                -0.070041035339748592,
                                0,
                                0.048752181747568818,
                                0,
                                -0.10054316357447859,
                                0,
                                0,
                                -0.11120871030395515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.057458344258388694,
                                0,
                                0,
                                -0.1369953713037606,
                                0,
                                0,
                                0,
                                0.62935549674741942,
                                0.04933702316439912,
                                0,
                                0,
                                0.37652390023665339,
                                0.18957741253242102,
                                0.10786542129000019,
                                0,
                                0,
                                -0.15802627217419921,
                                0,
                                0,
                                -0.16180697770479963,
                                0,
                                0.15914385304993828,
                                0,
                                -0.3433434346230323,
                                0,
                                -0.38033241803479989,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16902425235082,
                                0,
                                0,
                                0,
                                0.048185728990374557,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.055028820442949093,
                                -0.11070749796039561,
                                -0.030468022309740259,
                                0,
                                0,
                                -0.18668579759653142,
                                -0.25736685986125407,
                                0,
                                0,
                                0,
                                -0.25799920226550843,
                                0,
                                0.079620758223110696,
                                0,
                                -0.51661100404254157,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.046753204637611616,
                                0.49798629602198219,
                                0,
                                0,
                                -0.53599287400668938,
                                0,
                                0.01455656271441623,
                                0,
                                0.0061224500948207222,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.053593761753157769,
                                0,
                                0,
                                0,
                                -0.23613030051778558,
                                0,
                                0,
                                0.2137136368849856,
                                0,
                                -0.31902089545171169,
                                -0.042219896024240956,
                                0.049450570152011972,
                                0,
                                0,
                                0,
                                -0.065844995133840969,
                                0.11889282872885566,
                                0,
                                0,
                                -0.053782889174896265,
                                0,
                                0.191152318214655,
                                0,
                                0,
                                0,
                                -0.40253628203239489,
                                0,
                                0,
                                0,
                                0.0075124387355139897,
                                0.3764394580190441,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11719178263063126,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.050658962944224617,
                                0,
                                -0.044192538758183381,
                                -0.15268953286962181,
                                0.18633675150588719,
                                -0.037847281154472848,
                                0,
                                -0.536538813251899,
                                0,
                                -0.25548052277302724,
                                0,
                                0.071785726100653036,
                                0,
                                0,
                                -0.10005622491458921,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2449451951288793,
                                0,
                                0,
                                -0.29167149392908803,
                                0,
                                0,
                                0,
                                -0.21667039938285179,
                                0.47263714623572467,
                                0,
                                0,
                                0.18426681240371026,
                                0.39183628900091483,
                                -0.032881275147558647,
                                0,
                                0,
                                0.52889585920674043,
                                0,
                                0,
                                -0.068335200890718567,
                                0,
                                0.085634359505270111,
                                0,
                                -0.21465791871167841,
                                0,
                                0.110368155786849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17569627106759819,
                                0,
                                0.083124290139358292,
                                0,
                                0,
                                0.070285235133440163,
                                0,
                                0.30937032891263905,
                                0.0035689871122102862,
                                0.38237302149746055,
                                0,
                                0,
                                0,
                                0.13978299889631665,
                                0.063535679978073412,
                                0,
                                0,
                                -0.04601945502255278,
                                0,
                                -0.26036507385459728,
                                0,
                                0,
                                0,
                                -0.033803312172035707,
                                0,
                                0,
                                0,
                                0.38755693596751128,
                                0.23223543329215604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33177361706888925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50959067087151599,
                                0,
                                0.13302178316924634,
                                -0.1123864862587818,
                                0.17498382220778938,
                                -0.10239281452567359,
                                0,
                                -0.065273470780365869,
                                0,
                                -0.044856969559807579,
                                -0.19074484100534125,
                                0,
                                0,
                                -0.23499431665056411,
                                0,
                                0.26574154527221577,
                                -0.25801723207616345,
                                -0.0033959749625074279,
                                0,
                                0,
                                0,
                                0.05411242875719198,
                                -0.1608145319245583,
                                0,
                                0,
                                0.43471530164373579,
                                0,
                                -0.11697675360906365,
                                0,
                                0,
                                0,
                                -0.23409370373983107,
                                0,
                                0,
                                0,
                                0.053786268066074908,
                                -0.14094094963985471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11430542120452006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31537947415471812,
                                0,
                                0.12925177067838625,
                                0.26277034077724137,
                                0.23109310029527597,
                                -0.33497664261236648,
                                0,
                                -0.25873322557118811,
                                0,
                                0.1770395881950016,
                                -0.039216253104304294,
                                0,
                                0,
                                0.26794148722655298,
                                0,
                                -0.022109624566226949,
                                -0.13280692683458384,
                                0.13699135632972589,
                                0,
                                0,
                                0,
                                -0.071879344331831685,
                                0.36801905785586497,
                                0,
                                0,
                                0.57980006418743946,
                                0,
                                -0.010049999690522176,
                                0,
                                0,
                                0,
                                0.27531100517715312,
                                0,
                                0,
                                0,
                                0.24140660504466216,
                                -0.068333523226337636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.057490397980926623,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16726042329565421,
                                0,
                                -0.25473243059700523,
                                -0.13579173755042856,
                                -0.27194797237480361,
                                -0.041035769271477118,
                                0,
                                0.045308738540483312,
                                0,
                                -0.28610841805240261,
                                0,
                                0,
                                0.4789784148973496,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11375665014211682,
                                0.010641307353279755,
                                -0.0011861114446036769,
                                0,
                                0,
                                0.09436406590576242,
                                0.4195709025115143,
                                0,
                                0,
                                0,
                                0.53360460373852081,
                                0,
                                -0.17015984479661894,
                                0,
                                0.026932313065515672,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12954536989021362,
                                0.33784832967882794,
                                0,
                                0,
                                -0.18767784070943144,
                                0,
                                0.09085766663953837,
                                0,
                                0.28278961770404165,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.06160350373161106,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1343218868101573,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.074334993911774505,
                                -0.35848339782878064,
                                -0.16209608765787253,
                                0,
                                0,
                                0.081300708369211244,
                                0.1575763815924594,
                                0,
                                0,
                                0,
                                -0.05173717423656897,
                                0,
                                0.2337446372538855,
                                0,
                                0.2247186415922213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43385128128148648,
                                -0.1673061250712749,
                                0,
                                0,
                                -0.33792341042009627,
                                0,
                                -0.31905614847463176,
                                0,
                                0.46050403074703816,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19525183285262609,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25747623800287234,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25161896446662624,
                                -0.31724001027770588,
                                0.30145481167050869,
                                0,
                                0,
                                0.19979087520405309,
                                0.16600821680129671,
                                0,
                                0,
                                0,
                                -0.10132435955505681,
                                0,
                                -0.54205410757680561,
                                0,
                                -0.0016380997810695047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19625491799805622,
                                0.029221377486600864,
                                0,
                                0,
                                -0.15337906170434246,
                                0,
                                -0.35523560965179857,
                                0,
                                -0.26094773394018972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22389616533075646,
                                0,
                                0,
                                0,
                                0.18963631593808944,
                                0,
                                0,
                                0.039269387155761053,
                                0,
                                -0.19285726425894389,
                                0.31786124554373735,
                                -0.13373310187091333,
                                0,
                                0,
                                0,
                                0.041244605718155164,
                                -0.12557046035160638,
                                0,
                                0,
                                0.040547346866991976,
                                0,
                                0.20832262582508482,
                                0,
                                0,
                                0,
                                0.016146427138816845,
                                0,
                                0,
                                0,
                                -0.097048566541860934,
                                -0.032232137906277908,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2365207185364509,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.01621043953550589,
                                0,
                                0.20873251215144867,
                                -0.03463060530217571,
                                0.0059154054266190564,
                                -0.69235630413117177,
                                0,
                                0.16890859324325053,
                                0,
                                -0.35250037566174519,
                                0.08023699381370461,
                                0,
                                0,
                                0.3272506747095571,
                                0,
                                -0.0053067419814816358,
                                -0.33941177281602608,
                                0.18621028279394625,
                                0,
                                0,
                                0,
                                0.27137193903041029,
                                0.12793655951239621,
                                0,
                                0,
                                -0.29695048801167756,
                                0,
                                -0.25867025858559733,
                                0,
                                0,
                                0,
                                0.049246169469039938,
                                0,
                                0,
                                0,
                                -0.32549649547197501,
                                0.21735476543193649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.089677159127429115,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.370402442790426,
                                0,
                                -0.16917957861246993,
                                -0.077588084990315526,
                                0.10875540340830696,
                                -0.2671468805783811,
                                0,
                                0.21819215764589367,
                                0,
                                0.15863476417682704,
                                0,
                                0,
                                -0.29506130077672732,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29583296340571652,
                                0.099488143758482528,
                                0.51510807354983212,
                                0,
                                0,
                                0.060226740943592955,
                                0.31261510180392338,
                                0,
                                0,
                                0,
                                0.1062789775316787,
                                0,
                                0.33795791672556141,
                                0,
                                0.084127639095412987,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.060171245676683922,
                                -0.045833805892842673,
                                0,
                                0,
                                -0.39887152104915641,
                                0,
                                0.32710438340728742,
                                0,
                                -0.20949227995453604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.023230843312955468,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.00094279285091262294,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60813980101573872,
                                -0.31098046105461935,
                                0.31108407439612845,
                                0,
                                0,
                                0.036973993960705984,
                                -0.10676732578902738,
                                0,
                                0,
                                0,
                                0.21607998263883885,
                                0,
                                0.37050661071170399,
                                0,
                                -0.2016446139705558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.080740888026247792,
                                -0.23259996726368318,
                                0,
                                0,
                                0.10413269329933028,
                                0,
                                -0.0094637445553841237,
                                0,
                                0.13261287798687138,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33188726655493134,
                                0,
                                0,
                                0,
                                0.033449987476721753,
                                0,
                                0,
                                -0.1281842147664396,
                                0,
                                -0.18571396186402631,
                                -0.085768905782364582,
                                -0.1174253056460383,
                                0,
                                0,
                                0,
                                0.4221478415649238,
                                0.041762625391543295,
                                0,
                                0,
                                0.11329462167144497,
                                0,
                                -0.32326124752926017,
                                0,
                                0,
                                0,
                                0.11394634164862311,
                                0,
                                0,
                                0,
                                -0.23150222802177681,
                                -0.18057826021523291,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.044555739052340532,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15216517595942575,
                                0,
                                -0.040818603556572006,
                                0.18294775271651928,
                                0.37352375445017155,
                                0.23539927186081461,
                                0,
                                -0.034940941693444555,
                                0,
                                -0.52336800273140593,
                                0,
                                0.2840502241560533,
                                0,
                                0,
                                -0.29199953032334569,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5079810310400682,
                                0,
                                0,
                                -0.11135809510116619,
                                0,
                                0,
                                0,
                                0.29526776303498525,
                                0.07782353544713097,
                                0,
                                0,
                                -0.12289690947594242,
                                -0.23027930656670895,
                                -0.4435719653877479,
                                0,
                                0,
                                0.20473839746619149,
                                0,
                                0,
                                0.069943663672924442,
                                0,
                                -0.035993924277344477,
                                0,
                                -0.0082915628633991982,
                                0,
                                -0.034412791873769895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39512030883123106,
                                0,
                                0.50715813560128575,
                                0,
                                0,
                                -0.12535714467130013,
                                0,
                                0.026789322392929832,
                                -0.045102782792071736,
                                0.13443019018631219,
                                0,
                                0,
                                0,
                                0.090034857624277362,
                                -0.26527105017795238,
                                0,
                                0,
                                -0.051260697011526753,
                                0,
                                -0.049065204653025468,
                                0,
                                0,
                                0,
                                -0.052658893824454295,
                                0,
                                0,
                                0,
                                -0.036825940919354663,
                                0.16853881108235017,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.069859841674253131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.046932045049180915,
                                0,
                                -0.30998780331370107,
                                0.32836538397160414,
                                -0.46957377291346591,
                                0.00022138874726702895,
                                0,
                                -0.3719667398982105,
                                0,
                                -0.14265411775605902,
                                0,
                                0,
                                -0.24000602349867745,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44076130249006862,
                                0.51482446703298956,
                                -0.24683661168219717,
                                0,
                                0,
                                0.030747330603170898,
                                0.022691453207611397,
                                0,
                                0,
                                0,
                                0.26948583101079326,
                                0,
                                0.076158669548784239,
                                0,
                                -0.20399684125237744,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22543606957597351,
                                -0.15567051167460647,
                                0,
                                0,
                                -0.17932661126320948,
                                0,
                                -0.018516144906401327,
                                0,
                                -0.1886423551127088,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39688124364158711,
                                0,
                                0,
                                0,
                                0,
                                -0.0011451188799232181,
                                0,
                                0,
                                0.01930384393574585,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.079903974364553515,
                                0,
                                0,
                                -0.14432971946534667,
                                0,
                                0,
                                0,
                                0.28507334293870557,
                                0.30417062230453851,
                                0,
                                0,
                                -0.57872257480669398,
                                0.32590580967777971,
                                0.078692443713309149,
                                0,
                                0,
                                -0.079348730448173282,
                                0,
                                0,
                                0.22255241287245042,
                                0,
                                0.36203989863443475,
                                0,
                                0.29549479763534237,
                                0,
                                0.11671136173874548,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25191157135687298,
                                0,
                                0,
                                0,
                                0.27030151605934505,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17392121138778643,
                                0.083616082674951325,
                                0.075918116856352663,
                                0,
                                0,
                                0.18115743234243945,
                                0.43959820363646196,
                                0,
                                0,
                                0,
                                -0.35587893782688623,
                                0,
                                0.28763342332160791,
                                0,
                                0.022751450130899215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36757792140203782,
                                0.29726211707612665,
                                0,
                                0,
                                0.2458694012337328,
                                0,
                                -0.20044627418352481,
                                0,
                                -0.34157493547377749,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084770640482464063,
                                0,
                                0,
                                0,
                                -0.19975478837160859,
                                0,
                                0,
                                0.48630275167590287,
                                0,
                                -0.072418328057558962,
                                -0.10161897318334134,
                                -0.00026964130778172387,
                                0,
                                0,
                                0,
                                0.058808043069003384,
                                -0.24410630716674112,
                                0,
                                0,
                                0.2137273626201816,
                                0,
                                -0.1589293341176847,
                                0,
                                0,
                                0,
                                -0.10846683007796058,
                                0,
                                0,
                                0,
                                -0.34832944496539175,
                                -0.052112469824898103,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.098148046896633589,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24680072691769478,
                                0,
                                0.42786778669429415,
                                0.080948777534307528,
                                -0.39529417629296376,
                                0.1232821239009184,
                                0,
                                -0.047281633654969638,
                                0,
                                0.066179230499710195,
                                0,
                                0,
                                -0.14524471389112614,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.043663232844415083,
                                0.31288610976648074,
                                0.082539423562328795,
                                0,
                                0,
                                0.081381809627809776,
                                0.3859404082063459,
                                0,
                                0,
                                0,
                                -0.3945790134590913,
                                0,
                                -0.24448891905813874,
                                0,
                                -0.37370235249509492,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.035320682530601312,
                                -0.20605774239550337,
                                0,
                                0,
                                0.055150574247735694,
                                0,
                                0.12584011208720813,
                                0,
                                0.51591321539991475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18122371941311477,
                                0,
                                0,
                                0,
                                0,
                                -0.0020226348269724581,
                                0,
                                0,
                                0.24217235528304501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12655704910448046,
                                0,
                                0,
                                0.027165532932978496,
                                0,
                                0,
                                0,
                                0.0060839255120083077,
                                0.35016476024469223,
                                0,
                                0,
                                0.56892215468030038,
                                -0.27920189050680649,
                                -0.21884626173038693,
                                0,
                                0,
                                0.048279330615392316,
                                0,
                                0,
                                0.16778120335471147,
                                0,
                                0.1979346183569724,
                                0,
                                0.4296717903790237,
                                0,
                                0.092988195170892962,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29916123068001577,
                                0,
                                0,
                                0.056159356156643671,
                                0,
                                0,
                                0.055757829219302425,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.017628065464291576,
                                0,
                                0,
                                -0.35246300139166531,
                                0,
                                0,
                                0,
                                0.11802888756110644,
                                0.20225289745710892,
                                0,
                                0,
                                -0.038357587173636173,
                                -0.43734495873713958,
                                0.31236465429786303,
                                0,
                                0,
                                -0.10874890391795095,
                                0,
                                0,
                                0.33593884234571175,
                                0,
                                -0.22992325861724799,
                                0,
                                -0.42477022179872015,
                                0,
                                0.38973682429170925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11905947822770604,
                                0,
                                -0.53437810579274447,
                                0,
                                0,
                                -0.31563362449626597,
                                0,
                                -0.16142518387336674,
                                0.049840323677368681,
                                -0.11031731077432877,
                                0,
                                0,
                                0,
                                -0.060366970024896958,
                                0.21055113481600152,
                                0,
                                0,
                                -0.06250896945595899,
                                0,
                                -0.19298087821701757,
                                0,
                                0,
                                0,
                                0.023324053227141171,
                                0,
                                0,
                                0,
                                -0.068796816081271417,
                                0.3252160864288523,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17034162664357219,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20581021754042825,
                                0,
                                -0.22814874163541876,
                                0.34834125457973442,
                                -0.26241415933203383,
                                -0.17846686721291349,
                                0,
                                0.1674713398065433,
                                0,
                                0.020250511113164296,
                                0.13585121907446235,
                                0,
                                0,
                                0.31914318645454148,
                                0,
                                -0.086762579415610427,
                                0.10444431515539254,
                                -0.15626358438583543,
                                0,
                                0,
                                0,
                                0.01980081706838684,
                                0.20952076767886532,
                                0,
                                0,
                                -0.064086508699349121,
                                0,
                                -0.26752051182743891,
                                0,
                                0,
                                0,
                                -0.096072661744441429,
                                0,
                                0,
                                0,
                                0.263358377956318,
                                -0.20604101864252136,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54585547188213879,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20107215593644856,
                                0,
                                -0.064173818348992551,
                                0.33009662097202846,
                                0.0081574990376541631,
                                -0.3229787355684004,
                                0,
                                -0.069456857139847339,
                                0,
                                0.18749734128192186,
                                0,
                                -0.47120162354786815,
                                0,
                                0,
                                -0.010240797553754753,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48567095781989222,
                                0,
                                0,
                                -0.1231016874610649,
                                0,
                                0,
                                0,
                                -0.36924628676131682,
                                0.0021250049635742202,
                                0,
                                0,
                                0.074660527402633028,
                                0.038406447719577297,
                                0.056641526077099207,
                                0,
                                0,
                                -0.24939855396426833,
                                0,
                                0,
                                -0.00053509313632517375,
                                0,
                                0.44805177592742723,
                                0,
                                -0.2163045818272932,
                                0,
                                0.12652572572952789,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23341433754420987,
                                0,
                                0,
                                0.19116826396089184,
                                0,
                                0,
                                0.020616743247390854,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15292550327717458,
                                0,
                                0,
                                -0.064822428986712921,
                                0,
                                0,
                                0,
                                -0.010520537790981568,
                                -0.11894453743209597,
                                0,
                                0,
                                0.23876058936883943,
                                0.43795430421346293,
                                -0.31234058925169866,
                                0,
                                0,
                                -0.4753384503444934,
                                0,
                                0,
                                0.51915741535991833,
                                0,
                                -0.12130075662059964,
                                0,
                                -0.022437858343017269,
                                0,
                                0.12525059902620697,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22009011788623722,
                                0,
                                0,
                                0.28768372602161146,
                                0,
                                0,
                                0.0062591345331939711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28683395750716867,
                                0,
                                0,
                                -0.30273412987847614,
                                0,
                                0,
                                0,
                                0.10406509536722471,
                                -0.35456762216844179,
                                0,
                                0,
                                0.041973882688071659,
                                -0.14765961364291078,
                                -0.16328945685569363,
                                0,
                                0,
                                -0.10264188248012812,
                                0,
                                0,
                                -0.39035583492162651,
                                0,
                                0.47242538406780105,
                                0,
                                0.024504632268021669,
                                0,
                                0.41164546825825904,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.018698146518510796,
                                0,
                                0,
                                0,
                                -0.3225812451130613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21624443287034475,
                                -0.29353812520800793,
                                -0.034452191990445032,
                                0,
                                0,
                                -0.2357291718283146,
                                0.12911047054781122,
                                0,
                                0,
                                0,
                                -0.097143458989112974,
                                0,
                                0.038759130590769637,
                                0,
                                0.093149430292953583,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.045113989499238241,
                                0.33959111133143477,
                                0,
                                0,
                                0.33462790761694178,
                                0,
                                0.51751136962426803,
                                0,
                                0.14069425452419176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39118829785091602,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24444948357079496,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27447034041973217,
                                -0.16191459066212763,
                                -0.28410915598911335,
                                0,
                                0,
                                -0.21934363790406292,
                                0.16779089377965897,
                                0,
                                0,
                                0,
                                -0.24314803064704416,
                                0,
                                -0.18959938454227354,
                                0,
                                0.2602831950357678,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.042106378469509251,
                                -0.35061989788192599,
                                0,
                                0,
                                -0.35986691513383912,
                                0,
                                0.39370543233051936,
                                0,
                                -0.25703290303955362,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20883761456925293,
                                0,
                                0,
                                0,
                                0,
                                0.070317340824256711,
                                0,
                                0,
                                0.63424841332781134,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24070884289744499,
                                0,
                                0,
                                -0.32459507979105517,
                                0,
                                0,
                                0,
                                0.1257659707809885,
                                0.032642451416982049,
                                0,
                                0,
                                0.024942054218869445,
                                0.17332253729616387,
                                0.20093045113670782,
                                0,
                                0,
                                -0.066089204591982934,
                                0,
                                0,
                                -0.30619557537596626,
                                0,
                                -0.29877554389175853,
                                0,
                                0.22935816166671327,
                                0,
                                0.01381489798512821,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31839737586516847,
                                0,
                                0.036975164657190612,
                                0,
                                0,
                                -0.16089662456431458,
                                0,
                                0.065954154132862652,
                                -0.44002845774723653,
                                0.3946925020674189,
                                0,
                                0,
                                0,
                                -0.21662425745626751,
                                0.038740569798131043,
                                0,
                                0,
                                -0.057416889105567047,
                                0,
                                0.22874004685082713,
                                0,
                                0,
                                0,
                                -0.10254609021954418,
                                0,
                                0,
                                0,
                                -0.040773322306178736,
                                0.065254945745473469,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38617711622871059,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.090114126248721019,
                                0,
                                0.27550219701033907,
                                0.23204900185865951,
                                -0.046470305610090697,
                                -0.06842636986326775,
                                0,
                                0.32274304468530413,
                                0,
                                -0.3170169016802501,
                                0,
                                0,
                                -0.45293880448269458,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.043979134077562314,
                                -0.03116519134679956,
                                -0.53329093436004305,
                                0,
                                0,
                                0.28589111867778771,
                                0.1715102510349967,
                                0,
                                0,
                                0,
                                0.074953991242602672,
                                0,
                                0.12752098995416611,
                                0,
                                0.10809754410976313,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31509030159422474,
                                0.26412412267944102,
                                0,
                                0,
                                -0.043917585430678759,
                                0,
                                -0.05884421678342755,
                                0,
                                -0.052726197631629765,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43082781508182832,
                                0,
                                0,
                                0,
                                0,
                                -0.0027220353639155204,
                                0,
                                0,
                                0.49509237666227079,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22430356626022488,
                                0,
                                0,
                                -0.19128380490456195,
                                0,
                                0,
                                0,
                                -0.098345349592843176,
                                -0.055157151279890557,
                                0,
                                0,
                                -0.21272421517649695,
                                -0.22787133315522456,
                                -0.273518947857049,
                                0,
                                0,
                                0.10220681686278814,
                                0,
                                0,
                                0.25106191963122393,
                                0,
                                0.26823614842907084,
                                0,
                                -0.23991173542711935,
                                0,
                                -0.52636512384216849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.056780616959063682,
                                0,
                                0,
                                0,
                                -0.21245327321264648,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20147423064660225,
                                -0.18604416681605987,
                                -0.035732608407110171,
                                0,
                                0,
                                -0.37956187336188962,
                                0.22383227749793308,
                                0,
                                0,
                                0,
                                0.38003818014109136,
                                0,
                                -0.26411011207582014,
                                0,
                                -0.30296201435140502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46278863937462472,
                                -0.023625622034395347,
                                0,
                                0,
                                0.14275381468342457,
                                0,
                                -0.059904988166823346,
                                0,
                                -0.17925966777968283,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32773838858786725,
                                0,
                                0,
                                0,
                                0,
                                0.0023752368857632988,
                                0,
                                0,
                                0.1719584808601691,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24523630526657172,
                                0,
                                0,
                                0.57803031048771869,
                                0,
                                0,
                                0,
                                0.2658742715776643,
                                0.3239377295919767,
                                0,
                                0,
                                -0.012810154210143886,
                                -0.13691887040942957,
                                0.14932535922792092,
                                0,
                                0,
                                -0.10493051942674737,
                                0,
                                0,
                                -0.01555447709952576,
                                0,
                                0.23343191608898933,
                                0,
                                -0.088235648647206691,
                                0,
                                0.14625972895084102,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51420888727634884,
                                0,
                                0,
                                0,
                                -0.17396939807591139,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25064936500418483,
                                0.33532215518642117,
                                0.28047367875812579,
                                0,
                                0,
                                -0.12126473532487383,
                                -0.24853837515401989,
                                0,
                                0,
                                0,
                                0.002478764459676111,
                                0,
                                -0.2288960225534844,
                                0,
                                0.50777243597569088,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29435853236777443,
                                0.29861415314270401,
                                0,
                                0,
                                -0.10149608758950632,
                                0,
                                -0.035789143175746108,
                                0,
                                0.19342136385449285,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32292843079755229,
                                0,
                                0,
                                0,
                                0,
                                -0.48471622140065662,
                                0,
                                0,
                                0.26627047109943464,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.02363735729391275,
                                0,
                                0,
                                0.14836851118197802,
                                0,
                                0,
                                0,
                                0.31850390136277984,
                                -0.28435305280998885,
                                0,
                                0,
                                -0.022480530307931727,
                                0.15006307574675515,
                                -0.32083257834728662,
                                0,
                                0,
                                0.38684076486291896,
                                0,
                                0,
                                0.09389724206637752,
                                0,
                                -0.11411582578241085,
                                0,
                                -0.16122547337986054,
                                0,
                                0.39436978987295285,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10155278188616411,
                                0,
                                0.033458851129740036,
                                0,
                                0,
                                -0.031748577386712412,
                                0,
                                -0.34384231561565481,
                                -0.19328095092427622,
                                0.2730898291524318,
                                0,
                                0,
                                0,
                                0.17607475263012748,
                                0.12686303367907936,
                                0,
                                0,
                                0.039000876958172254,
                                0,
                                0.39815810579924016,
                                0,
                                0,
                                0,
                                -0.1747970215714941,
                                0,
                                0,
                                0,
                                -0.091494623284445076,
                                -0.42589769846995135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24730107454295716,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32167429777401757,
                                0,
                                -0.28241884794821159,
                                0.053967019007725672,
                                0.052975632661820191,
                                -0.047247213974624114,
                                0,
                                -0.0029768098308806043,
                                0,
                                0.29647126010194269,
                                0,
                                0.17063097223123086,
                                0,
                                0,
                                0.17752635707216763,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12694289714076892,
                                0,
                                0,
                                0.20983976158037126,
                                0,
                                0,
                                0,
                                -0.15306556773782448,
                                0.34505746703982648,
                                0,
                                0,
                                -0.1668622153993089,
                                0.079796589483834224,
                                -0.43090396785608981,
                                0,
                                0,
                                -0.30063274584170763,
                                0,
                                0,
                                -0.39120519311857294,
                                0,
                                -0.15090490261965056,
                                0,
                                -0.36746012042056242,
                                0,
                                0.095396090185701152,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32637186874968571,
                                0,
                                -0.15551525178293296,
                                0,
                                0,
                                0.12511559460763932,
                                0,
                                0.0051818828413924059,
                                -0.18816273878403225,
                                -0.013949054193220806,
                                0,
                                0,
                                0,
                                -0.46685102174389354,
                                -0.50665499371428913,
                                0,
                                0,
                                -0.1100253812466532,
                                0,
                                -0.25211882660804996,
                                0,
                                0,
                                0,
                                -0.046881683174584368,
                                0,
                                0,
                                0,
                                0.014393572763380231,
                                -0.24184554662277558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.025106716207525966,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14916005639357263,
                                0,
                                -0.43092006378220904,
                                -0.184643460697276,
                                0.11335822512039848,
                                -0.12199830792044619,
                                0,
                                0.069946110976166542,
                                0,
                                -0.19501527331835752,
                                0.034461412817442534,
                                0,
                                0,
                                -0.16226687353000568,
                                0,
                                0.12069567176272222,
                                -0.22143206055150855,
                                -0.075260042467069257,
                                0,
                                0,
                                0,
                                -0.2472925682347378,
                                0.28172865221931381,
                                0,
                                0,
                                -0.15628478383619965,
                                0,
                                -0.027952063633803897,
                                0,
                                0,
                                0,
                                0.46571960830793968,
                                0,
                                0,
                                0,
                                -0.32993966844067751,
                                -0.14293916311876326,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.021600768969741099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19870839989597547,
                                0,
                                0.1504839078573556,
                                -0.17533967582150828,
                                -0.044777565200791569,
                                -0.22929274304860986,
                                0,
                                -0.49173349261092186,
                                0,
                                0.03972032438337994,
                                0.16469117748452752,
                                0,
                                0,
                                -0.29458284360052189,
                                0,
                                -0.29030868626715123,
                                -0.42388734559135677,
                                -0.348529893505788,
                                0,
                                0,
                                0,
                                0.20241749698833675,
                                -0.077525398325950595,
                                0,
                                0,
                                0.10545145755194635,
                                0,
                                -0.1554518544382541,
                                0,
                                0,
                                0,
                                -0.14939259748375217,
                                0,
                                0,
                                0,
                                0.22595279059301174,
                                0.13064201738680936,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11363358840214757,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12173253834146279,
                                0,
                                0.10334665793228123,
                                -0.46211886418909637,
                                -0.21732672326097036,
                                -0.087154219029872568,
                                0,
                                0.099357467278131884,
                                0,
                                0.10626451051248499,
                                0.18176682264374666,
                                0,
                                0,
                                0.062848547608468253,
                                0,
                                0.22537436849842707,
                                -0.13279605777481129,
                                -0.34858901016612542,
                                0,
                                0,
                                0,
                                -0.2266559308979503,
                                0.42428834619692446,
                                0,
                                0,
                                -0.19483488347675199,
                                0,
                                -0.07619593922953645,
                                0,
                                0,
                                0,
                                -0.4921450707384587,
                                0,
                                0,
                                0,
                                -0.016076151994776366,
                                -0.21664775547036894,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35598297171890608,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.060937607591969922,
                                0,
                                0.051969263449648813,
                                0.069395185333308934,
                                -0.096958568454788605,
                                0.12473827309053503,
                                0,
                                0.076920324395748446,
                                0,
                                -0.1991874895551238,
                                0,
                                0,
                                -0.026981997623993968,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.063007547674494721,
                                0.14674157750203998,
                                0.0077070479375844943,
                                0,
                                0,
                                -0.72121489897168578,
                                0.25958291892434399,
                                0,
                                0,
                                0,
                                -0.064786482076027122,
                                0,
                                0.2014669903226082,
                                0,
                                0.12097398842989125,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39122455198134409,
                                -0.0038737823422306757,
                                0,
                                0,
                                -0.0094294452021589335,
                                0,
                                -0.41102992459995669,
                                0,
                                0.041823000324132276,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0538426781489637,
                                0,
                                0,
                                0,
                                -0.26415616130973868,
                                0,
                                0,
                                0.22290442278837252,
                                0,
                                0.23083726728622092,
                                -0.31141498049767963,
                                -0.33029339885939563,
                                0,
                                0,
                                0,
                                0.33950121559184221,
                                -0.16087758636389574,
                                0,
                                0,
                                -0.29469200491094205,
                                0,
                                0.39809789297140358,
                                0,
                                0,
                                0,
                                0.24633403123050696,
                                0,
                                0,
                                0,
                                0.32500853090856119,
                                -0.044505637988542603,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.064434070900760879,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.017010539762358584,
                                0,
                                -0.033982305312522582,
                                0.16583538064005354,
                                -0.073266103415036241,
                                -0.025418572754479108,
                                0,
                                -0.067481706249584925,
                                0,
                                -0.15083586174405064,
                                0,
                                -0.53901164300240834,
                                0,
                                0,
                                -0.22424701316126575,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35963935764848731,
                                0,
                                0,
                                -0.29127274948130782,
                                0,
                                0,
                                0,
                                0.078822818956202523,
                                0.25148915882248474,
                                0,
                                0,
                                -0.10187988829537199,
                                -0.19332777266630918,
                                -0.29214049746300708,
                                0,
                                0,
                                -0.26152193880717545,
                                0,
                                0,
                                -0.18146991707652638,
                                0,
                                -0.22973045730501668,
                                0,
                                0.23820833912937625,
                                0,
                                -0.058303784246019966,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16791282821252049,
                                0,
                                -0.3045931123023205,
                                0,
                                0,
                                -0.18299069272599597,
                                0,
                                0.0061722262167285408,
                                0.19139598542480329,
                                0.33795580909044842,
                                0,
                                0,
                                0,
                                0.26319258479908531,
                                0.031871232177738656,
                                0,
                                0,
                                -0.31128875409527873,
                                0,
                                -0.19152642995409244,
                                0,
                                0,
                                0,
                                -0.14149328285845456,
                                0,
                                0,
                                0,
                                0.11739728629938517,
                                -0.42870302454245662,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.099008002622909666,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22915194546715628,
                                0,
                                0.10148486088061673,
                                -0.2407871299248921,
                                -0.3487074072681916,
                                -0.074096448500463374,
                                0,
                                -0.10922824090667199,
                                0,
                                -0.1782865639899763};

const double rot_18_20[400] = {0.14072453051629139,
                               0,
                               0,
                               0,
                               0,
                               0.28391377334745738,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.083063432336387785,
                               0,
                               0,
                               0.69240587977768686,
                               -0.64268656088171172,
                               0.014769026183243706,
                               0,
                               0,
                               0,
                               0.50164808680147799,
                               0.71958122062945351,
                               -0.23078725079251844,
                               0,
                               0,
                               -0.20483288020001325,
                               0.17064609752441753,
                               0.16583529082783904,
                               -0.27494105978863825,
                               0,
                               0,
                               0,
                               0,
                               0.055846032486418257,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.035874271476098687,
                               0.3118025168116168,
                               0.26469755267409151,
                               0,
                               0,
                               -0.009455361945756767,
                               0.50176591878910315,
                               -0.29333165085677415,
                               0.69316204822408356,
                               0,
                               0,
                               0,
                               0,
                               0.11424495237857243,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21921122849047264,
                               -0.18805980520659996,
                               -0.10497739026424185,
                               0,
                               0,
                               -0.55944911314361079,
                               0.16848035604704287,
                               0.59034338829310962,
                               0.16181929644200754,
                               0,
                               0,
                               0,
                               0,
                               0.43531592335840003,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15829823832631679,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.69463915076972071,
                               0.48817216183138745,
                               0,
                               -0.15198029157226023,
                               0,
                               0,
                               0,
                               0,
                               -0.44603405402186769,
                               -0.1790577337062087,
                               -0.69559870140464819,
                               0,
                               0,
                               0,
                               0,
                               0.43227989517189658,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33772389812603193,
                               0,
                               0,
                               0.16060007357981265,
                               0.24709364996960814,
                               -0.35828962025120714,
                               0,
                               0,
                               0,
                               0.43519537110173473,
                               -0.016753563391492005,
                               0.63737006925219286,
                               0,
                               0,
                               0.28360328484924069,
                               -0.29080684155413666,
                               0.36901760060132027,
                               0.10738298026244794,
                               0,
                               0,
                               0,
                               0,
                               0.30228987020936177,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.04798785643379512,
                               0.025749679265117429,
                               -0.63289303013248788,
                               0,
                               0,
                               0.52655660957580641,
                               -0.16718127966839874,
                               0.051811665745076813,
                               0.31045333460975255,
                               0,
                               0,
                               0,
                               0,
                               0.43841004439362991,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33648148029523145,
                               -0.40688599885198234,
                               0.019314866968132671,
                               0,
                               0,
                               -0.040083884374316862,
                               0.3860998861206601,
                               -0.42948997770607261,
                               -0.3529455211633889,
                               0,
                               0,
                               0,
                               0,
                               0.51101752569004744,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.067100913838088,
                               -0.12109921387244696,
                               0.0050069327398605257,
                               0,
                               0,
                               0.49743005386499695,
                               0.65445451248790953,
                               0.45691099751084813,
                               -0.18324192345755408,
                               0,
                               0,
                               0,
                               0,
                               -0.25042912934281986,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14995700766777031,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.55805823041382963,
                               0.026808027466482087,
                               0,
                               0.015018956523457194,
                               0,
                               0,
                               0,
                               0,
                               -0.54985945001400682,
                               -0.60232404331664291,
                               0,
                               0,
                               0,
                               0,
                               -0.40740909140417231,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21865392087360888,
                               -0.047258201424213796,
                               0,
                               0.3683789591339548,
                               0,
                               0,
                               0,
                               0,
                               0.5455781862521264,
                               -0.59212865382381008,
                               -0.45763700899021365,
                               0,
                               0,
                               0,
                               0,
                               -0.27616515369007244,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10653820376746537,
                               0,
                               0,
                               -0.42037837117875321,
                               -0.69374558927145868,
                               -0.2120138425653541,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.02894065761998009,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27464174762250104,
                               0.70333265710892268,
                               0,
                               0.59519801297138697,
                               0,
                               0,
                               0,
                               0,
                               0.04097349433117338,
                               0.27040343999418709,
                               0,
                               -0.62417025429373796,
                               0.41042734261030106,
                               0.24178476333921714,
                               0,
                               0,
                               0.19553699031731789,
                               -0.028691661214456099,
                               -0.076564639117153943,
                               -0.38947115811190325,
                               0,
                               0,
                               0,
                               0,
                               0.43231142170889786,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50092962725043511,
                               0,
                               0,
                               0,
                               0,
                               -0.20999676737187287,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.036602006992851509,
                               0,
                               0,
                               0.21429391173868448,
                               0.042299445791422863,
                               0.80988890324393903,
                               0,
                               0,
                               -0.14565526160011213,
                               0,
                               0,
                               0,
                               0,
                               -0.60946629609810521,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35389255385340518,
                               0,
                               0,
                               0.52005372748149892,
                               0.20393968737085855,
                               -0.41236896520403932,
                               0,
                               0,
                               -0.12149680830610571,
                               0,
                               0,
                               0,
                               0,
                               0.49062415455717268,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.86087920139370777,
                               0,
                               0,
                               -0.041060674432788068,
                               0.035144427352681556,
                               0.022189082572229481,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.47394837544150437,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15576466097109354,
                               0.47677824696442517,
                               0,
                               -0.48520822688800391,
                               0,
                               0,
                               0,
                               0,
                               0.41377014819177549,
                               -0.34228650580472064,
                               0,
                               0,
                               0,
                               0,
                               -0.74900452040573229,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24196529798159408,
                               0.19168100881414327,
                               0,
                               -0.50128401759985708,
                               0,
                               0,
                               0,
                               0,
                               0.16783351213807418,
                               0.25347516593700964};

const double rot_18_10[100] = {-0.30784412248344223,
                               0,
                               0,
                               0,
                               0,
                               -0.49073339616126455,
                               0,
                               0.59529963463705227,
                               0,
                               -0.55680434188808448,
                               0,
                               0.50035979531831165,
                               0.86433022353807321,
                               0,
                               0.050728097812177797,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.86501312490210769,
                               0.50156121760879491,
                               0,
                               -0.013734581823778402,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.88341552036598547,
                               0,
                               0,
                               -0.46115328988397586,
                               0,
                               0.0831544442930226,
                               0,
                               0,
                               -0.037314460683602578,
                               -0.037008237858723148,
                               0,
                               0.99861805579234542,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.92495948683869911,
                               0,
                               0,
                               0,
                               0,
                               0.045079487256498768,
                               0,
                               0.2928766520428151,
                               0,
                               -0.23799381131443997,
                               0,
                               0,
                               0,
                               0.1707562412550068,
                               0,
                               0,
                               0.1515560409200441,
                               0,
                               -0.97358773232467533,
                               0,
                               0.20556027474698643,
                               0,
                               0,
                               0,
                               0,
                               -0.76045807075644023,
                               0,
                               -0.6087402024381694,
                               0,
                               -0.094254241299120967,
                               0,
                               0,
                               0,
                               -0.43637062739024635,
                               0,
                               0,
                               -0.87428165352466791,
                               0,
                               -0.21263176117695723,
                               0,
                               -0.08617956489466122,
                               0,
                               0,
                               0,
                               0,
                               0.42290908756151807,
                               0,
                               -0.43505974029404332,
                               0,
                               -0.79021769698465427};

const double rot_18_100[10000] = {0.045557713946106929,
                                  0,
                                  0,
                                  0,
                                  0.27712757504830149,
                                  0.078905495130781128,
                                  0.16149019364755302,
                                  -0.12581997081273857,
                                  0,
                                  0,
                                  0,
                                  0.34582001953616603,
                                  0.19094808570898078,
                                  0.056853194015823713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19027567850737342,
                                  0,
                                  0.26532083692697023,
                                  0,
                                  0,
                                  0.3238732913141717,
                                  0.35525077398898486,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17751843847028023,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19724212511129979,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.011847599548888262,
                                  0,
                                  0,
                                  -0.043568443823831071,
                                  0,
                                  -0.33758464843145225,
                                  0,
                                  -0.10812376975219319,
                                  0.10895074734816884,
                                  0,
                                  0,
                                  0,
                                  0.054888264110821788,
                                  0,
                                  0.026181536012511619,
                                  0,
                                  0.1613068960814362,
                                  0,
                                  0,
                                  0,
                                  0.060682680699295249,
                                  0,
                                  0,
                                  0,
                                  0.091269731533231646,
                                  0,
                                  0.042744583309246444,
                                  0.21279323324741092,
                                  0,
                                  0,
                                  0,
                                  0.1560869140166142,
                                  0,
                                  0,
                                  0,
                                  0.16333686058946567,
                                  -0.1614986694049306,
                                  0,
                                  0,
                                  0.008012524823373491,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0032867981618974543,
                                  -0.1433461285780416,
                                  -0.016030682176524924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095126527995441718,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06198652594923925,
                                  0,
                                  -0.049201336728142399,
                                  0,
                                  0,
                                  -0.10172569383139288,
                                  -0.32366452983277832,
                                  0,
                                  0.16360673502491435,
                                  0,
                                  -0.24192237170213632,
                                  -0.17628513587037359,
                                  0,
                                  0,
                                  0,
                                  0.20374637580340083,
                                  0.1631103460145874,
                                  0.06695345647469006,
                                  -0.068675579131196526,
                                  0,
                                  0.10506624887091581,
                                  0,
                                  0.17691192830310118,
                                  0.0079061726955384319,
                                  -0.0009165788446747411,
                                  0,
                                  0,
                                  -0.028294907445489223,
                                  -0.18287540817499481,
                                  -0.14798787928711687,
                                  0.050536271394125518,
                                  -0.14709633244983208,
                                  -0.018220572131386739,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035180186003473009,
                                  0,
                                  0,
                                  0,
                                  0.047110361218701123,
                                  0,
                                  -0.10174769931159354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15952468355926572,
                                  0,
                                  0,
                                  0,
                                  0.22376249820214503,
                                  0,
                                  0,
                                  -0.46699968632905264,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082240342981238237,
                                  0,
                                  -0.3362352075096246,
                                  0,
                                  -0.072556662111512529,
                                  -0.22138539563618392,
                                  0.19811506910690335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019671183725810726,
                                  0.062811813129575511,
                                  0.082242152032274529,
                                  0.012463016268789042,
                                  0,
                                  0,
                                  -0.12980968962945397,
                                  0.088578406165423548,
                                  0.26877728029540315,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.024378560418574249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.089927296980829338,
                                  0,
                                  0.27097606138333435,
                                  0,
                                  0,
                                  -0.12658369951570753,
                                  -0.22280834969985355,
                                  0,
                                  -0.29286398569594291,
                                  0,
                                  0.28903779000039148,
                                  -0.14443814867452112,
                                  0,
                                  0,
                                  0,
                                  0.19102285218174281,
                                  0.1256126491632869,
                                  -0.091522040613735034,
                                  0.19335447442327944,
                                  0,
                                  -0.23317929228185316,
                                  0,
                                  0.16813155618847894,
                                  0.01645703024632451,
                                  -0.069604855054971729,
                                  0,
                                  0,
                                  -0.02548716913627045,
                                  -0.11726493327560376,
                                  0.075855862046743827,
                                  0.045735130164403073,
                                  0.093538496635515292,
                                  -0.05598132747204658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14094122842817641,
                                  0,
                                  0,
                                  0,
                                  0.012069923520632372,
                                  0,
                                  0.12593483943348999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.010255960728301126,
                                  0,
                                  0,
                                  0,
                                  -0.057467766208950347,
                                  0,
                                  0,
                                  -0.23977598576123135,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056143264053657188,
                                  0,
                                  0.23838271756662507,
                                  0,
                                  0.17182228088019205,
                                  0.043352748626337013,
                                  0.083497278865804561,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11983212780587299,
                                  -0.24698948307782753,
                                  0.18494457271890541,
                                  -0.20125595160949294,
                                  0,
                                  0,
                                  -0.080991624943908769,
                                  0.3416806920505755,
                                  -0.013640145139297385,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.054867379477816558,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015041973285771009,
                                  0,
                                  0.11612568641639048,
                                  0,
                                  0,
                                  0.26919576866609402,
                                  -0.052182003987422641,
                                  0,
                                  -0.051191544092806671,
                                  0,
                                  -0.073233254467360065,
                                  -0.036182687554346254,
                                  0,
                                  0,
                                  0,
                                  -0.23700974881860631,
                                  0.037614041176433244,
                                  0.065493851077043877,
                                  -0.20202407582652931,
                                  0,
                                  -0.175985360741578,
                                  0,
                                  -0.3060062269420184,
                                  -0.043110817224145337,
                                  0.030718774855338957,
                                  0,
                                  0,
                                  -0.14029089079866114,
                                  0.1794563760705806,
                                  -0.23218898303013238,
                                  0.033850242816627282,
                                  -0.15535642294325047,
                                  -0.16656538644155411,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1993486449505994,
                                  0,
                                  0,
                                  0,
                                  -0.061018227455256827,
                                  0,
                                  -0.33386294593402499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082825637657278309,
                                  0,
                                  0,
                                  0,
                                  0.20366765426769978,
                                  0,
                                  0,
                                  -0.15944120163100942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051922451535138664,
                                  0,
                                  0.12001596839530591,
                                  0,
                                  0.12273130600791975,
                                  -0.078363440846757518,
                                  -0.06660240854771303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24136370014150962,
                                  -0.16919006079075519,
                                  -0.023529667022013506,
                                  -0.16586825508114561,
                                  0,
                                  0.090168262987067191,
                                  0,
                                  0,
                                  0,
                                  -0.25486434112792028,
                                  -0.069079894767135983,
                                  0.20951991573550038,
                                  -0.057403204945676009,
                                  0,
                                  0,
                                  0,
                                  0.028866433779021906,
                                  0.22376241382395726,
                                  0.11215606328963194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23121994971688209,
                                  0,
                                  0.37552846429384562,
                                  0,
                                  0,
                                  -0.16533111130466563,
                                  0.072493755784559272,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073325910939494393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20197255944923181,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38226160139805582,
                                  0,
                                  0,
                                  0.26430779243596825,
                                  0,
                                  0.0068529941634686634,
                                  0,
                                  0.17874159013546861,
                                  -0.24078482739368787,
                                  0,
                                  0,
                                  0,
                                  0.10078766623626084,
                                  0,
                                  -0.13264146033703214,
                                  0,
                                  0.11052003355518851,
                                  0,
                                  0,
                                  0,
                                  0.22664094515816893,
                                  0,
                                  0,
                                  0,
                                  -0.1530206486774443,
                                  0,
                                  -0.11720797490071655,
                                  0.087883665513458734,
                                  0,
                                  0,
                                  0,
                                  0.031742476780922839,
                                  0,
                                  0,
                                  0,
                                  0.046602399996857391,
                                  0.054543293680056927,
                                  0,
                                  0,
                                  -0.29983929277828442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20346659614326262,
                                  0,
                                  0,
                                  0,
                                  0.29620208559258743,
                                  0.11257465645154532,
                                  0.15924373394401395,
                                  0.11423742856317244,
                                  0,
                                  0,
                                  0,
                                  -0.27368746936489202,
                                  0.16241244925209136,
                                  -0.00059354866457514421,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36445904996380268,
                                  0,
                                  -0.19007939989097303,
                                  0,
                                  0,
                                  0.20521690138776799,
                                  0.029804284432949503,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20069293839374841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0069914143936313927,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022493907169395908,
                                  0,
                                  0,
                                  -0.097783990129188411,
                                  0,
                                  0.021792995149839553,
                                  0,
                                  -0.25592817740878859,
                                  -0.11735538723526848,
                                  0,
                                  0,
                                  0,
                                  0.008164697698728185,
                                  0,
                                  0.19708512028174213,
                                  0,
                                  0.11636072602092398,
                                  0,
                                  0,
                                  0,
                                  0.29347091208441672,
                                  0,
                                  0,
                                  0,
                                  -0.23141800698950307,
                                  0,
                                  0.096548398834674753,
                                  0.23348388795492397,
                                  0,
                                  0,
                                  0,
                                  -0.16643658871846162,
                                  0,
                                  0,
                                  0,
                                  -0.19847331592839779,
                                  -0.14409023282658645,
                                  0,
                                  0,
                                  -0.18049305670764279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22627624907822491,
                                  0,
                                  0,
                                  0,
                                  -0.15068398948636946,
                                  -0.20886443931200874,
                                  0.13224845359579879,
                                  0.14136791147699881,
                                  0,
                                  0,
                                  0,
                                  0.16589752253074205,
                                  0.03509402941103857,
                                  0.033421059038736059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.018580540336065553,
                                  0,
                                  -0.20918160191087723,
                                  0,
                                  0,
                                  -0.0024546854537090303,
                                  -0.10376100898655374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.04111727725928474,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.05482914617372292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0091539629646212803,
                                  0,
                                  0,
                                  -0.064442892391561743,
                                  0,
                                  0.0306426093996299,
                                  0,
                                  0.25444303131446327,
                                  0.11340230455287539,
                                  0,
                                  0,
                                  0,
                                  0.22357732099808858,
                                  0,
                                  -0.046592306938758932,
                                  0,
                                  -0.080250107326146652,
                                  0,
                                  0,
                                  0,
                                  0.55931433153599919,
                                  0,
                                  0,
                                  0,
                                  0.033967749721390515,
                                  0,
                                  0.21477326742844075,
                                  0.12586428327884644,
                                  0,
                                  0,
                                  0,
                                  0.059003762513344972,
                                  0,
                                  0,
                                  0,
                                  -0.086826533929555444,
                                  -0.15237552084305719,
                                  0,
                                  0,
                                  0.45164533885082014,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.012517250085283314,
                                  0,
                                  0,
                                  0,
                                  -0.26033946596499674,
                                  0.056947990891888962,
                                  0.18128453298391109,
                                  0.080450347065803215,
                                  0,
                                  0,
                                  0,
                                  -0.27547194542408904,
                                  0.039937587186978728,
                                  0.51956970331824592,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10046157426423623,
                                  0,
                                  -0.361885262578865,
                                  0,
                                  0,
                                  0.072448578728228324,
                                  0.022739493861117559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.09167629073971445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.091466186328408583,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053763504610026297,
                                  0,
                                  0,
                                  0.27789711616817536,
                                  0,
                                  0.0362937252092786,
                                  0,
                                  -0.045683708187667676,
                                  0.10783645709004402,
                                  0,
                                  0,
                                  0,
                                  0.15094903647161029,
                                  0,
                                  0.083527037314821473,
                                  0,
                                  0.39157046190440764,
                                  0,
                                  0,
                                  0,
                                  -0.1450325509004371,
                                  0,
                                  0,
                                  0,
                                  0.18437150567673419,
                                  0,
                                  -0.13728460324964845,
                                  0.036546240195091964,
                                  0,
                                  0,
                                  0,
                                  0.12526168578531977,
                                  0,
                                  0,
                                  0,
                                  0.073680779395696949,
                                  -0.062247255706640928,
                                  0,
                                  0,
                                  0.0045513828339082381,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22038053113102196,
                                  -0.24908072490094177,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.075503487618998805,
                                  0,
                                  0.10612125459615551,
                                  0,
                                  -0.11576084203399581,
                                  0.20824019152319437,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11448562015965597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.02994791494766582,
                                  0,
                                  0,
                                  0,
                                  -0.416178989053198,
                                  0.015728497458582236,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1982012801929236,
                                  -0.16369614827496431,
                                  0,
                                  0.10101599416383865,
                                  0.22685398277346508,
                                  0,
                                  -0.12677488744969118,
                                  0,
                                  -0.25570371738261999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25003977360875085,
                                  0,
                                  0,
                                  0.10904207078968421,
                                  0.088760528065464014,
                                  0.0027614867693938512,
                                  0,
                                  0.04304758771138769,
                                  0,
                                  0,
                                  0,
                                  -0.25027153666238527,
                                  -0.14193271113459396,
                                  0,
                                  0,
                                  0.18833780534122657,
                                  0,
                                  0.087283174180071157,
                                  0,
                                  -0.12719587686497769,
                                  0,
                                  0,
                                  0,
                                  -0.14362652866919307,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13501437599604818,
                                  -0.39075237125673912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.035517537359643428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16537050167667133,
                                  0.24420670445798243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44470359457092645,
                                  0,
                                  0.024195679157193513,
                                  0,
                                  0.15182919105354156,
                                  0.43645311275311038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25909111647298283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083705830137360618,
                                  0,
                                  0,
                                  0,
                                  0.054985886692732175,
                                  -0.041251993145956886,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20908795713772108,
                                  0.088456109791307289,
                                  0,
                                  0.1232909267198736,
                                  -0.057596094380363318,
                                  0,
                                  0.1649867693204049,
                                  0,
                                  -0.033240096019000145,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14871671995614613,
                                  0,
                                  0,
                                  -0.0069912722756008787,
                                  -0.40910832434056238,
                                  -0.090016526492856658,
                                  0,
                                  0.08466133937260395,
                                  0,
                                  0,
                                  0,
                                  0.085123775475952831,
                                  -0.19338771789443751,
                                  0,
                                  0,
                                  -0.092427152607154381,
                                  0,
                                  0.11822563801657805,
                                  0,
                                  -0.12041933101847982,
                                  0,
                                  0,
                                  0,
                                  0.07003728294421338,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16120689200752547,
                                  0.034314228084310332,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073061250498278635,
                                  0,
                                  -0.15837482487385349,
                                  0.17418277413459171,
                                  0.0029370603103430915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.01655076976378168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.011733410462906976,
                                  0,
                                  0.052142881093286131,
                                  0,
                                  0,
                                  0.099738722037205171,
                                  -0.10357025997434333,
                                  0,
                                  -0.18570231608713128,
                                  0,
                                  0.093600180055901386,
                                  0.013873279490577272,
                                  0,
                                  0,
                                  0,
                                  -0.17404699207852617,
                                  0.05640257392235374,
                                  -0.10486485156558625,
                                  -0.15990699347919995,
                                  0,
                                  0.0079558899876533938,
                                  0,
                                  0.2807945055332699,
                                  0.58446129228432198,
                                  0.11875860026735548,
                                  0,
                                  0,
                                  0.037419612993477312,
                                  0.055237249132414248,
                                  -0.17122071936970482,
                                  -0.12792618130200833,
                                  0.00047822116131055175,
                                  0.34348699430740798,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047752897609483799,
                                  0,
                                  0,
                                  0,
                                  -0.006755918448509219,
                                  0,
                                  -0.127502456261567,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19943262351584379,
                                  0,
                                  0,
                                  0,
                                  0.024204288101513694,
                                  0,
                                  0,
                                  0.083903347178816576,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.051312341756638714,
                                  0,
                                  -0.15879601715556071,
                                  0,
                                  0.094167670277927412,
                                  -0.13118289123456947,
                                  -0.018706557675185281,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11920086724538805,
                                  0.080215461689774989,
                                  0.087330841114961699,
                                  0.23671347931303,
                                  0,
                                  0.10972585245160768,
                                  0,
                                  0,
                                  0,
                                  0.056453445411033608,
                                  -0.001856617416048114,
                                  -0.235208271640688,
                                  0.016834000291056323,
                                  0,
                                  0,
                                  0,
                                  0.031527506597410777,
                                  -0.2266640832941107,
                                  -0.17322810895480406,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30217173224318572,
                                  0,
                                  -0.27874275478951732,
                                  0,
                                  0,
                                  -0.3323771905519769,
                                  0.1144547345709326,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030382415697121894,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019949471059616874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.010283113286845731,
                                  0,
                                  0,
                                  -0.010471541672356824,
                                  0,
                                  -0.19756683022149751,
                                  0,
                                  0.012518024044077314,
                                  0.33191916693461931,
                                  0,
                                  0,
                                  0,
                                  -0.091491195134872028,
                                  0,
                                  -0.096545856382514894,
                                  0,
                                  0.21520474463015016,
                                  0,
                                  0,
                                  0,
                                  0.12025062503184542,
                                  0,
                                  0,
                                  0,
                                  -0.016371739735263284,
                                  0,
                                  0.13754201907819549,
                                  0.084024146919633738,
                                  0,
                                  0,
                                  0,
                                  0.36796353759002837,
                                  0,
                                  0,
                                  0,
                                  0.22247759111928964,
                                  -0.056582160357148831,
                                  0,
                                  0,
                                  -0.33242003605694298,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06981387020719497,
                                  0,
                                  0,
                                  0,
                                  -0.23775414063926417,
                                  0.16271188310995821,
                                  0.17547503755789157,
                                  -0.24288744009649388,
                                  0,
                                  0,
                                  0,
                                  0.12962214094516683,
                                  0.067570047287615606,
                                  0.057122831193119339,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11639310078120624,
                                  0,
                                  -0.12667574338609305,
                                  0,
                                  0,
                                  0.029857598341050888,
                                  -0.22709319324889737,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10394594232008479,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17308889651202883,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30611681863255197,
                                  0,
                                  0,
                                  -0.27771210340919356,
                                  0,
                                  -0.1518583043278936,
                                  0,
                                  0.034659085637899462,
                                  -0.046759968820889723,
                                  0,
                                  0,
                                  0,
                                  -0.16683161194788748,
                                  0,
                                  -0.20494975909144664,
                                  0,
                                  -0.021259389763982249,
                                  0,
                                  0,
                                  0,
                                  0.36169165648713825,
                                  0,
                                  0,
                                  0,
                                  0.20379107809905594,
                                  0,
                                  -0.18914293053661654,
                                  -0.10138341125029683,
                                  0,
                                  0,
                                  0,
                                  -0.10194577896813631,
                                  0,
                                  0,
                                  0,
                                  -0.0028518723805465857,
                                  0.17644982982087953,
                                  0,
                                  0,
                                  -0.38389544089763283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33508197722503064,
                                  0,
                                  0,
                                  0,
                                  0.17985353050557579,
                                  0.16352099370225706,
                                  -0.31016664311144837,
                                  -0.32772647382595232,
                                  0,
                                  0,
                                  0,
                                  0.043000480985859929,
                                  0.24694785580660547,
                                  0.2226512433716315,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085346549337146985,
                                  0,
                                  -0.046679380310091487,
                                  0,
                                  0,
                                  -0.019303433480867632,
                                  -0.36439059196348356,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.029445386921332271,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.018405680432415333,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32200228180386231,
                                  0,
                                  0,
                                  -0.14419042343952973,
                                  0,
                                  0.19724690766098357,
                                  0,
                                  0.27556891441857045,
                                  0.015293158531194145,
                                  0,
                                  0,
                                  0,
                                  0.026824412773915646,
                                  0,
                                  0.019007191982933894,
                                  0,
                                  0.0388599282656895,
                                  0,
                                  0,
                                  0,
                                  -0.035639214394672158,
                                  0,
                                  0,
                                  0,
                                  0.070889272330988046,
                                  0,
                                  0.20487397611233105,
                                  0.2021351471412331,
                                  0,
                                  0,
                                  0,
                                  0.16584129612353976,
                                  0,
                                  0,
                                  0,
                                  0.087017318744701283,
                                  -0.049453005788303146,
                                  0,
                                  0,
                                  -0.0019540064381676769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16735151318070865,
                                  0.04792914580212071,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084641823281153133,
                                  0,
                                  0.12315164006111874,
                                  0,
                                  0.40812010559565415,
                                  -0.17999515857218851,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14423516155189764,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11238196442376455,
                                  0,
                                  0,
                                  0,
                                  -0.01136245102783557,
                                  0.096761478399107051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20928231501149314,
                                  -0.073758818710635957,
                                  0,
                                  -0.015329887153998079,
                                  0.36133568579755554,
                                  0,
                                  -0.2595428299918896,
                                  0,
                                  0.0054615869731058355,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067150627556698622,
                                  0,
                                  0,
                                  -0.13758846307311107,
                                  -0.19989850121040634,
                                  -0.17282084323008104,
                                  0,
                                  0.14092864051274639,
                                  0,
                                  0,
                                  0,
                                  -0.045341497655929208,
                                  -0.081369121489666851,
                                  0,
                                  0,
                                  0.055742433048538376,
                                  0,
                                  0.086617176629411582,
                                  0,
                                  0.42115553942532002,
                                  0,
                                  0,
                                  0,
                                  0.11873390971054143,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0012916719677757565,
                                  0.177519677990673,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32039273302662619,
                                  0,
                                  0.2132926900107483,
                                  0.27915213490134716,
                                  0.079677262054348608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062112111077773917,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2672578617478043,
                                  0,
                                  -0.026182053331214063,
                                  0,
                                  0,
                                  -0.14492463813687401,
                                  -0.1484874410514965,
                                  0,
                                  0.18289543849751885,
                                  0,
                                  0.041003848772229692,
                                  -0.097856219189662766,
                                  0,
                                  0,
                                  0,
                                  -0.14401829430410476,
                                  -0.25012756992777918,
                                  -0.028616148334360405,
                                  0.0099570207476320852,
                                  0,
                                  -0.22374433943971905,
                                  0,
                                  0.15648461182140183,
                                  -0.15987433111765492,
                                  -0.13559563318366311,
                                  0,
                                  0,
                                  0.30172060602739631,
                                  -0.14478574077990103,
                                  0.01110163047077159,
                                  0.10641842314108794,
                                  0.2102692913502496,
                                  0.043715738100212329,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.038607188563895181,
                                  0,
                                  0,
                                  0,
                                  0.17452836774267833,
                                  0,
                                  -0.28260045303629194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.054667510974829497,
                                  0,
                                  0,
                                  0,
                                  0.26732680924119784,
                                  0,
                                  0,
                                  0.21563130236375219,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1440908934454527,
                                  0,
                                  0.028811495463485562,
                                  0,
                                  -0.033463469133280833,
                                  -0.093266826931938676,
                                  -0.031078740993240109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23374793312732631,
                                  0.041586110232058077,
                                  0.10203310611209013,
                                  -0.047914767691733584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13176461766501529,
                                  -0.10333078698108604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.04697011343113193,
                                  0,
                                  0.20283557419652079,
                                  0,
                                  0.047606158211649707,
                                  -0.20564471548001914,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31284380634580028,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082193620763869657,
                                  0,
                                  0,
                                  0,
                                  -0.035546574782803333,
                                  -0.43078774308423773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0063286697604812096,
                                  0.23569825153098142,
                                  0,
                                  -0.52032525323529855,
                                  0.10816795817934929,
                                  0,
                                  0.23335723825000637,
                                  0,
                                  -0.057257284128743084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017416363668400728,
                                  0,
                                  0,
                                  -0.036977386303229449,
                                  -0.067888111881450344,
                                  -0.0092786177828177337,
                                  0,
                                  -0.15754213057716615,
                                  0,
                                  0,
                                  0,
                                  -0.11158969826772963,
                                  0.13605862840716507,
                                  0,
                                  0,
                                  0.038471869196978065,
                                  0,
                                  -0.13058509801078963,
                                  0,
                                  -0.27566209495801969,
                                  0,
                                  0,
                                  0,
                                  0.092017552109217485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.062925207589539081,
                                  0.040801132952383086,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16142565463450809,
                                  0,
                                  -0.041966061026328813,
                                  0.059523819900382247,
                                  0.23600610656220278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.013991821609175231,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.088074637102815503,
                                  0,
                                  -0.21972068147411158,
                                  0,
                                  0,
                                  -0.042622377862167576,
                                  0.088304247698437893,
                                  0,
                                  0.071718684066114119,
                                  0,
                                  0.099606132837214492,
                                  0.033076867447807176,
                                  0,
                                  0,
                                  0,
                                  0.10320324250466495,
                                  0.019436106118527238,
                                  0.17887595705928802,
                                  0.44410808333336982,
                                  0,
                                  0.082390111027571947,
                                  0,
                                  -0.02362545962087266,
                                  0.14834118146811542,
                                  -0.21862063919975253,
                                  0,
                                  0,
                                  0.028171341496464396,
                                  -0.021945043882864584,
                                  -0.037484591921879896,
                                  -0.17529257956620728,
                                  -0.086304430306632013,
                                  0.19457712978997491,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11066782024892197,
                                  0,
                                  0,
                                  0,
                                  -0.15561563659264049,
                                  0,
                                  -0.016514367066771875,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03442265137361912,
                                  0,
                                  0,
                                  0,
                                  0.059956971821485253,
                                  0,
                                  0,
                                  0.12630374574856601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2737826835453212,
                                  0,
                                  -0.23688960342888155,
                                  0,
                                  0.17436309082500981,
                                  -0.18390923939807366,
                                  -0.055588381966219048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21753913727672547,
                                  -0.15379870795429679,
                                  -0.2404351164455667,
                                  -0.27609674852180294,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23405042890484992,
                                  -0.22415995894243723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.093247037434895458,
                                  0,
                                  -0.36113260769749028,
                                  0,
                                  0.17791801903157362,
                                  -0.14535732195774281,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.088651399529906527,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094497239918816131,
                                  0,
                                  0,
                                  0,
                                  -0.10193737874679142,
                                  -0.33589688080362923,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30393789294400547,
                                  0.023533117150911331,
                                  0,
                                  0.22823976047114605,
                                  0.18504577938183497,
                                  0,
                                  0.061645716555406363,
                                  0,
                                  0.16348553287271211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043933537927765699,
                                  0,
                                  0,
                                  0.14342154426483608,
                                  0.06247620078081155,
                                  -0.32456515273463782,
                                  0,
                                  -0.1399245021434507,
                                  0,
                                  0,
                                  0,
                                  0.10616700983276942,
                                  -0.22783753691091849,
                                  0,
                                  0,
                                  -0.08929831763890253,
                                  0,
                                  0.021513092013074067,
                                  0,
                                  0.046290821578381852,
                                  0,
                                  0,
                                  0,
                                  -0.17531645376375948,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2952610570283794,
                                  -0.066910005603322054,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.076143522007101838,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11294836106008899,
                                  -0.15226153253903688,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15138764177828656,
                                  0,
                                  0.18205221112668274,
                                  0,
                                  -0.28035358247567788,
                                  -0.0085669227102499398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10074266429271084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28619452563350878,
                                  0,
                                  0,
                                  0,
                                  -0.085754755438456037,
                                  -0.054578497203870292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.029671938787789846,
                                  -0.27050777713054697,
                                  0,
                                  0.21075422930124466,
                                  -0.041451458730057407,
                                  0,
                                  0.14761478722147678,
                                  0,
                                  0.22691491140831371,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.048835576746353068,
                                  0,
                                  0,
                                  -0.26677363436062418,
                                  0.043844275990400049,
                                  0.11178557965917581,
                                  0,
                                  0.011056024705612774,
                                  0,
                                  0,
                                  0,
                                  0.48240587091136605,
                                  -0.19149112628239184,
                                  0,
                                  0,
                                  -0.063055456786405062,
                                  0,
                                  -0.18669223677221339,
                                  0,
                                  0.024891938675108659,
                                  0,
                                  0,
                                  0,
                                  0.1473468318516003,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.066885170697043528,
                                  0.010723627168376937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33202270354655311,
                                  0,
                                  -0.16672787069209435,
                                  0.10758470158242103,
                                  -0.24002868060031565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34083796525636206,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17519571232334474,
                                  0,
                                  -0.25357471053532166,
                                  0,
                                  0,
                                  -0.037580418615484938,
                                  -0.057497912265851873,
                                  0,
                                  0.18984968952494155,
                                  0,
                                  0.0042492383500912778,
                                  -0.10931954812252723,
                                  0,
                                  0,
                                  0,
                                  -0.095584308895093326,
                                  -0.20635461532999005,
                                  -0.25687518873915982,
                                  0.061379350719067492,
                                  0,
                                  0.031268088932745332,
                                  0,
                                  0.11613711806566793,
                                  -0.025762231675897293,
                                  -0.027809079854455097,
                                  0,
                                  0,
                                  0.069089959118829605,
                                  -0.0344780761551257,
                                  0.20266416992974315,
                                  0.27954464421736286,
                                  -0.14672490962113374,
                                  -0.14692482627908615,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27538796890040962,
                                  0,
                                  0,
                                  0,
                                  -0.1929182219272072,
                                  0,
                                  0.094302055594119943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029405970059641899,
                                  0,
                                  0,
                                  0,
                                  0.00048558411435779825,
                                  0,
                                  0,
                                  0.047760261165138283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.035745448456832356,
                                  0,
                                  -0.13712080561497131,
                                  0,
                                  0.26916682580707291,
                                  -0.003440926318479164,
                                  -0.058749216824481004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1606522133924467,
                                  0.023688388981163211,
                                  0.29131834112921073,
                                  0.033544938904220931,
                                  0,
                                  0,
                                  0.19861879910652941,
                                  -0.04783274378607133,
                                  0.038204780687600588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060058632385465549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16177700805468431,
                                  0,
                                  0.26970286884958233,
                                  0,
                                  0,
                                  0.13602261523698345,
                                  -0.10498019308686823,
                                  0,
                                  -0.057337282271761436,
                                  0,
                                  -0.20780964010677594,
                                  -0.25261173029221518,
                                  0,
                                  0,
                                  0,
                                  0.28243769783915468,
                                  -0.047180930592426923,
                                  -0.0036780786624493909,
                                  0.15998129088246857,
                                  0,
                                  0.16501301916212488,
                                  0,
                                  0.23511461806596792,
                                  0.11918939105896978,
                                  -0.10117686515481306,
                                  0,
                                  0,
                                  -0.13948136953931611,
                                  0.1702066210801344,
                                  -0.013987081671062615,
                                  0.067105814792520535,
                                  -0.16806675605218549,
                                  -0.17392478157544097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072051517328703296,
                                  0,
                                  0,
                                  0,
                                  0.051887072714719693,
                                  0,
                                  -0.073573577733343123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21851598333088193,
                                  0,
                                  0,
                                  0,
                                  0.063068812928427406,
                                  0,
                                  0,
                                  0.30880640598166137,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15757592931642392,
                                  0,
                                  -0.033181584772857722,
                                  0,
                                  0.0611312860440138,
                                  0.1409207167245948,
                                  -0.34784195863286499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075589327437223866,
                                  -0.11825750932450962,
                                  -0.0074391216885102869,
                                  0.19401136903539912,
                                  0,
                                  -0.027697635523452408,
                                  0,
                                  0,
                                  0,
                                  0.1455245012579891,
                                  0.28624198905196524,
                                  0.24450719193849391,
                                  -0.13455731629270559,
                                  0,
                                  0,
                                  0,
                                  -0.059371979947956684,
                                  -0.36345111791257501,
                                  -0.019563642722769854,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36985974821541423,
                                  0,
                                  0.16850933527074241,
                                  0,
                                  0,
                                  0.16757389648384519,
                                  -0.25136776840206876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022214537894713185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17751047786347515,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1536301760157876,
                                  0,
                                  0,
                                  0.22995989740934858,
                                  0,
                                  -0.14100419315262555,
                                  0,
                                  0.25990807208572264,
                                  -0.085151366272514808,
                                  0,
                                  0,
                                  0,
                                  0.24568365715375909,
                                  0,
                                  -0.010009893900412591,
                                  0,
                                  0.029268036813209906,
                                  0,
                                  0,
                                  0,
                                  -0.067410391355245458,
                                  0,
                                  0,
                                  0,
                                  0.031881745222475125,
                                  0,
                                  0.26715874705993825,
                                  -0.19370348719125616,
                                  0,
                                  0,
                                  0,
                                  -0.0014017432163600041,
                                  0,
                                  0,
                                  0,
                                  0.15489815113112618,
                                  0.12412825711678509,
                                  0,
                                  0,
                                  0.086141382511000703,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072677175129859509,
                                  0.053297744642806746,
                                  -0.17249283355661543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42223840166239246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058700039080352089,
                                  0,
                                  -0.25391789690532252,
                                  0,
                                  0,
                                  0.071265186084439186,
                                  -0.21532100119227413,
                                  0,
                                  -0.066012975359903595,
                                  0,
                                  0.072466295236731829,
                                  -0.057293950570557597,
                                  0,
                                  0,
                                  0,
                                  -0.11526458365536706,
                                  0.17676392428203883,
                                  -0.087487601778003105,
                                  -0.1910201548000913,
                                  0,
                                  -0.077545077386037012,
                                  0,
                                  0.17340807763849672,
                                  -0.1261437579684476,
                                  -0.19176788170915587,
                                  0,
                                  0,
                                  -0.096558680095782209,
                                  0.025167440041749881,
                                  0.23044076252319176,
                                  -0.039820336066187727,
                                  0.18037747227909467,
                                  0.13955183963125303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.071534565224661797,
                                  0,
                                  0,
                                  0,
                                  -0.031858259257390095,
                                  0,
                                  0.11864268377183425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025244665106724767,
                                  0,
                                  0,
                                  0,
                                  0.13603456600038605,
                                  0,
                                  0,
                                  0.12050266453914064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2871977851792718,
                                  0,
                                  -0.15762162479664091,
                                  0,
                                  0.11327905558237056,
                                  0.19116103943991394,
                                  0.11202512967210784,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24406078527389943,
                                  -0.18089094886839943,
                                  -0.18300187897904488,
                                  -0.092646360379100276,
                                  0,
                                  0.28147762228814366,
                                  0,
                                  0,
                                  0,
                                  0.32964234098307515,
                                  0.030113688967806959,
                                  0.13865824365038681,
                                  0.017888107669857243,
                                  0,
                                  0,
                                  0,
                                  -0.083133505573103061,
                                  0.023329624585751101,
                                  0.09885723422782991,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0076492474992556243,
                                  0,
                                  0.028854678344998212,
                                  0,
                                  0,
                                  -0.30029321310146861,
                                  -0.092969023731023143,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24517980508002374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094568811911418527,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072609615396800942,
                                  0,
                                  0,
                                  -0.29129527138140215,
                                  0,
                                  0.22054225405665423,
                                  0,
                                  -0.080337427737475084,
                                  0.10159369273094751,
                                  0,
                                  0,
                                  0,
                                  0.47649178268128639,
                                  0,
                                  -0.3262271263689509,
                                  0,
                                  -0.055625552623978738,
                                  0,
                                  0,
                                  0,
                                  -0.14875998465990098,
                                  0,
                                  0,
                                  0,
                                  0.0082552993924275078,
                                  0,
                                  -0.11229336888900555,
                                  0.1140392027346161,
                                  0,
                                  0,
                                  0,
                                  -0.17310740518877293,
                                  0,
                                  0,
                                  0,
                                  -0.065161305775565184,
                                  -0.069722152385787675,
                                  0,
                                  0,
                                  -0.16331105900680581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32887789445999921,
                                  -0.11915978828866022,
                                  -0.2253665034064429,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21763625753158805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2225911744194585,
                                  0,
                                  0.18150641937141765,
                                  0,
                                  0,
                                  -0.11535515555079723,
                                  0.13054930780177815,
                                  0,
                                  0.15121189430244844,
                                  0,
                                  -0.13376762942998083,
                                  0.067393981698650213,
                                  0,
                                  0,
                                  0,
                                  -0.007729233178481826,
                                  0.12816771954838088,
                                  -0.028606788858697971,
                                  -0.043918609095539268,
                                  0,
                                  -0.16415464861320533,
                                  0,
                                  -0.18347573054793143,
                                  0.17003932858309845,
                                  -0.36765470918744964,
                                  0,
                                  0,
                                  0.08837715689455565,
                                  -0.28074699450696483,
                                  -0.060289268812400931,
                                  0.2114545356274887,
                                  -0.1460537444557706,
                                  0.12881402042150059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.034223974396286085,
                                  0,
                                  0,
                                  0,
                                  0.17320795271846198,
                                  0,
                                  0.026461678061713644,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17229362357352801,
                                  0,
                                  0,
                                  0,
                                  -0.01844558619289673,
                                  0,
                                  0,
                                  0.17514443206594188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11817513761298486,
                                  0,
                                  0.095433540959548965,
                                  0,
                                  0.15434783680634565,
                                  0.011240949466396224,
                                  -0.083423032117774382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13868435675901111,
                                  -0.1423532996993874,
                                  -0.088799333695329927,
                                  0.1028337489600501,
                                  0,
                                  0,
                                  -0.04322620001253772,
                                  -0.19958741005961228,
                                  -0.31371074849066094,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077710347539567459,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13577198818955433,
                                  0,
                                  0.039475420447466623,
                                  0,
                                  0,
                                  0.25284233942517198,
                                  0.13745301881870473,
                                  0,
                                  -0.073654041145859439,
                                  0,
                                  0.32903778068079748,
                                  -0.033395820208909681,
                                  0,
                                  0,
                                  0,
                                  0.3145894920769659,
                                  -0.25242876891386162,
                                  -0.042041930841917,
                                  -0.09681637248439659,
                                  0,
                                  -0.063578956324457536,
                                  0,
                                  0.030293776992647199,
                                  -0.10187568902660141,
                                  0.15117375425093538,
                                  0,
                                  0,
                                  0.0026933509513931099,
                                  0.023756259400938663,
                                  0.078130772702834222,
                                  -0.021093855906540018,
                                  -0.17422209135788341,
                                  0.32649789385019656,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12838106233585839,
                                  0,
                                  0,
                                  0,
                                  0.12636669374289994,
                                  0,
                                  -0.18769221713994452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11023447589657523,
                                  0,
                                  0,
                                  0,
                                  0.15658466590468476,
                                  0,
                                  0,
                                  -0.088564283080080394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18210451359327195,
                                  0,
                                  -0.099375678515962435,
                                  0,
                                  0.045516610116848835,
                                  0.27292868281892235,
                                  0.13810743996705208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.090980954713723333,
                                  -0.093474963343152209,
                                  -0.059544691794522618,
                                  -0.093276733662071259,
                                  0,
                                  0.019868217362093588,
                                  0,
                                  0,
                                  0,
                                  0.11027115763361456,
                                  0.16232299505725881,
                                  0.13965523939711311,
                                  0.14098630743090645,
                                  0,
                                  0,
                                  0,
                                  0.06134514164876026,
                                  -0.31879202783358795,
                                  -0.11367476885121609,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1095458714391323,
                                  0,
                                  0.026922131434886649,
                                  0,
                                  0,
                                  -0.041155537999960946,
                                  0.11348287766078635,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45345538906154886,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22469720128910844,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36940286411257583,
                                  0,
                                  0,
                                  0.097612100540281937,
                                  0,
                                  0.26885511410684543,
                                  0,
                                  -0.02621182060977461,
                                  0.019835588632115694,
                                  0,
                                  0,
                                  0,
                                  -0.13602476075440359,
                                  0,
                                  -0.17737572373435601,
                                  0,
                                  0.12294258713778443,
                                  0,
                                  0,
                                  0,
                                  0.057310732705346736,
                                  0,
                                  0,
                                  0,
                                  0.28776363859006082,
                                  0,
                                  -0.14279133939908667,
                                  0.23712871195650193,
                                  0,
                                  0,
                                  0,
                                  -0.19441676644593225,
                                  0,
                                  0,
                                  0,
                                  0.1730157800925273,
                                  0.046647047269699288,
                                  0,
                                  0,
                                  0.05426410112606584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.069207367092962435,
                                  0,
                                  0,
                                  0,
                                  -0.01330866369451811,
                                  -0.21711780887007442,
                                  0.031043655424201524,
                                  -0.13869259489642249,
                                  0,
                                  0,
                                  0,
                                  -0.12415815663446329,
                                  -0.10878310962568635,
                                  -0.018602223985542059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19752515516711766,
                                  0,
                                  -0.0091738643202769199,
                                  0,
                                  0,
                                  0.06076111598199388,
                                  0.040540905725967691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22420894618555501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39304584535561438,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18833135286960911,
                                  0,
                                  0,
                                  -0.1131166777435722,
                                  0,
                                  -0.14402278402002849,
                                  0,
                                  -0.27916828510337172,
                                  -0.024834253055294644,
                                  0,
                                  0,
                                  0,
                                  0.41169098457077169,
                                  0,
                                  0.07006766218489105,
                                  0,
                                  -0.032427865373460679,
                                  0,
                                  0,
                                  0,
                                  0.098497134575854461,
                                  0,
                                  0,
                                  0,
                                  0.31789004183495678,
                                  0,
                                  0.28345270909303533,
                                  -0.25915112967063225,
                                  0,
                                  0,
                                  0,
                                  -0.068263517321167547,
                                  0,
                                  0,
                                  0,
                                  0.19837152679812331,
                                  -0.02435900770449094,
                                  0,
                                  0,
                                  -0.15822229938961122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38838405570699641,
                                  -0.043139503363386705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049617113791440216,
                                  0,
                                  0.036413398503181371,
                                  0,
                                  -0.059133330416874491,
                                  0.3478194777255994,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.010709649233380615,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062020746318465804,
                                  0,
                                  0,
                                  0,
                                  -0.0040041649242689888,
                                  0.15509567335724078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060729558485446956,
                                  0.40402088394266844,
                                  0,
                                  0.055809939427645713,
                                  0.20561751201929193,
                                  0,
                                  0.05961887968807867,
                                  0,
                                  0.25760327745630335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17006157624560697,
                                  0,
                                  0,
                                  -0.063354632025827917,
                                  -0.016760791918639942,
                                  0.14529989589001874,
                                  0,
                                  0.015451709976055456,
                                  0,
                                  0,
                                  0,
                                  0.025150665289381282,
                                  0.31193461528446437,
                                  0,
                                  0,
                                  0.33357471950070317,
                                  0,
                                  -0.033035027130572596,
                                  0,
                                  0.060784505820848475,
                                  0,
                                  0,
                                  0,
                                  -0.021134014731820666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23333101881794344,
                                  0.049678135878278851,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28784621089660412,
                                  0,
                                  0.059248665338523389,
                                  0.16011976469563854,
                                  -0.28885849980165035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022005705673850906,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14569759360967577,
                                  0,
                                  -0.22188403398992246,
                                  0,
                                  0,
                                  0.10390301163938895,
                                  0.2430162294262444,
                                  0,
                                  -0.043256432853005081,
                                  0,
                                  -0.020560902753874656,
                                  -0.046531098154639877,
                                  0,
                                  0,
                                  0,
                                  0.20757525847165331,
                                  0.26614433737426246,
                                  -0.044803920914788888,
                                  0.096529901464418671,
                                  0,
                                  -0.027038068873888262,
                                  0,
                                  0.20788677622325932,
                                  -0.12923614395421526,
                                  -0.15387906039107335,
                                  0,
                                  0,
                                  0.098764247120102566,
                                  0.10586109251497017,
                                  -0.11166320701627984,
                                  -0.23407858146784474,
                                  -0.13386209154867146,
                                  -0.075727662266134199,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038083869748487466,
                                  0,
                                  0,
                                  0,
                                  -0.10434523674312744,
                                  0,
                                  -0.17106234822798747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.029541862671084197,
                                  0,
                                  0,
                                  0,
                                  -0.077236659642583791,
                                  0,
                                  0,
                                  0.15629400193231624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10576768539214203,
                                  0,
                                  0.19999074969865269,
                                  0,
                                  -0.25331744112344379,
                                  -0.2823592922606119,
                                  0.21404859687089683,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1800378844705873,
                                  -0.20778972871725956,
                                  0.17647767205279274,
                                  0.014404956932817084,
                                  0,
                                  0,
                                  0.13093541372669731,
                                  -0.27585558854306563,
                                  0.033487627372710334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025341483209402663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12175659591541214,
                                  0,
                                  0.19211622601812764,
                                  0,
                                  0,
                                  0.017117829697637584,
                                  0.2291014109762938,
                                  0,
                                  0.13416401683254497,
                                  0,
                                  0.17906586648567591,
                                  0.045114603331995351,
                                  0,
                                  0,
                                  0,
                                  -0.30402542889680073,
                                  -0.02587262744762802,
                                  0.16443806158655647,
                                  0.19179169129173015,
                                  0,
                                  -0.23269773196475657,
                                  0,
                                  0.29464023120565364,
                                  0.1285858986209831,
                                  -0.14801111946782591,
                                  0,
                                  0,
                                  0.1151810023027736,
                                  0.13021878347784513,
                                  -0.10079754599415922,
                                  -0.020547737378967403,
                                  -0.04227818472659782,
                                  -0.16125228141424958,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.060386684027111767,
                                  0,
                                  0,
                                  0,
                                  -0.057539719274482509,
                                  0,
                                  0.021782058436222811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095551137426935343,
                                  0,
                                  0,
                                  0,
                                  0.2688345927526683,
                                  0,
                                  0,
                                  -0.072009843640950436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064280277288052468,
                                  0,
                                  0.097379324089390998,
                                  0,
                                  0.00476134522678781,
                                  0.12153841538699627,
                                  0.32068117066709401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24534096274872891,
                                  0.16993213439697469,
                                  -0.04015244934495335,
                                  0.16587077691873425,
                                  0,
                                  0,
                                  0.04268115248038136,
                                  -0.075087128443060092,
                                  -0.17087500853571819,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13603582678842141,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11159322338271151,
                                  0,
                                  0.087794857382099911,
                                  0,
                                  0,
                                  0.089695184758025154,
                                  -0.24935923627915296,
                                  0,
                                  -0.09189505771044186,
                                  0,
                                  -0.019875474758228245,
                                  0.33491804166585765,
                                  0,
                                  0,
                                  0,
                                  0.10173562744516629,
                                  -0.40519025228266736,
                                  -0.13540424826159606,
                                  -0.13314251746339228,
                                  0,
                                  0.075988649841795181,
                                  0,
                                  0.13292127896691838,
                                  0.077180655452255581,
                                  -0.40515472444661427,
                                  0,
                                  0,
                                  -0.096469497765075574,
                                  -0.12028635895197434,
                                  -0.22612850243926258,
                                  -0.20618871372095632,
                                  -0.0015018640978195605,
                                  -0.19692941325045515,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13493312686809489,
                                  0,
                                  0,
                                  0,
                                  -0.040145753320091168,
                                  0,
                                  0.061672069309679167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20271875884068055,
                                  0,
                                  0,
                                  0,
                                  0.082933233514379784,
                                  0,
                                  0,
                                  -0.025639189291184014,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015058347455238621,
                                  0,
                                  0.087950712589780933,
                                  0,
                                  -0.081591389714284951,
                                  -0.030583162347557511,
                                  -0.080983580699453953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01521562271022359,
                                  0.036458745849186867,
                                  -0.078641491090119198,
                                  -0.26642669022564686,
                                  0,
                                  0,
                                  0.15988555655757974,
                                  0.088331566232703149,
                                  0.268530099140464,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044539513492512318,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20990086998716215,
                                  0,
                                  -0.19327252635968162,
                                  0,
                                  0,
                                  -0.031453036794314479,
                                  0.034403214745387496,
                                  0,
                                  0.14598003000065507,
                                  0,
                                  0.11335497232311832,
                                  0.30807479111764841,
                                  0,
                                  0,
                                  0,
                                  0.081501592184632904,
                                  -0.18389034042654281,
                                  -0.11895482218622487,
                                  -0.13887739374696506,
                                  0,
                                  -0.056440852510289075,
                                  0,
                                  0.067447131832245225,
                                  0.018048793704519204,
                                  0.16368032310978323,
                                  0,
                                  0,
                                  -0.27234329723421435,
                                  0.020941532068441168,
                                  0.056882487567238023,
                                  -0.053133024920496673,
                                  -0.055525382190308489,
                                  -0.17649995424018969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14416211919486677,
                                  0,
                                  0,
                                  0,
                                  0.25225182417072844,
                                  0,
                                  0.1281312276301608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14597027334348467,
                                  0,
                                  0,
                                  0,
                                  0.074727230608281833,
                                  0,
                                  0,
                                  0.017584080624758528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.093170366137786828,
                                  0,
                                  -0.021271339100909448,
                                  0,
                                  0.11500558563515008,
                                  -0.18955446459919756,
                                  0.088464792098321116,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13999436493921549,
                                  -0.30953421826251054,
                                  -0.18629994743292472,
                                  0.33461985511913328,
                                  0,
                                  0.13746387114161759,
                                  0,
                                  0,
                                  0,
                                  -0.10728198062740617,
                                  -0.20870413700999088,
                                  -0.034538118012252643,
                                  -0.13217011896230083,
                                  0,
                                  0,
                                  0,
                                  -0.15773341601245372,
                                  0.26732256634290641,
                                  -0.20891140749913945,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10339452815321545,
                                  0,
                                  0.0273666594905164,
                                  0,
                                  0,
                                  0.2653338644566548,
                                  -0.059735406810427279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23174808065095689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0095512823911262073,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32563728220778615,
                                  0,
                                  0,
                                  0.032502590007181247,
                                  0,
                                  0.30137556658904863,
                                  0,
                                  -0.071796907602910354,
                                  -0.088001325738669603,
                                  0,
                                  0,
                                  0,
                                  0.021541905811352423,
                                  0,
                                  -0.25720225988521606,
                                  0,
                                  -0.0086097335008039344,
                                  0,
                                  0,
                                  0,
                                  -0.10283311415477352,
                                  0,
                                  0,
                                  0,
                                  -0.10320532525772762,
                                  0,
                                  -0.024650285445579536,
                                  0.12636376355629658,
                                  0,
                                  0,
                                  0,
                                  0.16620725526033833,
                                  0,
                                  0,
                                  0,
                                  0.52076671158174093,
                                  -0.10989005415324701,
                                  0,
                                  0,
                                  0.044363808644368362,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29544778678414357,
                                  0.16961085982411797,
                                  0.13537914735123099,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37417170801568078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14677476313350898,
                                  0,
                                  0.21093231135301155,
                                  0,
                                  0,
                                  -0.1237015483331641,
                                  -0.034289640275687136,
                                  0,
                                  0.21782138232118442,
                                  0,
                                  0.020265801735055586,
                                  -0.052697280474379993,
                                  0,
                                  0,
                                  0,
                                  -0.023382997073797922,
                                  0.10937385175037602,
                                  -0.059818038729617384,
                                  -0.16471267275613821,
                                  0,
                                  -0.033737549535918045,
                                  0,
                                  -0.070819470205256183,
                                  -0.11297154483395705,
                                  -0.18422374929602472,
                                  0,
                                  0,
                                  0.073455122932434377,
                                  0.14755763679326592,
                                  -0.15742636472037622,
                                  0.016594609985290148,
                                  -0.18764653280356997,
                                  0.18964457859852341,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11856218456114778,
                                  0,
                                  0,
                                  0,
                                  -0.12732236275805434,
                                  0,
                                  -0.043787517538383787,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.011364267109977629,
                                  0,
                                  0,
                                  0,
                                  -0.21851934651023058,
                                  0,
                                  0,
                                  -0.019354663414959686,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20242253964072621,
                                  0,
                                  -0.26205629246560852,
                                  0,
                                  0.13013248921680617,
                                  0.20924674592917281,
                                  0.1334759716130979,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20774274333549059,
                                  -0.093088196343953711,
                                  -0.22215402810725945,
                                  -0.056481650332645877,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25180351296111381,
                                  -0.1117828723552326,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064845957595407483,
                                  0,
                                  0.13487649357999687,
                                  0,
                                  -0.16102575848078909,
                                  -0.098361960337182364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22570112319453434,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32351445994480726,
                                  0,
                                  0,
                                  0,
                                  -0.14565458604042961,
                                  -0.15395996609263593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078472854970201344,
                                  -0.24686398153911612,
                                  0,
                                  0.069415496028187376,
                                  -0.27917682644436648,
                                  0,
                                  -0.11369092232869125,
                                  0,
                                  0.14850856343735702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070547340114964802,
                                  0,
                                  0,
                                  -0.096374409621836854,
                                  -0.48939651474794821,
                                  0.2160032942654907,
                                  0,
                                  -0.042492034762522869,
                                  0,
                                  0,
                                  0,
                                  -0.1120215329125076,
                                  0.072775483050344134,
                                  0,
                                  0,
                                  -0.033528210688551593,
                                  0,
                                  0.28296100778884153,
                                  0,
                                  -0.062384697996756819,
                                  0,
                                  0,
                                  0,
                                  -0.25303325097745216,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.023679048299022017,
                                  0.10466781269878087,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0056368890164526335,
                                  0,
                                  -0.17147145109739634,
                                  -0.097193443356358641,
                                  0.20039494912458095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17748174149045051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11630748390034534,
                                  0,
                                  -0.15393762282054119,
                                  0,
                                  0,
                                  0.16238725322276559,
                                  -0.025498857729061436,
                                  0,
                                  -0.18104166982448938,
                                  0,
                                  0.10448453169237606,
                                  -0.12468981185617098,
                                  0,
                                  0,
                                  0,
                                  0.096958049379629846,
                                  0.0042151477450852667,
                                  -0.23027615612910296,
                                  0.093757939472673066,
                                  0,
                                  0.078742895740995189,
                                  0,
                                  -0.18117764634514152,
                                  -0.16545624174071968,
                                  0.015355359043581561,
                                  0,
                                  0,
                                  0.14399944220339558,
                                  -0.3463020311923844,
                                  -0.23001481646210273,
                                  -0.0030545764858943567,
                                  0.15832769662444068,
                                  -0.011157801661900973,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.065135630312208814,
                                  0,
                                  0,
                                  0,
                                  -0.051917624842917398,
                                  0,
                                  -0.18400646526392633,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12570081805060809,
                                  0,
                                  0,
                                  0,
                                  0.19150612188571078,
                                  0,
                                  0,
                                  0.092358495140332092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34863381465780019,
                                  0,
                                  0.042166544723928806,
                                  0,
                                  0.0061323244951727255,
                                  -0.04485221841821347,
                                  0.003735526942476048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.03901506141072094,
                                  0.17069003822088552,
                                  -0.3260246500268737,
                                  0.21266756887178151,
                                  0,
                                  0,
                                  0.16333887769035355,
                                  -0.072188958321654326,
                                  -0.29101228552895664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25802081473552768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10352648125255894,
                                  0,
                                  -0.068400138418112461,
                                  0,
                                  0,
                                  -0.47093836405371586,
                                  -0.13859480264327009,
                                  0,
                                  -0.51026219113052129,
                                  0,
                                  0.053236497272340477,
                                  0.025280519448462893,
                                  0,
                                  0,
                                  0,
                                  -0.070106686381965308,
                                  0.079899409773730209,
                                  0.24324819949646082,
                                  -0.1092590040631725,
                                  0,
                                  -0.069396177070860904,
                                  0,
                                  -0.10416593421077688,
                                  -0.072005645690239234,
                                  -0.10038070595615504,
                                  0,
                                  0,
                                  -0.12824060006703131,
                                  0.045633328519277955,
                                  -0.052354996403821741,
                                  -0.0010374754690649084,
                                  0.025351590918337275,
                                  0.011250117915327852,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16021306231697069,
                                  0,
                                  0,
                                  0,
                                  -0.016039111371830728,
                                  0,
                                  0.035191004972519674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18871153868491053,
                                  0,
                                  0,
                                  0,
                                  0.051117062314142703,
                                  0,
                                  0,
                                  0.11887497769208308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12693353629965984,
                                  0,
                                  -0.041723100666875991,
                                  0,
                                  0.078423049422713192,
                                  -0.12699454835816823,
                                  0.010307437345761956,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.041572945473247698,
                                  0.052633305217255025,
                                  -0.067721707829073857,
                                  0.18000792610875593,
                                  0,
                                  0,
                                  -0.201386584798705,
                                  -0.30192157506711775,
                                  0.13043663666501976,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051470281777249216,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19903089784096517,
                                  0,
                                  0.0169084250316201,
                                  0,
                                  0,
                                  -0.19154222787695444,
                                  0.10781978632018202,
                                  0,
                                  -0.065292463344679988,
                                  0,
                                  -0.074280709443963477,
                                  -0.14314590745852954,
                                  0,
                                  0,
                                  0,
                                  0.14927670513171207,
                                  -0.12578412830889496,
                                  -0.12701117596497571,
                                  -0.26318183431186476,
                                  0,
                                  -0.18915146570316935,
                                  0,
                                  0.035648965162357459,
                                  -0.073546776292593791,
                                  0.054731299186773677,
                                  0,
                                  0,
                                  0.25134187969478128,
                                  0.28430582975051588,
                                  -0.04741884760817644,
                                  0.0048177122903215099,
                                  -0.12883749796108657,
                                  -0.15795043381772189,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11657330793076029,
                                  0,
                                  0,
                                  0,
                                  0.15275962104114921,
                                  0,
                                  -0.037224736338934049,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24576439905031261,
                                  0,
                                  0,
                                  0,
                                  -0.088826137130888605,
                                  0,
                                  0,
                                  0.12444904062445317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13755170361887892,
                                  0,
                                  -0.052128888292926487,
                                  0,
                                  0.24159207000538271,
                                  -0.32980315515201281,
                                  0.11930678822373611,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15762330690166299,
                                  -0.062841493923348452,
                                  -0.084297518522522777,
                                  -0.11119845320461411,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15371992565644224,
                                  -0.5476709913135458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092853217956896023,
                                  0,
                                  -0.12025841359168836,
                                  0,
                                  0.030404432609446811,
                                  0.0910946022670064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31854228718542299,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19410630767799067,
                                  0,
                                  0,
                                  0,
                                  0.016649669048164294,
                                  -0.17349512292857536,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.074245450883601863,
                                  0.16289707322271393,
                                  0,
                                  0.072148223800593464,
                                  -0.055631982092302378,
                                  0,
                                  -0.19290583628528346,
                                  0,
                                  -0.2081667202537052,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19893410398466868,
                                  0,
                                  0,
                                  -0.12014637815298718,
                                  -0.24973760354586583,
                                  0.033136479142117391,
                                  0,
                                  -0.09118083822858912,
                                  0,
                                  0,
                                  0,
                                  -0.057551972959801821,
                                  -0.11402189421094837,
                                  0,
                                  0,
                                  0.11291539597387169,
                                  0,
                                  0.0087647578874546495,
                                  0,
                                  -0.030183712909593437,
                                  0,
                                  0,
                                  0,
                                  0.33708894855620242,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28244557469678983,
                                  0.039180507694252013,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054041526183387006,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.050954193349744076,
                                  0.044757075548138507,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24564812810190639,
                                  0,
                                  -0.083910553910047592,
                                  0,
                                  -0.025411799273335055,
                                  0.10313585538755354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27793252853981482,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23625013102979409,
                                  0,
                                  0,
                                  0,
                                  0.037599248714756547,
                                  0.049392522438382838,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11861200938040303,
                                  -0.16000641068673305,
                                  0,
                                  -0.0092828793623985946,
                                  -0.13475648426677594,
                                  0,
                                  -0.041247777690035438,
                                  0,
                                  -0.061041153545898383,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10275104858316308,
                                  0,
                                  0,
                                  -0.3863107786590097,
                                  0.31357053283849917,
                                  0.11340240299673798,
                                  0,
                                  -0.34079811004701832,
                                  0,
                                  0,
                                  0,
                                  -0.24739104573091569,
                                  0.0059777237098431382,
                                  0,
                                  0,
                                  -0.034711647553696774,
                                  0,
                                  0.02690068390137438,
                                  0,
                                  0.16651644041025276,
                                  0,
                                  0,
                                  0,
                                  0.44219861018243461,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17187044452570049,
                                  -0.11505841343490049,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.011852401443866204,
                                  0,
                                  -0.10589010327337411,
                                  -0.10353678795083543,
                                  -0.010916322490424913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.096479671867196387,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16633291535154068,
                                  0,
                                  -0.15147528836877114,
                                  0,
                                  0,
                                  -0.11150607153682937,
                                  -0.092674125976211497,
                                  0,
                                  -0.015704967212681678,
                                  0,
                                  0.29021190808137454,
                                  -0.067101189186739962,
                                  0,
                                  0,
                                  0,
                                  -0.19577605442437107,
                                  -0.019806803556074445,
                                  0.16119699325559947,
                                  0.042481123823343493,
                                  0,
                                  0.2145866958789262,
                                  0,
                                  0.024388911191724268,
                                  0.10428359393947145,
                                  -0.12571843671977712,
                                  0,
                                  0,
                                  0.088331644587033034,
                                  0.16876117020267073,
                                  0.35664525241598716,
                                  0.019924098706707742,
                                  -0.14801904679204791,
                                  -0.089658675454008255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25459303457744553,
                                  0,
                                  0,
                                  0,
                                  0.18546448799354814,
                                  0,
                                  -0.38131087950460552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.012178374754232744,
                                  0,
                                  0,
                                  0,
                                  -0.0082950186232307703,
                                  0,
                                  0,
                                  -0.24054468542868954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12950624981798828,
                                  0,
                                  0.10180280670905884,
                                  0,
                                  -0.10998172032970978,
                                  -0.053639661020875133,
                                  -0.29028087178905088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.076246338585384904,
                                  -0.13500562969262839,
                                  -0.14407901912032706,
                                  0.022715348607090749,
                                  0,
                                  0,
                                  -0.035650232347175584,
                                  -0.090153511257858004,
                                  0.15729808715338645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095452953794757892,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16411500475451346,
                                  0,
                                  0.013818693832474634,
                                  0,
                                  0,
                                  0.12300582909753094,
                                  -0.15232989622915563,
                                  0,
                                  -0.059888870902481753,
                                  0,
                                  0.04458029228084831,
                                  0.32429407698111806,
                                  0,
                                  0,
                                  0,
                                  0.13979243628197532,
                                  0.032524150614466216,
                                  0.2016207984599678,
                                  0.012245105492836132,
                                  0,
                                  0.14030801647901184,
                                  0,
                                  -0.19273521834179569,
                                  -0.086046527908159184,
                                  -0.23297263671464338,
                                  0,
                                  0,
                                  0.20856789728137903,
                                  0.31178094306416682,
                                  -0.014720259496919942,
                                  0.23674516862849343,
                                  0.12316592155918449,
                                  0.059617416761800782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38700093638373345,
                                  0,
                                  0,
                                  0,
                                  0.20857938230062012,
                                  0,
                                  -0.050469929499127375,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12276379845856243,
                                  0,
                                  0,
                                  0,
                                  0.027449615696954241,
                                  0,
                                  0,
                                  0.089928627637002101,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13732408098734622,
                                  0,
                                  -0.21717521710135182,
                                  0,
                                  -0.13356912991166095,
                                  0.014841464893637996,
                                  0.073897446015375165,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.060260038666066641,
                                  0.067930964377757544,
                                  0.25944984333003601,
                                  0.0098667868982773906,
                                  0,
                                  0,
                                  0.073609604363419956,
                                  -0.042659116875827213,
                                  -0.16417360589876068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23068213746744307,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.024422284905855011,
                                  0,
                                  0.055473093572716903,
                                  0,
                                  0,
                                  0.090470825481328718,
                                  -0.17003160129119338,
                                  0,
                                  0.20257760312211165,
                                  0,
                                  -0.068269360302540522,
                                  0.032649811773905094,
                                  0,
                                  0,
                                  0,
                                  0.084760326984684997,
                                  0.027154745358260592,
                                  0.19945683807285788,
                                  -0.0077421157269144114,
                                  0,
                                  -0.044021091457239675,
                                  0,
                                  0.015755579410589398,
                                  -0.065253228463158536,
                                  0.12493871088578588,
                                  0,
                                  0,
                                  0.34750769493148403,
                                  -0.0086691621336061758,
                                  -0.12927409003909912,
                                  -0.05070411879534726,
                                  0.21671914998490727,
                                  0.2364665847896632,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0022303477087894513,
                                  0,
                                  0,
                                  0,
                                  0.047128887922118085,
                                  0,
                                  0.22094984942276422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14198332091293028,
                                  0,
                                  0,
                                  0,
                                  0.054230327020296731,
                                  0,
                                  0,
                                  -0.15378326052006713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.031053097817621864,
                                  0,
                                  0.2073769348110886,
                                  0,
                                  -0.0086009877469028911,
                                  -0.079522520643167879,
                                  -0.21892478442098062,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27175639364288207,
                                  -0.4253157010627639,
                                  -0.030822427198564303,
                                  0.24587492251542828,
                                  0,
                                  0,
                                  -0.0085467731872568564,
                                  -0.10216664913913112,
                                  0.10138412921504431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022824548739855968,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072364627269104129,
                                  0,
                                  0.01226599370715074,
                                  0,
                                  0,
                                  -0.039344118685304644,
                                  0.0064257337056952551,
                                  0,
                                  0.088261445410594497,
                                  0,
                                  0.0036626571812842929,
                                  0.10313976596925731,
                                  0,
                                  0,
                                  0,
                                  0.14452065220402627,
                                  -0.24802257617326975,
                                  0.3897676247471431,
                                  -0.20549609089479531,
                                  0,
                                  -0.060768420799209653,
                                  0,
                                  -0.04665980068821865,
                                  0.19591624240660407,
                                  0.051040583224501626,
                                  0,
                                  0,
                                  -0.12510956244222057,
                                  -0.24949181922255742,
                                  0.14738913675931056,
                                  0.16048034350982049,
                                  0.071251883536113864,
                                  0.039387406472633446,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043523171008093955,
                                  0,
                                  0,
                                  0,
                                  -0.48148928924893691,
                                  0,
                                  -0.23706398812741683,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084498188129656537,
                                  0,
                                  0,
                                  0,
                                  -0.084313771017902953,
                                  0,
                                  0,
                                  0.12703148491893371,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.278655808824054,
                                  0,
                                  0.050333017694757426,
                                  0,
                                  -0.041630654487769272,
                                  -0.081183165873822072,
                                  0.17158432255016909,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015347997171639326,
                                  -0.20183619243214387,
                                  0.13648364561940882,
                                  -0.00048575189836062502,
                                  0,
                                  0,
                                  -0.038516245648169661,
                                  0.033570800151225579,
                                  0.089610342767696291,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054122080173030697,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094701614627627675,
                                  0,
                                  -0.15360734044326574,
                                  0,
                                  0,
                                  -0.32038423805339777,
                                  0.33423163024034586,
                                  0,
                                  0.019077735151670078,
                                  0,
                                  -0.083748563634119477,
                                  -0.060418150989187958,
                                  0,
                                  0,
                                  0,
                                  -0.029164110712554866,
                                  -0.028668354152103691,
                                  0.16858430759917012,
                                  -0.096142712317281637,
                                  0,
                                  0.098683081489423341,
                                  0,
                                  0.21078813820210884,
                                  -0.074320248406841039,
                                  0.046638569101930663,
                                  0,
                                  0,
                                  -0.22795603693371966,
                                  -0.21843657912284334,
                                  -0.30107680630302536,
                                  -0.028651930590187592,
                                  0.012868003105595993,
                                  0.085430686101637066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15264752580082405,
                                  0,
                                  0,
                                  0,
                                  0.33798369155051905,
                                  0,
                                  -0.14232186531989796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20467857331308709,
                                  0,
                                  0,
                                  0,
                                  0.038398550664750411,
                                  0,
                                  0,
                                  -0.0045774709671757233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19266746686628047,
                                  0,
                                  0.015691795480971476,
                                  0,
                                  -0.021959114482004702,
                                  0.2956691835761327,
                                  -0.13846377969310145,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14314207371470467,
                                  -0.097281595715495925,
                                  0.16579706914380191,
                                  -0.16001158286987763,
                                  0,
                                  0,
                                  0.10788594946270717,
                                  0.063703709993847432,
                                  -0.0035568578448171646,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -8.0724622246106104e-07,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0049472626069817262,
                                  0,
                                  0.070582276342569916,
                                  0,
                                  0,
                                  0.096265930783455481,
                                  0.031606528226965219,
                                  0,
                                  -0.23841660242267776,
                                  0,
                                  -0.31886638781093862,
                                  -0.028807338263606614,
                                  0,
                                  0,
                                  0,
                                  -0.26641423919117618,
                                  -0.32708710288226478,
                                  -0.072499710521529079,
                                  0.12932412209409971,
                                  0,
                                  0.075933010247872593,
                                  0,
                                  0.023119178582783478,
                                  0.073169794661615495,
                                  -0.027467125105481039,
                                  0,
                                  0,
                                  0.15737879593879134,
                                  -0.13922527274263025,
                                  0.1466170980505743,
                                  -0.044860286713943327,
                                  -0.062661088090360528,
                                  0.18122710935769729,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1660925473068858,
                                  0,
                                  0,
                                  0,
                                  0.27336118847326052,
                                  0,
                                  0.020233420190205208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2779775971450773,
                                  0,
                                  0,
                                  0,
                                  -0.35537284605233505,
                                  0,
                                  0,
                                  -0.11934442757803661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14922461988401778,
                                  0,
                                  -0.026864426802566579,
                                  0,
                                  -0.12983678083594244,
                                  -0.12555612398838356,
                                  0.24204224688526785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1626705574775161,
                                  -0.11784995052077404,
                                  -0.074485746097810432,
                                  -0.11074878417604768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064654163954543875,
                                  0.034588800601968145,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021586364110082051,
                                  0,
                                  -0.4143146100058549,
                                  0,
                                  -0.008866071136306778,
                                  0.10375588656668167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086025778254165131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11595918339176764,
                                  0,
                                  0,
                                  0,
                                  0.14065443353185203,
                                  -0.18435271421776134,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37088569362778506,
                                  -0.13845700524258983,
                                  0,
                                  -0.18789294107426963,
                                  0.06738022740300019,
                                  0,
                                  0.039219703081378933,
                                  0,
                                  0.22235445999537662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10837103607930787,
                                  0,
                                  0,
                                  0.18613489321538054,
                                  0.06919020494533723,
                                  0.23327870589818611,
                                  0,
                                  0.35130237577969159,
                                  0,
                                  0,
                                  0,
                                  0.11558002499898029,
                                  -0.19107150524216612,
                                  0,
                                  0,
                                  0.17938183476358394,
                                  0,
                                  0.18424244504492068,
                                  0,
                                  -0.17793690317630906,
                                  0,
                                  0,
                                  0,
                                  0.27916917307416572,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14700860106098865,
                                  0.060350915081014485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098180244191491267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086407022433598324,
                                  -0.087151810776793515,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026764865374590087,
                                  0,
                                  -0.024966075546553501,
                                  0,
                                  0.1410309735571684,
                                  -0.0012993621473002884,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25112976645383545,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11757138809744634,
                                  0,
                                  0,
                                  0,
                                  0.069469185118209181,
                                  0.1305443553460649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036806507005666927,
                                  -0.051603675690243531,
                                  0,
                                  -0.15567991789817665,
                                  -0.017897627156850962,
                                  0,
                                  0.49911170504632346,
                                  0,
                                  0.20032310810422022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043034765624573201,
                                  0,
                                  0,
                                  0.10481373010348773,
                                  0.023420443822265234,
                                  0.21933881812172826,
                                  0,
                                  -0.24294654559842685,
                                  0,
                                  0,
                                  0,
                                  -0.14970744941536071,
                                  -0.20924547763933904,
                                  0,
                                  0,
                                  -0.025521577451492666,
                                  0,
                                  0.24843572961193036,
                                  0,
                                  0.16365255343461413,
                                  0,
                                  0,
                                  0,
                                  -0.14575777179441113,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26426773387702551,
                                  -0.26909958107451915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32828055978233012,
                                  -0.041834463524152356,
                                  0,
                                  0,
                                  0,
                                  -0.26968362129322426,
                                  -0.234985151679525,
                                  0.13385980522176316,
                                  -0.073046858857501534,
                                  0,
                                  0,
                                  0,
                                  0.21219377125723682,
                                  0.014392419748435142,
                                  -0.24388875914917793,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040707729073715858,
                                  0,
                                  -0.26447923035721521,
                                  0,
                                  0,
                                  0.18146311562376727,
                                  0.0069524735681113312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07105567152511609,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084149366674883458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092878477896591774,
                                  0,
                                  0,
                                  0.044409222110154786,
                                  0,
                                  -0.069480975029041797,
                                  0,
                                  0.20893200505762774,
                                  0.05876821358362487,
                                  0,
                                  0,
                                  0,
                                  0.041123327595565265,
                                  0,
                                  -0.042904535888965006,
                                  0,
                                  0.019863231119663705,
                                  0,
                                  0,
                                  0,
                                  -0.39428634026862613,
                                  0,
                                  0,
                                  0,
                                  0.014252752228763623,
                                  0,
                                  0.28906668989983936,
                                  0.27484385590754512,
                                  0,
                                  0,
                                  0,
                                  -0.37913424216532771,
                                  0,
                                  0,
                                  0,
                                  -0.14004500825797667,
                                  -0.1050449131378496,
                                  0,
                                  0,
                                  -0.26458895240644376,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070230202632426561,
                                  -0.006232510896153458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25960271005490082,
                                  0,
                                  -0.09139674175446541,
                                  0,
                                  -0.22099189568997649,
                                  -0.18841678607047985,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044815102413608296,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.091271025174669743,
                                  0,
                                  0,
                                  0,
                                  -0.10230717236900758,
                                  0.228723343264846,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2118884699614271,
                                  -0.32201948089824584,
                                  0,
                                  0.071821903012552576,
                                  0.44428570606651474,
                                  0,
                                  0.17584260445413302,
                                  0,
                                  0.12955192636782978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14641960430452494,
                                  0,
                                  0,
                                  0.092814171778294263,
                                  -0.14829113056179111,
                                  0.078511500007771184,
                                  0,
                                  -0.13288605848073506,
                                  0,
                                  0,
                                  0,
                                  -0.21067525229029135,
                                  0.094668445308918797,
                                  0,
                                  0,
                                  0.22325479934155629,
                                  0,
                                  -0.14147361427633703,
                                  0,
                                  -0.13826220395532415,
                                  0,
                                  0,
                                  0,
                                  0.056467481903147106,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.096323288544563124,
                                  0.35159367504007766,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.093310213271794687,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021887873346926285,
                                  0.10140526670780109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16610256244905949,
                                  0,
                                  0.11265702469521525,
                                  0,
                                  -0.00084101047200009146,
                                  -0.061869552688082086,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046949073912426226,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15685175778372784,
                                  0,
                                  0,
                                  0,
                                  -0.067754964077301652,
                                  -0.054347096817391846,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54099822885610493,
                                  0.020212512859632756,
                                  0,
                                  0.28549240555751831,
                                  -0.13996306882938636,
                                  0,
                                  0.12610875851845441,
                                  0,
                                  0.07594159925567695,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.008848565651973582,
                                  0,
                                  0,
                                  0.35169217314725759,
                                  0.00075529528196837704,
                                  -0.23272753601628443,
                                  0,
                                  -0.37008377498313311,
                                  0,
                                  0,
                                  0,
                                  -0.039598934069768776,
                                  0.21271272940956953,
                                  0,
                                  0,
                                  -0.18167810439130139,
                                  0,
                                  0.12648649040351087,
                                  0,
                                  0.0089696932586448563,
                                  0,
                                  0,
                                  0,
                                  0.2105457801678676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14375240855287649,
                                  0.13586906809739727,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.026016378269884476,
                                  0,
                                  0.079028325635387586,
                                  -0.0083263300269386734,
                                  0.17843304907594154,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014040306190443035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42530971335473988,
                                  0,
                                  0.095592868782242546,
                                  0,
                                  0,
                                  -0.12021339113124517,
                                  0.1018253606842377,
                                  0,
                                  -0.2061223965967012,
                                  0,
                                  -0.17531712829672921,
                                  0.028686253688692993,
                                  0,
                                  0,
                                  0,
                                  0.02073500529563934,
                                  -0.04245012439621159,
                                  -0.038304237888490175,
                                  -0.17044890424885187,
                                  0,
                                  0.19966670784650095,
                                  0,
                                  -0.036933033905242593,
                                  -0.020392185379712987,
                                  0.18840727985128228,
                                  0,
                                  0,
                                  0.30797467343386681,
                                  0.048548270449627492,
                                  0.15525031185967064,
                                  -0.20994145796584565,
                                  -0.065844625422279396,
                                  0.11310194663111257,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16622419373186187,
                                  0,
                                  0,
                                  0,
                                  -0.14608529567780321,
                                  0,
                                  0.066746886658908738,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20978706113952258,
                                  0,
                                  0,
                                  0,
                                  0.39156182729024636,
                                  0,
                                  0,
                                  0.15217332848826726,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11920883996288688,
                                  0,
                                  0.041840402544818564,
                                  0,
                                  0.087883874964942585,
                                  0.063331378309458369,
                                  -0.057886655228954038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036634382692285687,
                                  -0.04568726885162195,
                                  0.20920635451858466,
                                  -0.16790886848602268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26960156544207409,
                                  -0.23878236202649475,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053103070152374726,
                                  0,
                                  -0.30794077341613768,
                                  0,
                                  -0.052815347093759291,
                                  0.15164092145111466,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12337861186517882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063946982134671898,
                                  0,
                                  0,
                                  0,
                                  0.12132135387140799,
                                  0.16528452656113052,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15968949262538989,
                                  0.15892675526142985,
                                  0,
                                  0.024623496195251521,
                                  -0.095533694677127981,
                                  0,
                                  -0.12811910572020879,
                                  0,
                                  0.11398545233874269,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11744192506645186,
                                  0,
                                  0,
                                  -0.036809377019832286,
                                  0.022458131882947898,
                                  0.092635645895178781,
                                  0,
                                  -0.056050278428885353,
                                  0,
                                  0,
                                  0,
                                  -0.29821037611052048,
                                  -0.11937074094134477,
                                  0,
                                  0,
                                  -0.37829010029396254,
                                  0,
                                  -0.34675741060433396,
                                  0,
                                  -0.078973027632352949,
                                  0,
                                  0,
                                  0,
                                  -0.24320128149969064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.041402013975499211,
                                  0.33069591604397247,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15894271802032428,
                                  -0.15284563302051729,
                                  0,
                                  0,
                                  0,
                                  0.15293974734912152,
                                  -0.17592186466722684,
                                  0.37579667100518571,
                                  0.26003389004274952,
                                  0,
                                  0,
                                  0,
                                  -0.15717720814757649,
                                  -0.045489451486226531,
                                  -0.17588831704487942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26053758946522099,
                                  0,
                                  -0.081427033089969583,
                                  0,
                                  0,
                                  -0.045660363134315908,
                                  -0.022670543135938914,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33192847207880316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097873373946800749,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092761379172798031,
                                  0,
                                  0,
                                  -0.19379526669879962,
                                  0,
                                  0.18200882868140361,
                                  0,
                                  0.26789869568697239,
                                  -0.14131331543328679,
                                  0,
                                  0,
                                  0,
                                  -0.18499117906234921,
                                  0,
                                  0.23414474974014221,
                                  0,
                                  0.019136753635507979,
                                  0,
                                  0,
                                  0,
                                  0.080372734155219977,
                                  0,
                                  0,
                                  0,
                                  -0.077938526072072134,
                                  0,
                                  0.059613057641625854,
                                  -0.17350003078311638,
                                  0,
                                  0,
                                  0,
                                  0.091016548335205588,
                                  0,
                                  0,
                                  0,
                                  0.34154545397154773,
                                  -0.046189456452131274,
                                  0,
                                  0,
                                  -0.1586904984671435,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.165049425049242,
                                  -0.28975328063407146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0020824166241446918,
                                  0,
                                  0.22061409910375446,
                                  0,
                                  -0.25982119487850941,
                                  -0.10836488758057905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24840307582580948,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037748769007300752,
                                  0,
                                  0,
                                  0,
                                  0.35971444302887029,
                                  -0.1153872400674547,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23114668652627782,
                                  0.14758858389161031,
                                  0,
                                  0.19778093169546004,
                                  -0.079544331173324698,
                                  0,
                                  0.010822771517602185,
                                  0,
                                  0.063591266760348125,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14019976053203329,
                                  0,
                                  0,
                                  0.29772631341415273,
                                  0.18559145201929508,
                                  0.027435031440607469,
                                  0,
                                  0.19319728901702662,
                                  0,
                                  0,
                                  0,
                                  -0.1750839809336531,
                                  0.0019386584530583721,
                                  0,
                                  0,
                                  0.14079328106999972,
                                  0,
                                  0.25656201663880013,
                                  0,
                                  0.31469837671594136,
                                  0,
                                  0,
                                  0,
                                  0.07919100040096716,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.089476756840367211,
                                  0.13218341721564286,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.048098816711548587,
                                  0,
                                  -0.068808055907669113,
                                  0.1830481068225788,
                                  -0.11080340624921345,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32174681393814597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23656576635645418,
                                  0,
                                  0.030115452855143807,
                                  0,
                                  0,
                                  -0.23553869089632276,
                                  -0.10497454426689146,
                                  0,
                                  0.0059793008975168645,
                                  0,
                                  -0.097513254391156351,
                                  0.061915289762849719,
                                  0,
                                  0,
                                  0,
                                  0.17877363305428304,
                                  -0.19731826598101093,
                                  0.15102945540426041,
                                  0.086604550509239139,
                                  0,
                                  -0.22502726479845764,
                                  0,
                                  0.13397951009811504,
                                  -0.10597783144624595,
                                  0.18918892889602246,
                                  0,
                                  0,
                                  0.21494536314133331,
                                  0.043315607075446586,
                                  0.021425446307139225,
                                  -0.16723192587495916,
                                  -0.13481544943534224,
                                  -0.027544359143117526,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27545502749979023,
                                  0,
                                  0,
                                  0,
                                  -0.20387294714708129,
                                  0,
                                  -0.10464652331255482,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097397278831684669,
                                  0,
                                  0,
                                  0,
                                  -0.17518502966764798,
                                  0,
                                  0,
                                  -0.11329729937610002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043020995082061315,
                                  0,
                                  0.015543475817440207,
                                  0,
                                  -0.0223770367360283,
                                  0.13177156532736342,
                                  -0.18502900457847854,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050100694420496347,
                                  0.24000229081974458,
                                  -0.30495529086732759,
                                  0.090862757144618042,
                                  0,
                                  0.060944217996653359,
                                  0,
                                  0,
                                  0,
                                  -0.11017890608694286,
                                  0.049454785892374079,
                                  -0.0064641815891069987,
                                  -0.27239529727273665,
                                  0,
                                  0,
                                  0,
                                  0.013768336114025077,
                                  -0.065879372644552792,
                                  -0.026929383988381794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2050262173568925,
                                  0,
                                  -0.14367730382130259,
                                  0,
                                  0,
                                  -0.18999357346537768,
                                  0.13292340301576069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21945622129757664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48851997195711994,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1448273375971475,
                                  0,
                                  0,
                                  0.055818730068663974,
                                  0,
                                  -0.031070446999306348,
                                  0,
                                  -0.11860028452901572,
                                  -0.28523634215802796,
                                  0,
                                  0,
                                  0,
                                  0.16456529554719923,
                                  0,
                                  0.016829686146879585,
                                  0,
                                  -0.06047019429710522,
                                  0,
                                  0,
                                  0,
                                  -0.02747159656393007,
                                  0,
                                  0,
                                  0,
                                  -0.39745620056740294,
                                  0,
                                  0.072123590899262027,
                                  -0.24867184085037622,
                                  0,
                                  0,
                                  0,
                                  0.15866779008483084,
                                  0,
                                  0,
                                  0,
                                  -0.095355618719671215,
                                  -0.29194824996891444,
                                  0,
                                  0,
                                  -0.046646122036840279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.045135201473231135,
                                  0.089228059569155915,
                                  -0.032359888891689711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20094658928980128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1690240421308947,
                                  0,
                                  0.14286408589748847,
                                  0,
                                  0,
                                  -0.084036177565887327,
                                  0.0051221064546963478,
                                  0,
                                  0.092974646402954345,
                                  0,
                                  -0.085370011493267034,
                                  0.34727487221227266,
                                  0,
                                  0,
                                  0,
                                  0.056642412735677078,
                                  0.27193218222631549,
                                  -0.079463373915518873,
                                  -0.0096352060201720553,
                                  0,
                                  -0.051145773183497029,
                                  0,
                                  0.16789327400005344,
                                  0.036407872086124407,
                                  0.17092977336572562,
                                  0,
                                  0,
                                  -0.061355145327937476,
                                  -0.030809395615568412,
                                  0.24404317270280323,
                                  0.21146011282014471,
                                  -0.20561016888458553,
                                  0.13834214803671516,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13798380514573388,
                                  0,
                                  0,
                                  0,
                                  0.068279488458487012,
                                  0,
                                  0.08068007986348566,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.023921361154318522,
                                  0,
                                  0,
                                  0,
                                  0.28376299997992077,
                                  0,
                                  0,
                                  0.072665121388237747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25314379750869898,
                                  0,
                                  0.14362280762368615,
                                  0,
                                  -0.1920250874003053,
                                  -0.18107601140553597,
                                  -0.064097680779797689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026114019076063009,
                                  0.14639729426330822,
                                  -0.24296505553947842,
                                  -0.29061027531068589,
                                  0,
                                  0.45765594438808072,
                                  0,
                                  0,
                                  0,
                                  0.064775586744267838,
                                  -0.066620205286196207,
                                  0.040910212251138334,
                                  -0.07092856149617309,
                                  0,
                                  0,
                                  0,
                                  -0.18870111636850528,
                                  0.2189361843604081,
                                  0.036325598702246879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097862997300455876,
                                  0,
                                  0.17104302290227538,
                                  0,
                                  0,
                                  0.041375049846521614,
                                  0.15060846813432435,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28559506763654191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13317007110652029,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0097717960748912661,
                                  0,
                                  0,
                                  -0.17418717409735668,
                                  0,
                                  0.14628295405929254,
                                  0,
                                  0.27530525209210627,
                                  0.11218661979146888,
                                  0,
                                  0,
                                  0,
                                  -0.14101841401010323,
                                  0,
                                  0.2823313206153909,
                                  0,
                                  0.089803574167852215,
                                  0,
                                  0,
                                  0,
                                  -0.12311822700625179,
                                  0,
                                  0,
                                  0,
                                  0.27350422873576408,
                                  0,
                                  0.1706158195498623,
                                  -0.19347171069111146,
                                  0,
                                  0,
                                  0,
                                  0.13852452018809852,
                                  0,
                                  0,
                                  0,
                                  -0.2738645915814239,
                                  0.068647252016281801,
                                  0,
                                  0,
                                  -0.15665929683811283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.006531937608662948,
                                  -0.075532266211533028,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25257492921501523,
                                  0,
                                  -0.10352304411438069,
                                  0,
                                  0.25222236290310129,
                                  0.15994565756011281,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39218743898659675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16257828128986959,
                                  0,
                                  0,
                                  0,
                                  -0.15123672248363493,
                                  0.058948962525585499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0099424515860616815,
                                  0.10153898133065539,
                                  0,
                                  0.14490614032095805,
                                  0.21441631800483479,
                                  0,
                                  0.01256555790536293,
                                  0,
                                  -0.13912940025039611,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1661830016731588,
                                  0,
                                  0,
                                  0.045324866543084971,
                                  0.17902077033936203,
                                  0.33855137956576498,
                                  0,
                                  -0.26327077589300946,
                                  0,
                                  0,
                                  0,
                                  0.25668701617892442,
                                  0.12919879961969621,
                                  0,
                                  0,
                                  -0.073273356428727399,
                                  0,
                                  0.23166482642774561,
                                  0,
                                  -0.0043486849633847975,
                                  0,
                                  0,
                                  0,
                                  -0.11080802418141875,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25076532726353057,
                                  0.14209653435204669,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21075545205546231,
                                  -0.12703473561473119,
                                  0,
                                  0,
                                  0,
                                  -0.22280940199110377,
                                  0.17437114278092472,
                                  -0.23415146630163375,
                                  0.14150175206833854,
                                  0,
                                  0,
                                  0,
                                  0.080764632011922452,
                                  0.054560227366581199,
                                  -0.016642594925499757,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088588984290703388,
                                  0,
                                  0.20931421416251056,
                                  0,
                                  0,
                                  -0.26878869771508535,
                                  0.16932905053826641,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18878473153215425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10802829755729101,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26656650777446222,
                                  0,
                                  0,
                                  -0.033941464245746129,
                                  0,
                                  0.22931300859504783,
                                  0,
                                  -0.11164989795860937,
                                  -0.29584524279323832,
                                  0,
                                  0,
                                  0,
                                  -0.027651058925957879,
                                  0,
                                  0.034922794419456782,
                                  0,
                                  0.22601665915892391,
                                  0,
                                  0,
                                  0,
                                  0.092278404525185126,
                                  0,
                                  0,
                                  0,
                                  0.31148725513319925,
                                  0,
                                  0.35086800047448297,
                                  -0.025379300107345328,
                                  0,
                                  0,
                                  0,
                                  -0.2008063631010906,
                                  0,
                                  0,
                                  0,
                                  0.046183139524692052,
                                  -0.26281867840278444,
                                  0,
                                  0,
                                  0.024954630315272508,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25261142803924908,
                                  0,
                                  0,
                                  0,
                                  0.052081169552203203,
                                  0.4691741145488994,
                                  -0.016206527904720453,
                                  0.27736843702299241,
                                  0,
                                  0,
                                  0,
                                  -0.14051108795320866,
                                  0.23463388423337889,
                                  -0.18339393317854835,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1916156488891467,
                                  0,
                                  -0.14771977995595309,
                                  0,
                                  0,
                                  -0.008431737663499592,
                                  -0.13253206897352204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.081539755237465789,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23980455958080668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.03469466172283301,
                                  0,
                                  0,
                                  0.12840862383904927,
                                  0,
                                  -0.3275644483190665,
                                  0,
                                  0.18999982511565958,
                                  -0.19898150049949923,
                                  0,
                                  0,
                                  0,
                                  -0.035256001606189656,
                                  0,
                                  -0.11824913497396834,
                                  0,
                                  -0.15914681875706191,
                                  0,
                                  0,
                                  0,
                                  -0.092717805020612595,
                                  0,
                                  0,
                                  0,
                                  0.1240101586866853,
                                  0,
                                  -0.009555549710633356,
                                  0.01388768939918736,
                                  0,
                                  0,
                                  0,
                                  0.017089658232084345,
                                  0,
                                  0,
                                  0,
                                  0.032032176311080643,
                                  -0.34456422257301139,
                                  0,
                                  0,
                                  -0.04308735858704902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.091269199235290532,
                                  0.08875618498494986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.074002031113761121,
                                  0,
                                  0.26342707924339265,
                                  0,
                                  0.26114653133652244,
                                  0.1903674230088053,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040664366139382215,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.052165459867883665,
                                  0,
                                  0,
                                  0,
                                  0.29175496940206119,
                                  -0.26180046256503725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039816772542567075,
                                  -0.18388755506980337,
                                  0,
                                  0.18936753627345199,
                                  0.03846246913910821,
                                  0,
                                  0.078622128195370858,
                                  0,
                                  -0.13309814138187942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15773441245134207,
                                  0,
                                  0,
                                  0.1836225730259346,
                                  -0.10667984941445602,
                                  0.3302802442154642,
                                  0,
                                  -0.076749814274868045,
                                  0,
                                  0,
                                  0,
                                  -0.1534792952235251,
                                  -0.15363855603216009,
                                  0,
                                  0,
                                  0.11597538875762217,
                                  0,
                                  -0.44716463955475172,
                                  0,
                                  0.14730031347955591,
                                  0,
                                  0,
                                  0,
                                  -0.096690872370242778,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23573811023627933,
                                  -0.038262581322889518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.127317982999584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29825911356212303,
                                  -0.015296764179993006,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.080349242345912092,
                                  0,
                                  -0.12052797300713967,
                                  0,
                                  0.10771970187991776,
                                  0.0022345558428079129,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039326734938832666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51734404051950855,
                                  0,
                                  0,
                                  0,
                                  0.070775747112256635,
                                  -0.08185531983106463,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025567817833479264,
                                  -0.30195275742824418,
                                  0,
                                  -0.2807879790665882,
                                  0.077465858945473476,
                                  0,
                                  -0.10242335686034038,
                                  0,
                                  0.071926570869189632,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46363306673997645,
                                  0,
                                  0,
                                  -0.041460301808697558,
                                  -0.01928699319219835,
                                  0.14225959922433359,
                                  0,
                                  0.028061128439935676,
                                  0,
                                  0,
                                  0,
                                  -0.15185447462031965,
                                  0.089191376147323989,
                                  0,
                                  0,
                                  -0.25714915645665776,
                                  0,
                                  0.15319195192551222,
                                  0,
                                  0.19922618095101285,
                                  0,
                                  0,
                                  0,
                                  -0.018516430881415687,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047951325536143903,
                                  0.028513443285272316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056148280364757198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032897188850778629,
                                  -0.039292164897634776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2165152370095601,
                                  0,
                                  -0.21792617223743457,
                                  0,
                                  -0.21084284405929141,
                                  0.21516332851210535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24401847699101159,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064470579772921796,
                                  0,
                                  0,
                                  0,
                                  0.22093520185039897,
                                  0.15259178494831943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0075642503899880425,
                                  -0.169235787487413,
                                  0,
                                  -0.27409628683712106,
                                  -0.066420741984385551,
                                  0,
                                  -0.14685615323077891,
                                  0,
                                  0.03821594759418824,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033900956732454343,
                                  0,
                                  0,
                                  0.23213328104502001,
                                  -0.27057693552743567,
                                  -0.31846855524016227,
                                  0,
                                  -0.34014927147870533,
                                  0,
                                  0,
                                  0,
                                  0.15060499155110213,
                                  0.06341788555945381,
                                  0,
                                  0,
                                  0.24308740974733498,
                                  0,
                                  -0.14294537852898878,
                                  0,
                                  0.19925580497104931,
                                  0,
                                  0,
                                  0,
                                  -0.013548968258630948,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064466771353282007,
                                  -0.22154930880365065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021533775371586766,
                                  -0.029827975239206463,
                                  0,
                                  0,
                                  0,
                                  0.16934905556554139,
                                  -0.066841393893164458,
                                  0.0013679485823851021,
                                  0.082741499970050258,
                                  0,
                                  0,
                                  0,
                                  0.44713657639606619,
                                  0.039982891011396376,
                                  -0.23923935761972012,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082362522340831565,
                                  0,
                                  -0.2232468854312698,
                                  0,
                                  0,
                                  0.032702062911713028,
                                  -0.096295876729684107,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.016782052762531446,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.061996444875376304,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.090413499198819955,
                                  0,
                                  0,
                                  0.16157162434083611,
                                  0,
                                  0.20363570427952699,
                                  0,
                                  -0.038874684185373889,
                                  -0.34991560718330489,
                                  0,
                                  0,
                                  0,
                                  0.27334175918080406,
                                  0,
                                  0.20769549145022692,
                                  0,
                                  0.079365673913607965,
                                  0,
                                  0,
                                  0,
                                  -0.048804361817244714,
                                  0,
                                  0,
                                  0,
                                  0.25273802224187847,
                                  0,
                                  -0.25857355837697554,
                                  -0.012857459996696812,
                                  0,
                                  0,
                                  0,
                                  0.33780627834541055,
                                  0,
                                  0,
                                  0,
                                  -0.18257864757071673,
                                  0.11137502437421333,
                                  0,
                                  0,
                                  -0.11077804115550632,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33533178980291428,
                                  0.018506946723593681,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0025406304149484527,
                                  0,
                                  -0.31211183214161919,
                                  0,
                                  0.093414034615459746,
                                  0.065870166445948772,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12614124550730732,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10606701396571794,
                                  0,
                                  0,
                                  0,
                                  -0.021714147266966213,
                                  -0.39057870499910818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.04113265702633874,
                                  -0.19272044048650289,
                                  0,
                                  0.21034557463246664,
                                  -0.065091801698088064,
                                  0,
                                  0.067031470758336514,
                                  0,
                                  -0.021953888328862359,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11028146898649421,
                                  0,
                                  0,
                                  -0.11715429863515966,
                                  -0.0042708131028191673,
                                  0.035128596056352289,
                                  0,
                                  0.095891180724351446,
                                  0,
                                  0,
                                  0,
                                  0.0082748605459884977,
                                  0.60978083748040313,
                                  0,
                                  0,
                                  0.099350384229043756,
                                  0,
                                  -0.10022021378445699,
                                  0,
                                  0.13230377900129692,
                                  0,
                                  0,
                                  0,
                                  -0.064057955954758369,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1726623475859809,
                                  -0.090161195840041494,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12864672059674404,
                                  0.41839249149982111,
                                  0,
                                  0,
                                  0,
                                  -0.063722966343894488,
                                  0.032067299430617105,
                                  -0.27593652978260336,
                                  0.084048305458346129,
                                  0,
                                  0,
                                  0,
                                  0.048063154671351603,
                                  0.051696979455954778,
                                  -0.11727075639830595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.05075079615375714,
                                  0,
                                  0.039743905071360552,
                                  0,
                                  0,
                                  0.19635726274858648,
                                  -0.45110931479401517,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20436263417238063,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21318410373438379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23425389291814108,
                                  0,
                                  0,
                                  0.086949963543520012,
                                  0,
                                  -0.0017333212465172488,
                                  0,
                                  -0.30076754322631039,
                                  0.062231132584613151,
                                  0,
                                  0,
                                  0,
                                  0.00032066602804940031,
                                  0,
                                  0.26318109674615098,
                                  0,
                                  0.1936560590882806,
                                  0,
                                  0,
                                  0,
                                  0.13793151479669105,
                                  0,
                                  0,
                                  0,
                                  -0.080917160388888229,
                                  0,
                                  -0.0040185994782300817,
                                  -0.071099346002870475,
                                  0,
                                  0,
                                  0,
                                  -0.22108091519890835,
                                  0,
                                  0,
                                  0,
                                  0.14933426907694328,
                                  0.10397715213112466,
                                  0,
                                  0,
                                  -0.091237598275596618,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20153525611358125,
                                  0.04393540450933818,
                                  0.058053077220471684,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095532153174077525,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.073499122335324268,
                                  0,
                                  -0.13191438614211154,
                                  0,
                                  0,
                                  0.030155111810224306,
                                  -0.15181393996395895,
                                  0,
                                  -0.14370358158574506,
                                  0,
                                  0.22851036819469672,
                                  0.044675117786830136,
                                  0,
                                  0,
                                  0,
                                  0.020586241831416784,
                                  -0.044455114999836537,
                                  -0.0070986361751649019,
                                  0.14988359906506049,
                                  0,
                                  -0.31961549856171634,
                                  0,
                                  -0.17406527754848866,
                                  0.014904008317732462,
                                  0.12349286288505719,
                                  0,
                                  0,
                                  0.044946111922542942,
                                  -0.16848734062335552,
                                  -0.14740900596908754,
                                  0.14684584335368167,
                                  -0.51087351840439399,
                                  0.057016573427696005,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28716497371902588,
                                  0,
                                  0,
                                  0,
                                  0.089880025902988894,
                                  0,
                                  0.12518607191607869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.089167008532946707,
                                  0,
                                  0,
                                  0,
                                  -0.024235565868263129,
                                  0,
                                  0,
                                  0.12577736077700949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083038372873092361,
                                  0,
                                  -0.10797685344677631,
                                  0,
                                  -0.24194701311526967,
                                  0.0087492026397494385,
                                  -0.09001071982788629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21581955267791703,
                                  0.0067081465194326201,
                                  0.21686652716396851,
                                  0.0552340316948799,
                                  0,
                                  -0.0077511031166948071,
                                  0,
                                  0,
                                  0,
                                  -0.26417987315164249,
                                  0.38286280743756795,
                                  0.24288322389097142,
                                  -0.11136862572118172,
                                  0,
                                  0,
                                  0,
                                  -0.02422130822613594,
                                  0.21496288401169916,
                                  -0.17080289707012411,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15534892051488841,
                                  0,
                                  -0.12906089357201347,
                                  0,
                                  0,
                                  -0.10443518998322467,
                                  0.1589934063503376,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16227162364725062,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063794187711972677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16005201428050669,
                                  0,
                                  0,
                                  -0.029697757203819054,
                                  0,
                                  0.15301211272849327,
                                  0,
                                  -0.26067775645384422,
                                  0.18545644778017403,
                                  0,
                                  0,
                                  0,
                                  0.059140271989064304,
                                  0,
                                  0.21064010155731583,
                                  0,
                                  -0.44401845409908031,
                                  0,
                                  0,
                                  0,
                                  -0.03895893168055866,
                                  0,
                                  0,
                                  0,
                                  0.1109260032530802,
                                  0,
                                  0.099492413138640073,
                                  0.092001296099157692,
                                  0,
                                  0,
                                  0,
                                  0.13178885527039721,
                                  0,
                                  0,
                                  0,
                                  0.12241980249031792,
                                  0.24292226968731717,
                                  0,
                                  0,
                                  0.089409260042957239,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15608561462861148,
                                  0.33693696624819652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052940790167341156,
                                  0,
                                  -0.083360970817652716,
                                  0,
                                  -0.23769688662664473,
                                  0.1715262327977945,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12724801190842622,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32477138708325498,
                                  0,
                                  0,
                                  0,
                                  -0.29695838983760148,
                                  -0.21878711625518982,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15403983148849695,
                                  0.145354184420422,
                                  0,
                                  -0.10830808161200775,
                                  -0.11368674700644868,
                                  0,
                                  -0.19827004181696256,
                                  0,
                                  0.051025268859968373,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39810041999349194,
                                  0,
                                  0,
                                  0.046143160835446423,
                                  0.048866391170916193,
                                  0.076756354546746702,
                                  0,
                                  -0.03064397838485039,
                                  0,
                                  0,
                                  0,
                                  -0.18352211027153395,
                                  -0.10080567162352885,
                                  0,
                                  0,
                                  0.070280529899995711,
                                  0,
                                  0.16955823074877607,
                                  0,
                                  0.22193521861898319,
                                  0,
                                  0,
                                  0,
                                  -0.13741193160112974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14710392837825617,
                                  0.13520690144501923,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20462261639104101,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19569341291322589,
                                  -0.0051257353155596992,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22751871716100913,
                                  0,
                                  -0.089210318250768791,
                                  0,
                                  0.14494162804096899,
                                  -0.1113187906832874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22098631738489638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19070615681634137,
                                  0,
                                  0,
                                  0,
                                  -0.05208937836753421,
                                  0.029803864969669192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2388210858362935,
                                  -0.084855025776388995,
                                  0,
                                  -0.016398980649928032,
                                  -0.35111495268371201,
                                  0,
                                  0.17996564381283153,
                                  0,
                                  -0.10141011263959146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025691165609789256,
                                  0,
                                  0,
                                  -0.16617706604380905,
                                  0.24173156854277814,
                                  -0.18227511396353563,
                                  0,
                                  0.096127774376062181,
                                  0,
                                  0,
                                  0,
                                  -0.046660930382263627,
                                  -0.12107834586346082,
                                  0,
                                  0,
                                  0.45036378219003653,
                                  0,
                                  -0.11808292865069898,
                                  0,
                                  0.064057797299540475,
                                  0,
                                  0,
                                  0,
                                  -0.31916227305511408,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19369632555617208,
                                  0.20254336523101391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044709672988041911,
                                  0,
                                  -0.32901099815677898,
                                  0.19023351671977262,
                                  0.24421081646515969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14811059901476359,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10109534931142383,
                                  0,
                                  -0.10446440631958792,
                                  0,
                                  0,
                                  0.25136843595995545,
                                  0.050898804113201537,
                                  0,
                                  -0.18626315959750356,
                                  0,
                                  -0.13319215853657948,
                                  0.19985156782289934,
                                  0,
                                  0,
                                  0,
                                  0.026374544533925313,
                                  0.026224031518600595,
                                  0.25808795110608485,
                                  -0.14449372694339593,
                                  0,
                                  -0.082955931394357113,
                                  0,
                                  0.36578677519731922,
                                  -0.32085637412256673,
                                  -0.18753490830873049,
                                  0,
                                  0,
                                  0.023293482065757001,
                                  -0.0059135772374461319,
                                  0.049483044771681105,
                                  0.082807880674528739,
                                  -0.12516596012152501,
                                  0.067667418603641782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24739342840389156,
                                  0,
                                  0,
                                  0,
                                  -0.0089400893672582499,
                                  0,
                                  0.05277355418583847,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14804155053403301,
                                  0,
                                  0,
                                  0,
                                  -0.11416336056735692,
                                  0,
                                  0,
                                  -0.048886885858245799,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14856650790734346,
                                  0,
                                  -0.0029468404174025891,
                                  0,
                                  0.09300502313615186,
                                  0.08878416970428224,
                                  -0.038718635798724983,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070031329347883295,
                                  0.11899882689725369,
                                  0.021121069806205921,
                                  0.18939766649826914,
                                  0,
                                  -0.11675687571308511,
                                  0,
                                  0,
                                  0,
                                  0.010170534381100323,
                                  -0.20461753031553248,
                                  -0.22909390382162109,
                                  0.13739227802380016,
                                  0,
                                  0,
                                  0,
                                  -0.35910685147577281,
                                  0.038385469470207136,
                                  -0.091412042176080593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11191685989021384,
                                  0,
                                  -0.027303186238637332,
                                  0,
                                  0,
                                  0.24456231234791009,
                                  0.086712039202934882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2416697487978765,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35329144782851279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22913702301558164,
                                  0,
                                  0,
                                  0.010533313955772922,
                                  0,
                                  -0.15108644044193476,
                                  0,
                                  -0.042812476190076949,
                                  -0.19840356264347464,
                                  0,
                                  0,
                                  0,
                                  0.019642724938056542,
                                  0,
                                  -0.37799860940943736,
                                  0,
                                  -0.16727019753203182,
                                  0,
                                  0,
                                  0,
                                  0.074355444765891301,
                                  0,
                                  0,
                                  0,
                                  0.30667653206304823,
                                  0,
                                  0.0011984092246966581,
                                  -0.017973697854084373,
                                  0,
                                  0,
                                  0,
                                  0.18058356153140054,
                                  0,
                                  0,
                                  0,
                                  -0.17665344343953904,
                                  0.13687168424786794,
                                  0,
                                  0,
                                  -0.0093349269973976162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10978910264087685,
                                  0.011444175407572511,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30158185916933949,
                                  0,
                                  -0.035176279270137473,
                                  0,
                                  0.17293479459728606,
                                  0.081740227062331083,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024548582664576071,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.011756420652344786,
                                  0,
                                  0,
                                  0,
                                  0.10279735719545141,
                                  0.15591279249539997,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24625186489907955,
                                  -0.27153824516333536,
                                  0,
                                  0.055859693741822009,
                                  -0.18134425075439375,
                                  0,
                                  -0.0066631948721566983,
                                  0,
                                  -0.31902972298467741,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.029868098810263533,
                                  0,
                                  0,
                                  0.22871840498737875,
                                  0.086920299266898593,
                                  -0.061653648345985433,
                                  0,
                                  0.039435077289497952,
                                  0,
                                  0,
                                  0,
                                  -0.07929753321548598,
                                  0.075519584322978187,
                                  0,
                                  0,
                                  0.071970972871665845,
                                  0,
                                  0.1626680362589607,
                                  0,
                                  -0.36976380150918475,
                                  0,
                                  0,
                                  0,
                                  0.13969186353238155,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14269884276553638,
                                  0.21646226857153555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46691810466685058,
                                  0,
                                  -0.060535760229259314,
                                  -0.26117611438325994,
                                  0.10228073169048076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.031893568801385053,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.038402580412839123,
                                  0,
                                  -0.018824925473445775,
                                  0,
                                  0,
                                  -0.096253728232789271,
                                  0.039220477484472716,
                                  0,
                                  0.012655253031929537,
                                  0,
                                  -0.22490097371767453,
                                  0.10146613586960186,
                                  0,
                                  0,
                                  0,
                                  -0.073367417948650065,
                                  -0.10051418421745655,
                                  -0.30849006352064284,
                                  0.19299634450562506,
                                  0,
                                  -0.36419352775514602,
                                  0,
                                  -0.036560041328516264,
                                  -0.16072359647721515,
                                  -0.11301264159837507,
                                  0,
                                  0,
                                  -0.30551243387235633,
                                  0.23796243871229419,
                                  0.041462657183603625,
                                  -0.11266784473603955,
                                  0.12397266958515961,
                                  0.35580780926330174,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.034447816475834218,
                                  0,
                                  0,
                                  0,
                                  -0.16135209294218347,
                                  0,
                                  -0.16452704331104206,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063100253871666651,
                                  0,
                                  0,
                                  0,
                                  0.063820867929390929,
                                  0,
                                  0,
                                  -0.14656906373317791,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.071915390518220698,
                                  0,
                                  -0.064346711815412072,
                                  0,
                                  -0.12259587002194539,
                                  -0.080695329114519779,
                                  -0.23941622759499048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019746039126661626,
                                  -0.048591951444833012,
                                  0.1778601400272832,
                                  0.098824692842730724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21635236536753921,
                                  0.088497278968777141,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30383322718342431,
                                  0,
                                  0.16322683047032532,
                                  0,
                                  0.0071453052440246471,
                                  0.30993897614572086,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.059064598886510625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.023933138634149923,
                                  0,
                                  0,
                                  0,
                                  -0.073256811216516712,
                                  -0.19402961922880185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.025862812886693957,
                                  -0.12353594180268437,
                                  0,
                                  0.082560420167198181,
                                  0.13058816637642967,
                                  0,
                                  -0.0015976944396800131,
                                  0,
                                  0.38125290456212524,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068877993612870864,
                                  0,
                                  0,
                                  -0.050571756017524991,
                                  0.18669443479970413,
                                  -0.32592832702326824,
                                  0,
                                  0.10447528909425179,
                                  0,
                                  0,
                                  0,
                                  -0.33553119679033283,
                                  -0.040656255730958921,
                                  0,
                                  0,
                                  -0.092076301790169929,
                                  0,
                                  -0.082225043228185413,
                                  0,
                                  -0.15092681003127698,
                                  0,
                                  0,
                                  0,
                                  0.12427805200372162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40951037130159607,
                                  -0.013824368232019022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056302370736824932,
                                  -0.072673153205485869,
                                  0,
                                  0,
                                  0,
                                  -0.0056988392531726762,
                                  -0.0052207898757473878,
                                  0.11023111123640632,
                                  -0.21403230974106219,
                                  0,
                                  0,
                                  0,
                                  -0.065122663059189415,
                                  -0.17019711600738652,
                                  -0.13034969494369705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028191070592703482,
                                  0,
                                  0.16470776292066383,
                                  0,
                                  0,
                                  0.14869785071180575,
                                  -0.15981922953194111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16779381292051476,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072917446783193882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.00070722186031353662,
                                  0,
                                  0,
                                  0.2872734097518963,
                                  0,
                                  0.2826214547917002,
                                  0,
                                  -0.10064671461654573,
                                  0.32635603639595223,
                                  0,
                                  0,
                                  0,
                                  -0.13476563585123225,
                                  0,
                                  -0.032535791252351488,
                                  0,
                                  -0.15205922624574034,
                                  0,
                                  0,
                                  0,
                                  0.14882137197141704,
                                  0,
                                  0,
                                  0,
                                  0.15134520519394637,
                                  0,
                                  -0.098000855608187026,
                                  -0.096549721244450215,
                                  0,
                                  0,
                                  0,
                                  0.11673327123285972,
                                  0,
                                  0,
                                  0,
                                  -0.25033804432229229,
                                  -0.54000007635757996,
                                  0,
                                  0,
                                  -0.15554389173408806,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2619989546155933,
                                  -0.19095410103665109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.01020094787827391,
                                  0,
                                  0.15007226135186413,
                                  0,
                                  0.44181137047422525,
                                  0.034748475468670055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095101128787962397,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045756254933991256,
                                  0,
                                  0,
                                  0,
                                  -0.25562097104263953,
                                  0.12192323252952628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20793633679196005,
                                  -0.022323969100756236,
                                  0,
                                  -0.092784913319105683,
                                  -0.32449411580134924,
                                  0,
                                  -0.18763213939442064,
                                  0,
                                  0.4737372173048035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10158855538070552,
                                  0,
                                  0,
                                  0.09496902732200152,
                                  0.019319960592901878,
                                  0.050308270082013842,
                                  0,
                                  -0.098914433177658675,
                                  0,
                                  0,
                                  0,
                                  0.036604871530071921,
                                  0.019805622037296352,
                                  0,
                                  0,
                                  0.22967282097471953,
                                  0,
                                  -0.045410261143393249,
                                  0,
                                  -0.075576690440387367,
                                  0,
                                  0,
                                  0,
                                  0.11194646360321242,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11996218041171522,
                                  0.056383000212253488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20702165767698444,
                                  -0.0049092739528563941,
                                  0,
                                  0,
                                  0,
                                  -0.01064324727243281,
                                  -0.16690423037291111,
                                  -0.16090882074568197,
                                  0.22387158158921161,
                                  0,
                                  0,
                                  0,
                                  0.0045756109143536075,
                                  -0.14495629918474603,
                                  0.3113292971183263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030110109237204172,
                                  0,
                                  0.16177698200829355,
                                  0,
                                  0,
                                  -0.064761747321260402,
                                  -0.057523363878412122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14336430813158557,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19828660261581216,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17912579027412631,
                                  0,
                                  0,
                                  0.15514803916549172,
                                  0,
                                  -0.0886123470048642,
                                  0,
                                  0.060765875483259194,
                                  -0.023167244683202477,
                                  0,
                                  0,
                                  0,
                                  0.093463340683692636,
                                  0,
                                  0.31961201495432512,
                                  0,
                                  -0.52052032576173679,
                                  0,
                                  0,
                                  0,
                                  0.026904046914893925,
                                  0,
                                  0,
                                  0,
                                  0.063372527802812509,
                                  0,
                                  -0.018896155945713207,
                                  0.32357152336688494,
                                  0,
                                  0,
                                  0,
                                  0.011365762710534218,
                                  0,
                                  0,
                                  0,
                                  0.16113940862361856,
                                  -0.069085769123973198,
                                  0,
                                  0,
                                  -0.30471877527517133,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22230155500288762,
                                  0,
                                  0,
                                  0,
                                  -0.2513443464634954,
                                  0.21296684123522663,
                                  -0.095037202250233321,
                                  -0.083691862133855599,
                                  0,
                                  0,
                                  0,
                                  -0.075512500129199273,
                                  -0.47748345963620747,
                                  0.061783320800573839,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.052133642400171133,
                                  0,
                                  0.023509546362403658,
                                  0,
                                  0,
                                  0.32857520680278413,
                                  0.10620744670531659,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14235352304899529,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21308128484991029,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043407717865447587,
                                  0,
                                  0,
                                  -0.39469514402280859,
                                  0,
                                  0.13730604578995484,
                                  0,
                                  0.054133391262273033,
                                  -0.26210456576175778,
                                  0,
                                  0,
                                  0,
                                  0.030894382443680524,
                                  0,
                                  0.063714360524381938,
                                  0,
                                  0.023728860704159156,
                                  0,
                                  0,
                                  0,
                                  -0.00061673898828936823,
                                  0,
                                  0,
                                  0,
                                  -0.1040819619131149,
                                  0,
                                  -0.031289707801618161,
                                  0.28908308955490186,
                                  0,
                                  0,
                                  0,
                                  0.20327795219788974,
                                  0,
                                  0,
                                  0,
                                  -0.078607937439748421,
                                  -0.034256036714323444,
                                  0,
                                  0,
                                  -0.050425213172805752,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10431832333773157,
                                  0.28920222095151227,
                                  0.010239809487601489,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.071607394875356084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15314915406439139,
                                  0,
                                  0.25775658647590516,
                                  0,
                                  0,
                                  -0.025664814834552227,
                                  0.19278676148207743,
                                  0,
                                  0.019283963087671874,
                                  0,
                                  0.039351099344264513,
                                  -0.18623602615787418,
                                  0,
                                  0,
                                  0,
                                  0.30158171747073231,
                                  -0.03258404947982331,
                                  -0.022635460425243,
                                  -0.099848053964818079,
                                  0,
                                  -0.033017746787251535,
                                  0,
                                  -0.14518426072596508,
                                  0.019532692924384761,
                                  -0.23816327357862724,
                                  0,
                                  0,
                                  -0.14864222873449448,
                                  -0.088295196875607398,
                                  0.36068336508767862,
                                  -0.068775335081343703,
                                  0.092863659500487805,
                                  0.09280022833751278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044260093504599224,
                                  0,
                                  0,
                                  0,
                                  0.13204031760633525,
                                  0,
                                  -0.090126208737873303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26340034097709841,
                                  0,
                                  0,
                                  0,
                                  0.056250018136846242,
                                  0,
                                  0,
                                  -0.050574950526238775,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.079006222280302879,
                                  0,
                                  -0.011790303512274489,
                                  0,
                                  -0.079322272542918348,
                                  -0.16013084685623555,
                                  0.08764530118535642,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3477050159298295,
                                  0.21930225493304414,
                                  0.0091644698835572445,
                                  0.23349069501036149,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20477537788427258,
                                  -0.082927408430921043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24683383572601997,
                                  0,
                                  0.01205456316095959,
                                  0,
                                  0.029224999765185632,
                                  -0.070346515233958809,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21433951069230506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022797382936891708,
                                  0,
                                  0,
                                  0,
                                  -0.2808134879047024,
                                  0.12371597917194398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.05779378450823594,
                                  -0.024485305116154911,
                                  0,
                                  -0.10982569446221285,
                                  -0.11502845193201611,
                                  0,
                                  -0.06813672132059484,
                                  0,
                                  0.0084029274634661588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23748480551402532,
                                  0,
                                  0,
                                  0.42728858605780973,
                                  0.036840625081245498,
                                  0.15900597650953879,
                                  0,
                                  0.30172207327166872,
                                  0,
                                  0,
                                  0,
                                  0.045932567346559164,
                                  0.17158248417889838,
                                  0,
                                  0,
                                  -0.2577004528304353,
                                  0,
                                  -0.3123998385001292,
                                  0,
                                  0.14024021878285953,
                                  0,
                                  0,
                                  0,
                                  0.1289427158370155,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17959489772479417,
                                  -0.20111369925435749,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22033375246722448,
                                  0,
                                  -0.14085314205670832,
                                  0.17046455370977373,
                                  -0.17697137788879294,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.048825322145108263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19208585002558426,
                                  0,
                                  0.11184440527048138,
                                  0,
                                  0,
                                  -0.14285319348701292,
                                  -0.047403207964904021,
                                  0,
                                  0.049808020366152485,
                                  0,
                                  -0.037676488410252874,
                                  0.40604309219112772,
                                  0,
                                  0,
                                  0,
                                  0.09656641241749174,
                                  0.09350480674320126,
                                  -0.063352724722562315,
                                  0.2620372064470049,
                                  0,
                                  -0.0060077666071059388,
                                  0,
                                  -0.13501262985315376,
                                  0.033752261531529985,
                                  0.11839927006179257,
                                  0,
                                  0,
                                  0.07944576941933576,
                                  -0.052040106892341925,
                                  0.062606955715417204,
                                  -0.31070197142729239,
                                  0.07788905294110364,
                                  -0.20952229727162192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22320416950032576,
                                  0,
                                  0,
                                  0,
                                  0.1523622775971078,
                                  0,
                                  -0.22510337253998919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10851241991794645,
                                  0,
                                  0,
                                  0,
                                  0.012571387332967952,
                                  0,
                                  0,
                                  -0.018398113201612002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1991513501599953,
                                  0,
                                  -0.20725023893771971,
                                  0,
                                  0.24850519544201072,
                                  0.18123049656821466,
                                  0.13999976734313122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12056262019199666,
                                  -0.055091727564740747,
                                  0.18208937533350339,
                                  0.097167282939207261,
                                  0,
                                  0.048182559722732443,
                                  0,
                                  0,
                                  0,
                                  0.032250446489264908,
                                  -0.021768059572333014,
                                  0.19719521109030416,
                                  0.078629388016891372,
                                  0,
                                  0,
                                  0,
                                  -0.072312066551950979,
                                  -0.026391322577413306,
                                  -0.040286724874989389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37096019374033001,
                                  0,
                                  0.13071076371804216,
                                  0,
                                  0,
                                  -0.12620375574674059,
                                  -0.21880436490029237,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.037241865714900201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050184057719736989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15357688231333996,
                                  0,
                                  0,
                                  0.20961895148733511,
                                  0,
                                  0.030764648563359545,
                                  0,
                                  -0.24256832064739312,
                                  -0.052182503754629322,
                                  0,
                                  0,
                                  0,
                                  -0.13075446214174602,
                                  0,
                                  -0.16410376864595511,
                                  0,
                                  0.090855188341865845,
                                  0,
                                  0,
                                  0,
                                  -0.0067295199273006388,
                                  0,
                                  0,
                                  0,
                                  -0.095899652716276762,
                                  0,
                                  0.46640034160427696,
                                  0.28193374013970757,
                                  0,
                                  0,
                                  0,
                                  0.27735363169639038,
                                  0,
                                  0,
                                  0,
                                  -0.24498960908914663,
                                  0.30156438938114466,
                                  0,
                                  0,
                                  -0.068427095707188579,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2136087407572016,
                                  -0.040165802715977923,
                                  -0.1156959256417512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10766358294551934,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2448974936643937,
                                  0,
                                  0.33874470406681717,
                                  0,
                                  0,
                                  0.11530698769415981,
                                  -0.029585461840083663,
                                  0,
                                  -0.071520304965797393,
                                  0,
                                  -0.023780209683709756,
                                  -0.10112836098373791,
                                  0,
                                  0,
                                  0,
                                  -0.20903851928770167,
                                  -0.033147435571094966,
                                  0.18716545655767697,
                                  0.17045267162307426,
                                  0,
                                  -0.072589951766078548,
                                  0,
                                  0.11368637207149995,
                                  -0.24974200772527813,
                                  0.22432976443231428,
                                  0,
                                  0,
                                  -0.14970976761655316,
                                  -0.10057792131933439,
                                  0.060275783196492197,
                                  0.014078328905259362,
                                  0.11140817199673581,
                                  -0.14597619350356139,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075376028317275898,
                                  0,
                                  0,
                                  0,
                                  0.030417292961295226,
                                  0,
                                  -0.0044458426390060722,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20683775501180143,
                                  0,
                                  0,
                                  0,
                                  0.060536705201957801,
                                  0,
                                  0,
                                  0.25937647053283774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070331678655080665,
                                  0,
                                  -0.40513589643521075,
                                  0,
                                  -0.16994490632782222,
                                  -0.14011903468009543,
                                  0.031184835064149187,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12156682415633331,
                                  -0.21000167825298965,
                                  -0.115367825677776,
                                  -0.044966014693526984,
                                  0,
                                  0,
                                  0.22303702712034523,
                                  0.12754677437338111,
                                  -0.14051328635706833,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.077146584407381161,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.071472334292282891,
                                  0,
                                  -0.089243164133084946,
                                  0,
                                  0,
                                  0.034895232232981459,
                                  0.26581739924177855,
                                  0,
                                  -0.29203825350305901,
                                  0,
                                  -0.20901495557493507,
                                  0.1029491577209061,
                                  0,
                                  0,
                                  0,
                                  0.10603322542916321,
                                  -0.091970966693056461,
                                  -0.0027417006362159338,
                                  0.25275030906067542,
                                  0,
                                  0.024179006379429806,
                                  0,
                                  0.02427734650004381,
                                  0.084420409487475728,
                                  0.044481177938287979,
                                  0,
                                  0,
                                  0.02452062192960788,
                                  0.082893613998539381,
                                  -0.07752341921296195,
                                  0.50314532960095737,
                                  0.12970974388438011,
                                  -0.00093122245248929147,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24535796644401014,
                                  0,
                                  0,
                                  0,
                                  -0.060457407717644199,
                                  0,
                                  -0.043085058335635709,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22052482475169879,
                                  0,
                                  0,
                                  0,
                                  0.16251673232943803,
                                  0,
                                  0,
                                  -0.24373895358213682,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046987269932253245,
                                  0,
                                  -0.020632233559987612,
                                  0,
                                  0.23388687830811586,
                                  -0.021951367608158519,
                                  0.048018853176312076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14760397430274835,
                                  -0.074390511091950856,
                                  -0.13640916241977963,
                                  0.014790913385315397,
                                  0,
                                  0,
                                  -0.26578135217780158,
                                  0.22771676759945647,
                                  0.028719576842787711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14387643758214372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27730168478775852,
                                  0,
                                  0.1316092222524784,
                                  0,
                                  0,
                                  -0.2578478068680255,
                                  0.19499025455113356,
                                  0,
                                  -0.066564265168678027,
                                  0,
                                  0.14282863257612677,
                                  -0.016897087038192839,
                                  0,
                                  0,
                                  0,
                                  -0.054261296050075229,
                                  -0.16314161030748769,
                                  -0.16603184946704377,
                                  -0.053972378965425588,
                                  0,
                                  0.2275513926604826,
                                  0,
                                  -0.047097980313580402,
                                  -0.041700936158573995,
                                  -0.14278226375051631,
                                  0,
                                  0,
                                  0.10318360254029768,
                                  0.076928219087252475,
                                  -0.08899400125101023,
                                  0.052018088845915779,
                                  -0.090670639525177107,
                                  -0.050603719819230959,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032434266745592889,
                                  0,
                                  0,
                                  0,
                                  -0.22055036255246852,
                                  0,
                                  0.23118694006058887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021477692179368305,
                                  0,
                                  0,
                                  0,
                                  0.19974973973911075,
                                  0,
                                  0,
                                  -0.15937366470018738,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057567846053584476,
                                  0,
                                  -0.16705679411739882,
                                  0,
                                  -0.38775199468010568,
                                  0.075472950549812373,
                                  0.021903626886881505,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0014035948064974122,
                                  -0.25339247554044136,
                                  -0.036301729589467313,
                                  0.18927365420676359,
                                  0,
                                  0.2995452845359407,
                                  0,
                                  0,
                                  0,
                                  0.25161505601650225,
                                  -0.1787776586583591,
                                  0.12535509230861183,
                                  -0.32435470830295365,
                                  0,
                                  0,
                                  0,
                                  0.088314912214620608,
                                  -0.073045435844850473,
                                  0.29478831876426687,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17061991995300024,
                                  0,
                                  -0.26293836833472073,
                                  0,
                                  0,
                                  -0.099711403274688248,
                                  -0.017062791243695578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15660847190608834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10476765892198307,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064029792497487997,
                                  0,
                                  0,
                                  0.099454231816937771,
                                  0,
                                  -0.02453103386207562,
                                  0,
                                  -0.17001133585886252,
                                  -0.34863689242224327,
                                  0,
                                  0,
                                  0,
                                  -0.41907835784523406,
                                  0,
                                  -0.034294523013786771,
                                  0,
                                  -0.17008853449959777,
                                  0,
                                  0,
                                  0,
                                  -0.027329571927462049,
                                  0,
                                  0,
                                  0,
                                  0.16657407519219791,
                                  0,
                                  0.10505393229585638,
                                  0.029094911624198104,
                                  0,
                                  0,
                                  0,
                                  -0.10446043266676867,
                                  0,
                                  0,
                                  0,
                                  0.10861600373551783,
                                  -0.068085678386460152,
                                  0,
                                  0,
                                  0.10753239394333898,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064994695028189914,
                                  0,
                                  0,
                                  0,
                                  -0.14590888743326438,
                                  -0.018119941534946706,
                                  0.1849977911835318,
                                  0.40488509632790004,
                                  0,
                                  0,
                                  0,
                                  0.30810569358725176,
                                  0.011949783557794361,
                                  0.26263057349910596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25262925293059779,
                                  0,
                                  0.10665441633783972,
                                  0,
                                  0,
                                  0.10036107153523015,
                                  -0.24733498206444168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13873245990963995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0286076392934662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17895027058766497,
                                  0,
                                  0,
                                  -0.30043021698036598,
                                  0,
                                  -0.016597416713197942,
                                  0,
                                  -0.24215198845025329,
                                  0.039527692238712886,
                                  0,
                                  0,
                                  0,
                                  -0.13022393788463749,
                                  0,
                                  -0.17826306291737079,
                                  0,
                                  -0.050849942286418939,
                                  0,
                                  0,
                                  0,
                                  -0.24959372566769344,
                                  0,
                                  0,
                                  0,
                                  -0.030391951744251994,
                                  0,
                                  0.10754792962536924,
                                  -0.21502944838130217,
                                  0,
                                  0,
                                  0,
                                  0.2300582019481153,
                                  0,
                                  0,
                                  0,
                                  0.010358881024927359,
                                  -0.19131551065878105,
                                  0,
                                  0,
                                  -0.026589692826286024,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081010457060911409,
                                  -0.36612666441953301,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087490473909160066,
                                  0,
                                  0.16480362244491781,
                                  0,
                                  0.036805587459839591,
                                  0.33234920018098435,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059813106108950936,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043544630258111339,
                                  0,
                                  0,
                                  0,
                                  0.064283711240993691,
                                  0.10910259757239399,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.012034621444208089,
                                  -0.17205851193104593,
                                  0,
                                  -0.19585429964075982,
                                  0.027795062237294724,
                                  0,
                                  0.27459242034349157,
                                  0,
                                  -0.047336275963204145,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38818230888653704,
                                  0,
                                  0,
                                  -0.13242565428696035,
                                  0.029949681090988733,
                                  -0.25524444331218249,
                                  0,
                                  0.22179817796976473,
                                  0,
                                  0,
                                  0,
                                  0.042254752527849812,
                                  0.23385493335699653,
                                  0,
                                  0,
                                  -0.19943576237648786,
                                  0,
                                  0.14808879964559596,
                                  0,
                                  0.09097321250502248,
                                  0,
                                  0,
                                  0,
                                  -0.15007947133477312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28436231663018052,
                                  0.093402629630876755,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15067773629135214,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064268223647222733,
                                  0.018419390402845723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20121396348577644,
                                  0,
                                  0.048082927278000238,
                                  0,
                                  0.092868835456099544,
                                  -0.16832232403560637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.102738315566134,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27935119564668254,
                                  0,
                                  0,
                                  0,
                                  0.40980711541491027,
                                  0.076430757677614841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.042125922922628754,
                                  0.0039200013400907899,
                                  0,
                                  0.1450855826481901,
                                  0.070819023348231674,
                                  0,
                                  -0.30948645216641929,
                                  0,
                                  0.23698082153591812,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29411489233579458,
                                  0,
                                  0,
                                  -0.11745372660384151,
                                  0.052608689890274812,
                                  0.035688670679756104,
                                  0,
                                  -0.0059782271962843959,
                                  0,
                                  0,
                                  0,
                                  -0.060681712499974914,
                                  0.14923704718821099,
                                  0,
                                  0,
                                  0.0045089388890050854,
                                  0,
                                  0.11540827338123073,
                                  0,
                                  -0.35618359136601191,
                                  0,
                                  0,
                                  0,
                                  -0.20329387492413281,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0067392004002326811,
                                  -0.36809555568603974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16185572664409334,
                                  0.070073675519636072,
                                  0,
                                  0,
                                  0,
                                  0.13368753532473496,
                                  0.18117598100603585,
                                  -0.17848769873110254,
                                  0.16460444107478919,
                                  0,
                                  0,
                                  0,
                                  0.2135931871085045,
                                  0.033118804685242004,
                                  0.23039832644889682,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098324809707792671,
                                  0,
                                  -0.19657783392706138,
                                  0,
                                  0,
                                  0.29820441298766115,
                                  0.29462745784926569,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.04223289119360131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.088978054023757747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022427277134258308,
                                  0,
                                  0,
                                  0.21542283500025675,
                                  0,
                                  0.33699969078758218,
                                  0,
                                  0.10107091506966219,
                                  0.082696545031089058,
                                  0,
                                  0,
                                  0,
                                  0.013602398413872618,
                                  0,
                                  -0.23307919719782649,
                                  0,
                                  -0.16663723213488862,
                                  0,
                                  0,
                                  0,
                                  0.13715933093430013,
                                  0,
                                  0,
                                  0,
                                  -0.18241196402262921,
                                  0,
                                  0.23595165995152872,
                                  -0.2886306053683606,
                                  0,
                                  0,
                                  0,
                                  -0.092710921411168573,
                                  0,
                                  0,
                                  0,
                                  0.030056362217280953,
                                  0.17203078271222219,
                                  0,
                                  0,
                                  -0.24884260772636774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23363756362851143,
                                  0.14202899272315422,
                                  -0.053290769880499245,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022679180098190838,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040658758945577737,
                                  0,
                                  -0.022208682287312435,
                                  0,
                                  0,
                                  -0.085283617083137461,
                                  -0.24373752577760016,
                                  0,
                                  0.1357818503802731,
                                  0,
                                  -0.054088191247065473,
                                  -0.16983950520593222,
                                  0,
                                  0,
                                  0,
                                  -0.0052045113422350686,
                                  -0.26181412353422695,
                                  0.1924656416204559,
                                  0.22428195208445253,
                                  0,
                                  0.17586142497875573,
                                  0,
                                  -0.11530386160605197,
                                  -0.099932406213808792,
                                  0.029482726036233566,
                                  0,
                                  0,
                                  -0.24518413356425714,
                                  0.23901698920038178,
                                  -0.096720692999023292,
                                  -0.050814540145797719,
                                  -0.14007066138203789,
                                  0.25799561320347209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15049319359844809,
                                  0,
                                  0,
                                  0,
                                  0.10530007141479444,
                                  0,
                                  0.16714090338304022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027664301959229882,
                                  0,
                                  0,
                                  0,
                                  0.16958389688847372,
                                  0,
                                  0,
                                  0.1208097306496986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16749851142359395,
                                  0,
                                  0.31617195143405563,
                                  0,
                                  0.12998954753883385,
                                  -0.042314652732950174,
                                  0.31079261961687038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11048057301987571,
                                  0.1129739896200176,
                                  0.01213483509518457,
                                  0.047787309397168125,
                                  0,
                                  0,
                                  0.12764135288099976,
                                  -0.18664883573094473,
                                  0.11602951286813162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051833565091574163,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17588820017662862,
                                  0,
                                  0.045244910548977044,
                                  0,
                                  0,
                                  0.024859220291178111,
                                  -0.1095936543269219,
                                  0,
                                  -0.095221949741441395,
                                  0,
                                  -0.19610103473930368,
                                  0.084495707065554981,
                                  0,
                                  0,
                                  0,
                                  -0.19927345687983944,
                                  0.11294862922602916,
                                  -0.072882532021812385,
                                  0.047988502510795381,
                                  0,
                                  0.15907666098106504,
                                  0,
                                  -0.041050681054609933,
                                  -0.18117592953411918,
                                  -0.073638417997720015,
                                  0,
                                  0,
                                  0.018867791802854385,
                                  -0.23774518433847405,
                                  0.19611294675917604,
                                  -0.10797997862359854,
                                  -0.35493627223579638,
                                  0.025825242197223999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1804234936699145,
                                  0,
                                  0,
                                  0,
                                  -0.1109533130888684,
                                  0,
                                  -0.16105909723622369,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46483613071847735,
                                  0,
                                  0,
                                  0,
                                  0.099444286460120171,
                                  0,
                                  0,
                                  -0.0045811406788317816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10080011481736514,
                                  0,
                                  0.16139735151917009,
                                  0,
                                  0.12959715598473179,
                                  0.11842774876601535,
                                  0.14861298569384052,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11585744392649509,
                                  -0.14439439757444497,
                                  0.017760356136112945,
                                  0.23019500198142478,
                                  0,
                                  0,
                                  -0.12081576804775643,
                                  -0.0015707696635245804,
                                  0.074245361355385092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1010736312914305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10941703873987738,
                                  0,
                                  -0.076425146607706398,
                                  0,
                                  0,
                                  -0.16823156648170118,
                                  -0.23581072222372079,
                                  0,
                                  -0.0032543074803119652,
                                  0,
                                  -0.11959706760306196,
                                  0.045408879401143028,
                                  0,
                                  0,
                                  0,
                                  0.091545000244179345,
                                  0.060595322522301168,
                                  -0.22724237679306741,
                                  0.038021959038373458,
                                  0,
                                  0.026716137392971257,
                                  0,
                                  0.081565075964671177,
                                  0.12408023328373094,
                                  0.11008111313602935,
                                  0,
                                  0,
                                  -0.0055527255459897904,
                                  0.15502760985957315,
                                  -0.062118743435428128,
                                  0.24609477406297178,
                                  0.10830362707098823,
                                  -0.0057189397528490185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.079376016194794535,
                                  0,
                                  0,
                                  0,
                                  -0.020264412847079361,
                                  0,
                                  -0.27493040382628769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027319771426714642,
                                  0,
                                  0,
                                  0,
                                  -0.11985413692330195,
                                  0,
                                  0,
                                  0.19594111402933653,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3549905080954559,
                                  0,
                                  0.16410063172817102,
                                  0,
                                  -0.29134353707779964,
                                  0.28709147843718602,
                                  0.28153318307605169,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27372125760828264,
                                  -0.13073207965657124,
                                  -0.15313416320785989,
                                  0.023076167011897991,
                                  0,
                                  0,
                                  -0.10420943030322402,
                                  0.030846725671611161,
                                  0.072183762338453278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24243192172313321,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.058555105766318845,
                                  0,
                                  -0.2778204032384694,
                                  0,
                                  0,
                                  0.089882690939130525,
                                  -0.0082330229297279608,
                                  0,
                                  -0.05973234417918049,
                                  0,
                                  -0.31816473524975375,
                                  -0.19595177790140972,
                                  0,
                                  0,
                                  0,
                                  0.084352562632312236,
                                  -0.01674381369240184,
                                  0.15429158667697848,
                                  -0.028440448349509102,
                                  0,
                                  -0.36380773969785019,
                                  0,
                                  -0.18036757517502444,
                                  0.32184621464068908,
                                  -0.087066189454180987,
                                  0,
                                  0,
                                  0.065480566193383896,
                                  0.042598235228896053,
                                  0.18039867963820891,
                                  -0.16713160692425766,
                                  -0.0010605813253137912,
                                  -0.18366005795316817,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.052033060948931086,
                                  0,
                                  0,
                                  0,
                                  0.099994955814511441,
                                  0,
                                  0.16915237612398162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.089388894327398369,
                                  0,
                                  0,
                                  0,
                                  0.22216978307374632,
                                  0,
                                  0,
                                  -0.027700550929959693,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054941348151535264,
                                  0,
                                  -0.079238871248866694,
                                  0,
                                  -0.17978852509611046,
                                  0.28246178088229207,
                                  0.065241081997295267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22157471247816135,
                                  -0.058627037576891999,
                                  -0.076285254147830175,
                                  -0.020635118609222694,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0084440797473592684,
                                  0.024046424855085447,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33363810470550692,
                                  0,
                                  -0.23658041121685006,
                                  0,
                                  0.065365832177662161,
                                  -0.18403668706811288,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17606878459182693,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27721904921353308,
                                  0,
                                  0,
                                  0,
                                  -0.11198459862000208,
                                  0.21655948155728127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.020009783765524782,
                                  0.17956662729354,
                                  0,
                                  0.22554151128974725,
                                  -0.12516014246711857,
                                  0,
                                  0.33798216923938795,
                                  0,
                                  0.015659781896393294,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064738974878708944,
                                  0,
                                  0,
                                  -0.13594306412697674,
                                  -0.29315427278270434,
                                  -0.014208329534440841,
                                  0,
                                  0.22132769638036864,
                                  0,
                                  0,
                                  0,
                                  -0.30613981132015899,
                                  0.035738123667746001,
                                  0,
                                  0,
                                  0.014381218786042026,
                                  0,
                                  -0.020958619686705753,
                                  0,
                                  0.045378441778888133,
                                  0,
                                  0,
                                  0,
                                  0.19678154485680022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18773104145194613,
                                  -0.24763542446158798,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14895110499209599};

const double rot_18_30[900] = {-0.090552871281998321,
                               0.018511783690401865,
                               0.21360106091526293,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.47270373248044401,
                               0,
                               0,
                               -0.14089952361295996,
                               -0.13164779849569613,
                               -0.62780163357032781,
                               -0.093772472642530164,
                               -0.31458587335679444,
                               0,
                               0,
                               0,
                               -0.086962831740534985,
                               0,
                               0,
                               0,
                               0.062943899045823481,
                               0,
                               0,
                               0,
                               0,
                               0.41446656421579642,
                               0,
                               0.057672095284138247,
                               0.18210376631707004,
                               0.30136476041958882,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32345736011922721,
                               0,
                               0,
                               -0.57070917746486893,
                               0.26550751135992134,
                               0.02892662262100508,
                               0.42519870564550566,
                               0.23828062634694125,
                               0,
                               0,
                               0,
                               0.25594433361968244,
                               0,
                               0,
                               0,
                               -0.1038570854022553,
                               0,
                               0,
                               0,
                               0,
                               -0.23908454462389636,
                               0,
                               -0.26457312600567034,
                               0.65522518174001632,
                               -0.020150395006577233,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40878964161119646,
                               0,
                               0,
                               0.39580047734420754,
                               0.037459651479714612,
                               0.26032145103711551,
                               0.062752447296038141,
                               -0.20038278185917363,
                               0,
                               0,
                               0,
                               -0.12955917214571633,
                               0,
                               0,
                               0,
                               0.11190768421095268,
                               0,
                               0,
                               0,
                               0,
                               -0.18422126287988402,
                               0,
                               0,
                               0,
                               0,
                               -0.33808483107571641,
                               -0.14996787472035125,
                               0,
                               0,
                               0.23936826645048889,
                               0,
                               0.18009162655654321,
                               0.612888319424574,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10215405336663642,
                               0,
                               0,
                               -0.49487356985328601,
                               0,
                               0,
                               0,
                               0.21171685148328645,
                               0,
                               0,
                               0,
                               0,
                               -0.3125487234999163,
                               0,
                               0,
                               0,
                               0.0090432504715189377,
                               0.30430472962373228,
                               0,
                               0,
                               0.46676497424566787,
                               0,
                               0.23825975733795521,
                               -0.48663319472328626,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.47468578924908739,
                               0,
                               0,
                               -0.33005261517272483,
                               0,
                               0,
                               0,
                               0.23069414454837622,
                               0,
                               0,
                               0,
                               0,
                               -0.091578469998986459,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.57808003969979438,
                               0.32297235880795883,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.46025832987066795,
                               0,
                               0.33706639723523552,
                               0,
                               0,
                               0.075424058432355501,
                               0.062869147398876571,
                               0,
                               0,
                               -0.26285329470751206,
                               0.21271957279651987,
                               -0.33478059578152308,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.069373157917095946,
                               -0.70111278688138967,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.072652263949321672,
                               0,
                               0.40955107974317345,
                               0,
                               0,
                               -0.21334706686646276,
                               -0.51446949743869452,
                               0,
                               0,
                               -0.030725967599951415,
                               0.066110768307253792,
                               -0.12291148501984508,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27000546554667593,
                               0.077211923371712066,
                               0,
                               0,
                               -0.11482372430781931,
                               0,
                               -0.16352612758796367,
                               -0.25036936662709292,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.56236337441312667,
                               0,
                               0,
                               -0.12123764767263896,
                               0,
                               0,
                               0,
                               0.67794164612786767,
                               0,
                               0,
                               0,
                               0,
                               -0.16724012079044911,
                               -0.19535413763508608,
                               0.18951966463274211,
                               -0.18883906740528894,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.054565131729926802,
                               0,
                               0,
                               -0.12049930963764494,
                               -0.22856940715358467,
                               -0.19629394833410185,
                               -0.15041009857410911,
                               0.458759931638269,
                               0,
                               0,
                               0,
                               0.25838311684716059,
                               0,
                               0,
                               0,
                               0.69324565509452407,
                               0,
                               0,
                               0,
                               0,
                               -0.039381378543015579,
                               0,
                               0,
                               0,
                               0,
                               -0.38374553631015296,
                               -0.36792200707464168,
                               0,
                               0,
                               -0.22115680570069274,
                               0,
                               -0.45363614344595299,
                               -0.14599455330719266,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44490276272396978,
                               0,
                               0,
                               0.17668194057040498,
                               0,
                               0,
                               0,
                               0.31069027656278808,
                               0,
                               0,
                               0,
                               0,
                               -0.34011592549419356,
                               0,
                               0,
                               0,
                               -0.21998831517775727,
                               0.61275949210336056,
                               0,
                               0,
                               0.23890327894988009,
                               0,
                               -0.15304153399812243,
                               0.10798821407707507,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16106503509444028,
                               0,
                               0,
                               0.45298324189675265,
                               0,
                               0,
                               0,
                               -0.11225341483603853,
                               0,
                               0,
                               0,
                               0,
                               -0.49013917585702843,
                               0.28028744552455703,
                               -0.054006303146350756,
                               -0.37314937590444358,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54404088213290158,
                               0,
                               0,
                               -0.063875743986100422,
                               -0.27500728520284412,
                               0.28617015544719748,
                               -0.22862199367601488,
                               0.3811664692361551,
                               0,
                               0,
                               0,
                               -0.028201509166370264,
                               0,
                               0,
                               0,
                               -0.2639941219605263,
                               0,
                               0,
                               0,
                               0,
                               0.23163492540536798,
                               0,
                               -0.24548030343194874,
                               0.10534448199596258,
                               0.18158557336120898,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19249635053889566,
                               0,
                               0,
                               0.11500223847562845,
                               -0.65938248364116303,
                               0.0061887917001617609,
                               0.51311746381805901,
                               0.18716098820080826,
                               0,
                               0,
                               0,
                               0.0090826551900225205,
                               0,
                               0,
                               0,
                               -0.26349298444565178,
                               0,
                               0,
                               0,
                               0,
                               0.20672422434148452,
                               0,
                               0.12537536167003402,
                               -0.34390798912755971,
                               -0.095669936049420645,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16471101343075997,
                               0,
                               0,
                               -0.026303924555638042,
                               0.0025936644902576078,
                               0.37536571768807753,
                               0.49227267369419625,
                               -0.25955349291582108,
                               0,
                               0,
                               0,
                               -0.07698652275916093,
                               0,
                               0,
                               0,
                               0.54201981742521788,
                               0,
                               0,
                               0,
                               0,
                               0.28056194576992832,
                               0,
                               -0.52580536811257594,
                               -0.40590885236068486,
                               -0.17431907309388067,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21367306079051643,
                               0,
                               0,
                               -0.16369860210274839,
                               -0.26678638601816224,
                               0.10571189553036235,
                               -0.11118581862985606,
                               -0.31012684778661825,
                               0,
                               0,
                               0,
                               0.28536504985230465,
                               0,
                               0,
                               0,
                               -0.10323107224839619,
                               0,
                               0,
                               0,
                               0,
                               -0.41586701648299407,
                               0,
                               0.21633464981853098,
                               -0.28676665096391463,
                               -0.10561174326708243,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23885907915684088,
                               0,
                               0,
                               0.39355552217086331,
                               -0.031749937198917104,
                               -0.43070357672020543,
                               0.31195604827363704,
                               0.22720936330201447,
                               0,
                               0,
                               0,
                               -0.24299470727674938,
                               0,
                               0,
                               0,
                               0.044788344679498361,
                               0,
                               0,
                               0,
                               0,
                               -0.50136217868734256,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.017517142755945622,
                               0.27289325052808783,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12169118615568128,
                               0,
                               0.17075185205901808,
                               0,
                               0,
                               -0.57687038949753078,
                               -0.12392407044539476,
                               0,
                               0,
                               -0.34032536173187733,
                               -0.069141910367829879,
                               0.64227634755943419,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15626500412205704,
                               0.042563405912713889,
                               0,
                               0,
                               0.38447103780617109,
                               0,
                               -0.099463316655891129,
                               0.26636890213791808,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.069088108871885032,
                               0,
                               0,
                               0.37329190659597339,
                               0,
                               0,
                               0,
                               0.47255671127111543,
                               0,
                               0,
                               0,
                               0,
                               0.61455384058747431,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.61750027492978077,
                               -0.027724589881370582,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39073203661693734,
                               0,
                               0.13537900908341566,
                               0,
                               0,
                               0.021774189294584911,
                               0.15819913276241132,
                               0,
                               0,
                               -0.40218644721815311,
                               -0.3959762837027937,
                               -0.32073902246386687,
                               0,
                               0,
                               0.5164596425482707,
                               0.14753300217652168,
                               0.29065376199340676,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.056586858486371697,
                               0,
                               0,
                               -0.21560531095418908,
                               -0.5238814464042556,
                               0.11167847423702108,
                               -0.19658279113024257,
                               -0.28248603926432547,
                               0,
                               0,
                               0,
                               -0.1191122289112935,
                               0,
                               0,
                               0,
                               0.16961699390512494,
                               0,
                               0,
                               0,
                               0,
                               -0.35918165810883967,
                               0,
                               0,
                               0,
                               0,
                               0.50237757983523235,
                               0.31080135642986439,
                               0,
                               0,
                               -0.38018987273388533,
                               0,
                               0.1024155677418547,
                               0.44652422040293077,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.46349746056317337,
                               0,
                               0,
                               0.055556673013937484,
                               0,
                               0,
                               0,
                               0.25569030852826513,
                               0,
                               0,
                               0,
                               0,
                               -0.11536092548321283,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20939553076449086,
                               -0.10961816516353719,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.63194886745648171,
                               0,
                               -0.46566171410207502,
                               0,
                               0,
                               -0.15926902319360031,
                               -0.12173809775996242,
                               0,
                               0,
                               0.39343926565783449,
                               -0.35973426518769963,
                               0.0595582319688523,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.37107859723680203,
                               -0.01793965643408546,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.43769171387573519,
                               0,
                               -0.27404266210953021,
                               0,
                               0,
                               -0.33070720552933691,
                               -0.022212578674802058,
                               0,
                               0,
                               -0.34884241816702288,
                               -0.48061274373337759,
                               -0.36436949619347747,
                               0,
                               0,
                               0.36469084087986836,
                               0.19521937422852675,
                               -0.35903392705455467,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.050550282721469067,
                               0,
                               0,
                               0.18422205360538066,
                               -0.030571395193818157,
                               -0.19608959364872314,
                               0.18888603036753079,
                               -0.29946719925690307,
                               0,
                               0,
                               0,
                               0.69695333442579321,
                               0,
                               0,
                               0,
                               -0.10390083142310609,
                               0,
                               0,
                               0,
                               0,
                               0.046988526602762648,
                               0,
                               0,
                               0,
                               0,
                               -0.57311391160853753,
                               0.32483878503837077,
                               0,
                               0,
                               -0.54858857163747243,
                               0,
                               0.42726643906122724,
                               -0.12628786070919801,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.053486811072555068,
                               0,
                               0,
                               -0.02048240611337375,
                               0,
                               0,
                               0,
                               0.15551431159601825,
                               0,
                               0,
                               0,
                               0,
                               0.19773842414580761,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19566671931860805,
                               0.035397251068448057,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11711341171553659,
                               0,
                               0.55453583042546217,
                               0,
                               0,
                               0.28173189738142107,
                               0.13280906631951608,
                               0,
                               0,
                               0.28634860848692067,
                               -0.63943157942572337,
                               0.22662005800571378,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.013453320378379985,
                               -0.23211294429504947,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.0069742741419025478,
                               0,
                               0.1796574490567639,
                               0,
                               0,
                               -0.53508582388521408,
                               0.71585527810038552,
                               0,
                               0,
                               0.28103096199962008,
                               0.13895758113603596,
                               -0.12870089624933406,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24369062830384164,
                               0.51129539285059622,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10347004359928205,
                               0,
                               0.19860384434915707,
                               0,
                               0,
                               -0.3392891103579363,
                               -0.38155455086991336,
                               0,
                               0,
                               0.46360473957212656,
                               -0.014920573969858584,
                               -0.39139418523476083,
                               0,
                               0,
                               0.052624883620650459,
                               -0.24919318831275217,
                               0.62545597175488388,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1822303712516056,
                               0,
                               0,
                               0.45072845376672049,
                               0.023173499450472167,
                               0.16821093941598914,
                               -0.20484187855079161,
                               0.16934369338841182,
                               0,
                               0,
                               0,
                               0.44290686663070533,
                               0,
                               0,
                               0,
                               0.083689987691507817,
                               0,
                               0,
                               0,
                               0,
                               0.070244125833303195,
                               0,
                               0,
                               0,
                               0,
                               -0.10861344219758026,
                               0.40518690202225122,
                               0,
                               0,
                               -0.11113935215248823,
                               0,
                               -0.67224439609446063,
                               0.074903022576155262,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.040510128120185736,
                               0,
                               0,
                               -0.50219877329148144,
                               0,
                               0,
                               0,
                               -0.14265326308109511,
                               0,
                               0,
                               0,
                               0,
                               0.28276689391053017};

const double rot_18_2[4] = {0.24437734154047186, 0.96968021272046889, 0.96968021272046789, -0.24437734154046775};

const double rot_19_50[2500] = {0.21137635991902917,
                                0,
                                0,
                                0,
                                0.27084122993328164,
                                0.024661801967379327,
                                0,
                                0,
                                0,
                                0.62886002933955831,
                                0.22755468714367855,
                                -0.33367849074279465,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44271554707315003,
                                0.047380404580515963,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42810267912455074,
                                0,
                                0,
                                -0.50302317293908283,
                                0,
                                0,
                                0.15396657729626984,
                                -0.79457080272765845,
                                0,
                                -0.10156478440037094,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61214280914829033,
                                0.0040573151704396682,
                                0,
                                0,
                                0,
                                -0.19581968050457038,
                                0.19135945335706961,
                                0.1507074161609902,
                                0,
                                0,
                                -0.76958214722503193,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.085670089275605932,
                                0,
                                0,
                                0,
                                -0.74346027286800553,
                                0.54524705826855424,
                                0,
                                0,
                                0,
                                0.013525581102945661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.05552487796786041,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17250091780785159,
                                0,
                                0.1126644599091236,
                                0.75361507479370826,
                                -0.22186973168242413,
                                0,
                                0,
                                -0.40011357335950737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26783452741056146,
                                0,
                                0,
                                0,
                                0.34423886017396144,
                                -0.39421249321678076,
                                0,
                                0,
                                0,
                                -0.25643403732372827,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.040566531132633331,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0039860197095425,
                                0,
                                -0.31478345777828609,
                                -0.66760332272043121,
                                0.86394657661304586,
                                0,
                                0,
                                -0.23968265894322136,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.067736376185168368,
                                0,
                                0,
                                0,
                                0.42294370902248396,
                                0.44899156766166554,
                                0,
                                0,
                                0,
                                -0.81089698767013796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10102185777905742,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32329013473078744,
                                -0.20995038414368408,
                                0,
                                0,
                                0,
                                -0.12246790824131634,
                                0.70025097334121811,
                                0,
                                0,
                                0,
                                -0.22101574526485723,
                                -0.55043782759465931,
                                0.273052237141517,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.78703639317904983,
                                0.76900854285935616,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17209422762602214,
                                0,
                                0,
                                -0.28395755873853235,
                                0,
                                0,
                                -0.00022369504934671366,
                                0.7169518173963173,
                                0,
                                0.52739309652390598,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.151263902047338,
                                -0.32342753303022531,
                                0,
                                0,
                                -0.13272025170890028,
                                0,
                                0,
                                0,
                                -0.2860788368518612,
                                -0.10954329032256654,
                                0,
                                0,
                                0,
                                -1.0401194985711164,
                                0.0055762128090403873,
                                0.17714327354597265,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21996923090525264,
                                -0.2298092733475878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4284899886503829,
                                0,
                                0,
                                -0.39836110516342971,
                                0,
                                0,
                                0.016592834772344127,
                                -0.80713995977492903,
                                0,
                                0.38200894043286687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18858849903401365,
                                -0.88794408441092421,
                                0,
                                0,
                                0,
                                0.056742391527213484,
                                0.13454290587268139,
                                -0.33797479601957076,
                                0,
                                0,
                                0.43382646955598131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0540194423160538,
                                0,
                                0,
                                0,
                                -0.088835652267351975,
                                0.05120347421717264,
                                0,
                                0,
                                0,
                                -0.033205425515430459,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40312809652968462,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70012140957452351,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3693458228579462,
                                0,
                                0,
                                0,
                                0,
                                0.12788273652221063,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.09572306374928985,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10767089646126553,
                                0,
                                0,
                                0.32010067846207946,
                                0,
                                0,
                                0.15925185545996895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53069069302195127,
                                0,
                                -0.10048504907393632,
                                0,
                                0.62563572500792686,
                                0,
                                0,
                                0,
                                0,
                                -0.12449187517916126,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28266565441174718,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20719273563595825,
                                -0.24180782945683554,
                                0.33769821614065987,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18803243362165545,
                                -0.59190542572501714,
                                0.16307534662696604,
                                0.25949779932649819,
                                0,
                                -0.2535193347657973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.070201457193600963,
                                0,
                                0,
                                0.092216201520870095,
                                0,
                                0,
                                0.32629230533781384,
                                0,
                                -0.1616061049410577,
                                0,
                                0.093939520258788725,
                                0.076859093520477373,
                                0,
                                0,
                                0,
                                0,
                                0.14207069577382178,
                                0,
                                0,
                                0,
                                0.75771520670139181,
                                0.0086736118383694966,
                                0,
                                0,
                                0,
                                -0.049277579697768248,
                                0.27248782014627498,
                                -0.22398481358894784,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30586410748759985,
                                0.094568612465279311,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.024509745282043624,
                                0,
                                0,
                                -0.10338528458607361,
                                0,
                                0,
                                -0.45572210870354718,
                                0.36456721024737498,
                                0,
                                -0.092889264443025699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3861276317659883,
                                -0.51188916583059207,
                                0,
                                0,
                                0.27961671195610399,
                                0,
                                0,
                                0,
                                0.12620963721266393,
                                0.15857160472087803,
                                0,
                                0,
                                0,
                                -0.23985230414120159,
                                0.052170010044549783,
                                -0.20780708067520864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068687814625174232,
                                -0.1676037517738099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19127220569121237,
                                0,
                                0,
                                0.54237353721219106,
                                0,
                                0,
                                0.94823406550255585,
                                0.248961607364826,
                                0,
                                -0.1853656422968816,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45488612866983585,
                                -0.055701776930012721,
                                0,
                                0,
                                -0.119983590644789,
                                0,
                                0,
                                0,
                                0.1665421637223492,
                                -0.88410388575072241,
                                0,
                                0,
                                0,
                                -0.2233110925449977,
                                -0.17941418722315514,
                                -0.04485760642171388,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35529338111045417,
                                0.024376556708400943,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40178877985832206,
                                0,
                                0,
                                -0.11388922402523416,
                                0,
                                0,
                                0.33667598951670574,
                                0.15330961356350947,
                                0,
                                0.80925860160342244,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68122712122888607,
                                0.44943071699280546,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19616741666256138,
                                0,
                                0,
                                0,
                                0,
                                0.092512329058936388,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13170203342191514,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44819653772328721,
                                0,
                                0,
                                -0.081188304267366035,
                                0,
                                0,
                                0.035498980198423215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.055333834644843621,
                                0,
                                0.56958195173074133,
                                0,
                                0.045101980213567074,
                                0,
                                0,
                                0,
                                0,
                                -0.63036728311310075,
                                0,
                                0,
                                -0.096082598752992271,
                                0.1540213225659281,
                                0.32381040422825136,
                                0,
                                0,
                                0.64033459212537858,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24354372334306951,
                                0,
                                0,
                                0,
                                -0.81626828822421105,
                                -0.51843324030350302,
                                0,
                                0,
                                0,
                                -0.39417943843843173,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74330115170294575,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69828621808725866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.075498956234693132,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25322375163723126,
                                -0.26621039859653883,
                                0.12901933604103352,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.044394000068430806,
                                0.22949788358873652,
                                0.2520883610742119,
                                0.12027833009211274,
                                0,
                                -0.05184502443513609,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28373221626905237,
                                0,
                                0,
                                0.67512558393813749,
                                0,
                                0,
                                -0.1413360965336441,
                                0,
                                0.2877511457772039,
                                0,
                                -0.045546223721245338,
                                0.25723655602976542,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.023112650541160996,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13278776700216366,
                                0.088029031191801277,
                                -0.04804646503089547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.096426996983541111,
                                -0.32998093985833937,
                                -0.37540689199229427,
                                -0.14004381347904993,
                                0,
                                -0.23213014706423415,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19074867141912658,
                                0,
                                0,
                                0.011504286918158958,
                                0,
                                0,
                                -0.55594597355246089,
                                0,
                                0.016549455876961272,
                                0,
                                0.14021369755494964,
                                0.52310223675311462,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.061271543140503648,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17638939616017335,
                                -0.088202231538520137,
                                -0.39065261201376544,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.029680756240679881,
                                0.090558833612410614,
                                -0.21258163433280827,
                                -0.059476687708098837,
                                0,
                                -0.64610323839471928,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.062344239007654609,
                                0,
                                0,
                                0.27902262549601486,
                                0,
                                0,
                                0.011940521192473526,
                                0,
                                0.10132400401798042,
                                0,
                                0.19952745147206163,
                                -0.44443564962939563,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54486929079573088,
                                -0.018599364270564134,
                                0.23623559348529574,
                                0,
                                0,
                                -0.3406628949589664,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18800376540919292,
                                0,
                                0,
                                0,
                                -0.28675111772133777,
                                -0.78257576192319533,
                                0,
                                0,
                                0,
                                -0.25421298920492785,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71029162778947708,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51986260237378434,
                                0,
                                -0.3929850597553895,
                                0.04367580114975269,
                                -0.76342559544077127,
                                0,
                                0,
                                -0.35200004073403018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28367016964391623,
                                0,
                                0,
                                0,
                                -0.032759345597927932,
                                -0.25371613812593913,
                                0,
                                0,
                                0,
                                -0.69989586919563218,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.06142436335277375,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13358824896882826,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.017386683368938095,
                                0,
                                0,
                                0,
                                0,
                                -0.66190312077529545,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20190519739570661,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.015447170609279595,
                                0,
                                0,
                                0.23295575880257846,
                                0,
                                0,
                                0.062327899675600845,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.022323162190623622,
                                0,
                                -0.43794741091424988,
                                0,
                                -0.19114938816685034,
                                0,
                                0,
                                0,
                                0,
                                -0.48331163714897629,
                                0,
                                0.31546982273094237,
                                0,
                                0,
                                0,
                                0.42863783620859597,
                                0.14025422256100084,
                                0,
                                0,
                                0,
                                0.61731598304752167,
                                0.032218569436565814,
                                0.63240630707583323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17442158313360034,
                                -0.18471554093382805,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57621411669498446,
                                0,
                                0,
                                0.33696427718768335,
                                0,
                                0,
                                0.0040869476732423721,
                                -0.38855630900994137,
                                0,
                                0.56988081331262186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40801406328864298,
                                -0.84768061587674082,
                                0,
                                0,
                                -0.8847236265347499,
                                0,
                                0,
                                0,
                                0.53119818971496802,
                                0.34908234457023313,
                                0,
                                0,
                                0,
                                -0.49022242188213133,
                                0.29281610999189323,
                                0.32290893302923007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50042817493628389,
                                -0.45991469870651985,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48676134231697665,
                                0,
                                0,
                                0.35968506192784866,
                                0,
                                0,
                                -0.12981634283513258,
                                0.099535176705532108,
                                0,
                                -0.33768301334675832,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21502373438762545,
                                0.14483694339335001,
                                0,
                                0,
                                0,
                                -0.87350790743710438,
                                0.60549045334788221,
                                0.55744056627312155,
                                0,
                                0,
                                -0.30751292600682811,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40103637980768969,
                                0,
                                0,
                                0,
                                0.2780936995759466,
                                -0.65713525304344966,
                                0,
                                0,
                                0,
                                0.76774247500801041,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27282688985927361,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37621720813641307,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.023209923687978459,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.046789097814706568,
                                -0.28872369536663806,
                                -0.48060039684594352,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61904902019069152,
                                0.12395679361690173,
                                0.28852583015650701,
                                -0.20028958193192742,
                                0,
                                0.07259047508993785,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.03935802813581344,
                                0,
                                0,
                                -0.18269527635152885,
                                0,
                                0,
                                0.13555070068973107,
                                0,
                                -0.0086329433649847929,
                                0,
                                0.20403625500932621,
                                0.24639117210666953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12276228878528614,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44338075358665552,
                                -0.14560764436188306,
                                0.079482029951302588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2918816133899288,
                                -0.083919343392607385,
                                0.086718378616742489,
                                -0.12280861500575838,
                                0,
                                0.15609742399848231,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11014135124057663,
                                0,
                                0,
                                0.064573408565875123,
                                0,
                                0,
                                -0.49027371007500908,
                                0,
                                0.11449363370948992,
                                0,
                                -0.51288626560855421,
                                -0.29797300306025326,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12916569621236532,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60061319392626045,
                                -0.18508070519469391,
                                0.20945445820084804,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13907584694867034,
                                0.29472430218546414,
                                -0.19843449376655203,
                                0.07062724394261051,
                                0,
                                0.1846934638021657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20705221006410165,
                                0,
                                0,
                                -0.077908328637179253,
                                0,
                                0,
                                -0.14129871140768421,
                                0,
                                0.045787582210452323,
                                0,
                                0.51458983673529346,
                                0.15481758868249007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41888973403193946,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16055884867114043,
                                -0.36188162066717655,
                                0.40599088972523034,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24412191306493852,
                                0.0092139796608986801,
                                -0.35163748526811162,
                                -0.12318450457148591,
                                0,
                                -0.1362233300585817,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.069339095914261573,
                                0,
                                0,
                                -0.24606391837932531,
                                0,
                                0,
                                0.15429054693553781,
                                0,
                                0.42599071681549455,
                                0,
                                -0.037192386905886346,
                                -0.11786641894336067,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64274860820077095,
                                0,
                                0,
                                0,
                                0,
                                -0.20323465565244636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24348030116753588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29923925550893943,
                                0,
                                0,
                                0.0021097362734135029,
                                0,
                                0,
                                -0.14415111489111024,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12979685866043808,
                                0,
                                0.51192262848326353,
                                0,
                                -0.31018569187402389,
                                0,
                                0,
                                0,
                                0,
                                0.028843576016698087,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33327747837916799,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36297989594375607,
                                0.017739954658996419,
                                0.18664929920628801,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10334313494178081,
                                -0.012207301366314345,
                                0.27260354719155983,
                                -0.081153009178194777,
                                0,
                                -0.15665627277169222,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37016942246856943,
                                0,
                                0,
                                -0.35450385174518495,
                                0,
                                0,
                                -0.37350393169984436,
                                0,
                                -0.079232738407456399,
                                0,
                                0.28274661958650854,
                                -0.34252516597186083,
                                0,
                                0,
                                0,
                                0,
                                -1.0186964437591948,
                                0,
                                0,
                                0,
                                0.3229466299790314,
                                -0.70914629378879956,
                                0,
                                0,
                                0,
                                0.26499315592238359,
                                -0.10784467854685688,
                                -0.18669045867435913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11972074951868095,
                                0.16538420781889229,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2830872657436968,
                                0,
                                0,
                                0.11307142401744269,
                                0,
                                0,
                                0.38605474850052074,
                                0.083984651801250726,
                                0,
                                -0.32470176853851507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23424937911857258,
                                -0.2943791998814822,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.045241188977459747,
                                0,
                                0,
                                0,
                                0,
                                0.44847938291255007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1847325764502887,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27891066147989946,
                                0,
                                0,
                                0.16500287137324293,
                                0,
                                0,
                                -0.53023002444178791,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2847452618777076,
                                0,
                                -0.29343013906105148,
                                0,
                                -0.44962829160926104,
                                0,
                                0,
                                0,
                                0,
                                -0.084768262725848975,
                                0,
                                0,
                                -0.53038316735675839,
                                -0.82722930164509612,
                                -0.40484490929798145,
                                0,
                                0,
                                -0.73751651341745217,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44882175852349437,
                                0,
                                0,
                                0,
                                -0.16071416967172972,
                                -0.55375238195181642,
                                0,
                                0,
                                0,
                                0.30564919066287499,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35641119282008327,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54664613660579453,
                                -0.017547110877631042,
                                0,
                                0,
                                0,
                                0.23810613583195886,
                                -0.22429265409364366,
                                0,
                                0,
                                0,
                                -0.2271279147555619,
                                0.38276715518261145,
                                0.14129326448719817,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28570510123159126,
                                -0.44060409352639501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32206020349023368,
                                0,
                                0,
                                -0.51748216826429128,
                                0,
                                0,
                                0.26611411075983471,
                                0.55949820214279866,
                                0,
                                -0.52520496662074156,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6154382297343346,
                                -0.0346277215715503,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26253964847643796,
                                0,
                                0,
                                0,
                                0,
                                0.48630366911601264,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2792806776592503,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3685075909654833,
                                0,
                                0,
                                -0.21810200682791273,
                                0,
                                0,
                                0.2288442631703505,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40198681932355479,
                                0,
                                -0.27097734935107753,
                                0,
                                0.041559113292600515,
                                0,
                                0,
                                0,
                                0,
                                -0.37960329823641276,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35398900310767373,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28219368128944944,
                                0.58408721338663283,
                                0.026453151325216251,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28565754675638277,
                                -0.012252276315524072,
                                0.18551368687139974,
                                0.29532238786351811,
                                0,
                                -0.27914179464063976,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35425550883005608,
                                0,
                                0,
                                -0.060073174667125688,
                                0,
                                0,
                                -0.03941146802618424,
                                0,
                                0.16493680124755553,
                                0,
                                -0.036804654024291429,
                                0.11261433584005666,
                                0,
                                0,
                                0,
                                0,
                                0.13432147801032904,
                                0,
                                0,
                                0,
                                0.14252846020052143,
                                0.12174231898685423,
                                0,
                                0,
                                0,
                                -0.13850137017455424,
                                -1.2387474893808879,
                                -0.29705761031424871,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.076806889598182937,
                                -0.77566716256232449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.035246084488640597,
                                0,
                                0,
                                -0.22232586237392554,
                                0,
                                0,
                                -0.17068116789458387,
                                0.26954080575126432,
                                0,
                                -0.02555699396269432,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.057991452175798069,
                                -0.028315301054525926,
                                0,
                                0,
                                0.31158338978392347,
                                0,
                                0,
                                0,
                                0.50723924093371497,
                                -0.34348193794619963,
                                0,
                                0,
                                0,
                                -0.23371017655880461,
                                -0.15275949928479671,
                                1.0185856122730959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43079725984048622,
                                -0.073267188310134776,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71692085764332247,
                                0,
                                0,
                                0.10337440979239426,
                                0,
                                0,
                                -0.42887578378763141,
                                -0.41389475722049868,
                                0,
                                -0.32552194479836888,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22412596799735188,
                                0.59838650972608765,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.086579981513815296,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.041425958700394686,
                                0.23559198649180846,
                                0.39662098846491284,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.011697328948477383,
                                0.2336753409458123,
                                0.39330502084537688,
                                -0.29700471271402845,
                                0,
                                -0.13728045547705053,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61235168194758927,
                                0,
                                0,
                                0.087753606207114435,
                                0,
                                0,
                                -0.011009854885435891,
                                0,
                                0.10946506471960016,
                                0,
                                0.25803193978832761,
                                -0.011352197919794018,
                                0,
                                0,
                                0,
                                0,
                                -0.094163907296001853,
                                0,
                                0,
                                0,
                                0.45426952868683196,
                                0.72426692158463379,
                                0,
                                0,
                                0,
                                0.3717895455991066,
                                0.36890651230283494,
                                0.0089161150401915606,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18395842085378433,
                                -0.4472183568377911,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63208908168305222,
                                0,
                                0,
                                -0.49214540637137028,
                                0,
                                0,
                                0.55780522076594941,
                                0.18770000074429277,
                                0,
                                0.48490838538640252,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.033593958858353049,
                                0.22121266205824353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44830376573624253,
                                0,
                                0,
                                0,
                                0,
                                0.0562310366778878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1854975332001999,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56424560161075632,
                                0,
                                0,
                                0.28344815156542169,
                                0,
                                0,
                                0.3325349660699079,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42125490605701665,
                                0,
                                -0.046896848673792749,
                                0,
                                -0.18601090275781176,
                                0,
                                0,
                                0,
                                0,
                                0.194684220875775,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14864044318923486,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.081312132670664242,
                                -0.16338502083088585,
                                -0.1424642310515167,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13007232202581573,
                                0.16688883897721654,
                                0.11631452169041306,
                                0.6633183605469799,
                                0,
                                -0.1077675954659732,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3640378476751005,
                                0,
                                0,
                                -0.35892850382774344,
                                0,
                                0,
                                -0.13879510937698242,
                                0,
                                0.35074200571619113,
                                0,
                                -0.078881969084028725,
                                0.067373159352015849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10954646711059887,
                                0,
                                0,
                                0,
                                0,
                                0.10999397144282913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76288264357825786,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18351030776369698,
                                0,
                                0,
                                -0.06406725920432238,
                                0,
                                0,
                                0.20843008811910516,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31296470489130934,
                                0,
                                -0.019423008924219942,
                                0,
                                -0.29819189219824549,
                                0,
                                0,
                                0,
                                0,
                                -0.35418167254942373,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1775345753567576,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.020926004263173068,
                                0.19142994599621557,
                                -0.19377508423099671,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13363431387996239,
                                -0.43089165096654042,
                                0.08035498842706329,
                                -0.17501295926443952,
                                0,
                                0.30746044907677328,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.047305251158950248,
                                0,
                                0,
                                0.039382895928710658,
                                0,
                                0,
                                0.11232838664289622,
                                0,
                                0.6962309758512002,
                                0,
                                0.21921677618472396,
                                -0.097494638029019018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.01254823439234105,
                                0,
                                0,
                                0,
                                0,
                                -0.05181206098859667,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28992618733849873,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26681541174631251,
                                0,
                                0,
                                -0.59710368375208811,
                                0,
                                0,
                                0.47249348635717492,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40252261187017485,
                                0,
                                -0.13446266991146022,
                                0,
                                -0.23128591508808419,
                                0,
                                0,
                                0,
                                0,
                                0.16890723227513321,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21130332513029648,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19131212270929507,
                                0.28332025608441225,
                                0.086349363228895359,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52249783210185996,
                                0.12963964032074093,
                                -0.39193384467779946,
                                0.31737841713510956,
                                0,
                                0.31140334860099422,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18020420581591379,
                                0,
                                0,
                                0.24188836462780144,
                                0,
                                0,
                                0.051817214429468364,
                                0,
                                -0.038676762465463241,
                                0,
                                0.19576504009002638,
                                -0.23751195433362399,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60017512879510859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.046458037951502038,
                                0.21158804418178651,
                                0.10126747259643316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.070298719272282303,
                                0.29207203490473865,
                                -0.18146407467504511,
                                -0.25752864116070268,
                                0,
                                -0.23447154572775389,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.090583547925617999,
                                0,
                                0,
                                -0.16636726939420327,
                                0,
                                0,
                                0.2933927325536233,
                                0,
                                0.17051803248364386,
                                0,
                                -0.34391526328001776,
                                0.26232596639960692,
                                0,
                                0,
                                0,
                                0,
                                -0.35731687777086074,
                                0,
                                0,
                                0,
                                -0.58017465145112479,
                                -0.43101051512344918,
                                0,
                                0,
                                0,
                                0.29369647199129423,
                                0.54300605007268343,
                                0.30411905307616838,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27091499318286588,
                                -0.64632540380436243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45346437710812193,
                                0,
                                0,
                                -0.019643435830353169,
                                0,
                                0,
                                -0.37485087302324743,
                                0.32573130307133541,
                                0,
                                0.16473352395333341,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30250149673021454,
                                -0.44529997887366918,
                                0,
                                0,
                                -0.039119102784976927,
                                0,
                                0,
                                0,
                                0.22402298691543771,
                                -0.39438785194449222,
                                0,
                                0,
                                0,
                                0.024017541773543302,
                                0.32208151399317342,
                                -0.81344564547363141,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40904017554473898,
                                -0.29736232396367729,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18064562954048571,
                                0,
                                0,
                                0.29069932415461819,
                                0,
                                0,
                                -0.28728960705098439,
                                -0.044392819485299224,
                                0,
                                0.6546924462957473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47743976409220024,
                                0.040385886967713142,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35716376139863526,
                                0,
                                0,
                                0,
                                0,
                                0.20024310156557307,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24670432738447939,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24681064986422996,
                                0,
                                0,
                                0.56647724396481969,
                                0,
                                0,
                                0.48777872277004519,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13364013046911641,
                                0,
                                0.17728422161561475,
                                0,
                                -0.3047754966953285,
                                0,
                                0,
                                0,
                                0,
                                0.097755779234002901,
                                0,
                                0,
                                0.66101374083536568,
                                -0.53475160880755146,
                                0.45315766678793962,
                                0,
                                0,
                                -0.56918886073513353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36361492734514816,
                                0,
                                0,
                                0,
                                -0.06195140072679798,
                                0.018629568998154915,
                                0,
                                0,
                                0,
                                0.33620516291036207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.80547976149640033,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48517210957016338};

const double rot_19_20[400] = {0.48553238148525657,
                               0,
                               -0.3675607777866618,
                               0,
                               0.12073777598934823,
                               0,
                               0.77768689378370992,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.52196591491959143,
                               0,
                               0,
                               -0.2683010185882343,
                               0,
                               0.62072709006324933,
                               0,
                               -0.30527420031540881,
                               0,
                               0,
                               0,
                               0,
                               0.55575307940652729,
                               -0.40764863210955538,
                               0,
                               0,
                               0.07823188112949539,
                               0,
                               0,
                               -0.20086418926159461,
                               0,
                               0,
                               0,
                               0,
                               -0.48505556785910819,
                               0,
                               0.50264324290196338,
                               0,
                               0.87845576105817946,
                               0,
                               0.33505808124957215,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15829726268350994,
                               0,
                               0,
                               0.13963127441954454,
                               0,
                               -0.416375504223785,
                               0,
                               -0.65633733497389324,
                               0,
                               0,
                               0,
                               0,
                               0.31318518336895951,
                               0.30425445461743,
                               0,
                               0,
                               -0.40707530620016996,
                               0,
                               0,
                               -0.19871261924546002,
                               0,
                               0,
                               0,
                               0,
                               -0.065455224310775065,
                               0,
                               -0.22519766964258425,
                               0,
                               0.26631737769003971,
                               0,
                               -0.046779795322004492,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39795608597780102,
                               0,
                               0,
                               -1.103706108790717,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39070143665529011,
                               0,
                               -0.63572137515075522,
                               0,
                               0,
                               0.56066948827280982,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35897137140979812,
                               0,
                               0,
                               -0.47848298242220078,
                               0,
                               -0.73910071114251474,
                               0,
                               -0.20338108882365818,
                               0,
                               0.65202308575416223,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.49726400769636281,
                               0,
                               0,
                               0.043697203239142723,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3092192060123809,
                               0,
                               0.14926362854813824,
                               0,
                               0,
                               -0.20246802179630577,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.91712079464790652,
                               0,
                               0,
                               0,
                               -0.4926835516892108,
                               0,
                               -0.14097405142682107,
                               0,
                               0,
                               0,
                               0,
                               0.31963188773538731,
                               -0.40518875227809675,
                               0,
                               0,
                               0.40317075676436315,
                               0,
                               0,
                               0.55542785938345896,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.002483454793515763,
                               0,
                               -0.51625051738074346,
                               0,
                               0,
                               0,
                               0,
                               -0.68306569290552033,
                               -0.5076832793836934,
                               0,
                               0,
                               -0.024970024985887032,
                               0,
                               0,
                               -0.092383335176454695,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.86049640833800134,
                               0,
                               0.25422221941372053,
                               0,
                               0,
                               -0.41236179521757321,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15771729213596655,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13342377124242666,
                               0,
                               0.12098629408025841,
                               0.58376874838396775,
                               0,
                               0,
                               0,
                               -1.0399158677508704,
                               0,
                               0,
                               -0.079367850326718115,
                               0,
                               0.32097773442522354,
                               0,
                               0,
                               0,
                               0,
                               0.10527769848744811,
                               -0.46296694583384446,
                               0,
                               0,
                               -0.79349614948646729,
                               0,
                               0,
                               0.1887223154647743,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21871648872272706,
                               0,
                               0.86253319571738918,
                               0.4124997451978234,
                               0,
                               0,
                               0,
                               0.984872780499912,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.4514537387335116,
                               0,
                               -0.53818959010511702,
                               1.1686152814802977,
                               0,
                               0,
                               0,
                               0.42546673137864394,
                               0,
                               0,
                               -0.43850520387528857,
                               0,
                               0.29430253052399669,
                               0,
                               0,
                               0,
                               0,
                               0.11500816217866003,
                               -0.32402652593804426,
                               0,
                               0,
                               0.18805097008360053,
                               0,
                               0,
                               -0.75333655989397597,
                               0,
                               0,
                               0,
                               0,
                               -0.75393912713515487,
                               0,
                               0.098845041049553009,
                               0,
                               -0.64298102834368831,
                               0,
                               0.14870974679697849,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56885121357234514,
                               0,
                               0,
                               -0.36730804086261076,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10621582399042628,
                               0,
                               -0.71340715270134247,
                               0,
                               0,
                               -0.68892247380582428,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.071793163280779088,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1377107432636477,
                               0,
                               -1.0303216012075991,
                               0.78234622028535639,
                               0,
                               0,
                               0,
                               0.6970515033715452,
                               0,
                               0.61282295822267907,
                               0,
                               1.4151573268262891,
                               0,
                               -0.25607653684597426,
                               0,
                               0.22391183076514787,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.77013556104956815,
                               0,
                               0,
                               0.27697160749810129};

const double rot_19_10[100] = {0.39452296950286653,
                               0,
                               0,
                               0,
                               1.9496861974858946,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20752034752930326,
                               0,
                               0,
                               0,
                               -0.15604389260206433,
                               0,
                               0,
                               0,
                               -0.96570472140448449,
                               0,
                               0,
                               0.96206793936816426,
                               -0.55151900169602053,
                               0,
                               0,
                               -0.42179959257762134,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.029382945118536785,
                               -0.9787915909038547,
                               0,
                               0,
                               0.56253076529956048,
                               0,
                               0,
                               0,
                               -1.0210388436838835,
                               0,
                               0,
                               0,
                               0.023559235053632194,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.97770015731226012,
                               0,
                               0,
                               0,
                               0.065593634471103029,
                               0,
                               0,
                               0,
                               0.19949906643504189,
                               0,
                               0,
                               -1.3707725948737182,
                               -0.098368583556364367,
                               0,
                               0,
                               -1.3016237523020897,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.7896666982162861,
                               -0.61353606717795284,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.6135360671779525,
                               -0.78966669821628555,
                               0,
                               0,
                               -0.032213471605823198,
                               0,
                               0,
                               0,
                               0.98556977363272802,
                               0,
                               0,
                               0,
                               -0.16617615216580958};

const double rot_19_100[10000] = {0.15158730638872434,
                                  0,
                                  0,
                                  0.12931834805802422,
                                  0,
                                  0,
                                  0.064891301160380999,
                                  0,
                                  0,
                                  0,
                                  -0.24509889387677494,
                                  0,
                                  0,
                                  -0.013684207946433699,
                                  0,
                                  0.018788767560874588,
                                  0,
                                  -0.39621050716264317,
                                  -0.16024836111573454,
                                  0,
                                  0,
                                  0.12881379356810774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41006080668211553,
                                  0,
                                  0,
                                  -0.051286152351267836,
                                  -0.075434261170268441,
                                  0,
                                  0,
                                  -0.27572671081943917,
                                  0,
                                  0,
                                  0.2116274988747926,
                                  -0.18769281532588605,
                                  0,
                                  0.044808091736439452,
                                  0,
                                  0,
                                  -0.15717813168961284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10990313876503807,
                                  -0.039101509387671644,
                                  0,
                                  0,
                                  0,
                                  -0.34838304067467568,
                                  0,
                                  0,
                                  -0.35142987650999868,
                                  0,
                                  0.075939661389876997,
                                  0.014018239491512511,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14497399212593096,
                                  0.057365252479044337,
                                  0,
                                  0.047991592216956501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094677306012437817,
                                  0,
                                  0,
                                  -0.10500592274688142,
                                  -0.039459602982511124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1561785444187854,
                                  0,
                                  0,
                                  0,
                                  -0.27067444992492756,
                                  0,
                                  0,
                                  0.071477747458559032,
                                  0.10123050487880826,
                                  0,
                                  -0.15021092596322619,
                                  0.26547394028548266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.013429255512752232,
                                  0,
                                  0,
                                  -0.088960842449965258,
                                  0,
                                  0,
                                  0.28975292616473702,
                                  0,
                                  0,
                                  -0.50980129029369115,
                                  0.17274357384241479,
                                  0,
                                  0.058811530612924261,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26404210854611648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.020013566632405586,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0077129276207084903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19164673163108439,
                                  0,
                                  0.1187062914164727,
                                  0,
                                  -0.022723818727569251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26323711924122695,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48748043019687176,
                                  0,
                                  0,
                                  0,
                                  -0.068161950600241716,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11825727684401723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56161479749811971,
                                  0,
                                  0.22934527509652228,
                                  -0.1693418478703346,
                                  0.37218384410887484,
                                  0,
                                  -0.33445410352695676,
                                  0,
                                  0,
                                  0.020327591822556512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28413228650201272,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24102647769326407,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33286668154043614,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12152428447339582,
                                  0,
                                  0,
                                  0,
                                  -0.16598247015903486,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60391708119461796,
                                  0,
                                  0,
                                  0.46302057747192843,
                                  0.33101755487578743,
                                  0,
                                  0,
                                  0.1695315544841523,
                                  0,
                                  0.25779311130808236,
                                  0.049427806717060707,
                                  0,
                                  -0.16863077287040504,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32927243748474994,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056327389800375043,
                                  0,
                                  0,
                                  -0.26824026240611309,
                                  0,
                                  0,
                                  0.26526713328573881,
                                  0,
                                  0,
                                  0,
                                  -0.055754999828793742,
                                  0,
                                  0,
                                  0.044340020681388752,
                                  0,
                                  -0.19705741054131912,
                                  0,
                                  -0.079513863226242529,
                                  -0.1804381490781973,
                                  0,
                                  0,
                                  -0.045062437484252441,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38655454408861978,
                                  0,
                                  0,
                                  -0.045167455557766328,
                                  -0.12347616004845535,
                                  0,
                                  0,
                                  0.076161229046657009,
                                  0,
                                  0,
                                  0.30620926939708104,
                                  0.34763489414527493,
                                  0,
                                  0.28515068875201821,
                                  0,
                                  0,
                                  0.015891301751102514,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1601783906470112,
                                  -0.047969125993162304,
                                  0,
                                  0,
                                  0,
                                  -0.34153176460717116,
                                  0,
                                  0,
                                  0.081527052928554014,
                                  0,
                                  0.13970081839924775,
                                  0.03376501855298629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22714974091968948,
                                  0.18349852922637874,
                                  0,
                                  -0.073824048990883198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17322981224994349,
                                  0,
                                  0,
                                  -0.050969417280910839,
                                  0.065619680157286059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.038277979840693935,
                                  0,
                                  0,
                                  0,
                                  0.24891272421137878,
                                  0,
                                  0,
                                  0.062617272227734042,
                                  -0.39193926044325,
                                  0,
                                  0.22267370880420417,
                                  0.08827438131261392,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20172016666515577,
                                  0,
                                  0,
                                  0.18813087688160612,
                                  0,
                                  0,
                                  -0.20837125059299308,
                                  0,
                                  0,
                                  -0.16613689575761237,
                                  -0.18493192789591953,
                                  0,
                                  0.25810019650835631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17225043367270579,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.032175379409325633,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.078419929228949678,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28069196013818037,
                                  0,
                                  0.069279756341010051,
                                  0,
                                  -0.19565717914805425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54465980484921361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11688090241743057,
                                  0,
                                  0,
                                  0,
                                  -0.078545404183862966,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27563854650264147,
                                  0,
                                  0,
                                  -0.046774496130419813,
                                  0.44960113377048277,
                                  0,
                                  -0.0049786335644395842,
                                  -0.28723583199349267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34788411694616078,
                                  0,
                                  0,
                                  0.016862729709615831,
                                  0,
                                  0,
                                  -0.25197277015161207,
                                  0,
                                  0,
                                  -0.033946721539228543,
                                  -0.083903983096459911,
                                  0,
                                  0.0033888459168406001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16562231214305329,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.066289390302104526,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11397348508285027,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025706215706523799,
                                  0,
                                  -0.27812133601587713,
                                  0,
                                  -0.13404240844545154,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27564142288093463,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24834138805172223,
                                  0,
                                  0,
                                  0,
                                  0.407083697276579,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082112681768779533,
                                  0,
                                  0,
                                  -0.14002948116588165,
                                  0,
                                  0,
                                  -0.19531623886865523,
                                  0,
                                  0,
                                  0,
                                  0.084644889000492343,
                                  0,
                                  0,
                                  0.20156471404927001,
                                  0,
                                  0.094391592371946192,
                                  0,
                                  -0.0058727194181522066,
                                  0.0028691516269505053,
                                  0,
                                  0,
                                  -0.084346239632207679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11933534156630471,
                                  0,
                                  0,
                                  0.2937510728028549,
                                  0.26877006382193075,
                                  0,
                                  0,
                                  0.071535087958582766,
                                  0,
                                  0,
                                  -0.090081341765746129,
                                  0.20729147328496858,
                                  0,
                                  -0.073513186103590825,
                                  0,
                                  0,
                                  0.15673390898228992,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0059728526656559547,
                                  0.0014036941488936464,
                                  0,
                                  0,
                                  0,
                                  -0.41141683530733431,
                                  0,
                                  0,
                                  0.013184712084949902,
                                  0,
                                  -0.11450914166971642,
                                  0.32124784971163167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019329078105120176,
                                  0.19800182266570399,
                                  0,
                                  0.25572617487380028,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28102391397311932,
                                  0,
                                  0,
                                  -0.047692737712181923,
                                  -0.36584542372014889,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082750599027029151,
                                  0,
                                  0,
                                  0,
                                  -0.35554415145206419,
                                  0,
                                  0,
                                  0.031269457573399481,
                                  0.24376853506697357,
                                  0,
                                  0.24972181065963178,
                                  -0.32671736646954774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.016458607849232879,
                                  0,
                                  0,
                                  -0.13055014167525897,
                                  0,
                                  0,
                                  -0.36314191844473037,
                                  0,
                                  0,
                                  -0.031012108519441424,
                                  -0.03063896855126963,
                                  0,
                                  0.12078125202037995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19078203869491817,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079842818873381433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.00017501039028365584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29657550833516311,
                                  0,
                                  -0.045743715501716457,
                                  0,
                                  -0.19601927841444317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053403469707289347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.037348336597095799,
                                  0,
                                  0,
                                  0,
                                  -0.55037693765125328,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31208899749295937,
                                  0,
                                  0,
                                  -0.10813924995143059,
                                  0.025675751752404635,
                                  0,
                                  -0.15470787785901033,
                                  0.1685416779418924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1381920522438928,
                                  0,
                                  0,
                                  -0.0015484841423002299,
                                  0,
                                  0,
                                  -0.11068552447143712,
                                  0,
                                  0,
                                  0.55312309528152837,
                                  -0.25642215809456154,
                                  0,
                                  -0.28637805728765586,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.091622910415814954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27440591236131379,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040280058617735315,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.074451173206040305,
                                  0,
                                  0.22378922985432234,
                                  0,
                                  -0.29583931940427949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11451709409381246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33078429772160639,
                                  0,
                                  0,
                                  0,
                                  0.043034056349437036,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16802555690531507,
                                  0,
                                  -0.19054194046850281,
                                  -0.18035566836543271,
                                  0,
                                  -0.022301450469477874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.066252388834969922,
                                  0,
                                  0,
                                  0.38816677555458606,
                                  -0.26299942860229769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.015145544820324285,
                                  0,
                                  0,
                                  0.56122480564270327,
                                  0,
                                  0.21417488156013545,
                                  0,
                                  -0.55978896072197837,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34405703024434831,
                                  0,
                                  0,
                                  -0.37243029445762132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30891238370673035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32755170928206928,
                                  0.19934314119095142,
                                  0.081049274766015991,
                                  -0.20562125075994805,
                                  0,
                                  0,
                                  0,
                                  -0.097839815005593397,
                                  -0.40010904759501886,
                                  0,
                                  0,
                                  -0.37594083312278637,
                                  0,
                                  -0.33659125975367576,
                                  0,
                                  0,
                                  -0.39774308817583937,
                                  0,
                                  0,
                                  -0.22947184650366356,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24038135786259235,
                                  0,
                                  0,
                                  -0.030999426366571839,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.093472295893631069,
                                  -0.10508070158479677,
                                  0,
                                  -0.58495249222741796,
                                  -0.25267542098247603,
                                  -0.28711753500562803,
                                  0,
                                  0,
                                  -0.14603553787936266,
                                  0,
                                  0,
                                  -0.15109176643861227,
                                  0,
                                  0,
                                  0,
                                  0.094266524666781176,
                                  0,
                                  0,
                                  0.16912730497741443,
                                  0,
                                  -0.38054543462442419,
                                  0,
                                  0.21770322362255179,
                                  0.083875414163928713,
                                  0,
                                  0,
                                  -0.22056003005268646,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1306422372815573,
                                  0,
                                  0,
                                  0.0040998873808795163,
                                  0.0067011990587221397,
                                  0,
                                  0,
                                  -0.2242877789093303,
                                  0,
                                  0,
                                  0.09747553945733714,
                                  -0.057496372239679322,
                                  0,
                                  -0.24871334119174493,
                                  0,
                                  0,
                                  -0.17069441652343653,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11396810376381142,
                                  -0.13349205626416086,
                                  0,
                                  0,
                                  0,
                                  -0.038347388210375789,
                                  0,
                                  0,
                                  0.060556665250141077,
                                  0,
                                  -0.043173583237884547,
                                  -0.071336596273566116,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0076821206091766871,
                                  -0.025075597756719019,
                                  0,
                                  0.33835549591491731,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39273975217917101,
                                  0,
                                  0,
                                  -0.051283132939728276,
                                  0.17803772518453392,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26485282631804058,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.023604198203628288,
                                  0,
                                  0.084224882693170217,
                                  -0.33871731024163976,
                                  0,
                                  -0.071194299715119341,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.025444454930445594,
                                  0,
                                  0,
                                  -0.19343539276712193,
                                  -0.43895137862102745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015720009483019895,
                                  0,
                                  0,
                                  0.056195067760788489,
                                  0,
                                  0.31851959751348929,
                                  0,
                                  0.28697408559149318,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30876856629474214,
                                  0,
                                  0,
                                  -0.084799767409519902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48765483051210157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0066747694745192421,
                                  0.51344315971955812,
                                  0.026595622149339304,
                                  0.21564738637846556,
                                  0,
                                  0,
                                  0,
                                  -0.23872567758918736,
                                  -0.42893037430214881,
                                  0,
                                  0,
                                  -0.3437948762373062,
                                  0,
                                  0.51077998641735345,
                                  0,
                                  0,
                                  -0.19981735360163103,
                                  0,
                                  0,
                                  -0.1804274539102034,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42542782002406143,
                                  0,
                                  0,
                                  -0.14390096300931127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29745997419763964,
                                  0.11681626283499036,
                                  0,
                                  0.30598957076878697,
                                  -0.16618326341709092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098426608756351092,
                                  0,
                                  0.13929499008003215,
                                  -0.078330739688174195,
                                  0,
                                  0.12320741129072997,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34975039385692397,
                                  0,
                                  0,
                                  -0.20330910304921612,
                                  0.065801050315919846,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.018215947813027308,
                                  0,
                                  0,
                                  0.064319288311498149,
                                  0,
                                  0.070300439386542041,
                                  0,
                                  -0.25553024681180025,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035221930320455744,
                                  0,
                                  0,
                                  0.13008507637373887,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06195803674511597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15669398729802492,
                                  -0.32425080196576356,
                                  0.19977320599000864,
                                  0.29582016752010631,
                                  0,
                                  0,
                                  0,
                                  -0.24678409985090188,
                                  -0.2741391343269724,
                                  0,
                                  0,
                                  0.25188934972241861,
                                  0,
                                  0.62215045859699625,
                                  0,
                                  0,
                                  -0.40993371167640469,
                                  0,
                                  0,
                                  -0.096189590756083382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022508752404143323,
                                  0,
                                  0,
                                  -0.43860949303451424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.180331046395248,
                                  -0.40804838110707886,
                                  0,
                                  -0.49922530645893293,
                                  0.56727634629188195,
                                  0.0228515249026204,
                                  0,
                                  0,
                                  -0.071093117822532456,
                                  0,
                                  0,
                                  -0.20992321322600135,
                                  0,
                                  0,
                                  0,
                                  -0.036179358219899357,
                                  0,
                                  0,
                                  -0.083827089277649397,
                                  0,
                                  0.17314291432107665,
                                  0,
                                  -0.0028569045241068278,
                                  0.20488679337738031,
                                  0,
                                  0,
                                  -0.087998818185674094,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10540749379587785,
                                  0,
                                  0,
                                  -0.27628905914091384,
                                  0.074610524963564268,
                                  0,
                                  0,
                                  -0.035318596499045812,
                                  0,
                                  0,
                                  -0.38874078744665241,
                                  -0.14186214916313736,
                                  0,
                                  0.0082503605489046283,
                                  0,
                                  0,
                                  0.1204114684823292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22800628741976928,
                                  0.10426041963735115,
                                  0,
                                  0,
                                  0,
                                  -0.36296051647378741,
                                  0,
                                  0,
                                  -0.02646516237797588,
                                  0,
                                  -0.12188947967579888,
                                  0.16381761051886021,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026358413922959192,
                                  0.072653206081839256,
                                  0,
                                  -0.045607229172911212,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14469772916685814,
                                  0,
                                  0,
                                  -0.24927250285556918,
                                  0.48701580891228857,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13013882066781179,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58654368827283221,
                                  0,
                                  0.44841248361321501,
                                  -0.30574471800735176,
                                  0,
                                  -0.42612048543567727,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33436376273587831,
                                  0,
                                  0,
                                  -0.29092390360188164,
                                  0.42644161034714378,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2228918130544624,
                                  0,
                                  0,
                                  -0.008786721835974504,
                                  0,
                                  0.087373331025235895,
                                  0,
                                  0.053772716794138552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46059223476433447,
                                  0,
                                  0,
                                  0.4387624950434077,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27758045957633165,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29557993491489221,
                                  -0.15772610115677524,
                                  0.24281700952719668,
                                  -0.35039145761483681,
                                  0,
                                  0,
                                  0,
                                  -0.11400707952751105,
                                  0.16866064420345014,
                                  0,
                                  0,
                                  0.057789909656020204,
                                  0,
                                  0.1444990706409186,
                                  0,
                                  0,
                                  0.16307371272709403,
                                  0,
                                  0,
                                  -0.22584052025537843,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51140177589920666,
                                  0,
                                  0,
                                  0.25975831016970297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57754964310492141,
                                  0.20622945467316697,
                                  0,
                                  0.018419323538057024,
                                  0.061416711533992072,
                                  -0.0099459006902807862,
                                  0,
                                  0,
                                  -0.021584067710300088,
                                  0,
                                  0,
                                  -0.041380782641129023,
                                  0,
                                  0,
                                  0,
                                  -0.076249316011719817,
                                  0,
                                  0,
                                  -0.064895868866855555,
                                  0,
                                  -0.088650033118713251,
                                  0,
                                  0.10186750448643628,
                                  0.064380477827432836,
                                  0,
                                  0,
                                  0.34365560663356848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16771715481614688,
                                  0,
                                  0,
                                  0.11946397056667009,
                                  0.039582726461884502,
                                  0,
                                  0,
                                  -0.26898100217295889,
                                  0,
                                  0,
                                  -0.014209836876208706,
                                  0.17055418302146269,
                                  0,
                                  -0.22069823009287234,
                                  0,
                                  0,
                                  0.040242669773511909,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3674775212069778,
                                  0.011460765484150804,
                                  0,
                                  0,
                                  0,
                                  -0.096387970203058448,
                                  0,
                                  0,
                                  0.088530812383728175,
                                  0,
                                  -0.44475052610286908,
                                  -0.15151588537008365,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17064852862352012,
                                  -0.16033488077102226,
                                  0,
                                  -0.34687832218648051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043690880931351109,
                                  0,
                                  0,
                                  0.075243706882336531,
                                  -0.13337432754518141,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27876509708788189,
                                  0,
                                  0,
                                  0,
                                  0.097156143765720696,
                                  0,
                                  0,
                                  0.02494150253380438,
                                  0.0084405759080172713,
                                  0,
                                  -0.044029716442808613,
                                  -0.41005785792135574,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13493722405088066,
                                  0,
                                  0,
                                  0.21379102669399364,
                                  0,
                                  0,
                                  0.21978717493697411,
                                  0,
                                  0,
                                  0.13026777704380982,
                                  0.39952860826925329,
                                  0,
                                  -0.38603556555176116,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13504967301495596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12855717806581174,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.089830862853847088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075466771606705979,
                                  0,
                                  0.28523057268894791,
                                  0,
                                  0.24310039036427744,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37128632634496278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.027054162001433704,
                                  0,
                                  0,
                                  0,
                                  -0.23318245195778994,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30482369090061434,
                                  0,
                                  0,
                                  0.39341273291394102,
                                  0,
                                  0,
                                  -0.13227654580257583,
                                  0,
                                  0,
                                  0,
                                  -0.1270674767030037,
                                  0,
                                  0,
                                  0.19477475063357613,
                                  0,
                                  -0.032986752176445804,
                                  0,
                                  -0.20682211195356914,
                                  -0.24512256842299635,
                                  0,
                                  0,
                                  -0.011237708078015319,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28898591951737362,
                                  0,
                                  0,
                                  -0.045409878714181999,
                                  0.03342314938339129,
                                  0,
                                  0,
                                  0.32990398101500351,
                                  0,
                                  0,
                                  0.019512956804979623,
                                  0.1033959053591043,
                                  0,
                                  -0.18821252001509881,
                                  0,
                                  0,
                                  0.1725777730335307,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19505404188588749,
                                  0.026305360292958782,
                                  0,
                                  0,
                                  0,
                                  0.11290859297589953,
                                  0,
                                  0,
                                  -0.33891774570094979,
                                  0,
                                  -0.1172088276094075,
                                  -0.19854695669360764,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081527264915085607,
                                  -0.0060345414149538187,
                                  0,
                                  0.25888331680574339,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.02604237908422468,
                                  0,
                                  0,
                                  -0.072625070827671584,
                                  0.073161378993126747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.01808715043276134,
                                  0,
                                  0,
                                  0.00778323201191945,
                                  0,
                                  0,
                                  0.26482187987606487,
                                  0,
                                  0,
                                  0.031394010133599465,
                                  0,
                                  0,
                                  0,
                                  -0.046584351835640116,
                                  0,
                                  0,
                                  0.1311039623652786,
                                  0,
                                  -0.13107605530109856,
                                  0,
                                  -0.1939293655382438,
                                  -0.005846476786077047,
                                  0,
                                  0,
                                  -0.036432236466663631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085898096680763578,
                                  0,
                                  0,
                                  -0.08962853989322786,
                                  0.33658959449278314,
                                  0,
                                  0,
                                  0.020039857375246294,
                                  0,
                                  0,
                                  0.22773074632952214,
                                  -0.081566622310752637,
                                  0,
                                  -0.048240794262372787,
                                  0,
                                  0,
                                  0.053344246289786831,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17419451671049657,
                                  -0.23643105067659181,
                                  0,
                                  0,
                                  0,
                                  0.10952953413081062,
                                  0,
                                  0,
                                  0.30451576893482663,
                                  0,
                                  -0.1215773911906608,
                                  0.50396155932217324,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.076658450827430266,
                                  -0.13331113922984866,
                                  0,
                                  -0.11820954323650533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24743671022872932,
                                  0,
                                  0,
                                  0.17057471700297386,
                                  -0.010766361319009063,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2696924773197098,
                                  0,
                                  0,
                                  0,
                                  0.15152239140756865,
                                  0,
                                  0,
                                  0.25066905620188068,
                                  0.27957784821079362,
                                  0,
                                  0.17632648559597272,
                                  0.3871666900266405,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26054790539639983,
                                  0,
                                  0,
                                  -0.13049702039425054,
                                  0,
                                  0,
                                  0.25079860989285768,
                                  0,
                                  0,
                                  0.27334380845484169,
                                  0.16923216169707531,
                                  0,
                                  -0.11436315008746743,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15340470106597365,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.027033904243868773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30504159008016929,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11729100245736236,
                                  0,
                                  -0.43524200622914605,
                                  0,
                                  -0.062801542301580554,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21411080658155965,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10105326215086251,
                                  0,
                                  0,
                                  0,
                                  -0.10147413473554359,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21873287525380011,
                                  0,
                                  0.12834260064759848,
                                  0.073322286124621355,
                                  0,
                                  0.039627643499776974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24762765501048528,
                                  0,
                                  0,
                                  -0.039618979502830366,
                                  -0.4610764665724108,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32372321289570671,
                                  0,
                                  0,
                                  0.055127889487122904,
                                  0,
                                  0.14608277523675947,
                                  0,
                                  -0.15950342492842939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52525522428091354,
                                  0,
                                  0,
                                  -0.45783547457054979,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07318001940177471,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18496653186166079,
                                  0.0059985158645265713,
                                  -0.35749842486163469,
                                  -0.43482521313106826,
                                  0,
                                  0,
                                  0,
                                  -0.36176486497226246,
                                  0.16686572803970334,
                                  0,
                                  0,
                                  0.40490504118015158,
                                  0,
                                  0.20656748641215833,
                                  0,
                                  0,
                                  0.14380770900412168,
                                  0,
                                  0,
                                  0.64374144177350578,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017411679612261446,
                                  0,
                                  0,
                                  -0.37507822599608864,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081675541512964675,
                                  -0.069552799469535478,
                                  0,
                                  0.026808399580206456,
                                  -0.32372366283936171,
                                  -0.10781588328961411,
                                  0,
                                  0,
                                  0.2676279990224481,
                                  0,
                                  0,
                                  0.16147383951741065,
                                  0,
                                  0,
                                  0,
                                  -0.22479834653304473,
                                  0,
                                  0,
                                  -0.20453055421884925,
                                  0,
                                  -0.10076053029941467,
                                  0,
                                  0.25196120269683975,
                                  0.26979625956858999,
                                  0,
                                  0,
                                  -0.078543502727496897,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.018795018610075279,
                                  0,
                                  0,
                                  -0.080187369912222362,
                                  -0.25039810292400061,
                                  0,
                                  0,
                                  0.2037639269818034,
                                  0,
                                  0,
                                  -0.011599432237544493,
                                  -0.13994371859245869,
                                  0,
                                  -0.22731058617349414,
                                  0,
                                  0,
                                  -0.1813774730437866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26453946732824773,
                                  -0.36513874324706841,
                                  0,
                                  0,
                                  0,
                                  -0.17500908115268127,
                                  0,
                                  0,
                                  0.16160986576183561,
                                  0,
                                  0.11537379600631058,
                                  -0.025201814515953935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052746725662348067,
                                  0.19235765057500914,
                                  0,
                                  0.040927260510433043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25370559380906171,
                                  0,
                                  0,
                                  -0.13104850122458972,
                                  -0.17833715381693832,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.040277877259379931,
                                  0,
                                  0,
                                  0,
                                  -0.057272288841392412,
                                  0,
                                  0,
                                  -0.00037287497995838921,
                                  0.036574407774293119,
                                  0,
                                  0.089254286244506501,
                                  0.02529478659980702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21042245338623369,
                                  0,
                                  0,
                                  0.18363137632390841,
                                  0,
                                  0,
                                  -0.16528757336338668,
                                  0,
                                  0,
                                  0.13188719513581565,
                                  0.22890627623204629,
                                  0,
                                  0.39844056527579202,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19450280262277256,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48631828974118363,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14780085057115819,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22400897204905257,
                                  0,
                                  -0.043246293449736226,
                                  0,
                                  0.44970809145075941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075947320029496557,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24749707159045986,
                                  0,
                                  0,
                                  0,
                                  0.18819749348090992,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12911675814551626,
                                  0,
                                  0.23290954676370146,
                                  0.50269374816178947,
                                  0,
                                  0.016931480647662974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33653736782704557,
                                  0,
                                  0,
                                  -0.46751021585251262,
                                  0.12840638351374739,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23854016929774335,
                                  0,
                                  0,
                                  0.098871923091712791,
                                  0,
                                  0.17646916930931145,
                                  0,
                                  0.35999696904735801,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22462448567332477,
                                  0,
                                  0,
                                  -0.26028024740257782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54780333112818391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10264113078953557,
                                  0.018982465867456236,
                                  -0.14479206368961864,
                                  0.052737076811472529,
                                  0,
                                  0,
                                  0,
                                  0.084055661542996485,
                                  -0.35429331590424951,
                                  0,
                                  0,
                                  -0.21030132275164698,
                                  0,
                                  -0.61187847596283296,
                                  0,
                                  0,
                                  -0.15980384190493954,
                                  0,
                                  0,
                                  0.17490874681931415,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1456054145023114,
                                  0,
                                  0,
                                  -0.14377099485856723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32383288313954239,
                                  0.25915525975180775,
                                  0,
                                  -0.37522113835422249,
                                  0.15720659626867348,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27820810859086964,
                                  0,
                                  0.071628559744098472,
                                  -0.18901661702482389,
                                  0,
                                  0.068142720259614611,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094683959836309992,
                                  0,
                                  0,
                                  0.1336149237701042,
                                  -0.22346084191484669,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1464307424910799,
                                  0,
                                  0,
                                  -0.1571965598329266,
                                  0,
                                  -0.093960443183566236,
                                  0,
                                  -0.087081268707903239,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30227677433691819,
                                  0,
                                  0,
                                  0.51050007054420754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09010226546839456,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13320579230160762,
                                  0.0046350604029215415,
                                  -0.51652021288629713,
                                  -0.49524572317325521,
                                  0,
                                  0,
                                  0,
                                  0.60026837840849012,
                                  -0.035941522902473662,
                                  0,
                                  0,
                                  -0.10868367707295304,
                                  0,
                                  0.17464125209591472,
                                  0,
                                  0,
                                  -0.65487762906774716,
                                  0,
                                  0,
                                  0.033346401435860526,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12028288539499027,
                                  0,
                                  0,
                                  0.22027686934248816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086000474909983873,
                                  0.3526419942838388,
                                  0,
                                  -0.44139045700328522,
                                  0.080137562829886155,
                                  0,
                                  0.3063706083807386,
                                  0,
                                  0,
                                  -0.095220102156104158,
                                  0.17206248991873235,
                                  0,
                                  0.0068424741606494081,
                                  0.32947229337889283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46614234832580981,
                                  0,
                                  0,
                                  -0.38796473948646082,
                                  0,
                                  0,
                                  -0.031044793928590875,
                                  0,
                                  0,
                                  0.14932794896566984,
                                  0.01003784026716909,
                                  0,
                                  0.24526533476286735,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18383653094593702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046228684228920923,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0033876149320001699,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21432486643163343,
                                  0,
                                  0.29077185348117734,
                                  0,
                                  0.12285791878364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078378278679492139,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17586856396288289,
                                  0,
                                  0,
                                  0,
                                  -0.29824026091869427,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049782245803805684,
                                  0,
                                  0,
                                  0.26167675189885115,
                                  0.05059616118268348,
                                  0,
                                  0.30588558507809505,
                                  0.071139613887071282,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032064413434067796,
                                  0,
                                  0,
                                  0.34609424715927273,
                                  0,
                                  0,
                                  -0.057378457601686521,
                                  0,
                                  0,
                                  0.20115639396099766,
                                  0.094860235723132347,
                                  0,
                                  -0.076556191940120297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25083714063721418,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41365640298418899,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35539865824545974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23991924099039388,
                                  0,
                                  -0.15981074671478998,
                                  0,
                                  0.12596990854173465,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15853103089526852,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37428691710961309,
                                  0,
                                  0,
                                  0,
                                  -0.15461025366122672,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53242156780222794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37241919559068576,
                                  0,
                                  -0.54398909929861738,
                                  0.3387476849572702,
                                  -0.30194082477163692,
                                  0,
                                  0.29771021485800192,
                                  0,
                                  0,
                                  -0.057177959265465553,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22613432580067586,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28864808033185246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38898867359820632,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21271838694900666,
                                  0,
                                  0,
                                  0,
                                  -0.19191572506106364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27978002761304738,
                                  0,
                                  0,
                                  -0.17257436020644315,
                                  0.10299594259403466,
                                  0,
                                  0,
                                  0.040529257430369448,
                                  0,
                                  0.23704999251554107,
                                  0.43147012377129873,
                                  0,
                                  0.096955036201148689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46714068320895946,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0067668760505833342,
                                  0,
                                  0,
                                  -0.30443188953821881,
                                  -0.07834806903057813,
                                  0,
                                  -0.22303493506870625,
                                  -0.21555493539491763,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.289491287757768,
                                  0,
                                  0,
                                  -0.26020110711259864,
                                  0,
                                  0,
                                  -0.0032918799927086281,
                                  0,
                                  0,
                                  0.33958606628632942,
                                  0.1801434697417757,
                                  0,
                                  0.37712250130357972,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30626406098041431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40067886002966902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18861151329666487,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.065170255205571417,
                                  0,
                                  -0.035411007932139686,
                                  0,
                                  0.17228709877734727,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18833280240849709,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051326501149833378,
                                  0,
                                  0,
                                  0,
                                  -0.014593462916847919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.066222477219066059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068507083607164801,
                                  0,
                                  -0.14352185345905005,
                                  0.37761526674767931,
                                  0.33826706052801203,
                                  0,
                                  0.20472873012011264,
                                  0,
                                  0,
                                  0.47935875901093233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34454020026796273,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10106293639261694,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.8195010376669265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55380327909111815,
                                  0,
                                  0,
                                  0,
                                  -0.35683410414086919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43613070011891175,
                                  0,
                                  0,
                                  -0.090664233275182707,
                                  -0.20853775352599269,
                                  0,
                                  0,
                                  0.19082305291183596,
                                  0,
                                  -0.19332548352061776,
                                  0.16546722280054643,
                                  0,
                                  -0.73100046105958616,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31192898413659348,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.058916681988736778,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28329049784412058,
                                  0,
                                  0.32072968914834143,
                                  -0.34818909368077133,
                                  0.00015328909480613433,
                                  0,
                                  0.49922754398110275,
                                  0,
                                  0,
                                  -0.20167516657790294,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3580801425107647,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23342161300934947,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5592365113824127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29683559536742987,
                                  0,
                                  0,
                                  0,
                                  0.35870460530172865,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41370361752198709,
                                  0,
                                  0,
                                  -0.49116630614882983,
                                  0.05336411796395079,
                                  0,
                                  0,
                                  0.1615868059780998,
                                  0,
                                  0.48908582208368934,
                                  -0.77266200891191283,
                                  0,
                                  0.10071685995929941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31548043315740187,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13345043467714754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42037007264099846,
                                  0,
                                  -0.0329710655761873,
                                  0.28643844320509704,
                                  -0.034630979106651388,
                                  0,
                                  -0.14748514709789748,
                                  0,
                                  0,
                                  0.28908231124044742,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70941534036793319,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28039017064555294,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12269527162714597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014362992881119391,
                                  0,
                                  0,
                                  0,
                                  0.3526858055447612,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21136927032537731,
                                  0,
                                  0,
                                  0.34403428514650619,
                                  0.42262372561972866,
                                  0,
                                  0,
                                  0.35936895334549745,
                                  0,
                                  0.090370601508482473,
                                  0.037815664834392013,
                                  0,
                                  0.22140890806216645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054385687664201633,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.018043192606018138,
                                  0,
                                  -0.299284324406281,
                                  -0.089941646993109803,
                                  0,
                                  -0.29844733051405198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27099270886416765,
                                  0,
                                  0,
                                  0.35914443164829529,
                                  0.33240808433307079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.069991987090900445,
                                  0,
                                  0,
                                  -0.21630458181812645,
                                  0,
                                  -0.56667519989091253,
                                  0,
                                  -0.25764801151393363,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30060775613776719,
                                  0,
                                  0,
                                  0.23939334304423773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.078094189537594533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25229300486685902,
                                  0.27399130388427079,
                                  -0.33965156863770518,
                                  -0.24348985873809653,
                                  0,
                                  0,
                                  0,
                                  -0.18326316877069168,
                                  0.0056780866076549946,
                                  0,
                                  0,
                                  0.080247955885349914,
                                  0,
                                  -0.22943705480352458,
                                  0,
                                  0,
                                  0.14408573621113224,
                                  0,
                                  0,
                                  0.47087162048750414,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.82818454607649428,
                                  0,
                                  0,
                                  -0.22135043487181266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21094253294116941,
                                  -0.056404716475205355,
                                  0,
                                  -0.26711947184722351,
                                  0.064707753409559685,
                                  0,
                                  0,
                                  -0.0048912428004279258,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29012829871765217,
                                  0,
                                  0.16816070927196319,
                                  0.2058539809597065,
                                  -0.53181081956616005,
                                  0,
                                  -0.23788058046472696,
                                  0,
                                  0,
                                  0.31088785118322182,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021817022812011172,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12946882533759727,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40934480555431146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18000997014316406,
                                  0,
                                  0,
                                  0,
                                  0.35660625431650406,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46778126671977888,
                                  0,
                                  0,
                                  -0.21201052413701224,
                                  -0.57582413762824769,
                                  0,
                                  0,
                                  -0.35172867029835331,
                                  0,
                                  0.06025342588655417,
                                  0.12201585792407443,
                                  0,
                                  -0.076888623154938898,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41914515609144676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39050484716937528,
                                  0,
                                  0,
                                  0.19650966968887335,
                                  -0.26075384404149726,
                                  0,
                                  -0.38281403404740622,
                                  0.11526405545865548,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038989442089133623,
                                  0,
                                  0,
                                  0.17918291902998126,
                                  0,
                                  0,
                                  -0.34419496964942931,
                                  0,
                                  0,
                                  0.056756088786902269,
                                  0.0417925430665433,
                                  0,
                                  -0.09914116054560683,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18887656627599919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.012248411176442802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23137789466017977,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48135354302749328,
                                  0,
                                  0.022001344828005878,
                                  0,
                                  -0.035446905803326614,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14837287764040061,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.099615363989059416,
                                  0,
                                  0,
                                  0,
                                  -0.24378603178130009,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26438344942071279,
                                  0,
                                  -0.12668155739267214,
                                  0.092303339978245677,
                                  0,
                                  -0.0088119251982046402,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040772816146697248,
                                  0,
                                  0,
                                  0.087618826227034888,
                                  -0.55810932304401895,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15079370629441738,
                                  0,
                                  0,
                                  0.66996091291257087,
                                  0,
                                  -0.38053582085115056,
                                  0,
                                  0.15882857030239825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085734362657967605,
                                  0,
                                  0,
                                  -0.018684968638530024,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33774462624956125,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13411862014561704,
                                  -0.18679856296814348,
                                  0.004751855948891685,
                                  0.14463694230332372,
                                  0,
                                  0,
                                  0,
                                  0.77992151908821139,
                                  -0.03866407680557897,
                                  0,
                                  0,
                                  0.2123152973878511,
                                  0,
                                  0.27872148349437953,
                                  0,
                                  0,
                                  0.2360712135019658,
                                  0,
                                  0,
                                  0.042344498015994485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23696671690110438,
                                  0,
                                  0,
                                  0.17928756464326867,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.074871837556264975,
                                  0.080397266361377867,
                                  0,
                                  -0.25527407809863994,
                                  0.054895672336673376,
                                  0,
                                  0,
                                  0.28773455987277358,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25959880462163643,
                                  0,
                                  0.32074668954511271,
                                  -0.045498456370481721,
                                  -0.49345776103055322,
                                  0,
                                  0.14055100163415193,
                                  0,
                                  0,
                                  0.082143146123546562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12545048440067527,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13438465782257114,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26210984518896097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059603968965474874,
                                  0,
                                  0,
                                  0,
                                  -0.35422916289403894,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35831266430755787,
                                  0,
                                  0,
                                  -0.27202743555874254,
                                  -0.10200016729996747,
                                  0,
                                  0,
                                  0.64850568655903906,
                                  0,
                                  -0.60489817674249335,
                                  -0.27667128847942474,
                                  0,
                                  -0.28574793606841969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.417731462139872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16152957003095686,
                                  0,
                                  -0.056381338483572442,
                                  0.023763043930163576,
                                  0,
                                  0.42233802876239046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48297077575512953,
                                  0,
                                  0,
                                  0.28249944739780225,
                                  0.36186369805757684,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54287480700855528,
                                  0,
                                  0,
                                  0.070203788724345351,
                                  0,
                                  -0.34341987606178292,
                                  0,
                                  0.10916999927750096,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19482249538190444,
                                  0,
                                  0,
                                  -0.11401392535793284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19993286487227982,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16354415166571465,
                                  0.18569119480242763,
                                  -0.11759537466106651,
                                  -0.067284885319498722,
                                  0,
                                  0,
                                  0,
                                  0.44111644407282319,
                                  -0.17710410161543438,
                                  0,
                                  0,
                                  -0.0038838303172015129,
                                  0,
                                  0.29162859637253102,
                                  0,
                                  0,
                                  0.14925779179153795,
                                  0,
                                  0,
                                  0.027465358258255138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51403604950612092,
                                  0,
                                  0,
                                  -0.41773742245300244,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35278543478321484,
                                  0.22206792192338776,
                                  0,
                                  -0.42199619387941834,
                                  -0.20069715585820247,
                                  0.31123819539644099,
                                  0,
                                  0,
                                  0.059381477689002551,
                                  0,
                                  0,
                                  0.25170398013052386,
                                  0,
                                  0,
                                  0,
                                  -0.015320256509573402,
                                  0,
                                  0,
                                  0.037314167315757603,
                                  0,
                                  -0.26432539939940897,
                                  0,
                                  -0.28157011609083699,
                                  0.17541652093078525,
                                  0,
                                  0,
                                  -0.40033069509009611,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0044462943578990654,
                                  0,
                                  0,
                                  -0.0032258982987779933,
                                  0.10804788277891861,
                                  0,
                                  0,
                                  -0.12746615548199627,
                                  0,
                                  0,
                                  -0.14605827430354673,
                                  0.19591016296117539,
                                  0,
                                  0.047045254490039094,
                                  0,
                                  0,
                                  0.011275046455185123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075093911804457972,
                                  -0.043587454192383211,
                                  0,
                                  0,
                                  0,
                                  0.018514990812297506,
                                  0,
                                  0,
                                  0.090280889382192628,
                                  0,
                                  -0.15098596822832555,
                                  -0.19688192371000543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22449851554536351,
                                  0.07398703000950313,
                                  0,
                                  0.17478149029712756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30650359104267072,
                                  0,
                                  0,
                                  0.28609885413785313,
                                  0.25037836616367942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.04394138510595251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022804854276856412,
                                  0,
                                  -0.11494058185440825,
                                  0.1636854106478777,
                                  0,
                                  -0.27798212245541215,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22912981618242764,
                                  0,
                                  0,
                                  -0.05761863817738367,
                                  0.13477340931781409,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36274504674076435,
                                  0,
                                  0,
                                  0.21988462785031845,
                                  0,
                                  -0.11794937567243352,
                                  0,
                                  0.08691856173457084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24800532483816384,
                                  0,
                                  0,
                                  -0.099483793755738598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045075965531898583,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18763203993248578,
                                  -0.30842655559590415,
                                  -0.48961349305849922,
                                  -0.31540506463708445,
                                  0,
                                  0,
                                  0,
                                  -0.10707279396934283,
                                  -0.40752872978623511,
                                  0,
                                  0,
                                  -0.56151813176632626,
                                  0,
                                  0.072292695430388285,
                                  0,
                                  0,
                                  0.65262039132993288,
                                  0,
                                  0,
                                  0.11624329821147811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18734220130150553,
                                  0,
                                  0,
                                  0.25915883021598396,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10342267663612756,
                                  -0.5306515170777123,
                                  0,
                                  -0.15571998351197569,
                                  0.41587902105113217,
                                  0,
                                  -0.16429884389764587,
                                  0,
                                  0,
                                  0.16043205027020488,
                                  0.35143473770187011,
                                  0,
                                  -0.15663461874107951,
                                  0.052219762609312728,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.027451450492992364,
                                  0,
                                  0,
                                  0.45439361442447135,
                                  0,
                                  0,
                                  0.051373031794666665,
                                  0,
                                  0,
                                  0.016103498828170873,
                                  -0.20617063095583971,
                                  0,
                                  0.21661108201861468,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24102375613675903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28292427996245872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47478869521614731,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084268483010732864,
                                  0,
                                  0.30991742052941673,
                                  0,
                                  0.072447373596777165,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12068697466781995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0028632084393013105,
                                  0,
                                  0,
                                  0,
                                  0.10204102151016978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072464567632596566,
                                  0,
                                  0,
                                  0.12310213066665734,
                                  0,
                                  0,
                                  0.0041589583746655945,
                                  0,
                                  0,
                                  0,
                                  0.1330147558667405,
                                  0,
                                  0,
                                  0.40130206023304249,
                                  0,
                                  0.060431098854580215,
                                  0,
                                  -0.18421761931767194,
                                  0.28407339057046715,
                                  0,
                                  0,
                                  -0.063165963847821402,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18886211081080098,
                                  0,
                                  0,
                                  0.16519060840670263,
                                  -0.10040324539410379,
                                  0,
                                  0,
                                  -0.27871647100934849,
                                  0,
                                  0,
                                  0.005917446894934196,
                                  -0.075104076450930479,
                                  0,
                                  0.13878588734651071,
                                  0,
                                  0,
                                  0.068017040039006368,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13448453562128557,
                                  -0.24121828562233991,
                                  0,
                                  0,
                                  0,
                                  0.024535190707832735,
                                  0,
                                  0,
                                  0.037188554788691743,
                                  0,
                                  -0.10923462618831196,
                                  -0.25063028572223661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01753440114696133,
                                  0.051932893269814269,
                                  0,
                                  -0.10769653653282679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09088619018570275,
                                  0,
                                  0,
                                  -0.46107933194133149,
                                  -0.20580035278083614,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25974062453239266,
                                  0,
                                  0,
                                  -0.21504219929999233,
                                  0,
                                  0,
                                  0.036122761140734774,
                                  0,
                                  0,
                                  0.20546115026096837,
                                  0,
                                  0,
                                  0,
                                  0.090103832252272517,
                                  0,
                                  0,
                                  0.064332486454379972,
                                  0,
                                  0.28703428038440787,
                                  0,
                                  -0.43496908507336957,
                                  0.34814223526475913,
                                  0,
                                  0,
                                  0.11723814578809622,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17983539529031167,
                                  0,
                                  0,
                                  0.10816339714274611,
                                  -0.14615747119228412,
                                  0,
                                  0,
                                  0.15866062577121845,
                                  0,
                                  0,
                                  -0.086839586275780437,
                                  0.14077776425039301,
                                  0,
                                  -0.10796360775647104,
                                  0,
                                  0,
                                  -0.058064934102561756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10000501079009749,
                                  0.19838682845441447,
                                  0,
                                  0,
                                  0,
                                  0.033282528125028993,
                                  0,
                                  0,
                                  0.27880126109577186,
                                  0,
                                  0.087948009334666927,
                                  -0.038893572430876606,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2892760782530211,
                                  -0.17229407981578704,
                                  0,
                                  0.10618103089418554,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10839744107624144,
                                  0,
                                  0,
                                  -0.0026202539254680211,
                                  0.062030321765835165,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28424389573828929,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32235319691276598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31329966440884732,
                                  0,
                                  -0.66807540682250488,
                                  0.23808733444602326,
                                  0.11415688223110174,
                                  0,
                                  0.22654768119863183,
                                  0,
                                  0,
                                  0.37341047483499712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26827624295186869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33423148093551486,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50338369280794204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34602800454921412,
                                  0,
                                  0,
                                  0,
                                  -0.13697762446812597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22511055326400836,
                                  0,
                                  0,
                                  0.043547524871749212,
                                  0.19603651416223536,
                                  0,
                                  0,
                                  0.031906364611654456,
                                  0,
                                  0.06269748424435137,
                                  -0.16234195631779255,
                                  0,
                                  -0.3258032594626239,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40780234726611925,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11846177748489814,
                                  0,
                                  0.19917147654520551,
                                  0.10321610711251736,
                                  0,
                                  0.0025191648960336687,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13214186804428507,
                                  0,
                                  0,
                                  -0.37541928711022915,
                                  0.20233648738832921,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42232508463775104,
                                  0,
                                  0,
                                  0.28909942009776141,
                                  0,
                                  0.11921256841594409,
                                  0,
                                  -0.096962476530320682,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58882203539700462,
                                  0,
                                  0,
                                  0.39105530554058565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35178953021231352,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15169486497125748,
                                  -0.5291603988526431,
                                  -0.35343019480935223,
                                  0.14549863805778013,
                                  0,
                                  0,
                                  0,
                                  0.040171548048861021,
                                  -0.12176195058172606,
                                  0,
                                  0,
                                  0.0090017706522722285,
                                  0,
                                  0.0066713889119325506,
                                  0,
                                  0,
                                  -0.083005533037725329,
                                  0,
                                  0,
                                  0.35563221643198606,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.020286214534048698,
                                  0,
                                  0,
                                  0.072415830222314612,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19471451332343387,
                                  0.1636409581279713,
                                  0,
                                  -0.15394499874837475,
                                  -0.4922173134920938,
                                  0.19088365813210539,
                                  0,
                                  0,
                                  -0.18334735199337601,
                                  0,
                                  0,
                                  0.080714684580959858,
                                  0,
                                  0,
                                  0,
                                  -0.35653721339611866,
                                  0,
                                  0,
                                  -0.1052371539638146,
                                  0,
                                  -0.45504246530386327,
                                  0,
                                  -0.14656715743770493,
                                  -0.013055153472557635,
                                  0,
                                  0,
                                  0.027051545207253679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.077447645798983306,
                                  0,
                                  0,
                                  0.11962260262328307,
                                  0.071246944930345391,
                                  0,
                                  0,
                                  0.25185732089267421,
                                  0,
                                  0,
                                  -0.1978037299236092,
                                  -0.25153950661230878,
                                  0,
                                  0.029191761576785054,
                                  0,
                                  0,
                                  -0.0092650594363324137,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15283838795130136,
                                  0.17717721113168708,
                                  0,
                                  0,
                                  0,
                                  0.025588535420082006,
                                  0,
                                  0,
                                  0.01170245754735659,
                                  0,
                                  -0.20593069057626287,
                                  0.058466326386716505,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21847026050877549,
                                  -0.28870375944224991,
                                  0,
                                  0.089566071568990963,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.011777321782670058,
                                  0,
                                  0,
                                  -0.30629573860877618,
                                  -0.16254435391467123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052839626219249633,
                                  0,
                                  0,
                                  0,
                                  -0.24027047281128389,
                                  0,
                                  0,
                                  -0.087463778843306306,
                                  -0.27157744807670459,
                                  0,
                                  0.4798616373964017,
                                  0.069913070931023322,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21633969699479311,
                                  0,
                                  0,
                                  -0.041516047845228984,
                                  0,
                                  0,
                                  -0.16258671539454439,
                                  0,
                                  0,
                                  -0.0096507109239582015,
                                  0.25269829285829992,
                                  0,
                                  -0.088906318045868293,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23359694864462488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10580422357800977,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.59041742567253552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09809005685423082,
                                  0,
                                  0.025665171400317276,
                                  0,
                                  0.016908127877683587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19008734479979159,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.071691639740183638,
                                  0,
                                  0,
                                  0,
                                  0.11270370567027174,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40487789945413621,
                                  0,
                                  -0.3072362798029088,
                                  0.054329788633603007,
                                  0,
                                  0.270192805328061,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11717759587760904,
                                  0,
                                  0,
                                  0.3032245413573999,
                                  -0.016154805809190119,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0032861707471421309,
                                  0,
                                  0,
                                  -0.026377669743729997,
                                  0,
                                  0.50318648630771734,
                                  0,
                                  0.057916178271587557,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17684690720522372,
                                  0,
                                  0,
                                  0.60385718158543478,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43598974734080703,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.407692592317066,
                                  -0.20883888202642115,
                                  -0.069871949058828015,
                                  0.040731473634898055,
                                  0,
                                  0,
                                  0,
                                  -0.037479193859205805,
                                  -0.069370608407612638,
                                  0,
                                  0,
                                  -0.078333497434389776,
                                  0,
                                  0.0362829085860032,
                                  0,
                                  0,
                                  -0.12505253866330324,
                                  0,
                                  0,
                                  -0.0056308626424928995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0074954669862034801,
                                  0,
                                  0,
                                  -0.30422284224867396,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28590203250991147,
                                  -0.23605834311341892,
                                  0,
                                  0.02650961845686528,
                                  0.3001812472671207,
                                  -0.030808916234176038,
                                  0,
                                  0,
                                  -0.29323584686553256,
                                  0,
                                  0,
                                  -0.15676857237606903,
                                  0,
                                  0,
                                  0,
                                  -0.13145435021463067,
                                  0,
                                  0,
                                  0.020873728217952685,
                                  0,
                                  0.19030730817898472,
                                  0,
                                  -0.035919339192143844,
                                  0.27835627645879035,
                                  0,
                                  0,
                                  -0.22426945669524112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.037016819042986787,
                                  0,
                                  0,
                                  0.051770603229358503,
                                  0.24990364786140565,
                                  0,
                                  0,
                                  0.3416901790825056,
                                  0,
                                  0,
                                  0.14933608121250636,
                                  0.011589214732235287,
                                  0,
                                  0.13266226095870817,
                                  0,
                                  0,
                                  -0.19095374565216899,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075892784627246815,
                                  -0.28307555360372599,
                                  0,
                                  0,
                                  0,
                                  -0.073948009905620685,
                                  0,
                                  0,
                                  -0.19609038542402762,
                                  0,
                                  0.1481773640415697,
                                  -0.14698928562613636,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27448331877925125,
                                  -0.39738411823162945,
                                  0,
                                  -0.16424583959930072,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.069257794484297655,
                                  0,
                                  0,
                                  0.058601492604921118,
                                  -0.037962182020433645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049548467573781362,
                                  0,
                                  0,
                                  0.13803277471208736,
                                  0,
                                  0,
                                  -0.086362817674822859,
                                  0,
                                  0,
                                  0.18353812762626839,
                                  0,
                                  0,
                                  0,
                                  -0.062436559364216056,
                                  0,
                                  0,
                                  0.33855149098332588,
                                  0,
                                  0.070704721684499497,
                                  0,
                                  0.10961354969969295,
                                  0.01464433729262706,
                                  0,
                                  0,
                                  -0.1222947072029465,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22800598737040653,
                                  0,
                                  0,
                                  -0.28864260412805426,
                                  -0.032483161926827334,
                                  0,
                                  0,
                                  0.22105553143809731,
                                  0,
                                  0,
                                  -0.021960805401965974,
                                  -0.027868931374070566,
                                  0,
                                  -0.19527117604629476,
                                  0,
                                  0,
                                  0.28638640155107542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1838069209755277,
                                  -0.17327403209183559,
                                  0,
                                  0,
                                  0,
                                  -0.0084998709441226859,
                                  0,
                                  0,
                                  -0.23327533690347663,
                                  0,
                                  -0.22629756302744525,
                                  -0.069131059628808611,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30231725515258479,
                                  0.15376815938283861,
                                  0,
                                  -0.33814753871534209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.031412278234372898,
                                  0,
                                  0,
                                  0.12423287749976347,
                                  -0.004862840608899896,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24971292078856203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -1.0437315745272175,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23174600161795417,
                                  0,
                                  -0.10382932898848804,
                                  -0.3458447714813021,
                                  -0.61118044160885232,
                                  0,
                                  -0.064874632263298954,
                                  0,
                                  0,
                                  0.21234139870461527,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32710970698824726,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28174783940749032,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.041932750720935504,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24273169759015667,
                                  0,
                                  0,
                                  0,
                                  0.064315919980691902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22197221011699145,
                                  0,
                                  0,
                                  0.23684492921019182,
                                  0.57454362641489021,
                                  0,
                                  0,
                                  0.16708839270995515,
                                  0,
                                  0.01122144440246616,
                                  0.037469734747901932,
                                  0,
                                  -0.1852129765852856,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23975694687027038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039210348168628943,
                                  0,
                                  0,
                                  -0.22315232621945019,
                                  0,
                                  0,
                                  -0.24189906990295229,
                                  0,
                                  0,
                                  0,
                                  -0.17494650034646012,
                                  0,
                                  0,
                                  -0.025707021960489334,
                                  0,
                                  -0.0027459732756788015,
                                  0,
                                  -0.24349463980360625,
                                  -0.19405760078215337,
                                  0,
                                  0,
                                  -0.10982778544497555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11114856507899101,
                                  0,
                                  0,
                                  -0.37373100582483826,
                                  -0.027013644907002133,
                                  0,
                                  0,
                                  -0.07241035957102912,
                                  0,
                                  0,
                                  -0.013703026826339212,
                                  0.20934014888121802,
                                  0,
                                  -0.39345381912310995,
                                  0,
                                  0,
                                  -0.014217652364421466,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11285032892402895,
                                  0.10232165314770923,
                                  0,
                                  0,
                                  0,
                                  -0.10119568255639461,
                                  0,
                                  0,
                                  0.31167871886592852,
                                  0,
                                  0.1163982359342737,
                                  -0.28593148694222442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019970030765645491,
                                  -0.050753084784517538,
                                  0,
                                  -0.097839143788253424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032775611436384897,
                                  0,
                                  0,
                                  -0.016376445264806049,
                                  -0.20960779633614296,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33034093544963805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23463874854961972,
                                  0,
                                  -0.35742900986948239,
                                  0.052028943445888778,
                                  0,
                                  0.14294688996513566,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25833881630262223,
                                  0,
                                  0,
                                  0.24742890693725214,
                                  -0.022441154626520542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056474940387798656,
                                  0,
                                  0,
                                  -0.095848749349918105,
                                  0,
                                  0.087101966179497281,
                                  0,
                                  0.11620763595836706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10319929586636956,
                                  0,
                                  0,
                                  -0.5012970195031532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.011129072309868912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34276497578485088,
                                  -0.62022292585259964,
                                  -0.074987174741424564,
                                  0.11666877852311557,
                                  0,
                                  0,
                                  0,
                                  -0.092118389597910272,
                                  -0.3121771480454345,
                                  0,
                                  0,
                                  0.20736837659197108,
                                  0,
                                  0.074141704029780917,
                                  0,
                                  0,
                                  -0.0078824474950258787,
                                  0,
                                  0,
                                  -0.20308694613553305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60726237719223097,
                                  0,
                                  0,
                                  0.11727326694611884,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17491100886926803,
                                  0.699223301666411,
                                  0,
                                  0.049648941326299961,
                                  0.1086375587104644,
                                  0,
                                  0.073684738413504092,
                                  0,
                                  0,
                                  0.1057388627869125,
                                  0.2773159081763657,
                                  0,
                                  -0.065714880543573384,
                                  0.078827315896581845,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42578731670558351,
                                  0,
                                  0,
                                  -0.25271620198736838,
                                  0,
                                  0,
                                  -0.48626436589203759,
                                  0,
                                  0,
                                  -0.27649994543312634,
                                  0.055578164068071534,
                                  0,
                                  -0.34235430092497943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.07062782964629355,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01088822346596233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037024360828596954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30676732881195845,
                                  0,
                                  0.16431534606816503,
                                  0,
                                  0.29234091918126259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035041479221869544,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054287949240404192,
                                  0,
                                  0,
                                  0,
                                  0.019258853737383771,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10512350524465935,
                                  0,
                                  0,
                                  -0.069683493461341617,
                                  0,
                                  0,
                                  0.26735072756211986,
                                  0,
                                  0,
                                  0,
                                  -0.06380901647783932,
                                  0,
                                  0,
                                  -0.10720667757431811,
                                  0,
                                  0.37273971163302949,
                                  0,
                                  0.048222760873655166,
                                  -0.27290648308037213,
                                  0,
                                  0,
                                  -0.021392951885106298,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072278427623395508,
                                  0,
                                  0,
                                  -0.19730759704638187,
                                  0.13654975542676964,
                                  0,
                                  0,
                                  -0.18916173446890688,
                                  0,
                                  0,
                                  -0.17476690270044951,
                                  0.14722713287017319,
                                  0,
                                  0.083522969297544186,
                                  0,
                                  0,
                                  -0.35199273429316841,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.078079579198368915,
                                  -0.32424617097315583,
                                  0,
                                  0,
                                  0,
                                  0.062436762356077431,
                                  0,
                                  0,
                                  -0.040552176792867226,
                                  0,
                                  -0.36195566414392427,
                                  0.019559482870880752,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19395947149722756,
                                  -0.17681078671092632,
                                  0,
                                  0.2668057466967339,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053908068929756935,
                                  0,
                                  0,
                                  -0.075504103582014398,
                                  -0.042487296564050432,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.023027434166585682,
                                  0,
                                  0,
                                  0,
                                  -0.083935395381875361,
                                  0,
                                  0,
                                  0.20912612860257462,
                                  0.10015361091104792,
                                  0,
                                  -0.0013101102848137661,
                                  0.18863239756027933,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098325300983763519,
                                  0,
                                  0,
                                  0.05036980887287773,
                                  0,
                                  0,
                                  -0.23042754648714192,
                                  0,
                                  0,
                                  0.11300203464694611,
                                  0.52787384943599369,
                                  0,
                                  0.1735577082988724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085691963283731354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097978334214265772,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2341799647095357,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.059254775448266905,
                                  0,
                                  0.31827427955214321,
                                  0,
                                  -0.3550285741096858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16004485755492587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35838571683329967,
                                  0,
                                  0,
                                  0,
                                  0.24509050962547119,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.031872573114468561,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25812629644627511,
                                  0,
                                  0.61181361309505722,
                                  0.52622576658774967,
                                  0.1346302777222157,
                                  0,
                                  0.46655668654961657,
                                  0,
                                  0,
                                  0.10898518873008052,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30236672032671602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50644536861156386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054631042093933851,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26859596935255914,
                                  0,
                                  0,
                                  0,
                                  -0.4528747598571613,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097837698656777994,
                                  0,
                                  0,
                                  -0.24665900741368743,
                                  0.37472290921944773,
                                  0,
                                  0,
                                  -0.25731938932066972,
                                  0,
                                  -0.26907563363785714,
                                  0.092041247574723137,
                                  0,
                                  0.44392485720410146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56935458620612267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26053470804305506,
                                  0,
                                  0,
                                  -0.23097676741617199,
                                  0.079084335566273159,
                                  0,
                                  -0.044867493383706138,
                                  -0.16688639550345655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29448291324261439,
                                  0,
                                  0,
                                  0.044603826837643593,
                                  0,
                                  0,
                                  0.11246429348881834,
                                  0,
                                  0,
                                  -0.11409171335739457,
                                  0.36300357999015781,
                                  0,
                                  0.0183989358452726,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21764888738020394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.048346810014048412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050906974678079489,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16660561382599179,
                                  0,
                                  0.01166828137350856,
                                  0,
                                  -0.51051904936107784,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40761341229159076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29836417956622874,
                                  0,
                                  0,
                                  0,
                                  -0.013222440871933097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53592407067210879,
                                  0,
                                  -0.12101859365383472,
                                  -0.14458353736866816,
                                  0,
                                  0.41285743035653161,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.038875487125628404,
                                  0,
                                  0,
                                  -0.4335370454645926,
                                  -0.16872300640134377,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12272296243702591,
                                  0,
                                  0,
                                  -0.27658629648594885,
                                  0,
                                  -0.48472602200043785,
                                  0,
                                  -0.19978929874193818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0021322478290166607,
                                  0,
                                  0,
                                  0.20290094934739936,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.035831467551686265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.55660631640596947,
                                  -0.52476368597359291,
                                  0.33052262480546934,
                                  -0.18811552514010332,
                                  0,
                                  0,
                                  0,
                                  -0.048603103135305602,
                                  -0.11097902333113026,
                                  0,
                                  0,
                                  -0.056761950951965019,
                                  0,
                                  -0.10816369536290676,
                                  0,
                                  0,
                                  0.19544235949986735,
                                  0,
                                  0,
                                  -0.053926582742354359,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027973683577283786,
                                  0,
                                  0,
                                  -0.29094445340042818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16570094622939194,
                                  -0.18171180533772568,
                                  0,
                                  -0.062462886200183886,
                                  -0.25838018079002278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50313561804710072,
                                  0,
                                  -0.49440485545122226,
                                  -0.084443052521079365,
                                  0,
                                  0.34453317040557407,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39606062701628619,
                                  0,
                                  0,
                                  -0.33032451047102629,
                                  -0.11712234869869508,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24334293777967442,
                                  0,
                                  0,
                                  0.50754175805662383,
                                  0,
                                  0.28885912615302523,
                                  0,
                                  -0.076413024347457337,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10886225274320716,
                                  0,
                                  0,
                                  0.064569737696725776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30033531397934132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11547062089410703,
                                  0.046739019869018475,
                                  0.049828883169032362,
                                  -0.36873908463199412,
                                  0,
                                  0,
                                  0,
                                  0.57025022103843015,
                                  0.049153200020382218,
                                  0,
                                  0,
                                  -0.076546276521622492,
                                  0,
                                  -0.0224424936181397,
                                  0,
                                  0,
                                  0.17205366298828123,
                                  0,
                                  0,
                                  -0.3690563606177435,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29758298004490963,
                                  0,
                                  0,
                                  -0.04781504029743102,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23787215893697861,
                                  -0.18753800657562036,
                                  0,
                                  0.38151249744926197,
                                  -0.18098430330313081,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11935220715727417,
                                  0,
                                  0.042263705497006435,
                                  0.13226042011660236,
                                  0,
                                  0.016338395573130188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13927348444213808,
                                  0,
                                  0,
                                  -0.49975150101862764,
                                  -0.38415714858113326,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.055115753758863878,
                                  0,
                                  0,
                                  -0.080874783895428556,
                                  0,
                                  0.14842972532580695,
                                  0,
                                  -0.092253123371462228,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21736387921842537,
                                  0,
                                  0,
                                  0.064251551947817648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30489730735029924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19632581125195109,
                                  0.22203825205008018,
                                  -0.55446422259069872,
                                  -0.0068093298010016602,
                                  0,
                                  0,
                                  0,
                                  4.1153051595306658e-05,
                                  -0.20256975343235015,
                                  0,
                                  0,
                                  0.55367735091604997,
                                  0,
                                  -0.01250927684699632,
                                  0,
                                  0,
                                  0.17024717803526809,
                                  0,
                                  0,
                                  -0.46697216088103105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20144860952976845,
                                  0,
                                  0,
                                  -0.16082832093379762,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1598503166888216,
                                  0.069440028451336955,
                                  0,
                                  -0.22430665557661347,
                                  0.09684332704148238,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10200959289097987,
                                  0,
                                  -0.17581140938229142,
                                  0.29743732134257617,
                                  0,
                                  -0.190113999734776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34599765339579941,
                                  0,
                                  0,
                                  0.16867329952772786,
                                  -0.18368947317093412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41207501980647765,
                                  0,
                                  0,
                                  0.080730557862444652,
                                  0,
                                  -0.43411586707835265,
                                  0,
                                  0.034767840078407185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067750635824279398,
                                  0,
                                  0,
                                  0.2939010007602168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0015317578722778141,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0031739308512872847,
                                  0.17800871352646419,
                                  0.24652369783392439,
                                  -0.08861368508668277,
                                  0,
                                  0,
                                  0,
                                  -0.38197636017117143,
                                  -0.55467566561643511,
                                  0,
                                  0,
                                  0.16423786380505295,
                                  0,
                                  -0.27411849428037549,
                                  0,
                                  0,
                                  -0.0089173716932812244,
                                  0,
                                  0,
                                  -0.089620728190376225,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25196455115152999,
                                  0,
                                  0,
                                  0.40339142712770248,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16711968902313387,
                                  0.31150248685468374,
                                  0,
                                  0.37200312679091813,
                                  0.052530963185919585,
                                  -0.073204094929944785,
                                  0,
                                  0,
                                  0.15075898706641919,
                                  0,
                                  0,
                                  0.19461170757433788,
                                  0,
                                  0,
                                  0,
                                  -0.068068636597237109,
                                  0,
                                  0,
                                  0.02230706579294009,
                                  0,
                                  0.085952352274820565,
                                  0,
                                  0.22912690201207084,
                                  -0.17593501182132426,
                                  0,
                                  0,
                                  -0.56754636982505802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23848561033929336,
                                  0,
                                  0,
                                  0.20477089167959411,
                                  -0.10846147505352914,
                                  0,
                                  0,
                                  -0.026369535462440905,
                                  0,
                                  0,
                                  -0.0092821277363017846,
                                  0.17468764067900641,
                                  0,
                                  0.012040305895243096,
                                  0,
                                  0,
                                  -0.080549140777251421,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19867142443308486,
                                  0.37737590558272743,
                                  0,
                                  0,
                                  0,
                                  0.055040506807803868,
                                  0,
                                  0,
                                  -0.035299520267490371,
                                  0,
                                  -0.078020346146444,
                                  0.078872301398424299,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073395943130320315,
                                  -0.13056759462095613,
                                  0,
                                  -0.24730259686854114,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1201208087926917,
                                  0,
                                  0,
                                  -0.24771764210422159,
                                  -0.066214289588876679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072257996256099633,
                                  0,
                                  0,
                                  -0.54368658009825965,
                                  0,
                                  0,
                                  -0.26766721786403935,
                                  0,
                                  0,
                                  -0.06494229767355561,
                                  0,
                                  0,
                                  0,
                                  -0.12214039401668575,
                                  0,
                                  0,
                                  0.044443459355573887,
                                  0,
                                  -0.18827281495647666,
                                  0,
                                  -0.099561057423835031,
                                  0.078322670150530571,
                                  0,
                                  0,
                                  0.093925794102629911,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3214395113716178,
                                  0,
                                  0,
                                  0.062011497987000563,
                                  -0.17247376353582669,
                                  0,
                                  0,
                                  -0.046652946255784165,
                                  0,
                                  0,
                                  0.036407948329038473,
                                  -0.020158565722546047,
                                  0,
                                  0.28428262713637276,
                                  0,
                                  0,
                                  0.050327480630080038,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094851349858283515,
                                  -0.056047332786650195,
                                  0,
                                  0,
                                  0,
                                  0.13899846178184802,
                                  0,
                                  0,
                                  -0.10118946921242404,
                                  0,
                                  -0.24837933537902515,
                                  0.0019701984531166304,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049876393986145448,
                                  0.054358813483486895,
                                  0,
                                  -0.12734977489754351,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30689157995651417,
                                  0,
                                  0,
                                  0.062692799835020227,
                                  0.17153790768836194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27306781880636033,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1489997714441697,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70575735284054353,
                                  0,
                                  -0.13078774548897548,
                                  -0.52591836050154905,
                                  0.10087027423839443,
                                  0,
                                  0.36750626987414164,
                                  0,
                                  0,
                                  -0.26385245814000857,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20691528539545562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23923573825985964,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12830181220940728,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18535963482566881,
                                  0,
                                  0,
                                  0,
                                  -0.38651105072693953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25556259980491569,
                                  0,
                                  0,
                                  0.53306993532908464,
                                  -0.044339141790343595,
                                  0,
                                  0,
                                  -0.25087557534633254,
                                  0,
                                  0.45291932688211317,
                                  0.12461341429185938,
                                  0,
                                  0.31738240923534339,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33788381896689068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067314044688289582,
                                  0,
                                  0.058634930775965995,
                                  -0.10321147364222422,
                                  0,
                                  -0.2293293220813383,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019047742050591315,
                                  0,
                                  0,
                                  -0.19614957895240398,
                                  -0.18867429945652686,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16781945717982527,
                                  0,
                                  0,
                                  0.076377404089977369,
                                  0,
                                  -0.18371714608938178,
                                  0,
                                  -0.77308029261244149,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049358000911653724,
                                  0,
                                  0,
                                  -0.048362295587870065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.00548373199199019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19868019607588083,
                                  -0.36755392284629024,
                                  -0.63599305806754369,
                                  0.59773738648988661,
                                  0,
                                  0,
                                  0,
                                  0.22571241971454345,
                                  -0.055877788699990133,
                                  0,
                                  0,
                                  -0.10095783859002326,
                                  0,
                                  0.085708138040609894,
                                  0,
                                  0,
                                  -0.13260125128163652,
                                  0,
                                  0,
                                  0.16060912386205853,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13914209723468421,
                                  0,
                                  0,
                                  -0.25401732138608135,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55420415637334319,
                                  0.35346290859918156,
                                  0,
                                  0.42108135223654974,
                                  0.18543942016635392,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37170324968428037,
                                  0,
                                  0.46938523244859959,
                                  -0.44316337186872518,
                                  0,
                                  -0.083714058520400203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.067699684546598596,
                                  0,
                                  0,
                                  0.12683758794232006,
                                  -0.18140002783397424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39518690116837463,
                                  0,
                                  0,
                                  -0.019002525975877666,
                                  0,
                                  -0.079516365565286587,
                                  0,
                                  0.45348929464806009,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057114428683125149,
                                  0,
                                  0,
                                  -0.105704380661123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13939307873221021,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17111830526308153,
                                  -0.40146650789997079,
                                  -0.059067737372426161,
                                  0.16355208476213409,
                                  0,
                                  0,
                                  0,
                                  0.0016814324265694391,
                                  -0.17476024836264598,
                                  0,
                                  0,
                                  -0.16355442351149235,
                                  0,
                                  -0.69837369879676814,
                                  0,
                                  0,
                                  0.15252138692801739,
                                  0,
                                  0,
                                  -0.12894155266838991,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2150504981256316,
                                  0,
                                  0,
                                  -0.23582399196014092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.076309563344700793,
                                  -0.17397354236986573,
                                  0,
                                  -0.041335895815869009,
                                  0.12996634544003455,
                                  -0.11928280459969058,
                                  0,
                                  0,
                                  -0.10896476270928079,
                                  0,
                                  0,
                                  0.33009706081137558,
                                  0,
                                  0,
                                  0,
                                  0.22463933651872864,
                                  0,
                                  0,
                                  0.086499001430257155,
                                  0,
                                  -0.041133874301136741,
                                  0,
                                  0.071986215218870997,
                                  0.0035325135671923419,
                                  0,
                                  0,
                                  0.13879827794472591,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12227945085676629,
                                  0,
                                  0,
                                  -0.45384921121839344,
                                  0.12457523561524762,
                                  0,
                                  0,
                                  0.15952094207480194,
                                  0,
                                  0,
                                  0.079702489784922642,
                                  -0.10776628891132442,
                                  0,
                                  0.17195740900063805,
                                  0,
                                  0,
                                  0.17047040999774174,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.07160489026254252,
                                  0.12423390858771356,
                                  0,
                                  0,
                                  0,
                                  0.052281429734566662,
                                  0,
                                  0,
                                  0.19654334651624347,
                                  0,
                                  -0.061189282967751273,
                                  -0.016293151031614401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48512280007369801,
                                  -0.0009212547374230079,
                                  0,
                                  0.12952442356371918,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.022908416284467614,
                                  0,
                                  0,
                                  -0.29738372605062963,
                                  -0.14411336771372268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12066213936728001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.010299670651129082,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039734332679135301,
                                  0,
                                  0.18531444484162851,
                                  -0.57797573187573215,
                                  0.11466837060510027,
                                  0,
                                  0.16055357595136771,
                                  0,
                                  0,
                                  0.61616548146208827,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40496022947072713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5151010699252444,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.083821014008510442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25097286977285943,
                                  0,
                                  0,
                                  0,
                                  -0.24394654107791355,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24124161912547523,
                                  0,
                                  0,
                                  -0.067320550409351948,
                                  0.57251541278652696,
                                  0,
                                  0,
                                  -0.23406068427510177,
                                  0,
                                  -0.21662019382096254,
                                  0.59798491486588068,
                                  0,
                                  -0.084250853017961924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.011203279285268639,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11812678007180359,
                                  0,
                                  0.50776937782706399,
                                  -0.090868934108592439,
                                  0,
                                  -0.044981873758645347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.027209842481234994,
                                  0,
                                  0,
                                  0.36184967568271903,
                                  -0.04403149940960932,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21946832549101447,
                                  0,
                                  0,
                                  0.060295976176055768,
                                  0,
                                  0.018373599382029634,
                                  0,
                                  -0.14968704934152308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57971519811843042,
                                  0,
                                  0,
                                  -0.40153918344789508,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48361872426302044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24855519015952329,
                                  -0.27110464399213136,
                                  -0.22895357881616019,
                                  -0.54997216878758115,
                                  0,
                                  0,
                                  0,
                                  -0.11937914395723645,
                                  0.10205540594099761,
                                  0,
                                  0,
                                  0.059591618407784694,
                                  0,
                                  0.037177608805423715,
                                  0,
                                  0,
                                  0.14668096140403541,
                                  0,
                                  0,
                                  -0.15789491098946107,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45558333321849215,
                                  0,
                                  0,
                                  0.14376785494048921,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.096085506741070414,
                                  0.026777023638844176,
                                  0,
                                  0.055328834393269494,
                                  0.25269493424206108,
                                  0.044325803437771406,
                                  0,
                                  0,
                                  0.15915351531032099,
                                  0,
                                  0,
                                  -0.15614183990759098,
                                  0,
                                  0,
                                  0,
                                  0.20184866839492846,
                                  0,
                                  0,
                                  -0.30060665975440859,
                                  0,
                                  0.086891864235784377,
                                  0,
                                  -0.065394372826267422,
                                  -0.065410074804039833,
                                  0,
                                  0,
                                  -0.059818145321118774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.096036747616950524,
                                  0,
                                  0,
                                  0.12200460295397141,
                                  0.054746135807922876,
                                  0,
                                  0,
                                  0.31735785769834585,
                                  0,
                                  0,
                                  0.35386985018540307,
                                  -0.10213331287732731,
                                  0,
                                  0.084981918901099823,
                                  0,
                                  0,
                                  -0.15015781836101402,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23289118908275211,
                                  0.056433990820018751,
                                  0,
                                  0,
                                  0,
                                  -0.20930210408967931,
                                  0,
                                  0,
                                  0.22308980109708559,
                                  0,
                                  -0.47051157226621831,
                                  -0.25310053198833921,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0165592494373187,
                                  0.20029487186658942,
                                  0,
                                  -0.058042390770979564,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046382235941973153,
                                  0,
                                  0,
                                  -0.040909736878163773,
                                  0.14181522585660883,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.012273915772101672,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.432038606627699,
                                  0,
                                  0.010610294511100423,
                                  -0.21942705041551228,
                                  0,
                                  0.0042670221687062119,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14817652004233378,
                                  0,
                                  0,
                                  -0.31049524409174795,
                                  0.36165963858331462,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47531290258972891,
                                  0,
                                  0,
                                  -0.18943266223621244,
                                  0,
                                  -0.18902126646455569,
                                  0,
                                  -0.028004228910999674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26715518654403664,
                                  0,
                                  0,
                                  -0.094997259334169859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17240811985933432,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7463373893546511,
                                  -0.27585362554179793,
                                  0.0643026875075179,
                                  0.10919842105063879,
                                  0,
                                  0,
                                  0,
                                  0.04290367756857514,
                                  -0.17849152444359861,
                                  0,
                                  0,
                                  0.28512499406523739,
                                  0,
                                  0.15912146232136434,
                                  0,
                                  0,
                                  -0.03226247008883186,
                                  0,
                                  0,
                                  0.011518843181236514,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18566335555180513,
                                  0,
                                  0,
                                  -0.13924635372302391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61304810708630808,
                                  0.089700834856695222,
                                  0,
                                  0.079762948780898166,
                                  -0.14208070708337436,
                                  -0.1026354482910018,
                                  0,
                                  0,
                                  0.11577889421674512,
                                  0,
                                  0,
                                  0.068615664539043025,
                                  0,
                                  0,
                                  0,
                                  0.053605227620790882,
                                  0,
                                  0,
                                  0.25538912564755689,
                                  0,
                                  0.053205771681620162,
                                  0,
                                  0.063735727774237763,
                                  -0.0031561262003476668,
                                  0,
                                  0,
                                  -0.069986264464276596,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24540666158970084,
                                  0,
                                  0,
                                  -0.10701833219318962,
                                  -0.27993165411846249,
                                  0,
                                  0,
                                  -0.098137593835160977,
                                  0,
                                  0,
                                  0.2279494154952541,
                                  -0.24678680904567971,
                                  0,
                                  -0.078816043298319136,
                                  0,
                                  0,
                                  -0.016430674375133129,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21953666556990911,
                                  0.17681175618113154,
                                  0,
                                  0,
                                  0,
                                  -0.36138719419075482,
                                  0,
                                  0,
                                  0.040971856199259131,
                                  0,
                                  -0.073793863808752358,
                                  0.14953917853103499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03522168754100697,
                                  -0.46645024501930948,
                                  0,
                                  0.0017013763910648377,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33616002289013569,
                                  0,
                                  0,
                                  0.1784770553867544,
                                  0.094975506767465828,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.013973803208178776,
                                  0,
                                  0,
                                  -0.30273616218831084,
                                  0,
                                  0,
                                  0.060951134663666681,
                                  0,
                                  0,
                                  0.10239529544191811,
                                  0,
                                  0,
                                  0,
                                  0.016763682577551051,
                                  0,
                                  0,
                                  0.18823750979224632,
                                  0,
                                  -0.031444119594561525,
                                  0,
                                  -0.082136119031661597,
                                  -0.21730877736175752,
                                  0,
                                  0,
                                  -0.074468397244625534,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13173250325479777,
                                  0,
                                  0,
                                  0.060329950779846625,
                                  0.37312656402981365,
                                  0,
                                  0,
                                  -0.046555540899134273,
                                  0,
                                  0,
                                  -0.28545784331461216,
                                  -0.41826363364388131,
                                  0,
                                  0.09245312944454924,
                                  0,
                                  0,
                                  -0.26957906458995445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036276332382950395,
                                  0.10745900244280561,
                                  0,
                                  0,
                                  0,
                                  -0.10310351242782695,
                                  0,
                                  0,
                                  0.14115027952622189,
                                  0,
                                  0.17150174440447402,
                                  -0.20516061687634235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059898569155281772,
                                  0.21469870644139216,
                                  0,
                                  -0.28144130122679084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050341187999774765,
                                  0,
                                  0,
                                  0.16511901009578886,
                                  -0.072386020034941878,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13800745884770801,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36481515126308756,
                                  0,
                                  -0.37590558707545335,
                                  0.015408721703322355,
                                  0,
                                  -0.24144725724574403,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35655958764766243,
                                  0,
                                  0,
                                  -0.39571605991191905,
                                  0.15154964526313933,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37901987091109113,
                                  0,
                                  0,
                                  0.54452864549472768,
                                  0,
                                  -0.29143611350539861,
                                  0,
                                  0.31762729476882678,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1034197616216041,
                                  0,
                                  0,
                                  -0.13418259014723519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27807882208452528,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.041850626805222578,
                                  -0.18375354712785694,
                                  -0.092908688574783932,
                                  -0.41984907562360635,
                                  0,
                                  0,
                                  0,
                                  -0.20503933116822756,
                                  0.10822594238103925,
                                  0,
                                  0,
                                  0.02419526712264377,
                                  0,
                                  -0.22179282334431541,
                                  0,
                                  0,
                                  -0.74624234266544931,
                                  0,
                                  0,
                                  0.078016484920080981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1670375138079061,
                                  0,
                                  0,
                                  0.0045475327933630419,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14470903292065654,
                                  -0.15897044599638699,
                                  0,
                                  0.19300264885357507,
                                  0.32262404461565675,
                                  0,
                                  0,
                                  0.15708728803073679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27703490438266898,
                                  0,
                                  -0.09098559861921994,
                                  0.12467215213318958,
                                  -0.081283880267571815,
                                  0,
                                  0.4110656858226901,
                                  0,
                                  0,
                                  0.2929912180607786,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38425998621674956,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11208200144026348,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12121012983836438,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.078594400832538575,
                                  0,
                                  0,
                                  0,
                                  0.56877311235184569,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13191579942131676,
                                  0,
                                  0,
                                  0.42520679147189971,
                                  -0.086965131398200529,
                                  0,
                                  0,
                                  0.031555812639559283,
                                  0,
                                  -0.665151608714176,
                                  -0.0171887826660828,
                                  0,
                                  0.0081176356793939836,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052068213674177889,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21040568882163524,
                                  0,
                                  0,
                                  -0.6282503021175756,
                                  0.25437733018231795,
                                  0,
                                  0.31278548736337236,
                                  0.22749949331480762,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1247755627958272,
                                  0,
                                  0,
                                  0.30935993763872371,
                                  0,
                                  0,
                                  0.025926466081515262,
                                  0,
                                  0,
                                  -0.055466420165703051,
                                  -0.082392249869220502,
                                  0,
                                  -0.076905999773762668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23594590703160986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017924417502519489,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062905658916388135,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25671554318017076,
                                  0,
                                  0.19518595621724627,
                                  0,
                                  0.037772004524962016,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069837483013474547,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18261393082119881,
                                  0,
                                  0,
                                  0,
                                  -0.12412498851817895,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050942179675062885,
                                  0,
                                  -0.049290560329204605,
                                  -0.035826773953835697,
                                  0,
                                  -0.17201191364875248,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14223473237319062,
                                  0,
                                  0,
                                  -0.27412956989685106,
                                  -0.20808900176197176,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.036639624191861349,
                                  0,
                                  0,
                                  0.18547521445196313,
                                  0,
                                  0.16552986822460414,
                                  0,
                                  -0.15723942280622383,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35838439568247932,
                                  0,
                                  0,
                                  0.20809370283141007,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25297211973988309,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057148988215061064,
                                  0.15201303349153653,
                                  0.39498767698299775,
                                  -0.27343062619131464,
                                  0,
                                  0,
                                  0,
                                  0.28336680465062136,
                                  -0.12338620669903153,
                                  0,
                                  0,
                                  -0.28286937724382094,
                                  0,
                                  0.15503754076306081,
                                  0,
                                  0,
                                  0.52882299352088313,
                                  0,
                                  0,
                                  0.48008060705091204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.016583873532703013,
                                  0,
                                  0,
                                  -0.34223167924408732,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060899971545466502,
                                  0.39240518444056549,
                                  0,
                                  0.12540948207141955,
                                  0.69720381655465824,
                                  0,
                                  0,
                                  0.16205272529184123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34000585143356449,
                                  0,
                                  0.29202909847446534,
                                  -0.0011939520609665581,
                                  0.44871803444307201,
                                  0,
                                  0.28916940730886331,
                                  0,
                                  0,
                                  0.16741325122808423,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14250231507414104,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35436024869331162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1820042575452509,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14668512325681543,
                                  0,
                                  0,
                                  0,
                                  0.40329745129767669,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14939831229134959,
                                  0,
                                  0,
                                  -0.49136742846362275,
                                  0.17801200463940012,
                                  0,
                                  0,
                                  -0.13508764912350468,
                                  0,
                                  0.22339985324458858,
                                  0.39959730355981427,
                                  0,
                                  -0.42737632157180194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13760426399808995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42723445953290889,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21135921404696473,
                                  0,
                                  -0.37903736908571267,
                                  -0.40028357714288348,
                                  0.38373899742471007,
                                  0,
                                  0.49752437331791505,
                                  0,
                                  0,
                                  0.039063034078085875,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61872039176816374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10579972599229907,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.074770969376526011,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27963752480501841,
                                  0,
                                  0,
                                  0,
                                  -0.048973207797877033,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35910809541112049,
                                  0,
                                  0,
                                  -0.29033534184972959,
                                  -0.22197982682249209,
                                  0,
                                  0,
                                  0.33390574446480603,
                                  0,
                                  -0.42517138381676084,
                                  0.10066513948184377,
                                  0,
                                  0.089403761778186944,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050699948754946343,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085880793721453907,
                                  0,
                                  0,
                                  0.26343708834459739,
                                  0,
                                  0,
                                  0.014431354201946758,
                                  0,
                                  0,
                                  0,
                                  -0.20846295988572988,
                                  0,
                                  0,
                                  0.087723136818568595,
                                  0,
                                  -0.11456929819360373,
                                  0,
                                  0.1386120532999528,
                                  0.39090416267369216,
                                  0,
                                  0,
                                  0.15240621614199168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0010836405044543015,
                                  0,
                                  0,
                                  -0.23582180716332446,
                                  0.094312420978627076,
                                  0,
                                  0,
                                  0.02388895166485186,
                                  0,
                                  0,
                                  -0.088561159358192337,
                                  0.29356219634407116,
                                  0,
                                  0.21026445018195927,
                                  0,
                                  0,
                                  -0.28274149602766108,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26835457096068982,
                                  0.30638103923022336,
                                  0,
                                  0,
                                  0,
                                  -0.13374331513377505,
                                  0,
                                  0,
                                  -0.16747105243093263,
                                  0,
                                  -0.089069953325711368,
                                  0.017043908884937075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029555454240091147,
                                  0.10977677574613595,
                                  0,
                                  0.015184455114521739,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20381372491746275,
                                  0,
                                  0,
                                  0.20763146755185174,
                                  -0.19777952204930768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15255670799677984,
                                  0,
                                  0,
                                  0.20460923169816853,
                                  0,
                                  0,
                                  -0.2233428654508218,
                                  0,
                                  0,
                                  0.040130464820968687,
                                  0,
                                  0,
                                  0,
                                  -0.4169171555630039,
                                  0,
                                  0,
                                  0.40103456760498163,
                                  0,
                                  0.24694725832626893,
                                  0,
                                  0.15688873547912766,
                                  0.027037990066355995,
                                  0,
                                  0,
                                  0.15888141450478663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.054750888153285458,
                                  0,
                                  0,
                                  0.13440975824505055,
                                  0.047908371909420162,
                                  0,
                                  0,
                                  0.05273245781283907,
                                  0,
                                  0,
                                  0.24628023904252455,
                                  -0.096464126254060617,
                                  0,
                                  -0.15349375788503195,
                                  0,
                                  0,
                                  -0.24067959715687573,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10577553816748858,
                                  0.19774768214874303,
                                  0,
                                  0,
                                  0,
                                  0.18861068517321983,
                                  0,
                                  0,
                                  0.16532480863871929,
                                  0,
                                  -0.067669824355832159,
                                  0.0097844174303075831,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.090819768503864917,
                                  0.26013855132811414,
                                  0,
                                  0.15457507638098666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064249409741065133,
                                  0,
                                  0,
                                  -0.042893027102999338,
                                  0.22667332846592025,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.088320553069523175,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.81801239645018808,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0093653980468527687,
                                  0,
                                  -0.12459743799769291,
                                  0.38252732853336147,
                                  0.058442603692013331,
                                  0,
                                  0.54187779182145512,
                                  0,
                                  0,
                                  0.16680032560865621,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.045455892288499056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60581841079463172,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.093663784324175492,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10687870690694706,
                                  0,
                                  0,
                                  0,
                                  -0.43127417775715593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097915199633894417,
                                  0,
                                  0,
                                  0.2844632302497358,
                                  -0.043316636076469059,
                                  0,
                                  0,
                                  0.090827154562186277,
                                  0,
                                  0.44143544823678199,
                                  -0.024636396192765454,
                                  0,
                                  0.29124390478430484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33108094032550317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.034540776230147036,
                                  0,
                                  0,
                                  -0.11567505092802371,
                                  0,
                                  0,
                                  -0.26489048000805837,
                                  0,
                                  0,
                                  0,
                                  -0.085683199458088818,
                                  0,
                                  0,
                                  -0.13732952064896706,
                                  0,
                                  0.14012651775696164,
                                  0,
                                  -0.18132573274303457,
                                  0.13927370157653352,
                                  0,
                                  0,
                                  -0.34043125997613355,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24785844964796844,
                                  0,
                                  0,
                                  -0.23888624834152913,
                                  -0.21208447942293285,
                                  0,
                                  0,
                                  -0.13381081849331863,
                                  0,
                                  0,
                                  0.14383999711934281,
                                  -0.22658725173450558,
                                  0,
                                  0.14223581418301606,
                                  0,
                                  0,
                                  0.0069883933504891037,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13528451140773062,
                                  0.13951499862145247,
                                  0,
                                  0,
                                  0,
                                  0.26416890087708406,
                                  0,
                                  0,
                                  -0.014585688866450683,
                                  0,
                                  -0.17636286758910005,
                                  0.16749641879608496,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036880415042556444,
                                  0.21454967168315123,
                                  0,
                                  0.075603032770715881,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.037087131346188275,
                                  0,
                                  0,
                                  0.14208460796025163,
                                  -0.34627703928735598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25700962983105591,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028646558132173747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48188683184300812,
                                  0,
                                  -0.52899702604872134,
                                  -0.025396990943775313,
                                  0.43515560380645452,
                                  0,
                                  -0.081547468968664244,
                                  0,
                                  0,
                                  0.74895942774774416,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16563802712014056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14812598991373693,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2977858645948957,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.04224516988957383,
                                  0,
                                  0,
                                  0,
                                  -0.10795300815142468,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15395065483911122,
                                  0,
                                  0,
                                  -0.3097902360973106,
                                  0.049891428124207916,
                                  0,
                                  0,
                                  -0.38116503587823547,
                                  0,
                                  -0.13224636659481293,
                                  -0.63368245167559445,
                                  0,
                                  0.67923124855049288,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081285738982151301,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12156047700194673,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37491731724629607,
                                  0,
                                  0.080608675037832866,
                                  -0.054804722141544589,
                                  -0.093283097378807689,
                                  0,
                                  0.19941151442796468,
                                  0,
                                  0,
                                  0.15856161215613454,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34345082367455054,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20115888316239464,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.00090744157403584158,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10393889827348601,
                                  0,
                                  0,
                                  0,
                                  -0.10888331659957305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15710172478231066,
                                  0,
                                  0,
                                  0.47952159905297237,
                                  -0.1745380869939675,
                                  0,
                                  0,
                                  -0.72297227234367545,
                                  0,
                                  0.11318974894475956,
                                  -0.6955409912755266,
                                  0,
                                  -0.38186232670329912,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24329719690370788,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20639926660823776,
                                  0,
                                  0.42188709852724204,
                                  0.58355333160030309,
                                  0,
                                  0.35176720012116441,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29202164971463029,
                                  0,
                                  0,
                                  -0.23441624139356917,
                                  -0.32212320512886572,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.091596610216713725,
                                  0,
                                  0,
                                  -0.1112888015840262,
                                  0,
                                  -0.053499474933793992,
                                  0,
                                  0.012859100108803617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15175939775756986,
                                  0,
                                  0,
                                  0.10177340367523299,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0089931863389975664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31503706511614432,
                                  -0.25590457462962585,
                                  0.087830544135955618,
                                  -0.30507741364488361,
                                  0,
                                  0,
                                  0,
                                  -0.21485525466600502,
                                  0.11277919835337004,
                                  0,
                                  0,
                                  -0.39088555787882517,
                                  0,
                                  0.22757468880508541,
                                  0,
                                  0,
                                  -0.30458424998076472,
                                  0,
                                  0,
                                  0.010046337414577194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40845628501372999,
                                  0,
                                  0,
                                  -0.028534118183321799,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13555184273630261,
                                  -0.29470746728548047,
                                  0,
                                  0.13753209898542568,
                                  -0.028018643581331562,
                                  0,
                                  0,
                                  0.026723604622884978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36310258398340223,
                                  0,
                                  0.19384655142059001,
                                  -0.16726592990161263,
                                  0.13251269791407785,
                                  0,
                                  0.2466682700082114,
                                  0,
                                  0,
                                  -0.064364321707638214,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22112740366615363,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26677598121754997,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68956365778936213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.99578128183486125,
                                  0,
                                  0,
                                  0,
                                  -0.25578628848934487,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31056875600391204,
                                  0,
                                  0,
                                  0.03385389290522528,
                                  -0.028309508401344725,
                                  0,
                                  0,
                                  0.17420887963849968,
                                  0,
                                  -0.23201464584301565,
                                  -0.31868860713023317,
                                  0,
                                  0.068477688126560035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23441523358634364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10140320929134107,
                                  0,
                                  0,
                                  0.11163767495931209,
                                  0,
                                  0,
                                  -0.11445019287596223,
                                  0,
                                  0,
                                  0,
                                  -0.030720445225776223,
                                  0,
                                  0,
                                  -0.055297582202827406,
                                  0,
                                  -0.087144215327898816,
                                  0,
                                  -0.15078097895808942,
                                  0.055013294365888324,
                                  0,
                                  0,
                                  -0.0060583047033832098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11348578873718421,
                                  0,
                                  0,
                                  -0.11321841071657737,
                                  0.15052703216808636,
                                  0,
                                  0,
                                  -0.066819471919136536,
                                  0,
                                  0,
                                  0.11603256685305657,
                                  0.25182300348905379,
                                  0,
                                  -0.13381753565301016,
                                  0,
                                  0,
                                  -0.21975687720740975,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28455561956401171,
                                  -0.029869715819067312,
                                  0,
                                  0,
                                  0,
                                  0.19108247836051453,
                                  0,
                                  0,
                                  -0.035111044264077504,
                                  0,
                                  0.10222088757222744,
                                  0.2928860508193783,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069638145274262153,
                                  0.1005794514918766,
                                  0,
                                  -0.31886239444235481,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31791322752881068,
                                  0,
                                  0,
                                  -0.38974506872708153,
                                  0.21657677878669809,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31385880037842445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20352024651116637,
                                  0,
                                  0.39067679790343746,
                                  -0.095367364228767057,
                                  0,
                                  0.073903824367659229,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0070626813096427796,
                                  0,
                                  0,
                                  0.28928152377504257,
                                  0.37509159475087411,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4073216165780234,
                                  0,
                                  0,
                                  0.4572713733797083,
                                  0,
                                  -0.065509447973625803,
                                  0,
                                  0.070321349541196218,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.020672340861173345,
                                  0,
                                  0,
                                  0.24131593986659328,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23755639967808279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6024609627257892,
                                  0.23152305691207559,
                                  0.12995582792814964,
                                  -0.19149595686632415,
                                  0,
                                  0,
                                  0,
                                  0.097519529135932245,
                                  -0.4305999705770468,
                                  0,
                                  0,
                                  0.48034115536806793,
                                  0,
                                  -0.19090452101315655,
                                  0,
                                  0,
                                  -0.14434454550653181,
                                  0,
                                  0,
                                  0.053078851158003079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.04393354397798431,
                                  0,
                                  0,
                                  -0.17173178970005931,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13311009846896049,
                                  -0.10917366861234762,
                                  0,
                                  0.50010956906316861,
                                  -0.073296498212682526,
                                  0,
                                  -0.037178697354401283,
                                  0,
                                  0,
                                  -0.22641468360175171,
                                  -0.18134077278984381,
                                  0,
                                  0.060811374591596676,
                                  0.13878939112762162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053036102905007661,
                                  0,
                                  0,
                                  -0.1253360165240609,
                                  0,
                                  0,
                                  -0.14308467250457896,
                                  0,
                                  0,
                                  0.008729370240123031,
                                  0.074362270146450568,
                                  0,
                                  -0.29221202934955848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52836033622119705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46843850948473909,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063297505398993148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29012597777975091,
                                  0,
                                  0.016450642407571162,
                                  0,
                                  0.10218686869345603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.091906429516905738,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22532679180824267,
                                  0,
                                  0,
                                  0,
                                  0.32374292176775488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25252584194930217,
                                  0,
                                  0,
                                  -0.16279320223325316,
                                  0,
                                  0,
                                  0.43694610306278958,
                                  0,
                                  0,
                                  0,
                                  -0.099567550302684021,
                                  0,
                                  0,
                                  -0.32569816706724586,
                                  0,
                                  0.11815769038960433,
                                  0,
                                  -0.11314112155662338,
                                  0.16852741567795815,
                                  0,
                                  0,
                                  -0.060319296767879629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17723923794736909,
                                  0,
                                  0,
                                  0.19294589893661485,
                                  0.13692826279678583,
                                  0,
                                  0,
                                  -0.11296438317634046,
                                  0,
                                  0,
                                  0.10298172106193082,
                                  -0.12590726511343087,
                                  0,
                                  -0.36370822777809142,
                                  0,
                                  0,
                                  0.22905738618500776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26232557063985401,
                                  0.047607015184541711,
                                  0,
                                  0,
                                  0,
                                  -0.026859848280585338,
                                  0,
                                  0,
                                  -0.18852977576731952,
                                  0,
                                  -0.020634061420876367,
                                  0.0742959475345015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18090751103092079,
                                  0.16067481823120208,
                                  0,
                                  -0.020092961126548955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15183642772056369,
                                  0,
                                  0,
                                  0.05817047930155296,
                                  -0.0029586343337920269,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18429567046890877,
                                  0,
                                  0,
                                  -0.087586467936354592,
                                  0,
                                  0,
                                  0.18497057513685425,
                                  0,
                                  0,
                                  -0.054525832687435029,
                                  0,
                                  0,
                                  0,
                                  -0.3478422858692608,
                                  0,
                                  0,
                                  -0.12947459644033002,
                                  0,
                                  0.11228625398975647,
                                  0,
                                  0.20202376402021976,
                                  0.099375676114925426,
                                  0,
                                  0,
                                  -0.057213954204450489,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070660609517660317,
                                  0,
                                  0,
                                  -0.043408224514878253,
                                  0.36529612971937353,
                                  0,
                                  0,
                                  -0.25696420815110815,
                                  0,
                                  0,
                                  0.25871074789480253,
                                  0.008769406657003171,
                                  0,
                                  0.21431303596446832,
                                  0,
                                  0,
                                  0.42053880031297225,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.026311095191446525,
                                  0.066239224999023558,
                                  0,
                                  0,
                                  0,
                                  -0.015360633201192575,
                                  0,
                                  0,
                                  0.13630218891919732,
                                  0,
                                  0.14253843476830183,
                                  -0.2576834374305827,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26211641194080876,
                                  -0.11944983763954491,
                                  0,
                                  0.11594717625258427,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13447413934089172,
                                  0,
                                  0,
                                  -0.084734011926845099,
                                  0.051209027532587291,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14056287603743362,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26478098761429431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23545921561083782,
                                  0,
                                  0.26636648418570358,
                                  -0.55957487017307972,
                                  0.070692713347490332,
                                  0,
                                  -0.11562388665896536,
                                  0,
                                  0,
                                  0.58069770696495915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21141956226472464,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0049464574898319229,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19325065962396715,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16501688236790957,
                                  0,
                                  0,
                                  0,
                                  -0.07270346709406364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25303096491521221,
                                  0,
                                  0,
                                  0.17442955229556859,
                                  -0.49089437650511114,
                                  0,
                                  0,
                                  0.30006967208357205,
                                  0,
                                  0.32399055031398227,
                                  0.120842332268429,
                                  0,
                                  0.021157796551118171,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073083616667134005,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26400898504284454,
                                  0,
                                  0,
                                  0.34088348655175388,
                                  0.0010666329509622929,
                                  0,
                                  0.3846624708103854,
                                  -0.25248390552336869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20273915124863323,
                                  0,
                                  0,
                                  -0.29119609962917098,
                                  0,
                                  0,
                                  0.22656235967605859,
                                  0,
                                  0,
                                  0.091184751397674346,
                                  -0.21465867687199905,
                                  0,
                                  0.024404599464802314,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12409990330173244,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.04169617189657128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.00052637330252713194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29844928176078178,
                                  0,
                                  0.45120459785699918,
                                  0,
                                  -0.023821536315704772,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082886030512688891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10373974325006133,
                                  0,
                                  0,
                                  0,
                                  0.20535119033858645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31208249317878078,
                                  0,
                                  0.12174057371964553,
                                  0.2655767314952126,
                                  0,
                                  -0.47862547978329395,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092266421497051068,
                                  0,
                                  0,
                                  -0.033628156393939901,
                                  0.1046841463230585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3154176712618369,
                                  0,
                                  0,
                                  -0.39676988997969181,
                                  0,
                                  0.057576564378257596,
                                  0,
                                  -0.17942731453570265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032135352370809903,
                                  0,
                                  0,
                                  -0.24749801316245115,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017737771085614053,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13474857383035146,
                                  -0.26644479205485927,
                                  0.1240338506997235,
                                  0.018307547892367888,
                                  0,
                                  0,
                                  0,
                                  0.70451583998752365,
                                  -0.32838071887910802,
                                  0,
                                  0,
                                  0.11510093844154831,
                                  0,
                                  0.18884052835045823,
                                  0,
                                  0,
                                  0.007675768182710499,
                                  0,
                                  0,
                                  -0.0075534897408425401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15935774091293181,
                                  0,
                                  0,
                                  0.013214743787521138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3626929297158869,
                                  -0.46533788446285174,
                                  0,
                                  0.31898676100933815,
                                  0.11107110661940971,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33222402903836162,
                                  0,
                                  -0.10179633849769038,
                                  0.11223459347217901,
                                  0,
                                  -0.75308523491040513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58022571204346518,
                                  0,
                                  0,
                                  -0.08504098108822386,
                                  -0.21268854564725584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.099253936335309823,
                                  0,
                                  0,
                                  0.17787630651843025,
                                  0,
                                  0.13542997521955225,
                                  0,
                                  -0.093279703453176668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16279045368033834,
                                  0,
                                  0,
                                  0.33837014491594508,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2931901254428867,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37775359653569601,
                                  -0.0080415006912065816,
                                  0.3632286128841723,
                                  0.039215285570271839,
                                  0,
                                  0,
                                  0,
                                  -0.098426791129145721,
                                  0.21679540613018974,
                                  0,
                                  0,
                                  0.015389638487293703,
                                  0,
                                  -0.024230971756655579,
                                  0,
                                  0,
                                  -0.0395127933860972,
                                  0,
                                  0,
                                  -0.33531463320229543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068411706125886498,
                                  0,
                                  0,
                                  -0.47699758650996532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0056807189431486577,
                                  0.18173450240152514,
                                  0,
                                  0.00049433188253776225,
                                  -0.29166195307007942,
                                  -0.10280215425271261,
                                  0,
                                  0,
                                  0.11001254375327328,
                                  0,
                                  0,
                                  -0.064383373181193831,
                                  0,
                                  0,
                                  0,
                                  -0.40668177862657301,
                                  0,
                                  0,
                                  0.036069552583275141,
                                  0,
                                  0.117884648446278,
                                  0,
                                  -0.021432005109589598,
                                  -0.17367232110658776,
                                  0,
                                  0,
                                  -0.010736790523655927,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -9.6952686417482725e-05,
                                  0,
                                  0,
                                  0.13990931658690711,
                                  -0.28780472006884172,
                                  0,
                                  0,
                                  0.062213744696855672,
                                  0,
                                  0,
                                  -0.26825957263126632,
                                  0.054742453322473572,
                                  0,
                                  0.20758329822522217,
                                  0,
                                  0,
                                  0.19950003771401503,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31472487948227412,
                                  -0.23208941192779239,
                                  0,
                                  0,
                                  0,
                                  -0.040271894146623598,
                                  0,
                                  0,
                                  0.33506551546829516,
                                  0,
                                  -0.0089346220785971701,
                                  0.10181994707098231,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36037988036350455,
                                  0.032512972056372637,
                                  0,
                                  -0.040942139750678924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19687635802055273,
                                  0,
                                  0,
                                  0.083032677073574757,
                                  0.070300736570782854,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19306059837633935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085670493873778619,
                                  0,
                                  0.21231879752986757,
                                  -0.17303532167982297,
                                  0,
                                  0.35266353569842424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39082188075449575,
                                  0,
                                  0,
                                  -0.099079443148504184,
                                  0.14493099325938846,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22192302687395765,
                                  0,
                                  0,
                                  -0.0098788558677077587,
                                  0,
                                  -0.10609259851206425,
                                  0,
                                  -0.53354804117586152,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16480580273939435,
                                  0,
                                  0,
                                  0.14891144933586681,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42102034502525515,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22873303617120794,
                                  0.54767054882709021,
                                  -0.1689867655300295,
                                  0.083093878392033887,
                                  0,
                                  0,
                                  0,
                                  0.11254604486308632,
                                  0.026148917881377416,
                                  0,
                                  0,
                                  0.10932952380405922,
                                  0,
                                  -0.2400057733050602,
                                  0,
                                  0,
                                  0.07119910820322356,
                                  0,
                                  0,
                                  0.28902092090905046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14245786945283664,
                                  0,
                                  0,
                                  0.44102766210709693,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27544035520068089,
                                  -0.029287939256824672,
                                  0,
                                  -0.2408724967018101,
                                  0.32901046605649581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14296983555506212,
                                  0,
                                  0.32949551420594403,
                                  0.20308116317690358,
                                  0,
                                  0.070902698097385405,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54290289126374258,
                                  0,
                                  0,
                                  0.20270179679895911,
                                  0.27479457720105055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14599400939451215,
                                  0,
                                  0,
                                  0.29055745327580507,
                                  0,
                                  -0.30508597720741354,
                                  0,
                                  -0.16749676883222434,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23156922861728352,
                                  0,
                                  0,
                                  0.031919817412556194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29590299680219845,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11225384000743946,
                                  0.10878459955264452,
                                  -0.18838649832941287,
                                  0.2316188591671238,
                                  0,
                                  0,
                                  0,
                                  0.12977430315523986,
                                  0.40885022014519568,
                                  0,
                                  0,
                                  -0.14335721700773232,
                                  0,
                                  -0.074240564895860409,
                                  0,
                                  0,
                                  0.33702826964424693,
                                  0,
                                  0,
                                  -0.52562870736834433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25592529049739349,
                                  0,
                                  0,
                                  -0.34969100192223668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56293411217756206,
                                  0.038381292333491156,
                                  0,
                                  0.19565105090989218,
                                  0.088691354014473506};

const double rot_19_30[900] = {-0.41182862490004113,
                               0,
                               0,
                               0.19620407345203439,
                               0,
                               0,
                               0,
                               0.6260646309246275,
                               0,
                               0.37323727759753145,
                               0,
                               0,
                               0.16999450236411506,
                               0.10880906344695156,
                               0,
                               0,
                               0,
                               0,
                               -0.14423839627181545,
                               0,
                               0.045495476061496364,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44387617796769702,
                               0,
                               0,
                               0,
                               0,
                               -0.22421876719400863,
                               0,
                               0,
                               0.27219959402703564,
                               0.13011052859444294,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.58637836640085361,
                               0.10199747964888754,
                               0,
                               0.76582064590020138,
                               0,
                               0,
                               0,
                               0,
                               -0.26889448389523968,
                               0.53138035474348544,
                               0,
                               0,
                               0,
                               0.44518912963231017,
                               0,
                               0,
                               0.47588495083577292,
                               0,
                               0,
                               0,
                               0.56972061020806153,
                               0,
                               -0.17502463925437509,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39825115290128843,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.47327524206105043,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18901026424750864,
                               0,
                               0,
                               0.20013824353345186,
                               0,
                               0,
                               0.35789266472597087,
                               0,
                               0,
                               0,
                               0.33983476771753418,
                               0,
                               0.22933114547796449,
                               0,
                               0,
                               0.29908546131854874,
                               -0.044633300318021124,
                               0,
                               0,
                               0,
                               0,
                               0.391675930652853,
                               0,
                               0.1291482525828099,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63422671806495701,
                               0,
                               0,
                               0,
                               0,
                               0.30329671789531221,
                               0,
                               0,
                               -0.26764133611626711,
                               0.88900662490815918,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.46684442001635962,
                               -0.54285612190126853,
                               0,
                               0.00058314933102263794,
                               0,
                               0,
                               0,
                               0,
                               0.0080413010611841973,
                               -0.24747540936675286,
                               0,
                               0,
                               0,
                               -0.84484284613303617,
                               0,
                               0.5301136370474191,
                               0,
                               0,
                               1.2764527380715731,
                               0.38514364076818919,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10480906578535948,
                               -0.46733325129050451,
                               0,
                               -0.017159793074020352,
                               0,
                               0,
                               0,
                               0,
                               0.065962131238477439,
                               -0.50214169249525409,
                               0,
                               0,
                               0,
                               -0.0049866375341101055,
                               0,
                               0,
                               -0.30020255647057809,
                               0,
                               0,
                               0,
                               0.46309183150518368,
                               0,
                               -0.32049023856038383,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.38268896044764161,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.66277991282779392,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.083560363646273922,
                               0,
                               0,
                               -0.26483623254731958,
                               0,
                               0,
                               0.79110889970832099,
                               0,
                               0,
                               0,
                               -0.34139304388654557,
                               0,
                               0.06956725965980641,
                               0,
                               0,
                               -0.33327627425361062,
                               -0.085552819299257843,
                               0,
                               0,
                               0,
                               0,
                               -0.23237590084765389,
                               0,
                               -0.031720691369938499,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.096034073513366888,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44171505779432019,
                               0,
                               0,
                               0,
                               -0.2645402118994471,
                               0,
                               0.0073805529777283552,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.38624672612740535,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13982507886503395,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.7524056255238577,
                               0,
                               0,
                               0.080812383467263132,
                               0,
                               0,
                               -0.065749702700663618,
                               0,
                               0,
                               0,
                               0.27553845049089709,
                               0,
                               0.021622417700852832,
                               0,
                               0,
                               -0.28703737577517391,
                               0.45439695851011747,
                               0,
                               0,
                               0,
                               0,
                               -0.24688267051925131,
                               0,
                               -0.68112989054216211,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31464477882068881,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.47134707981588453,
                               0.32853345141858836,
                               0,
                               0,
                               0,
                               -0.01240210355402319,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0453758219871254,
                               -0.56842633393511122,
                               0,
                               0,
                               0,
                               0,
                               1.0207409475438893,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.78069969018105678,
                               0.57649335865791906,
                               0,
                               0,
                               0,
                               0.97446554030964072,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.76047751394170771,
                               0.40216647286179202,
                               0,
                               0,
                               0,
                               0,
                               0.36465245477827457,
                               0,
                               0.33293376581251743,
                               0,
                               0,
                               -0.090183286494270237,
                               0,
                               0,
                               0,
                               0.0044082833048935954,
                               0,
                               0.43643361633456706,
                               0,
                               0,
                               -0.53560495890578474,
                               0.36270483834445655,
                               0,
                               0,
                               0,
                               0,
                               -0.012841359239679218,
                               0,
                               0.52034754646766657,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.034269616359609414,
                               0,
                               0,
                               0,
                               -0.69382749252389242,
                               0,
                               0,
                               -0.26091057775241117,
                               0,
                               0,
                               0,
                               0.15164280631766702,
                               0,
                               -0.25505473151959368,
                               0,
                               0,
                               -0.34576708310220811,
                               0.034589592781562623,
                               0,
                               0,
                               0,
                               0,
                               0.20181933590279313,
                               0,
                               0.26035287982715333,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36498581094631222,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56476032865498516,
                               0,
                               0,
                               0,
                               -0.50163366274161159,
                               0,
                               0.12368230386340616,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.53815249674857202,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.34811875503069351,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.057596440273217871,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.89482351324092257,
                               0.99549632853118863,
                               0,
                               0,
                               0,
                               -0.59389381815706965,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10835489528122581,
                               0.4565763560018829,
                               0,
                               0,
                               0,
                               0,
                               -0.080919960743121022,
                               0,
                               0,
                               0.47197413086880041,
                               0,
                               0,
                               0.10743079404736849,
                               1.3000566114595227,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58210044250301751,
                               0.1296050283330889,
                               0,
                               0.16068370060471179,
                               0,
                               0,
                               0,
                               0,
                               0.11675666792941369,
                               0.47649996237763209,
                               0,
                               0,
                               0,
                               0.59006200828905531,
                               0,
                               -0.43573184117759284,
                               0,
                               0,
                               -0.23946067521749848,
                               -0.039014025873079047,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34758674343048945,
                               -0.45529922505303261,
                               0,
                               0.92984127382816428,
                               0,
                               0,
                               0,
                               0,
                               0.30101666325658055,
                               -0.408940807049258,
                               0,
                               0,
                               0,
                               -0.4646623705370021,
                               -0.016175210894814728,
                               0,
                               0,
                               0.24791455169922169,
                               0,
                               0,
                               0,
                               -0.097589108843117875,
                               0,
                               -0.22749811346194543,
                               0,
                               0,
                               -0.048786986923782416,
                               0.4825507555079962,
                               0,
                               0,
                               0,
                               0,
                               0.70580841524640725,
                               0,
                               -0.14720126473585313,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34918272968150676,
                               0,
                               0,
                               0,
                               0,
                               0.60113681300520971,
                               0,
                               0,
                               -0.27819631613158396,
                               -0.25921826826891442,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27819970248527942,
                               0.038772469408245511,
                               0,
                               0.26228865615181007,
                               0,
                               0,
                               0,
                               0,
                               0.91604049249647246,
                               -0.40733312095801549,
                               0,
                               0,
                               0,
                               0.3012968180177325,
                               0.3317645560771455,
                               0,
                               0,
                               0.24988661164313972,
                               0,
                               0,
                               0,
                               0.47669683893318815,
                               0,
                               -0.67288784863593742,
                               0,
                               0,
                               -0.19786535226665225,
                               -0.084324549899398166,
                               0,
                               0,
                               0,
                               0,
                               -0.18854087139914627,
                               0,
                               0.2351197404412784,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10188595430766859,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32968876699524219,
                               0,
                               0,
                               0,
                               -0.15086451098535553,
                               0,
                               -0.69472292236117761,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.4216367434338692,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.21311357685839952,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40337369439931503,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.96440277818505427,
                               -0.16799660871913269,
                               0,
                               0,
                               0,
                               0.86538295690871847,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51068938050362123,
                               -0.52106122925502119,
                               0,
                               0,
                               0,
                               0,
                               0.3016137606260843,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30171434609909131,
                               -0.11475958176843717,
                               0,
                               0,
                               0,
                               -0.6302669950846338,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31953806358999959,
                               0.58067238043942215,
                               0,
                               0,
                               0,
                               0,
                               1.2299496283203692,
                               0,
                               0,
                               0.79887528391095142,
                               0,
                               0,
                               0.33403746963178083,
                               -0.075102830993213535,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25131283372147373,
                               0.42832830598909882,
                               0,
                               0.46137335059968682,
                               0,
                               0,
                               0,
                               0,
                               -0.069008625877509139,
                               0.87975306475221526,
                               0,
                               0,
                               0,
                               -0.59226397424426369,
                               0,
                               -0.7147386364008389,
                               0,
                               0,
                               0.46607631741556471,
                               0.39236621528855004,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.066365261451927102,
                               0.43217060412868025,
                               0,
                               -0.37463407817550914,
                               0,
                               0,
                               0,
                               0,
                               1.0996341650083139,
                               -0.16438006472189903,
                               0,
                               0,
                               0,
                               -0.71594315260956354,
                               0.10536676838602965,
                               0,
                               0,
                               -0.055930216560601945,
                               0,
                               0,
                               0,
                               0.20076423077642966,
                               0,
                               0.20672049185675581,
                               0,
                               0,
                               -0.49013040146413833,
                               -0.63218310193873084,
                               0,
                               0,
                               0,
                               0,
                               0.36908876170742294,
                               0,
                               -0.31750915676175118,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.16064916252526118,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24627390131516955,
                               0,
                               0,
                               0,
                               -0.34144754489541901,
                               0,
                               -0.60717432335047905,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.27995176754205153,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3880440896069956,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.47450065653373308,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18331145965193904,
                               -0.080901863953035891,
                               0,
                               0,
                               0,
                               0.028016554160897655,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0203155642536024,
                               -0.91831990891481352,
                               0,
                               0,
                               0,
                               0,
                               0.098759707390750295,
                               0,
                               0,
                               0.1789766598326139,
                               0,
                               0,
                               0.073369664331397633,
                               -0.21226186382801765,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.029392209795230249,
                               -0.8438198047957518,
                               0,
                               -0.51392774297262245,
                               0,
                               0,
                               0,
                               0,
                               0.40441161615029109,
                               0.59647001559273904,
                               0,
                               0,
                               0,
                               -0.11098785986363448};

const double rot_19_2[4] = {-0.36521971548548221, -0.93092134975018459, 0.9309213497501827, -0.36521971548548138};

const double rot_20_50[2500] = {-0.088938621737266799,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73281153740557148,
                                -0.21097389758051394,
                                0.1693525854542397,
                                -0.15194177184408922,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29167071611238632,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68665793872058267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68692784597489276,
                                0,
                                0,
                                0,
                                0,
                                -0.38104695795222049,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66426224343312323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35857165738004482,
                                0,
                                0,
                                0.3836735805488759,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.085058191807599867,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29986453526423629,
                                0,
                                -0.14045267632675618,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25960218974989785,
                                -0.11696715312268238,
                                0,
                                0.46721878049642573,
                                0,
                                0.3637894358742233,
                                0,
                                0,
                                -0.4190818607235941,
                                0,
                                0,
                                0,
                                0,
                                -0.32147165005553779,
                                0,
                                0,
                                0.099430342762185278,
                                0,
                                0,
                                0,
                                0,
                                0.40999681380774156,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.042886229594043583,
                                0,
                                0,
                                0,
                                0,
                                -0.18228835032945362,
                                0,
                                -0.20172051639465557,
                                0,
                                0.22421104730619063,
                                0,
                                0,
                                0.073960080427566716,
                                0,
                                0,
                                0,
                                -0.057709119863578295,
                                0,
                                -0.35124805775696138,
                                0,
                                -0.47285942658127217,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.066887836271366227,
                                0,
                                0,
                                -0.013132990947513693,
                                0,
                                -0.02123542692296982,
                                0.48142818067391124,
                                0,
                                0,
                                0,
                                -0.635319060909731,
                                0,
                                0,
                                0.34219900011083976,
                                -0.3933028043378709,
                                0.36880985113421016,
                                -0.2402490265548608,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56204119011000042,
                                0,
                                0,
                                0.15939684131031773,
                                0.32415037063410262,
                                0,
                                0,
                                0.39297310804519303,
                                0,
                                -0.17882892098411379,
                                0,
                                0,
                                -0.48620875935715385,
                                0,
                                0,
                                0.32278347898789755,
                                0,
                                0,
                                0,
                                0,
                                -0.1484941231114506,
                                0,
                                -0.031603152420422477,
                                0,
                                0,
                                0,
                                0.22263893817972122,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2707205345882252,
                                0,
                                0,
                                -0.61761613903591428,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18429553111520033,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19697924924020738,
                                0,
                                0.30480543035042007,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.038273599566449934,
                                -0.4598456121952586,
                                0,
                                0.0047817614660176436,
                                0,
                                0.39980095237514524,
                                0,
                                0,
                                -0.082475189732825333,
                                0,
                                0,
                                0,
                                0,
                                -0.4239711427698305,
                                0,
                                0,
                                -0.43376532351310876,
                                0,
                                0,
                                0,
                                0,
                                -0.024799739189597707,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43835802491350517,
                                0,
                                0,
                                0,
                                0,
                                -0.24736806908729128,
                                0,
                                -0.13297127860899025,
                                0,
                                0.20320358458955523,
                                0,
                                0,
                                -0.13410112324238793,
                                0,
                                0,
                                0,
                                0.26187853387904791,
                                0,
                                0.34904382782304877,
                                0,
                                0.034787141666825644,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30422178005113126,
                                0,
                                0,
                                0.065817998896132032,
                                0,
                                -0.11253735305953391,
                                0.0025567203810550193,
                                0,
                                0,
                                0,
                                -0.035587769991554871,
                                0,
                                0,
                                -0.22535523858604156,
                                -0.011964682151586671,
                                -0.4440568604665231,
                                -0.32853791995212123,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22460563239036924,
                                0,
                                0,
                                0.54885560720830162,
                                0.71377018672350423,
                                0,
                                0,
                                0.27178244440239163,
                                0,
                                0.26251726596720243,
                                0,
                                0,
                                0.036253619780588477,
                                0,
                                0,
                                0.083681722738361358,
                                0,
                                0,
                                0,
                                0,
                                -0.23813065234852232,
                                0,
                                0.25490846520270188,
                                0,
                                0,
                                0,
                                0.23846278189757053,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26023225690319829,
                                0,
                                0,
                                -0.022219551961669387,
                                0.50090892853500013,
                                0.090635034162592831,
                                0.54347641511505829,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54967976223092085,
                                0,
                                0,
                                0.29440187210327362,
                                0.69258750105676792,
                                0,
                                0,
                                -0.091528777753355495,
                                0,
                                0.060207857202374135,
                                0,
                                0,
                                0.112662657977327,
                                0,
                                0,
                                0.16825685753936079,
                                0,
                                0,
                                0,
                                0,
                                -0.23998761537235297,
                                0,
                                -0.030598819584485654,
                                0,
                                0,
                                0,
                                -0.56709448525255646,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23377810662996784,
                                0,
                                0,
                                -0.16062112320242311,
                                -0.49427699382564733,
                                -0.47106874429439105,
                                0.36013978776807137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00050132298955989085,
                                0,
                                0,
                                0.10408669023565437,
                                0.088038747251500696,
                                0,
                                0,
                                -0.19456651904176109,
                                0,
                                0.088058063458773539,
                                0,
                                0,
                                -0.55866478293829791,
                                0,
                                0,
                                -0.47454601132741414,
                                0,
                                0,
                                0,
                                0,
                                -0.31890012222749753,
                                0,
                                -0.61808636868157429,
                                0,
                                0,
                                0,
                                -0.30949968896099966,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.012459328735853092,
                                0,
                                0,
                                -0.29708761456820609,
                                -0.30300529703878049,
                                0.29819242752277553,
                                -0.065576401977346696,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18639144145954545,
                                0,
                                0,
                                0.11639082920455231,
                                -0.17305235209330697,
                                0,
                                0,
                                0.68726303495645635,
                                0,
                                0.95177881752350035,
                                0,
                                0,
                                0.53153436930754028,
                                0,
                                0,
                                -0.19508850829413313,
                                0,
                                0,
                                0,
                                0,
                                0.28312735536633055,
                                0,
                                -0.24086139503128123,
                                0,
                                0,
                                0,
                                -0.31688659546083703,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2503073683285677,
                                0,
                                0,
                                -0.054237328663630756,
                                0,
                                0,
                                0,
                                0,
                                0.38575117232601003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32883574069540172,
                                0,
                                0,
                                0,
                                0,
                                -0.044710508208222803,
                                0,
                                -0.10043070989742173,
                                0,
                                0.37565635997861618,
                                0,
                                0,
                                -0.030320948871053216,
                                0,
                                0,
                                0,
                                -0.44750517427618164,
                                0,
                                0.17790711229490999,
                                0,
                                0.20158336878530037,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37019971219850917,
                                0,
                                0,
                                -0.24594555001620805,
                                0,
                                -0.18177553906610347,
                                -0.14219051021573342,
                                -1.2345425827752083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58526109947297611,
                                0.45445627896683699,
                                0.072618487990958464,
                                0.14955025586209938,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41693250796071124,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32655898594369859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.060922400078959972,
                                0,
                                0,
                                0,
                                0,
                                -0.091342626294489859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48441277487116474,
                                0,
                                0,
                                0,
                                0,
                                0.35542353163219875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17762205722560925,
                                0.69632114775619525,
                                0.55870813469797409,
                                0.66720269626525563,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62210990053555093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.032888052348538185,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.047094609001936953,
                                0,
                                0,
                                0,
                                0,
                                -0.13778453980255806,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85249811978723289,
                                0,
                                0,
                                0,
                                0,
                                0.34324745834687831,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17471636708784186,
                                0.41178916675981753,
                                -0.29064893110741258,
                                -0.71490672543387024,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24580959148751033,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6548613521538601,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3335616534782207,
                                0,
                                0,
                                0,
                                0,
                                0.14316516613727842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68714511265515343,
                                0,
                                0,
                                0,
                                0,
                                0.63457659439790237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.062808411509148718,
                                -0.36506064285073542,
                                0.32498644097932539,
                                0.48612835763815726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60972449964852093,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3698527990079325,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65412664561208544,
                                0,
                                0,
                                0,
                                0,
                                -0.53765530516454918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46858864166354969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.098333731741238356,
                                0,
                                0,
                                0.46828323853540249,
                                0.0017193073536511255,
                                -0.3264425489578795,
                                -0.049445658339702242,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23202287458384088,
                                0,
                                0,
                                -0.087612024836895647,
                                0.065556693912517616,
                                0,
                                0,
                                0.083899230263074442,
                                0,
                                0.075750950130858696,
                                0,
                                0,
                                -0.46443590966458798,
                                0,
                                0,
                                -0.28242710709644464,
                                0,
                                0,
                                0,
                                0,
                                0.96835045454669977,
                                0,
                                0.42269253493392822,
                                0,
                                0,
                                0,
                                -0.13694996539874463,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1051590530243577,
                                0,
                                0,
                                -0.081351546486955625,
                                0,
                                0,
                                0,
                                0,
                                -0.49742749738006992,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43061181539827742,
                                0,
                                0,
                                0,
                                0,
                                -0.27049415741802074,
                                0,
                                0.18302101512342725,
                                0,
                                0.32643899626812223,
                                0,
                                0,
                                -0.27013467803654478,
                                0,
                                0,
                                0,
                                -0.090055155752829144,
                                0,
                                0.20153991663961968,
                                0,
                                -0.11375666144726032,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31529177463016206,
                                0,
                                0,
                                -0.21985359688325107,
                                0,
                                -0.16516176542413993,
                                0.16300963754915282,
                                0,
                                0.082276071010008944,
                                0,
                                0,
                                -0.23650883841686363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40217099181408139,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19566388274184446,
                                0,
                                -0.3907975856177941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48031339126460593,
                                0.19088416323750937,
                                0,
                                -0.37722131361874517,
                                0,
                                0.28390474696735424,
                                0,
                                0,
                                -0.30742488594287409,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1250522921939905,
                                0,
                                0,
                                -0.57214558220949396,
                                0.046288416651562206,
                                -0.090052298583137194,
                                -0.39153347581071585,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61896317403733314,
                                0,
                                0,
                                -0.48033781104842249,
                                -0.15011348604593938,
                                0,
                                0,
                                0.24562957241185024,
                                0,
                                -0.17645997168290117,
                                0,
                                0,
                                0.17368393561219725,
                                0,
                                0,
                                -0.34084278623770531,
                                0,
                                0,
                                0,
                                0,
                                -0.72211664254824259,
                                0,
                                0.68685949350818232,
                                0,
                                0,
                                0,
                                -0.1643733212633246,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46810526949230813,
                                0,
                                0,
                                -0.35885465028682573,
                                0.070368078863968786,
                                0.63358976321734006,
                                0.30751109436551177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42738552588841017,
                                0,
                                0,
                                0.091227008832214795,
                                -0.45442981960786732,
                                0,
                                0,
                                0.036853023245157684,
                                0,
                                0.68921196546921237,
                                0,
                                0,
                                -0.6378850220694986,
                                0,
                                0,
                                -0.51447825854047968,
                                0,
                                0,
                                0,
                                0,
                                -0.095245897744947183,
                                0,
                                0.63711247586124942,
                                0,
                                0,
                                0,
                                0.054826493935335133,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2842736541896202,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1254367149585795,
                                0.12677794028378153,
                                0.84978160011680548,
                                -0.605763127333796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10465304829800311,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30546556556295695,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27528829558548995,
                                0,
                                0,
                                0,
                                0,
                                0.24139974441362877,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22293124942663248,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25000622896993868,
                                0,
                                0,
                                0.20272517157754574,
                                0,
                                0,
                                0,
                                0,
                                -0.0019341380087921564,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25846878863094208,
                                0,
                                0,
                                0,
                                0,
                                -0.44184062146186709,
                                0,
                                0.24234417065294964,
                                0,
                                -0.21714267365218096,
                                0,
                                0,
                                -0.29639628741609592,
                                0,
                                0,
                                0,
                                -0.051670520181277282,
                                0,
                                -0.25576661707104587,
                                0,
                                0.13781863850835052,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39338046304724827,
                                0,
                                0,
                                0.38549377125376688,
                                0,
                                0.1002317857362381,
                                -0.20038356599807305,
                                0,
                                0,
                                0,
                                -0.83795315847283869,
                                0,
                                0,
                                -0.19142569534222936,
                                -0.69646004081298762,
                                0.01861827727450388,
                                0.31237100921604566,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.081538767381665267,
                                0,
                                0,
                                0.38026994183418739,
                                -0.019959122962181969,
                                0,
                                0,
                                -0.1917172735734044,
                                0,
                                -0.41797449261988084,
                                0,
                                0,
                                0.65963785857547175,
                                0,
                                0,
                                -0.4048333753275456,
                                0,
                                0,
                                0,
                                0,
                                0.45515612656982635,
                                0,
                                0.21576021701392306,
                                0,
                                0,
                                0,
                                -0.092416918788129715,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22215080120744521,
                                0,
                                0,
                                -0.30403159321324408,
                                0,
                                0,
                                0,
                                0,
                                -0.0091746286450269873,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19546600069383402,
                                0,
                                0,
                                0,
                                0,
                                -0.13096511218003326,
                                0,
                                -0.35509342019638551,
                                0,
                                0.31034350210036743,
                                0,
                                0,
                                -0.25526815567312489,
                                0,
                                0,
                                0,
                                0.0057962388226438614,
                                0,
                                -0.24188966272997997,
                                0,
                                -0.013768974769429131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.058006176372055601,
                                0,
                                0,
                                0.099177341801938046,
                                0,
                                0.61561529743293741,
                                -0.25355022440801278,
                                0,
                                0,
                                0,
                                0.46406224287491549,
                                0,
                                0,
                                0.16492360651890398,
                                0.1573475538732475,
                                0.24972582205707924,
                                -0.33543878497683005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.056282407332281438,
                                0,
                                0,
                                0.66721420422681033,
                                -0.20845085691161566,
                                0,
                                0,
                                -0.38328270404842329,
                                0,
                                -0.32502503119633286,
                                0,
                                0,
                                0.39416553462420989,
                                0,
                                0,
                                -0.69039024372519264,
                                0,
                                0,
                                0,
                                0,
                                -0.19127851533342749,
                                0,
                                0.010115229078123254,
                                0,
                                0,
                                0,
                                -0.030308338869858221,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39003306396930332,
                                0,
                                0,
                                0.22595697707673368,
                                0,
                                0,
                                0,
                                0,
                                -0.16361225047991865,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.073919202505644099,
                                0,
                                0,
                                0,
                                0,
                                -0.27588877586251609,
                                0,
                                0.043492315513370697,
                                0,
                                0.44568126034734168,
                                0,
                                0,
                                0.41826932345933254,
                                0,
                                0,
                                0,
                                0.19722607220342536,
                                0,
                                0.028134826667724405,
                                0,
                                -0.045570769074831,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.063867232856765363,
                                0,
                                0,
                                0.49017975435275379,
                                0,
                                -0.16314644644166454,
                                0.01609535859164743,
                                -0.53533638558152252,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20847768332956784,
                                0.60725357473891273,
                                0.18091376453366137,
                                -0.21904622679525593,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.060665999882921984,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58691912016821624,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36231006293624335,
                                0,
                                0,
                                0,
                                0,
                                -0.95494331466248328,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10110431528911784,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16688458279735502,
                                0,
                                0,
                                0.047769984966305662,
                                -0.207267652143001,
                                -0.10247919418312458,
                                0.15220722289398222,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19045375134389647,
                                0,
                                0,
                                0.51772265830831776,
                                -0.4642286081999959,
                                0,
                                0,
                                0.12705704770565318,
                                0,
                                -0.2502131448029884,
                                0,
                                0,
                                0.21211651650309848,
                                0,
                                0,
                                0.43025004440942288,
                                0,
                                0,
                                0,
                                0,
                                -0.3182102507144538,
                                0,
                                0.74301868727502296,
                                0,
                                0,
                                0,
                                -0.81569443415725129,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39752331720717887,
                                0,
                                0,
                                0.0085423288123984229,
                                0,
                                0,
                                0,
                                0,
                                -0.050956451170893785,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28603438700450962,
                                0,
                                0,
                                0,
                                0,
                                0.093442643554645488,
                                0,
                                0.30962117992051114,
                                0,
                                0.054135389467061826,
                                0,
                                0,
                                -0.56053944397514799,
                                0,
                                0,
                                0,
                                -0.12946704382577906,
                                0,
                                -0.16040913011365671,
                                0,
                                -0.073667979538763667,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34851659795928897,
                                0,
                                0,
                                0.05305058777910631,
                                0,
                                -0.049971260565650488,
                                0.40132656606065853,
                                0,
                                0.33759928962922697,
                                0,
                                0,
                                -0.38728402005943147,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.098244527776887053,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26615601934251443,
                                0,
                                0.28210344519146296,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52062638229167801,
                                0.12405918333802241,
                                0,
                                0.49002435822600221,
                                0,
                                -0.20298617977030917,
                                0,
                                0,
                                0.090524405814294023,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.035955148929455436,
                                0,
                                0,
                                -0.40512183705041943,
                                0.27980648087807464,
                                0.53000286797670582,
                                0.15371510554291454,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45036891460328166,
                                0,
                                0,
                                0.05522587105003568,
                                0.089520473374315845,
                                0,
                                0,
                                0.60777931585505374,
                                0,
                                -0.72690869625026766,
                                0,
                                0,
                                -0.19751324072848978,
                                0,
                                0,
                                0.18106392560797432,
                                0,
                                0,
                                0,
                                0,
                                0.23960856480452511,
                                0,
                                -0.30427038002400442,
                                0,
                                0,
                                0,
                                -0.29261309703282273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16919380272741277,
                                0,
                                0,
                                0.28809966420709449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15968340031687403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.080898678578494823,
                                0,
                                0.38088962023206052,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36223136917989252,
                                -0.4292698573566347,
                                0,
                                -0.45399477078369976,
                                0,
                                -0.28591123370684768,
                                0,
                                0,
                                -0.32849823828709723,
                                0,
                                0,
                                0,
                                0,
                                -0.19762688547341645,
                                0,
                                0,
                                0.50822617955457738,
                                0,
                                0,
                                0,
                                0,
                                0.16910338206147613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30249210746355271,
                                0,
                                0,
                                0,
                                0,
                                0.12547358126280023,
                                0,
                                -0.30289448512502126,
                                0,
                                0.20753919754467304,
                                0,
                                0,
                                -0.40209647255063874,
                                0,
                                0,
                                0,
                                0.013694735810088498,
                                0,
                                0.10539639347245311,
                                0,
                                0.27479415269416047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2568974569616661,
                                0,
                                0,
                                0.17718813761733734,
                                0,
                                -0.25541512860800775,
                                -0.14447475853421371,
                                0.29676167892741545,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30539407910762711,
                                -0.42200403238142875,
                                -0.392625839777338,
                                -0.34657692648032989,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.84638965080475004,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56983837678616933,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25830014190391903,
                                0,
                                0,
                                0,
                                0,
                                -0.10563088099318541,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1796144228702049,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16890281768024834,
                                0,
                                0,
                                -0.34927617166476627,
                                0,
                                0,
                                0,
                                0,
                                0.049119736916045265,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13169840501598828,
                                0,
                                0,
                                0,
                                0,
                                0.18911097962681095,
                                0,
                                -0.35154652555434307,
                                0,
                                -0.26066029693376236,
                                0,
                                0,
                                -0.13888968931632667,
                                0,
                                0,
                                0,
                                0.034866573573424389,
                                0,
                                0.17038935065713132,
                                0,
                                0.052900145179189159,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37576893927138599,
                                0,
                                0,
                                0.50689291053943564,
                                0,
                                -0.20521350925824244,
                                0.33141632461186937,
                                0,
                                0,
                                0,
                                -0.69114901086752578,
                                0,
                                0,
                                -0.50538096924608622,
                                0.20833008170609099,
                                -0.44456570709854631,
                                -0.23624070002084147,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37668310581936759,
                                0,
                                0,
                                0.62488582735626952,
                                -0.51945627639347636,
                                0,
                                0,
                                -0.32858129877930897,
                                0,
                                -0.43016360800844378,
                                0,
                                0,
                                -0.25387530616850879,
                                0,
                                0,
                                0.36195915957245711,
                                0,
                                0,
                                0,
                                0,
                                0.30135102308199957,
                                0,
                                -0.52263286410189003,
                                0,
                                0,
                                0,
                                0.21362764923258995,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.055063064474458981,
                                0,
                                0,
                                -0.18816607517375955,
                                0,
                                0,
                                0,
                                0,
                                0.24325875795166726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2437216009418674,
                                0,
                                0,
                                0,
                                0,
                                -0.0045815862193384765,
                                0,
                                0.31743340310183027,
                                0,
                                -0.050893503403547313,
                                0,
                                0,
                                0.0023552277503367941,
                                0,
                                0,
                                0,
                                -0.43346701901516987,
                                0,
                                0.26814905084498619,
                                0,
                                -0.44758144358467628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22210668271739012,
                                0,
                                0,
                                0.34435495041958131,
                                0,
                                -0.050990386169853449,
                                -0.33010217255076868,
                                0,
                                0,
                                0,
                                -0.67354152153633451,
                                0,
                                0,
                                0.69775312236128861,
                                0.33009463022831159,
                                -0.39005571003879619,
                                -0.175880779900877,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38985224006294233,
                                0,
                                0,
                                -0.12888573941798423,
                                -0.25615287682798388,
                                0,
                                0,
                                0.54951446697212047,
                                0,
                                -0.011548927362008583,
                                0,
                                0,
                                0.17791914511945284,
                                0,
                                0,
                                -0.39695560921469758,
                                0,
                                0,
                                0,
                                0,
                                -0.40411429023592588,
                                0,
                                -0.39326131928023522,
                                0,
                                0,
                                0,
                                -0.16513498334490198,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54903063245475003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29248014686226326,
                                -0.26811565036693497,
                                0.07976433748559153,
                                0.10234630515094784,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22461318867757399,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55769892637144558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79750169368777613,
                                0,
                                0,
                                0,
                                0,
                                0.2701697933584743,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36367917166103408,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23497523646441038,
                                0,
                                0,
                                0.26461655237769649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70009562073672427,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1601621284738248,
                                0,
                                0.13826041440425163,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1076597048894406,
                                -0.4664935513842392,
                                0,
                                0.19328472205790229,
                                0,
                                0.19571235523661368,
                                0,
                                0,
                                0.1870663929725791,
                                0,
                                0,
                                0,
                                0.25565688282934829,
                                0,
                                0,
                                -0.02549551949180379,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12469761586585611,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66597793518230974,
                                0,
                                -0.1386605124853047,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00040008490203721769,
                                -0.13039524841478148,
                                0,
                                -0.30801495849325033,
                                0,
                                0.44305793297069906,
                                0,
                                0,
                                0.38407039194901149,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32067933136228388,
                                0,
                                0,
                                0.060439012693369425,
                                0.23709117517864825,
                                -0.19175222147667131,
                                0.75192455061026864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29302385668310343,
                                0,
                                0,
                                0.2329740278467512,
                                -0.45205588752250153,
                                0,
                                0,
                                0.32717281239969764,
                                0,
                                0.013119235845679018,
                                0,
                                0,
                                0.079402847109428173,
                                0,
                                0,
                                -0.32162275563757636,
                                0,
                                0,
                                0,
                                0,
                                -0.091477602884792064,
                                0,
                                -0.096742100589335175,
                                0,
                                0,
                                0,
                                0.61414792903843141,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36871620633844848,
                                0,
                                0,
                                0.26663213032879984,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.09046840378267515,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28527900391864869,
                                0,
                                0.21545895235719187,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49041761504911119,
                                0.14847565506232027,
                                0,
                                -0.090203192662026921,
                                0,
                                0.15847676698105295,
                                0,
                                0,
                                0.60096464539373318,
                                0,
                                0,
                                0,
                                0,
                                -0.022429720407757651,
                                0,
                                0,
                                -0.40678392207702035,
                                0,
                                0,
                                0,
                                0,
                                0.061427787299666303,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25398786690363612,
                                0,
                                0,
                                0,
                                0,
                                -0.19733972102761421,
                                0,
                                0.096286152586293305,
                                0,
                                -0.01073916829307725,
                                0,
                                0,
                                0.13751007435003149,
                                0,
                                0,
                                0,
                                -0.13342764416132066,
                                0,
                                -0.52531187666760704,
                                0,
                                0.41220180873507217,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22406126081701239,
                                0,
                                0,
                                -0.011158902735029425,
                                0,
                                -0.4277847704742232,
                                -0.038840509252275009,
                                0,
                                -0.42155127030460277,
                                0,
                                0,
                                -0.06012091880634915,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4549945853055683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38979460165726809,
                                0,
                                0.49595379859748978,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17118441982644306,
                                0.33920798129169277,
                                0,
                                -0.22729883154170061,
                                0,
                                -0.0056006902037177703,
                                0,
                                0,
                                -0.13299488873772575,
                                0,
                                0,
                                -0.040473730162449997,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57751143157524831,
                                -0.92241792440377812,
                                0.88086296171919964,
                                -0.11582886094953074,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10865768107746844,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.77552959009573386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51076032042458319,
                                0,
                                0,
                                0,
                                0,
                                -0.20663343774630205,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.042474806976804717,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.020552883927785634,
                                0,
                                0,
                                0.15731424642279099,
                                0,
                                0,
                                0,
                                0,
                                -0.29584848467113445,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.06837618637819344,
                                0,
                                0,
                                0,
                                0,
                                -0.37533260549835185,
                                0,
                                -0.40067299884793584,
                                0,
                                -0.29211992569362349,
                                0,
                                0,
                                0.14637585066920128,
                                0,
                                0,
                                0,
                                -0.56830459174008419,
                                0,
                                0.14273128595536488,
                                0,
                                0.084754326783643558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2658577726659731,
                                0,
                                0,
                                -0.0098684231718238757,
                                0,
                                0.10827427812265533,
                                0.20353902679538358,
                                0,
                                -0.46318102916037124,
                                0,
                                0,
                                -0.1924551114520956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20253394942098946,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23045606721670542,
                                0,
                                -0.42337840688841588,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12951127828314349,
                                -0.40869843875940232,
                                0,
                                -0.033453395694159643,
                                0,
                                -0.49448559673065484,
                                0,
                                0,
                                0.21354711234999993,
                                0,
                                0,
                                0,
                                0,
                                -0.36138186490945179,
                                0,
                                0,
                                -0.040735687704348551,
                                0,
                                0,
                                0,
                                0,
                                -0.39021678076309624,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20864947689657359,
                                0,
                                0,
                                0,
                                0,
                                0.54906501787734552,
                                0,
                                0.00094784490140008401,
                                0,
                                0.3144895741101103,
                                0,
                                0,
                                0.12926580156229112,
                                0,
                                0,
                                0,
                                -0.35817263266518373,
                                0,
                                -0.23004633753983375,
                                0,
                                0.054798377554835472,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.064457478222250675,
                                0,
                                0,
                                0.24955930109341312,
                                0,
                                0.064753318963414769,
                                0.0037364894164753186,
                                0,
                                0,
                                0.13801708984968339,
                                0,
                                0,
                                0.012836051606291223,
                                0,
                                0,
                                0,
                                0,
                                -0.26803675075616384,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19795159731579443,
                                0,
                                0,
                                0,
                                0,
                                0.019371114589440845,
                                0,
                                -0.35994554370629428,
                                0,
                                -0.13331017820860563,
                                0,
                                0,
                                -0.14988789658205909,
                                0,
                                0,
                                0,
                                0.054750712662671563,
                                0,
                                -0.26605103179637773,
                                0,
                                -0.48599821739554899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.035973603417781594,
                                0,
                                0,
                                -0.1253810444091312,
                                0,
                                -0.44671639439297539,
                                -0.41597940039675285};

const double rot_20_20[400] = {0.11395189904660478,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18774247741532207,
                               0.76151883692509792,
                               0,
                               0,
                               0,
                               0.76570386250892375,
                               0,
                               0.54607084281139773,
                               0,
                               0,
                               0,
                               -0.56921467661566871,
                               0,
                               -0.20130359317847268,
                               -0.021871778962026633,
                               0,
                               0,
                               0.18098868059957166,
                               0,
                               0,
                               0,
                               0,
                               0.020311025251759235,
                               -0.57470780065461691,
                               0,
                               0,
                               -0.77171237664900283,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14811476802640483,
                               0.07230795921214328,
                               0,
                               0,
                               -0.53736753164722884,
                               0,
                               0,
                               0,
                               0,
                               -0.22457456153625383,
                               -0.68114936821041117,
                               0,
                               0,
                               0.41191202332024879,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0664784873518296,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.7246853337808089,
                               0.22241142837944089,
                               -0.24145203169384316,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1465733833944016,
                               0,
                               0.0023420517608615521,
                               -0.98824517941561285,
                               0,
                               0,
                               0,
                               0,
                               -0.043384599060842188,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5498209398801629,
                               0.50424579243865997,
                               0,
                               0,
                               0.53616760185833912,
                               0,
                               0,
                               0,
                               0,
                               -0.30879704062255875,
                               0.00077538289253825665,
                               0,
                               0,
                               0.24617311810755974,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39331500291675631,
                               0,
                               0.23003424038513148,
                               -0.018720048985866378,
                               0,
                               0,
                               0,
                               0,
                               -0.88996467148814051,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.84751340741968062,
                               0,
                               0.25378355172385414,
                               -0.14455543984118535,
                               0,
                               0,
                               0,
                               0,
                               0.44319144613883227,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.94746773673612972,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.93547659678128503,
                               0.57538314904326149,
                               0,
                               0,
                               0,
                               -0.45668808992070897,
                               0,
                               -0.75129327933838375,
                               0,
                               0,
                               0,
                               -0.22131259564457961,
                               -0.7385045025780983,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.38649694120722444,
                               0.71516578532568431,
                               0,
                               0,
                               0,
                               -0.58532191850310555,
                               0,
                               -0.42096139233633234,
                               0,
                               0,
                               0,
                               -0.42508324255387642,
                               0,
                               -0.19932088998173081,
                               -0.27518835923517254,
                               0,
                               0,
                               0.32547303091666013,
                               0,
                               0,
                               0,
                               0,
                               0.75726498341889548,
                               -0.27437339472991895,
                               0,
                               0,
                               0.36038707115576063,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57746263372673989,
                               -0.72542460722129809,
                               0,
                               0,
                               -0.080169707081496011,
                               0,
                               0,
                               0,
                               0,
                               -0.30223312520794227,
                               0.20601748715430057,
                               0,
                               0,
                               -0.0089887133305472378,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32487009096682368,
                               0,
                               0.93950661089659782,
                               0.046095009926140407,
                               0,
                               0,
                               0,
                               0,
                               0.098295483806257022,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14804740067799543,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.032769148364194589,
                               -0.53678838024177267,
                               0,
                               0,
                               0,
                               1.3809128037930427,
                               0,
                               -0.41756642343176309,
                               0,
                               0,
                               0,
                               -0.044443606505065375,
                               0,
                               -0.51190223910575161,
                               0.37156408775176397,
                               0,
                               0,
                               -0.52786708588058084,
                               0,
                               0,
                               0,
                               0,
                               0.43474475175830701,
                               0.29668487673905508,
                               0,
                               0,
                               -0.21030371054406405,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.037010981945515262,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33196483677574745,
                               0.29769247290066647,
                               0,
                               0,
                               0,
                               0.48359373331712391,
                               0,
                               -0.29678953327945395,
                               0,
                               0,
                               0,
                               1.5154579833189479,
                               0,
                               0,
                               0,
                               0.82093259477788516,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20590123691868212,
                               -0.96149419033644201,
                               0.85097902036251805,
                               0,
                               0,
                               0,
                               0,
                               0.20823661617501749,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.18408492064727411,
                               -0.84105457268399553,
                               -1.4849956931806068,
                               0,
                               0,
                               0,
                               0,
                               -0.17769285505608021,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0262622790592859,
                               -1.0451646426873569,
                               -0.080841662634631939,
                               0,
                               -0.87804308800281416,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0421225926840192,
                               -0.31963825613869473,
                               0,
                               0,
                               0,
                               0.19163241817030119,
                               0,
                               0.25903700998438817,
                               0,
                               0,
                               0,
                               -0.47163865401857852};

const double rot_20_10[100] = {0.48937298633944837,
                               0,
                               0,
                               0,
                               0.87239371118945575,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.77498838901076794,
                               0,
                               0,
                               0,
                               0.56811117619826157,
                               -0.27684415900849829,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.6202130714940628,
                               -0.10251993377847635,
                               0,
                               0,
                               0,
                               1.8057465903535141,
                               0,
                               0,
                               0,
                               0,
                               0.066376410091706806,
                               -1.0326604474936782,
                               0,
                               0,
                               0,
                               0.20426642912960394,
                               0,
                               0,
                               1.7238303464766207,
                               0,
                               0,
                               0,
                               -1.0138304737403547,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.39548683977350085,
                               0,
                               0,
                               0,
                               -0.094290816911808073,
                               0.91361884908974655,
                               0,
                               0,
                               0,
                               0,
                               0.49293321704310383,
                               0,
                               0,
                               0,
                               -0.81753222158195804,
                               -0.2977547820116484,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1215354984859331,
                               -0.052527033229206432,
                               0,
                               0,
                               0,
                               0.057132850208105407,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.93403253750501913,
                               0.35718793216167777,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35718793216167766,
                               -0.93403253750501913};

const double rot_20_100[10000] = {0.2137281892066247,
                                  0.15961031817071822,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.016744691009132888,
                                  0,
                                  0,
                                  -0.16437716145645692,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11120064722537372,
                                  0.30724892626076494,
                                  0,
                                  -0.062317772159627284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24867641727835454,
                                  0.10963622916040963,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092143681054585758,
                                  0,
                                  0.13582333683809494,
                                  0,
                                  -0.064667104095909977,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40666820808935111,
                                  0,
                                  -0.021741881469784487,
                                  0,
                                  0,
                                  0.047681786072371585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073202625970143126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037080409151922754,
                                  -0.00061561279609453207,
                                  0,
                                  0,
                                  0.019696129054425155,
                                  0,
                                  0,
                                  -0.064854060708868774,
                                  0,
                                  0,
                                  0,
                                  0.17818133745892767,
                                  0,
                                  0,
                                  0.041546633455553927,
                                  0.14792057494127417,
                                  0,
                                  0.020376157495122543,
                                  -0.13358418171703051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44308299234174064,
                                  0.23422485126650033,
                                  0.39347367523795923,
                                  0,
                                  -0.055005495217265492,
                                  -0.15431759149535876,
                                  0,
                                  0.19511905955128586,
                                  -0.34412187467358935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29702580340097867,
                                  0,
                                  0,
                                  0.092972699414183332,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16677493249606748,
                                  0.026025261935202722,
                                  0,
                                  -0.084726408894737759,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050709645398064052,
                                  -0.13071713896913251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.089797796973947214,
                                  0,
                                  0.17225102084310809,
                                  0,
                                  -0.02361014204875498,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24006458338724124,
                                  0,
                                  0.209352332241446,
                                  0,
                                  0,
                                  -0.2733512368559739,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14321576547195916,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13876136480468343,
                                  -0.28297957433873738,
                                  0,
                                  0,
                                  -0.19497356828670842,
                                  0,
                                  0,
                                  0.14865070590269461,
                                  0,
                                  0,
                                  0,
                                  -0.31254783955685411,
                                  0,
                                  0,
                                  0.1752707185625243,
                                  -0.018339746288935276,
                                  0,
                                  -0.25095301689081356,
                                  0.041203976584438112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26006308368301034,
                                  0.11423355075423745,
                                  0.068202855257521358,
                                  0,
                                  -0.13463911146574037,
                                  -0.0026206521699369441,
                                  0,
                                  0,
                                  0,
                                  -0.052861195990478775,
                                  0.13014433965673267,
                                  0,
                                  0,
                                  -0.24181107270122543,
                                  0.59631764428027734,
                                  0,
                                  0,
                                  -0.03288029856499404,
                                  0,
                                  -0.030449526686932384,
                                  0.26028537034741128,
                                  0.24170611415769958,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21505024415006863,
                                  0.39536972159580636,
                                  0,
                                  -0.30491604062886485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25346844223959453,
                                  0,
                                  0.094074242881285255,
                                  -0.28971429908384533,
                                  0,
                                  0,
                                  0,
                                  0.21165501591368963,
                                  0,
                                  0,
                                  0,
                                  0.0034987565267112939,
                                  -0.032238416690818832,
                                  0,
                                  0.22225782037288291,
                                  0,
                                  0,
                                  0.33039583880496975,
                                  0,
                                  0,
                                  0.25956399036836969,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10700900567948307,
                                  0,
                                  0,
                                  0.37798966318781124,
                                  0,
                                  -0.1189491689657247,
                                  0,
                                  0.30546145455645024,
                                  0,
                                  0.14581136059125518,
                                  -0.10207209231166336,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021497771179616931,
                                  -0.036444952769688177,
                                  0.05315132332372996,
                                  -0.69390453990245116,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17084762581987722,
                                  0.29733896423122513,
                                  0,
                                  0,
                                  -0.46841180290830581,
                                  -0.38986074661430214,
                                  0,
                                  0,
                                  0.17532742676946361,
                                  0,
                                  0.087344864275803263,
                                  0.40473169244878932,
                                  0.082947359457420877,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25107695275149455,
                                  -0.26575090917617128,
                                  0,
                                  -0.17628267747691531,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27587417105828677,
                                  0,
                                  -0.1826718926920578,
                                  -0.14215069803990152,
                                  0,
                                  0,
                                  0,
                                  0.047094924780259284,
                                  0,
                                  0,
                                  0,
                                  0.62022661800423651,
                                  -0.010200740704578409,
                                  0,
                                  0.11439288779833054,
                                  0,
                                  0,
                                  0.026208778555054477,
                                  0,
                                  0,
                                  -0.27620695313886484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.091233387234972249,
                                  0,
                                  0,
                                  -0.027505888617622737,
                                  0,
                                  -0.056503808772627999,
                                  0,
                                  0.13773401911803304,
                                  0,
                                  -0.30427708685198868,
                                  -0.26361494765704041,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10897068334274523,
                                  -0.38179212552416164,
                                  0.012501355478582381,
                                  0.055254394882855662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56944983215572009,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12643249432849796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017230907619627915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13310643681283563,
                                  0.50031623562771177,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045095397159276088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10154575299484786,
                                  0,
                                  0,
                                  -0.023901920487119407,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.048228710431256393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24545938111573226,
                                  0,
                                  0,
                                  -0.33968452208864813,
                                  0.062014289071247453,
                                  -0.13280999381630645,
                                  -0.29824330284526324,
                                  0,
                                  0,
                                  0.1246373070255378,
                                  0,
                                  0,
                                  -0.043418912562505255,
                                  0,
                                  0,
                                  0,
                                  0.26773413849785277,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.026114004846300401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.016110153654387879,
                                  0.0075352893049083283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58383179164514409,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.018711086150481403,
                                  0,
                                  0,
                                  0,
                                  -0.7257018296174903,
                                  0,
                                  0,
                                  0,
                                  0.039563605655919348,
                                  -0.39581237811538872,
                                  0,
                                  0,
                                  -0.50814710926978657,
                                  0.63963919297770244,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12917833149414057,
                                  0,
                                  0.535489847828303,
                                  0,
                                  0.091272629524878732,
                                  0,
                                  0.16073327505061885,
                                  0.21985446677343803,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11132098303450724,
                                  0.45778444445132155,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16935434963606383,
                                  0.038158751213514204,
                                  0,
                                  0.43852141076139023,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.091002383807784512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17226222460469398,
                                  0,
                                  0,
                                  0.26682152800648101,
                                  0,
                                  0,
                                  -0.13069562477964236,
                                  0.05914824234806107,
                                  0,
                                  0,
                                  0.18384659985167345,
                                  -0.24688363249068385,
                                  0,
                                  0,
                                  0.31490766301413275,
                                  0,
                                  0.26927127224316261,
                                  -0.11898765270088378,
                                  -0.10877543933902672,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54109382245446269,
                                  0.1387689718206378,
                                  0,
                                  0.1615182949645626,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16774401226691849,
                                  0,
                                  -0.36763464483237918,
                                  -0.37800992868545041,
                                  0,
                                  0,
                                  0,
                                  -0.090292228970666411,
                                  0,
                                  0,
                                  0,
                                  -0.13515478884597606,
                                  -0.32457885290190708,
                                  0,
                                  0.26226048438178673,
                                  0,
                                  0,
                                  0.15719739227001972,
                                  0,
                                  0,
                                  0.15932522942341151,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2452750897184679,
                                  0,
                                  0,
                                  -0.13128095694908609,
                                  0,
                                  0.1667899170116324,
                                  0,
                                  -0.17164443575941549,
                                  0,
                                  0.09219445955077038,
                                  0.23371455281890169,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38142627288065228,
                                  0.067684565559340673,
                                  0.022830173301510669,
                                  -0.10108563951475297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29290865461701016,
                                  -0.019095505326250352,
                                  0,
                                  0,
                                  -0.037276637327905163,
                                  0.4079071351313302,
                                  0,
                                  0,
                                  0.28175270501743627,
                                  0,
                                  0.017704997744902296,
                                  0.2781425673082486,
                                  -0.051054930694312099,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1738113426766516,
                                  -0.31528974073926852,
                                  0,
                                  0.087834649804341552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26163531702272191,
                                  0,
                                  -0.38033396039254719,
                                  0.24208471757235475,
                                  0,
                                  0,
                                  0,
                                  0.39525557449899867,
                                  0,
                                  0,
                                  0,
                                  -0.21989816631930073,
                                  0.063993729258897,
                                  0,
                                  -0.036612211181092466,
                                  0,
                                  0,
                                  -0.043003226189490845,
                                  0,
                                  0,
                                  0.15150654245448661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22511720413296205,
                                  0,
                                  0,
                                  -0.23963042229135223,
                                  0,
                                  -0.06910991587747907,
                                  0,
                                  0.34440227881237928,
                                  0,
                                  -0.24534733404997838,
                                  0.12326616100238748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28990301158805465,
                                  0.38706725596799363,
                                  -0.10377762520908028,
                                  -0.037748750997313257,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058867223456553666,
                                  -0.0008657177847794296,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094596933083916937,
                                  0,
                                  0,
                                  0.086841648708197078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019509172877742828,
                                  -0.064796115684030889,
                                  0,
                                  0.03148943566673186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073214739904603088,
                                  0.11622658240225547,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094149876733326185,
                                  0,
                                  -0.33776931964597701,
                                  0,
                                  -0.37440306271140189,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26439384852290088,
                                  0,
                                  -0.049513455725884468,
                                  0,
                                  0,
                                  0.030064743794359146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26869679569530874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28102171823707145,
                                  -0.16946187282601177,
                                  0,
                                  0,
                                  -0.1131875869510596,
                                  0,
                                  0,
                                  -0.19169046628107073,
                                  0,
                                  0,
                                  0,
                                  0.30975107889070352,
                                  0,
                                  0,
                                  0.01611832045647496,
                                  0.17307719621123266,
                                  0,
                                  -0.16303099924991538,
                                  0.19900539479553542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032400739409066147,
                                  -0.059053009176603805,
                                  0.11900410064528373,
                                  0,
                                  0.061613788147098822,
                                  -0.41824704702102694,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16382899008112939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3367978038517157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.025786814882853858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.041366673057716782,
                                  0.052645839842285373,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2917343642910783,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36056617676023439,
                                  0,
                                  0,
                                  -0.030260794436902369,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21827631381073179,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21157982423040375,
                                  0,
                                  0,
                                  0.33114631692277102,
                                  0.41792731278112177,
                                  -0.24196167811577696,
                                  0.41185190183900433,
                                  0,
                                  0,
                                  -0.035822771487043131,
                                  0,
                                  0,
                                  -0.08336171834387493,
                                  0,
                                  0,
                                  0,
                                  0.007462029585075745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.013928863053663715,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13339135378619865,
                                  0.085862688565602377,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18925248474264172,
                                  -0.31755161059367876,
                                  0,
                                  0,
                                  -0.20260869267511472,
                                  -0.032707343989177157,
                                  0,
                                  0,
                                  0.33893228133974451,
                                  0,
                                  0.11078229718431996,
                                  0.15006879858819139,
                                  0.4739912400559283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083622941985511082,
                                  -0.22892831465396474,
                                  0,
                                  -0.018795536315307504,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24447558543109915,
                                  0,
                                  0.13330282275659414,
                                  -0.32550031353372577,
                                  0,
                                  0,
                                  0,
                                  0.0026816192422107928,
                                  0,
                                  0,
                                  0,
                                  0.18475430105455731,
                                  0.13137937656850179,
                                  0,
                                  -0.26611643765918647,
                                  0,
                                  0,
                                  0.24281624881493136,
                                  0,
                                  0,
                                  0.52459963814922028,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23409059046386924,
                                  0,
                                  0,
                                  -0.14370799082158983,
                                  0,
                                  0.024165892855521606,
                                  0,
                                  -0.037148643720441153,
                                  0,
                                  -0.12956895241210237,
                                  0.15485891358772824,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18179939561010719,
                                  -0.069452660091721297,
                                  -0.10518436818580804,
                                  0.069919562351973066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.062450531892776127,
                                  0.13406030363182625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.076981054395158746,
                                  0,
                                  0,
                                  0.134300774845656,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26006181653381644,
                                  0.37222251615839985,
                                  0,
                                  0.22811648821894037,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06578555120144633,
                                  -0.019321923148990554,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1136438404235323,
                                  0,
                                  -0.066944094475293051,
                                  0,
                                  0.31727100429306188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084862146817081097,
                                  0,
                                  -0.040986500914777804,
                                  0,
                                  0,
                                  0.18871998932995532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15598979055268433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22897929468095843,
                                  0.0098832431531886214,
                                  0,
                                  0,
                                  0.24559656608564703,
                                  0,
                                  0,
                                  0.25513489343026552,
                                  0,
                                  0,
                                  0,
                                  -0.072254576606073234,
                                  0,
                                  0,
                                  0.34103668976290336,
                                  -0.046609356526339005,
                                  0,
                                  -0.12825100357492594,
                                  0.11463211443935278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20481766651156741,
                                  -0.023160170927674542,
                                  0.21718633805243304,
                                  0,
                                  -0.13360361967854242,
                                  -0.25616980667498496,
                                  0,
                                  0,
                                  0,
                                  0.027723234967882031,
                                  0.013787727697790145,
                                  0,
                                  0,
                                  -0.0079078224205835143,
                                  0.051570696959012244,
                                  0,
                                  0,
                                  0.26700319124820071,
                                  0,
                                  -0.11092414051590237,
                                  0.24651621402017787,
                                  -0.16377637795132388,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.095652645039619344,
                                  0.058116030517690112,
                                  0,
                                  0.22930023586560813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.76035559053077861,
                                  0,
                                  -0.14251989513990118,
                                  -0.021422475892811717,
                                  0,
                                  0,
                                  0,
                                  -0.094051155453090285,
                                  0,
                                  0,
                                  0,
                                  0.10651896637224725,
                                  -0.57125351635064547,
                                  0,
                                  0.02481908751048801,
                                  0,
                                  0,
                                  0.020688179368793719,
                                  0,
                                  0,
                                  -0.50833774188018066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14657521813853289,
                                  0,
                                  0,
                                  0.021656963872217289,
                                  0,
                                  -0.16198795759741058,
                                  0,
                                  -0.039003325906589136,
                                  0,
                                  0.50804694716082854,
                                  -0.2183722579438088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10346905859131379,
                                  -0.087275497123578807,
                                  -0.13720822957526441,
                                  -0.0027796090906484147,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015257138178342781,
                                  -0.40562314722285414,
                                  0,
                                  0,
                                  -0.28545890202414154,
                                  -0.063429425823009949,
                                  0,
                                  0,
                                  0.0083848881554848941,
                                  0,
                                  0.24073795239830484,
                                  -0.12414238887651401,
                                  -0.070831794764755443,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098751087459516718,
                                  -0.22607149723881201,
                                  0,
                                  -0.13157912660580956,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.095997282442723944,
                                  0,
                                  0.050832873122156313,
                                  0.30889256973346174,
                                  0,
                                  0,
                                  0,
                                  -0.29437515514502077,
                                  0,
                                  0,
                                  0,
                                  0.46744830531543163,
                                  0.15737397535461239,
                                  0,
                                  0.089179916887391172,
                                  0,
                                  0,
                                  -0.11069423280785201,
                                  0,
                                  0,
                                  -0.15643019175390316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079223165289261363,
                                  0,
                                  0,
                                  -0.22462061246564094,
                                  0,
                                  0.18691733193045423,
                                  0,
                                  0.22078860648603069,
                                  0,
                                  0.30389837296012107,
                                  -0.28104797369734541,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34753027713746776,
                                  0.33841820228762159,
                                  -0.29386138724860372,
                                  -0.24131291245811348,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13187313763157257,
                                  -0.061068785332661378,
                                  0,
                                  0,
                                  -0.3703082820672961,
                                  -0.29185286300745239,
                                  0,
                                  0,
                                  0.25954075418992023,
                                  0,
                                  0.092221126964255135,
                                  -0.009799958321601028,
                                  0.18441915792962033,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1809071380317688,
                                  0.48616458153471132,
                                  0,
                                  -0.35619272003731134,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36864472999732267,
                                  0,
                                  -0.28169740621169054,
                                  0.25442394449633221,
                                  0,
                                  0,
                                  0,
                                  -0.11051884766569639,
                                  0,
                                  0,
                                  0,
                                  -0.29290560257550008,
                                  0.21403660427332147,
                                  0,
                                  -0.37401935788059126,
                                  0,
                                  0,
                                  0.00029482354894407037,
                                  0,
                                  0,
                                  -0.15502295420828532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37898410992288678,
                                  0,
                                  0,
                                  0.34168368960592083,
                                  0,
                                  -0.093136965499996921,
                                  0,
                                  -0.093470177711759292,
                                  0,
                                  -0.091536087292992063,
                                  -0.062699713532556697,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.034600677854967378,
                                  0.017247000117244608,
                                  0.15979331333006033,
                                  0.0017788844782694949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15025515030134989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092192795015737877,
                                  0,
                                  0,
                                  0,
                                  0.33317258833118119,
                                  0,
                                  0,
                                  0,
                                  0.24917690952343879,
                                  -0.10283187112420841,
                                  0,
                                  0,
                                  -0.26415176781764316,
                                  -0.56182958038393915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20180766306547793,
                                  0,
                                  -0.33107040662261805,
                                  0,
                                  -0.20403256682231291,
                                  0,
                                  0.064655478088316426,
                                  -0.3058762639808455,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047026261019888271,
                                  0.1103326589139408,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43906540418799345,
                                  0.6615349195945921,
                                  0,
                                  0.86537610023938738,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08879911054556737,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18686617486976187,
                                  0,
                                  0,
                                  0.083224957897718013,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17430083026223567,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022750927633915043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24969929195475787,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36443721567493303,
                                  -0.12105519143871719,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20609464107777312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32398221546884737,
                                  0,
                                  0,
                                  -0.24307134887697246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28357117544983013,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033897830396511355,
                                  0,
                                  0,
                                  0.24778351010658106,
                                  -0.5059632513679686,
                                  -0.10798437592399318,
                                  -0.074836222217935455,
                                  0,
                                  0,
                                  0.045440917791727931,
                                  0,
                                  0,
                                  -0.068650815566591972,
                                  0,
                                  0,
                                  0,
                                  -0.23514266536726353,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08826306521219128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.016035864997793227,
                                  -0.25772899792717019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.011832878147250508,
                                  0.082655193314191952,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23083725090475299,
                                  0,
                                  0,
                                  0.014292100727356025,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14624407714135926,
                                  0.065146551855294554,
                                  0,
                                  -0.19582281167356352,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.024207783349546236,
                                  -0.20266402276134901,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0094937087995755967,
                                  0,
                                  0.11940900391858847,
                                  0,
                                  -0.023812278559291768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4072009847260421,
                                  0,
                                  0.041195892835099959,
                                  0,
                                  0,
                                  -0.14884670740784484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019626715797652804,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13868441388558536,
                                  0.10004707371429936,
                                  0,
                                  0,
                                  0.089863040597888078,
                                  0,
                                  0,
                                  -0.28143384601861682,
                                  0,
                                  0,
                                  0,
                                  0.086372334097370995,
                                  0,
                                  0,
                                  0.1560215622725421,
                                  -0.32842630624807473,
                                  0,
                                  0.26276889551152005,
                                  0.19073684720106773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16519184244134946,
                                  -0.12440736073127569,
                                  0.4394850400867123,
                                  0,
                                  -0.048734122819830222,
                                  0.17038118381281156,
                                  0,
                                  0.14545391287679926,
                                  -0.26476420559824582,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24794213098142751,
                                  0,
                                  0,
                                  0.18103705332253298,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14365411093810121,
                                  -0.054067327342035738,
                                  0,
                                  0.026881093099317448,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1248454219707867,
                                  -0.18849140293318337,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2611361383180193,
                                  0,
                                  -0.039709182289100864,
                                  0,
                                  0.098199099175096588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15926853848894093,
                                  0,
                                  -0.09181453216059296,
                                  0,
                                  0,
                                  0.36603373290053692,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18283922235349459,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.037826506760458491,
                                  -0.16671681359002186,
                                  0,
                                  0,
                                  0.13384346662370031,
                                  0,
                                  0,
                                  -0.28248348533041046,
                                  0,
                                  0,
                                  0,
                                  0.1116481703674044,
                                  0,
                                  0,
                                  0.073803804436929313,
                                  0.072205007841007043,
                                  0,
                                  -0.16528381035450912,
                                  0.34427513343419253,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01547562584301366,
                                  -0.19368545057918393,
                                  0.087678420974255961,
                                  0,
                                  0.19013357845963771,
                                  0.28456674706931467,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28112657213008585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32405390519279625,
                                  0,
                                  0,
                                  0,
                                  -0.30614986325857613,
                                  0,
                                  0,
                                  0,
                                  -0.40432650135645715,
                                  -0.32456267695722735,
                                  0,
                                  0,
                                  -0.069117539781971757,
                                  -0.22300203953707554,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12039671126756496,
                                  0,
                                  0.057622401473992502,
                                  0,
                                  -0.21433949023101145,
                                  0,
                                  0.23671104453830388,
                                  -0.36978448979975764,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44693619821041791,
                                  0.027735969686860512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60024858604391884,
                                  -0.31428606696655342,
                                  0,
                                  0.14777289809548919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19703874632229917,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29290376472083868,
                                  0,
                                  0,
                                  0.65096128718311996,
                                  -0.16685024458853492,
                                  -0.33582001938557371,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1491689731555903,
                                  0,
                                  0,
                                  0.085966294065954629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42430580851616856,
                                  -0.0048349033781500128,
                                  0,
                                  -0.068943722854146849,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26130611275539173,
                                  -0.20934793312011063,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22786358296582301,
                                  0,
                                  -0.15946122881432276,
                                  0,
                                  -0.081675715771322113,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17532549299340283,
                                  0,
                                  -0.089896432489806388,
                                  0,
                                  0,
                                  -0.21233124256327643,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13329020541063591,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056180344609038708,
                                  0.4227221231863319,
                                  0,
                                  0,
                                  -0.1304404857948091,
                                  0,
                                  0,
                                  4.4214364141384466e-06,
                                  0,
                                  0,
                                  0,
                                  -0.12081699593239503,
                                  0,
                                  0,
                                  0.073457915506784377,
                                  0.22581080640051873,
                                  0,
                                  -0.016900104693544409,
                                  -0.06401271330749482,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.090263269451759887,
                                  -0.099233154939232932,
                                  0.13189849021047889,
                                  0,
                                  -0.18537994769021876,
                                  -0.056070202134577002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35608744161288464,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31118899540809269,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14266167268541496,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.039539735428884407,
                                  0.19134415855590403,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22335058734335489,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046934586746187765,
                                  0,
                                  0,
                                  -0.035134190456917624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10287775514896563,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.018181976624831141,
                                  0,
                                  0,
                                  -0.23625254107850693,
                                  -0.08567360489785858,
                                  -0.55927265276213489,
                                  -0.03098041126412375,
                                  0,
                                  0,
                                  -0.22465291510840094,
                                  0,
                                  0,
                                  0.0041685223406674509,
                                  0,
                                  0,
                                  0,
                                  -0.015132565361903529,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18831772446213027,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38092855145238336,
                                  -0.21309926867744866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057267664786665097,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10679541999871754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20456883940245293,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61349509436711003,
                                  0.22270067928801232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32493652882805751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.091036490322968594,
                                  0,
                                  0,
                                  -0.14998222477861103,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39559418487945491,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17052812611361942,
                                  0,
                                  0,
                                  0.0085254351945240146,
                                  -0.0286977692628212,
                                  0.091083918726737462,
                                  -0.16106613545527593,
                                  0,
                                  0,
                                  -0.020014081329642969,
                                  0,
                                  0,
                                  0.26388465476074624,
                                  0,
                                  0,
                                  0,
                                  0.015477169123613792,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0036926570688839422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28509741861813021,
                                  0.094074673117518187,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33052335465754523,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11552988250571075,
                                  0,
                                  0,
                                  0,
                                  0.42448455672702901,
                                  0,
                                  0,
                                  0,
                                  0.26154946135712748,
                                  -0.32521896224882885,
                                  0,
                                  0,
                                  -0.16754435521401748,
                                  -0.0225449910222262,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28956391370689621,
                                  0,
                                  0.78739870644585874,
                                  0,
                                  -0.093797558369994219,
                                  0,
                                  -0.39697194790149376,
                                  0.44880732053601141,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16440746167218706,
                                  -0.2665403395179386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.082748786312316053,
                                  0.084460477017538893,
                                  0,
                                  -0.23350440717941157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.041347958968578347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22876845879653016,
                                  0,
                                  0,
                                  -0.072655302763139723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70077428445974732,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.188253391287863,
                                  0,
                                  0,
                                  0,
                                  0.0047431255844267578,
                                  0,
                                  0,
                                  0,
                                  -0.081582591465400867,
                                  0.24438656487121613,
                                  0,
                                  0,
                                  0.20443470047121645,
                                  -0.13263432569876227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.020961800416999948,
                                  0,
                                  0.18544128074003491,
                                  0,
                                  -0.2473226152849852,
                                  0,
                                  0.12289205509792847,
                                  -0.19420520368273711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.83489402206741525,
                                  -0.11708367499906598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31483347163847086,
                                  0.12510359407483407,
                                  0,
                                  0.19591509456743078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26566560014550794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38823098165645387,
                                  0,
                                  0,
                                  -0.014233298387192311,
                                  0.0089467932570712633,
                                  -0.060631568547821174,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21588745536481216,
                                  0,
                                  0,
                                  0.34763873194585482,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021995013758964746,
                                  0.26030748949057864,
                                  0,
                                  -0.20894657097027938,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049867912277703798,
                                  -0.29503875519518935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16007619534680073,
                                  0,
                                  -0.094583124560680784,
                                  0,
                                  -0.082360140067279597,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19801965108157543,
                                  0,
                                  -0.14333522524798759,
                                  0,
                                  0,
                                  -0.0004208723893109308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.083357356330320084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43289500603570397,
                                  0.12290560255820665,
                                  0,
                                  0,
                                  -0.24241184928585352,
                                  0,
                                  0,
                                  0.11016253700442925,
                                  0,
                                  0,
                                  0,
                                  0.21010351984975711,
                                  0,
                                  0,
                                  -0.14279109281917399,
                                  -0.31222370740371486,
                                  0,
                                  -0.1111597108381337,
                                  -0.099870352696860176,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062447958486383258,
                                  0.048051940079332681,
                                  -0.10890719671736336,
                                  0,
                                  0.091051537559848711,
                                  0.18755684895593885,
                                  0,
                                  -0.14394880637835383,
                                  -0.063827176530749305,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.099277711364287216,
                                  0,
                                  0,
                                  -0.15773512249495547,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34562114876227529,
                                  0.17550185228239115,
                                  0,
                                  0.37814149338207681,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086884151088294073,
                                  -0.040131906684364498,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063358013088381709,
                                  0,
                                  0.043790197517083365,
                                  0,
                                  0.21453540125327067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17337541923818311,
                                  0,
                                  0.39844648131615001,
                                  0,
                                  0,
                                  -0.0094537215379506406,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28489257012866231,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03653466324217719,
                                  -0.19792388838153815,
                                  0,
                                  0,
                                  -0.25656859832835099,
                                  0,
                                  0,
                                  -0.14821261513690417,
                                  0,
                                  0,
                                  0,
                                  0.022243672702297483,
                                  0,
                                  0,
                                  -0.083163733316694452,
                                  -0.021779280664070297,
                                  0,
                                  -0.045793650194176805,
                                  -0.030288784608711095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.066904192299243687,
                                  -0.16477390193464123,
                                  0.058427880640680253,
                                  0,
                                  0.3568223309195489,
                                  0.12028548008970706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.023587614503856633,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31432248398685714,
                                  0,
                                  0,
                                  0,
                                  -0.59391644518869346,
                                  0,
                                  0,
                                  0,
                                  -0.057525845317971128,
                                  0.013747717588805088,
                                  0,
                                  0,
                                  -0.2997861926698529,
                                  -0.03120997858947953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47434405925595563,
                                  0,
                                  -0.041342712615612107,
                                  0,
                                  -0.13729030111816792,
                                  0,
                                  -0.47978881988680122,
                                  -0.52669325550674106,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11463570786626143,
                                  -0.41854464460276974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33622527552756626,
                                  -0.035376002410342743,
                                  0,
                                  -0.30105126858246428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08805833404618392,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064244817780362284,
                                  0,
                                  0,
                                  -0.012039947887353915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30798581996413799,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23133855356557395,
                                  0,
                                  0,
                                  0,
                                  -0.31827485471732608,
                                  0,
                                  0,
                                  0,
                                  0.076514136252454651,
                                  -0.12028300268968288,
                                  0,
                                  0,
                                  0.42799835294141386,
                                  0.16373989544358883,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017951878704579934,
                                  0,
                                  -0.15797546397825049,
                                  0,
                                  -0.81904417111836914,
                                  0,
                                  0.1599960846936862,
                                  0.70009956886436353,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10398366901225262,
                                  -0.55467295344523271,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16411069687207264,
                                  0.036141821005690231,
                                  0,
                                  -0.18665464945400043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.047141454699220361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19570556654345123,
                                  0,
                                  0,
                                  0.39489947300927253,
                                  0,
                                  0,
                                  -0.54901280731268609,
                                  0.075631155898903776,
                                  0,
                                  0,
                                  0.39462435020288206,
                                  -0.11033406368110196,
                                  0,
                                  0,
                                  0.38147884139832616,
                                  0,
                                  0.0089183582795389418,
                                  -0.21882367258818702,
                                  -0.27148619735725965,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17531197598374704,
                                  -0.12637767590398191,
                                  0,
                                  -0.31148744690453661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34352994618089178,
                                  0,
                                  0.27793181411898721,
                                  0.33031229797521083,
                                  0,
                                  0,
                                  0,
                                  0.084441743589953461,
                                  0,
                                  0,
                                  0,
                                  0.046897421822371575,
                                  0.36791402923290928,
                                  0,
                                  0.075872475234847775,
                                  0,
                                  0,
                                  0.19542676840548379,
                                  0,
                                  0,
                                  -0.034044355203816955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052491681474526299,
                                  0,
                                  0,
                                  0.044988103357590313,
                                  0,
                                  -0.15763100024373802,
                                  0,
                                  0.14424011852446644,
                                  0,
                                  0.12422408204947996,
                                  0.094263658494519495,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2671528287896795,
                                  -0.63308640622371448,
                                  -0.23218816057739947,
                                  0.18908214709199622,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.01833281238849279,
                                  0.35450032252829061,
                                  0,
                                  0,
                                  0.2085778247692528,
                                  0.25389344429917826,
                                  0,
                                  0,
                                  0.21444576222051831,
                                  0,
                                  0.045505324142879569,
                                  0.30112029440792187,
                                  0.10166546295888955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34213474167778102,
                                  0.28646849606572272,
                                  0,
                                  -0.45569240867183441,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49976543854947619,
                                  0,
                                  -0.29460470332380323,
                                  -0.013811023985488006,
                                  0,
                                  0,
                                  0,
                                  -0.11338478451054046,
                                  0,
                                  0,
                                  0,
                                  -0.24675263115285603,
                                  -0.034927273485439156,
                                  0,
                                  0.032069567101441834,
                                  0,
                                  0,
                                  -0.14507361679096462,
                                  0,
                                  0,
                                  0.21537975634231782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15901532599383275,
                                  0,
                                  0,
                                  -0.10234772610050014,
                                  0,
                                  -0.089782772054587179,
                                  0,
                                  -0.43205247618114651,
                                  0,
                                  -0.19950980996641576,
                                  -0.34077739130146384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36197734738298648,
                                  0.12054599905841669,
                                  -0.38395932733811938,
                                  0.079762934858296955,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22073587770319514,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22166279478701978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.05106648332027075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27124671942229062,
                                  -0.31536084141520943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.052225231925832671,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.012273937064010271,
                                  0,
                                  0,
                                  -0.003010071231827019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16272768446955727,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.03907761330095251,
                                  0,
                                  0,
                                  -0.11629363423081765,
                                  0.34393694871772629,
                                  0.038558594425150333,
                                  -0.070424967594355126,
                                  0,
                                  0,
                                  -0.02509392847117007,
                                  0,
                                  0,
                                  -0.36706576374266037,
                                  0,
                                  0,
                                  0,
                                  0.051641180111048041,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13211269000527015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021020870798289168,
                                  -0.63357635529778444,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11060352631787966,
                                  0.59818594342237874,
                                  0,
                                  0,
                                  -0.18504377386700052,
                                  -0.041046556851905162,
                                  0,
                                  0,
                                  0.3323746050997784,
                                  0,
                                  -0.11273101294229308,
                                  -0.24518229353822249,
                                  0.094106360804162403,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3264060526913023,
                                  0.15871034713047436,
                                  0,
                                  0.1570538439955661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014729299178651251,
                                  0,
                                  0.034003783718659607,
                                  -0.36394072740312383,
                                  0,
                                  0,
                                  0,
                                  0.2637100923787804,
                                  0,
                                  0,
                                  0,
                                  -0.064235509402649812,
                                  0.52028871504971885,
                                  0,
                                  0.37288390292656842,
                                  0,
                                  0,
                                  -0.1481290635351305,
                                  0,
                                  0,
                                  -0.051692920772969109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44982478362350409,
                                  0,
                                  0,
                                  -0.041792854769667535,
                                  0,
                                  -0.07906424287193696,
                                  0,
                                  0.10493357851551824,
                                  0,
                                  0.063539169332208462,
                                  -0.16207578927679997,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074971089644929559,
                                  0.51599823582132076,
                                  -0.24516512250591349,
                                  0.19002801272539724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058417632147698281,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.84103965814265391,
                                  0,
                                  0,
                                  0,
                                  0.47815561993694472,
                                  0,
                                  0,
                                  0,
                                  0.36843146685403572,
                                  0.23740307679459793,
                                  0,
                                  0,
                                  -0.49730958427304717,
                                  0.055484444584992368,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10123744711492613,
                                  0,
                                  -0.12802150675470955,
                                  0,
                                  -0.13864505539749403,
                                  0,
                                  -0.20681614712263449,
                                  0.41620692983505359,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.031234372381287533,
                                  -0.31800917687280872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070605037356553962,
                                  -0.61219140903394764,
                                  0,
                                  0.064214031827328724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27888277665996419,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4005989467542464,
                                  0,
                                  0,
                                  0.1173473926050015,
                                  -0.082955372941491828,
                                  0.030198336251588825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10712731984604752,
                                  0,
                                  0,
                                  0.028787782588146876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057370382751348051,
                                  0.12482816870181528,
                                  0,
                                  0.059933393246590028,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30313306662620415,
                                  0.28160576144748012,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10937246292746652,
                                  0,
                                  -0.032449025389900965,
                                  0,
                                  -0.18938069346855871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079263917459908295,
                                  0,
                                  -0.14193619016961678,
                                  0,
                                  0,
                                  -0.29943146637967227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25169704979133811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069868858028549141,
                                  0.12663771991077308,
                                  0,
                                  0,
                                  0.068187023327831497,
                                  0,
                                  0,
                                  -0.040212246107269194,
                                  0,
                                  0,
                                  0,
                                  -0.079126779355186833,
                                  0,
                                  0,
                                  0.3680890802028125,
                                  0.36669174775152052,
                                  0,
                                  -0.043090505769207803,
                                  0.14165972474009453,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29732692656677173,
                                  -0.14535983377738509,
                                  -0.1324890471657626,
                                  0,
                                  0.16273498205591,
                                  0.28112841837738112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13486202545746925,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072595217066367554,
                                  0,
                                  0,
                                  0,
                                  0.10665226041064527,
                                  0,
                                  0,
                                  0,
                                  0.8076979162784631,
                                  0.032498526573524145,
                                  0,
                                  0,
                                  0.74192899931776801,
                                  -0.18884882117597368,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39423530597948175,
                                  0,
                                  0.18626559997442385,
                                  0,
                                  0.1796202223024661,
                                  0,
                                  0.0034766933682387202,
                                  -0.51460071854000788,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34695345033988306,
                                  0.15706765077829929,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03384323595485688,
                                  -0.09963775028314989,
                                  0,
                                  -0.069096205065933794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.032991988441607917,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.055127775660031519,
                                  0,
                                  0,
                                  0.11774892231324342,
                                  -0.32490416125692367,
                                  -0.0026019126882091716,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098470510016869753,
                                  0,
                                  0,
                                  0.25465511194292634,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2548043890409098,
                                  0.11080599776334146,
                                  0,
                                  -0.25787937884106832,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063851903378223274,
                                  0.054495724738926957,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12899885063891867,
                                  0,
                                  0.14436728755436443,
                                  0,
                                  -0.1886402900305347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11328929882874364,
                                  0,
                                  -0.20560084767299119,
                                  0,
                                  0,
                                  0.36538224434923777,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.041394842920634486,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27477804293280672,
                                  -0.32014015435541232,
                                  0,
                                  0,
                                  -0.14085705951067051,
                                  0,
                                  0,
                                  0.23571826489483205,
                                  0,
                                  0,
                                  0,
                                  -0.078516447352253715,
                                  0,
                                  0,
                                  0.067141575349060137,
                                  0.13300071952519221,
                                  0,
                                  0.16921941720831202,
                                  -0.088927365115398463,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.079641304860479337,
                                  0.11477077941278119,
                                  0.061205819613750448,
                                  0,
                                  0.25332075384280539,
                                  0.0026230543074849131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46472815613387919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35667846871908748,
                                  0,
                                  0,
                                  0,
                                  0.12485148276620878,
                                  0,
                                  0,
                                  0,
                                  0.070122293218761997,
                                  0.20770294243098958,
                                  0,
                                  0,
                                  0.37945620131582258,
                                  0.60164620630231869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52785188865935417,
                                  0,
                                  0.0033200695737591436,
                                  0,
                                  -0.0081509231261673587,
                                  0,
                                  -0.10549425922120451,
                                  -0.074205928280908565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3749533176219888,
                                  0.22624410774792855,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092501439923213122,
                                  0.25831330806052438,
                                  0,
                                  0.26192075114625102,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12988208749189431,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27341452873942301,
                                  0,
                                  0,
                                  -0.27399391131042844,
                                  0.027238153539704716,
                                  0.013345734279559419,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10972196576707136,
                                  0,
                                  0,
                                  0.32846362698786924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.09667906027000038,
                                  -0.23070894770855915,
                                  0,
                                  0.33044008749269055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21994143225082491,
                                  -0.062349474804957117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30777931635762495,
                                  0,
                                  -0.0052349792102746456,
                                  0,
                                  -0.068390859525244402,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088930197447868675,
                                  0,
                                  0.36865016710316578,
                                  0,
                                  0,
                                  0.037110355225124327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2236821326908337,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.033709113292327342,
                                  0.1621386120718584,
                                  0,
                                  0,
                                  -0.066675913969981029,
                                  0,
                                  0,
                                  -0.048702697575614684,
                                  0,
                                  0,
                                  0,
                                  0.3113143088880958,
                                  0,
                                  0,
                                  0.055608624733409787,
                                  0.13835882411584333,
                                  0,
                                  0.18875400558876484,
                                  0.099625201218257436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13482735783537345,
                                  0.35724029441692129,
                                  -0.080771191058608388,
                                  0,
                                  -0.092371708414575301,
                                  0.025844190964447442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67844240671879907,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10809279156052402,
                                  0,
                                  0,
                                  0,
                                  0.39276857944964283,
                                  0,
                                  0,
                                  0,
                                  -0.083130935412450896,
                                  -0.37505844922857756,
                                  0,
                                  0,
                                  0.35518009287701058,
                                  -0.0957218445230303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47904115518720336,
                                  0,
                                  -0.051473451471679352,
                                  0,
                                  0.057367643545009485,
                                  0,
                                  0.23880787932626865,
                                  -0.19446188999721953,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40769144794311069,
                                  -0.25086608071805949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45273486890834108,
                                  0.2777557893337379,
                                  0,
                                  -0.11389813334742611,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16196932643183809,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057971458082239267,
                                  0,
                                  0,
                                  -0.363874869540041,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28252443855878168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44070992632649475,
                                  0,
                                  0,
                                  0,
                                  -0.14582922937854589,
                                  0,
                                  0,
                                  0,
                                  0.17018085881705866,
                                  -0.3265613760070995,
                                  0,
                                  0,
                                  0.35671465065087604,
                                  -0.31010566669951989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36691486488436387,
                                  0,
                                  0.00051151966680904894,
                                  0,
                                  0.29736251710947448,
                                  0,
                                  0.1738174019130192,
                                  0.28145228697601604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.175491038566428,
                                  -0.11516068350513702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.048987004097901507,
                                  0.81906857539414679,
                                  0,
                                  -0.63896012766797194,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051817933622371283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043566991596433041,
                                  0,
                                  0,
                                  0.037420276166944669,
                                  0,
                                  0,
                                  0.17190926614937982,
                                  -0.21376142829667819,
                                  0,
                                  0,
                                  -0.092315498197854465,
                                  0.29173244502869461,
                                  0,
                                  0,
                                  0.12885672481677024,
                                  0,
                                  0.064719569461092891,
                                  0.039820333871927072,
                                  0.23681259109053185,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07737643079211623,
                                  -0.049174496578878055,
                                  0,
                                  -0.24228508781822675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10121564577134579,
                                  0,
                                  -0.18292404608545693,
                                  0.28092429096077776,
                                  0,
                                  0,
                                  0,
                                  0.15463688164776765,
                                  0,
                                  0,
                                  0,
                                  -0.26795791052045898,
                                  0.13924764734209222,
                                  0,
                                  0.26214812189277864,
                                  0,
                                  0,
                                  0.41815185937836946,
                                  0,
                                  0,
                                  -0.53927858344410395,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2260370316797555,
                                  0,
                                  0,
                                  -0.11868258512434604,
                                  0,
                                  -0.10178177927903334,
                                  0,
                                  -0.30697245354142932,
                                  0,
                                  0.33111553095311214,
                                  0.60643533285204154,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34225192726178494,
                                  0.082550416222506778,
                                  0.14736884500056516,
                                  0.17353103340436354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11088422473363588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.097305581570326358,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13193970200681654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14228256368588979,
                                  -0.34863032065315419,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30818786235525958,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097292550331367411,
                                  0,
                                  0,
                                  0.1715331059906981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.050048499668753535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18223615556619746,
                                  0,
                                  0,
                                  -0.13916536421199877,
                                  -0.23770469274331879,
                                  -0.25519671642363262,
                                  0.37930516157240152,
                                  0,
                                  0,
                                  -0.12215539319282381,
                                  0,
                                  0,
                                  0.13013227511120615,
                                  0,
                                  0,
                                  0,
                                  0.54600446112537404,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15043975409817176,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10281694701509156,
                                  0.03752027457351044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.086110551712045749,
                                  -0.29154136271894809,
                                  0,
                                  0,
                                  -0.017036730918918989,
                                  -0.39482603120677873,
                                  0,
                                  0,
                                  0.11136494939823763,
                                  0,
                                  0.093883535894695572,
                                  0.39616862884147974,
                                  0.011151939298051989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015490192733874357,
                                  -0.01468557976616185,
                                  0,
                                  -0.080518911841639174,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22587803941890508,
                                  0,
                                  0.0085473701764140382,
                                  -0.18696670573191396,
                                  0,
                                  0,
                                  0,
                                  0.090087900405233873,
                                  0,
                                  0,
                                  0,
                                  -0.01121463492966039,
                                  0.066549419777217164,
                                  0,
                                  0.072496376998235634,
                                  0,
                                  0,
                                  -0.8189459114227422,
                                  0,
                                  0,
                                  0.04703289505582868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017165370763403562,
                                  0,
                                  0,
                                  0.089476681034173638,
                                  0,
                                  -0.34504919486373287,
                                  0,
                                  0.36221524498508589,
                                  0,
                                  0.32424481050720932,
                                  0.394790675048933,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19761080848908655,
                                  -0.089176121534432828,
                                  -0.023265551730613992,
                                  0.22386695540697066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067587537792606997,
                                  -0.056988400075270396,
                                  0,
                                  0,
                                  -0.060065328602115567,
                                  -0.24514572979394134,
                                  0,
                                  0,
                                  -0.47086131765657391,
                                  0,
                                  0.29505386865458516,
                                  -0.13964429432857622,
                                  0.075581102744837758,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.02759341890402893,
                                  -0.47862828867669777,
                                  0,
                                  0.15876271593722235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26012964549905815,
                                  0,
                                  -0.46536305792043453,
                                  0.09968111099223792,
                                  0,
                                  0,
                                  0,
                                  0.01450145923336351,
                                  0,
                                  0,
                                  0,
                                  -0.12852276960964226,
                                  0.12123363664274805,
                                  0,
                                  -0.12011014285758356,
                                  0,
                                  0,
                                  0.13959338555355053,
                                  0,
                                  0,
                                  -0.26182810882594304,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38028448013581884,
                                  0,
                                  0,
                                  0.38219896361496292,
                                  0,
                                  -0.43233459044946032,
                                  0,
                                  0.046733551045031824,
                                  0,
                                  -0.22313298989399147,
                                  0.12864970534994177,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.096208328140373847,
                                  -0.072737412381983113,
                                  -0.25445444601398715,
                                  -0.44007052187483225,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12259137586166377,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0057768950026558658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18099966239524451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0026253316829203052,
                                  0.19990354500554858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13582847104064755,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0034003960032943439,
                                  0,
                                  0,
                                  0.67948998754785628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29828751689388699,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14352618769987732,
                                  0,
                                  0,
                                  0.34538270159230122,
                                  -0.091784492730212441,
                                  -0.12745858521321185,
                                  -0.082280354884260859,
                                  0,
                                  0,
                                  -0.09619733978900312,
                                  0,
                                  0,
                                  0.15368495518415859,
                                  0,
                                  0,
                                  0,
                                  0.020364637758528571,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16883661607108666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1902312604286463,
                                  -0.27157908056260066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14202843476979352,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16669658366529741,
                                  0,
                                  0,
                                  0,
                                  0.26965261386889539,
                                  0,
                                  0,
                                  0,
                                  -0.71130074857850034,
                                  -0.28722653339424187,
                                  0,
                                  0,
                                  0.48470054379207483,
                                  0.17608769053650725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42200705239273051,
                                  0,
                                  -0.15591718858238554,
                                  0,
                                  -0.026466480789065869,
                                  0,
                                  -0.33481033068352151,
                                  -0.2663907367843022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056932109860541598,
                                  -0.12741290797700708,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.62011925185715011,
                                  -0.090311272888383573,
                                  0,
                                  -0.33963410315925868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29659083819671067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17005180211816756,
                                  0,
                                  0,
                                  0.52480198109844778,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13592667424750157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043537085993992725,
                                  0,
                                  0,
                                  0,
                                  -0.30607169493794906,
                                  0,
                                  0,
                                  0,
                                  0.022875217700980187,
                                  0.28325074217036117,
                                  0,
                                  0,
                                  -0.069062265496804109,
                                  0.13775732607481492,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1104231346339566,
                                  0,
                                  -0.061189571676825656,
                                  0,
                                  -0.17318095498121949,
                                  0,
                                  -0.46072964031580865,
                                  -0.047843688779994856,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23948116209900078,
                                  0.1249860312289022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38254622003047545,
                                  0.42959279074867823,
                                  0,
                                  0.00068441948740346342,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.97251201911002649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29874144283816334,
                                  0,
                                  0,
                                  0.37696268451531717,
                                  0,
                                  0,
                                  0.45196807220699414,
                                  0.086098786894157009,
                                  0,
                                  0,
                                  0.027102213067141383,
                                  -0.28581028662329871,
                                  0,
                                  0,
                                  0.037034045161739124,
                                  0,
                                  0.00099452590722133149,
                                  0.34167795302940196,
                                  -0.28526308196950939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036169563430182974,
                                  -0.14440372510885532,
                                  0,
                                  0.13847457698507848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.013738026264538291,
                                  0,
                                  0.051654608069075673,
                                  0.22657106120973908,
                                  0,
                                  0,
                                  0,
                                  -0.25802665737664365,
                                  0,
                                  0,
                                  0,
                                  -0.24968038129695827,
                                  0.29921444192592572,
                                  0,
                                  0.13491575600078531,
                                  0,
                                  0,
                                  0.35521125735230286,
                                  0,
                                  0,
                                  0.26853207783903721,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0032103698619909242,
                                  0,
                                  0,
                                  -0.32669158648567131,
                                  0,
                                  -0.46959570341523793,
                                  0,
                                  0.16274349002913643,
                                  0,
                                  0.41337664100469207,
                                  -0.089938290108491761,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18701352593212389,
                                  -0.20187082477067714,
                                  0.0700709331363399,
                                  -0.13252743644047549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1007247619544567,
                                  -0.15114042711801354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18711692542786704,
                                  0,
                                  0,
                                  -0.11507234304515418,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13623739051268802,
                                  -0.040235061522421053,
                                  0,
                                  0.16901833158538543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21640117702967629,
                                  0.029550103157971682,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40908344072248115,
                                  0,
                                  -0.32779428063825128,
                                  0,
                                  0.12425216289040684,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028360612327857936,
                                  0,
                                  -0.31161079653861912,
                                  0,
                                  0,
                                  0.24114970898623364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20656984917728111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.038291615920546689,
                                  0.080054675670306233,
                                  0,
                                  0,
                                  -0.18240796352868197,
                                  0,
                                  0,
                                  -0.11455875470023077,
                                  0,
                                  0,
                                  0,
                                  -0.34069688189424818,
                                  0,
                                  0,
                                  0.10198669689781512,
                                  -0.10035394625003337,
                                  0,
                                  0.19970784659059868,
                                  0.17513604238501532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23019054867235994,
                                  -0.058579096423380883,
                                  -0.076235632043209711,
                                  0,
                                  -0.082862952569311754,
                                  -0.053566401867746735,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14937166245352637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15488958960063517,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17002876523851854,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2591433180589594,
                                  -0.02356211488681325,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2557352623968237,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1528628113347813,
                                  0,
                                  0,
                                  0.078204050951274154,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29631353496734802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3830194815182329,
                                  0,
                                  0,
                                  0.39446320240151223,
                                  -0.08585715562066093,
                                  -0.17528571403475612,
                                  -0.20223540837161699,
                                  0,
                                  0,
                                  -0.34480856372163876,
                                  0,
                                  0,
                                  0.047963808741626854,
                                  0,
                                  0,
                                  0,
                                  -0.12846290313440126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16111207811710671,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32141612814385684,
                                  0.16164623792868446,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33341495976442803,
                                  0.075947447933587972,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075509670596169046,
                                  0,
                                  0,
                                  -0.26089016621369254,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085205390105010964,
                                  -0.19068726749237919,
                                  0,
                                  0.01030012258556566,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18346655232427167,
                                  0.21401659584997584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029349241310392907,
                                  0,
                                  -0.060395874739763947,
                                  0,
                                  -0.11402677937895184,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081502816720834481,
                                  0,
                                  0.027043764713643087,
                                  0,
                                  0,
                                  0.098687508126267809,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061195595540358333,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.045437342436985891,
                                  -0.064593772797689492,
                                  0,
                                  0,
                                  -0.12871623693884912,
                                  0,
                                  0,
                                  0.22141372096958556,
                                  0,
                                  0,
                                  0,
                                  0.11965416380671104,
                                  0,
                                  0,
                                  0.099603573725164318,
                                  -0.26146759500877792,
                                  0,
                                  -0.47485541930292424,
                                  0.21215173985635155,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.03256287185639542,
                                  0.072791398198902499,
                                  0.1419570162893799,
                                  0,
                                  -0.3082292635491205,
                                  0.3021536233871398,
                                  0,
                                  0,
                                  0,
                                  -0.29427776158511343,
                                  -0.0966185440310766,
                                  0,
                                  0,
                                  0.030887290253347119,
                                  -0.46130610886990725,
                                  0,
                                  0,
                                  0.48799256835622651,
                                  0,
                                  -0.29883758032139868,
                                  0.032964969881188355,
                                  0.034548071914626367,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025513432240212634,
                                  -0.098036736372033723,
                                  0,
                                  0.041299819206304766,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20875199034743896,
                                  0,
                                  0.32058398015741929,
                                  -0.14164488238493603,
                                  0,
                                  0,
                                  0,
                                  0.07353555553511415,
                                  0,
                                  0,
                                  0,
                                  -0.26308837848683936,
                                  -0.14380090257180997,
                                  0,
                                  -0.022235423141507091,
                                  0,
                                  0,
                                  -0.10826679163177984,
                                  0,
                                  0,
                                  -0.17789316978559055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1922730823658923,
                                  0,
                                  0,
                                  -0.047324304521975898,
                                  0,
                                  0.078487319478991069,
                                  0,
                                  -0.15049388041725012,
                                  0,
                                  -0.028641824652496352,
                                  -0.32287459332590773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1527179453512845,
                                  0.25333546713663274,
                                  0.031860827609062739,
                                  -0.56336582567013782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12314190008279857,
                                  0.20277147295503226,
                                  0,
                                  0,
                                  0.52362105190701091,
                                  0.13106516940303167,
                                  0,
                                  0,
                                  0.044270499537954394,
                                  0,
                                  0.01733058973129906,
                                  0.094878984045619869,
                                  0.6254057934504349,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27434807846280368,
                                  -0.28891788390552281,
                                  0,
                                  0.25915880486411047,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12677742274427387,
                                  0,
                                  -0.10110021518584184,
                                  0.089361069505445367,
                                  0,
                                  0,
                                  0,
                                  -0.1154957116478478,
                                  0,
                                  0,
                                  0,
                                  0.27576259883556942,
                                  0.039657917030389206,
                                  0,
                                  -0.13141650163570467,
                                  0,
                                  0,
                                  0.1516788017199695,
                                  0,
                                  0,
                                  -0.14859134221090145,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053585992626965381,
                                  0,
                                  0,
                                  0.53672109465802109,
                                  0,
                                  -0.2354029873903794,
                                  0,
                                  0.18590909473618941,
                                  0,
                                  0.2756378367732803,
                                  -0.34575011295490521,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.00077742854225116426,
                                  0.1401219843531786,
                                  0.3847835770969617,
                                  0.1327014889729233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23844421884343778,
                                  -0.0013949035996232255,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4046648219162402,
                                  0,
                                  0,
                                  -0.036933779920607236,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25515125470133221,
                                  0.078404395451845937,
                                  0,
                                  0.026336157783883984,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19891858791741279,
                                  -0.055805910730946193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33660867952016021,
                                  0,
                                  0.159476783371793,
                                  0,
                                  -0.14657002376126055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043819420474315605,
                                  0,
                                  0.079793929052340354,
                                  0,
                                  0,
                                  0.017384969681400145,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26192118036699952,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056268239419865668,
                                  -0.036759178738948517,
                                  0,
                                  0,
                                  -0.078735434141395721,
                                  0,
                                  0,
                                  0.13460829892283019,
                                  0,
                                  0,
                                  0,
                                  -0.24570981262687441,
                                  0,
                                  0,
                                  -0.15117304481800101,
                                  -0.037024207752901411,
                                  0,
                                  -0.068193027778034765,
                                  0.37811567848438821,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13103942921919826,
                                  0.10064014042380674,
                                  -0.26688106393320432,
                                  0,
                                  0.097516025997373093,
                                  -0.23852838820956149,
                                  0,
                                  0,
                                  0,
                                  0.31666054468292965,
                                  -0.14698508334420063,
                                  0,
                                  0,
                                  0.37864323398992872,
                                  0.16978361813619036,
                                  0,
                                  0,
                                  0.0044950435146140083,
                                  0,
                                  0.22944782512344578,
                                  0.21854102511137979,
                                  -0.15541182425896138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17967614974297758,
                                  0.16552067315424226,
                                  0,
                                  0.035521148485349319,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16642022013842886,
                                  0,
                                  0.28608430150904224,
                                  -0.26745061800481984,
                                  0,
                                  0,
                                  0,
                                  -0.121243250715695,
                                  0,
                                  0,
                                  0,
                                  0.031256334962656146,
                                  -0.0089441969970009694,
                                  0,
                                  -0.25505361610382005,
                                  0,
                                  0,
                                  -0.053342586737568809,
                                  0,
                                  0,
                                  -0.54609508254208095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11447075074204652,
                                  0,
                                  0,
                                  -0.60186832237637378,
                                  0,
                                  -0.48277858697249637,
                                  0,
                                  0.29087783835022585,
                                  0,
                                  -0.35867893444555976,
                                  0.10853487261687778,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13240169834579954,
                                  0.047863332148617037,
                                  0.16674304262906825,
                                  -0.16062115549702391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13921232166371122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11714194608970097,
                                  0,
                                  0,
                                  0,
                                  -0.40704531342191302,
                                  0,
                                  0,
                                  0,
                                  -0.2241318495342044,
                                  0.52007314473101351,
                                  0,
                                  0,
                                  0.12688645481979313,
                                  -0.026948076052480171,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18763534294316006,
                                  0,
                                  0.4625481617707885,
                                  0,
                                  0.3861469643247798,
                                  0,
                                  0.32516792255647969,
                                  -0.021231965257853092,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38251829516392621,
                                  -0.71659847518704511,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077271008508565747,
                                  -0.13173766939041312,
                                  0,
                                  0.58650598998497172,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1181585544936459,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12527206048796338,
                                  0,
                                  0,
                                  -0.1698132133576831,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3670660829567311,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083096109939305371,
                                  0,
                                  0,
                                  0,
                                  -0.05958856221467862,
                                  0,
                                  0,
                                  0,
                                  0.37592348199609266,
                                  -0.16342752298697003,
                                  0,
                                  0,
                                  0.23378557017124527,
                                  0.06038896794712853,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19226639306274934,
                                  0,
                                  -0.31220506970517975,
                                  0,
                                  0.6380380465064267,
                                  0,
                                  -0.014924174739033756,
                                  0.3705028973996442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017184096288738373,
                                  -0.28052754141792602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18167473944913623,
                                  -0.10790758236617191,
                                  0,
                                  0.24465313862361393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31719982821357712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.8562282673983993,
                                  0,
                                  0,
                                  -0.031136605262141567,
                                  0,
                                  0,
                                  -0.014752877082874148,
                                  0.15975161386913309,
                                  0,
                                  0,
                                  -0.057612363740884964,
                                  0.12240273130823318,
                                  0,
                                  0,
                                  0.43060473114668579,
                                  0,
                                  0.34841056012861188,
                                  -0.20260277543457852,
                                  0.23197573869034888,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42340935776189581,
                                  -0.086577834011625818,
                                  0,
                                  0.37840807500282109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085218625156292041,
                                  0,
                                  0.049970246113253708,
                                  -0.095793524674033306,
                                  0,
                                  0,
                                  0,
                                  0.23713459797017111,
                                  0,
                                  0,
                                  0,
                                  -0.091823504568917122,
                                  0.040574814737657498,
                                  0,
                                  0.5586590416684869,
                                  0,
                                  0,
                                  0.13392585311677693,
                                  0,
                                  0,
                                  -0.13312092300349734,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42644060375787607,
                                  0,
                                  0,
                                  0.33926102180237294,
                                  0,
                                  -0.060029376490384798,
                                  0,
                                  0.28601073146872708,
                                  0,
                                  -0.14219811802621221,
                                  -0.41773906518876858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1305145062187206,
                                  -0.28119303554332381,
                                  0.26505319753688483,
                                  -0.1239043019770623,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42506943358848809,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27354317192027799,
                                  0,
                                  0,
                                  0,
                                  0.23010744292489432,
                                  0,
                                  0,
                                  0,
                                  -0.084362491664159128,
                                  0.47256149893043542,
                                  0,
                                  0,
                                  -0.0094160097806993345,
                                  0.089338660940516415,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.012984776990339203,
                                  0,
                                  0.33214746710962634,
                                  0,
                                  -0.14425197675354134,
                                  0,
                                  0.13044434400894711,
                                  0.28033655130707702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.50892160915639761,
                                  -0.096838833551614323,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10156330951220643,
                                  0.116360105863326,
                                  0,
                                  -0.12030715929749078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59931378424029935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.69435025617911394,
                                  0,
                                  0,
                                  0.47384267430573213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.060445586684737873,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11302240645632299,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24595171315685638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30647805150557922,
                                  -0.077461112385067782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.047628340923122181,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14325691359756115,
                                  0,
                                  0,
                                  0.10753257017178934,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37084050323752266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.093615288263662291,
                                  0,
                                  0,
                                  -0.082833427082332461,
                                  -0.14598205254411598,
                                  0.23737185037537334,
                                  0.083148365677182756,
                                  0,
                                  0,
                                  -0.10664236374419807,
                                  0,
                                  0,
                                  -0.1086287478376072,
                                  0,
                                  0,
                                  0,
                                  0.13041972967852508,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54918841168910126,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42278012991936736,
                                  0.17477416287111786,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34213037895560411,
                                  0.15083383496069558,
                                  0,
                                  0,
                                  -0.0055031314137141962,
                                  -0.016127086312622361,
                                  0,
                                  0,
                                  0.28620553521233533,
                                  0,
                                  0.078300107396361687,
                                  -0.13357432760124421,
                                  -0.70338313426497068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21672834620699177,
                                  -0.39016589990684214,
                                  0,
                                  -0.20609298768873191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046344377280470153,
                                  0,
                                  0.17226186985022857,
                                  -0.1672431486863579,
                                  0,
                                  0,
                                  0,
                                  0.14303409083919033,
                                  0,
                                  0,
                                  0,
                                  0.22940645827103046,
                                  -0.14933040463303254,
                                  0,
                                  -0.32927762553896278,
                                  0,
                                  0,
                                  0.16726554505219121,
                                  0,
                                  0,
                                  -0.17329512597545738,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080949354788231231,
                                  0,
                                  0,
                                  0.43777317631465995,
                                  0,
                                  0.0044099710954619356,
                                  0,
                                  0.024866558202396468,
                                  0,
                                  0.022916601699113776,
                                  -0.045612732083906322,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026924485834690544,
                                  0.41935775313979123,
                                  0.22351384836991728,
                                  0.10286215683407871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14108379735660134,
                                  -0.18390685473178847,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28120464305539766,
                                  0,
                                  0,
                                  0.29483702642698745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18211852812295354,
                                  -0.13828222957019287,
                                  0,
                                  -0.0045995011457262607,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054248040348186109,
                                  0.41499421962364552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0066600230391686485,
                                  0,
                                  0.32255197276418512,
                                  0,
                                  0.13731093628052105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.069008986470536618,
                                  0,
                                  -0.086029678009828109,
                                  0,
                                  0,
                                  0.18752038681946387,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030241659463186694,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12150563825251884,
                                  0.015521602761472394,
                                  0,
                                  0,
                                  -0.081146648375864994,
                                  0,
                                  0,
                                  -0.37464871366439589,
                                  0,
                                  0,
                                  0,
                                  -0.114687073286418,
                                  0,
                                  0,
                                  -0.085277319907431912,
                                  0.071261252290984747,
                                  0,
                                  -0.19653365558069499,
                                  -0.28056063646841684,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069416901509448278,
                                  0.029861046837606549,
                                  0.10023135093156087,
                                  0,
                                  -0.24131006045749853,
                                  0.053232017582582378,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35225240182500861,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021467682774495501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33899100064887711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17484913759597062,
                                  -0.09665111152968639,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038596468920278335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27258374072796171,
                                  0,
                                  0,
                                  0.18585747337567218,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11425293197992369,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35735555048557549,
                                  0,
                                  0,
                                  -0.31564096135589276,
                                  -0.19639369447629584,
                                  0.10220627355825203,
                                  -0.018751724507251256,
                                  0,
                                  0,
                                  -0.27669700013425541,
                                  0,
                                  0,
                                  -0.056950936099017802,
                                  0,
                                  0,
                                  0,
                                  -0.43129858045616676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1860141257507319,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024582961397785298,
                                  0.13968318088970721,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14254520301727475,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50362529821552215,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23580390900808595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20705062658054571,
                                  0.13269019668430015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.042144662949115043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0046591777416095312,
                                  0,
                                  0,
                                  0.022819812348453913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079300458661522868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13147359781343157,
                                  0,
                                  0,
                                  0.16281364866534809,
                                  -0.19536209629372084,
                                  -0.078343055840922216,
                                  0.179117779642648,
                                  0,
                                  0,
                                  0.26619557295557172,
                                  0,
                                  0,
                                  -0.49797814677157692,
                                  0,
                                  0,
                                  0,
                                  0.14671895697854825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10177363702199739,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045607562093260168,
                                  0.35828432432604751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22886587938184622,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2569750340781749,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1294188559988825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23605640357949217,
                                  -0.033503956617652035,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52206941214836966,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19292860938458312,
                                  0,
                                  0,
                                  -0.18224823370213228,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11309809465715276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.031097229260674375,
                                  0,
                                  0,
                                  0.036430329496611569,
                                  0.41725978873277286,
                                  -0.21051888427831913,
                                  0.051724404576775393,
                                  0,
                                  0,
                                  -0.33518923865672845,
                                  0,
                                  0,
                                  0.095891746753977491,
                                  0,
                                  0,
                                  0,
                                  -0.194755701697684,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.076894141091485083,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086364548109642669,
                                  0.23656798205778654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081368936319747232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20240512432054408,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40862642291709261,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14009098863856759,
                                  0.34313438572498656,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16491439312624112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087897152660766115,
                                  0,
                                  0,
                                  -0.16989791791834363,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14578009210941634,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32712161539341211,
                                  0,
                                  0,
                                  0.15124034469489431,
                                  -0.045840265951266036,
                                  0.20333883087064697,
                                  0.46648632591820371,
                                  0,
                                  0,
                                  0.17108288670002414,
                                  0,
                                  0,
                                  0.13392937383374559,
                                  0,
                                  0,
                                  0,
                                  -0.19833720896063151,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067278120949727738,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086973153057336522,
                                  -0.27102539018917354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27280585976137373,
                                  0.20678993347363245,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1154843253936261,
                                  0,
                                  0,
                                  0.080852652579245593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.02623855302038168,
                                  -0.26514751838257228,
                                  0,
                                  0.13131170596165123,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.039523651195836014,
                                  -0.19267049720842327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084437957028047989,
                                  0,
                                  0.090149880891100209,
                                  0,
                                  0.10012236293448022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17994874075346357,
                                  0,
                                  -0.095359765047202449,
                                  0,
                                  0,
                                  0.15736284670480116,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19830517320219182,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.089591107582311133,
                                  0.13378149587912938,
                                  0,
                                  0,
                                  -0.080179570458284624,
                                  0,
                                  0,
                                  0.41187714943770659,
                                  0,
                                  0,
                                  0,
                                  0.2024875808460769,
                                  0,
                                  0,
                                  0.00642683544870307,
                                  0.20611502325092593,
                                  0,
                                  -0.14368116862683586,
                                  -0.17907844085136496,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30018115578929722,
                                  -0.41059915475954889,
                                  0.00090270601889705718,
                                  0,
                                  -0.040169723543497182,
                                  0.081416354940990407,
                                  0,
                                  0.25580285710604783,
                                  0.047858282641200192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19049644333638685,
                                  0,
                                  0,
                                  0.20716692646919263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.071868087386209145,
                                  -0.23422521097309132,
                                  0,
                                  -0.20067668759392818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.091352863633196779,
                                  0.10884853753433682,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10764989694683266,
                                  0,
                                  -0.36810071292284835,
                                  0,
                                  0.069274398176478513,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18053529595731252,
                                  0,
                                  0.17192408526860786,
                                  0,
                                  0,
                                  -0.11739689658554488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10243805027809884,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.050460725724738059,
                                  -0.071053041227282412,
                                  0,
                                  0,
                                  0.1780515301908222,
                                  0,
                                  0,
                                  0.23851377477864155,
                                  0,
                                  0,
                                  0,
                                  -0.20341786487303326,
                                  0,
                                  0,
                                  -0.23064070660265726,
                                  0.15025571848250474,
                                  0,
                                  0.0044496373657960959,
                                  0.1491728736865211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12204438455061822,
                                  0.16552741068914939,
                                  0.3951727344178001,
                                  0,
                                  0.16642137696403872,
                                  0.18028769737276365,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049827836116717331,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28666331464611189,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40443216038646751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13193789397343658,
                                  0.16478218515401605,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20587997580069942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051323273600074167,
                                  0,
                                  0,
                                  0.22229237588993705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34516468745769341,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.067556637291445717,
                                  0,
                                  0,
                                  -0.27707047998092005,
                                  0.034905730186457921,
                                  0.18859145057978555,
                                  0.38207633174901123,
                                  0,
                                  0,
                                  -0.071553792303159086,
                                  0,
                                  0,
                                  0.34647482582935196,
                                  0,
                                  0,
                                  0,
                                  -0.074205398063898337,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062336407808909949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29743530577900612,
                                  -0.08073276038622279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42743581742075115,
                                  0.36442539722363188,
                                  0,
                                  0,
                                  -0.3805094567113077,
                                  0.063250874611283939,
                                  0,
                                  0,
                                  -0.1775085655356706,
                                  0,
                                  -0.19589184509690663,
                                  -0.02426595114900482,
                                  0.18311657329385875,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38048865168429591,
                                  -0.38072247260828523,
                                  0,
                                  -0.35135647755416649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014761669924942943,
                                  0,
                                  -0.033445162742858678,
                                  -0.17171542765400966,
                                  0,
                                  0,
                                  0,
                                  -0.089405417886792335,
                                  0,
                                  0,
                                  0,
                                  -0.40954182263748035,
                                  0.064191302578149839,
                                  0,
                                  -0.010605243690550563,
                                  0,
                                  0,
                                  0.037646159822556931,
                                  0,
                                  0,
                                  -0.10500147038743085,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15773101188747515,
                                  0,
                                  0,
                                  -0.12616651076547394,
                                  0,
                                  0.26931377119640326,
                                  0,
                                  0.33338094361753379,
                                  0,
                                  0.14625408885524999,
                                  -0.077483318651873093,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52820156836669352,
                                  0.4983545112341719,
                                  0.49289852039806292,
                                  0.11544428877150524,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.026536894707419677,
                                  -0.42824933720047481,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38381462526574084,
                                  0,
                                  0,
                                  -0.15255033112675728,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.018222124674555949,
                                  -0.045521216567670067,
                                  0,
                                  0.21150771233546142,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18398630290300544,
                                  -0.22096928485245823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16908978780637773,
                                  0,
                                  -0.15121284742092755,
                                  0,
                                  -0.15230510300002795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037326415610075089,
                                  0,
                                  -0.012287526580311937,
                                  0,
                                  0,
                                  0.092547527949883968,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030171915774934888,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088633401269229195,
                                  -0.22551763707857228,
                                  0,
                                  0,
                                  0.22484419708035819,
                                  0,
                                  0,
                                  0.12123544376891449,
                                  0,
                                  0,
                                  0,
                                  0.1206480151115352,
                                  0,
                                  0,
                                  0.2990512470652627,
                                  -0.011340579779024279,
                                  0,
                                  0.11545842346983969,
                                  -0.3288018168026377,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030282615267469341,
                                  0.25566272338101093,
                                  0.012191598816935011,
                                  0,
                                  -0.090751125446573461,
                                  0.075049080448695751,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044211866680038049,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22513895900695627,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.099712823044604798,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068458436420375662,
                                  -0.014631029257322847,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15146354143552757,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44233587863840845,
                                  0,
                                  0,
                                  0.14809045623262848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19677188998677816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10596108026467985,
                                  0,
                                  0,
                                  -0.1541788411312317,
                                  -0.055072369736869783,
                                  -0.44766817888721988,
                                  0.13668184209153184,
                                  0,
                                  0,
                                  0.47383242694283212,
                                  0,
                                  0,
                                  -0.042895788844089795,
                                  0,
                                  0,
                                  0,
                                  -0.37628688476380145,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12094300710135437,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11643030244504982,
                                  0.0030781872740570648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31615961390739927,
                                  0.13063743905208994,
                                  0,
                                  0,
                                  -0.13009699086602008,
                                  0.17251750834261931,
                                  0,
                                  0,
                                  0.065171799204462116,
                                  0,
                                  0.059447569896065318,
                                  -0.044186318653001114,
                                  0.1071471009273523,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16480629446664041,
                                  0.025092150863595328,
                                  0,
                                  -0.16169841859669881,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.07820886187737372,
                                  0,
                                  0.2860390507319327,
                                  0.52999981607219404,
                                  0,
                                  0,
                                  0,
                                  -0.43927640917475641,
                                  0,
                                  0,
                                  0,
                                  -0.22788535285271694,
                                  -0.70011857939635469,
                                  0,
                                  0.062058457713941903,
                                  0,
                                  0,
                                  -0.11937351229776566,
                                  0,
                                  0,
                                  -0.026550927884290629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33695911216902136,
                                  0,
                                  0,
                                  0.1855294055112483,
                                  0,
                                  -0.10565348109234618,
                                  0,
                                  0.16025170426576824,
                                  0,
                                  -0.35652543714929696,
                                  0.21763116402889371,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053635565662269485,
                                  0.3092053015960271,
                                  0.018957557495215396,
                                  0.077191344896131026,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34638054707727756,
                                  0.045304486489110375,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15000832064128425,
                                  0,
                                  0,
                                  0.33048452294761932,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21409261792801701,
                                  0.031447584327087913,
                                  0,
                                  -0.073991789934445412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085516209552754283,
                                  0.15203441397905559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37852434857193068,
                                  0,
                                  -0.077567121807061795,
                                  0,
                                  0.39749838023672057,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039263633823188385,
                                  0,
                                  0.12975563252024191,
                                  0,
                                  0,
                                  -0.017037851659390223,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34367569049528357,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.014830238158599379,
                                  0.11518964623517064,
                                  0,
                                  0,
                                  0.15314899842605309,
                                  0,
                                  0,
                                  0.040594042142761279,
                                  0,
                                  0,
                                  0,
                                  -0.012910578654865806,
                                  0,
                                  0,
                                  0.18562301015044316,
                                  -0.052310106059474469,
                                  0,
                                  0.0024570668519583588,
                                  0.071391448474097133,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21610074877474611,
                                  0.20571669978951818,
                                  -0.21803904432346566,
                                  0,
                                  0.041599527522808703,
                                  0.009574698176194817,
                                  0,
                                  0,
                                  0,
                                  -0.18860958748117918,
                                  -0.2888461456108643,
                                  0,
                                  0,
                                  -0.04610488169183298,
                                  0.042371282872573017,
                                  0,
                                  0,
                                  0.17532791362045444,
                                  0,
                                  -0.52063640555981505,
                                  0.17331594862755464,
                                  -0.27333369346484332,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.062058588028507645,
                                  0.2254667363271631,
                                  0,
                                  0.51955028350217558,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083965886839442755,
                                  0,
                                  -0.24050315232668415,
                                  -0.021398665111088636,
                                  0,
                                  0,
                                  0,
                                  -0.51605101599525993,
                                  0,
                                  0,
                                  0,
                                  0.22344425317150976,
                                  0.20455914096362865,
                                  0,
                                  0.10341395620422369,
                                  0,
                                  0,
                                  0.1885600329190085,
                                  0,
                                  0,
                                  -0.15802627571444733,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21856740552113924,
                                  0,
                                  0,
                                  0.55733635683270988,
                                  0,
                                  0.18870121862254563,
                                  0,
                                  0.1126196752562188,
                                  0,
                                  -0.4924627631221471,
                                  0.094471336614451382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.015564490434617332,
                                  0.14570013755024724,
                                  0.036262817315950914,
                                  0.081064155397786886,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19271050794993552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10917072767911565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25029350910345594,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.059417779541516377,
                                  0.10227623529487012,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.084866660838660068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32500337876815788,
                                  0,
                                  0,
                                  -0.34137528931514327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032612823818053541,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5845112520248994,
                                  0,
                                  0,
                                  0.21728455787011397,
                                  -0.1237972572864717,
                                  -0.053846774781956895,
                                  -0.042522639090832232,
                                  0,
                                  0,
                                  -0.035656173159153148,
                                  0,
                                  0,
                                  0.24708543394615395,
                                  0,
                                  0,
                                  0,
                                  0.31198240753765188,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059796124312622018,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18802958790849322,
                                  -0.19076358912598282,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3783028887606204,
                                  0.25199501956349912,
                                  0,
                                  0,
                                  -0.16203609203460409,
                                  -0.079857149265146588,
                                  0,
                                  0,
                                  -0.031212050902221865,
                                  0,
                                  0.11081184607041256,
                                  -0.12017910975321407,
                                  0.032992906610759321,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18846955077247632,
                                  0.36317840578285115,
                                  0,
                                  0.29134122034760157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11940074978364439,
                                  0,
                                  0.069952844465328692,
                                  0.15463448710075492,
                                  0,
                                  0,
                                  0,
                                  0.11677804771258984,
                                  0,
                                  0,
                                  0,
                                  0.45616895415077713,
                                  -0.029040483167613707,
                                  0,
                                  -0.10468983598359974,
                                  0,
                                  0,
                                  0.14397783243226914,
                                  0,
                                  0,
                                  0.25182631345611967,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.099833507010871181,
                                  0,
                                  0,
                                  -0.13307567617148613,
                                  0,
                                  -0.55737916077618066,
                                  0,
                                  -0.21867450473024411,
                                  0,
                                  -0.019796292446506922,
                                  0.36827843156235501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.090449001173378257,
                                  0.16144966756295909,
                                  0.12412748953821352,
                                  -0.16137690705856811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40365600031585219,
                                  0.01016621334114725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19147513750796946,
                                  0,
                                  0,
                                  -0.054130468318172642,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21872572098183563,
                                  0.039198408502704007,
                                  0,
                                  0.12757228291397674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.034096734035558775,
                                  -0.32805644860934935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053413933374269099,
                                  0,
                                  0.019604749735011688,
                                  0,
                                  0.2814119530905812,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1475336539320205,
                                  0,
                                  -0.17978845569744595,
                                  0,
                                  0,
                                  -0.10906941795931045,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27349433047712768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.00064812879963395062,
                                  -0.088378416153366682,
                                  0,
                                  0,
                                  -0.068697287500167431,
                                  0,
                                  0,
                                  -0.049196508068015607,
                                  0,
                                  0,
                                  0,
                                  -0.072076563090321399,
                                  0,
                                  0,
                                  -0.35325149920165216,
                                  0.38726534131282669,
                                  0,
                                  -0.12980457297311815,
                                  0.035916243612999353,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0899764843187357,
                                  0.11390060902179568,
                                  0.23252754602955572,
                                  0,
                                  -0.087129987235487816,
                                  -0.062757906947677911,
                                  0,
                                  0,
                                  0,
                                  -0.3386231566542946,
                                  0.01993425503484381,
                                  0,
                                  0,
                                  -0.42825304917194978,
                                  0.35345577989936561,
                                  0,
                                  0,
                                  -0.11739534048913083,
                                  0,
                                  0.1497435633076066,
                                  0.36552742385192794,
                                  -0.21068717478928781,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3474839765908776,
                                  -0.16302190843115302,
                                  0,
                                  0.31540959806975005,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12410333274574877,
                                  0,
                                  0.49217963419934774,
                                  0.020094045164510629,
                                  0,
                                  0,
                                  0,
                                  -0.034737947715984964,
                                  0,
                                  0,
                                  0,
                                  -0.099543267038093158,
                                  0.17685328057662814,
                                  0,
                                  0.13575000549446503,
                                  0,
                                  0,
                                  -0.1227334793968799,
                                  0,
                                  0,
                                  -0.08274916513405127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081549799676161827,
                                  0,
                                  0,
                                  0.25070909800130403,
                                  0,
                                  -0.10086603234051966,
                                  0,
                                  -0.48281782986032068,
                                  0,
                                  -0.069567940384546972,
                                  -0.19764827427643544,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29554691127202232,
                                  0.22620354781887186,
                                  0.022424812239079692,
                                  0.24643282813973888,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088494786025479236,
                                  -0.35666076128665558,
                                  0,
                                  0,
                                  -0.31797828791474181,
                                  0.0038724577268857089,
                                  0,
                                  0,
                                  0.051673621463442107,
                                  0,
                                  -0.30818334931822966,
                                  -0.42216551756764908,
                                  -0.11564715265582372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17316295371004242,
                                  0.10884207371538301,
                                  0,
                                  0.0749799050785636,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30286230396588348,
                                  0,
                                  -0.10472871206396246,
                                  0.077194258987394793,
                                  0,
                                  0,
                                  0,
                                  0.30402519567836739,
                                  0,
                                  0,
                                  0,
                                  -0.1535387452793549,
                                  -0.3324921182183645,
                                  0,
                                  -0.10712592169093364,
                                  0,
                                  0,
                                  0.33884066498195559,
                                  0,
                                  0,
                                  -0.014621809926516689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058961750242137595,
                                  0,
                                  0,
                                  -0.059077150012406932,
                                  0,
                                  -0.3494730143029337,
                                  0,
                                  0.14257138821063664,
                                  0,
                                  -0.068034050799015588,
                                  -0.40059328784034537,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22083974517397081,
                                  -0.063919677400796293,
                                  0.01135034682810758,
                                  0.28567000895304795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18425209460114261,
                                  0.18334971736859954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.018923781451037631,
                                  0,
                                  0,
                                  0.11016842064408702,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.087014298523540631,
                                  -0.0086453652344863925,
                                  0,
                                  0.12304273978243749,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083407650435235348,
                                  -0.080824752433352631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.054358359436701441,
                                  0,
                                  0.16189646630628529,
                                  0,
                                  0.15640675997618939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17046567321729056,
                                  0,
                                  -0.40198858582908858,
                                  0,
                                  0,
                                  -0.31170861733548233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23462918888753667,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16770434224783456,
                                  -0.26941551353932758,
                                  0,
                                  0,
                                  -0.26765304952299512,
                                  0,
                                  0,
                                  -0.039348967475733236,
                                  0,
                                  0,
                                  0,
                                  0.20794268964767587,
                                  0,
                                  0,
                                  0.13839868264054736,
                                  0.053431625636556304,
                                  0,
                                  0.090306599256399056,
                                  0.26320510790434165,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26411879752454381,
                                  0.22673776563508408,
                                  -0.09150383414153454,
                                  0,
                                  -0.17362380941751698,
                                  0.10442400888539846,
                                  0,
                                  -0.10219085823236601,
                                  -0.1657788394518156,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16087482904515538,
                                  0,
                                  0,
                                  -0.096858179050541851,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17407991804148032,
                                  -0.021133278345916679,
                                  0,
                                  0.084521299046957099,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30055506761656436,
                                  0.041787822001676495,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056978159334554281,
                                  0,
                                  0.19464822529763678,
                                  0,
                                  -0.08588447017767642,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045572816370722885,
                                  0,
                                  -0.086389694568460434,
                                  0,
                                  0,
                                  0.17594725663253713,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22280359980077552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33303105700400393,
                                  0.035759361079687815,
                                  0,
                                  0,
                                  0.25259961761752486,
                                  0,
                                  0,
                                  0.14557102906870628,
                                  0,
                                  0,
                                  0,
                                  0.019565279299567785,
                                  0,
                                  0,
                                  -0.35799017396625094,
                                  0.02888381570269434,
                                  0,
                                  0.31328526787905153,
                                  0.30741980621332743,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19384412147674884,
                                  0.059715712990780399,
                                  -0.032373920224883376,
                                  0,
                                  -0.28244483970814405,
                                  0.1304208368169546,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34132109963044788,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.57423465786705719,
                                  0,
                                  0,
                                  0,
                                  0.014470415214740406,
                                  0,
                                  0,
                                  0,
                                  -0.28125408677570929,
                                  0.23040394346333154,
                                  0,
                                  0,
                                  0.41144699430045595,
                                  -0.63685589918476604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.72459511538261701,
                                  0,
                                  -0.025150925366388875,
                                  0,
                                  -0.19601311870415422,
                                  0,
                                  -0.15740422772704576,
                                  0.47614357668651075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09611357449396131,
                                  0.63701699124093147,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36148818651765907,
                                  -0.31692444280010301,
                                  0,
                                  -0.1866644096155877,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10094824529924692,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.05734325825821103,
                                  0,
                                  0,
                                  -0.048222084741572593,
                                  -0.008933742840275977,
                                  -0.2916178622231872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11671702557909128,
                                  0,
                                  0,
                                  -0.031899427156575982,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20952418170805698,
                                  -0.26331618610036334,
                                  0,
                                  -0.071991482225039816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0024064680747840211,
                                  0.23191040550167816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.011175020748826606,
                                  0,
                                  -0.0965764861085191,
                                  0,
                                  0.3500727635569918,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.038365889269203167,
                                  0,
                                  -0.22143113100222897,
                                  0,
                                  0,
                                  -0.27240490310409138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26653601304921598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0065424781392239163,
                                  -0.1580711140545151,
                                  0,
                                  0,
                                  0.025708488877168395,
                                  0,
                                  0,
                                  0.11212550741720906,
                                  0,
                                  0,
                                  0,
                                  0.29145564481970543,
                                  0,
                                  0,
                                  -0.074784327921851454,
                                  -0.25620255070147524,
                                  0,
                                  0.082225654274504678,
                                  -0.038651826713851527,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28363369099055247,
                                  -0.083416575760979772,
                                  0.028179224291020745,
                                  0,
                                  0.16090525055664001,
                                  -0.2889505389602014,
                                  0,
                                  0.063451583639410863,
                                  0.11077724828036663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2299678323076369,
                                  0,
                                  0,
                                  -0.013289234416298493,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12700291260761917,
                                  -0.074229429906749966,
                                  0,
                                  0.21508685154742604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35222651465521398,
                                  -0.095203305645351677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085555717974389225,
                                  0,
                                  -0.081735307272302216,
                                  0,
                                  -0.075210546087973257,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09166266050413123,
                                  0,
                                  -0.24081111710881092,
                                  0,
                                  0,
                                  0.082716758972036591,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.066784321485412884,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20365413562138904,
                                  0.31007483542368208,
                                  0,
                                  0,
                                  0.01577749067099983,
                                  0,
                                  0,
                                  -0.14689339866501755,
                                  0,
                                  0,
                                  0,
                                  -0.13403728241976487,
                                  0,
                                  0,
                                  -0.086254476800129223,
                                  -0.23242390663731571,
                                  0,
                                  -0.32698087337216886,
                                  -0.068561136414642149,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17170642208163517,
                                  0.42273617624960802,
                                  0.058462033423653498,
                                  0,
                                  0.26181089298491489,
                                  -0.040203654789031977,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056703511137539339,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019076842457654095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27470599748603425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17053968056830668,
                                  0.10367275942077941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15221916013406006,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1699446087806836,
                                  0,
                                  0,
                                  0.31817133340354531,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36458131877724709,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.036130959131851027,
                                  0,
                                  0,
                                  0.20076540649840097,
                                  0.1435477507768399,
                                  0.25044873202978235,
                                  -0.11517182880137174,
                                  0,
                                  0,
                                  0.075339126786686958,
                                  0,
                                  0,
                                  -0.17410343199192893,
                                  0,
                                  0,
                                  0,
                                  0.056248485341773458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.64285126607890208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057379289991286872,
                                  -0.031810622123972974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.077407631861636877,
                                  -0.34457258104611205,
                                  0,
                                  0,
                                  0.32671578453958139,
                                  -0.44177969344944762,
                                  0,
                                  0,
                                  -0.33962362459894768,
                                  0,
                                  0.17271914713113146,
                                  0.45064070019788827,
                                  0.058229591149685775,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0035924517857624169,
                                  0.22378333365299519,
                                  0,
                                  0.092258422910663773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26989173393655319,
                                  0,
                                  0.092612363525964664,
                                  0.22263797464420704,
                                  0,
                                  0,
                                  0,
                                  0.44626804905992484,
                                  0,
                                  0,
                                  0,
                                  0.064165336107803894,
                                  -0.072565477795998076,
                                  0,
                                  0.33675564999164387,
                                  0,
                                  0,
                                  0.39837431022463099,
                                  0,
                                  0,
                                  -0.071116923165010115,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22154256204562428,
                                  0,
                                  0,
                                  0.13495426933019933,
                                  0,
                                  0.17373641231256212,
                                  0,
                                  0.16387886066097238,
                                  0,
                                  0.0075616649003594216,
                                  -0.031916873403380563,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11748333277729674,
                                  0.37781451756745377,
                                  -0.11100672991731034,
                                  0.18215174777793494,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16419020047451305,
                                  -0.25772711885363403,
                                  0,
                                  0,
                                  0.13176622500237153,
                                  0.29882991024623368,
                                  0,
                                  0,
                                  -0.11783232729785711,
                                  0,
                                  0.72637032001658908,
                                  0.025342443138502473,
                                  -0.12939852847182748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.023637747550126445,
                                  0.083145456658925601,
                                  0,
                                  -0.071824903921141769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21934570671827172,
                                  0,
                                  -0.13493393104528603,
                                  0.098104656353701913,
                                  0,
                                  0,
                                  0,
                                  -0.11248909487354274,
                                  0,
                                  0,
                                  0,
                                  0.048914999181024377,
                                  0.013807822516483187,
                                  0,
                                  -0.058375081837969134,
                                  0,
                                  0,
                                  -0.017290127795961261,
                                  0,
                                  0,
                                  0.17751192300202945,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.76701771392082896,
                                  0,
                                  0,
                                  -0.22659548260700293,
                                  0,
                                  -0.16155726656526159,
                                  0,
                                  0.069976352483062151,
                                  0,
                                  0.036875447480792245,
                                  -0.13717394643989919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34222867302461712,
                                  -0.094524482364407983,
                                  0.45332351696444795,
                                  -0.018211703753875364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20488278985748543,
                                  -0.16857017138514563,
                                  0,
                                  0,
                                  0.10488962533753236,
                                  -0.015590452420013697,
                                  0,
                                  0,
                                  -0.12847368996431588,
                                  0,
                                  -0.36027394572046123,
                                  -0.15165316564066264,
                                  -0.028857591861072372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.013758318236044183,
                                  -0.31312017985335633,
                                  0,
                                  -0.35719968796284524,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26896466950005171,
                                  0,
                                  -0.19812883746426316,
                                  0.10306574668658684,
                                  0,
                                  0,
                                  0,
                                  0.17639823288069861,
                                  0,
                                  0,
                                  0,
                                  0.18861369146700804,
                                  0.12219195351561435,
                                  0,
                                  0.39167146564509531,
                                  0,
                                  0,
                                  -0.37492439675104267,
                                  0,
                                  0,
                                  0.23244616821954336,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025692536296937876,
                                  0,
                                  0,
                                  -0.10447464758905756,
                                  0,
                                  -0.13932409244549782,
                                  0,
                                  -0.36541635380134235,
                                  0,
                                  -0.10091389949694426,
                                  -0.12065710914598154,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33477322448833491,
                                  0.10769163628094054,
                                  0.45930349310253987,
                                  -0.22565633538071125,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24261243628624013,
                                  -0.17019923807756512,
                                  0,
                                  0,
                                  0.10687041977140416,
                                  -0.070700963110249357,
                                  0,
                                  0,
                                  -0.18286215874988992,
                                  0,
                                  -0.080629793412953288,
                                  -0.13321655138852267,
                                  -0.019514782613827771,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068093653980160082,
                                  -0.20066569785232177,
                                  0,
                                  -0.44710487594770554,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29288454011197723,
                                  0,
                                  0.0047005328143310795,
                                  -0.40382337681785679,
                                  0,
                                  0,
                                  0,
                                  -0.38531013096176603,
                                  0,
                                  0,
                                  0,
                                  -0.06889755887127455,
                                  -0.089037412721975503,
                                  0,
                                  0.45057638388125337,
                                  0,
                                  0,
                                  0.011230629562195775,
                                  0,
                                  0,
                                  -0.1218987894265485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23736572524423952,
                                  0,
                                  0,
                                  0.12484797575160589,
                                  0,
                                  -0.35351932383495815,
                                  0,
                                  -0.013308730224294405,
                                  0,
                                  -0.031653020693966631,
                                  -0.10452985864641361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53461946661895388,
                                  0.46443717534339768,
                                  -0.25288268305884082,
                                  0.22382912597046131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36934830715274797,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079363921808001198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1813618389731548,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.084622749465399605,
                                  0.30689373291544808,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36281330198486683,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34042708293833085,
                                  0,
                                  0,
                                  0.086262261737826737,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.100792151642112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20287909094335033,
                                  0,
                                  0,
                                  -0.032854726701340736,
                                  0.095514530074352608,
                                  -0.090023315050417052,
                                  -0.062111764031805794,
                                  0,
                                  0,
                                  -0.080655719917340149,
                                  0,
                                  0,
                                  -0.2194211577020011,
                                  0,
                                  0,
                                  0,
                                  0.070558819690393848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26003733967511211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51652234586705648,
                                  0.023521027473042563,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.042482776641213277,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39226533908147271,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18318112447145662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.065173513020525833,
                                  0.29994306134842275,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.027097416883660304,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35034675524053954,
                                  0,
                                  0,
                                  -0.11481451557446259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.062192565607907438,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027299861120363412,
                                  0,
                                  0,
                                  -0.059604336766166346,
                                  -0.20778808223980549,
                                  0.09588815356190046,
                                  0.26305301699717243,
                                  0,
                                  0,
                                  -0.49299542237176125,
                                  0,
                                  0,
                                  -0.43319401639677674,
                                  0,
                                  0,
                                  0,
                                  -0.020041002636402065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036548747665689163,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.029602470452629738,
                                  -0.12979361907642259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.035555209243511396,
                                  -0.069579770446110037,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.01136704351640672,
                                  0,
                                  0,
                                  0.070629043891000859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.027323452794069343,
                                  0.2153535994612395,
                                  0,
                                  -0.22073902527490899,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47787752197542155,
                                  0.030844048499801737,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.02022261167353661,
                                  0,
                                  -0.2236543082327685,
                                  0,
                                  0.096846607884291308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14063808098602593,
                                  0,
                                  0.26416624870043875,
                                  0,
                                  0,
                                  0.18332201777296583,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11896642663548512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41624078553393001,
                                  0.043622883671682357,
                                  0,
                                  0,
                                  -0.27179874069870147,
                                  0,
                                  0,
                                  -0.043028941482995756,
                                  0,
                                  0,
                                  0,
                                  0.1123020384924682,
                                  0,
                                  0,
                                  -0.052182080616537188,
                                  0.018561845948448848,
                                  0,
                                  -0.00096738310979396086,
                                  0.10818819614565822,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1079368587366339,
                                  -0.098481815950284365,
                                  -0.070990449629218619,
                                  0,
                                  -0.36632724592197441,
                                  -0.16619911981078284,
                                  0,
                                  0.0095213799166470828,
                                  -0.30808813953875669,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16748549701137005,
                                  0,
                                  0,
                                  -0.20801446189831641,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.074468930832053734,
                                  -0.030696354918668636,
                                  0,
                                  -0.26307867776123417,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.059190146820747636,
                                  -0.055074231726158926,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33679489752096198,
                                  0,
                                  0.35780591988228438,
                                  0,
                                  0.11542049423238995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.035446668463000638,
                                  0,
                                  0.030880726494823679,
                                  0,
                                  0,
                                  0.0764823197081137,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18749972523082314,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095026708787684891,
                                  0.31370779779285113,
                                  0,
                                  0,
                                  0.11351617502162326,
                                  0,
                                  0,
                                  0.070362992979869116,
                                  0,
                                  0,
                                  0,
                                  0.24711714016997788,
                                  0,
                                  0,
                                  0.11761469214831896,
                                  0.14803358277995751,
                                  0,
                                  -0.20742752907450335,
                                  0.24607787553977065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16869952203705654,
                                  0.10792407424080372,
                                  -0.03013950406861822,
                                  0,
                                  0.23793240130503682,
                                  -0.17360801106134874,
                                  0,
                                  0.071233230885478269,
                                  0.093531760558945284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064906233140406305,
                                  0,
                                  0,
                                  -0.32816193783729658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.059385749728413172,
                                  -0.20833027759184158,
                                  0,
                                  -0.24783014289732344,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11737404418835537,
                                  -0.012668409480763632,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22360500570212244,
                                  0,
                                  -0.078021052442469457,
                                  0,
                                  0.23469891011269189,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12878324704848002,
                                  0,
                                  0.055582586988025248,
                                  0,
                                  0,
                                  0.21758931868507891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15964093824014391,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36412104579066401,
                                  0.10634157234387998,
                                  0,
                                  0,
                                  -0.4342497389870576,
                                  0,
                                  0,
                                  0.0089072138408486379,
                                  0,
                                  0,
                                  0,
                                  -0.031054635952294712,
                                  0,
                                  0,
                                  0.23769678277102693,
                                  0.15562977774968731,
                                  0,
                                  0.22340830042539261,
                                  -0.0084861432266251403,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.065656686052946028,
                                  0.22659157944231145,
                                  0.056563972494245968,
                                  0,
                                  0.11752130634687578,
                                  0.10694071050607494,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15399853928892834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45585181219663568,
                                  0,
                                  0,
                                  0,
                                  0.1831309978010387,
                                  0,
                                  0,
                                  0,
                                  0.13019398556437267,
                                  0.30388012927483643,
                                  0,
                                  0,
                                  0.051781676883906849,
                                  -0.18363297174694665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19697737819451494,
                                  0,
                                  -0.1603204405004203,
                                  0,
                                  0.5532847807562602,
                                  0,
                                  -0.082873362955216551,
                                  -0.016045310435401167,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12037873393161222,
                                  -0.081689453722241526,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13834331216228624,
                                  0.20475568884888506,
                                  0,
                                  -0.10876579473538858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.058685436437376837,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39973731690529651,
                                  0,
                                  0,
                                  0.63271595206935072,
                                  0.1548173173565634,
                                  0.075501377516412171,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053166538461844007,
                                  0,
                                  0,
                                  -0.20656659780011499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34162754111004456,
                                  0.18276821629680837,
                                  0,
                                  -0.29167422198448745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16459029068175929,
                                  -0.097894368611732271,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13962214417897162,
                                  0,
                                  -0.26571714017961107,
                                  0,
                                  0.16145408808087106,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2428860165897575,
                                  0,
                                  -0.013899423849407705,
                                  0,
                                  0,
                                  -0.0065752140399519959,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.090502922566621027,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0015853019945197763,
                                  -0.1712969005248739,
                                  0,
                                  0,
                                  0.2665483149862517,
                                  0,
                                  0,
                                  -0.20125897459417499,
                                  0,
                                  0,
                                  0,
                                  0.13319317188625568,
                                  0,
                                  0,
                                  -0.10533887227006264,
                                  0.19635958848879381,
                                  0,
                                  -0.19852175972646485,
                                  -0.10601115076041642,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12622222470929931,
                                  0.14046307093221627,
                                  -0.3480478127884305,
                                  0,
                                  -0.12171779113432421,
                                  0.1970533076988763,
                                  0,
                                  -0.15910243992028855,
                                  0.27187540138095756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.048140484129789107,
                                  0,
                                  0,
                                  0.057299413420629428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15447200558165383,
                                  -0.42758672242815809,
                                  0,
                                  -0.18603108083020711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13318812846109432,
                                  -0.35548314460784264,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12849093504466655,
                                  0,
                                  0.10467492632428994,
                                  0,
                                  -0.026653165191060261,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37448735941984479,
                                  0,
                                  0.077913585912647354,
                                  0,
                                  0,
                                  0.044379776832836559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0073495505461303977,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13548571182757921,
                                  -0.18026075175355036,
                                  0,
                                  0,
                                  0.17238580055716171,
                                  0,
                                  0,
                                  -0.22135597981507862,
                                  0,
                                  0,
                                  0,
                                  -0.18910684740173345,
                                  0,
                                  0,
                                  0.22034712288988759,
                                  -0.034104557261306262,
                                  0,
                                  -0.067291115135181073,
                                  -0.013582987189597506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14729813869027367,
                                  -0.066242077078823819,
                                  -0.093759504812814295,
                                  0,
                                  -0.096130355937108794,
                                  -0.2633974842236943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26326823733010241,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17676965181961646,
                                  0,
                                  0,
                                  0,
                                  0.15308759127143501,
                                  0,
                                  0,
                                  0,
                                  0.26941659055772055,
                                  0.1098798335621763,
                                  0,
                                  0,
                                  -0.16489937385985454,
                                  0.20689961062791018,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088653019034451164,
                                  0,
                                  0.1168660804667796,
                                  0,
                                  -0.03442210775380853,
                                  0,
                                  0.68098780209994159,
                                  -0.23709606349050141,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16532241418440191,
                                  -0.14007702277369805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47211147218123589,
                                  0.032279939712449357,
                                  0,
                                  -0.61232861070210121,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49882160735352699,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10946445195237493,
                                  0,
                                  0,
                                  -0.013213235944859875};

const double rot_20_30[900] = {-0.013719087870402782,
                               0,
                               0,
                               0.61464216792894344,
                               0.55974395670208976,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.51876058006406178,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17994529100275797,
                               0.084974394876527665,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5118709659374896,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.28739258475242824,
                               0,
                               0,
                               0,
                               -0.41729061818936408,
                               0.75657794534451273,
                               -0.44955659989969549,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1805017859527337,
                               0,
                               0,
                               0.46228394363590186,
                               0,
                               0,
                               0,
                               0.14983986675175465,
                               0,
                               0.30049431516091696,
                               0,
                               0,
                               0,
                               -0.077838170104818485,
                               0,
                               0,
                               0,
                               0.017206282247387322,
                               -0.78542906209740648,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10337179180308806,
                               0,
                               -0.21159971255913657,
                               0.9427270811059425,
                               0,
                               0,
                               0.33814542167843953,
                               0,
                               0,
                               0.10164348158423583,
                               -0.33836881373355654,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44828128443197163,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22408018686575379,
                               -0.71390810488754153,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41162157940193833,
                               0,
                               0,
                               0.23321134295682286,
                               -0.66423907616460065,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22903623130801493,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.5139357340507249,
                               0.13556939402716078,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38414416489204495,
                               0,
                               0.080774022513704746,
                               0,
                               0.3315989493586412,
                               0.4656863668335558,
                               0,
                               0,
                               -0.30036107100120035,
                               0,
                               0.098118642056923361,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39721155903092087,
                               0,
                               0,
                               0,
                               -0.28115939415073465,
                               0,
                               0,
                               -0.42710126897129652,
                               0,
                               0,
                               0,
                               0.39208951095688072,
                               0,
                               0,
                               0,
                               0.022629236684736244,
                               0,
                               0.34033488052966637,
                               0,
                               0,
                               0,
                               0.81690766699351935,
                               0,
                               0,
                               0,
                               -1.0151857562134254,
                               0.22293649033197749,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44403530296947558,
                               0,
                               -0.18065467241218836,
                               -0.14454809329276708,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1665148034993558,
                               0,
                               -0.14954088002012331,
                               0,
                               -0.1955319648674706,
                               0.64574549931424174,
                               0,
                               0,
                               0.37872573832962231,
                               0,
                               0.32912994331784795,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23719642051252021,
                               0,
                               0,
                               0,
                               -0.039695638199282825,
                               0,
                               0,
                               0.43022407672178942,
                               0,
                               0,
                               0,
                               0.57989980328988899,
                               0,
                               0,
                               0,
                               -0.5214717249825277,
                               0,
                               -0.19712531010663153,
                               0,
                               0,
                               0,
                               0.63721465242067954,
                               0,
                               0,
                               0,
                               0.033521178906076018,
                               -0.86623389170296161,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.089823523326434979,
                               0,
                               0.20677572842870204,
                               -0.64106749402596153,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.071569536473624212,
                               0,
                               -0.24842780484414181,
                               0,
                               0.12275282636000021,
                               0.20222648192430029,
                               0,
                               0,
                               -0.56215554390858247,
                               0,
                               -0.45723679378130894,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.082858034019526738,
                               0,
                               0,
                               0,
                               0.2770714523304651,
                               0,
                               0,
                               0.51814982025063427,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.56650080092177379,
                               0,
                               0.42418830716725253,
                               0,
                               0.086426061732026688,
                               -0.22998528267541379,
                               0,
                               0,
                               -0.26921986335725406,
                               0,
                               0.063403177631569538,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.44204481609077695,
                               0,
                               0,
                               0,
                               -0.34026679057649589,
                               0,
                               0,
                               0.22603986874429191,
                               0,
                               -0.080889851817517733,
                               0,
                               0,
                               -0.73748466095484844,
                               0.16330323254972523,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.61585203978276482,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17737129700081181,
                               0.11032202438189563,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25259569043010111,
                               0,
                               0,
                               0,
                               -0.26294692159194222,
                               0,
                               -0.63626186141697494,
                               0,
                               0,
                               0,
                               0.43179779750178082,
                               0,
                               0,
                               0,
                               0.44904231798235117,
                               0.41280910341412896,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51243824478355071,
                               0,
                               -0.51178356624099575,
                               0.44165385666156315,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.53465185043906605,
                               0,
                               -0.17266364366925788,
                               0,
                               -0.34742789978956451,
                               0.25495358123349476,
                               0,
                               0,
                               -0.38079020759629467,
                               0,
                               0.11635069149072025,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.080506219593948991,
                               0,
                               0,
                               0,
                               0.30817200276729201,
                               0,
                               0,
                               -0.4885051591810019,
                               0,
                               0,
                               0.9081240317193161,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50223097832384478,
                               0,
                               0,
                               0,
                               -0.82584728756615511,
                               0.13961598216940924,
                               -0.62396875671512053,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.70757710600892232,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35859754257135501,
                               0,
                               -0.21083310991376136,
                               0,
                               0.78113460776081323,
                               0.10257358993476551,
                               0,
                               0,
                               0.037797382252459197,
                               0,
                               0.19726298384201735,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40468987726248506,
                               0,
                               0,
                               0,
                               -0.039498241211905108,
                               0,
                               0,
                               0.024274486918958241,
                               0,
                               0,
                               0,
                               0.018632317185628119,
                               0,
                               0,
                               0,
                               0.31879973711086496,
                               0,
                               -0.90247828912630679,
                               0,
                               0,
                               0,
                               -0.52891264792369275,
                               0,
                               0,
                               0,
                               -0.24885908251445535,
                               -0.28701896151558765,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.79144836628820858,
                               0,
                               -0.43708243969402738,
                               -0.25625053285593369,
                               0,
                               0,
                               0,
                               0,
                               -0.22472456082157388,
                               0,
                               0,
                               0,
                               -0.39472488599236893,
                               0,
                               -0.15231363392611702,
                               0,
                               0,
                               0,
                               -0.20135520569728621,
                               0,
                               0,
                               0,
                               0.68246674661940532,
                               0.53062855097037942,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.71264259424433107,
                               0,
                               0.58853327100042208,
                               0.32351102082683375,
                               0,
                               0,
                               0,
                               -0.69144640798448942,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57058058502005249,
                               0,
                               0,
                               0,
                               0.079071948724381974,
                               -0.48324446103221741,
                               -0.19647383274306074,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.77004815027746909,
                               0,
                               -0.63778253047886879,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19147340281868339,
                               0,
                               0,
                               0,
                               -0.82005657119857578,
                               -0.018209861299157332,
                               0.87777226972714806,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14741167563954988,
                               0,
                               -0.5747432725197289,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.56122193573869139,
                               0,
                               0,
                               0,
                               0.35647187536953201,
                               0.24216035497053617,
                               0.15247905377039622,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.71178653686085847,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24608280660727322,
                               0,
                               -0.52218343048132987,
                               0,
                               0.023256990695428262,
                               -0.053556191525436725,
                               0,
                               0,
                               0.31857597822107553,
                               0,
                               -0.56430931521005856,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.29420202177002952,
                               0,
                               0,
                               0,
                               -0.32477145948537672,
                               0,
                               0,
                               -0.22669710257064651,
                               0,
                               0.19488401344374989,
                               0,
                               0,
                               -0.11001189889025315,
                               0.23277278725554981,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30496869973577845,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.76555006570700168,
                               -0.46546924925001781,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.81945969331844748,
                               0,
                               0,
                               -0.03885658927636499,
                               0.22389413184834808,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.072070192345500592,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18907761174221432,
                               -0.48569840264639597,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43299960329799803,
                               0,
                               0,
                               0,
                               -0.59539474660299518,
                               0,
                               -0.077740389049726133,
                               0,
                               0,
                               0,
                               -0.88982006065626551,
                               0,
                               0,
                               0,
                               -0.31118396185927416,
                               0.76455757146156744,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30398215146281332,
                               0,
                               0.26457120128158851,
                               0.032211817863594339,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.13570383456364185,
                               0,
                               0.50149205141585074,
                               0,
                               0.24727648778020159,
                               0.20668268158410791,
                               0,
                               0,
                               0.3579156917545977,
                               0,
                               -0.37818143800587778,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17520475358265941,
                               0,
                               0,
                               0,
                               0.5500970463009478,
                               0,
                               0,
                               -0.14764312003063548,
                               0,
                               0,
                               0,
                               -0.79889341559902338,
                               0,
                               0,
                               0,
                               -0.58370397128395735,
                               0,
                               -0.33560638611252563,
                               0,
                               0,
                               0,
                               -0.14377643581642474,
                               0,
                               0,
                               0,
                               -0.66675347968097998,
                               -0.12955350346195116,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.1958274333527785,
                               0,
                               0.013561365646498569,
                               0.40595909879163705,
                               0,
                               0,
                               0,
                               0,
                               -0.15649347480132003,
                               0,
                               0,
                               0,
                               -0.38370014850745365,
                               0,
                               0.85742152620672962,
                               0,
                               0,
                               0,
                               -0.41667591023672323,
                               0,
                               0,
                               0,
                               0.29331796861392639,
                               -0.0048858340985974144,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28403780711361137,
                               0,
                               -0.64188996100964335,
                               -0.30966703201928159,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.072413035151002988,
                               0,
                               0.36197768100959088,
                               0,
                               -0.19159252844119479,
                               0.38891067247968075,
                               0,
                               0,
                               -0.042751972707539554,
                               0,
                               -0.39375676817248484,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.54422888456089624,
                               0,
                               0,
                               0,
                               -0.47139178750724497,
                               0,
                               0,
                               0.022402743054134117,
                               0,
                               0,
                               -0.38226176205635404,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42767690401746339,
                               0,
                               0,
                               0,
                               0.48971459768870562,
                               -1.1754041068946015,
                               -0.52781972417089396,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.019995805338907803};

const double rot_20_2[4] = {0.4845968657549875, 0.87473760505676346, 0.87473760505676357, -0.48459686575498812};

const double rot_21_50[2500] = {-0.37201538358227515,
                                0,
                                0,
                                0,
                                0,
                                0.3781022411383741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45942709631900369,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12812240029498737,
                                -0.51532730390729764,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30995218625538734,
                                0,
                                0.23759110639379555,
                                0,
                                0,
                                0.056583234920064895,
                                0,
                                0,
                                0,
                                0.2569777374711204,
                                0.061913662068511621,
                                0,
                                0.27156072036305912,
                                0,
                                0.48874911788249492,
                                0,
                                0,
                                -0.71022677522124178,
                                0,
                                0,
                                0,
                                -0.69614836858389584,
                                0,
                                -0.35868846789423331,
                                0,
                                0,
                                0,
                                -0.0048052432649784982,
                                0,
                                0,
                                -0.3052716537161928,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.81300877161423513,
                                0,
                                0,
                                0,
                                0,
                                -0.073162721693336735,
                                0,
                                0.21049996512662458,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.028701379728711056,
                                0,
                                0,
                                0,
                                0,
                                0.21987795731643822,
                                0.16386569470155857,
                                -0.30249749751450306,
                                0,
                                0.29006841096372921,
                                0,
                                0,
                                0,
                                0.096565655471517187,
                                0,
                                0.17783320540986661,
                                0,
                                0,
                                0.28942528110764321,
                                0,
                                -0.065152473200023209,
                                0.14980471204427109,
                                -0.38506612156623865,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.079486777378677362,
                                0,
                                0,
                                -0.0012466761487250804,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16186666363824628,
                                0,
                                -0.6450846675976305,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62738392122943054,
                                0,
                                0.10800112333218018,
                                0,
                                0,
                                -0.0023801914677915453,
                                0,
                                0,
                                0,
                                -0.69618451185363506,
                                0,
                                -0.176881644895863,
                                0,
                                0,
                                0,
                                0.15208328031890039,
                                0,
                                0,
                                0.42991508522614413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50931908181577534,
                                0,
                                0,
                                0,
                                0,
                                -0.17029323576384273,
                                0,
                                0.47391061026508852,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52150147056023544,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51835573123256828,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13469353845585291,
                                0,
                                -0.16375855118446192,
                                0,
                                0,
                                0.4988175562389307,
                                -0.48882854462507758,
                                0,
                                0.82457921265175482,
                                0.060577475937851878,
                                0,
                                0,
                                0,
                                0.34896021667170662,
                                0,
                                0,
                                0,
                                -0.32306615372198549,
                                0,
                                0,
                                0,
                                0.25145621828565268,
                                0,
                                0,
                                0,
                                0,
                                -0.44774563753735186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.053985502066046034,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.030251350019876212,
                                -0.69479201321554551,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.040340850456177621,
                                0,
                                -0.42760875217144623,
                                0,
                                0,
                                -0.14127699207463021,
                                0,
                                0,
                                0,
                                0.14959253265537373,
                                0.15137486795118094,
                                0,
                                -0.23285393864488449,
                                0,
                                0.074370102065355895,
                                0,
                                0,
                                -0.31467676290636803,
                                0,
                                0,
                                0,
                                -0.21932625933655589,
                                0,
                                0.38110328167138185,
                                0,
                                0,
                                0,
                                0.98655528041306351,
                                0,
                                0,
                                -0.24089745822487982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.036144172968612526,
                                0,
                                0,
                                0,
                                0,
                                -0.18289834016348966,
                                0,
                                0.13609490299973412,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.070948741574959298,
                                0,
                                0,
                                0,
                                0,
                                -0.46064089480409437,
                                -0.17003377361609257,
                                0.1191384052407123,
                                0,
                                0.21605485194859286,
                                0,
                                0,
                                0,
                                0.2846622179855679,
                                0,
                                0.045622283452225618,
                                0,
                                0,
                                0.10889417462024312,
                                0,
                                -0.17899152313476469,
                                -0.012874356595378523,
                                0.56193226584303901,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.065568009337861166,
                                0,
                                0,
                                0.12170421395036796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20013010474068763,
                                0,
                                -0.43690326474439278,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.080584346799925113,
                                0,
                                0,
                                0,
                                0,
                                -0.11204730519893048,
                                -0.3650113165126207,
                                0.20672568214593007,
                                0,
                                -0.26240899469120593,
                                0,
                                0,
                                0,
                                -0.47455256677573415,
                                0,
                                0.012766928597510982,
                                0,
                                0,
                                -0.035274338979669161,
                                0,
                                0.034392407989793358,
                                -0.023654482313573123,
                                -0.067859535190062714,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13844018571297514,
                                0,
                                0,
                                -0.57039351640456104,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.066818656396873385,
                                0,
                                -0.39267089633253976,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1858889440477704,
                                0,
                                0,
                                0,
                                0,
                                -0.078239643704974993,
                                -0.059770478978422775,
                                -0.5915269068024015,
                                0,
                                -0.50336747293909223,
                                0,
                                0,
                                0,
                                -0.053263162161083927,
                                0,
                                -0.033783576689347825,
                                0,
                                0,
                                0.32506275904599891,
                                0,
                                0.18548528942683026,
                                -0.3413233089471861,
                                0.12786222930645935,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19415504013203166,
                                0,
                                0,
                                0.14844364981308528,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.099220543038162995,
                                0,
                                -0.077413215469119542,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34853241378908462,
                                0,
                                -0.50091209980188256,
                                0,
                                0,
                                -0.20341407895183461,
                                0,
                                0,
                                0,
                                -0.44330723843117381,
                                0,
                                0.67319151384899767,
                                0,
                                0,
                                0,
                                -0.39462052868160646,
                                0,
                                0,
                                -1.0044404814744423,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.068344128357153033,
                                0,
                                0,
                                0,
                                0,
                                0.39937091015369541,
                                0,
                                0.16633977232328057,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29218795548768944,
                                0,
                                0,
                                0,
                                0,
                                0.071097584285536863,
                                -0.32120305209801936,
                                -0.12373358665889407,
                                0,
                                0.42313054256290045,
                                0,
                                0,
                                0,
                                -0.037095439645629516,
                                0,
                                -0.42212985377430667,
                                0,
                                0,
                                -0.052211765651222708,
                                0,
                                -0.028005492988374819,
                                -0.55858156292558747,
                                -0.1082434325965054,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23043726492986122,
                                0,
                                0,
                                -0.10502563167942169,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20263043346559526,
                                0,
                                -0.0070428472548958385,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56014600887546506,
                                0,
                                -0.41544600014425948,
                                0,
                                0,
                                -0.14635276868703928,
                                0,
                                0,
                                0,
                                0.088828227999902643,
                                0,
                                -0.15193758138409538,
                                0,
                                0,
                                0,
                                0.16964217172847093,
                                0,
                                0,
                                0.59539544091164309,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21811216651475759,
                                0,
                                0,
                                0,
                                0,
                                -0.52538153730517279,
                                0,
                                -0.6534229308637034,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.025145067735587417,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76064878931123103,
                                0,
                                0,
                                0,
                                0,
                                -0.051533508880578213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6461318402632602,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.025280176985149116,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.092673180453568982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50619761574885636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27222196816309829,
                                0,
                                -0.77734995390174211,
                                0,
                                0,
                                -0.026570936030593739,
                                0.33669441496761321,
                                0,
                                0.28259812257705186,
                                -0.94454114223311558,
                                0,
                                0,
                                0,
                                0.29203756744795017,
                                0,
                                0,
                                0,
                                -0.44576014600054109,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15027801346050876,
                                0,
                                0,
                                0,
                                0,
                                -0.16908550763367808,
                                -0.17710813581038415,
                                -0.36303013554472574,
                                0,
                                0.39085935564226509,
                                0,
                                0,
                                0,
                                -0.27210782704151354,
                                0,
                                0.47198493316550438,
                                0,
                                0,
                                0.058761560618311809,
                                0,
                                0.023529721925335867,
                                0.17994686701646159,
                                0.23262112125382883,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13143906334739663,
                                0,
                                0,
                                -0.22762058860831186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27320538714157966,
                                0,
                                0.31914946813579148,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51107286402298879,
                                0,
                                -0.29991238236484807,
                                0,
                                0,
                                -0.83192641904324194,
                                0,
                                0,
                                0,
                                0.22672195338547535,
                                0,
                                -0.096641898253408701,
                                0,
                                0,
                                0,
                                -0.10826352755402277,
                                0,
                                0,
                                0.68255689260779029,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0094213478332052861,
                                0,
                                0,
                                0,
                                0,
                                0.82533167230205851,
                                0,
                                -0.22343259473194596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49510866915785146,
                                0,
                                0,
                                0,
                                0,
                                -0.27725864484392138,
                                -0.26988772460555122,
                                -0.21663276741750728,
                                0,
                                -0.31689492377957307,
                                0,
                                0,
                                0,
                                0.023659965494963093,
                                0,
                                0.17313562364748419,
                                0,
                                0,
                                -0.17464317396480944,
                                0,
                                -0.35888031159072137,
                                0.07548841086498019,
                                -0.19774280475265221,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28119410952758778,
                                0,
                                0,
                                0.23222860827774175,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29898206876678901,
                                0,
                                0.027950214060335897,
                                0,
                                0,
                                0,
                                0,
                                -0.088228380890730013,
                                0,
                                0,
                                0,
                                0,
                                -0.2989166880029604,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38838469779734613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20112182201999002,
                                0.32403928635401247,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55598504077126298,
                                0,
                                -0.26319613579065199,
                                0,
                                0,
                                -0.043423327883270114,
                                0,
                                0,
                                0,
                                -0.15799244700965143,
                                0.4486999848328862,
                                0,
                                -0.10282737241968283,
                                0,
                                0.025893353365005225,
                                0,
                                0,
                                -0.48831774538513717,
                                0,
                                0,
                                0,
                                0.05665045124758078,
                                0,
                                0.31161182725631337,
                                0,
                                0,
                                0,
                                -0.64656920959346464,
                                0,
                                0,
                                0.11246064015863691,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16379560245519817,
                                0,
                                0,
                                0,
                                0,
                                -0.76782116895499852,
                                0,
                                0.19389289258528788,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.091744445399877916,
                                0,
                                0,
                                0,
                                0,
                                0.14305769611459759,
                                0.24472479070428388,
                                0.28396581572094515,
                                0,
                                -0.14818701840533832,
                                0,
                                0,
                                0,
                                0.049148976330646368,
                                0,
                                0.37048021188442831,
                                0,
                                0,
                                -0.076213918309149253,
                                0,
                                0.26608196150639574,
                                -0.4183664509332149,
                                0.28461397833396179,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.060313186209702739,
                                0,
                                0,
                                0.0089511084032932141,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55244480329549639,
                                0,
                                -0.16553913122857089,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65417747286965677,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41408778271983171,
                                0,
                                0,
                                0,
                                0,
                                -0.16457879997324976,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5130715238146546,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33204603934080501,
                                0,
                                0,
                                0,
                                0,
                                -0.31731612302683843,
                                0,
                                0,
                                0,
                                0,
                                -0.31837363834572829,
                                0.20378696556333559,
                                0.16692153015437564,
                                0,
                                0.041803923514999529,
                                0,
                                0,
                                0,
                                -0.22980271174192829,
                                0,
                                -0.37374320668136574,
                                0,
                                0,
                                0.44239392976451442,
                                0,
                                -0.27543075331344602,
                                -0.051379747433903417,
                                -0.0015882870325793774,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28086837577271961,
                                0,
                                0,
                                0.10532462556758301,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39753402248815989,
                                0,
                                0.10993375580012055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.049131831570590728,
                                0,
                                0,
                                0,
                                0,
                                -0.50298874030671992,
                                0.43886936322895309,
                                -0.13698632933178426,
                                0,
                                -0.0069444421445121474,
                                0,
                                0,
                                0,
                                -0.13753847452472043,
                                0,
                                -0.16607493262938408,
                                0,
                                0,
                                -0.49930102706206247,
                                0,
                                0.13782932434583206,
                                0.090726471835994749,
                                -0.15825401287038932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35854300947527512,
                                0,
                                0,
                                -0.023766164365682942,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13177505353584351,
                                0,
                                -0.19650503516295048,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13681367671305705,
                                0,
                                0,
                                0,
                                0,
                                -0.19416661644691185,
                                0.076029000649648973,
                                0.20961304433876912,
                                0,
                                0.13045433949865715,
                                0,
                                0,
                                0,
                                -0.2051076298480882,
                                0,
                                0.46835995693353832,
                                0,
                                0,
                                0.021444576917252253,
                                0,
                                -0.24367976603691113,
                                -0.47664320789134751,
                                -0.37482986139038477,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.095017875808419458,
                                0,
                                0,
                                0.22738423140192665,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35058533024418165,
                                0,
                                0.065167873838888085,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19241959678867657,
                                0,
                                0.66586648275598259,
                                0,
                                0,
                                -0.039791600123624031,
                                0,
                                0,
                                0,
                                0.6252100564641645,
                                0,
                                -0.12464819986999015,
                                0,
                                0,
                                0,
                                0.23513153207148343,
                                0,
                                0,
                                -0.21712849586519717,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61355526887791978,
                                0,
                                0,
                                0,
                                0,
                                0.44697319661039864,
                                0,
                                -0.65065939830571951,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56586724901517493,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42024045446483843,
                                0,
                                0,
                                0,
                                0,
                                0.53283955068916689,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42228508030097422,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20235992958031429,
                                0,
                                0,
                                0.034906331341266791,
                                0,
                                0,
                                0,
                                0,
                                -0.08842924971397699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19281707827725353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42040030365821829,
                                0.25123947378315487,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10917005192143435,
                                0,
                                -0.088444936292113516,
                                0,
                                0,
                                -0.68471444997280684,
                                0,
                                0,
                                0,
                                0.31629205475054739,
                                -0.35399230607041443,
                                0.27280511335119917,
                                0,
                                0,
                                0,
                                0,
                                0.16653064931964695,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20712667699008611,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65242916610467239,
                                0.00091233933407788848,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16063578447590887,
                                0,
                                0.26502791044637608,
                                0,
                                0,
                                -0.33566440474054993,
                                0,
                                0,
                                0,
                                0.45033811742785457,
                                0.13326718392202175,
                                0,
                                0,
                                0,
                                0,
                                0.63706561898405289,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10091691965442046,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.93397397308955443,
                                0,
                                0.24420871390163398,
                                0,
                                0,
                                -0.41914077237569364,
                                -0.9423443667179936,
                                0,
                                -0.038272017118820889,
                                -0.060526190700777638,
                                0,
                                0,
                                0,
                                0.73766838054027029,
                                0,
                                0,
                                0,
                                -0.19279105313188938,
                                0,
                                0,
                                0,
                                0,
                                -0.44053392204049552,
                                0,
                                -0.64295791974506789,
                                0,
                                0,
                                -0.44775012037635165,
                                0,
                                0,
                                0,
                                -0.0439873534965768,
                                0,
                                -0.84777653392431929,
                                0,
                                0,
                                0,
                                -0.06362603565336776,
                                0,
                                0,
                                -0.66077830762793344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.058161555149399198,
                                0,
                                0,
                                0,
                                0,
                                -0.41402610544400792,
                                0,
                                0.27542994469612925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68936248529409805,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.89898724654422224,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.064997437715212714,
                                0,
                                0.34056005461267624,
                                0,
                                0,
                                -0.73650603389947644,
                                -0.45499279381879115,
                                0,
                                -0.42303991058366847,
                                -0.40331279727236163,
                                0,
                                0,
                                0,
                                -0.14995528418993295,
                                0,
                                0,
                                0,
                                -0.48792637751079498,
                                0,
                                0,
                                0,
                                0,
                                0.45289725887302718,
                                0,
                                -0.31947290726209721,
                                0,
                                0,
                                0.099361006625325765,
                                0,
                                0,
                                0,
                                1.1055358641098396,
                                0,
                                0.11917405886196991,
                                0,
                                0,
                                0,
                                -0.030633831197284717,
                                0,
                                0,
                                -0.0037533575865930022,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0068823659521092817,
                                0,
                                0,
                                0,
                                0,
                                -0.065125042203250189,
                                0,
                                0.63797100160915843,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37095671249924833,
                                0,
                                0,
                                0,
                                0,
                                0.3895746735432134,
                                -0.13723725502183692,
                                -0.093583295413636219,
                                0,
                                0.013624599515590696,
                                0,
                                0,
                                0,
                                -0.30962091779247919,
                                0,
                                -0.075193706446983088,
                                0,
                                0,
                                -0.43921747147550888,
                                0,
                                -0.36060020034740048,
                                0.0099633688225978373,
                                0.26034718321832817,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0034066722924233437,
                                0,
                                0,
                                0.38146137174986416,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.072189073725345873,
                                0,
                                -0.19941388045102473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65802966249591899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.81453484401696308,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.063983515721467876,
                                0,
                                0.16307577802429263,
                                0,
                                0,
                                0.31508998732064253,
                                0.36003865725596973,
                                0,
                                -0.28310020746634784,
                                -0.80656662518118116,
                                0,
                                0,
                                0,
                                0.5430852651194551,
                                0,
                                0,
                                0,
                                -0.20655195551646213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62674535466940151,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22434138475790064,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084535743935221411,
                                0,
                                0.023272738743942006,
                                0,
                                0,
                                -0.8504245268614532,
                                0.65338711959273243,
                                0,
                                0.52513683695713653,
                                0.30151196813190428,
                                0,
                                0,
                                0,
                                -0.071390553074218377,
                                0,
                                0,
                                0,
                                -0.32805218006508319,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43606108949677169,
                                0,
                                0,
                                0,
                                0,
                                -0.21262614063811,
                                -0.40054291578703155,
                                0.0051029465950993991,
                                0,
                                0.12914085547633655,
                                0,
                                0,
                                0,
                                0.29058572853510417,
                                0,
                                -0.007029268595797734,
                                0,
                                0,
                                -0.21641679935325764,
                                0,
                                0.47198277888646445,
                                -0.053352467748382579,
                                -0.2293194035618156,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35146329189258907,
                                0,
                                0,
                                0.21458521956063031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.090853137473029158,
                                0,
                                -0.012163158785245666,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30608220071446157,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53604743925726783,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5433653991734273,
                                0,
                                -0.011237174234529246,
                                0,
                                0,
                                -0.34659431440065303,
                                0.42823339186584652,
                                0,
                                -0.27030592580885526,
                                0.65903828334031744,
                                0,
                                0,
                                0,
                                0.91289702873589107,
                                0,
                                0,
                                0,
                                -0.40166112158712275,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11530445646875859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50059934175676402,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34253766770733701,
                                0,
                                1.3950094090046625,
                                0,
                                0,
                                -0.22394451282580569,
                                0.15550919407042951,
                                0,
                                0.65327044934865097,
                                -0.39988262155316162,
                                0,
                                0,
                                0,
                                -0.16199183976991274,
                                0,
                                0,
                                0,
                                0.19773915136727455,
                                0,
                                0,
                                0,
                                0.31986510952088293,
                                0,
                                0,
                                0,
                                0,
                                0.30429175127334679,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.065223380860771035,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24512498464306906,
                                -0.099493783401985961,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1619309182996361,
                                0,
                                0.21741063572823088,
                                0,
                                0,
                                -0.42375734760217554,
                                0,
                                0,
                                0,
                                -0.45975113440708332,
                                0.51616187316657758,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.045911650621823286,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25847250750615003,
                                0,
                                0,
                                0,
                                0,
                                -0.1995300838599316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35267307952547144,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87572457303283002,
                                0,
                                0,
                                0.53577986807768752,
                                0,
                                0,
                                0,
                                0,
                                -0.33586139662619618,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.091955377773467364,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19852987235386754,
                                -0.056809551520885793,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3708327965945577,
                                0,
                                0.54369156323864742,
                                0,
                                0,
                                0.262828357100095,
                                0,
                                0,
                                0,
                                -0.065645997145925894,
                                -0.20623822912447937,
                                0,
                                0,
                                0,
                                0,
                                0.68720331547431956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33551106020334404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61022473704427183,
                                0,
                                -0.29219931072783495,
                                0,
                                0,
                                -0.25483802569444841,
                                -0.38900342580793601,
                                0,
                                -0.2602925540005806,
                                0.15746253092314064,
                                0,
                                0,
                                0,
                                -0.26561714503903167,
                                0,
                                0,
                                0,
                                0.90882211322305362,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35383790838910589,
                                0,
                                0,
                                0,
                                0,
                                0.010781614763280795,
                                0.053273121393432585,
                                -0.10984076277517489,
                                0,
                                -0.14537522292317556,
                                0,
                                0,
                                0,
                                0.54252206714308482,
                                0,
                                0.045565318546261044,
                                0,
                                0,
                                -0.17694155994806823,
                                0,
                                -0.46698523727400537,
                                -0.18672808190008244,
                                -0.046733672675875318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.026732808582899802,
                                0,
                                0,
                                -0.48943058678496154,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.090682685936338533,
                                0,
                                0.08557975019762909,
                                0,
                                0,
                                0,
                                0,
                                -0.52592015237057443,
                                0,
                                0,
                                0,
                                0,
                                -0.50019413598323559,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.09455815655748577,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18272116423420973,
                                -0.14723742212093366,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11090181971120944,
                                0,
                                0.46129463249770597,
                                0,
                                0,
                                -0.33106237727867927,
                                0,
                                0,
                                0,
                                -0.26854473220537267,
                                -0.048950688696992352,
                                0,
                                0,
                                -0.12963868067434242,
                                0,
                                0,
                                0,
                                0,
                                0.025501116692967032,
                                -0.34371486408729118,
                                0.33997051143418139,
                                0,
                                -0.18957841074780901,
                                0,
                                0,
                                0,
                                0.12157551528229989,
                                0,
                                0.048878341036311015,
                                0,
                                0,
                                0.19607878906156637,
                                0,
                                -0.045635567693335474,
                                0.24358856444062268,
                                -0.20240954306099757,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.66235506395285004,
                                0,
                                0,
                                0.16274794925004815,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29858820987887535,
                                0,
                                -0.022878459434168521,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5240573046890965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30468417142638249,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.55764031086844323,
                                0,
                                -0.14952275244610896,
                                0,
                                0,
                                -0.33876930412780387,
                                0.29969907681637353,
                                0,
                                0.14381125434188971,
                                -0.008369397513570468,
                                0,
                                0,
                                0,
                                0.37402892650562936,
                                0,
                                0,
                                0,
                                0.82663199811496657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49910513560533348,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.080837187087396761,
                                0,
                                0,
                                0,
                                0,
                                0.80406957094397935,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12871777803295495,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2850671350689209,
                                0,
                                0,
                                -0.057340883623016078,
                                0,
                                0,
                                0,
                                0,
                                0.26100890636558061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45096815171662585,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.03084289536748747,
                                -0.19134095851477348,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57860381215626433,
                                0,
                                -0.20562072866983866,
                                0,
                                0,
                                -0.16144936957463901,
                                0,
                                0,
                                0,
                                -0.42308076120563065,
                                -0.32484760805892288,
                                -0.21376448886668731,
                                0,
                                0,
                                0,
                                0,
                                -0.089123470910182717,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57451401158585214,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45385086824326126,
                                0.11028011883831323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21128361644792792,
                                0,
                                0.12420222529401223,
                                0,
                                0,
                                0.095560773815682218,
                                0,
                                0,
                                0,
                                0.34202881921208672,
                                0.46040259718717425};

const double rot_21_20[400] = {1.226676208144786,
                               0,
                               1.0243335183318261,
                               0,
                               0,
                               0,
                               0,
                               0.64001956478326372,
                               0,
                               0,
                               0,
                               -0.055193111873069856,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.74075317057585588,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.67177729961782418,
                               0,
                               0,
                               0,
                               0,
                               -0.84345709977886374,
                               0,
                               -0.30499635731302355,
                               0,
                               0,
                               0,
                               0,
                               0.91958044757575919,
                               0,
                               0,
                               0,
                               1.1827767174257513,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.3533603222768642,
                               -0.10884748542899156,
                               0,
                               0,
                               0,
                               0,
                               -0.2858496180237336,
                               0.045660338207607301,
                               0,
                               -0.87872771068169331,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.085623871827539458,
                               0,
                               0,
                               0,
                               -0.37386215354126401,
                               -0.72597977849468409,
                               0,
                               0,
                               0,
                               0,
                               0.13937043480710104,
                               0.40623647325675549,
                               0,
                               -0.047347743550468446,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.38273548600119417,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42393741442133259,
                               0,
                               0,
                               0.86083206903605325,
                               0,
                               0,
                               0,
                               0,
                               -0.27677658328032612,
                               0,
                               0,
                               -0.051380351502615468,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43910077221117566,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44480636621403713,
                               0,
                               0,
                               -0.79196990102667597,
                               1.4851584190317544,
                               0,
                               0.19300750936934857,
                               0,
                               -0.40978649198844169,
                               0,
                               0,
                               0,
                               0,
                               -1.0283232826443962,
                               0,
                               0,
                               0,
                               0.66962568044490312,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26977002433720743,
                               0,
                               0,
                               0.031660606882006295,
                               0,
                               0,
                               0,
                               0,
                               -0.13791945010643952,
                               0,
                               0,
                               -0.95247045372720229,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.68388617803426732,
                               0.42569279122495918,
                               0,
                               0,
                               0,
                               0,
                               0.14669148049171682,
                               0.30881329993764284,
                               0,
                               -0.38764179463561604,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.28971561465898887,
                               0,
                               0,
                               0,
                               -0.31546691925621162,
                               0.19155542214675375,
                               0,
                               0,
                               0,
                               0,
                               0.1407783723781614,
                               -0.62786405392514355,
                               0,
                               -0.16568401242718078,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.64984931390780432,
                               0.32733843617815273,
                               0,
                               -0.84495518714231344,
                               0,
                               0,
                               0,
                               0,
                               0.62881314921180986,
                               0,
                               0,
                               0,
                               0.029499721195099915,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.068538315074774467,
                               -0.44215215200690611,
                               0,
                               0,
                               0,
                               0,
                               0.44491474661219799,
                               -0.51411446180921483,
                               0,
                               -0.19747764957055874,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54639156304621428,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.53676872290799449,
                               0,
                               0,
                               -0.023317405162490784,
                               0,
                               0,
                               0,
                               0,
                               0.79950197141404222,
                               0,
                               0,
                               -0.26857444857854407,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19717730807859218,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.55193188215395461,
                               0,
                               0,
                               1.2352811385060654,
                               0.54023866992780745,
                               0,
                               0,
                               -0.67177729961782495,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.74075317057585666,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.67777617303249782,
                               0,
                               0,
                               -0.50736776948034401,
                               0,
                               0,
                               0,
                               0,
                               -0.51494615828751089,
                               0,
                               0,
                               -0.13426786595047963,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.3051892050285541,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27031678816785515,
                               0,
                               0,
                               0.7267141118512529,
                               -0.27176479668251363,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.87683393064311077,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.0416959416472951,
                               0,
                               0,
                               -0.55897168934143315,
                               -1.0425957744632248,
                               0,
                               0,
                               0,
                               0,
                               0.40428503621240675,
                               0.21840153010805435,
                               0,
                               0,
                               0,
                               0,
                               0.81214518741791053,
                               0.28105952579410898,
                               0,
                               -0.094239199161419165,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20346766818569914};

const double rot_21_10[100] = {-1.2141938635865743,
                               0,
                               -1.3639853301440072,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.17732008745966066,
                               0,
                               0,
                               0,
                               0,
                               0.50497678803329038,
                               0.84472245745622254,
                               0,
                               0,
                               -1.2718322651306557,
                               0,
                               0.21844901041953724,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.40876879520127712,
                               0,
                               0,
                               0,
                               0,
                               -1.1353631461919969,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.17728790045870549,
                               0,
                               0,
                               0,
                               -0.98415903204255772,
                               0,
                               0.27300043943902841,
                               0,
                               0,
                               0,
                               0,
                               0.79940098187394626,
                               -0.53519046165367024,
                               0,
                               0,
                               0,
                               0.94553072221340062,
                               0,
                               0,
                               0,
                               0,
                               -0.32550962155757041,
                               -0.0038909669816292458,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.8618053982335716,
                               0,
                               0,
                               0,
                               0,
                               0.27845871767110902,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.98415903204255772,
                               0,
                               0,
                               0,
                               0.17728790045870554};

const double rot_21_100[10000] = {0.3316283578893291,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025878767504211218,
                                  0,
                                  0,
                                  0,
                                  -0.2288510111292687,
                                  0.026099013497305479,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085050571720604623,
                                  0,
                                  0.14730595220696002,
                                  0,
                                  0,
                                  0.105368578223645,
                                  0,
                                  0,
                                  -0.14806497090261458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.012997410741988189,
                                  0,
                                  0.18917355080922937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17585886600140621,
                                  0,
                                  0.11800142944219252,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.090550115317447472,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12289383071483978,
                                  0,
                                  0.015663253777807695,
                                  0,
                                  0.31872974200073445,
                                  0,
                                  0.087180360156276143,
                                  0.083203075118876119,
                                  0.070958897411674993,
                                  -0.041697179033609075,
                                  -0.040167658092860305,
                                  0.32897333723644867,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25396475712329342,
                                  -0.41195254544177795,
                                  0.34047848838982953,
                                  0,
                                  0,
                                  -0.037215081455644207,
                                  0,
                                  0,
                                  -0.085852495625206887,
                                  0,
                                  0.17953347122531602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054642819484840531,
                                  -0.20775445725910568,
                                  0,
                                  -0.47118688979943291,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18374372975969772,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062256827701763044,
                                  0,
                                  0,
                                  0.042408146367884529,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029233077995492324,
                                  0,
                                  0,
                                  0.68548524416600343,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063967243259794582,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31700266744134276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24286867064269863,
                                  0.32285369721893076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13621962631984375,
                                  0,
                                  0.028385639507242093,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38467189409586261,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24783151479686016,
                                  0,
                                  0,
                                  -0.25575599517745429,
                                  0.13789452511605213,
                                  0.16356082072559797,
                                  0.10119112180122103,
                                  0,
                                  0,
                                  0,
                                  0.51187933948542974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16022424520735662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14956145820704028,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11696959572243498,
                                  0.0529591769443934,
                                  0,
                                  0,
                                  0,
                                  0.35957032688590468,
                                  0,
                                  0,
                                  0,
                                  0.32567077246653958,
                                  0,
                                  0.029644955800216179,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22111694191456005,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022347105736709335,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16054669756497197,
                                  0,
                                  -0.10900384663009249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16983403726467011,
                                  0,
                                  0,
                                  0.27737456478159278,
                                  0,
                                  0,
                                  0,
                                  0.028303459151120453,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079769563795080087,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23635911324919004,
                                  0,
                                  0,
                                  -0.42280738750665559,
                                  0,
                                  0,
                                  -0.47189002847496397,
                                  0.14370828415774312,
                                  -0.070728035551432922,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54837565880056827,
                                  0,
                                  -0.10414972674769357,
                                  0,
                                  -0.14563371095055874,
                                  0,
                                  0.14484167795660241,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39687408168295346,
                                  0,
                                  -0.322397392448178,
                                  0.15644173002097506,
                                  0,
                                  -0.12662430585117473,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10101318697928253,
                                  0,
                                  -0.2521935648491731,
                                  0,
                                  0.6188099523512457,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45895541367612269,
                                  0,
                                  0.28118943662748769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.099167374394814711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0072638839641734343,
                                  0,
                                  0,
                                  -0.040532354864998413,
                                  -0.16360509189683714,
                                  -0.079280617122495289,
                                  -0.33199026532907527,
                                  0,
                                  0,
                                  0,
                                  0.093399355003297643,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36464103600174158,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072310192410098548,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21320426964094902,
                                  0.1631057722819052,
                                  0,
                                  0,
                                  0,
                                  -0.0094646628699889615,
                                  0,
                                  0,
                                  0,
                                  -0.31191759492676613,
                                  0,
                                  -0.24862243840091558,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4174831909104989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030364255115172517,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.023129423058823703,
                                  0,
                                  0.03967050115727648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027255369193104458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3373118539990535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0058705810476680038,
                                  0.76026893023721609,
                                  0,
                                  -0.33631835827346673,
                                  0,
                                  0,
                                  -0.35244549813003878,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49029997949510035,
                                  0,
                                  0.48004452677405757,
                                  -0.087387155245765291,
                                  0,
                                  0,
                                  0,
                                  -0.59102035074268078,
                                  -0.22496651441569979,
                                  0,
                                  0.066873650080982588,
                                  0,
                                  0.17327055006335759,
                                  0,
                                  -0.12225383181068328,
                                  0,
                                  -0.0081998912808556278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33337830684803321,
                                  0,
                                  0,
                                  0.095986409880848986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18337949953435484,
                                  0,
                                  0,
                                  -0.039279862071732362,
                                  -0.29308827185089537,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19051480375525354,
                                  0,
                                  0,
                                  0.55629542461119863,
                                  0,
                                  0,
                                  0,
                                  -0.17924988068642203,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55601715159731868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39527817254557179,
                                  0,
                                  0,
                                  0.28476574002498645,
                                  0,
                                  0,
                                  0.34153003834010265,
                                  0.21718793676315701,
                                  0.06836468630380671,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33643944656950986,
                                  0,
                                  0.44603506015362548,
                                  0,
                                  0.66503612868755302,
                                  0,
                                  -0.57140062555962201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15810473658985036,
                                  0,
                                  -0.34715034322198174,
                                  -0.3070393396226781,
                                  0,
                                  -0.38792783922540985,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18692836200630966,
                                  0,
                                  0.29050352089121234,
                                  0,
                                  -0.099654292113545997,
                                  0,
                                  0,
                                  0,
                                  0.14084078329548588,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23753108658612554,
                                  0,
                                  0,
                                  0,
                                  0.10011380992423502,
                                  0.31247689980223065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049943416267116438,
                                  0,
                                  -0.088493893957754213,
                                  0,
                                  0,
                                  -0.056911890170845615,
                                  0,
                                  0,
                                  -0.03138529915032047,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053026548317423164,
                                  0,
                                  -0.2032875059947768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044891991735440999,
                                  0,
                                  0.3055614931674947,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059533989279675924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1012336148494411,
                                  0,
                                  -0.18446497465644129,
                                  0,
                                  -0.077091356421111909,
                                  0,
                                  -0.2453222410479729,
                                  -0.23030356613305225,
                                  0.079120369602540319,
                                  0.084983083877877036,
                                  0.25618601541109964,
                                  -0.03683087854615745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15872741362013804,
                                  0.14075749273202207,
                                  0.2543846003654287,
                                  0,
                                  0,
                                  -0.12189258812429064,
                                  0,
                                  0,
                                  -0.0059263179280033135,
                                  0,
                                  0.31467796206952109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42788249056758265,
                                  -0.08851683099958968,
                                  0,
                                  -0.0098772894232813935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20392163608721814,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17164336464507549,
                                  0,
                                  0,
                                  0.39973796742982343,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.83339714450195468,
                                  0,
                                  0,
                                  -0.19370889032210914,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030198375199023936,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.091984120792001828,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072489908368603265,
                                  0.14954857553948359,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045528093017789845,
                                  0,
                                  0.079203817648590108,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13968097670543544,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16537639226896317,
                                  0,
                                  0,
                                  -0.081084169242885223,
                                  -0.023114380043823306,
                                  0.023476173407030863,
                                  -0.046845999528184051,
                                  0,
                                  0,
                                  0,
                                  0.063868790018198868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1775861725712235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21717579510798812,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.050397685744295942,
                                  -0.15652348894286675,
                                  0,
                                  0,
                                  0,
                                  -0.15685463674221378,
                                  0,
                                  0,
                                  0,
                                  -0.17598762030587534,
                                  0,
                                  -0.15228528709450445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058133301701146105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.63703586136385604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50208863909845891,
                                  0,
                                  -0.29165956299031781,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.090717432330176651,
                                  0,
                                  0,
                                  0.59606613324370528,
                                  0,
                                  0,
                                  0,
                                  -0.27102376787287957,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34471415618298029,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14515891256093211,
                                  0,
                                  0,
                                  0.20394148520671165,
                                  0,
                                  0,
                                  -0.3851948948238873,
                                  -0.12060588177109871,
                                  -0.65673334764913838,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11621082014984027,
                                  0,
                                  0.044482185142998253,
                                  0,
                                  0.14382691114869214,
                                  0,
                                  0.038277348293767451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2356047244939804,
                                  0,
                                  0.27931094578021509,
                                  0.2791300070356596,
                                  0,
                                  -0.017712689318796881,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49853007147009193,
                                  0,
                                  0.36625346228012773,
                                  0,
                                  -0.67928384643398609,
                                  0,
                                  0,
                                  0,
                                  0.050018433832708813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.042904886087916073,
                                  0,
                                  0,
                                  0,
                                  0.045452434004924859,
                                  -0.08009172270916684,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28652898181547226,
                                  0,
                                  -0.39782186920578316,
                                  0,
                                  0,
                                  -0.13213926604637902,
                                  0,
                                  0,
                                  0.07069420885278975,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37825247037403809,
                                  0,
                                  0.26389049983595342,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18929472248878199,
                                  0,
                                  0.08909573155581231,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22604959108176695,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.041912818853370414,
                                  0,
                                  -0.10131419886877985,
                                  0,
                                  -0.11897090591926426,
                                  0,
                                  -0.023075122148517663,
                                  0.116409003847968,
                                  -0.064063195274549289,
                                  -0.12432444273358992,
                                  -0.23663540979877767,
                                  -0.17948763016392058,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.039086787111029413,
                                  -0.068910442056264704,
                                  0.0043049830339551426,
                                  0,
                                  0,
                                  0.18626114807735938,
                                  0,
                                  0,
                                  0.18451985356914125,
                                  0,
                                  0.42443363948750923,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10643064010768902,
                                  -0.047289548936704041,
                                  0.16778205195718293,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16955214184033313,
                                  0,
                                  0,
                                  0,
                                  0.0088262793420875989,
                                  0.089616057032311708,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17315885791245658,
                                  0,
                                  -0.011873801186092525,
                                  0,
                                  0,
                                  -0.26648289082496601,
                                  0,
                                  0,
                                  -0.13661047352817668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.012619760062086554,
                                  0,
                                  -0.22453798089272717,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18445811249425595,
                                  0,
                                  -0.32790010753679594,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.058217269434292694,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19790432602956251,
                                  0,
                                  -0.19822085113617069,
                                  0,
                                  0.43759186689696655,
                                  0,
                                  0.10973968381030244,
                                  -0.18322524872380841,
                                  -0.08012105214364014,
                                  0.15688911194767405,
                                  -0.11792499723603934,
                                  -0.084986394451328051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.045013206011385962,
                                  0.071653530025733783,
                                  0.24137695488334177,
                                  0,
                                  0,
                                  0.18932134237745765,
                                  0,
                                  0,
                                  0.28503448964515482,
                                  0,
                                  0.056334564489283832,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17119005022656281,
                                  0.19227965713541273,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1072088062961825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48214796404234678,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35159090740368282,
                                  0.068769367405614359,
                                  0,
                                  0.096911967284642658,
                                  0,
                                  0,
                                  -0.054633533421557703,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44257893241955487,
                                  0,
                                  0.20262386001478355,
                                  -0.19279883524702346,
                                  0,
                                  0,
                                  0,
                                  0.032530790600186286,
                                  -0.22150375818320278,
                                  0,
                                  -0.020872703974532308,
                                  0,
                                  0.77260491045835988,
                                  0,
                                  0.19956164920303732,
                                  0,
                                  0.54407422448594811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15688404047400051,
                                  0,
                                  0,
                                  -0.30485023477926471,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24818986229333873,
                                  0,
                                  0,
                                  -0.18369554074238603,
                                  0.35604621519967722,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.016759395458210549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49920090106204629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40342389454273514,
                                  0,
                                  0,
                                  -0.46965468384658088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03416865429978725,
                                  0,
                                  0,
                                  -0.14166673691179976,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.026304277090440739,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1065350840712245,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42191789057006435,
                                  -0.39483910077062284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064358921897080562,
                                  0,
                                  0.10928173027252669,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13225482048022641,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45093314318652439,
                                  0,
                                  0,
                                  -0.15146608536861897,
                                  -0.10412021136852709,
                                  -0.070448165646465333,
                                  0.30201920795934578,
                                  0,
                                  0,
                                  0,
                                  -0.077239470124037951,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057796968139644994,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43349034681601434,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16136230523775877,
                                  -0.083924761043201498,
                                  0,
                                  0,
                                  0,
                                  0.064994139240011545,
                                  0,
                                  0,
                                  0,
                                  0.058038275867451999,
                                  0,
                                  -0.00038885702855162574,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34246474410353017,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12659693879405981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41679154894012838,
                                  0,
                                  -0.29699070510437753,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3910270841067145,
                                  0,
                                  0,
                                  -0.12666669350165236,
                                  0,
                                  0,
                                  0,
                                  -0.44703791829672451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33034216739943595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11837075319176832,
                                  0,
                                  0,
                                  -0.13673522351369466,
                                  0,
                                  0,
                                  0.19709311871294186,
                                  -0.35513931229271622,
                                  -0.40467805533669493,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36948203980195143,
                                  0,
                                  0.056947563711005053,
                                  0,
                                  0.15457882225026104,
                                  0,
                                  0.36673335552508657,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37892400779566421,
                                  0,
                                  -0.10040407049355565,
                                  -0.41358163679213877,
                                  0,
                                  -0.19908216220733196,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29885296904265984,
                                  0,
                                  0.47780188828228509,
                                  0,
                                  0.34395108693457316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17229157656172395,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28725081171376454,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36765169062682818,
                                  0,
                                  0,
                                  -0.44887912563262022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34328054375616662,
                                  0,
                                  0,
                                  0.22333310241746446,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057140967935877487,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3030217518643053,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5367511776465691,
                                  0.015298476548644895,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23593922618231924,
                                  0,
                                  -0.16584596896282225,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11421412152944518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18697252386676216,
                                  0,
                                  0,
                                  0.55804729199746972,
                                  0.16703907459506862,
                                  -0.072212903278252513,
                                  -0.019844145560528839,
                                  0,
                                  0,
                                  0,
                                  0.23616537850564837,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20269756627696786,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017405538388380402,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10926423458537075,
                                  -0.11152125493410765,
                                  0,
                                  0,
                                  0,
                                  -0.049675711461485479,
                                  0,
                                  0,
                                  0,
                                  0.09876786791740115,
                                  0,
                                  -0.29788020194095782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.04808041333247208,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061527959481502338,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22998121805807026,
                                  0,
                                  -0.49235527322000178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32951042718807316,
                                  0,
                                  -0.043057656414301607,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15285568588798279,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10401428812904395,
                                  0,
                                  0,
                                  0.40039762468605239,
                                  0.28031404075501709,
                                  -0.071390034868978589,
                                  -0.031139226113571963,
                                  0,
                                  0,
                                  0,
                                  0.20670536655349661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11385210736595584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.013388179800634715,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077725985952911442,
                                  -0.056907049281144477,
                                  0,
                                  0,
                                  0,
                                  -0.15551564904939255,
                                  0,
                                  0,
                                  0,
                                  -0.075043101515242128,
                                  0,
                                  0.15406405379361415,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30595983827702933,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34842934030946793,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2654955398315732,
                                  0,
                                  0.45411634434321202,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0146791772730108,
                                  0,
                                  -0.22616573534249246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34082723289876871,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21971374187062861,
                                  0,
                                  0,
                                  -0.39927298181298193,
                                  0.10522368851087301,
                                  -0.18026625999854931,
                                  0.22445107836548964,
                                  0,
                                  0,
                                  0,
                                  0.34526698499208891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13348690098033505,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053234709355058689,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10069881496985721,
                                  0.18750763597524456,
                                  0,
                                  0,
                                  0,
                                  -0.48400641864501615,
                                  0,
                                  0,
                                  0,
                                  -0.068502832784051407,
                                  0,
                                  -0.24558512516548905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16512568515751816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.00057323944143401404,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11971866453853947,
                                  0,
                                  0.069307099920497231,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24487150940041413,
                                  0,
                                  -0.13566818142439205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11359745169548252,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075262122569835332,
                                  0,
                                  0,
                                  -0.061455796608428655,
                                  0.20322775056126932,
                                  -0.44221533816379999,
                                  0.31882345638472076,
                                  0,
                                  0,
                                  0,
                                  -0.23255376915611053,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.064644590298650245,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18960665741169436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13091463265293704,
                                  -0.099436355720320863,
                                  0,
                                  0,
                                  0,
                                  0.36300562671120429,
                                  0,
                                  0,
                                  0,
                                  0.14889052570509725,
                                  0,
                                  -0.36095739244008451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07316901965980549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1533256894773628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10637737846828188,
                                  0,
                                  0.33931513396364871,
                                  0,
                                  0,
                                  -0.0047923574055458778,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.036026395782162872,
                                  0,
                                  0,
                                  0,
                                  0.012595475719022302,
                                  0.012706881693509772,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46420871835936395,
                                  0,
                                  0.077666959478434133,
                                  0,
                                  0,
                                  -0.1655344322277176,
                                  0,
                                  0,
                                  -0.20514681615262736,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10800673570970658,
                                  0,
                                  0.22679118675939963,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15252471102112777,
                                  0,
                                  -0.21499577526101327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36878339390272541,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.024557866988976738,
                                  0,
                                  -0.029895403457809402,
                                  0,
                                  -0.20399172655699446,
                                  0,
                                  -0.22645079100023771,
                                  0.011558921654477885,
                                  -0.16807476624254516,
                                  0.037957566407405781,
                                  0.10648483925313726,
                                  0.05717388374215937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12966312259026003,
                                  -0.094451928156479445,
                                  0.18432081531526456,
                                  0,
                                  0,
                                  0.290340536370776,
                                  0,
                                  0,
                                  0.031821017049495394,
                                  0,
                                  -0.20010278404753251,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33862067230535253,
                                  -0.014780640086916839,
                                  0,
                                  -0.080708633573397096,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.01948161803812036,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45180801855810321,
                                  0,
                                  0,
                                  -0.15408602188152826,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20277922593510381,
                                  0,
                                  0,
                                  -0.16570826776623082,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36549072416928902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40612826902687665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.051766259933213307,
                                  0.62884939751239322,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2142746154680556,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19004565773146759,
                                  0,
                                  0,
                                  0,
                                  0.20869881918089556,
                                  -0.14818305984790067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06774478340194201,
                                  0,
                                  0.25481907829581502,
                                  0,
                                  0,
                                  0.054678720654906025,
                                  0,
                                  0,
                                  -0.20835723118009214,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.01466957248256697,
                                  0,
                                  0.14855796167237054,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.039533717419003328,
                                  0,
                                  -0.27205844989198585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11395256601702075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17965717071190068,
                                  0,
                                  0.015620167824248535,
                                  0,
                                  -0.082264870213992938,
                                  0,
                                  0.029283120498866361,
                                  0.16418753233499978,
                                  -0.089952932796910384,
                                  -0.18519426815161444,
                                  -0.25144449480143111,
                                  0.15774390298196658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.368449670828358,
                                  0.32159447204383984,
                                  0.042046850531176613,
                                  0,
                                  0,
                                  -0.19004381801677098,
                                  0,
                                  0,
                                  0.22419905600172355,
                                  0,
                                  -0.017708708014699943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078207000222788189,
                                  -0.30712435339694288,
                                  0,
                                  0,
                                  0.34082943166618707,
                                  0,
                                  0.28885402347609457,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017494613157507853,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26999279968430406,
                                  0,
                                  0,
                                  0.037346372210337708,
                                  0.14501198530284914,
                                  -0.55979241467307705,
                                  -0.051443297961882961,
                                  0,
                                  0,
                                  0,
                                  -0.13922718771179421,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2641005622197502,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053937425712004078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.01437389203596437,
                                  0.0021502277646642358,
                                  0,
                                  0,
                                  0,
                                  0.095708111037479948,
                                  0,
                                  0,
                                  0,
                                  -0.26364108266155184,
                                  0,
                                  0.15915484716268163,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2507751089947442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26140839548934885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17549845681880291,
                                  0,
                                  -0.17460342005307694,
                                  0,
                                  0,
                                  0,
                                  0.45453500894641519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027469796399169782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24245710183272598,
                                  0,
                                  0,
                                  0.16164396443000226,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21224298163660815,
                                  0,
                                  0,
                                  -0.19385802400429125,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5093962281737181,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44240070501984807,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18117208526368236,
                                  0.37023624374012148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17257246183659891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32447050293402652,
                                  0,
                                  0,
                                  0,
                                  -0.012138475945764381,
                                  0.13089554441001419,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28953910807929345,
                                  0,
                                  -0.21983746457783176,
                                  0,
                                  0,
                                  -0.11605667890386173,
                                  0,
                                  0,
                                  -0.33006925707594581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2885652963635475,
                                  0,
                                  0.077697384252990595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23710576197080899,
                                  0,
                                  0.0070820944214383987,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1548076427879799,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12011675384029347,
                                  0,
                                  0.26797507843809526,
                                  0,
                                  -0.1056688887141279,
                                  0,
                                  -0.043782778279864543,
                                  -0.19101246970152549,
                                  -0.15731113886664791,
                                  0.011533570314648033,
                                  0.0045464113931943419,
                                  0.24064946287627487,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2128128722081388,
                                  0.098900051423516933,
                                  0.2468427773194696,
                                  0,
                                  0,
                                  0.15335247602237578,
                                  0,
                                  0,
                                  -0.095199870310826704,
                                  0,
                                  -0.032720392510728696,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16635476177232236,
                                  -0.16610989996868067,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38985286490220433,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.042489855986791121,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26817129756083757,
                                  -0.26024225942476853,
                                  0,
                                  0.05893542510607179,
                                  0,
                                  0,
                                  -0.49532852710965269,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25479050527928654,
                                  0,
                                  0.20753505063146027,
                                  0.0071340473368097686,
                                  0,
                                  0,
                                  0,
                                  0.071938405559582946,
                                  -0.36257227693869076,
                                  0,
                                  -0.42089415026606825,
                                  0,
                                  0.23947955300979323,
                                  0,
                                  -0.40138253465391954,
                                  0,
                                  0.30647124860995584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40255540610170493,
                                  0,
                                  0,
                                  0.44814221679177235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36567079886656367,
                                  0,
                                  0,
                                  -0.37320533944395623,
                                  0.070496024521419676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070764927859199134,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.74752558179405781,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18287074991066435,
                                  0.25717195078415661,
                                  0,
                                  0.44416738537340095,
                                  0,
                                  0,
                                  0.27220131489068372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31714280833163183,
                                  0,
                                  -0.051220580358756054,
                                  0.20462867737875456,
                                  0,
                                  0,
                                  0,
                                  -0.5358453837027265,
                                  0.031037670649474006,
                                  0,
                                  0.094032894731224087,
                                  0,
                                  0.40970568496805398,
                                  0,
                                  -0.19423570135179496,
                                  0,
                                  -0.13775756891856766,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.05635011813092785,
                                  0,
                                  0,
                                  0.089139770761508363,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.089178894151137833,
                                  0,
                                  0,
                                  -0.068833110040796397,
                                  -0.28630582131218663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31468844239593652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21378659034921108,
                                  0,
                                  0,
                                  0,
                                  -0.14244419172433448,
                                  -0.38339924058036484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.022668003622499183,
                                  0,
                                  -0.08047053082605779,
                                  0,
                                  0,
                                  -0.18149227574727364,
                                  0,
                                  0,
                                  0.16570397287698221,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16112883274051726,
                                  0,
                                  0.063846017904427191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27634575931247141,
                                  0,
                                  -0.25648747058166804,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24575768993876104,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0092879663588073154,
                                  0,
                                  -0.17477582092735738,
                                  0,
                                  0.19333847246905198,
                                  0,
                                  0.075134187534056485,
                                  0.14029034299457194,
                                  0.09838008691203648,
                                  -0.15738422084309189,
                                  0.26742913667963092,
                                  0.12905372610500687,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064828730075613183,
                                  0.22423243039580146,
                                  0.026334742454847473,
                                  0,
                                  0,
                                  -0.054208388400990473,
                                  0,
                                  0,
                                  -0.14208770336299159,
                                  0,
                                  0.28129689239563788,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10995959377886647,
                                  -0.050222756419036341,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20114018344754742,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14555177622531734,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36074313345257819,
                                  -0.34338135655808966,
                                  0,
                                  0.46386893453861761,
                                  0,
                                  0,
                                  0.12474209346650952,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021136014190308017,
                                  0,
                                  0.82438279258481084,
                                  0.26484825383777399,
                                  0,
                                  0,
                                  0,
                                  -0.024672884660209948,
                                  -0.17082071782303676,
                                  0,
                                  -0.3834379102805564,
                                  0,
                                  0.03199487499736714,
                                  0,
                                  0.56146590479448266,
                                  0,
                                  -0.0014365712279654635,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030910209979675085,
                                  0,
                                  0,
                                  -0.1020863296040178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2625814148512442,
                                  0,
                                  0,
                                  -0.049814051887509619,
                                  0.20142598956447427,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17108706490548795,
                                  0,
                                  0.12225879728953436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.04378601565867344,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029148137578285892,
                                  0,
                                  0,
                                  -0.16918464872144923,
                                  -0.22059139373356923,
                                  -0.14451104822289568,
                                  -0.3661829280945465,
                                  0,
                                  0,
                                  0,
                                  0.095378214881086054,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53861256305343286,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17884872302999069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30342640504209145,
                                  -0.19053788875362676,
                                  0,
                                  0,
                                  0,
                                  0.18411299896394201,
                                  0,
                                  0,
                                  0,
                                  0.16568194962170363,
                                  0,
                                  -0.038598242916485254,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026416970424269805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20017347241777872,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33493193575160113,
                                  0,
                                  0.21310454293750536,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25104391402462789,
                                  0,
                                  0,
                                  -0.2099716363914241,
                                  0,
                                  0,
                                  0,
                                  0.26443890490994704,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11731734513357951,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61059137441669253,
                                  0,
                                  0,
                                  -0.052172655720092082,
                                  0,
                                  0,
                                  0.35153027225485017,
                                  -0.078953408661018104,
                                  -0.50655422244449155,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45905833581966976,
                                  0,
                                  -0.52583882272116889,
                                  0,
                                  0.21003347007766038,
                                  0,
                                  -0.33852038648418004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045554865468600221,
                                  0,
                                  0.15597653512394988,
                                  -0.2197387932688839,
                                  0,
                                  -0.1649154547362334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.038610493996170128,
                                  0,
                                  -0.23135756624370302,
                                  0,
                                  -0.40634837840763499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28470754109266805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20030404156530404,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60452863268263501,
                                  -0.21346992929845715,
                                  0,
                                  -0.078283081569451157,
                                  0,
                                  0,
                                  0.0030548368136121334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1697051668635704,
                                  0,
                                  0.20792432914664635,
                                  -0.21608542064237973,
                                  0,
                                  0,
                                  0,
                                  -0.17250241868287436,
                                  -0.44855264459100669,
                                  0,
                                  0.89442086855004344,
                                  0,
                                  0.3777986745080853,
                                  0,
                                  -0.062346341800909637,
                                  0,
                                  0.2632378447124869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22361412393561142,
                                  0,
                                  0,
                                  0.34490158441363378,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3323094072242026,
                                  0,
                                  0,
                                  0.3451263778086151,
                                  0.45732779175546134,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.042648691126456209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18347508064408666,
                                  0,
                                  0,
                                  0,
                                  -0.26566550317023696,
                                  -0.22117909907252503,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078422196006288872,
                                  0,
                                  0.11393505861414069,
                                  0,
                                  0,
                                  -0.20894385263831811,
                                  0,
                                  0,
                                  -0.20591461534112238,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22804961749350092,
                                  0,
                                  -0.072057141647131326,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06868012670358889,
                                  0,
                                  0.11341868780060839,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14685732954910308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032386044364351232,
                                  0,
                                  -0.13700351821249357,
                                  0,
                                  -0.41713848946644166,
                                  0,
                                  0.078096507374798035,
                                  -0.016892020978741998,
                                  0.037584358305251683,
                                  -0.34207012737131226,
                                  0.048112173972809043,
                                  -0.23504585154511129,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14443696361013492,
                                  -0.08533960500785906,
                                  0.31271717426245116,
                                  0,
                                  0,
                                  0.081522583644096758,
                                  0,
                                  0,
                                  -0.17950459571148433,
                                  0,
                                  -0.029851709501993479,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23942693180902455,
                                  0.21040098620775693,
                                  0,
                                  0,
                                  0,
                                  0.32073360112429344,
                                  0,
                                  0,
                                  0.3570823275441703,
                                  0,
                                  0,
                                  0,
                                  0.65060844361833736,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.68506917233919129,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26796060996204496,
                                  0,
                                  0,
                                  0.02375074698571783,
                                  0,
                                  0,
                                  0.48616902657306316,
                                  -0.23500494590108939,
                                  -0.20440218345328159,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.025553905823746326,
                                  0,
                                  0.071320151716692329,
                                  0,
                                  0.15999097273739349,
                                  0,
                                  0.17903279705957048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.042165813752453887,
                                  0,
                                  -0.56495620658737278,
                                  0.16139422851061902,
                                  0,
                                  0.41181444999030975,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16647942032888263,
                                  0,
                                  -0.14483191207727553,
                                  0,
                                  0.070494607406400595,
                                  0,
                                  0,
                                  0,
                                  0.19101836519096593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11626138490637805,
                                  0,
                                  0,
                                  0,
                                  0.2607836886399757,
                                  -0.032424721159740238,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080002805778087549,
                                  0,
                                  -0.25409899882470088,
                                  0,
                                  0,
                                  0.011552969408979707,
                                  0,
                                  0,
                                  0.072100179101581161,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014679144050844419,
                                  0,
                                  -0.094095615892097903,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13520725810744627,
                                  0,
                                  -0.073677658430156098,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.07011347006331127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51375089579482269,
                                  0,
                                  0.039894898911440754,
                                  0,
                                  0.039996774584285855,
                                  0,
                                  0.097584198062473662,
                                  0.34580574357916438,
                                  0.098421923504953809,
                                  0.036601116765033359,
                                  0.40252587999417516,
                                  -0.0067142645420934441,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.00056309927804967796,
                                  0.092705132419738281,
                                  0.21290231627291903,
                                  0,
                                  0,
                                  0.29101924815555158,
                                  0,
                                  0,
                                  -0.079575136057904755,
                                  0,
                                  -0.1785830120964666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13764377390234814,
                                  0.04270834837399401,
                                  0,
                                  0,
                                  0.05075913824147002,
                                  0,
                                  -0.30212321431066402,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.05943738068995276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17821589510877081,
                                  0,
                                  0,
                                  0.098399258702169298,
                                  -0.37451674868908669,
                                  0.17152923847805185,
                                  0.2985928028309825,
                                  0,
                                  0,
                                  0,
                                  -0.34281658641479068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10343540786848085,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38987588620021363,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.095908367086389251,
                                  -0.1068691330089907,
                                  0,
                                  0,
                                  0,
                                  0.034876235128457847,
                                  0,
                                  0,
                                  0,
                                  0.048999233726339027,
                                  0,
                                  -0.049505862208823068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52061078265353644,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14288210652923944,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027298024968557801,
                                  0,
                                  -0.056721369835343337,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17324579487227559,
                                  0,
                                  0,
                                  0.24590912987586441,
                                  0,
                                  0,
                                  0,
                                  -0.10689711358427721,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.78188283645660439,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6342294234708763,
                                  0,
                                  0,
                                  0.12729446383495124,
                                  0,
                                  0,
                                  -0.41948559959704296,
                                  -0.068403126826447225,
                                  0.569478674478897,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.042720685197043598,
                                  0,
                                  0.15577751975971602,
                                  0,
                                  0.082723660084700792,
                                  0,
                                  -0.31357838739625482,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039248910643006868,
                                  0,
                                  0.35202482778115424,
                                  -0.49027583342475645,
                                  0,
                                  0.10465422801843706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41970378076037196,
                                  0,
                                  -0.018123236183051936,
                                  0,
                                  -0.13140385790224465,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26650517414244385,
                                  0,
                                  0,
                                  -0.25064566624257079,
                                  0,
                                  0,
                                  0,
                                  -0.19382306115902187,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29902113301864819,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.099034967634897206,
                                  0,
                                  0,
                                  0.73167375437830406,
                                  0,
                                  0,
                                  -0.0052746029217279333,
                                  -0.34628755368910952,
                                  -0.030671663084351423,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19819391435400444,
                                  0,
                                  -0.11227204794454679,
                                  0,
                                  -0.15937304422948506,
                                  0,
                                  -0.52047302307829602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29142804718622894,
                                  0,
                                  -0.059346307202837671,
                                  0.58866092746638565,
                                  0,
                                  -0.12860733576688918,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27245572227476605,
                                  0,
                                  0.4422020212199585,
                                  0,
                                  0.53336836306024182,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20234642628893801,
                                  0,
                                  0,
                                  0.017307628850987137,
                                  0,
                                  0,
                                  0,
                                  -0.39360086967530222,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1155313927932119,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47819143271510606,
                                  0,
                                  0,
                                  -0.20691581810596343,
                                  0,
                                  0,
                                  0.52320421750358315,
                                  -0.25142402458233082,
                                  0.12221235455842425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.02990080127161833,
                                  0,
                                  0.63437806253418116,
                                  0,
                                  -0.2701762371671263,
                                  0,
                                  0.023667851523409132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36161700118175577,
                                  0,
                                  -0.06582041817557005,
                                  0.37670421938940502,
                                  0,
                                  -0.17136060882517584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092792662120178018,
                                  0,
                                  -0.53086277619908828,
                                  0,
                                  0.13931847663891042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0018960307405775645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51109822369724467,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23468021234883155,
                                  0,
                                  0,
                                  -0.31542002250995543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017910260022176612,
                                  0,
                                  0,
                                  0.036430321340106916,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51641033511005852,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33766729080265756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38213460977564767,
                                  0.23629807221135393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.065042475073884276,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11898742584284126,
                                  0,
                                  0,
                                  0,
                                  0.23156745909283133,
                                  -0.075531279964810932,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0017579608399421257,
                                  0,
                                  0.31164930695447718,
                                  0,
                                  0,
                                  0.10396688221717404,
                                  0,
                                  0,
                                  -0.19115429164522985,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23509634143795613,
                                  0,
                                  -0.17361247015815687,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.086750344211291588,
                                  0,
                                  -0.040085015652803813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.052676698477215164,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10873862266832651,
                                  0,
                                  0.08661130651478724,
                                  0,
                                  -0.10511162582830832,
                                  0,
                                  -0.18844948677032736,
                                  0.10780810422323225,
                                  0.45771842322227063,
                                  -0.12178662782518103,
                                  0.16337813124576545,
                                  0.13489619876001649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03834342078678124,
                                  -0.21371387360012481,
                                  -0.052302700725555616,
                                  0,
                                  0,
                                  0.10149280198606725,
                                  0,
                                  0,
                                  0.39234100950322465,
                                  0,
                                  0.17901123740827515,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033705524093806796,
                                  0.29403496405204133,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.060714197806944453,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025221521876692826,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15449214157592803,
                                  0.2532361379785103,
                                  0,
                                  0.1600669931907496,
                                  0,
                                  0,
                                  0.10687155941387665,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072247553649647689,
                                  0,
                                  -0.082777098558147702,
                                  -0.17533421625211371,
                                  0,
                                  0,
                                  0,
                                  0.57394434720166287,
                                  -0.25248779071297611,
                                  0,
                                  -0.29457555189312262,
                                  0,
                                  0.28334126002302912,
                                  0,
                                  -0.41586825845742892,
                                  0,
                                  -0.17387030319809044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39133677432606412,
                                  0,
                                  0,
                                  0.11048285111984052,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59401187112247011,
                                  0,
                                  0,
                                  0.25583969892235869,
                                  -0.15704881945574753,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.025253766013769233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0037365588431406472,
                                  0,
                                  0,
                                  0,
                                  0.18083437650176273,
                                  -0.38642487960566752,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25044435094368883,
                                  0,
                                  -0.080799098817034842,
                                  0,
                                  0,
                                  0.10241092820845964,
                                  0,
                                  0,
                                  -0.1784147923276215,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.071860521647893,
                                  0,
                                  -0.15763638969529065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070538716237841748,
                                  0,
                                  0.015968882449904617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.034272573334358652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030234509515830246,
                                  0,
                                  0.28470594071130489,
                                  0,
                                  -0.040259593808544832,
                                  0,
                                  -0.055570740322845036,
                                  -0.13109667237453887,
                                  -0.042234720064744345,
                                  0.28572533838259817,
                                  0.12150268655167348,
                                  -0.31046524198088638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24484719568127314,
                                  0.085742347373712308,
                                  0.24253264345899148,
                                  0,
                                  0,
                                  -0.34979946982042914,
                                  0,
                                  0,
                                  0.13098286249899466,
                                  0,
                                  0.085384858652969825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2341861615118602,
                                  -0.20765054703827224,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31691093740100157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.003511958806013793,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46468471976890724,
                                  0.060964733537439489,
                                  0,
                                  0.15333778585647287,
                                  0,
                                  0,
                                  -0.059287453212358496,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4798568730098508,
                                  0,
                                  -0.20435290164278519,
                                  -0.4224289799751193,
                                  0,
                                  0,
                                  0,
                                  -0.16659858485084059,
                                  -0.1752252852758463,
                                  0,
                                  -0.358786094045493,
                                  0,
                                  0.29901233529164495,
                                  0,
                                  -0.29759060687206296,
                                  0,
                                  -0.19517939359349376,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53290475293696682,
                                  0,
                                  0,
                                  -0.13786466420538451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12317562945126401,
                                  0,
                                  0,
                                  -0.093203934422218693,
                                  0.22227347112101975,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.012625107257203873,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40934996135327661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075105104138681267,
                                  -0.21811228963447116,
                                  0,
                                  -0.32567700412095019,
                                  0,
                                  0,
                                  0.30873811208494861,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.025623456792697324,
                                  0,
                                  -0.26326516898986529,
                                  0.64819961804261605,
                                  0,
                                  0,
                                  0,
                                  -0.15468334263878616,
                                  -0.12033325745971803,
                                  0,
                                  -0.26121234761874335,
                                  0,
                                  0.4719614013653578,
                                  0,
                                  0.32743436396888476,
                                  0,
                                  -0.041893790715056271,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1112703750608794,
                                  0,
                                  0,
                                  0.55166392630073435,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11608539649021617,
                                  0,
                                  0,
                                  0.34946392907348411,
                                  -0.090235325056825744,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056550465536551631,
                                  0,
                                  -0.34986415427151496,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22956969464653876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46672529643162525,
                                  0,
                                  0,
                                  -0.13932756459654128,
                                  0.43160251415261519,
                                  -0.11106643824887147,
                                  -0.36742364375787451,
                                  0,
                                  0,
                                  0,
                                  -0.11920277822745201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033941069344554278,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28000126819965715,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0576171495034382,
                                  0.12714421617514804,
                                  0,
                                  0,
                                  0,
                                  0.13261791906776499,
                                  0,
                                  0,
                                  0,
                                  0.18037472494548903,
                                  0,
                                  -0.077041268737917737,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18681086658209045,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.010169573931699143,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077900576978339742,
                                  0,
                                  -0.20114188004585068,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.031612352833567593,
                                  0,
                                  0.27959942161069895,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25802076595571155,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2407995523701216,
                                  0,
                                  0,
                                  -0.18608757760075839,
                                  0.0072357780126401199,
                                  -0.18700704174053071,
                                  -0.061117119581681784,
                                  0,
                                  0,
                                  0,
                                  -0.082121859242636056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29041413724329029,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.045504844130408936,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34499023069566709,
                                  -0.22453343354726377,
                                  0,
                                  0,
                                  0,
                                  -0.11493428717410695,
                                  0,
                                  0,
                                  0,
                                  0.38775624286862909,
                                  0,
                                  0.21743813748760518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074570435122737727,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34768270077480939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24011059045863986,
                                  0,
                                  -0.25563250182575969,
                                  0,
                                  0,
                                  -0.11587236857285997,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044619615707348938,
                                  0,
                                  0,
                                  0,
                                  -0.22649032933799629,
                                  0.2620326010481806,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26018446241845095,
                                  0,
                                  -0.10219864353939197,
                                  0,
                                  0,
                                  0.10612059949484637,
                                  0,
                                  0,
                                  -0.23118767248577449,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.099681362281555816,
                                  0,
                                  -0.13420104067271565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067251804854817923,
                                  0,
                                  0.037757786706956828,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18751093141271458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.013090988400563056,
                                  0,
                                  -0.21664821810006776,
                                  0,
                                  -0.13130062662556177,
                                  0,
                                  0.52903481918519246,
                                  0.1652079628993558,
                                  -0.02862756199938446,
                                  0.12215161796188262,
                                  0.24566203203818127,
                                  0.10707047766643661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23040937820667498,
                                  -0.032865015166451156,
                                  -0.12742857629292867,
                                  0,
                                  0,
                                  -0.14479123574001451,
                                  0,
                                  0,
                                  0.24011509125079561,
                                  0,
                                  0.11126668109411608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13579880122354834,
                                  -0.1174612571798458,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22795113453469593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41975071654483742,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058226821350610317,
                                  -0.14495782677889593,
                                  0,
                                  -0.70472641725321916,
                                  0,
                                  0,
                                  0.087596983028918801,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051703574519911227,
                                  0,
                                  0.0062004200935039666,
                                  0.12759973662398447,
                                  0,
                                  0,
                                  0,
                                  -0.10317440968867117,
                                  -0.43468397065019082,
                                  0,
                                  -0.64575011432123874,
                                  0,
                                  -0.38070705821451972,
                                  0,
                                  -0.095006768169261277,
                                  0,
                                  0.5108648884166882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40427150051785898,
                                  0,
                                  0,
                                  -0.001391763520551325,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4186799952837012,
                                  0,
                                  0,
                                  -0.042098447118622248,
                                  0.11303910575867752,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039047202388589351,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26093943202275571,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.52363621278294359,
                                  0.15268668404598823,
                                  0,
                                  -0.26734335997113801,
                                  0,
                                  0,
                                  0.66427627854774218,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056129331358205338,
                                  0,
                                  0.38358876564751226,
                                  0.014440479921899145,
                                  0,
                                  0,
                                  0,
                                  0.18761383286660885,
                                  -0.066560104491834596,
                                  0,
                                  -0.15344144365733819,
                                  0,
                                  0.066917359607286037,
                                  0,
                                  -0.35135361001914295,
                                  0,
                                  0.4223823222106004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12277068168426522,
                                  0,
                                  0,
                                  -0.50253218967894675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50217721497245971,
                                  0,
                                  0,
                                  -0.016174217415819422,
                                  -0.38223416618852735,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3133410051451519,
                                  0,
                                  -0.32322357621541209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.068343037347380162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030476141921236689,
                                  0,
                                  0,
                                  -0.081528938772481602,
                                  -0.41174468360728633,
                                  -0.12983025716033347,
                                  -0.1235542465022315,
                                  0,
                                  0,
                                  0,
                                  0.27667693933399334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061786530423187061,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18261020258806207,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4607789438566684,
                                  0.17809876390414739,
                                  0,
                                  0,
                                  0,
                                  0.36113837927241443,
                                  0,
                                  0,
                                  0,
                                  -0.21549985897145318,
                                  0,
                                  -0.014381566453776506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15144016858767836,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.080748327182620927,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1258328550514583,
                                  0,
                                  -0.057752068262352851,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.015220084385394475,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23575943606159599,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53719084984644683,
                                  0.10075467422000997,
                                  0,
                                  0.30690953071766697,
                                  0,
                                  0,
                                  -0.14909386944753195,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18917068911067267,
                                  0,
                                  -0.64555512477546384,
                                  0.14212031383868715,
                                  0,
                                  0,
                                  0,
                                  0.049825708208479036,
                                  0.31795979838862698,
                                  0,
                                  -0.088236657385694861,
                                  0,
                                  0.078199094635776359,
                                  0,
                                  0.58792085686470841,
                                  0,
                                  0.76004415538704284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10096606889419003,
                                  0,
                                  0,
                                  -0.15952623001662372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13119403193975632,
                                  0,
                                  0,
                                  0.16816861278771233,
                                  -0.17648171231144991,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061079999020343195,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46042134986163524,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30215268002774331,
                                  0,
                                  0,
                                  -0.033629024516206266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063753470971703086,
                                  0,
                                  0,
                                  0.24480246816648249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51313294546554822,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50271645024911327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26008735676104283,
                                  -0.21020662518554692,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0081943180632322206,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18029646971217309,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33483420547196679,
                                  0.053658082510414727,
                                  0,
                                  0.57003413452574658,
                                  0,
                                  0,
                                  0.13439672079403833,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33977565605325438,
                                  0,
                                  -0.19147016985201198,
                                  0.24334294228966236,
                                  0,
                                  0,
                                  0,
                                  -0.2119870517006906,
                                  -0.077122220248867557,
                                  0,
                                  -0.31231519001703606,
                                  0,
                                  -0.31499056813990189,
                                  0,
                                  -0.26664917540607802,
                                  0,
                                  0.10954092788464645,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044208002362618966,
                                  0,
                                  0,
                                  -0.2682272074431496,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.020783147922130797,
                                  0,
                                  0,
                                  0.55042715496068828,
                                  0.3374461541768799,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.00077765367645029476,
                                  0,
                                  0.039847857129280989,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027246551608444674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2762129367619674,
                                  0,
                                  0,
                                  0.25974406028522001,
                                  -0.41843285641598232,
                                  -0.37232906298263918,
                                  0.019004452375577227,
                                  0,
                                  0,
                                  0,
                                  0.22411977228162469,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.040590496346979477,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.01767576526231688,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0080420954720474142,
                                  0.083968121127557194,
                                  0,
                                  0,
                                  0,
                                  -0.24715066501310382,
                                  0,
                                  0,
                                  0,
                                  0.49967226949425125,
                                  0,
                                  0.031783281432417466,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.047013577918063675,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16893551648373148,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35422915091099511,
                                  0,
                                  0.11195380404480201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15080323430920467,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.056478204053751813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14428497041919319,
                                  0.25125588712237257,
                                  0,
                                  0.05213242554946261,
                                  0,
                                  0,
                                  0.38958678173257189,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45213196101215625,
                                  0,
                                  -0.07319054998490003,
                                  0.21638761418051977,
                                  0,
                                  0,
                                  0,
                                  0.30291522240695878,
                                  -0.089073698237442184,
                                  0,
                                  0.47318634801450982,
                                  0,
                                  -0.0039355147636930821,
                                  0,
                                  0.062664233559524413,
                                  0,
                                  0.41294921771476339,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06717068992071222,
                                  0,
                                  0,
                                  0.41050615794781559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025665462630777319,
                                  0,
                                  0,
                                  -0.74524247227771501,
                                  0.14693792013842263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18606286441553024,
                                  0,
                                  0.090089331489792784,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30039636613144149,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021614403403550947,
                                  0,
                                  0,
                                  0.22660235500607948,
                                  -0.14242077518213886,
                                  -0.16158526957224631,
                                  0.080391674470605079,
                                  0,
                                  0,
                                  0,
                                  0.038522709317347144,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38066376465623014,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19575583488833959,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55934320380979685,
                                  0.16889708547213408,
                                  0,
                                  0,
                                  0,
                                  0.23045753269717975,
                                  0,
                                  0,
                                  0,
                                  -0.12856170658071159,
                                  0,
                                  -0.24783288723223446,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15488308097413286,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23643214256038311,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.090610666247403854,
                                  0,
                                  -0.13074784571994252,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33743160460441668,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10960378137410146,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29218825766763956,
                                  0.47578839985281796,
                                  0,
                                  -0.14234506033177427,
                                  0,
                                  0,
                                  -0.60173230815752243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021863992330779194,
                                  0,
                                  0.28534849045554739,
                                  0.39486632159337248,
                                  0,
                                  0,
                                  0,
                                  0.44186191980258399,
                                  0.20978366686897529,
                                  0,
                                  0.46518974464597568,
                                  0,
                                  0.24185577317833956,
                                  0,
                                  -0.30572222164585355,
                                  0,
                                  -0.10871537226637287,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.55688154648534582,
                                  0,
                                  0,
                                  -0.11338371778286951,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.055632490276141221,
                                  0,
                                  0,
                                  0.5099090701163661,
                                  0.26729220267532816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50584256988471277,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32831206165339294,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26528767352308524,
                                  0,
                                  0,
                                  0.3912775645670078,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17310036398601472,
                                  0,
                                  0,
                                  0.48580589711295363,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18584130899942267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21899530571473624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17645936960263517,
                                  -0.18235638609728111,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5245884717880005,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10395909291901999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.4348327411398345,
                                  0,
                                  0,
                                  -0.33578714571804613,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25508838040330162,
                                  0,
                                  0,
                                  0.24563541474755696,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18289125709702292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11187402226266921,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43512092171571409,
                                  0.22685867446597677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30689984797874048,
                                  0,
                                  0,
                                  -0.53542701095383149,
                                  0,
                                  0,
                                  0,
                                  -0.39943101669243836,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24615014288153805,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17646736029991897,
                                  0,
                                  0,
                                  0.16704867307012269,
                                  0,
                                  0,
                                  0.12491574722338947,
                                  0.15906932764878062,
                                  0.46542597698706512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61973228608036079,
                                  0,
                                  0.044343680472779645,
                                  0,
                                  0.48491972809555745,
                                  0,
                                  0.17778886986069187,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10133975483872154,
                                  0,
                                  -0.054727013276839181,
                                  0.26296518529124618,
                                  0,
                                  0.19897460856799451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.75403006766505853,
                                  0,
                                  -0.2353024080536629,
                                  0,
                                  0.053600383522862269,
                                  0,
                                  0,
                                  0,
                                  -0.012250284836732982,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20066636001015112,
                                  0,
                                  0,
                                  0,
                                  0.28304925493428151,
                                  7.8575609169607985e-05,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0081790861429302947,
                                  0,
                                  0.015693643644088796,
                                  0,
                                  0,
                                  0.068921282433817843,
                                  0,
                                  0,
                                  0.16932129348273664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2784039084121594,
                                  0,
                                  0.24343709231843069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31202724283037431,
                                  0,
                                  0.16745763352933624,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15829596910271543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1069616692327055,
                                  0,
                                  -0.035399517901589253,
                                  0,
                                  0.10579774787628451,
                                  0,
                                  0.12531344428967944,
                                  -0.36849161868541358,
                                  0.02103431169080807,
                                  -0.4878107244108828,
                                  0.20220098483814772,
                                  0.15822186218791362,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075173376643471373,
                                  0.13209115719547032,
                                  0.11478676174854262,
                                  0,
                                  0,
                                  -0.074105631353969692,
                                  0,
                                  0,
                                  0.07908635067794223,
                                  0,
                                  0.10758142398866212,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13772286706008879,
                                  -0.01553956218861223,
                                  0,
                                  0,
                                  0,
                                  0.11459513932192587,
                                  0,
                                  0,
                                  -0.22582795293296015,
                                  0,
                                  0,
                                  0,
                                  0.35680563282072553,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22187524079950149,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19662451672143891,
                                  0,
                                  0,
                                  0.63199862975634091,
                                  0,
                                  0,
                                  -0.42936625021523239,
                                  -0.40727619591538572,
                                  -0.0078196312388865725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24662655150034901,
                                  0,
                                  0.10646847364850563,
                                  0,
                                  0.12696919321272401,
                                  0,
                                  0.47786737605951612,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33202910241366068,
                                  0,
                                  0.057271210394189163,
                                  0.027360584597794002,
                                  0,
                                  -0.24668154464027284,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18820121083981503,
                                  0,
                                  -0.43372012657433257,
                                  0,
                                  -0.072215421341726871,
                                  0,
                                  0,
                                  0,
                                  0.12728509058134457,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27459666282300332,
                                  0,
                                  0,
                                  0,
                                  0.015447278574557303,
                                  0.35964111201621002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037337983200552718,
                                  0,
                                  -0.11353220865878991,
                                  0,
                                  0,
                                  -0.1946889710749419,
                                  0,
                                  0,
                                  -0.11609981577632754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20460001915719558,
                                  0,
                                  -0.016405154397557839,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1266534792369329,
                                  0,
                                  -0.2933455329406679,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.131056482618336,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14926951220845974,
                                  0,
                                  0.30880159586440359,
                                  0,
                                  -0.17132310299943893,
                                  0,
                                  0.1557003081863875,
                                  -0.043657424909454581,
                                  0.28899525210905153,
                                  -0.23726147531815905,
                                  0.11736099223761648,
                                  -0.010720796699439223,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34089763399435791,
                                  0.057697356912116082,
                                  -0.14880295514812955,
                                  0,
                                  0,
                                  -0.17494604366006627,
                                  0,
                                  0,
                                  -0.16977169026841013,
                                  0,
                                  -0.09238429775487543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029987268388012432,
                                  -0.11985182015559256,
                                  0,
                                  0,
                                  0,
                                  0.55227483908236152,
                                  0,
                                  0,
                                  0.053572964096237692,
                                  0,
                                  0,
                                  0,
                                  -0.37880595976774756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31563263808857389,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2587261856808396,
                                  0,
                                  0,
                                  -0.0036474796706982802,
                                  0,
                                  0,
                                  -0.092892574289785534,
                                  -0.07650948386902115,
                                  -0.03632218005368823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1989879165961323,
                                  0,
                                  -0.51558339017661414,
                                  0,
                                  0.52456580628718152,
                                  0,
                                  -0.37947287005617303,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18305190073087305,
                                  0,
                                  -0.31152975037048336,
                                  0.32039507479777257,
                                  0,
                                  -0.0490855816400802,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18623300207615412,
                                  0,
                                  -0.16888460677054584,
                                  0,
                                  0.018949229800545336,
                                  0,
                                  0,
                                  0,
                                  -0.097233371090852019,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.032352926570295246,
                                  0,
                                  0,
                                  0,
                                  0.30265275601569236,
                                  0.22632732458611876,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081517949972261222,
                                  0,
                                  0.11793009239966852,
                                  0,
                                  0,
                                  -0.0508989077687938,
                                  0,
                                  0,
                                  -0.050529392255376768,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3520364056876954,
                                  0,
                                  0.085430296864156402,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14738553669493115,
                                  0,
                                  -0.12592022481203813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.035580239059108364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17843610243994504,
                                  0,
                                  0.14894507734461682,
                                  0,
                                  0.20757977849466386,
                                  0,
                                  0.016881766469937873,
                                  0.19444948085827479,
                                  0.15527455282444477,
                                  0.027445638454890744,
                                  -0.029858479045619477,
                                  -0.33806167774209656,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27535198407929484,
                                  -0.11463367072657357,
                                  -0.029445821570998277,
                                  0,
                                  0,
                                  0.20638205203444396,
                                  0,
                                  0,
                                  -0.32741774661998013,
                                  0,
                                  0.30836677907296423,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046488774982826338,
                                  -0.1969358203659328,
                                  0,
                                  0,
                                  0,
                                  -0.15674127568874766,
                                  0,
                                  0,
                                  0.20114354313588312,
                                  0,
                                  0,
                                  0,
                                  -0.52474049168332937,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1373534462509986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11888661889379268,
                                  0,
                                  0,
                                  0.52476323935625591,
                                  0,
                                  0,
                                  0.25962740346198543,
                                  -0.043852158613233778,
                                  -0.015012043573327943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2545829575645932,
                                  0,
                                  -0.68168864442540522,
                                  0,
                                  0.094059203390510701,
                                  0,
                                  0.19446656063047973,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30371849993941524,
                                  0,
                                  0.5379549508889262,
                                  0.29769545628300459,
                                  0,
                                  0.60932751697817611,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0013413247897542842,
                                  0,
                                  -0.34230978462521189,
                                  0,
                                  0.46111225545050627,
                                  0,
                                  0,
                                  0,
                                  0.054634517421696754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38475890816881314,
                                  0,
                                  0,
                                  0,
                                  0.28506270371499087,
                                  -0.12298037905270261,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1306397370716538,
                                  0,
                                  -0.061977832506062078,
                                  0,
                                  0,
                                  0.030215371802721692,
                                  0,
                                  0,
                                  -0.16266812248105367,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14590361871205562,
                                  0,
                                  0.25211306515052856,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26699501666101255,
                                  0,
                                  0.27254466077351897,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2188821362783418,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22302580084108009,
                                  0,
                                  0.012401266706723119,
                                  0,
                                  0.025422082453553589,
                                  0,
                                  0.043368725575756217,
                                  0.20586591706284282,
                                  -0.059013119674114753,
                                  0.24418716956829736,
                                  0.034438337727664359,
                                  0.16375414817132436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13308607824429319,
                                  -0.11300962426747459,
                                  -0.014847049866533606,
                                  0,
                                  0,
                                  -0.19649241564911396,
                                  0,
                                  0,
                                  -0.27603682756416448,
                                  0,
                                  -0.034182400947446963,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10317334958062516,
                                  0.28765923144894945,
                                  0.28552594202285109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19355833168684231,
                                  0,
                                  0,
                                  0,
                                  0.23067381323385097,
                                  -0.055860081959100361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30382445256060869,
                                  0,
                                  -0.16717561164153261,
                                  0,
                                  0,
                                  0.14790991492216915,
                                  0,
                                  0,
                                  0.01954746313495033,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0055443104849742467,
                                  0,
                                  0.00089573775787819311,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33867201023617188,
                                  0,
                                  -0.29638648666093498,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27710846361673563,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26285398473348165,
                                  0,
                                  -0.30925458555297752,
                                  0,
                                  -0.05856165260152589,
                                  0,
                                  0.048526119806114917,
                                  -0.17156466493839995,
                                  -0.018746868734567122,
                                  0.066338093736138679,
                                  0.077065826574196944,
                                  0.19220639940891479,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12518656262700081,
                                  0.03582129310015443,
                                  0.0051101876649055676,
                                  0,
                                  0,
                                  -0.11336756941146656,
                                  0,
                                  0,
                                  -0.23458061989734283,
                                  0,
                                  -0.099271839960563657,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0011639071280388786,
                                  0.24596176254104793,
                                  -0.1164972272415469,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.084183397463186385,
                                  0,
                                  0,
                                  0,
                                  -0.01206874347477252,
                                  0.077554533006719023,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23622004438782218,
                                  0,
                                  0.12347156839098339,
                                  0,
                                  0,
                                  0.15343464792754985,
                                  0,
                                  0,
                                  0.043473896371931664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13853124007927925,
                                  0,
                                  0.44744942816149047,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019176568044929058,
                                  0,
                                  -0.27253681208472169,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.075546253177546902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16973108320258395,
                                  0,
                                  0.072144622027281335,
                                  0,
                                  -0.089991345934228431,
                                  0,
                                  0.32037518195368248,
                                  -0.17015065840014687,
                                  -0.057992396765249685,
                                  0.13763694481472538,
                                  0.13259852832781832,
                                  -0.34439495040404006,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021649623560762804,
                                  -0.19103641695355211,
                                  0.19210529531468373,
                                  0,
                                  0,
                                  -0.16163837537453074,
                                  0,
                                  0,
                                  0.09533931139124828,
                                  0,
                                  0.080729955108608698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25947176539384736,
                                  0.24864116842023065,
                                  0.12664292532800919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12798238985890995,
                                  0,
                                  0,
                                  0,
                                  -0.069706197927280902,
                                  0.080122689885698095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11731177754307764,
                                  0,
                                  0.39966270171105689,
                                  0,
                                  0,
                                  -0.03590526767093271,
                                  0,
                                  0,
                                  -0.13243874013160922,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23664672821613483,
                                  0,
                                  -0.10299858172580129,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069781624966987629,
                                  0,
                                  0.011469784193913471,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.091119107879943401,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059192854269499329,
                                  0,
                                  0.098734898185630651,
                                  0,
                                  0.13183820954414496,
                                  0,
                                  -0.09699599128227572,
                                  0.062533096555801096,
                                  -0.56107432455925155,
                                  -0.13524021852925813,
                                  0.31105618426972304,
                                  -0.095621753119028832,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046343934245572524,
                                  0.15135252673025057,
                                  -0.2134818513825304,
                                  0,
                                  0,
                                  -0.021954346155533162,
                                  0,
                                  0,
                                  -0.18663812991357057,
                                  0,
                                  0.23684087046689456,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11116947290840926,
                                  0.16347437665791775,
                                  -0.21518567461655705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14356056750005763,
                                  0,
                                  0,
                                  0,
                                  -0.15050775068204217,
                                  -0.01975129381953044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068562305250791294,
                                  0,
                                  -0.034017390665116193,
                                  0,
                                  0,
                                  -0.23652434367181829,
                                  0,
                                  0,
                                  -0.19024739336221516,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15457357936429869,
                                  0,
                                  0.28631329586925752,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14493902841952586,
                                  0,
                                  0.046211024393477573,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49099579176045549,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21879136199007057,
                                  0,
                                  -0.098925823660149043,
                                  0,
                                  0.21756818731669525,
                                  0,
                                  -0.2647409688895257,
                                  0.18629022747000998,
                                  0.087114745106260758,
                                  0.10103583600273264,
                                  0.33412059845631198,
                                  0.023128943677084932,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.041814431582373711,
                                  0.037855310580764447,
                                  -0.016989469825996025,
                                  0,
                                  0,
                                  -0.15938276263023488,
                                  0,
                                  0,
                                  0.16387766151616767,
                                  0,
                                  -0.19221350054900821,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.032680907278216986,
                                  -0.091998029500914125,
                                  0.29239785360870868,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019774898164281539,
                                  0,
                                  0,
                                  0,
                                  -0.073799311024148356,
                                  -0.20669562872978775,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26055581033790087,
                                  0,
                                  -0.2958494683539179,
                                  0,
                                  0,
                                  0.24945224273424457,
                                  0,
                                  0,
                                  -0.073004940868334131,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014899411247386252,
                                  0,
                                  -0.1580508164992907,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043954713782925349,
                                  0,
                                  -0.097360703749457267,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14957973350080994,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27276945325628393,
                                  0,
                                  0.019881338534608765,
                                  0,
                                  0.087941159124446472,
                                  0,
                                  -0.068550758987924593,
                                  0.076316502005491532,
                                  -0.17815347210400356,
                                  -0.29692178581405615,
                                  0.21061969011016574,
                                  -0.22643555988739825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11442985466654461,
                                  -0.34445643332277842,
                                  -0.14606717371342789,
                                  0,
                                  0,
                                  -0.0040019084866320248,
                                  0,
                                  0,
                                  0.080016844524886777,
                                  0,
                                  -0.086594042156891537,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25167583288072953,
                                  -0.21226148072235429,
                                  0,
                                  0,
                                  0,
                                  -0.17782078297139459,
                                  0,
                                  0,
                                  -0.35330008860839374,
                                  0,
                                  0,
                                  0,
                                  -0.11090749781780754,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34111445128823242,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59024660275174812,
                                  0,
                                  0,
                                  -0.25577680097034117,
                                  0,
                                  0,
                                  0.029054577336080314,
                                  -0.29527355180460557,
                                  -0.05009176742695659,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18548792106522927,
                                  0,
                                  -0.27334950569645988,
                                  0,
                                  0.25281306385714569,
                                  0,
                                  0.21222048254881354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26072178833903059,
                                  0,
                                  0.20137424603416451,
                                  0.68787634533847963,
                                  0,
                                  0.21013736744481015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38582519043863717,
                                  0,
                                  0.19317225443906999,
                                  0,
                                  -0.6026788504119408,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56063850333299514,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019160058473556577,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23246032084843318,
                                  -0.095106823991533557,
                                  0,
                                  -0.080047918616985195,
                                  0,
                                  0,
                                  -0.17221935102244845,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085322937778439217,
                                  0,
                                  -0.25241288322809474,
                                  0.76165363517329576,
                                  0,
                                  0,
                                  0,
                                  0.18439502575627581,
                                  0.44460260505519711,
                                  0,
                                  0.03935192228313443,
                                  0,
                                  0.40414703391231122,
                                  0,
                                  -0.18670996080242414,
                                  0,
                                  -0.30720134337276961,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32509860710899585,
                                  0,
                                  0,
                                  -0.25514849215143603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067102304609258437,
                                  0,
                                  0,
                                  -0.44898971680460703,
                                  0.54802382646183456,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45336767960434987,
                                  0,
                                  0,
                                  0.13678627772277982,
                                  0,
                                  0,
                                  0,
                                  0.2937591963338661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20447852166228428,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033148114300949411,
                                  0,
                                  0,
                                  0.13778289932457488,
                                  0,
                                  0,
                                  0.34279858249942985,
                                  0.38223013186767635,
                                  0.044649780275102816,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36198557239924195,
                                  0,
                                  -0.21495166126492027,
                                  0,
                                  -0.11736312620068048,
                                  0,
                                  0.34116206017875905,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17195801208331585,
                                  0,
                                  0.45238234529699639,
                                  0.49285829561336869,
                                  0,
                                  -0.79329744247328693,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3605463145046473,
                                  0,
                                  0.013436135101196761,
                                  0,
                                  -0.20021623993246601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53341629339611007,
                                  0,
                                  0,
                                  -0.013725109993086621,
                                  0,
                                  0,
                                  0,
                                  -0.15374654019432066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22930717174517581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24699617172869717,
                                  0,
                                  0,
                                  0.17803007735662993,
                                  0,
                                  0,
                                  0.13389461561421706,
                                  0.14264181100145285,
                                  0.1578377455715082,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.64980479866056184,
                                  0,
                                  -0.30953186719625991,
                                  0,
                                  0.22621263304652856,
                                  0,
                                  0.50071459141592323,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2452539861941771,
                                  0,
                                  -0.3097192234244478,
                                  -0.23005062793786277,
                                  0,
                                  -0.46321719703441766,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0031170452199769209,
                                  0,
                                  -0.041084305228144526,
                                  0,
                                  0.017251345855370193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38090333502943252,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035658973476967365,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25007092899910716,
                                  -0.36025444787956629,
                                  0,
                                  -0.14581684599357639,
                                  0,
                                  0,
                                  0.16108409992241976,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.066748637687138887,
                                  0,
                                  -0.033209857947638526,
                                  0.057753987098207116,
                                  0,
                                  0,
                                  0,
                                  -0.35848414053195532,
                                  1.0217139203922143,
                                  0,
                                  0.27888091496592304,
                                  0,
                                  0.068365216936381659,
                                  0,
                                  -0.34207640444609128,
                                  0,
                                  0.14241269910797233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11359625068587882,
                                  0,
                                  0,
                                  0.23616128422344651,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47655093716607333,
                                  0,
                                  0,
                                  0.085877024857563947,
                                  0.037067525684247815,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080151783515346339,
                                  0,
                                  0,
                                  -0.31016023129615977,
                                  0,
                                  0,
                                  0,
                                  0.4456634803197676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10804717260068374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44065339259051123,
                                  0,
                                  0,
                                  0.27035258520632155,
                                  0,
                                  0,
                                  -0.25203341404358653,
                                  0.6323737159751347,
                                  -0.17368788208745295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12086368413938722,
                                  0,
                                  0.31350637600935582,
                                  0,
                                  0.40625818065982094,
                                  0,
                                  0.097342956179133369,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.6052434691415417,
                                  0,
                                  0.15759550131043454,
                                  0.27759924615187542,
                                  0,
                                  0.19200731023105322,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44659462277017031,
                                  0,
                                  -0.34430541983085178,
                                  0,
                                  0.36474989539759245,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070057890679272372,
                                  0,
                                  -0.15291361227719222,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41658217330412189,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19416804594363593,
                                  0,
                                  0,
                                  -0.20841075093532968,
                                  -0.076521701785585289,
                                  -0.25346725226436317,
                                  0.11538918925086009,
                                  0,
                                  0,
                                  0,
                                  0.060645379175166381,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19010733225260648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47055866992234652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.028998585841517002,
                                  -0.38115086554836325,
                                  0,
                                  0,
                                  0,
                                  -0.24115107592059956,
                                  0,
                                  0,
                                  0,
                                  -0.25125391946377024,
                                  0,
                                  -0.054468706019679347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28047185621570464,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.092382328562049601,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10000156443004711,
                                  0,
                                  -0.069332186398249257,
                                  0,
                                  0,
                                  0.22279705949908676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0058379618874139748,
                                  0,
                                  0,
                                  0,
                                  -0.067578893833322634,
                                  -0.18852482305200186,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092937403108885319,
                                  0,
                                  -0.15217521036143136,
                                  0,
                                  0,
                                  -0.1260612985784263,
                                  0,
                                  0,
                                  -0.38655457001926302,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11631148357312891,
                                  0,
                                  0.1720252705693297,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20771526844136617,
                                  0,
                                  0.26493680128298858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.023466352910549024,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14786332836846583,
                                  0,
                                  0.21485239612868798,
                                  0,
                                  0.22543226835408864,
                                  0,
                                  0.22331655915807969,
                                  -0.18352263625557308,
                                  0.16858907304563595,
                                  -0.023843291807301693,
                                  -0.023532940232914735,
                                  -0.09365474622837254,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0092891803266731895,
                                  0.23939618788492614,
                                  -0.3364366469820006,
                                  0,
                                  0,
                                  0.17428262158578633,
                                  0,
                                  0,
                                  0.073156866563785158,
                                  0,
                                  -0.013524551224131995,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23872867608081416,
                                  0.227817720349141,
                                  0.17205416413393712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23383275519049007,
                                  0,
                                  0,
                                  0,
                                  -0.20224085736960035,
                                  -0.14496882560366825,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17633358236690269,
                                  0,
                                  0.0083138025240774398,
                                  0,
                                  0,
                                  -0.40111675836175809,
                                  0,
                                  0,
                                  0.24852647603605646,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0287117580211281,
                                  0,
                                  -0.14464445279005264,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25367012252865323,
                                  0,
                                  -0.097519476244341638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097992573431082919,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085542319411932632,
                                  0,
                                  0.31881558245290131,
                                  0,
                                  0.082956070374203647,
                                  0,
                                  -0.0055501811236579046,
                                  -0.092164334535463632,
                                  0.15376405704242699,
                                  0.061405820907963676,
                                  -0.018092277491367742,
                                  0.096207199397949944,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43218351785218029,
                                  -0.18071450063590083,
                                  0.058043486840040986,
                                  0,
                                  0,
                                  -0.29160496890612947,
                                  0,
                                  0,
                                  -0.098637920583125746,
                                  0,
                                  0.033131773744963733,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.083119724204058693,
                                  0.088477862816057684,
                                  0.2385975410134803,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.062262411629406364,
                                  0,
                                  0,
                                  0,
                                  -0.2259485228334952,
                                  0.029587552689834658,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06697996312437704,
                                  0,
                                  0.1978245308744519,
                                  0,
                                  0,
                                  0.16855755399420655,
                                  0,
                                  0,
                                  0.031023756089529474,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3223997559278774,
                                  0,
                                  0.23035749114687415,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.05533094856216686,
                                  0,
                                  0.038913042635661789,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25664230410571248,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.023774398864233784,
                                  0,
                                  -0.26623632090627736,
                                  0,
                                  0.080712562725112541,
                                  0,
                                  -0.15357904195857427,
                                  -0.13790920219408556,
                                  0.35093355893057188,
                                  0.08545208479957439,
                                  0.087121120820650599,
                                  -0.31870842121974813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14734964675252668,
                                  0.20297482323900162,
                                  -0.028424304957869413,
                                  0,
                                  0,
                                  0.038934339196928132,
                                  0,
                                  0,
                                  -0.10248611516882464,
                                  0,
                                  -0.20631255191773107,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25945376618543325,
                                  -0.20252572322713056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.012801993557665273,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.57830163121726619,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.52044802386462607,
                                  -0.5285581401554279,
                                  0,
                                  0.033014294959630826,
                                  0,
                                  0,
                                  0.059396689037276386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.63495690410739603,
                                  0,
                                  0.24290224756546147,
                                  -0.12992375037518747,
                                  0,
                                  0,
                                  0,
                                  0.037884783201165111,
                                  0.047766102789152429,
                                  0,
                                  0.0018487275991934393,
                                  0,
                                  0.64178745383238067,
                                  0,
                                  0.42366544272689999,
                                  0,
                                  0.12712861467482262,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07812566125950321,
                                  0,
                                  0,
                                  -0.42178154083738173,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027493496663182355,
                                  0,
                                  0,
                                  0.40461035601720508,
                                  -0.33905226731060695,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11886229309424091,
                                  0,
                                  0.11595007394117986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32721071308143324,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079823993752316746,
                                  0,
                                  0,
                                  -0.015939802822634123,
                                  0.035059819286901009,
                                  -0.10000338320220849,
                                  0.21616795998544322,
                                  0,
                                  0,
                                  0,
                                  -0.15175296908719885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18188983737082831,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21721029748845602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086718910272730612,
                                  0.72848077772188613,
                                  0,
                                  0,
                                  0,
                                  -0.091228748816031255,
                                  0,
                                  0,
                                  0,
                                  0.050346554119813036,
                                  0,
                                  0.15885376523637756,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14277527999086406,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25812539579128535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15438777105367019,
                                  0,
                                  -0.11107392601040746,
                                  0,
                                  0,
                                  -0.059830632427562973,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30427616120292905,
                                  0,
                                  0,
                                  0,
                                  0.31499246395726921,
                                  -0.0060417529711971228,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.091551580823128573,
                                  0,
                                  0.037885396003817538,
                                  0,
                                  0,
                                  -0.3872284890131697,
                                  0,
                                  0,
                                  -0.25444034084909156,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11653770912425865,
                                  0,
                                  -0.090279548018768599,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039719870982596939,
                                  0,
                                  0.06876692370820317,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14935556103153996,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22439024795278381,
                                  0,
                                  -0.42292827714595355,
                                  0,
                                  0.034828550885729975,
                                  0,
                                  0.062489069879518515,
                                  0.041138011729729591,
                                  0.015897659175643317,
                                  -0.11480491908186199,
                                  -0.17828600935502956,
                                  -0.15840003506734032,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18616172735807412,
                                  -0.21098345875274621,
                                  -0.10787176657695718,
                                  0,
                                  0,
                                  -0.30509773719617844,
                                  0,
                                  0,
                                  -0.11569389769184005,
                                  0,
                                  -0.10493216302670343,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068395349978019757,
                                  -0.10211681770901647,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072350487929534885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18204570920560198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29389817741783952,
                                  -0.30974296432476989,
                                  0,
                                  0.21890581627185296,
                                  0,
                                  0,
                                  -0.34923768891387874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.084970163555928055,
                                  0,
                                  -0.25052729245309646,
                                  0.45464409785244214,
                                  0,
                                  0,
                                  0,
                                  -0.23016759216375193,
                                  -0.35933611660351816,
                                  0,
                                  0.6945164548937055,
                                  0,
                                  0.25254620829144536,
                                  0,
                                  -0.070164485607109098,
                                  0,
                                  0.004345764218813452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12702652905246645,
                                  0,
                                  0,
                                  -0.30871244365743356,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36390038242786038,
                                  0,
                                  0,
                                  -0.072073356461205912,
                                  -0.49080951695020592,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.72594224404772201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085116073549724947,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.027663359977352951,
                                  0.14302311654846939,
                                  0,
                                  -0.29630962064353916,
                                  0,
                                  0,
                                  0.33333462040407763,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19250825268728672,
                                  0,
                                  -0.50009560548050969,
                                  0.094049525230718689,
                                  0,
                                  0,
                                  0,
                                  -0.01965452960410586,
                                  -0.0096774734982541522,
                                  0,
                                  0.20492769109018771,
                                  0,
                                  0.041001769831871732,
                                  0,
                                  0.17136971979137799,
                                  0,
                                  -0.36367368416727397,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42294217953446894,
                                  0,
                                  0,
                                  -0.3453805398741423,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019019618544386059,
                                  0,
                                  0,
                                  -0.13132046550801113,
                                  0.54378630113798621,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06218602761854615,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1401259299876883,
                                  0,
                                  0,
                                  0,
                                  -0.0065751179597553777,
                                  0.1872975807687535,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12466811692003787,
                                  0,
                                  0.026420561949793222,
                                  0,
                                  0,
                                  -0.015366220809858583,
                                  0,
                                  0,
                                  0.16209939712252308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.110029938329337,
                                  0,
                                  -0.037583506545652776,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19488571435758634,
                                  0,
                                  0.22858332054687661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11194209670837446,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28667923682805885,
                                  0,
                                  0.1221086368462302,
                                  0,
                                  0.12526278810764674,
                                  0,
                                  0.13616715717878608,
                                  0.43537852199257532,
                                  -0.030488094476330579,
                                  -0.2015565530699541,
                                  -0.13256667857547352,
                                  -0.18061184722160198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.043516819049985833,
                                  0.26529472290251505,
                                  0.37109462739117743,
                                  0,
                                  0,
                                  -0.16654024458824171,
                                  0,
                                  0,
                                  0.13426185383974534,
                                  0,
                                  -0.21930944925678536,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17922944106174907,
                                  0.18368795068897723,
                                  0,
                                  0,
                                  0,
                                  0.19814092962795696,
                                  0,
                                  0,
                                  -0.38583201420884378,
                                  0,
                                  0,
                                  0,
                                  -0.68034969895587571,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12708538220124899,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38977578336605778,
                                  0,
                                  0,
                                  0.35675679721189746,
                                  0,
                                  0,
                                  -0.057744876996175046,
                                  0.57237500537211738,
                                  -0.46331052206064205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17002023698153174,
                                  0,
                                  0.087751286379837951,
                                  0,
                                  -0.41175008271299934,
                                  0,
                                  -0.15209912855436913,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13751881984166461,
                                  0,
                                  -0.49675552436939485,
                                  -0.30755557387582644,
                                  0,
                                  -0.030299489309473616,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24592225209233792,
                                  0,
                                  -0.24106393277702959,
                                  0,
                                  -0.26527303207012748,
                                  0,
                                  0,
                                  0,
                                  -0.29953340715853283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16260399093365679,
                                  0,
                                  0,
                                  0,
                                  0.16188601573624462,
                                  -0.16291857477188454,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22385307717586544,
                                  0,
                                  0.19354889970039726,
                                  0,
                                  0,
                                  0.041972480134731517,
                                  0,
                                  0,
                                  0.003755483019998191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31926953784340956,
                                  0,
                                  -0.19838879890807593,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10018868701291953,
                                  0,
                                  0.16728480092891079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26942073675423667,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067749753464387913,
                                  0,
                                  0.021323715185275979,
                                  0,
                                  0.20185225685611821,
                                  0,
                                  0.33079848526696737,
                                  -0.21696357841788694,
                                  -0.016011742556824759,
                                  -0.071128822440243114,
                                  0.045731663666515043,
                                  -0.018887314621316979,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16286506844026619,
                                  -0.13667274441011742,
                                  0.1024896013295272,
                                  0,
                                  0,
                                  0.23551302282516567,
                                  0,
                                  0,
                                  -0.090700584534081335,
                                  0,
                                  -0.29549776953758738,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16644060500526392,
                                  -0.21299209083642542,
                                  0,
                                  0,
                                  0,
                                  -0.19014841868400162,
                                  0,
                                  0,
                                  0.24480518742778976,
                                  0,
                                  0,
                                  0,
                                  -0.023381182868118258,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31493885874703587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38098188321765658,
                                  0,
                                  0,
                                  0.11697913842841295,
                                  0,
                                  0,
                                  -0.16679167938081255,
                                  0.0054643100080174756,
                                  0.22968231093002295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29307943514540558,
                                  0,
                                  -0.051858497925011834,
                                  0,
                                  -0.5026791610897996,
                                  0,
                                  0.15417019825537162,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19124862295132941,
                                  0,
                                  -0.68455174892609505,
                                  0.36760030253345605,
                                  0,
                                  0.42020710997598515,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040204534729895436,
                                  0,
                                  0.58228303330016884,
                                  0,
                                  -0.38085970977610661,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46486275534419741,
                                  0,
                                  0.35159737778088024,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.083956265359306947,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037074268930665302,
                                  0,
                                  0,
                                  -0.041523778389131391,
                                  0.004075778787988588,
                                  0.21560739735091616,
                                  -0.069866421004091295,
                                  0,
                                  0,
                                  0,
                                  -0.14847928128877855,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098870961403553809,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072544967371161256,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20608861219041735,
                                  0.06686308628406748,
                                  0,
                                  0,
                                  0,
                                  -0.11752294681889472,
                                  0,
                                  0,
                                  0,
                                  0.18641391371260513,
                                  0,
                                  -0.66082478671753975,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063947378093594409,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10985191925695673,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072225760383659771,
                                  0,
                                  0.089989213573642451,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12499082941230462,
                                  0,
                                  0,
                                  -0.19561693124298424,
                                  0,
                                  0,
                                  0,
                                  -0.0035850722981176242,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.03820360163595006,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3431207465170687,
                                  0,
                                  0,
                                  -0.045979725271675563,
                                  0,
                                  0,
                                  0.15857762130399039,
                                  0.54226711774545888,
                                  -0.010675514156080711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.055276207280928871,
                                  0,
                                  0.18889433494060909,
                                  0,
                                  0.59196752083659532,
                                  0,
                                  0.28645503586636728,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.85417219933987665,
                                  0,
                                  0.37149774525341217,
                                  -0.19785740454665143,
                                  0,
                                  -0.088406996417922934,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34602988353841407,
                                  0,
                                  0.40356519254178619,
                                  0,
                                  -0.052347847903261399,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1414980703688383,
                                  0,
                                  -0.37165465725878249,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36245492030245507,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32196240442061591,
                                  0,
                                  0,
                                  -0.062300339768117469,
                                  -0.1253072718494522,
                                  -0.098886998416152824,
                                  -0.42555714952241136,
                                  0,
                                  0,
                                  0,
                                  -0.32162828333144478,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21219658870241398,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29126972408661445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25910326696169683,
                                  0.12762673813266395,
                                  0,
                                  0,
                                  0,
                                  -0.22165124883956111,
                                  0,
                                  0,
                                  0,
                                  0.15734090383933777,
                                  0,
                                  -0.032123743950566198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.016057003144048232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0065796269957224818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053224118994602256,
                                  0,
                                  -0.039653511630175997,
                                  0,
                                  0,
                                  0.035916974150970532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32124948614763582,
                                  0,
                                  0,
                                  0,
                                  0.15000720375466126,
                                  0.16662827719491652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10221658918920416,
                                  0,
                                  -0.040125521323683758,
                                  0,
                                  0,
                                  -0.26020997104709864,
                                  0,
                                  0,
                                  0.24012122519980081,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014137424464706463,
                                  0,
                                  0.16744193914484934,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42822168202568245,
                                  0,
                                  0.069804488987814134,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073107046515992272,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14162116406638456,
                                  0,
                                  0.063384572432081288,
                                  0,
                                  0.07397554267180502,
                                  0,
                                  -0.1090593511633222,
                                  -0.10621290003113948,
                                  -0.19209084615020744,
                                  -0.096547392012170441,
                                  0.17944917865532159,
                                  -0.048436716480209308,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16800917729683529,
                                  -0.25425806121584643,
                                  -0.1274503387723501,
                                  0,
                                  0,
                                  -0.071716650757486039,
                                  0,
                                  0,
                                  0.32041362037850646,
                                  0,
                                  -0.22680107060054613,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2899887837329404,
                                  -0.0063080460208801703,
                                  -0.3191100738280101,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11592870824471728,
                                  0,
                                  0,
                                  0,
                                  -0.10525089724386721,
                                  0.16157354979389987,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20605262856114079,
                                  0,
                                  -0.26190522082110379,
                                  0,
                                  0,
                                  0.32885812374237605,
                                  0,
                                  0,
                                  -0.26224364488825896,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0062221992792225074,
                                  0,
                                  -0.058867871067894748,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083394023738471601,
                                  0,
                                  -0.14299393785292655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019488200814288502,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28727180693729865,
                                  0,
                                  0.012571832547992906,
                                  0,
                                  0.29798102774282287,
                                  0,
                                  -0.27799852508266037,
                                  -0.046737948622130029,
                                  0.035337311812716474,
                                  -0.29346019578925553,
                                  -0.15958628737214711,
                                  -0.064436524457390384,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14462407982695424,
                                  -0.036938010729919452,
                                  0.093821218334259132,
                                  0,
                                  0,
                                  -0.20212421628243127,
                                  0,
                                  0,
                                  -0.10441042286487977,
                                  0,
                                  -0.073401519716510863,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074024025952339589,
                                  0.25816931816733352};

const double rot_21_30[900] = {-0.1930942865392288,
                               0,
                               0,
                               0.32138622241018133,
                               0,
                               0,
                               -0.12313840715284227,
                               0.12881034458282659,
                               0,
                               0,
                               0.64477194230347756,
                               0,
                               0,
                               -0.045645888969365445,
                               -0.014429207197242264,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63761347760238385,
                               0,
                               0.055648600710027925,
                               0,
                               0.15593028938398612,
                               0,
                               0,
                               0.42644145296967806,
                               0.11544517382616626,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.68471506239343083,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.0004240053213931394,
                               0,
                               0,
                               0,
                               -0.55827497475082122,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.3136169781683107,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.48484791863897242,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.025598765804594831,
                               0.52936282442113525,
                               -0.087859784895598286,
                               0,
                               0,
                               0,
                               0,
                               -0.1150974365812566,
                               0,
                               0,
                               0,
                               0,
                               0.0049174229050552437,
                               0,
                               0,
                               0.056300483432170048,
                               0,
                               0,
                               0.22416490932019126,
                               0.1879115595663885,
                               0,
                               0,
                               0.097764934902974221,
                               0,
                               0,
                               -0.15644022714011346,
                               0.91406736503988628,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12502555833287538,
                               0,
                               0.16144147080733046,
                               0,
                               -0.080838318882087506,
                               0,
                               0,
                               0.30410634870210829,
                               -0.67208364605070536,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24081091546048317,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.58399063369329851,
                               0,
                               0,
                               0,
                               -0.22417205522580955,
                               0,
                               0,
                               0,
                               0,
                               -0.41937615596255068,
                               0,
                               0,
                               -0.086481213231319326,
                               0.12193448317761643,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.44548835594646519,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32686261533863831,
                               0,
                               0,
                               0,
                               -0.70461164962724199,
                               0,
                               0,
                               0,
                               -0.097762468041890357,
                               0,
                               0,
                               -0.23083884047645675,
                               0,
                               0,
                               0.40568122805814466,
                               0.51509687124191506,
                               0,
                               0,
                               -0.3449048771083148,
                               0,
                               0,
                               -0.36451217443216294,
                               -0.21851004243189159,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.35369079711719897,
                               0,
                               0.28737008514547613,
                               0.53092536033948556,
                               0,
                               0,
                               0.46572813851890549,
                               0,
                               0,
                               -0.41618946471206486,
                               0.072857963270338277,
                               0,
                               0,
                               -0.15381462772495422,
                               0,
                               0,
                               -0.40176584364586543,
                               -0.069985534537644972,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.074977144482838431,
                               0,
                               0.35650992879430893,
                               0,
                               0,
                               -0.064762220265324716,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49027256232012073,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.5663773687194098,
                               -0.88263475619114429,
                               -0.54708214197822469,
                               0,
                               0,
                               0,
                               0,
                               -0.29003475711996057,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25711186990139206,
                               0,
                               0,
                               -0.3409884326426918,
                               0,
                               0,
                               1.059159066151901,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.59751951701939954,
                               0,
                               0.31819206927127774,
                               -0.43287276800456331,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.43138806700088128,
                               0,
                               0,
                               -0.50999271371903321,
                               0,
                               0,
                               -0.23698827376204129,
                               0.26591697778570345,
                               0,
                               0,
                               0.19029625982250997,
                               0,
                               0,
                               0.49590841625934429,
                               0.046523152240149232,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10056206535963608,
                               0,
                               0.36403506716290612,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.93781367860287945,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32551879904547343,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12059442646046092,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.18711707602985672,
                               0,
                               0,
                               0.85608787262594244,
                               0,
                               0,
                               0.30156070871414187,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.48242668129704241,
                               0,
                               -1.038611378723832,
                               0.076361402487585411,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33705975492006945,
                               0,
                               0,
                               0.18651657791656978,
                               0,
                               0,
                               0.028948755884558221,
                               -0.43338142294988036,
                               0,
                               0,
                               -0.30059125169990475,
                               0,
                               0,
                               0.32113976778298742,
                               0.065628251744820815,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16780102434326546,
                               0,
                               0.66105574447411841,
                               -0.28497087044087555,
                               0,
                               0,
                               0.43747801564629774,
                               0,
                               0,
                               -0.077331404530550471,
                               0.63766730110580694,
                               0,
                               0,
                               -0.090608502244398564,
                               0,
                               0,
                               0.43410003842991257,
                               -0.097557584154053467,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32954212576670239,
                               0,
                               -0.0060511879395121759,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.9970638533150139,
                               0,
                               0,
                               0.32574974676789725,
                               0,
                               0,
                               -0.58549393899301361,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.73279728525372634,
                               0,
                               -0.26804006300093736,
                               -1.2122801657422304,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.77281342623455807,
                               0,
                               0,
                               -0.34143249399696002,
                               -0.10390436281751894,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.48191939060235245,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.1856880545633938,
                               0,
                               0,
                               0,
                               0.093063370968513165,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25757676421008052,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.88541203650466205,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.38691050147512246,
                               0,
                               0,
                               0,
                               0.08421266414269768,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33665413029115571,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.3025282622726078,
                               -0.34757494468816508,
                               -0.77452387712148119,
                               0,
                               0,
                               0,
                               0,
                               0.39073414412801583,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33090405000834416,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1381475583916352,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.3981292946473195,
                               -0.96036189657172677,
                               0.12615568049184456,
                               0,
                               0,
                               0,
                               0,
                               -1.0481461403725851,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14214332039549535,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42960910598907737,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63765247548960713,
                               0.6967613798186223,
                               -0.94392674080940153,
                               0,
                               0,
                               0,
                               0,
                               -1.0004807078776947,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.92737895385844249,
                               0,
                               0,
                               -0.14610197766834551,
                               0,
                               0,
                               -0.97639323424683855,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29566749802996256,
                               0,
                               0.15311170787723888,
                               -0.30071831968700818,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15223830494418253,
                               0,
                               0,
                               -0.20051295183011286,
                               -0.71345529511770112,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.19305123489329126,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.62438148321043685,
                               0,
                               0,
                               0,
                               -0.021876486343103331,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39911140586783167,
                               0,
                               0,
                               -0.96897505958840169,
                               0,
                               0,
                               0.48026039155021483,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.54185820604229551,
                               0,
                               -0.74327041517116799,
                               -0.059858221118161747,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24327483245503392,
                               0,
                               0,
                               0.66543099834702824,
                               0,
                               0,
                               0.13568089436451997,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.8168002700949073,
                               0,
                               -6.1529450476549563e-05,
                               -0.96718944533911455,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.12091346491206345,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0459516030486016,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51107725693549066,
                               0.75647752864582696,
                               -0.88275409419208239,
                               0,
                               0,
                               0,
                               0,
                               0.33511943074537065,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41576129882703589,
                               0,
                               0,
                               0.74927059452350786,
                               -0.017128678280695794,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.072114025753617819,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.35746790133992251,
                               0,
                               0,
                               0,
                               0.36394916370509761,
                               0,
                               0,
                               0,
                               -0.10079563489851298,
                               0,
                               0,
                               -0.073522563999789362,
                               0,
                               0,
                               0.29010240593202508,
                               -0.059801176011272245,
                               0,
                               0,
                               0.5442519794731725,
                               0,
                               0,
                               -0.2053875564357375,
                               -0.29618337390815264,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.53464035538157695,
                               0,
                               0.42981382005137664,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.23272239850173193,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33178763852901361,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.91419759798138933,
                               0,
                               0.52931850269631153,
                               0,
                               0,
                               0.36287504578612151,
                               0,
                               0,
                               0.67056325007791673,
                               -0.093471958094550167,
                               0,
                               0,
                               0.033240954047057507,
                               0,
                               0,
                               0.31539687736366534,
                               -0.088963431439887192,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.11996114273266328,
                               0,
                               -0.082862689842723963};

const double rot_21_2[4] = {-0.95637076633526918, 0.29215570728515605, -0.29215570728515605, -0.9563707663352693};

const double rot_22_50[2500] = {0.47396437262086621,
                                0,
                                0,
                                0,
                                0.067695334135727384,
                                -0.45784871975452507,
                                0,
                                0,
                                -0.11135417298061526,
                                0,
                                0,
                                -0.30834472603263752,
                                0.18212888546827138,
                                -0.27061709709862874,
                                0.15929059212982274,
                                0.0085153374622587985,
                                -0.39437272480281443,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31418598305457895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10380980279743204,
                                0,
                                0,
                                -0.18001567979292224,
                                0,
                                0.13223441325256707,
                                0,
                                0,
                                0,
                                -0.083139383322388183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70469892300109782,
                                -0.81822729810569639,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47271210812508496,
                                0,
                                0,
                                0.014535997065691482,
                                0,
                                0,
                                0,
                                -0.37006525752601033,
                                0,
                                0,
                                -0.54979261443108185,
                                0,
                                0,
                                0,
                                0,
                                0.53073567008960698,
                                0,
                                0,
                                0,
                                -0.3321764053893041,
                                0,
                                0.16900830379700615,
                                0,
                                0,
                                0,
                                -0.47538792194684937,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45872545989859531,
                                0.70228992589942785,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2830198083960701,
                                0,
                                0,
                                -0.43696807115989988,
                                0,
                                0,
                                0,
                                -0.71923149781952989,
                                0,
                                0,
                                0.3922680103000466,
                                0,
                                0,
                                0,
                                0,
                                0.2450178159960047,
                                0,
                                0,
                                0,
                                -0.73819498790458793,
                                0,
                                -0.55993572496179267,
                                0,
                                0,
                                0,
                                0.48636977418557303,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56955443555106511,
                                0,
                                0,
                                -0.21879824929592998,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60997056316623521,
                                0,
                                0,
                                0,
                                -0.23523592155692699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44758802969815104,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45063196657271565,
                                0,
                                0,
                                0,
                                -0.18637086228552255,
                                0.16591480205494941,
                                0,
                                0,
                                0.050873188657285462,
                                0,
                                0,
                                0.17624827323663686,
                                -0.10714375155473317,
                                0.13027161782783969,
                                0.263687981744961,
                                0.15863157007224357,
                                0.28533357371033347,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.04659514566175614,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27139068607590522,
                                0,
                                0,
                                -0.33521723536075054,
                                0,
                                -0.035168963407280721,
                                0,
                                0,
                                0,
                                -0.55409833045805135,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12291323276515934,
                                0,
                                0,
                                0,
                                -0.044971817258717628,
                                0.21052792875870921,
                                0,
                                0,
                                -0.15753427013440785,
                                0,
                                0,
                                0.34100438130423782,
                                0.2535970429865444,
                                -0.30657632067607921,
                                0.18322237410954612,
                                -0.16653199159320195,
                                0.10771083597505471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12681869496495018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56644052329942174,
                                0,
                                0,
                                -0.38898709791283814,
                                0,
                                -0.27905415781884846,
                                0,
                                0,
                                0,
                                0.011014952483319771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29056408655464222,
                                0,
                                0,
                                -0.063009601397420623,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72044734227873486,
                                0,
                                0,
                                0,
                                -0.55583085557135847,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2891539187607951,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0324921054946673,
                                0,
                                0,
                                -0.21273497883473172,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12212196478607418,
                                0,
                                0,
                                0,
                                -0.64945512475747069,
                                0,
                                0,
                                -0.15209645300850527,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.034202850827188484,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.014755006019887662,
                                0,
                                0,
                                -0.018798454262131448,
                                0,
                                0,
                                0.68437847929733331,
                                0,
                                0,
                                -0.73402578886117942,
                                0.20874100512450725,
                                0,
                                0,
                                0,
                                0.15138777007953599,
                                0.40590861277059331,
                                0,
                                0,
                                -0.15733884295453807,
                                0,
                                0,
                                -0.13902426936149065,
                                -0.15736240509995325,
                                0.54665885112834045,
                                0.21900910238290125,
                                0.13132645304366716,
                                -0.44086320262142781,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11362616258047437,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2919189062052131,
                                0,
                                0,
                                -0.077483589607140163,
                                0,
                                -0.083694925547140989,
                                0,
                                0,
                                0,
                                0.17423249247560796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10428099210901484,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.068676171539696462,
                                0,
                                -0.29029745952462666,
                                0,
                                0,
                                0,
                                0,
                                0.078236358850368629,
                                0,
                                0,
                                0,
                                0,
                                -0.28650741177080458,
                                0,
                                -0.39472742902319924,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14950710192178795,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73336519937881639,
                                0,
                                0,
                                0.18285108929476035,
                                0.25001572956648488,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68572789583994154,
                                0,
                                0,
                                -0.27642928855434651,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24651539849610649,
                                0,
                                0,
                                0,
                                0.30848530056292151,
                                0,
                                0,
                                0.35435429645727418,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18701338211636831,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33754701465250203,
                                0,
                                0,
                                -0.58888357668798041,
                                0,
                                0,
                                -0.59432186229970829,
                                0,
                                0,
                                -0.24092678282480148,
                                0.14911937781042472,
                                0,
                                0,
                                0,
                                -0.014854618633775582,
                                -0.12869953747043991,
                                0,
                                0,
                                -0.37111644685748052,
                                0,
                                0,
                                0.35897103181415513,
                                0.46828589534029547,
                                0.30587869522432753,
                                -0.17933434074944271,
                                0.045205040609639355,
                                -0.087233169194913418,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18644227135315394,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1978577777300381,
                                0,
                                0,
                                0.33456289470709444,
                                0,
                                -0.38690203253331706,
                                0,
                                0,
                                0,
                                -0.064732097291779492,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.05115547996971867,
                                0,
                                0,
                                0,
                                -0.068026735541846753,
                                0.45003617735174134,
                                0,
                                0,
                                0.10890719524339615,
                                0,
                                0,
                                -0.42705412917789087,
                                0.48432563082681668,
                                0.040698139703863725,
                                0.13437233684620092,
                                0.067245869819654858,
                                0.33557479193532397,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37295207521525131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0097404958545524445,
                                0,
                                0,
                                0.19509946946871681,
                                0,
                                0.19890258102509034,
                                0,
                                0,
                                0,
                                0.088072227338587453,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3488715301173847,
                                0,
                                0,
                                0,
                                0.17800427749345654,
                                0.0046050182175314197,
                                0,
                                0,
                                0.0017478676625383117,
                                0,
                                0,
                                -0.2194823557428455,
                                -0.17866298064754479,
                                -0.2313121283039393,
                                0.33489276641849774,
                                0.46729070282273527,
                                -0.082789246855721421,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18719754507245737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11613777287068787,
                                0,
                                0,
                                0.15387775614309171,
                                0,
                                -0.51300179849531502,
                                0,
                                0,
                                0,
                                -0.20058082658651438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26987949822642404,
                                0,
                                0,
                                0,
                                0.012994078498089888,
                                -0.30624101613963889,
                                0,
                                0,
                                -0.36998410623751199,
                                0,
                                0,
                                -0.073232999438258534,
                                0.21715380259836167,
                                0.1861190371954882,
                                0.5860950879895569,
                                -0.060568858582975171,
                                0.19288885019155219,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30114854378322542,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20641905779076702,
                                0,
                                0,
                                -0.15649313149877614,
                                0,
                                0.16360150706973894,
                                0,
                                0,
                                0,
                                0.20056992756314435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.01950218940785127,
                                0,
                                0,
                                0,
                                -0.76017207155543487,
                                -0.0001693644326379827,
                                0,
                                0,
                                0.0078562164185712879,
                                0,
                                0,
                                -0.18825724260229937,
                                0.19103939921827429,
                                -0.14577199339338012,
                                -0.074217959188406943,
                                0.28659237489133937,
                                -0.18394349315269637,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41580114350203223,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.098329714228802767,
                                0,
                                0,
                                0.051183498391830999,
                                0,
                                -0.13613772121316267,
                                0,
                                0,
                                0,
                                0.057608724539709333,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33579775641803811,
                                0,
                                0,
                                0,
                                -0.055253532937065392,
                                -0.030985272030080654,
                                0,
                                0,
                                -0.46536787973002369,
                                0,
                                0,
                                -0.14950185381953629,
                                -0.051733041147508652,
                                0.17616224837046376,
                                -0.41386241292527026,
                                0.33213192671629993,
                                0.056890566375566068,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19326473130002458,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14161983784429144,
                                0,
                                0,
                                -0.29569351099589136,
                                0,
                                0.30052220673254559,
                                0,
                                0,
                                0,
                                -0.30102056338973482,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53377470058774112,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21358289162167837,
                                0,
                                -0.34385193913544027,
                                0,
                                0,
                                0,
                                0,
                                -0.26009178618486967,
                                0,
                                0,
                                0,
                                0,
                                -0.29174730455076014,
                                0,
                                0.52573512246944709,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2547635681323559,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.054554290439494932,
                                0,
                                0,
                                0.19764256029446262,
                                -0.12299547767180195,
                                0,
                                0,
                                0,
                                0,
                                0.6020394015353806,
                                0,
                                0,
                                0.39884904587938308,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15148693620368786,
                                0,
                                0,
                                0,
                                -0.22532251451657784,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63619923782693499,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.062117452128099174,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12468505741777472,
                                0,
                                0.14700152963823707,
                                0,
                                0,
                                0,
                                0,
                                0.29498631882993626,
                                0,
                                0,
                                0,
                                0,
                                0.15155195849585548,
                                0,
                                -0.24282871579904866,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52779616089261572,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.062960437859447174,
                                0,
                                0,
                                0.11012408903345131,
                                -0.70382865817654205,
                                0,
                                0,
                                0.69548524797594857,
                                0.028298814654607936,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13880000578130372,
                                0,
                                0,
                                0.18992525145051781,
                                0,
                                0,
                                0,
                                0.69070857422103094,
                                0,
                                0,
                                0.45406543519618175,
                                0,
                                0,
                                0,
                                0,
                                -0.57301369427597437,
                                0,
                                0,
                                0,
                                -0.36977667904098233,
                                0,
                                0.18657363112614228,
                                0,
                                0,
                                0,
                                -0.76599956669674796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31022309688377803,
                                0,
                                0,
                                -0.57371897374660974,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36664886841245747,
                                0,
                                0,
                                0,
                                -0.13389089693773126,
                                0,
                                0,
                                -0.2891147814799353,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70095255568393411,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6819877392657071,
                                0,
                                0,
                                -0.36583621321769011,
                                0,
                                0,
                                -0.50178417421906707,
                                0,
                                0,
                                0.40469720103029172,
                                0,
                                0,
                                0,
                                0.41220253424538772,
                                0,
                                0,
                                -0.88512497372383314,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.05563363881345583,
                                0,
                                0,
                                0,
                                0.060815162305929982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19962280911293889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10009950352990707,
                                -0.14715427114437502,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.70074552475102314,
                                0,
                                0,
                                0.62224156273741449,
                                0,
                                0,
                                0,
                                0.17384341260266739,
                                0,
                                0,
                                -0.36998102989465326,
                                0,
                                0,
                                0,
                                0,
                                -0.81353343109517973,
                                0,
                                0,
                                0,
                                -0.55702758742059832,
                                0,
                                -0.47770960933257767,
                                0,
                                0,
                                0,
                                0.65938517195654633,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26486190240570184,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60349743591943528,
                                0,
                                -0.3277110615440077,
                                0,
                                0,
                                0,
                                0,
                                -0.13967538243481528,
                                0,
                                0,
                                0,
                                0,
                                0.47382039009466059,
                                0,
                                -0.21017290673737471,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23404335395296508,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2699914167347342,
                                0,
                                0,
                                0.15176182416520015,
                                0.13911701716994973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.035962610889547962,
                                0,
                                0,
                                -0.5021114882086839,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.083749594182764,
                                0,
                                0,
                                0,
                                0.31327373983670154,
                                0,
                                0,
                                -0.33830097792238667,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49672910637021289,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59546953262181868,
                                0,
                                0,
                                0.14310800483978997,
                                0,
                                0,
                                0.010587533175034388,
                                0,
                                0,
                                -0.32449255547677802,
                                -0.041567436477872109,
                                0,
                                0,
                                0,
                                -0.06966436902215152,
                                -0.44829954936874955,
                                0,
                                0,
                                0.49520000534502739,
                                0,
                                0,
                                -0.060706964688997445,
                                0.056423221711953062,
                                0.47135873725049832,
                                -0.043936634642672188,
                                0.17039245622330801,
                                0.25036971976857153,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1705198994594127,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26267155640198137,
                                0,
                                0,
                                -0.22112767157655105,
                                0,
                                -0.23826979457059685,
                                0,
                                0,
                                0,
                                0.14416372494000518,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18795252737663393,
                                0.70629770214385323,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46874320578520234,
                                0,
                                0,
                                -0.35658458055107056,
                                0,
                                0,
                                0,
                                -0.4337664050682436,
                                0,
                                0,
                                -0.34183430465683184,
                                0,
                                0,
                                0,
                                0,
                                -0.20391231376158644,
                                0,
                                0,
                                0,
                                0.25067071587803696,
                                0,
                                0.3163719438865028,
                                0,
                                0,
                                0,
                                -0.50706272966676402,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.95619721211265041,
                                0,
                                0,
                                -0.22263028660085013,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21560332991393238,
                                0,
                                0,
                                0,
                                -0.27474149948905419,
                                0,
                                0,
                                0.51166325829502435,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10424883314464649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27057563383416045,
                                0,
                                0,
                                0.39225369681656858,
                                0,
                                0,
                                -0.62190374328002385,
                                0,
                                0,
                                -0.36698199296928996,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20168303677082144,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42236524917384499,
                                0,
                                -0.088344770741752537,
                                0,
                                0,
                                0,
                                0,
                                -0.72396844418294359,
                                0,
                                0,
                                0,
                                0,
                                0.076901751260750745,
                                0,
                                -0.39579386566347668,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23045751006273424,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.090318676107602733,
                                0,
                                0,
                                -0.15602780376038303,
                                0.028582793615883867,
                                0,
                                0,
                                -0.57117952059385291,
                                -0.032653431391727161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.010924877973824465,
                                0,
                                0,
                                -0.72828597579943755,
                                0,
                                0,
                                0,
                                0.68856897611571644,
                                0,
                                0,
                                -0.6844551500948004,
                                0,
                                0,
                                0,
                                0,
                                -0.1147733927984749,
                                0,
                                0,
                                0,
                                -0.87304245887433152,
                                0,
                                0.29246049643285499,
                                0,
                                0,
                                0,
                                -0.035307724132743287,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20897696418192188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12633411160285263,
                                0,
                                0.13869815455589179,
                                0,
                                0,
                                0,
                                0,
                                0.24522757089584277,
                                0,
                                0,
                                0,
                                0,
                                0.099526389897664075,
                                0,
                                0.27583994166681342,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.67677448334945634,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.032053407539651857,
                                0,
                                0,
                                -0.13690408016194458,
                                0.54516745680984324,
                                0,
                                0,
                                0,
                                0,
                                0.2425239912037051,
                                0,
                                0,
                                -0.075035563090202151,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28783353777169046,
                                0,
                                0,
                                0,
                                -0.76239583005792055,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52101461669178617,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34013427705383276,
                                0,
                                0,
                                0,
                                -0.035246507188195789,
                                -0.15856857989202403,
                                0,
                                0,
                                -0.35429253398754718,
                                0,
                                0,
                                -0.048161407332778433,
                                -0.36991225885855916,
                                -0.074581552731255329,
                                0.052414105842154599,
                                0.11803353035711135,
                                0.48807241270044327,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.026164915056021754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38464578626663726,
                                0,
                                0,
                                0.41011551490984632,
                                0,
                                -0.022362914248981219,
                                0,
                                0,
                                0,
                                0.12432418398209899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.074804094991969092,
                                0,
                                0,
                                -0.22881788919209678,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24317715284486136,
                                0,
                                0,
                                0,
                                -0.30884155905760491,
                                0,
                                0,
                                -1.3715552182647006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.021722844140148561,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48486140667613831,
                                0,
                                0,
                                -0.21623967793461543,
                                0,
                                0,
                                -0.55477698741441406,
                                0,
                                0,
                                -0.096224182227369254,
                                0,
                                -0.16733909039790332,
                                -0.36886987917702324,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15546208479272161,
                                0,
                                0,
                                -0.73561474882951772,
                                0,
                                0,
                                0,
                                -0.17394123036920389,
                                0,
                                0,
                                0.81745340898737573,
                                0,
                                0,
                                0,
                                0,
                                -0.66311233865195263,
                                0,
                                0,
                                0,
                                -0.27921979222025434,
                                0,
                                -0.031374806025008695,
                                0,
                                0,
                                0,
                                -0.13092389749733255,
                                0,
                                0,
                                0,
                                0,
                                -0.069208343885567111,
                                0,
                                0,
                                0,
                                0.22825843532084325,
                                -0.083760270002907422,
                                0,
                                0,
                                0.24644218709979537,
                                0,
                                0,
                                0.30740459198490383,
                                0.26873513443148872,
                                0.00091400657018474857,
                                0.17075278081096143,
                                0.33522852838004658,
                                -0.10369309224894177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2412193847354728,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34322293249657687,
                                0,
                                0,
                                0.3279581976228369,
                                0,
                                0.39888357566289484,
                                0,
                                0,
                                0,
                                -0.33719633940578031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43670817313080657,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.069184009713621569,
                                0,
                                0.011709949042624831,
                                0,
                                0,
                                0,
                                0,
                                -0.020812651442856964,
                                0,
                                0,
                                0,
                                0,
                                -0.34081289466393083,
                                0,
                                -0.064502072626360957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.070139410796443077,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32043839849992001,
                                0,
                                0,
                                0.75817865082670344,
                                0.034353131767912298,
                                0,
                                -0.22147163512229356,
                                0,
                                0,
                                0,
                                -0.29977216617006075,
                                -0.082080794175511812,
                                0,
                                0,
                                0.0073018496434483562,
                                0,
                                0,
                                -0.18272129016720368,
                                -0.12573288712820696,
                                0.23021890017241703,
                                0.18698784912682886,
                                -0.56937078111168193,
                                -0.11285234514305245,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13157051162026628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2009707424668194,
                                0,
                                0,
                                0.2809885605918182,
                                0,
                                -0.035038916611570499,
                                0,
                                0,
                                0,
                                -0.49227460734549344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0076297973153515884,
                                -0.1810995797532137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18778956934063565,
                                0,
                                0,
                                -0.65661105664743735,
                                0,
                                0,
                                0,
                                0.58013649570165426,
                                0,
                                0,
                                -0.46729097164697048,
                                0,
                                0,
                                0,
                                0,
                                0.19041940339872218,
                                0,
                                0,
                                0,
                                0.3399978733898445,
                                0,
                                -1.0628662647060789,
                                0,
                                0,
                                0,
                                -0.31423550721981819,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41921081310886843,
                                0,
                                0,
                                -0.40691094035424658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47142924940952763,
                                0,
                                0,
                                0,
                                0.54004483107555945,
                                0,
                                0,
                                0.0068620171182267459,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38122241229818138,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2912239350182067,
                                0,
                                0,
                                -0.62210207820382646,
                                0,
                                0,
                                0.44976529099567442,
                                0,
                                0,
                                -0.31144514184287203,
                                0,
                                -1.0417842826709027,
                                0.44758454757434496,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.097208636891268907,
                                0,
                                0,
                                0.20620236042305046,
                                0,
                                0,
                                0,
                                -0.0047506640199200551,
                                0,
                                0,
                                0.015064915514369679,
                                0,
                                0,
                                0,
                                0,
                                -0.03469944845368423,
                                0,
                                0,
                                0,
                                -0.34943443269310837,
                                0,
                                -0.2248135108777867,
                                0,
                                0,
                                0,
                                -0.68231088072454571,
                                0,
                                0,
                                0,
                                0,
                                0.099041644192545658,
                                0,
                                0,
                                0,
                                0.41238891845470244,
                                -0.0056994452542933095,
                                0,
                                0,
                                -0.02824577328269896,
                                0,
                                0,
                                -0.42637569054828045,
                                0.25713287918409183,
                                -0.024111917219707991,
                                -0.26850204071049605,
                                -0.17092606615805034,
                                0.17706877845468982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50500867288100082,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.096409852289010931,
                                0,
                                0,
                                -0.078017673447849489,
                                0,
                                -0.30125391132505391,
                                0,
                                0,
                                0,
                                -0.27743319852378512,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15632527346359903,
                                0,
                                0,
                                0.83452887975201828,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10178535765447649,
                                0,
                                0,
                                0,
                                0.044810201863338103,
                                0,
                                0,
                                -0.073854592437077815,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.041850720707937911,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21618776945941287,
                                0,
                                0,
                                -0.52267538154900417,
                                0,
                                0,
                                -0.052375276084386135,
                                0,
                                0,
                                -0.23264366484764884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.083259018557979639,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3033559173116947,
                                0,
                                -0.0097573805949897618,
                                0,
                                0,
                                0,
                                0,
                                0.074493143845953638,
                                0,
                                0,
                                0,
                                0,
                                -0.66721358265041641,
                                0,
                                -0.26047682346940942,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18211536455924862,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36010883357158413,
                                0,
                                0,
                                -0.46685750178433938,
                                -0.03970192526245761,
                                0,
                                0,
                                -0.23737736992360151,
                                -0.21484118487656734,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80286903488752759,
                                0,
                                0,
                                0.17237492932668722,
                                0,
                                0,
                                0,
                                -0.42822639689709546,
                                0,
                                0,
                                -0.88272806889357136,
                                0,
                                0,
                                0,
                                0,
                                -0.67980889603476535,
                                0,
                                0,
                                0,
                                0.094828175160021982,
                                0,
                                0.071948950338511425,
                                0,
                                0,
                                0,
                                -0.360332244695099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53121883883563648,
                                0,
                                0,
                                0.090083616639930766,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32370080977720672,
                                0,
                                0,
                                0,
                                -0.99922601310561265,
                                0,
                                0,
                                -0.021874707072776157,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.84955111825786456,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65250943474050382,
                                0,
                                0,
                                0.56051412012041646,
                                0,
                                0,
                                -0.12855687646097991,
                                0,
                                0,
                                -0.27781888527249354,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34619771096620627,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22229541517696932,
                                0,
                                0.79789344489877878,
                                0,
                                0,
                                0,
                                0,
                                -0.34508904933107803,
                                0,
                                0,
                                0,
                                0,
                                -0.078963145376626909,
                                0,
                                -0.01876042398628102,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.084994552344684518,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14601079989425028,
                                0,
                                0,
                                0.16928373748658065,
                                0.10594408291649453,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47786323554323967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.47888538328458696,
                                0,
                                -0.067682966707621778,
                                0,
                                0,
                                0,
                                0,
                                -0.33221902045087881,
                                0,
                                0,
                                0,
                                0,
                                -0.044060198492076819,
                                0,
                                0.39944123206571158,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15150607150853956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34565409698838689,
                                0,
                                0,
                                -0.16675956108766896,
                                -0.30924239944183068,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.018652383358053817,
                                0,
                                0,
                                0.30509537877419413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6300917103814061,
                                0,
                                0,
                                0,
                                0.57464727794096093,
                                0,
                                0,
                                -0.37054445709265332,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61001206759605597,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12740292006605045,
                                0,
                                0,
                                0.39743594064293553,
                                0,
                                0,
                                -0.11995751651196768,
                                0,
                                0,
                                -0.48927536482431472};

const double rot_22_20[400] = {0.8696110659125621,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.49373737355239278,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.091239463443454183,
                               0.014915640022975475,
                               0,
                               0,
                               -0.10404615716454335,
                               0,
                               0,
                               0.76909820919865202,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.55780200722616247,
                               -0.27923493068460725,
                               0,
                               0,
                               0,
                               0,
                               -0.75845675829041703,
                               0.21755392158862025,
                               0,
                               0,
                               -0.54602770722639093,
                               0,
                               0,
                               -0.2287445685848527,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.001498631229198244,
                               -0.16413730957178507,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.55590758332663937,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.60705419549723938,
                               0,
                               0.55287057681356577,
                               0,
                               0,
                               0,
                               0.12956113546496154,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24830371774882443,
                               0,
                               0,
                               0.71692763470437515,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.72326425084679602,
                               0,
                               0,
                               0,
                               1.4392384656583994,
                               0,
                               0,
                               0,
                               0.082544512323764613,
                               0.082172185951884608,
                               0,
                               0,
                               -0.38083396594274532,
                               0,
                               0,
                               0.54697411858541167,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.70090712034872282,
                               0.22571696428849225,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1436993639885749,
                               0,
                               0,
                               0.064823393355159187,
                               0,
                               0.64329037632058939,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.32832338944313028,
                               0,
                               0,
                               0,
                               0,
                               -0.15783818734044014,
                               0,
                               0,
                               0.90141230348021395,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.68884767014048465,
                               0,
                               0,
                               0,
                               0.37277466952923627,
                               0,
                               0,
                               0,
                               -0.1259369573449792,
                               -0.74701654940093032,
                               0,
                               0,
                               0.04403272188006685,
                               0,
                               0,
                               0.01428103200418615,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30110696667282733,
                               -0.57731960285931205,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.42135313817584358,
                               0,
                               0,
                               -0.2369101039114026,
                               0,
                               0.22621735716389782,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.85253855891218877,
                               -0.49373737355239516,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.86961106591256399,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.26146061148056265,
                               0,
                               0,
                               -0.26446548624617428,
                               0,
                               -1.7090522613692674,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.40084813432973165,
                               0,
                               0,
                               0,
                               -0.37102895572746364,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.63479399939926295,
                               0,
                               -0.44395372727743987,
                               0,
                               0,
                               0,
                               0.51213199507055274,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41702225208467242,
                               0,
                               0,
                               -0.95392652999411265,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.2994448648769832,
                               0,
                               0,
                               0,
                               1.0677131044336661,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.72430199176037313,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.23773050152204572,
                               0,
                               0.54795925669253476,
                               0,
                               0,
                               0,
                               -0.34440018348281609,
                               0,
                               0,
                               -0.62491167750255838,
                               -0.15956223680653819,
                               0,
                               0,
                               0.57692937689838653,
                               0,
                               0,
                               0.22858943616081798,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.08648086462190159,
                               0.43754509677038,
                               0,
                               0,
                               0,
                               0,
                               -0.056836499672311358,
                               0.60183196512517423,
                               0,
                               0,
                               0.45957289299976628,
                               0,
                               0,
                               0.067276313429340123,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.31534035288668855,
                               -0.56515043446064062,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.3194065877876551,
                               0,
                               0,
                               -0.18843032582367136,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.29698260957676853,
                               0,
                               0,
                               0,
                               0.1653450141150066,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.16938387628012164,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41473604943622211,
                               0,
                               0.44382413897316181,
                               0,
                               0,
                               0,
                               0.77609486882667089,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.14002933961196878,
                               0,
                               0,
                               1.1162875880237086,
                               0,
                               0.0031913636730888234,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.26381995069219755};

const double rot_22_10[100] = {0.95213807638875758,
                               0,
                               0,
                               0,
                               -0.30566825725075925,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.24297477919901889,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.4991329886096274,
                               -0.83176289671685266,
                               0,
                               0,
                               0,
                               1,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.2455855136313554,
                               0,
                               0.15120587573993605,
                               0,
                               0,
                               0,
                               0,
                               0.30566825725075936,
                               0,
                               0,
                               0,
                               0.95213807638875758,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.1259317304217875,
                               0,
                               1.4689898739619791,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.014663067582229905,
                               0,
                               0,
                               1.7654792950264548,
                               0,
                               0.16185198181436128,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.8245783778601099,
                               0.54210186750125944,
                               0,
                               0,
                               0.95643462539577251,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.2663395547927711,
                               0.11956608589745188,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.1263275184716273,
                               0,
                               0,
                               0.78374369178674519};

const double rot_22_100[10000] = {-0.11362420056051162,
                                  0,
                                  0,
                                  0.050592691502717148,
                                  0,
                                  0,
                                  -0.46123912845511428,
                                  0,
                                  0,
                                  0,
                                  -0.25741673634225132,
                                  0,
                                  0,
                                  0,
                                  -0.44586778195944332,
                                  0,
                                  0,
                                  -0.28238984384423288,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.028422706073289755,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35029376205614088,
                                  -0.24510421830278009,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.010089046113940795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.037635133147228175,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31198011435796091,
                                  0,
                                  0.068911610517998989,
                                  0,
                                  -0.35986856426054198,
                                  0,
                                  0,
                                  0.69156015931176074,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30060078746260011,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3242535131410586,
                                  0,
                                  0.13849317758465063,
                                  0.25342075559635818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081332059674027513,
                                  0,
                                  0.038528936660985016,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.045072901609196511,
                                  0,
                                  -0.022146847219607121,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.094681539711623658,
                                  0,
                                  0,
                                  -0.080106805561435498,
                                  -0.40385554544035418,
                                  0,
                                  0.079778006781486305,
                                  0,
                                  0,
                                  -0.050482395681230009,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.004786688991795361,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14386103013624713,
                                  0,
                                  0,
                                  0,
                                  -0.076875745099126369,
                                  0.037656406580992771,
                                  0.059419430715940386,
                                  0,
                                  0,
                                  0,
                                  -0.30788574166467869,
                                  -0.046946547601386342,
                                  0,
                                  0,
                                  -0.26648330905483614,
                                  0.22397730952791278,
                                  0,
                                  0.20224969665517872,
                                  0,
                                  0,
                                  0.06973857277271904,
                                  0,
                                  -0.26159455276320503,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.083041091469984687,
                                  0,
                                  0,
                                  0,
                                  -0.063216007068986044,
                                  0,
                                  -0.29653810377520351,
                                  -0.073225351521292267,
                                  0.40753129236048546,
                                  -0.16715480811937744,
                                  -0.027422625888758229,
                                  0.26465135192864803,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14231147359043184,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23534831957696076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20045862359056438,
                                  0,
                                  0,
                                  0.45859674041977966,
                                  0,
                                  -0.1230093604907028,
                                  -0.079566275807524914,
                                  -0.45966062398911861,
                                  0,
                                  0,
                                  -0.17138709056324367,
                                  0,
                                  0,
                                  0,
                                  0.32847899425731303,
                                  0,
                                  0.016366826080161212,
                                  0,
                                  0,
                                  -0.3429346291005505,
                                  -0.12414179781481527,
                                  0,
                                  0,
                                  -0.0081918395042716551,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.057641510196694487,
                                  0,
                                  0.078319910440623947,
                                  0,
                                  -0.14405586722769043,
                                  0,
                                  0,
                                  0,
                                  0.31217683288818882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.041208261109525829,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14518918010107168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2625811592752299,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10486089607518694,
                                  0.12548850407376849,
                                  0,
                                  -0.09631530762006299,
                                  0,
                                  0,
                                  0.31194724157539644,
                                  0,
                                  0,
                                  -0.35686131994470177,
                                  0,
                                  0,
                                  0,
                                  0.45877938090481807,
                                  0,
                                  0,
                                  0,
                                  0.16137446331191937,
                                  0,
                                  0,
                                  0.10415399724814792,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47103301955866411,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1917582482586887,
                                  -0.10701992687283045,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22567081965945737,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.60614488839354563,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024977287254375785,
                                  0,
                                  -0.39316343330213249,
                                  0,
                                  -0.29676145815583144,
                                  0,
                                  0,
                                  -0.024553072935352794,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049229720661628132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29698010985065049,
                                  0,
                                  -0.18397160806914983,
                                  0.037564630813320565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43566212856330283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26151778261012948,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21104769641344218,
                                  0.55389429433187487,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077535971003766094,
                                  0,
                                  0.22506574458939299,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20517525020304545,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088072094536742501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049607510862653414,
                                  -0.12870426703806503,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67433133036884618,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.044872479429614115,
                                  0,
                                  0,
                                  -0.20542411974173236,
                                  0,
                                  0.22524502395213358,
                                  -0.1257898853922319,
                                  -0.077503424355050615,
                                  0,
                                  0,
                                  -0.18546267567521002,
                                  0,
                                  0,
                                  0,
                                  0.13271114369475406,
                                  0,
                                  -0.03439730545759933,
                                  0,
                                  0,
                                  0.45481247931621127,
                                  -0.58541621836632229,
                                  0,
                                  0,
                                  -0.12204981188276334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30950617011403025,
                                  0,
                                  -0.0055881560544172489,
                                  0,
                                  -0.096605694428624919,
                                  0,
                                  0,
                                  0,
                                  0.22675450553167975,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.004789897806718374,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14138359240208093,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0079267899367617169,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.097550003404787186,
                                  -0.28178184551566121,
                                  0,
                                  -0.028003225626827527,
                                  0,
                                  0,
                                  0.17550935205772036,
                                  0,
                                  0,
                                  -0.273505452108667,
                                  0,
                                  0,
                                  0,
                                  0.20775751573920659,
                                  0,
                                  0,
                                  0,
                                  -0.4620929509303851,
                                  0,
                                  0,
                                  0.020318448646722082,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.088307020887465421,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18927662231103878,
                                  -0.094744640056538085,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33124309870372559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.43599278831725685,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23930326301943167,
                                  0,
                                  -0.13716793272328626,
                                  0,
                                  -0.29614375776827856,
                                  0,
                                  0,
                                  -0.58682546198685492,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.82592557798660127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061063004829100542,
                                  0,
                                  0.22623586180861185,
                                  -0.3420949303193232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.07015454013545229,
                                  0,
                                  0,
                                  0.26710700882678334,
                                  0,
                                  0,
                                  0.17051087074804352,
                                  0,
                                  0.059504679596172581,
                                  -0.11333083401092228,
                                  0.042060971485092066,
                                  0,
                                  0,
                                  -0.01075027029422067,
                                  0,
                                  0,
                                  0,
                                  0.41584436903391464,
                                  0,
                                  0.57179372943849527,
                                  0,
                                  0,
                                  0.096442154573285449,
                                  0.15952001334120719,
                                  0,
                                  0,
                                  0.080140238762890698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10394367678570457,
                                  0,
                                  -0.17369804702668379,
                                  0,
                                  -0.088190858441109965,
                                  0,
                                  0,
                                  0,
                                  -0.30168846098100122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20168636308613824,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.020290348689488501,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18002763144338574,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11946110287677178,
                                  -0.33574823211143889,
                                  0,
                                  0,
                                  0,
                                  -0.081573639347671686,
                                  0,
                                  0,
                                  0.040872274064098831,
                                  0,
                                  -0.43675746013300321,
                                  0.49500692455371148,
                                  -0.20028536949782938,
                                  0,
                                  0,
                                  -0.037389639472324793,
                                  0,
                                  0,
                                  0,
                                  0.090922177872864399,
                                  0,
                                  0.015327553445575209,
                                  0,
                                  0,
                                  0.38202901750963097,
                                  0.025637507832922235,
                                  0,
                                  0,
                                  0.11656228101869807,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19087156601915276,
                                  0,
                                  0.26978731144858348,
                                  0,
                                  0.022877190602880765,
                                  0,
                                  0,
                                  0,
                                  0.25867977247296381,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29146550042981134,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22122908183571055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15989990101071519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.005828358656029247,
                                  -0.097621333672743768,
                                  0,
                                  0,
                                  0,
                                  -0.095579137645132706,
                                  0,
                                  0,
                                  -0.2809436683584674,
                                  0,
                                  -0.2640084860711952,
                                  -0.44782684970621756,
                                  0.13177065854873724,
                                  0,
                                  0,
                                  0.13944166714803849,
                                  0,
                                  0,
                                  0,
                                  0.073151854992260706,
                                  0,
                                  0.0071257708115563881,
                                  0,
                                  0,
                                  0.14062522844442996,
                                  0.10114608190708532,
                                  0,
                                  0,
                                  0.25666859016082577,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24358528220702144,
                                  0,
                                  0.25663679416184898,
                                  0,
                                  -0.29451284803807892,
                                  0,
                                  0,
                                  0,
                                  0.067361074176529048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14851568435978246,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21175230141900944,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45602754807067591,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11055080025601108,
                                  0.0064493955324864474,
                                  0,
                                  0.26677919141357831,
                                  0,
                                  0,
                                  -0.025598367532327738,
                                  0,
                                  0,
                                  -0.13882025984822161,
                                  0,
                                  0,
                                  0,
                                  0.43015206714791626,
                                  0,
                                  0,
                                  0,
                                  -0.037061166983141075,
                                  0,
                                  0,
                                  -0.074195277999216949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36439763947764336,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12411562588197834,
                                  -0.50949910485137706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14872543220060483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.053115495277394759,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47238055235300386,
                                  0,
                                  0.038584097969456721,
                                  0,
                                  0.45389407691151162,
                                  0,
                                  0,
                                  0.46868843351112977,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049472270517293269,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.016048831723079783,
                                  0,
                                  0.21691139620330474,
                                  0.3248960857634543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31920077559528021,
                                  0,
                                  -0.18674374001070532,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31205331071895898,
                                  0,
                                  -0.014513339969458781,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31227766036880672,
                                  0,
                                  0,
                                  0.021119376638460328,
                                  -0.26103864814076994,
                                  0,
                                  0.084684186946463277,
                                  0,
                                  0,
                                  0.0742919017605113,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10512351874185563,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24586557726230057,
                                  0,
                                  0,
                                  0,
                                  -0.17165366360839257,
                                  -0.049320597398522369,
                                  -0.10674664327781737,
                                  0,
                                  0,
                                  0,
                                  0.073685572727227075,
                                  -0.32559511588355594,
                                  0,
                                  0,
                                  -0.039589831723429787,
                                  -0.16417810562780191,
                                  0,
                                  -0.0020535798948540613,
                                  0,
                                  0,
                                  -0.056332802224360434,
                                  0,
                                  0.35719437489017108,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069631115716988018,
                                  0,
                                  0,
                                  0,
                                  0.27961714973040175,
                                  0,
                                  -0.15417082090768705,
                                  0.19157105836178639,
                                  0.01928525820140305,
                                  0.11846344968329968,
                                  -0.11064275513832784,
                                  -0.21296406705695076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27663624913122997,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10578507782847613,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15278874814031684,
                                  0,
                                  0,
                                  0.17387739087818374,
                                  0,
                                  -0.074006547111071477,
                                  -0.20483107241946358,
                                  -0.093679346256489299,
                                  0,
                                  0,
                                  0.25705268556433053,
                                  0,
                                  0,
                                  0,
                                  -0.28692761031250691,
                                  0,
                                  0.12925105261874811,
                                  0,
                                  0,
                                  0.21952394916964174,
                                  -0.07020195353009058,
                                  0,
                                  0,
                                  -0.42266481254150434,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.02523850267234963,
                                  0,
                                  0.25023648483662053,
                                  0,
                                  0.055726977844925689,
                                  0,
                                  0,
                                  0,
                                  -0.15886081316494829,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26943613400773081,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29703841135351655,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14039131374635105,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.44856011427784015,
                                  0.14141648065901283,
                                  0,
                                  0,
                                  0.1103621048483855,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20232390352420504,
                                  0,
                                  0.055183484570559216,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.029109748902059227,
                                  0,
                                  0,
                                  0.36404249586931631,
                                  -0.30801123109757345,
                                  0,
                                  -0.12685164475359903,
                                  0,
                                  0,
                                  -0.45306541939048445,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068056649137676936,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.066379140178657009,
                                  0,
                                  0,
                                  0,
                                  -0.040650465920300638,
                                  -0.28748161358118152,
                                  0.15173178493836939,
                                  0,
                                  0,
                                  0,
                                  0.13880118308117717,
                                  -0.048434251555314861,
                                  0,
                                  0,
                                  0.20480021588727268,
                                  0.0011438519878578593,
                                  0,
                                  -0.051303120450455,
                                  0,
                                  0,
                                  0.26309181038616425,
                                  0,
                                  0.18081756788627215,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17684901412951573,
                                  0,
                                  0,
                                  0,
                                  -0.032481989213605456,
                                  0,
                                  -0.13705859694411171,
                                  0.13544202425580287,
                                  -0.10183888199271884,
                                  0.015642394046905379,
                                  0.24733934612417854,
                                  0.20509624079968974,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14446178679492899,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074764275530637886,
                                  0,
                                  0,
                                  0,
                                  -0.42657999327409102,
                                  0,
                                  0,
                                  -0.51714777637377618,
                                  0,
                                  0,
                                  0.29048541408301298,
                                  0,
                                  0,
                                  0,
                                  0.41948818564954005,
                                  0,
                                  0,
                                  0,
                                  0.28127669065431182,
                                  0,
                                  0,
                                  -0.039790176173407785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14109855625443293,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2629595185409247,
                                  -0.29435913915597628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.05065835762005453,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38530965577717602,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43573590583004063,
                                  0,
                                  -0.095272378413296055,
                                  0,
                                  -0.38496778491738359,
                                  0,
                                  0,
                                  -0.59220681359087202,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20012249051143621,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27644687714934679,
                                  0,
                                  0.15260122330037823,
                                  0.15803657068004942,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12584848818066724,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030159453360469567,
                                  0,
                                  0,
                                  0,
                                  0.041991205620792692,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3181474711982018,
                                  0,
                                  0,
                                  -0.6033506972174707,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12256116222010502,
                                  0.1173407885259103,
                                  -0.18811499690540739,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19680038970374081,
                                  0,
                                  0,
                                  0,
                                  0.22676586461774473,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16004962602170808,
                                  0,
                                  0,
                                  0,
                                  0.06759831392012032,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31887338900949824,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54828053537562205,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046885584017935855,
                                  0,
                                  0,
                                  -0.24255333888383143,
                                  0.74246431999282647,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16059599799633681,
                                  0.51713139804638852,
                                  -0.34442257641353469,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23947055135961554,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22228245795381635,
                                  0,
                                  0,
                                  0.0062964078115594598,
                                  0,
                                  0.053746410896772429,
                                  -0.22760990092493075,
                                  -0.24618752493673327,
                                  0,
                                  0,
                                  -0.40977772349995989,
                                  0,
                                  0,
                                  0,
                                  0.0081454473227053556,
                                  0,
                                  -0.31381244662263125,
                                  0,
                                  0,
                                  -0.047931719259411407,
                                  0.01190243813981192,
                                  0,
                                  0,
                                  -0.26908918810936211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46408315617524887,
                                  0,
                                  -0.16630104830886791,
                                  0,
                                  0.2722707221463343,
                                  0,
                                  0,
                                  0,
                                  -0.16533622860318462,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31582427225269727,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.016000188983563132,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035103790984387928,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1303027631440693,
                                  -0.17671570137814291,
                                  0,
                                  0.42626689685430541,
                                  0,
                                  0,
                                  0.2069816302784887,
                                  0,
                                  0,
                                  0.079244849388292987,
                                  0,
                                  0,
                                  0,
                                  -0.17960512779652565,
                                  0,
                                  0,
                                  0,
                                  0.092004021368099376,
                                  0,
                                  0,
                                  0.067406479651278564,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16223072292719168,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30749718060549625,
                                  0.1739988689553725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.071633142360595981,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.010482657655928526,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25949084812587436,
                                  0,
                                  0.98870968140854043,
                                  0,
                                  -0.20050119024372803,
                                  0,
                                  0,
                                  -0.030845734727771783,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.42734110337504394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2725678239358606,
                                  0,
                                  0.23221025559907632,
                                  0.16844894525172013,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15918103999371608,
                                  0,
                                  0,
                                  0.031538823495502959,
                                  0,
                                  0,
                                  0.25115858193004648,
                                  0,
                                  0.0761021458835036,
                                  0.20572741252222726,
                                  0.05732953341192909,
                                  0,
                                  0,
                                  -0.29247524573943107,
                                  0,
                                  0,
                                  0,
                                  -0.10225111692942104,
                                  0,
                                  -0.081164101965821453,
                                  0,
                                  0,
                                  0.22588775759200308,
                                  0.080467788974234608,
                                  0,
                                  0,
                                  0.32437217565146109,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.069263277200346279,
                                  0,
                                  0.26881536519745275,
                                  0,
                                  0.2203759333374401,
                                  0,
                                  0,
                                  0,
                                  -0.2759753326092908,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36458638469723464,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4536248438010323,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15773149189268545,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098839373834346281,
                                  -0.20996702214761101,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.45681632301253006,
                                  0,
                                  0,
                                  0,
                                  -0.012836582315718242,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18806942347276226,
                                  0,
                                  0,
                                  -0.65196606684603975,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56649909749885319,
                                  0.18308875992996232,
                                  -0.26452036739863982,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1621160303333227,
                                  0,
                                  0,
                                  0,
                                  -0.25463756545473815,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23213118644109315,
                                  0,
                                  0,
                                  0,
                                  -0.043800608131583811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24253264411936415,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48860659675175372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28684854699508,
                                  0,
                                  0,
                                  0.48451036306327799,
                                  0.15587287609030848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.72076220918876999,
                                  -0.02683363604607944,
                                  -0.068454757892342011,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17829862491565607,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040184495530560228,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017692669866569515,
                                  0,
                                  0.22239852412450004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057438296119345721,
                                  0,
                                  0,
                                  0.21242577837982188,
                                  0.081485484340851455,
                                  0,
                                  -0.22244118676693042,
                                  0,
                                  0,
                                  0.012875220826966512,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.040997176236188329,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12402979535507969,
                                  0,
                                  0,
                                  0,
                                  -0.076480398239179542,
                                  -0.025886849723989296,
                                  -0.14901567945916197,
                                  0,
                                  0,
                                  0,
                                  -0.42284763673406628,
                                  0.0013919048687299901,
                                  0,
                                  0,
                                  -0.13260619209165661,
                                  -0.14321882167987135,
                                  0,
                                  0.25322137544136392,
                                  0,
                                  0,
                                  0.13864230299007557,
                                  0,
                                  0.10119978758897999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077681680458091665,
                                  0,
                                  0,
                                  0,
                                  -0.0038469229873621669,
                                  0,
                                  0.25835541161166725,
                                  0.45655955903218998,
                                  0.13706348569720314,
                                  -0.01536687194266937,
                                  0.22935856226106272,
                                  -0.19628970554195485,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2633444654512026,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1639474671103128,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1706179234840047,
                                  0,
                                  0,
                                  -0.32270513862785066,
                                  0,
                                  -0.16229730733607983,
                                  0.013364951161727513,
                                  -0.28213376913682031,
                                  0,
                                  0,
                                  0.29340239381502886,
                                  0,
                                  0,
                                  0,
                                  0.064066180472812762,
                                  0,
                                  0.23444222090548153,
                                  0,
                                  0,
                                  0.086548588859488088,
                                  -0.02712435817358104,
                                  0,
                                  0,
                                  -0.039657335245637526,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19850436113260633,
                                  0,
                                  -0.28918622834757618,
                                  0,
                                  0.55611351995725933,
                                  0,
                                  0,
                                  0,
                                  0.17064473537520894,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31394578649521415,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13606291267650902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16340564087986306,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0068148342191663921,
                                  0.021054224497842548,
                                  0,
                                  0,
                                  0,
                                  -0.026024188441272557,
                                  0,
                                  0,
                                  0.045834844565864813,
                                  0,
                                  0.10147170910918249,
                                  -0.10572380631608354,
                                  0.42322610669665728,
                                  0,
                                  0,
                                  -0.22899372310815602,
                                  0,
                                  0,
                                  0,
                                  -0.10154441314630389,
                                  0,
                                  0.15520553181280949,
                                  0,
                                  0,
                                  -0.11636566077787772,
                                  0.15131189091415259,
                                  0,
                                  0,
                                  0.11091785415860386,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.08747545648871452,
                                  0,
                                  -0.1169931178380557,
                                  0,
                                  0.19663810902927986,
                                  0,
                                  0,
                                  0,
                                  0.64628526795611796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17812161223928211,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19442726519495712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14984248687334567,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27581082098533272,
                                  -0.12371813022183799,
                                  0,
                                  0,
                                  -0.11531998052190164,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18072842305071982,
                                  0,
                                  0.045075423967514835,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22578458533549117,
                                  0,
                                  0,
                                  -0.33682243752403368,
                                  -0.077743755955967719,
                                  0,
                                  -0.26005311210003823,
                                  0,
                                  0,
                                  0.074895273576418273,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12273719636650723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082464519451926524,
                                  0,
                                  0,
                                  0,
                                  -0.044891985469285474,
                                  -0.10725705683943258,
                                  0.066992467699826266,
                                  0,
                                  0,
                                  0,
                                  0.15419627180477397,
                                  -0.086987361866927293,
                                  0,
                                  0,
                                  -0.33337945484030052,
                                  -0.081852106997567176,
                                  0,
                                  0.19286148857718499,
                                  0,
                                  0,
                                  -0.12084046199985252,
                                  0,
                                  0.28541055200393617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11802147916419249,
                                  0,
                                  0,
                                  0,
                                  -0.36687854441701567,
                                  0,
                                  0.20797405388785484,
                                  0.072610960642107605,
                                  0.17228547484408699,
                                  0.0040434014200373819,
                                  -0.019465603211780369,
                                  0.078517129803701138,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31128511072350046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23619494403102848,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2870390033976275,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36831207939946325,
                                  0,
                                  0.14223043270778057,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11931031822475142,
                                  0,
                                  0,
                                  -0.1076752748349976,
                                  -0.18849949615621089,
                                  0,
                                  0.017260034659473709,
                                  0,
                                  0,
                                  0.090346673541581782,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.026193622180896468,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29036734309020273,
                                  0,
                                  0,
                                  0,
                                  0.0028626404304044921,
                                  0.20697103504187761,
                                  0.1588458035935672,
                                  0,
                                  0,
                                  0,
                                  -0.048757521942325292,
                                  -0.0065795521270935959,
                                  0,
                                  0,
                                  -0.052241132589995312,
                                  -0.036969934478322863,
                                  0,
                                  -0.047107798143240828,
                                  0,
                                  0,
                                  0.37020693532751542,
                                  0,
                                  -0.14906267303928677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24339782247280764,
                                  0,
                                  0,
                                  0,
                                  -0.19926772638305568,
                                  0,
                                  -0.049902836516202032,
                                  -0.15497517848224315,
                                  -0.24453631334451584,
                                  0.21303862823608935,
                                  0.201186050244376,
                                  -0.2806763688260866,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.09816009863876124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10624161443231002,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27775948974656406,
                                  0,
                                  0,
                                  0.26734829742550925,
                                  0,
                                  -0.27174703895890245,
                                  -0.13841905127876811,
                                  0.16716525897820789,
                                  0,
                                  0,
                                  0.083490083531107026,
                                  0,
                                  0,
                                  0,
                                  -0.16419580158239022,
                                  0,
                                  0.26948969509656762,
                                  0,
                                  0,
                                  -0.22796979995077127,
                                  -0.36015929222696946,
                                  0,
                                  0,
                                  -0.10155091985708983,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.065955821881047608,
                                  0,
                                  0.2594390527616845,
                                  0,
                                  0.16894697572858036,
                                  0,
                                  0,
                                  0,
                                  0.041302995945561312,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16249435456538228,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070342538402756449,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20919210439529265,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.49961585605378728,
                                  -0.072341677854889055,
                                  0,
                                  0,
                                  0.19149538875690253,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11529092758980701,
                                  0,
                                  -0.21020214369418663,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19352404197252751,
                                  0,
                                  0,
                                  -0.11020273369713895,
                                  0.16034483382232467,
                                  0,
                                  -0.078488656772188484,
                                  0,
                                  0,
                                  0.1299174435796393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46617531976600812,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.011606412638467612,
                                  0,
                                  0,
                                  0,
                                  0.033026843514830886,
                                  0.24388321942175231,
                                  -0.083001472365674206,
                                  0,
                                  0,
                                  0,
                                  0.15287175779492629,
                                  -0.084759245163445796,
                                  0,
                                  0,
                                  -0.13130885420018265,
                                  0.30382683445235159,
                                  0,
                                  -0.20033021057474357,
                                  0,
                                  0,
                                  0.28937109746510697,
                                  0,
                                  -0.14086089362258056,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.021418884051493198,
                                  0,
                                  0,
                                  0,
                                  -0.0024701637441163077,
                                  0,
                                  0.12024144099869027,
                                  0.3656453469769389,
                                  0.026706019513240538,
                                  -0.084550604356241302,
                                  0.11945660793694464,
                                  -0.008130441378757472,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24033603779746004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10098829372092195,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16546229116051461,
                                  0,
                                  0,
                                  0,
                                  -0.88393017910536775,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2929628557123779,
                                  0,
                                  0,
                                  -0.025608895080576007,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35754440912690977,
                                  0.21079228486921117,
                                  -0.048254402104283653,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19543331940738823,
                                  0,
                                  0,
                                  0,
                                  0.1229777644859819,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.54846406552922811,
                                  0,
                                  0,
                                  0,
                                  -0.41178760568683137,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15852922197569055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11805547871908206,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049620586374426512,
                                  0,
                                  0,
                                  -0.12851255128263303,
                                  -0.000685915372597155,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.073949113461419691,
                                  0.22335972279277874,
                                  0.32012477123337446,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49766933839475058,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23299974096226206,
                                  0,
                                  0,
                                  -0.53423088039200328,
                                  0,
                                  0,
                                  0.034173475722017038,
                                  0,
                                  0,
                                  0,
                                  0.065361530656829245,
                                  0,
                                  0,
                                  0,
                                  -0.25926130133741881,
                                  0,
                                  0,
                                  0.68672625667281106,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07748000967958088,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11165705320583252,
                                  0.14395325524051811,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072563689019370922,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23300142647179478,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31467402349607831,
                                  0,
                                  -0.094309932604368693,
                                  0,
                                  0.17084626189543234,
                                  0,
                                  0,
                                  0.37309920912814387,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24310270631406095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16704742425780894,
                                  0,
                                  0.15914790806992529,
                                  -0.50705922061861253,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16327011984026582,
                                  0,
                                  -0.15481755293182331,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12554407649290686,
                                  0,
                                  0.09266087785736353,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.048175582106351117,
                                  0,
                                  0,
                                  -0.096737441609044336,
                                  0.27373001842162276,
                                  0,
                                  -0.098071894148891489,
                                  0,
                                  0,
                                  -0.25192158909875323,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28816922674323514,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.017084499554309688,
                                  0,
                                  0,
                                  0,
                                  -0.32894805991910492,
                                  -0.097426000301230303,
                                  -0.062454311355941816,
                                  0,
                                  0,
                                  0,
                                  0.14524885028265713,
                                  0.036307623670822145,
                                  0,
                                  0,
                                  -0.34676516402916407,
                                  -0.15025161438494664,
                                  0,
                                  0.21461098074222554,
                                  0,
                                  0,
                                  0.28636809227063842,
                                  0,
                                  -0.069252967729358531,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1438389366906575,
                                  0,
                                  0,
                                  0,
                                  0.30120845240539706,
                                  0,
                                  0.0032403653547036695,
                                  -0.35767799986180732,
                                  -0.1462394078978041,
                                  0.038413904059265473,
                                  -0.057811465815272807,
                                  0.093825486773718617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0096499625727167505,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12043220378167843,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.50003923106117121,
                                  0,
                                  0,
                                  0,
                                  0.34893633049905493,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14971652698932011,
                                  0,
                                  0,
                                  0.30544579347009027,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40129742189862211,
                                  0.36379511911799062,
                                  -0.14547912064037555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3272760101894131,
                                  0,
                                  0,
                                  0,
                                  -0.25274805358581065,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3870234727868449,
                                  0,
                                  0,
                                  0,
                                  -0.0066419541340716759,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.043542256861646006,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0819062823950302,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51052926503024298,
                                  0,
                                  0,
                                  0.53346030916313814,
                                  0.081058440840241372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059728043215269151,
                                  0.5990472735823833,
                                  0.27542929101095004,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024694159651390081,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10515999822167765,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32082110186686419,
                                  0.12587047656431066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.014207952214098769,
                                  0,
                                  -0.177130588126095,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19026394434983745,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.67528344353904091,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39580418829689457,
                                  0.42817222055160059,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.079963765428202577,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32663543737621215,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.31887274875599991,
                                  -0.3798357704566212,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081982685504090963,
                                  0,
                                  -0.5132015722777461,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44460389372331521,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15627882819904726,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10464385663592549,
                                  0.32179945935128107,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20163410151568459,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14539569432175639,
                                  0,
                                  0,
                                  -0.011817667317295446,
                                  0,
                                  0,
                                  0.18403397444836503,
                                  0,
                                  0,
                                  0,
                                  -0.41857344974178234,
                                  0,
                                  0,
                                  0,
                                  -0.14166053372190193,
                                  0,
                                  0,
                                  0.10922392917777524,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22922617172335524,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17032993648226041,
                                  0.22780249577785405,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3536065087842285,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26845521714359949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37748545302525782,
                                  0,
                                  -0.036459959149832424,
                                  0,
                                  0.12883934765091426,
                                  0,
                                  0,
                                  0.017319954405667373,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45768754841141773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21921354122862127,
                                  0,
                                  -0.33540959206084353,
                                  0.62302461923405461,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061754722229557017,
                                  -0.25889250148340565,
                                  0,
                                  0,
                                  0.15532965214698696,
                                  0,
                                  0,
                                  0.24594776260680493,
                                  0,
                                  0,
                                  0,
                                  -0.41983767479998046,
                                  0,
                                  0,
                                  0,
                                  0.2246730599081273,
                                  0,
                                  0,
                                  0.19949248104462902,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41120140527347326,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24679406740499307,
                                  0.29182888218263797,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45590332469978334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036193364509821857,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16980073099168266,
                                  0,
                                  -0.086795331622244953,
                                  0,
                                  -0.25347269204440076,
                                  0,
                                  0,
                                  0.55602211489441045,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24139538722702492,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25762744442501645,
                                  0,
                                  0.072483824185044149,
                                  0.15832515331460809,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37508747936029829,
                                  0,
                                  -0.10948875321579812,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.031654029109111428,
                                  0,
                                  0.069138667212922153,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27492265062657251,
                                  0,
                                  0,
                                  -0.39150398528963243,
                                  -0.068700234070498814,
                                  0,
                                  -0.2046304828396501,
                                  0,
                                  0,
                                  0.0059686511248954058,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11779984486574469,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.040545492799075371,
                                  0,
                                  0,
                                  0,
                                  0.30065171551290715,
                                  -0.18545561160979387,
                                  -0.048854575423163515,
                                  0,
                                  0,
                                  0,
                                  -0.31613721387873422,
                                  -0.099075820756042488,
                                  0,
                                  0,
                                  0.096707695775232722,
                                  -0.079661789230680388,
                                  0,
                                  -0.36832117189987595,
                                  0,
                                  0,
                                  0.22615624068924117,
                                  0,
                                  0.076653576323022166,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056033338626164546,
                                  0,
                                  0,
                                  0,
                                  0.27643765898573713,
                                  0,
                                  -0.10164806169614501,
                                  0.10596341199068357,
                                  0.014830886584834849,
                                  -0.024209398750054578,
                                  -0.26622869239290803,
                                  0.22953515484062773,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13406841762140637,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.049476228366481204,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1389754220478866,
                                  0,
                                  0,
                                  0,
                                  0.13167868095361324,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22571416420441406,
                                  0,
                                  0,
                                  -0.096565238643728235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23110001051428378,
                                  0.1244399232335939,
                                  -0.2987646083750673,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050355817155001578,
                                  0,
                                  0,
                                  0,
                                  -0.44130506161198135,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25803595938079793,
                                  0,
                                  0,
                                  0,
                                  -0.59763897300155999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.74177923593932515,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33009692607049662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23468660376581768,
                                  0,
                                  0,
                                  -0.29062654585709796,
                                  0.55300724449812799,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.59842622056292205,
                                  -0.16475100813573118,
                                  0.094102461703820334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14496516694384243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.074844515680129717,
                                  0,
                                  0,
                                  0,
                                  -0.22605763459640826,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021480886665165691,
                                  0,
                                  0,
                                  -0.43486002604260893,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60768811480049378,
                                  -0.41334327774955165,
                                  -0.39105416416085698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16600757278350428,
                                  0,
                                  0,
                                  0,
                                  0.22602773628864417,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070370267206805601,
                                  0,
                                  0,
                                  0,
                                  -0.046962124143302225,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.088926092506804791,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32296903122658233,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082645374485430273,
                                  0,
                                  0,
                                  0.45854812051266358,
                                  0.042868131945221481,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021107678662115908,
                                  -0.24829192845738907,
                                  -0.38582881192979041,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1669976202390292,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26348560139348925,
                                  0,
                                  0,
                                  0,
                                  -0.11586203304929069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30252438967096662,
                                  0,
                                  0,
                                  -0.18196372267105568,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19857665663368573,
                                  -0.99279268400336174,
                                  -0.075590514215054638,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.036288001229653657,
                                  0,
                                  0,
                                  0,
                                  -0.37805485154310775,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29881289882993545,
                                  0,
                                  0,
                                  0,
                                  -0.033610067880564219,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11211314041907736,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0036798807799585474,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16119217688064857,
                                  0,
                                  0,
                                  -0.30739948131122519,
                                  -0.81552717501703442,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0013325073066485533,
                                  0.56302989410479476,
                                  0.11102826830465479,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.078827290495089533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41567692324678562,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025141563351711416,
                                  -0.058291088887645885,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24508957586097002,
                                  0,
                                  0.55454371357261967,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17798457563232201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27252399568094382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38219716481706467,
                                  0.31851529482386171,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31956315894378517,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10139505177383525,
                                  0,
                                  0,
                                  0.19479098999843183,
                                  0,
                                  0.15889407830983399,
                                  -0.24050703795831341,
                                  0.17739763899249195,
                                  0,
                                  0,
                                  0.053743926143644802,
                                  0,
                                  0,
                                  0,
                                  0.33323033410496794,
                                  0,
                                  -0.16693493013984512,
                                  0,
                                  0,
                                  0.27679263249310537,
                                  0.35268116447511605,
                                  0,
                                  0,
                                  -0.27488289966764834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13500342190069262,
                                  0,
                                  0.34925028139402337,
                                  0,
                                  0.33038521176649199,
                                  0,
                                  0,
                                  0,
                                  0.15159064624794599,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1390317016650999,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28427198234359935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.068898235301843136,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17809664419951865,
                                  0.09957995525871266,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39901926086577966,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.00023128764963015885,
                                  -0.31511486186729587,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.65253329574844532,
                                  0,
                                  0.075992344663702652,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27715069724767427,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.078621444706658328,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21501045827093646,
                                  0.077555794155945518,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41793949605297792,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11913724336274903,
                                  0,
                                  0,
                                  -0.23769019873899233,
                                  0,
                                  0.073429599087167133,
                                  0.25626876310775992,
                                  0.28224255911144885,
                                  0,
                                  0,
                                  -0.18128020861487854,
                                  0,
                                  0,
                                  0,
                                  0.28715804829528313,
                                  0,
                                  0.079281913473134444,
                                  0,
                                  0,
                                  -0.094115444231499729,
                                  -0.15756921596482548,
                                  0,
                                  0,
                                  -0.39516338986113542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.48858014220293339,
                                  0,
                                  0.18764591853432391,
                                  0,
                                  -0.2493499741083226,
                                  0,
                                  0,
                                  0,
                                  -0.0042244741989070043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28576842868964869,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.053383929903914662,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.04711124555979844,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11716558643010344,
                                  0.17481417236641891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082731749146471092,
                                  0,
                                  0,
                                  0,
                                  0.5241090974890722,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36208948937956165,
                                  0,
                                  0,
                                  -0.19707599784094063,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.07901653531565439,
                                  -0.68569907895441862,
                                  0.35033825561020604,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.61314415280137824,
                                  0,
                                  0,
                                  0,
                                  -0.25121667538509762,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11446192177135206,
                                  0,
                                  0,
                                  0,
                                  -0.0025986886371629925,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2467584100769882,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35824708588288623,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10327195565287571,
                                  0,
                                  0,
                                  0.411182633558689,
                                  0.13618789998136127,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.047851647704500629,
                                  -0.44294307006695133,
                                  0.30051116971273201,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45230945509957354,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36917030408935486,
                                  0,
                                  0,
                                  0.27365174204476722,
                                  0,
                                  -0.083815204384646985,
                                  -0.044978052404249805,
                                  0.11004071313773083,
                                  0,
                                  0,
                                  0.09948699057027427,
                                  0,
                                  0,
                                  0,
                                  -0.039286052440883387,
                                  0,
                                  0.13976389515638718,
                                  0,
                                  0,
                                  0.12558750921549749,
                                  -0.094325866062226441,
                                  0,
                                  0,
                                  -0.17267513849059316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077009957291359274,
                                  0,
                                  -0.19426163954553397,
                                  0,
                                  -0.10338728817151564,
                                  0,
                                  0,
                                  0,
                                  -0.0099318669706913321,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24611318949690036,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37948705471799671,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.37875177943947141,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3904484192119963,
                                  -0.35674787343087927,
                                  0,
                                  0,
                                  0.054248946057013664,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050527352798101978,
                                  0,
                                  0.092932759860936576,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.041639604434663857,
                                  0,
                                  0,
                                  -0.072709644884454791,
                                  -0.068143617938092343,
                                  0,
                                  -0.24957038105175522,
                                  0,
                                  0,
                                  0.0096437326129746488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064938640406110901,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53226786575026108,
                                  0,
                                  0,
                                  0,
                                  0.041729872713038338,
                                  0.13235614586676953,
                                  -0.090247487575845331,
                                  0,
                                  0,
                                  0,
                                  0.11640493485409026,
                                  0.12643549643815719,
                                  0,
                                  0,
                                  0.25222710550738359,
                                  -0.17643027788727367,
                                  0,
                                  0.03617373671894776,
                                  0,
                                  0,
                                  -0.04781761872171475,
                                  0,
                                  0.17408046936639382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32428481187340791,
                                  0,
                                  0,
                                  0,
                                  0.084485200592699511,
                                  0,
                                  -0.12294788736700447,
                                  -0.10768214743326415,
                                  0.070416830641653494,
                                  -0.42168779206623513,
                                  -0.099302690640116445,
                                  -0.23279220646687682,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18990067875326785,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12964912949389681,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.025396729288040452,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.82839207071208887,
                                  0.024328757802313063,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0064044706199527963,
                                  0,
                                  0.19536732875432336,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30895632106216653,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34169578089049435,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10184206553627381,
                                  -0.096217247219886198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20610847750682676,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30788572217217147,
                                  0,
                                  0,
                                  0,
                                  0.12611362528541614,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43865843510934727,
                                  0,
                                  0,
                                  0.24010481943276707,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28609278707901864,
                                  0.10074639138563896,
                                  0.66993783150739539,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37788534713644206,
                                  0,
                                  0,
                                  0,
                                  -0.25577340237486806,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17912881005240378,
                                  0,
                                  0,
                                  0,
                                  -0.2622540478040829,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34395500389297506,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36770808656588228,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.77329981085641497,
                                  0,
                                  0,
                                  0.19603576908406692,
                                  -0.1786338962712318,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.064967392353125292,
                                  -0.42285400600421091,
                                  -0.45632519305091834,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23120724766353412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22983807940365411,
                                  0,
                                  0,
                                  -0.34864453862808548,
                                  0,
                                  -0.21804645314020446,
                                  -0.076601070738157973,
                                  -0.25985204158808056,
                                  0,
                                  0,
                                  -0.32914481731328443,
                                  0,
                                  0,
                                  0,
                                  -0.053123679247220265,
                                  0,
                                  0.2426268203158741,
                                  0,
                                  0,
                                  -0.11746630945244428,
                                  0.41785150998845988,
                                  0,
                                  0,
                                  -0.27468283275133232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34287763986702346,
                                  0,
                                  0.17842990711937118,
                                  0,
                                  -0.10794462187277196,
                                  0,
                                  0,
                                  0,
                                  0.0019552179775526287,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20971309740777327,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08139471857581293,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12356951908801424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.066833538593590869,
                                  -0.19852528677036221,
                                  0,
                                  0,
                                  0.096082510409794986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1498566621497974,
                                  0,
                                  -0.027539454950527707,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.44921664188635618,
                                  0,
                                  0,
                                  0.12625696117488225,
                                  -0.014788997574537534,
                                  0,
                                  -0.10818404680669985,
                                  0,
                                  0,
                                  0.066674503135079152,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25419753832135084,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26590369169559497,
                                  0,
                                  0,
                                  0,
                                  -0.027350813632783133,
                                  0.052649941951594531,
                                  0.17643193861424625,
                                  0,
                                  0,
                                  0,
                                  -0.063769735009732723,
                                  0.11723992622857851,
                                  0,
                                  0,
                                  0.1230931907963029,
                                  -0.086686270116855174,
                                  0,
                                  0.11171087108099223,
                                  0,
                                  0,
                                  -0.18627057912706058,
                                  0,
                                  -0.22848538480410971,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31251284581745131,
                                  0,
                                  0,
                                  0,
                                  0.17243031333145337,
                                  0,
                                  -0.16991125858162542,
                                  0.032642210181933362,
                                  0.19013533534193069,
                                  0.23006378293016302,
                                  0.22090922847270167,
                                  -0.041106553871963214,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18961238880290879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30126876150625298,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.04922113074544248,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.061207736878885304,
                                  0,
                                  -0.3114813663071247,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19167335658016887,
                                  0,
                                  0,
                                  0.11562451050449711,
                                  0.030568666559350567,
                                  0,
                                  -0.38818979288103356,
                                  0,
                                  0,
                                  -0.11017007389771079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10305940686821372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15790480388617043,
                                  0,
                                  0,
                                  0,
                                  -0.072791946202885371,
                                  0.50715265971674184,
                                  0.052662320740741862,
                                  0,
                                  0,
                                  0,
                                  -0.28158208262905288,
                                  0.21455835513105509,
                                  0,
                                  0,
                                  0.056153043305258804,
                                  -0.1142438746759122,
                                  0,
                                  -0.0042832242366234018,
                                  0,
                                  0,
                                  -0.02663335163585764,
                                  0,
                                  0.309576871191447,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18191897324793649,
                                  0,
                                  0,
                                  0,
                                  -0.10053711839343654,
                                  0,
                                  -0.053933196709630551,
                                  -0.20451951271226376,
                                  0.024261837788228546,
                                  0.083440036800396758,
                                  -0.05301295896900779,
                                  0.2064082237841901,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.054903183798603622,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0097495265382369547,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21742483674199073,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.46811045866163076,
                                  0,
                                  0.11768417357213223,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.024478364409289587,
                                  0,
                                  0,
                                  0.15171122439642534,
                                  0.23162123711838065,
                                  0,
                                  -0.036520271386892011,
                                  0,
                                  0,
                                  -0.17350149106335891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12907940830638209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021586127919314677,
                                  0,
                                  0,
                                  0,
                                  -0.032768691560046193,
                                  -0.051353099865014337,
                                  0.025191841071675321,
                                  0,
                                  0,
                                  0,
                                  0.12384902024090005,
                                  0.16276206994942577,
                                  0,
                                  0,
                                  -0.26191010915066365,
                                  -0.3894539465393716,
                                  0,
                                  -0.28673844401923126,
                                  0,
                                  0,
                                  -0.010300433639940661,
                                  0,
                                  -0.19364533683710156,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20692787488918032,
                                  0,
                                  0,
                                  0,
                                  -0.050621263915402073,
                                  0,
                                  -0.011870318996910595,
                                  0.13440056905479345,
                                  0.17177304079451197,
                                  -0.2610829095394212,
                                  -0.1041694707439941,
                                  0.10447717877118154,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15612826871383628,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.015875887203666096,
                                  0,
                                  0,
                                  0,
                                  0.18816413351574715,
                                  0,
                                  0,
                                  -0.10137995724792229,
                                  0,
                                  0,
                                  0.099225246508332421,
                                  0,
                                  0,
                                  0,
                                  0.16487188624429938,
                                  0,
                                  0,
                                  0,
                                  -0.2774978323010574,
                                  0,
                                  0,
                                  0.48747161776097042,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23453313543614257,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13163245355350273,
                                  -0.44124104749738746,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11137655983284316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.69240268837751029,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06474080009345215,
                                  0,
                                  0.46103635120217806,
                                  0,
                                  -0.22111335894902162,
                                  0,
                                  0,
                                  0.11931150587209723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12104558054634698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11429859575002403,
                                  0,
                                  -0.91955467469155883,
                                  0.21163167810029809,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36152351442090991,
                                  0,
                                  0,
                                  0.32314055965797728,
                                  0,
                                  0,
                                  -0.0027446532200724634,
                                  0,
                                  0.26884984102021603,
                                  0.13934222933207707,
                                  -0.090051103669994748,
                                  0,
                                  0,
                                  -0.20025048559099817,
                                  0,
                                  0,
                                  0,
                                  -0.52587925348157072,
                                  0,
                                  0.34386112904251087,
                                  0,
                                  0,
                                  0.020628497721699578,
                                  0.059360608170600147,
                                  0,
                                  0,
                                  -0.11367970217418705,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.085735339755057954,
                                  0,
                                  0.13201660042291724,
                                  0,
                                  -0.053656951924253134,
                                  0,
                                  0,
                                  0,
                                  0.10411090189819712,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11322888952609605,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23470858427981939,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.40561699448443334,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27029206142192519,
                                  0.0040014283909569764,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32823562794771732,
                                  0,
                                  0,
                                  0,
                                  -0.1718265706837257,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.56712822026516552,
                                  0,
                                  0,
                                  -0.61054507347195064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1665217412442811,
                                  0.16196311852649398,
                                  0.71012766839827268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22110001114060893,
                                  0,
                                  0,
                                  0,
                                  0.34022306751324993,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11569123467657663,
                                  0,
                                  0,
                                  0,
                                  0.25577996745559789,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.32000971281823998,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10877275445995066,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22459128930879135,
                                  0,
                                  0,
                                  0.11802114941288058,
                                  -0.35534892781112681,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1573780772781023,
                                  0.051269917456561204,
                                  -0.2086437954804353,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.30664002179219224,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.091192050159704274,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0090496175288870932,
                                  0,
                                  0.1957627479629222,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032173671772703062,
                                  0,
                                  0,
                                  0.056583315743156185,
                                  0.10431451627878366,
                                  0,
                                  0.158586177027597,
                                  0,
                                  0,
                                  -0.10740131642322698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16499407018769835,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1170099306709772,
                                  0,
                                  0,
                                  0,
                                  -0.21789748704708872,
                                  0.27137249686919362,
                                  -0.16239982147220317,
                                  0,
                                  0,
                                  0,
                                  0.081390051251980317,
                                  -0.16336306346541538,
                                  0,
                                  0,
                                  0.33856838647555243,
                                  5.3767020395986687e-05,
                                  0,
                                  0.19183975527993161,
                                  0,
                                  0,
                                  0.37029026256044462,
                                  0,
                                  -0.095960599894522533,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10572595663523397,
                                  0,
                                  0,
                                  0,
                                  -0.18333030546726453,
                                  0,
                                  -0.01035287273996531,
                                  0.15527502927266573,
                                  0.19285545381280067,
                                  0.065823373164288143,
                                  -0.40468455817154958,
                                  0.14726398734631949,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.039908815147851918,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.29054960546816566,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.046584156206487613,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.067267167921660501,
                                  0,
                                  -0.097472013776446736,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11117718234067797,
                                  0,
                                  0,
                                  -0.050522441910130528,
                                  -0.21427812296771007,
                                  0,
                                  -0.04135797103669589,
                                  0,
                                  0,
                                  -0.22877930356921358,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24712302911814416,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20222292765302563,
                                  0,
                                  0,
                                  0,
                                  0.056239994641604001,
                                  0.11310756794068354,
                                  0.1488331425067296,
                                  0,
                                  0,
                                  0,
                                  0.15774281419494499,
                                  0.0067090074934723024,
                                  0,
                                  0,
                                  -0.24919713420492207,
                                  0.072559968471889669,
                                  0,
                                  -0.17909917934258474,
                                  0,
                                  0,
                                  0.18614487452391029,
                                  0,
                                  0.02088728914397775,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12140047209056866,
                                  0,
                                  0,
                                  0,
                                  0.21747236414776464,
                                  0,
                                  0.068934246619334005,
                                  -0.094750544872591977,
                                  0.30698505039243429,
                                  -0.127452854480577,
                                  0.14999766197043204,
                                  -0.33028342105672531,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38567990536789371,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32065289921839973,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25532637705815159,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2208563518545778,
                                  0.030912647679862598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032873812298539598,
                                  0,
                                  0.16933318456930119,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36006849976725891,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.487575567198686,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39306739509618382,
                                  0.56123415567896429,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13585246947957666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.099255210894078405,
                                  0,
                                  0,
                                  0,
                                  -0.37854929475000232,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039318100516487459,
                                  0,
                                  0,
                                  0.0095549376851582213,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.35201855882899552,
                                  0.14672309475179376,
                                  0.60270421900500737,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.38555864431674886,
                                  0,
                                  0,
                                  0,
                                  -0.26084561016508795,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53117896442715262,
                                  0,
                                  0,
                                  0,
                                  0.054734846650456338,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45489613273742924,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27795149587453333,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22513274764738497,
                                  0,
                                  0,
                                  -0.295832370677654,
                                  -0.26393750774780117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.30752329420635749,
                                  -0.22388483730665709,
                                  0.09773310760022122,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.81309534602003275,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17048291541780397,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19046301725154807,
                                  0,
                                  0.1337719155256728,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.020505922283277814,
                                  0,
                                  0,
                                  -0.072311855513293055,
                                  -0.086390231249427837,
                                  0,
                                  0.17421569961851016,
                                  0,
                                  0,
                                  -0.3082928760505862,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.012991597620763382,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.019411307809931971,
                                  0,
                                  0,
                                  0,
                                  0.43142314403060805,
                                  0.35933275641493123,
                                  0.15533336961382585,
                                  0,
                                  0,
                                  0,
                                  -0.0076903926749025842,
                                  -0.069069391313704168,
                                  0,
                                  0,
                                  -0.22289012986922729,
                                  -0.30327883114395782,
                                  0,
                                  0.0040342044432738026,
                                  0,
                                  0,
                                  -0.029626443499347944,
                                  0,
                                  -0.0039896514233996698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32223833249467093,
                                  0,
                                  0,
                                  0,
                                  -0.113505489258843,
                                  0,
                                  -0.017136380358583201,
                                  0.15648221570930032,
                                  -0.23134231839879182,
                                  0.22281834179523941,
                                  -0.10070169148052746,
                                  -0.0060056094536401925,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.080354577796271837,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17215109724848243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.052453114221613112,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0072116532564929572,
                                  0,
                                  -0.29697581289660796,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20006833023056167,
                                  0,
                                  0,
                                  0.048982912038023907,
                                  0.15132674027076792,
                                  0,
                                  -0.14754145950812486,
                                  0,
                                  0,
                                  -0.1344827680591491,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.3199825917536499,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.05879387588519544,
                                  0,
                                  0,
                                  0,
                                  -0.017854719947241401,
                                  0.061962730168967729,
                                  0.086491289046396969,
                                  0,
                                  0,
                                  0,
                                  -0.17992558831440542,
                                  -0.48239295775089958,
                                  0,
                                  0,
                                  0.17836838007189992,
                                  -0.0041311313169842025,
                                  0,
                                  -0.065571364351684994,
                                  0,
                                  0,
                                  0.12122510355486826,
                                  0,
                                  -0.12450860027405819,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072332338154057735,
                                  0,
                                  0,
                                  0,
                                  0.081948447128896318,
                                  0,
                                  0.29333551246017842,
                                  -0.18712651398843491,
                                  -0.0016369390211213447,
                                  -0.14681310699798472,
                                  0.077904530300159355,
                                  -0.13566636574636134,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33298091990740397,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25497810761556411,
                                  0,
                                  0,
                                  0,
                                  -0.74211278034999417,
                                  0,
                                  0,
                                  0.14353906284341511,
                                  0,
                                  0,
                                  -0.15548170671871706,
                                  0,
                                  0,
                                  0,
                                  0.43609636833579196,
                                  0,
                                  0,
                                  0,
                                  -0.33909634802102395,
                                  0,
                                  0,
                                  -0.022810792365140952,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.094734498748466192,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34559013378257619,
                                  0.39330357317167275,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14764796381392051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059283092427422274,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.089314870641888033,
                                  0,
                                  0.42264750934309103,
                                  0,
                                  -0.38352183236631315,
                                  0,
                                  0,
                                  0.31944406322283064,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23777674000075838,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10529598582689403,
                                  0,
                                  -0.12256123909913624,
                                  -0.063235267952377425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24035290167247556,
                                  0,
                                  -0.24533273954320547,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.037053133129809762,
                                  0,
                                  0.039235845883826392,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.017808778998178763,
                                  0,
                                  0,
                                  -0.10864462626142034,
                                  0.12516959050154494,
                                  0,
                                  -0.31281970746039178,
                                  0,
                                  0,
                                  -0.1711625748399439,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.054868077834893711,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.050576076271963664,
                                  0,
                                  0,
                                  0,
                                  -0.16193180670285623,
                                  -0.0074567251819717961,
                                  0.52597344808617408,
                                  0,
                                  0,
                                  0,
                                  0.13526762630980549,
                                  -0.042136466437019945,
                                  0,
                                  0,
                                  0.095019262507115634,
                                  0.21573017985199797,
                                  0,
                                  0.026677992487611154,
                                  0,
                                  0,
                                  -0.19507415509685316,
                                  0,
                                  -0.16655524223670151,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.014668129207975372,
                                  0,
                                  0,
                                  0,
                                  -0.10886408499101916,
                                  0,
                                  -0.20030921675027485,
                                  0.30571539535805253,
                                  -0.1120269780272653,
                                  -0.12356392327706985,
                                  -0.2309798054200321,
                                  -0.17331069084645984,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15767161182238559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22270656109508075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.56765047631100496,
                                  0,
                                  0,
                                  -0.059993118495699868,
                                  0,
                                  0.50753747415334538,
                                  0.1322703376380793,
                                  -0.18874827480835407,
                                  0,
                                  0,
                                  0.10418168783225706,
                                  0,
                                  0,
                                  0,
                                  0.20380746338514791,
                                  0,
                                  0.33392042521348742,
                                  0,
                                  0,
                                  -0.023919854352731699,
                                  -0.036213694896357312,
                                  0,
                                  0,
                                  0.1242847727855555,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0022874084588024226,
                                  0,
                                  0.20652147062538267,
                                  0,
                                  0.13581689628736626,
                                  0,
                                  0,
                                  0,
                                  -0.014641742695513424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1752296800426435,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.069699188188651895,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.095809635507984117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.076497257073905867,
                                  0.2651829079551673,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.17634886760746932,
                                  0,
                                  0,
                                  0,
                                  -0.0074482622268570997,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54527522513791982,
                                  0,
                                  0,
                                  0.11287874106513016,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25149877556270722,
                                  -0.19865540880950588,
                                  0.18140330265053337,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51152429589310866,
                                  0,
                                  0,
                                  0,
                                  0.22149337134604416,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36822668645789436,
                                  0,
                                  0,
                                  0,
                                  -0.19990245551376859,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.42836491308761954,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29052428711013129,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.58210839931016678,
                                  0,
                                  0,
                                  0.53043443874771046,
                                  -0.16560007978172347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41937106753567405,
                                  0.30215022982322892,
                                  -0.66142683481486764,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060824207581362755,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26002088242873744,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19575804029407151,
                                  0,
                                  -0.35361847064097818,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.081865376739003917,
                                  0,
                                  0,
                                  -0.16562194550266465,
                                  -0.047570951630429334,
                                  0,
                                  -0.022856511353907101,
                                  0,
                                  0,
                                  0.052627904294309344,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.092138895927699804,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.057261541031764493,
                                  0,
                                  0,
                                  0,
                                  -0.045791807802742744,
                                  0.043047137440920605,
                                  -0.31341167877048387,
                                  0,
                                  0,
                                  0,
                                  0.23150076438713069,
                                  0.023580723822127961,
                                  0,
                                  0,
                                  0.11485978653387137,
                                  -0.42154486052516527,
                                  0,
                                  -0.028867059617653082,
                                  0,
                                  0,
                                  0.043665941439430325,
                                  0,
                                  -0.23047481343549425,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.033146723488710672,
                                  0,
                                  0,
                                  0,
                                  -0.13964943103831906,
                                  0,
                                  -0.32091833476084086,
                                  0.1811809705235001,
                                  0.060974374774582021,
                                  -0.044809926944706105,
                                  0.29665739024165705,
                                  0.023432487811920488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.12605204029590178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21886841942064281,
                                  0,
                                  0,
                                  0,
                                  0.22699376832264834,
                                  0,
                                  0,
                                  0.052876143293132255,
                                  0,
                                  0,
                                  -0.31535120726332971,
                                  0,
                                  0,
                                  0,
                                  -0.047123554730217974,
                                  0,
                                  0,
                                  0,
                                  0.42393181306005101,
                                  0,
                                  0,
                                  0.00084360290942059627,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38850112666349651,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13642230947876599,
                                  0.2779831861519178,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26959456801294229,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65157159420181554,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.067907011005595805,
                                  0,
                                  -0.40539478564778597,
                                  0,
                                  0.097661747559036879,
                                  0,
                                  0,
                                  0.38900771687552183,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.029719119778019634,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46925990103139292,
                                  0,
                                  0.1019259910685614,
                                  0.061109161818862986,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.034735481620855831,
                                  0,
                                  0.20923228477665198,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.033356324200349265,
                                  0,
                                  0.32493058325995139,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12856644390750721,
                                  0,
                                  0,
                                  -0.31391177544082349,
                                  -0.18696701928456089,
                                  0,
                                  -0.15837267140571343,
                                  0,
                                  0,
                                  0.14644464196149426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16723531488216406,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16390367925506125,
                                  0,
                                  0,
                                  0,
                                  -0.080577715062898625,
                                  0.13698796574326971,
                                  0.12197542965790625,
                                  0,
                                  0,
                                  0,
                                  0.22234134927952276,
                                  0.28834259236097359,
                                  0,
                                  0,
                                  0.28557057251023665,
                                  -0.021005313649972195,
                                  0,
                                  0.063379039274043952,
                                  0,
                                  0,
                                  0.12414846425524631,
                                  0,
                                  -0.048738667166667055,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.055399227122877925,
                                  0,
                                  0,
                                  0,
                                  0.2422687147839355,
                                  0,
                                  0.2699256564461523,
                                  0.015986914307306668,
                                  0.090492466396402807,
                                  0.11365396551953989,
                                  0.17268532825793784,
                                  0.1395087777789481,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.071167542669766368,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33361601296833782,
                                  0,
                                  0,
                                  0,
                                  0.10387892489335841,
                                  0,
                                  0,
                                  0.076816493978267578,
                                  0,
                                  0,
                                  0.4462862386168378,
                                  0,
                                  0,
                                  0,
                                  0.057519135964806976,
                                  0,
                                  0,
                                  0,
                                  -0.013955261746289018,
                                  0,
                                  0,
                                  -0.34114666101652813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.051989172387817723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10936908801196921,
                                  0.14765158389562347,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.58534888383908079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06193077516143209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21526901797814851,
                                  0,
                                  -0.30701535912173428,
                                  0,
                                  -0.086222289941124422,
                                  0,
                                  0,
                                  0.099253829113748568,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.38562579345694609,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15707561997914421,
                                  0,
                                  -0.32314768072621858,
                                  -0.47490757029571495,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.79136988861901603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2613393823898994,
                                  0,
                                  0,
                                  0,
                                  0.21528207625015677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28346717607984451,
                                  0,
                                  0,
                                  -0.42715658843530263,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098689239980293109,
                                  0.61726108863651585,
                                  0.039095441133005851,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.077106091524496587,
                                  0,
                                  0,
                                  0,
                                  0.15324358930457355,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3605969184476604,
                                  0,
                                  0,
                                  0,
                                  -0.30646735012930915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19815065686911978,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.51535600659441883,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13441540885055916,
                                  0,
                                  0,
                                  0.41189475419945198,
                                  -0.70461555144137522,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27281478626182043,
                                  -0.36018023572102509,
                                  0.17281321892588575,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25882092802984397,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.082353766693477326,
                                  0,
                                  0,
                                  -0.59039842043602675,
                                  0,
                                  0,
                                  -0.1171273956470919,
                                  0,
                                  0,
                                  0,
                                  -0.035886245232443395,
                                  0,
                                  0,
                                  0,
                                  -0.077158808789878935,
                                  0,
                                  0,
                                  -0.17624451369328856,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.061182080974304422,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20568320474039015,
                                  -0.28647267292245415,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10475976287292606,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.22166145683119209,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29003868256737469,
                                  0,
                                  -0.048492137395243162,
                                  0,
                                  -0.53970161255656446,
                                  0,
                                  0,
                                  -0.11253442014566971,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18513300170310187,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.5884289340069675,
                                  0,
                                  0.1870287882152783,
                                  0.37466107767090934,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.00027506427256807076,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18724924029450102,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.072066305372292222,
                                  0.45630377385395698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.64624683293398544,
                                  0,
                                  -0.40341222425122403,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.044307013641795581,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11678812619663685,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056704444093763545,
                                  -0.13584704099037706,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.36589923947588321,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.61399031597356224,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.048604401708179902,
                                  -0.29075708061467032,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.060760980747048172,
                                  0,
                                  -0.14923602845721862,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53880798499490667,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25136047013723839,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033865583278678071,
                                  -0.37027973683406656,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13564823347201846,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11138519406305825,
                                  0,
                                  0,
                                  -0.0067937596359798208,
                                  0,
                                  0,
                                  -0.33435299858721612,
                                  0,
                                  0,
                                  0,
                                  0.11768632011413167,
                                  0,
                                  0,
                                  0,
                                  0.035453387968761324,
                                  0,
                                  0,
                                  0.35562350336379944,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.47754207347233579,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21345255785188616,
                                  0.65163278954787618,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15758109255303321,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1112881808209468,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27248607182690232,
                                  0,
                                  -0.02690999795580401,
                                  0,
                                  -0.27159589453981148,
                                  0,
                                  0,
                                  -0.19952809905100619,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.39799948458829426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.65103727805862199,
                                  0,
                                  0.16415034176519189,
                                  0.31251412064634648,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31357608065358666,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.86983404257684005,
                                  0,
                                  0,
                                  0,
                                  0.36451281754683595,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20097242873299825,
                                  0,
                                  0,
                                  0.074178890795349894,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.11114283086705443,
                                  -0.39200788539592318,
                                  -0.013011068484059529,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08131083901528563,
                                  0,
                                  0,
                                  0,
                                  0.1824577668266657,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14541088892268861,
                                  0,
                                  0,
                                  0,
                                  -0.62534001506725867,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.06122276740265982,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0099463973589597569,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40050709050718092,
                                  0,
                                  0,
                                  0.32588547836747656,
                                  0.32582063920739085,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28681485825172648,
                                  0.15735263853456932,
                                  0.42442495720805085,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.086041936506312505,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26560199309459692,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13688852739311572,
                                  0,
                                  -0.22973182813740481,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11154845531406436,
                                  0,
                                  0,
                                  0.087241797074741528,
                                  0.33249935415036475,
                                  0,
                                  0.07008303165197137,
                                  0,
                                  0,
                                  0.096999990836213509,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.16984269170763874,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.071625814341663777,
                                  0,
                                  0,
                                  0,
                                  0.41114641070726415,
                                  -0.20013343609869605,
                                  0.23227182232658633,
                                  0,
                                  0,
                                  0,
                                  0.099267410236132697,
                                  0.26292756026978081,
                                  0,
                                  0,
                                  0.015633337321628717,
                                  0.083689713604223032,
                                  0,
                                  0.19678930548678381,
                                  0,
                                  0,
                                  0.31831001620714905,
                                  0,
                                  0.2097881359777484,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18019033496067924,
                                  0,
                                  0,
                                  0,
                                  0.042620748659060216,
                                  0,
                                  -0.082124594588702804,
                                  0.0685895058170575,
                                  0.20838283273351804,
                                  0.11620377201719839,
                                  0.032276417511586476,
                                  0.092579618592943475,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15956046785593839,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.089237208581633184,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18803101267147143,
                                  0,
                                  0,
                                  -0.18369903443820784,
                                  0,
                                  0.20731233866340634,
                                  -0.2354578121542257,
                                  -0.21057091165986683,
                                  0,
                                  0,
                                  0.13006685770564819,
                                  0,
                                  0,
                                  0,
                                  -0.047929850062241507,
                                  0,
                                  -0.076536542933716256,
                                  0,
                                  0,
                                  -0.26764206016336656,
                                  -0.13957922994053223,
                                  0,
                                  0,
                                  0.2807954891292001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19196514599815107,
                                  0,
                                  0.42368675121401705,
                                  0,
                                  0.075169869315277207,
                                  0,
                                  0,
                                  0,
                                  0.0078539828764860493,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1083861507966314,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33378766907155283,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23675582189751943,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25175697398924873,
                                  -0.35838098805816926,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28081644322904509,
                                  0,
                                  0,
                                  0,
                                  -0.3070087526114767,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.43028907623533558,
                                  0,
                                  0,
                                  0.42914458563745106,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.069790122209238109,
                                  0.090959788808982922,
                                  0.022524631701284215,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063026558777313238,
                                  0,
                                  0,
                                  0,
                                  0.30213724046275858,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.33678790319526597,
                                  0,
                                  0,
                                  0,
                                  -0.51163961073917985,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.058807845026655835,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.72361188262856613,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24633929235062924,
                                  0,
                                  0,
                                  -0.0037700201229823229,
                                  0.069715535223018432,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13947252360471168,
                                  -0.34499282165926087,
                                  -0.01210613623390959,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.030962273385165412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.020515438037014951,
                                  0,
                                  0,
                                  0,
                                  0.47707676802735915,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18585500875631375,
                                  0,
                                  0,
                                  0.20923345424810358,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36312665100899294,
                                  0.41720038327156,
                                  -0.17699783437789174,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.94794007567214678,
                                  0,
                                  0,
                                  0,
                                  -0.82501590041436235,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.149532630900024,
                                  0,
                                  0,
                                  0,
                                  0.13833749574789342,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.19060698169352691,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26425811399614552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28250677190690127,
                                  0,
                                  0,
                                  0.040369943611388515,
                                  0.14577261364744365,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.031822672706629057,
                                  -0.22440979071866768,
                                  0.070141427722925268,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.032400279333227144,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24199274986330865,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1626938672366634,
                                  0,
                                  0.01933681436377193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.030134249824643931,
                                  0,
                                  0,
                                  0.37783966429097338,
                                  -0.21548217107577844,
                                  0,
                                  -0.28947036069766191,
                                  0,
                                  0,
                                  0.072265136491037191,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.070610270494166807,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049447419319722227,
                                  0,
                                  0,
                                  0,
                                  0.33090220907574824,
                                  0.018644953605057732,
                                  -0.15297262746997556,
                                  0,
                                  0,
                                  0,
                                  0.18556322512751577,
                                  0.0023106323228559364,
                                  0,
                                  0,
                                  -0.055669622075673587,
                                  -0.027298449073786424,
                                  0,
                                  0.087906270456810931,
                                  0,
                                  0,
                                  -0.088387391835833676,
                                  0,
                                  -0.35325291592933022,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24663429262827777,
                                  0,
                                  0,
                                  0,
                                  0.17618565305097994,
                                  0,
                                  0.19746465305045383,
                                  -0.054320384606705005,
                                  0.14796606251988917,
                                  0.1645390774538199,
                                  -0.33991269831697829,
                                  -0.090273310722458922,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08546919545873799,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.049157736377593568,
                                  0,
                                  0,
                                  0,
                                  0.16314515509306277,
                                  0,
                                  0,
                                  -0.43044642660068505,
                                  0,
                                  0,
                                  0.32145650806921128,
                                  0,
                                  0,
                                  0,
                                  0.28197453731223115,
                                  0,
                                  0,
                                  0,
                                  -0.1618429236046319,
                                  0,
                                  0,
                                  -0.16185497655310843,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.45027811711793048,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12988324085039546,
                                  0.51674973894677534,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.47913077141232685,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12176517640096476,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15331065818077444,
                                  0,
                                  -0.0068903036767039155,
                                  0,
                                  0.38589995425101165,
                                  0,
                                  0,
                                  0.1068215234251387,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.26267796097914559,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36032503772037505,
                                  0,
                                  0.085272225099164309,
                                  -0.14780623612504698,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.33268712378661203,
                                  0,
                                  0.49265448803601719,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033816920985214272,
                                  0,
                                  -0.15924059527316875,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.072551769929872417,
                                  0,
                                  0,
                                  0.0077387608161498672,
                                  0.055887823919346505,
                                  0,
                                  -0.29784407166999011,
                                  0,
                                  0,
                                  0.26990186875328737,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21991808689973394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25049070737558804,
                                  0,
                                  0,
                                  0,
                                  -0.13913091071749284,
                                  -0.1168097609644132,
                                  0.088068585427541729,
                                  0,
                                  0,
                                  0,
                                  0.077229787668231215,
                                  -0.20655093631044102,
                                  0,
                                  0,
                                  -0.12571839602031684,
                                  -0.093353040987756347,
                                  0,
                                  0.033903733259466454,
                                  0,
                                  0,
                                  0.13348172836485986,
                                  0,
                                  -0.014015745119734468,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0086627240643842654,
                                  0,
                                  0,
                                  0,
                                  0.034587706268951385,
                                  0,
                                  -0.27289000408611963,
                                  0.0047170339910184711,
                                  0.0035594263517090899,
                                  0.42466008803644018,
                                  -0.16162628564453377,
                                  -0.054021826331784296,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.17284265681806227,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.039740487852769957,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.06609901943357338,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14036789621663703,
                                  0,
                                  0.0097194596193652394,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35633864067644272,
                                  0,
                                  0,
                                  0.24807692988588517,
                                  -0.14258920005660053,
                                  0,
                                  0.041015735440935064,
                                  0,
                                  0,
                                  0.25708628129194316,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.27290698106956979,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.048915571155297766,
                                  0,
                                  0,
                                  0,
                                  0.025293935616976113,
                                  0.089150082790656754,
                                  0.099635652383063142,
                                  0,
                                  0,
                                  0,
                                  0.32354449436848998,
                                  -0.14713023809654668,
                                  0,
                                  0,
                                  -0.044353318334491465,
                                  -0.0038777665187204741,
                                  0,
                                  -0.14263358550214891,
                                  0,
                                  0,
                                  0.14766880013762351,
                                  0,
                                  0.25488528165873625,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15822443659314739,
                                  0,
                                  0,
                                  0,
                                  -0.24176561658823578,
                                  0,
                                  0.090779716467330157,
                                  -0.16621492800670801,
                                  0.15264703389970358,
                                  -0.13492061976777825,
                                  -0.083306735345974908,
                                  0.084357418950983531,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27390077065999141,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.34417564714680393,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.063238293744674046,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.26002300547803459,
                                  0,
                                  -0.20481385491170856,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24352030271800115,
                                  0,
                                  0,
                                  0.03279040065082077,
                                  -0.050009455812597678,
                                  0,
                                  0.38796835994710643,
                                  0,
                                  0,
                                  0.15840740103907069,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019124570187982311,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10100010720216643,
                                  0,
                                  0,
                                  0,
                                  -0.16161851582961245,
                                  0.15736707442531092,
                                  0.352965528376741,
                                  0,
                                  0,
                                  0,
                                  -0.075126814420552912,
                                  0.13166882819327855,
                                  0,
                                  0,
                                  -0.030046556922715281,
                                  -0.21373794500441015,
                                  0,
                                  0.15413604140293902,
                                  0,
                                  0,
                                  0.076957748705027737,
                                  0,
                                  0.10218373929917175,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.36873874296443154,
                                  0,
                                  0,
                                  0,
                                  0.32534599174568607,
                                  0,
                                  0.023657646264010825,
                                  0.17331656282362243,
                                  0.015948291836113251,
                                  -0.17266996036695872,
                                  -0.19353150280709336,
                                  -0.10319678514046654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.039904460077722193,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.0064517001569784488,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.021882112551632152,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28159488387667292,
                                  0,
                                  0.1047312479628725,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.010252502289898815,
                                  0,
                                  0,
                                  -0.026192961916260946,
                                  0.10543753540694054,
                                  0,
                                  0.10340643422537121,
                                  0,
                                  0,
                                  -0.11272488019202462,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10337072848999813,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.046149103824503782,
                                  0,
                                  0,
                                  0,
                                  -0.16169910452349168,
                                  -0.13329529038162832,
                                  -0.03553116016840014,
                                  0,
                                  0,
                                  0,
                                  -0.16314924698075606,
                                  0.2504843957237905,
                                  0,
                                  0,
                                  0.085602496101243222,
                                  0.0080715942467397377,
                                  0,
                                  -0.38180334119567821,
                                  0,
                                  0,
                                  0.06323151757736048,
                                  0,
                                  0.064346470725052701,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.025774075723639704,
                                  0,
                                  0,
                                  0,
                                  -0.23210482464706916,
                                  0,
                                  -0.067852728886595423,
                                  -0.11916675349119858,
                                  0.36613562423221768,
                                  0.28194084519515916,
                                  -0.13671256190366274,
                                  -0.41765995155004615,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.19344173097820075,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21875528740489938,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12272656880742985,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.076176129997451353,
                                  0,
                                  0.24960097304772583,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12165678688372293,
                                  0,
                                  0,
                                  -0.056702481531400575,
                                  0.2973445892629768,
                                  0,
                                  0.10415014214613647,
                                  0,
                                  0,
                                  -0.056582523839097183,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14571042200216436,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.25825508667166164,
                                  0,
                                  0,
                                  0,
                                  0.086216378119897602,
                                  0.15852499033489906,
                                  0.1777386915612203,
                                  0,
                                  0,
                                  0,
                                  0.075657710842305589,
                                  -0.42191903538041664,
                                  0,
                                  0,
                                  0.095646912641142445,
                                  -0.10559679553011722,
                                  0,
                                  -0.050929320186548131,
                                  0,
                                  0,
                                  -0.23528785483093445,
                                  0,
                                  0.057669974720752117,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.22137909828480959,
                                  0,
                                  0,
                                  0,
                                  0.13168661880896315,
                                  0,
                                  -0.058816835411934221,
                                  -0.098760846281877077,
                                  0.40423821403005589,
                                  0.14240738302793737,
                                  0.27922148813608699,
                                  0.16505009360552941,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098986862559293079,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.026456078226913669,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27213285854983449,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29666717972082013,
                                  0,
                                  -0.27008759613102001,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.042896493228922784,
                                  0,
                                  0,
                                  -0.29622019518064613,
                                  -0.045207030113014419,
                                  0,
                                  0.077188628033754994,
                                  0,
                                  0,
                                  -0.38465303579224774,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2798850732069495,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.035421242808338041,
                                  0,
                                  0,
                                  0,
                                  0.17822000120417619,
                                  -0.14578577525131056,
                                  -0.11877838453177297,
                                  0,
                                  0,
                                  0,
                                  0.088428034862939695,
                                  -0.015261901285912568,
                                  0,
                                  0,
                                  0.18056514905481327,
                                  -0.015580556574223282,
                                  0,
                                  0.38590127058799473,
                                  0,
                                  0,
                                  -0.025695497138202406,
                                  0,
                                  0.013213842115733893,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21142029726993983,
                                  0,
                                  0,
                                  0,
                                  -0.088168854294696744,
                                  0,
                                  0.13505135650119404,
                                  -0.038246664554154319,
                                  0.15057039483897977,
                                  0.071452893138302095,
                                  -0.090421362442544437,
                                  -0.21699774892288007,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.15643217258541806,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.04883284584776424,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32899093480466285,
                                  0,
                                  0,
                                  0,
                                  0.5501325971386497,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28037497417547308,
                                  0,
                                  0,
                                  -0.39402665459423031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.5464914518206454,
                                  0.33233730368934217,
                                  0.54732406144572976,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.095098045596841332,
                                  0,
                                  0,
                                  0,
                                  0.41672354137757617,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.098674172336530072,
                                  0,
                                  0,
                                  0,
                                  -0.46803446098672769,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.20418403788817968,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.098778482264036363,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11740828246363275,
                                  0,
                                  0,
                                  -0.17037547239117748,
                                  0.29172475388825758,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.34729589834336622,
                                  0.1529447170042362,
                                  -0.26422257536756072,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0014401762313646649,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2954828009151691,
                                  0,
                                  0,
                                  0,
                                  0.28787439940205412,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.39774567270498057,
                                  0,
                                  0,
                                  0.017515288263378677,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.18500174178653728,
                                  0.0014148358979809783,
                                  -0.035434037449985654,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.41468321062664032,
                                  0,
                                  0,
                                  0,
                                  0.54245373003634934,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.23741716021966475,
                                  0,
                                  0,
                                  0,
                                  0.76274849577916015,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18527966015598671,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.029403379992473031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.53362047226282372,
                                  0,
                                  0,
                                  -0.073296474470668185,
                                  -0.023147472259021133,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1645707716118209,
                                  -0.11845188816383123,
                                  0.67034501302432881,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14407136220211486,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.46460539011356961,
                                  0,
                                  0,
                                  0,
                                  -0.14544865583339603,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.12143229715093,
                                  0,
                                  0,
                                  0.31714588049704717,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.070667500517365534,
                                  -0.27340561936550312,
                                  0.60412448018243525,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.24838227711659872,
                                  0,
                                  0,
                                  0,
                                  -0.037588624494676225,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.015479756772388081,
                                  0,
                                  0,
                                  0,
                                  -0.33018407186079157,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.66183611849244584,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.21368420332239585,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.13971603147611286,
                                  0,
                                  0,
                                  0.048706379585138182,
                                  0.52345849727145577,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.7651796439418912,
                                  0.040454455309891904,
                                  0.18050693009144259,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25906878716620879,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1771279736211053,
                                  0,
                                  0,
                                  0.090005694411120288,
                                  0,
                                  0,
                                  0.5298388534983054,
                                  0,
                                  0,
                                  0,
                                  0.3973509710367169,
                                  0,
                                  0,
                                  0,
                                  0.17960739553989388,
                                  0,
                                  0,
                                  0.39758984150625543,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1466529535580787,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28220723767049688,
                                  -0.12920423999315483,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.35541366086051018,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.1300211680945364,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.70265368283871166,
                                  0,
                                  0.16129845723274458,
                                  0,
                                  0.09306750303973696,
                                  0,
                                  0,
                                  0.22280776710817735,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.4135092471760789,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11191027579467618,
                                  0,
                                  0.18344634240566113,
                                  0.23268038389800749,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13341396702139777,
                                  0,
                                  -0.018890113073390561,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11663208311632908,
                                  0,
                                  -0.0033870659681579634,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40779918736061904,
                                  0,
                                  0,
                                  0.0092687869132547611,
                                  0.061218004221935227,
                                  0,
                                  -0.0076848150049589545,
                                  0,
                                  0,
                                  -0.24237966363857008,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.24036179909315758,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.20163159444639847,
                                  0,
                                  0,
                                  0,
                                  -0.059870283528966797,
                                  0.2781011587041417,
                                  -0.32396750562649967,
                                  0,
                                  0,
                                  0,
                                  0.18006770102612479,
                                  0.10802052674036813,
                                  0,
                                  0,
                                  -0.15063711203707267,
                                  0.40533442324758401,
                                  0,
                                  -0.07334353334026561,
                                  0,
                                  0,
                                  -0.14319018043976056,
                                  0,
                                  0.21179348833697723,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.085685685208154616,
                                  0,
                                  0,
                                  0,
                                  0.24022660829450815,
                                  0,
                                  -0.14856317705631103,
                                  0.1659379148577565,
                                  0.0098571562498085286,
                                  0.17173331982281953,
                                  0.013595898130528253,
                                  0.012242909956253469,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.056812871536588594,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15215282010289197,
                                  0,
                                  0,
                                  0,
                                  -0.5275436280747281,
                                  0,
                                  0,
                                  -0.35298647854959542,
                                  0,
                                  0,
                                  -0.60374538863299587,
                                  0,
                                  0,
                                  0,
                                  -0.074735334994592201,
                                  0,
                                  0,
                                  0,
                                  0.23635325375942595,
                                  0,
                                  0,
                                  0.16767142159745355,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.13831678313631829,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.026169835104324402,
                                  -0.5188153377523631,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.050786428914905063,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0079039133700268271,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.03802941934604661,
                                  0,
                                  0.28804412464424545,
                                  0,
                                  0.21616895249810672,
                                  0,
                                  0,
                                  -0.087493316596868542,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23529231404757728,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.051629282252780226,
                                  0,
                                  0.11628145565964779,
                                  -0.26847009545674116,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.51559036993823371,
                                  -0.12597858867154066,
                                  0,
                                  0,
                                  -0.061498696548874174,
                                  0,
                                  0,
                                  -0.21743633929095044,
                                  0,
                                  0,
                                  0,
                                  0.061408789828928091,
                                  0,
                                  0,
                                  0,
                                  -0.4262116710559265,
                                  0,
                                  0,
                                  0.040664914787468823,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.40621055751687729,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.63628759943181656,
                                  0.061265360965779926,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.076570196842555935,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.10956719047888952,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.48078107629103306,
                                  0,
                                  -0.049262699172892194,
                                  0,
                                  0.39846236924141387,
                                  0,
                                  0,
                                  -0.24665027751130369,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.41194219171353397,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.53958030344634411,
                                  0,
                                  0.23318851520844458,
                                  0.41387858871821248,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37282037929518036,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.16476404531629241,
                                  0,
                                  0,
                                  0,
                                  -0.31467460693632282,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29498808599275766,
                                  0,
                                  0,
                                  -0.067636928124122031,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.49380803194735368,
                                  0.014305769192500192,
                                  0.23810630231097124,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.2607857048694826,
                                  0,
                                  0,
                                  0,
                                  -0.50256987746474402,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.54857130126721176,
                                  0,
                                  0,
                                  0,
                                  0.23681956068428778,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.019575198382174683,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15963307795949896,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.3475031244564597,
                                  0,
                                  0,
                                  0.62696304411285375,
                                  0.041364650781550376,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0033344889581419959,
                                  0.64933923359521961,
                                  0.20202934049821764,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.11938659054317372,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.063027782450342629,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.08748609961565415,
                                  -0.3688997152352243,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.28062069360325614,
                                  0,
                                  0.29907492281666115,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.31330275887980608,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.0073724037741397519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.68438846979602497,
                                  -0.33057364790987009,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.090627880011341644,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.18880023209012509,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.10472051907239512,
                                  0,
                                  0.30636058466741273,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.051028332528498754,
                                  0,
                                  0,
                                  0.045921166397022331,
                                  0.18043202418044477,
                                  0,
                                  -0.098416063696552911,
                                  0,
                                  0,
                                  0.11735700082431565,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.033530141174194519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.37642587602419258,
                                  0,
                                  0,
                                  0,
                                  0.2847250978789157,
                                  0.081715731657851787,
                                  -0.11334114285509313,
                                  0,
                                  0,
                                  0,
                                  -0.021809097976264943,
                                  -0.090153301503457267,
                                  0,
                                  0,
                                  -0.029574856496256911,
                                  0.099203746746477348,
                                  0,
                                  0.2488345836832567,
                                  0,
                                  0,
                                  0.13880765671415191,
                                  0,
                                  0.07554761143265426,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.28158478033233336,
                                  0,
                                  0,
                                  0,
                                  -0.012158249810483773,
                                  0,
                                  -0.44792135894228841,
                                  -0.13789690440493466,
                                  -0.053432403779443423,
                                  -0.26792603012864946,
                                  0.076052095967612532,
                                  -0.25004580989558101,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059774824736621747,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.059771623818131114,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.094528326604865501,
                                  0,
                                  0,
                                  -0.14909812864871988,
                                  0,
                                  -0.29392110521750625,
                                  -0.11596712272695418,
                                  0.21022024311918711,
                                  0,
                                  0,
                                  -0.41408699943467853,
                                  0,
                                  0,
                                  0,
                                  0.098177107488487431,
                                  0,
                                  0.17889130368977138,
                                  0,
                                  0,
                                  -0.058545867286448575,
                                  -0.28728182066123215,
                                  0,
                                  0,
                                  0.15659123113290357,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.21417960976693207,
                                  0,
                                  0.068920356755075934,
                                  0,
                                  0.33969788758892827,
                                  0,
                                  0,
                                  0,
                                  -0.26802132622306413,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.14902996653056519,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.27742116080315898,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.15217450293573598,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.23338639718605128,
                                  0.29421711772646508,
                                  0,
                                  0,
                                  0,
                                  -0.073860082638237984,
                                  0,
                                  0,
                                  0.12762129202563391,
                                  0,
                                  0.032302100806219897,
                                  -0.34001645849251411,
                                  -0.20271421457259001,
                                  0,
                                  0,
                                  -0.23857661796176194,
                                  0,
                                  0,
                                  0,
                                  -0.16071535058791284,
                                  0,
                                  0.13307511759194915,
                                  0,
                                  0,
                                  0.36729193667866072,
                                  0.033072681344091512,
                                  0,
                                  0,
                                  0.22353985439454196,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.2271305701318958,
                                  0,
                                  -0.16356602826931302,
                                  0,
                                  -0.19120914130004632,
                                  0,
                                  0,
                                  0,
                                  0.073234686918077579,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32497135504017044,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.1630721708198295,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32819005843202931,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.012256835209851652,
                                  0.41684663720834136,
                                  0,
                                  -0.11951360353108671,
                                  0,
                                  0,
                                  0.51407502112023051,
                                  0,
                                  0,
                                  0.55999697507623458,
                                  0,
                                  0,
                                  0,
                                  -0.60579350271033294,
                                  0,
                                  0,
                                  0,
                                  -0.28377530598137179,
                                  0,
                                  0,
                                  0.27635452644328051,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.29841407893717709,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.60970290940093985,
                                  0.067924376518118043,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.32155633407116674,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.010788106476061082,
                                  0,
                                  0,
                                  0,
                                  0,
                                  -0.091119258982718193,
                                  0,
                                  -0.25300821766609555,
                                  0,
                                  -0.0110866001449627,
                                  0,
                                  0,
                                  -0.03356399704325861,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.25330494441403967,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.051155367999532041,
                                  0,
                                  0.49996023533676193,
                                  0.35059007666229552,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0,
                                  0.14747922864050481};

const double rot_22_30[900] = {0.49242419016938427,
                               0,
                               -0.33744938049742668,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.93587267859525236,
                               0,
                               0,
                               0,
                               0.20922795147624737,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.27323734370344371,
                               0,
                               0,
                               0,
                               0.26972893965343464,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.33018300924412841,
                               0,
                               0,
                               0,
                               -0.086315051860842568,
                               0,
                               0,
                               0,
                               0,
                               0.20672510236374836,
                               0,
                               0,
                               0,
                               -0.2631267102956546,
                               0,
                               0,
                               0,
                               0,
                               0.11837705686899748,
                               0,
                               0,
                               0,
                               0,
                               0,
                               1.365009303075307,
                               0,
                               0,
                               0,
                               0,
                               -0.34273989982565639,
                               0,
                               0.093809138948486082,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.60900135212433348,
                               0,
                               0,
                               0,
                               -0.80061719561929723,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.25712250458949165,
                               0,
                               0,
                               0,
                               -0.16704266759358499,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.91119236686729344,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36253595492015139,
                               0,
                               -0.19569402635980726,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.58460821421207854,
                               0,
                               -0.4957102348671848,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.22230625486043012,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.24591014974208295,
                               0,
                               0.54715268613475965,
                               0.056891689049967165,
                               0,
                               -0.64659270309337524,
                               0,
                               0,
                               0,
                               0.12295274775670478,
                               0,
                               0,
                               0,
                               0,
                               -1.4703225039383712,
                               0,
                               0,
                               0,
                               0.43389590772576814,
                               0,
                               0,
                               0,
                               0,
                               -0.91932336722347419,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32979431307859308,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.41739699823956977,
                               0,
                               0.28637016712809615,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.57167674312363748,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50049999477491047,
                               0,
                               -0.21523504696775939,
                               0.346599487013865,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.15723529014622811,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.072284255992455984,
                               0,
                               0.7179729081792815,
                               0,
                               0.17315500411228441,
                               0.079908602457554767,
                               0,
                               0,
                               -0.0019382251296811443,
                               0.047127345496138971,
                               0.30425491808941701,
                               0,
                               0,
                               0,
                               -0.56868542640129749,
                               0,
                               0,
                               0.3015031629408611,
                               0,
                               0.86508827559119994,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.31353199910173901,
                               0,
                               0,
                               0,
                               0.32870845783901947,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.51576277741919596,
                               0,
                               0,
                               0,
                               0.20212093944063581,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.34629148796327391,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.41665571788136957,
                               0,
                               0.84052377605927642,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.6198081424101014,
                               0,
                               0,
                               0,
                               0.83635193503324157,
                               0,
                               0,
                               0,
                               0,
                               0.34088331713861997,
                               0,
                               0,
                               0,
                               0.60796180912814102,
                               0,
                               0,
                               0,
                               0,
                               0.6375945266620191,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.32377733254214769,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.22318305474870165,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.83364602448934755,
                               0,
                               0.50519662501460016,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20419182145923909,
                               0,
                               -0.23306802070678767,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.091214835199555241,
                               0,
                               0,
                               0,
                               -0.29494368833968976,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.57230288664282425,
                               0,
                               0,
                               0,
                               0.80905861227804321,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.079063322544451586,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.060726175595040927,
                               0,
                               0.35073167939768979,
                               0,
                               -0.11962277140826597,
                               -0.4957981833543777,
                               0,
                               0,
                               -0.17307847024693396,
                               -0.55273979226944259,
                               -0.51920249671346397,
                               0,
                               0,
                               0,
                               0.043295475759384701,
                               0,
                               0,
                               0,
                               0.65358916983275372,
                               0,
                               0,
                               0,
                               -0.31210126461449933,
                               0,
                               0,
                               0,
                               0,
                               0.76673062559730354,
                               0,
                               0,
                               0,
                               0.54374896161243802,
                               0,
                               0,
                               0,
                               0,
                               -0.66647352879197619,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.76688464257499411,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.10965555868800572,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.49370604808869989,
                               0,
                               0.061686766687579157,
                               0,
                               -0.50224392118828209,
                               0.45749071267606861,
                               0,
                               0,
                               -0.0091336313824589184,
                               -0.41964715674531833,
                               0.26034013862780503,
                               0,
                               0,
                               0,
                               0.18685257189091031,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.36756422086000223,
                               0,
                               -0.28708741692901563,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.079658470279241833,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.57801124728685882,
                               0,
                               -0.47389505959509193,
                               0.46632430474791958,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.2517522904425914,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.34704930493420461,
                               0,
                               0.1087360813739451,
                               0,
                               0.66707823735907612,
                               0.40803455299083802,
                               0,
                               0,
                               -0.24189989367337017,
                               -0.074988623926307729,
                               -0.28947965075347704,
                               0,
                               0,
                               0,
                               0.21196966089184094,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.5521440074255447,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.30612029033009858,
                               0,
                               -0.24675595785029433,
                               0,
                               -0.017378563320587119,
                               0.18598547875393448,
                               0,
                               0,
                               -0.050438416270717469,
                               -0.50441463512346996,
                               0.052286890245977269,
                               0,
                               0,
                               0,
                               -0.49591750377760185,
                               0,
                               0,
                               0,
                               0.6769121410919251,
                               0,
                               0,
                               0,
                               0.78888567122482434,
                               0,
                               0,
                               0,
                               0,
                               -0.079092865627854114,
                               0,
                               0,
                               0,
                               -0.25371751386004693,
                               0,
                               0,
                               0,
                               0,
                               -0.12006693102797979,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.33567638120519094,
                               0,
                               0,
                               0,
                               0,
                               0.57185224675550839,
                               0,
                               0.42615189776711648,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.90874152026466493,
                               0,
                               0,
                               0,
                               -1.0714199621718301,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -1.0024246871956251,
                               0,
                               0,
                               0,
                               -0.1938005320158277,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.074740962725790033,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.092715638054593458,
                               0,
                               -0.0024838091093668906,
                               0,
                               -0.06878498814539992,
                               -0.16798714346740634,
                               0,
                               0,
                               -0.88847459413868246,
                               0.079711110970381319,
                               0.37450550497122481,
                               0,
                               0,
                               0,
                               0.12986545261529991,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.036749477504581546,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.65833186447031089,
                               0,
                               -0.38187923118295708,
                               0,
                               0.20922921129333369,
                               -0.47935039756750852,
                               0,
                               0,
                               0.060745587144903128,
                               -0.051166862497014264,
                               0.23283362637530705,
                               0,
                               0,
                               0,
                               -0.29213634944028205,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.75520274338603355,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.20925811831369343,
                               0,
                               -0.334800164326301,
                               0,
                               0.31024297564182951,
                               0.16886150349204507,
                               0,
                               0,
                               -0.13851512230431903,
                               -0.33192842865729577,
                               0.019599054437818647,
                               0,
                               0,
                               0,
                               -0.13884074034546912,
                               0,
                               0,
                               0.60583909845949346,
                               0,
                               -0.26426502514331762,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.15759889501826682,
                               0,
                               0,
                               0,
                               -0.24900499140737137,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.47350498496644244,
                               0,
                               0,
                               0,
                               -0.61733353969609583,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.45251097678291879,
                               0,
                               0,
                               0,
                               -0.41645380432352663,
                               0,
                               0,
                               0,
                               0,
                               -0.70144664371648968,
                               0,
                               0,
                               0,
                               0.51973689711713544,
                               0,
                               0,
                               0,
                               0,
                               1.3768588671195559,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.068070874233287837,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.25717195883441063,
                               0,
                               -0.29706288406168641,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.50546553845118336,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.19736223663001717,
                               0,
                               -0.17481639246287992,
                               -0.72153183742586324,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.10719875515519552,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.21772186479484673,
                               0,
                               0.16448656579313792,
                               0,
                               0.33675577223268183,
                               -0.22562698936318615,
                               0,
                               0,
                               0.31085929438985022,
                               -0.37006511664579589,
                               0.53730656388371734,
                               0,
                               0,
                               0,
                               0.47692532186573594,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.47231616781949115,
                               0,
                               -0.70354010108677767,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.14071794823986411,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.395844217112161,
                               0,
                               -0.27193501024156419,
                               0.17749909522603372,
                               0,
                               0,
                               0,
                               0,
                               -0.24431444182758141,
                               0,
                               0.081420357059717757,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0.58491299097871785,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -0.39910707188082778,
                               0,
                               -0.57027349950252204,
                               -0.32719971408137555};

const double rot_22_2[4] = {0.96975123086048387, -0.24409537120678149, 0.24409537120678099, 0.96975123086048387};

const double rot_23_50[25000] = {-0.27552300140840374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0507181916934831,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50531367435415264,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63016142780758821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19921708351547499,
                                 0,
                                 0.5832361966686026,
                                 0,
                                 0,
                                 0,
                                 -0.29699930061658109,
                                 0,
                                 0,
                                 -0.0098712113336424517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23688511609357196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18059804094910825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77490885686764943,
                                 0,
                                 0.20054748303311717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.013652445050786916,
                                 0,
                                 0.51998112534972596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11775296360491332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17936112878084101,
                                 0,
                                 0,
                                 0.49372693257409928,
                                 -0.00075904714668308115,
                                 0.61186275247200139,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02998395177934482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21946010734368621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53549898319315015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076229125910206585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26946853198606319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39619126845410801,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.152375311742495,
                                 -0.097172294413192528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6456767310314413,
                                 0,
                                 0,
                                 0.14480803293563432,
                                 0,
                                 0,
                                 0,
                                 -0.33178681919673036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26640148399934804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33619572801412684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68859813457790331,
                                 0,
                                 0,
                                 0,
                                 0.24506181198239435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68363758769651917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047915423761768043,
                                 0.15607608829988656,
                                 0,
                                 0,
                                 0,
                                 0.51579189237051681,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62861011692482593,
                                 0,
                                 0.19423623792451372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88203795881336422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57315879426824001,
                                 -0.44614523164751529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37723158237881527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.127045124919623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59655972812045799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032432788634862104,
                                 0,
                                 -0.51554774459777375,
                                 0,
                                 0,
                                 0,
                                 -0.0087221243468474652,
                                 0,
                                 0,
                                 -0.69320558976902058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86752190103781102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069286884992563968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26761344230074652,
                                 0,
                                 -0.32181875237800678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23847543296049098,
                                 0,
                                 0.10271456946259007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11265088757361807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33698461047101436,
                                 0,
                                 0,
                                 -0.46961129286611891,
                                 0.6125579828706792,
                                 0.060463476516490741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1374021123484529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11479930603551919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49221443287666772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92069088458850246,
                                 0,
                                 0,
                                 0,
                                 -0.24357428471102047,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6688166072640348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.017988335766523381,
                                 -0.40512023707513156,
                                 0,
                                 0,
                                 0,
                                 -0.042192638626776649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30321401245632373,
                                 0,
                                 -0.34203551242322477,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49752043692173431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41388808122856574,
                                 0,
                                 0,
                                 0,
                                 -0.16303694745891861,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24769471024423129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14885601564459239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11162022626680733,
                                 -0.16752285020049129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023363589127538595,
                                 0,
                                 0,
                                 0.23701118316427094,
                                 0,
                                 0,
                                 0,
                                 -0.17855586244671645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53025897913607534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69253754513758981,
                                 0,
                                 0,
                                 0,
                                 -0.0056912418674852361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15350310557035435,
                                 0,
                                 0,
                                 -0.068642542382577665,
                                 0.061588992557226122,
                                 -0.45034839311126973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55656191293914492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59715322432965789,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31421742834797128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26458358684255023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50793421107787018,
                                 0,
                                 0,
                                 0.036237632683811243,
                                 -0.14748997643202283,
                                 -0.48855148544644666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44228722890263561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26489005727463161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38008500943148005,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2539304302512338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68143732713889704,
                                 0,
                                 0,
                                 0.11458282936689933,
                                 -0.56526014018622128,
                                 -0.16603931795681809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078016941398887873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10927054248964703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30482536836090901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64743647900026946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4177733687570761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18404968378741376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51600202707389187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046306671969770771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11685544381747384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6252231772850787,
                                 0,
                                 0.5579169978771088,
                                 0,
                                 0,
                                 0,
                                 0.52447918589113718,
                                 0,
                                 0,
                                 -0.42854780305908247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23700942108221495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24096973804756988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40840680987407596,
                                 0,
                                 -0.37162405084617128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50198043264575243,
                                 0,
                                 0.57347642269365118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1217986221218131,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32208953329784573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40846496338271171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50348166560709962,
                                 0.034992815651224807,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16646153100367733,
                                 0,
                                 0,
                                 0.65151293644754649,
                                 0,
                                 0,
                                 0,
                                 -0.044984791186149897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069973780108589623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.027622601704335753,
                                 0,
                                 0,
                                 0.32189055761813845,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25994291189302565,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31997381769507355,
                                 0,
                                 -0.81461901250714153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11624306617962904,
                                 0,
                                 -0.22207278421622509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91475947176554451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066378396026001624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.063348156230373875,
                                 0.4191822111212043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61935856945460066,
                                 0,
                                 0,
                                 0.83303802793369197,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38341235427778164,
                                 0,
                                 0,
                                 0,
                                 -0.54402537301424503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75175532854909133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73277142796302397,
                                 -0.31293617237278687,
                                 0,
                                 0,
                                 0,
                                 0.055890577465900496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14356749323736515,
                                 0,
                                 -0.10132855640461373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43694240569340459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7247339989461109,
                                 -0.49064767434643453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089373942266897377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86399498360661164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66888232878840381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31786791511179185,
                                 0,
                                 -0.47537853695488502,
                                 0,
                                 0,
                                 0,
                                 -0.52772990066283409,
                                 0,
                                 0,
                                 0.19248390902600951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21423512935606309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25909770358135537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12806795714675442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50689895846608768,
                                 -0.30163679969370161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31039175019021348,
                                 0,
                                 0,
                                 -0.027605194630950555,
                                 0,
                                 0,
                                 0,
                                 0.61563434608355538,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21495695511509577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01793735461600135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21162920397040705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79275296971832865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12083777307446671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24501624798468094,
                                 -0.14376459920753124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.036584880200895419,
                                 0,
                                 0,
                                 -0.039953604882356143,
                                 0,
                                 0,
                                 0,
                                 0.31434769750622665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.060808992577883865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35497305159409065,
                                 0,
                                 0,
                                 0,
                                 -0.673088481054124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25094885537128209,
                                 0,
                                 0,
                                 0.4888203203150846,
                                 0.22920054662563702,
                                 -0.32694956905239714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25933517631804354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.014939333029889354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13462701988386783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033804944371626892,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1075661624149071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5973891516166383,
                                 0.19985303361054216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22645975894896583,
                                 0,
                                 0,
                                 -0.3821198649283154,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39386643484154837,
                                 0,
                                 0,
                                 0,
                                 0.63118972163215759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14783260075237636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087618356226792204,
                                 0.62011898787545805,
                                 0,
                                 0,
                                 0,
                                 -0.26963107448535012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71991972586565645,
                                 0,
                                 -0.69507705513656026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71528211178602574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35907231805154094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0084996313360312867,
                                 0,
                                 0,
                                 0,
                                 -0.56290103752016662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15803586397763886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49081990323158231,
                                 0.48245415146530679,
                                 0,
                                 0,
                                 0,
                                 0.68574233137116258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58860477005824896,
                                 0,
                                 0.76032163738788316,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30025521484214635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064866248301647056,
                                 0,
                                 0.0070426663545553603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88991665792342933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.031318622901045645,
                                 0,
                                 -0.18645317204505957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36188343727908723,
                                 0,
                                 -0.20320797011436925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64894511167560553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020356227534296042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3270720268569175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22434623976867854,
                                 0.31525671818233997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16012804863525848,
                                 0,
                                 0,
                                 0.01770437200869944,
                                 0,
                                 0,
                                 0,
                                 -0.37272891869369884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39559410353163132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.019640348664012028,
                                 0,
                                 0,
                                 0.17735443912756887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21212092076366157,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24028958892494712,
                                 0,
                                 0.14049925834627025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73924735457589263,
                                 0,
                                 -0.54734298068678289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18174899914712203,
                                 0,
                                 0,
                                 0,
                                 0.2212573725366091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1889524543596276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69653046580231537,
                                 0.40405439766784174,
                                 0,
                                 0,
                                 0,
                                 -0.32421956944172053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17311981235016469,
                                 0,
                                 0.56686578269116683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018026327166932699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.047745722071943428,
                                 0,
                                 0,
                                 0,
                                 0.2602464241555118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1521803123994924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078433304577532739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2413144292111308,
                                 -0.097941349428975852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42080496716011861,
                                 0,
                                 0,
                                 0.20951199878398136,
                                 0,
                                 0,
                                 0,
                                 -0.24051376863952043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6289369698343128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40094304251503043,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10830972721223826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52502031030727669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71849111629097173,
                                 -0.86531096072353364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82234694160748889,
                                 0,
                                 0,
                                 0.33629110269218065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91076227353271422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13439392994778512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12853855579391496,
                                 0.36505884032554659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5691475821332439,
                                 0,
                                 0,
                                 0.70148568599989669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43702225524831012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24840239471620992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25847520672518476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0017096717002923062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17270385262897081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098428082043843873,
                                 -0.83764089399471342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19896280250971701,
                                 0,
                                 0,
                                 -0.02862571304084853,
                                 0,
                                 0,
                                 0,
                                 -0.30788856577905543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08394846382116232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22311953622674024,
                                 0,
                                 0.97235907864213778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50035652199439828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28734184074395014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40442484283064734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10776603268360967,
                                 0,
                                 0.078101609751046602,
                                 0,
                                 0,
                                 0,
                                 0.43377618991001071,
                                 0,
                                 0,
                                 -0.44701510119139826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080820588595433618,
                                 0,
                                 0,
                                 0,
                                 0.068710598118664201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68999663746674045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37449856542807536,
                                 0.96058777781397631,
                                 0,
                                 0,
                                 0,
                                 -0.51814861940843238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19868842577480239,
                                 0,
                                 -0.28271421839143451,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20177188321374021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89277529449086668,
                                 -0.20972156298398703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43674924011942884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.00098783687974856454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2607426255706809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8308452210010614,
                                 0,
                                 1.2348176573000778,
                                 0,
                                 0,
                                 0,
                                 0.29018177099591824,
                                 0,
                                 0,
                                 -0.061979159160042527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16757659271670308,
                                 0,
                                 0,
                                 0,
                                 1.0171049853723575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52306745738260341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23122686769379011,
                                 -0.67281646970488085,
                                 0,
                                 0,
                                 0,
                                 -0.49600697104882718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39794601406562269,
                                 0,
                                 0.53469245124938636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27895269080942298,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32477231021714537,
                                 0,
                                 0,
                                 0,
                                 0.00081965285470040998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17175483834967925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46473694910920887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40443016579809549,
                                 -0.050961902827736334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22870787768848877,
                                 0,
                                 0,
                                 0.637391801382163,
                                 0,
                                 0,
                                 0,
                                 0.27432654155164704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044662071041377038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22920066204676498,
                                 0,
                                 0,
                                 0,
                                 -0.07851894315546229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088231808764956232,
                                 0,
                                 0,
                                 -0.31572396554464566,
                                 -0.25464103767279511,
                                 0.072650121864255873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61112890478199233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66340906831321456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051556499244579612,
                                 0,
                                 0,
                                 -0.092449205617982741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01508455546621853,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53804829619590833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0273598371286261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55708638225506002,
                                 0,
                                 0.67670545694354578,
                                 0,
                                 0,
                                 0,
                                 -0.61398482580940117,
                                 0,
                                 0,
                                 0.23828620478597007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34112083545855426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21372861784824465,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05769114376164225,
                                 0.30039976078169772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2573756362195174,
                                 0,
                                 0,
                                 0.7456042575160241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70949505236304988,
                                 0,
                                 0,
                                 0,
                                 -0.088727580133618145,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098397023824472199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67685074759643771,
                                 -0.046128105082073961,
                                 0,
                                 0,
                                 0,
                                 -0.060899423473706006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79683021432662759,
                                 0,
                                 0.27403990579588511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32064397618376561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12470126216139343,
                                 -0.15802687793181608,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5353942156663708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29205459413355694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47481311976407281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3904767198873797,
                                 0,
                                 0.024634045372427957,
                                 0,
                                 0,
                                 0,
                                 1.0051928150797327,
                                 0,
                                 0,
                                 0.57456298134251504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0030298572951810362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062528219537006088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1399941813296242,
                                 0.64162624664940904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21175392367194062,
                                 0,
                                 0,
                                 -0.31891873949597327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61620869943639089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19389064102432355,
                                 0,
                                 0,
                                 -0.42180307284136465,
                                 -0.4029040451432454,
                                 0.20181376320034913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16739937661719387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24418197681367654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3377389111448918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55355351645192519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11673736065473585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51389942931189714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33471428203826042,
                                 -0.19078111719471597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40317919826354043,
                                 0,
                                 0,
                                 -0.2115004175910378,
                                 0,
                                 0,
                                 0,
                                 -0.10661808513121551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17876424808707236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12968122185085443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11966044069112773,
                                 0,
                                 0,
                                 0,
                                 -0.55167426694982891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56559782863760333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5657600650015191,
                                 -0.60293762604596746,
                                 0,
                                 0,
                                 0,
                                 -0.72251467170018635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25257414760521291,
                                 0,
                                 0.44617241885077535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27803581952837764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28637806721784914,
                                 -0.99157881617209476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22924722330699354,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3344648049090722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059332933695992962,
                                 -0.061810198907248481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41142797048507129,
                                 0,
                                 0,
                                 -0.4738784572269864,
                                 -0.54321021455576113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19736388980702566,
                                 0,
                                 0.044829118373404211,
                                 0,
                                 0,
                                 0,
                                 -0.22747534510863662,
                                 0,
                                 0,
                                 -0.2466155746119367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74554329113740281,
                                 0,
                                 0.014517086278503039,
                                 0,
                                 0.78202816209174064,
                                 -0.1917059979742497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54055119526665762,
                                 -0.61773976645585205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21526970335689533,
                                 0,
                                 0.55718672899893773,
                                 0,
                                 0,
                                 0,
                                 -0.26234452654460594,
                                 0,
                                 0,
                                 0.28843192418884478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56653377932951521,
                                 0,
                                 0.56651858967119739,
                                 0,
                                 0.36733426894468685,
                                 0.096436417958180753,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38790705345476034,
                                 -0.27006184380863113,
                                 0,
                                 0,
                                 0,
                                 0.088612146806548275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49421677710398654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.060769726728126847,
                                 0,
                                 0,
                                 0,
                                 0.56396284219802961,
                                 0.44613878623235192,
                                 0,
                                 0,
                                 0,
                                 -0.03568365392285202,
                                 0,
                                 0,
                                 0.026462184001033499,
                                 0.041616692312761799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63480495079749322,
                                 0.059401141594851749,
                                 0,
                                 0,
                                 0,
                                 0.022346696043583403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05412103550804015,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43613973467731859,
                                 0,
                                 0,
                                 0,
                                 0.27013911901111909,
                                 0.13453551143645953,
                                 0,
                                 0,
                                 0,
                                 0.3638318226922358,
                                 0,
                                 0,
                                 0.41266742845147991,
                                 -0.078133860658530008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83262537654455337,
                                 0,
                                 0,
                                 0,
                                 0.24813584424991306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20273027815360117,
                                 0,
                                 0,
                                 0,
                                 -0.8268729517740826,
                                 0,
                                 -0.2099972627706056,
                                 0,
                                 0,
                                 -0.28477386697481533,
                                 0.74727028364498693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054775852273285339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086451515863421924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21950919058864696,
                                 0,
                                 0.147531703055368,
                                 0,
                                 0.23885973944925876,
                                 0,
                                 0,
                                 0.7056290027828086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11939821291122496,
                                 0,
                                 0,
                                 -0.32870269501416682,
                                 0,
                                 0.49528636927702163,
                                 1.12526474171094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20240624469993163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0141785843633482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38274117603949187,
                                 -0.52017055263845335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43259791419353605,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25183029214475466,
                                 0.21796044583565086,
                                 0,
                                 0,
                                 0,
                                 0.20818304083670189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40432841712418788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59862536474827521,
                                 0,
                                 0,
                                 0,
                                 -0.12552715658449173,
                                 0.3624982374275828,
                                 0,
                                 0,
                                 0,
                                 -0.41022781447112794,
                                 0,
                                 0,
                                 0.083474521140146418,
                                 -0.038521145876157292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53714192230633706,
                                 0,
                                 0,
                                 0,
                                 -0.10868345483882644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30949529078626092,
                                 0,
                                 0,
                                 0,
                                 0.23740883119377443,
                                 0,
                                 0.023863984522090903,
                                 0,
                                 0,
                                 -1.3585304734848249,
                                 -0.068682097022887398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35540847500550898,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69741350406623914,
                                 0.33902523897851961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30313542737306032,
                                 0,
                                 0.47151988540530881,
                                 0,
                                 0,
                                 0,
                                 -0.75739520699748963,
                                 0,
                                 0,
                                 0.062825365106163156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67530186664690905,
                                 0,
                                 0.16842823634652312,
                                 0,
                                 0.28010070612343824,
                                 -0.36506731904500522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41621007687522921,
                                 0,
                                 0,
                                 0,
                                 -0.14941278595169116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47537295629261367,
                                 0,
                                 0,
                                 0,
                                 -0.47188992338989066,
                                 0,
                                 0,
                                 -0.58645059817042255,
                                 0,
                                 0,
                                 0,
                                 -0.10890886022692756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26714587576147958,
                                 0.079454532747703172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80344471038991117,
                                 0,
                                 -0.030296809496123726,
                                 0,
                                 0,
                                 0,
                                 -0.43538637050318241,
                                 0,
                                 0,
                                 -0.14212901567667802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098646533098698502,
                                 0,
                                 -0.56300585495051625,
                                 0,
                                 0.046692973466335441,
                                 0.74270700594971217,
                                 0,
                                 0,
                                 0,
                                 0.13890454051185991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27296352680890212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01930107743348268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015648449784767759,
                                 0.19965787366201954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.4837232204444293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18608157601741981,
                                 0.68134721626822115,
                                 0,
                                 0,
                                 0,
                                 0.23670583573166087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18702053042795783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2211203079489393,
                                 0,
                                 0,
                                 0,
                                 0.52708208058338257,
                                 -0.23234018659957617,
                                 0,
                                 0,
                                 0,
                                 0.10110380000397376,
                                 0,
                                 0,
                                 0.094377425556738351,
                                 0.10155066263108907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15536825445053154,
                                 0,
                                 0,
                                 0,
                                 0.44131908767064976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33076708548414629,
                                 0,
                                 0,
                                 0,
                                 0.21659972221552487,
                                 0,
                                 0,
                                 -0.054776980205151024,
                                 0,
                                 0,
                                 0,
                                 0.78852732755601151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44926098564381262,
                                 -0.020660541395042802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52003006643375127,
                                 0,
                                 0.24279001420563845,
                                 0,
                                 0,
                                 0,
                                 -0.71690751270162811,
                                 0,
                                 0,
                                 -0.13921227459839269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58250963304722114,
                                 0,
                                 -0.66714512482565813,
                                 0,
                                 -0.31271659022593584,
                                 0.14839897491005535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39084264305713184,
                                 0,
                                 0,
                                 0,
                                 -0.4443586665170004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1375194071031789,
                                 0,
                                 0,
                                 0,
                                 0.41307759513675374,
                                 0,
                                 0.23814110773287753,
                                 0,
                                 0,
                                 -0.18569620176644094,
                                 0.33910376303454548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61389026290572923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44790559980637101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6969584778542709,
                                 0,
                                 0.18732816046976047,
                                 0,
                                 -0.44782374749849319,
                                 0,
                                 0,
                                 0.16403803351209362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20275190495225304,
                                 0,
                                 0,
                                 -0.014229951642151045,
                                 0,
                                 0.098854450362914542,
                                 0,
                                 0.116447626830843,
                                 0.74960650062997591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39891860810805835,
                                 0,
                                 0.62231074864329183,
                                 0,
                                 0,
                                 0,
                                 -0.30735731361017277,
                                 0,
                                 0,
                                 -0.2952343586084713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61141956908048511,
                                 0,
                                 0.4368527028100323,
                                 0,
                                 0.2841728870138453,
                                 0.069562895211328094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46753411047828652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064476803127978849,
                                 0,
                                 0.13890087045393151,
                                 0,
                                 -0.39894766488381644,
                                 0,
                                 0,
                                 -0.14614401937368307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37148143858010707,
                                 0,
                                 0,
                                 -0.65354420860158235,
                                 0,
                                 -0.11101954811496711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086340577984996808,
                                 0,
                                 0,
                                 0,
                                 0.51115056814958759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30868499975129515,
                                 0,
                                 0,
                                 0,
                                 -0.033081087044186233,
                                 0,
                                 0.78263261048134081,
                                 0,
                                 0,
                                 0.35257856552406952,
                                 0.56814611655023195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33953968556653569,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18465096687142743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.023265041437511874,
                                 0,
                                 0.459391418981977,
                                 0,
                                 0.41659416092500312,
                                 0,
                                 0,
                                 -0.53188406595125381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45708311053472583,
                                 0,
                                 0,
                                 0.042126154364399482,
                                 0,
                                 0.29524793834809532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53155294930821995,
                                 0,
                                 0,
                                 0,
                                 0.82126477101487261,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69714801070573629,
                                 0,
                                 0,
                                 0,
                                 -0.095901122130728489,
                                 0,
                                 -1.0968549809038097,
                                 0,
                                 0,
                                 0.22871087437730975,
                                 -0.62905073075304552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21548218337729586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32846233642391715,
                                 0.0033579945469671482,
                                 0,
                                 0,
                                 0,
                                 -0.50275887518479268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1181000508189578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05834637409288472,
                                 0,
                                 0,
                                 0,
                                 -0.15162290818907784,
                                 0.08438465765340715,
                                 0,
                                 0,
                                 0,
                                 0.18200704096307035,
                                 0,
                                 0,
                                 0.60386065096242214,
                                 0.44056586794413505,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61588858870683583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27568531307101229,
                                 0,
                                 0.34684020697557016,
                                 0,
                                 0.13212991505772773,
                                 0,
                                 0,
                                 0.32788957180683498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22004942823386048,
                                 0,
                                 0,
                                 0.48163718342332462,
                                 0,
                                 -0.1378938439813262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7628789466297079,
                                 0,
                                 0,
                                 0,
                                 -0.098177413184481213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42416553550026237,
                                 0,
                                 0,
                                 0,
                                 0.82234145396731406,
                                 0,
                                 -0.5665213470702718,
                                 0,
                                 0,
                                 0.045985040157176665,
                                 1.1768498805969543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061566677681430648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.82646003865275064,
                                 0,
                                 0,
                                 0,
                                 0.54486135655798162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35617849158422393,
                                 0,
                                 0,
                                 0,
                                 -0.70879930971189353,
                                 0,
                                 0.24086647967444114,
                                 0,
                                 0,
                                 -0.31803488514966333,
                                 -0.071397840770900042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53617185695039915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31982020026379943,
                                 -0.12497574374678488,
                                 0,
                                 0,
                                 0,
                                 0.40855511692604662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28366330309397902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42939110292680438,
                                 0,
                                 0,
                                 0,
                                 -0.19713634516944514,
                                 -0.55768275848356641,
                                 0,
                                 0,
                                 0,
                                 0.25966751983733988,
                                 0,
                                 0,
                                 0.10662170148732945,
                                 0.14720402451593273,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012136261289160788,
                                 0.006992173397571369,
                                 0,
                                 0,
                                 0,
                                 -0.40633100747390694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15124984539094646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3906497171480019,
                                 0,
                                 0,
                                 0,
                                 0.24281229150180023,
                                 -0.084007693922675347,
                                 0,
                                 0,
                                 0,
                                 0.19601148362730178,
                                 0,
                                 0,
                                 -0.61572674805984129,
                                 0.41911834160181488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2049392308188096,
                                 0,
                                 0,
                                 0,
                                 -0.42372892584677935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88491108571317367,
                                 0,
                                 0,
                                 0,
                                 -0.099855194325134469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19205961150904247,
                                 0,
                                 0,
                                 0,
                                 0.17353355569198525,
                                 0,
                                 0,
                                 0.36928269711686212,
                                 0,
                                 0,
                                 0,
                                 -0.059923374689760764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43749766138405027,
                                 0,
                                 0,
                                 0,
                                 -1.0333319240330514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3869934199822796,
                                 0,
                                 0,
                                 0,
                                 -0.89976821668093487,
                                 0,
                                 -0.25310685961092089,
                                 0,
                                 0,
                                 0.12183740316853237,
                                 0.096306666823068127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44413735273148441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062962976216514227,
                                 0.44781044530172942,
                                 0,
                                 0,
                                 0,
                                 -0.49815906899975793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5115584990897839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2237429453872842,
                                 0,
                                 0,
                                 0,
                                 -0.067824051712173233,
                                 -0.18435158858880515,
                                 0,
                                 0,
                                 0,
                                 -0.25821813340446509,
                                 0,
                                 0,
                                 0.019722762975133125,
                                 -0.36046470711044476,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31548686552673927,
                                 0,
                                 0,
                                 0,
                                 0.13014932652166725,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088071026032427974,
                                 0,
                                 0,
                                 0,
                                 -0.58159996232932576,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.055565270133770647,
                                 0,
                                 0,
                                 0,
                                 -0.50195468193628801,
                                 0,
                                 0,
                                 0.34645529881960263,
                                 0,
                                 0,
                                 0,
                                 0.52811712919497655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21927098553503843,
                                 0.30230725804212949,
                                 0,
                                 0,
                                 0,
                                 0.061275271332706417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066751666293823633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037885914180788446,
                                 0,
                                 0,
                                 0,
                                 -0.33859037423600646,
                                 0.42875973232643666,
                                 0,
                                 0,
                                 0,
                                 0.66418096830516549,
                                 0,
                                 0,
                                 -0.22805147916809265,
                                 -0.24343907844647805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29349972077113706,
                                 0.32279148610680009,
                                 0,
                                 0,
                                 0,
                                 0.23573906500818814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41343155763484446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083415741843840804,
                                 0,
                                 0,
                                 0,
                                 -0.27448968103145888,
                                 0.23337717681736067,
                                 0,
                                 0,
                                 0,
                                 -0.20262525728077804,
                                 0,
                                 0,
                                 -0.074823033643082015,
                                 0.63225141509838656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042219951839061728,
                                 0,
                                 0,
                                 0,
                                 0.65864534775445382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1572870191304061,
                                 0,
                                 0,
                                 0,
                                 -0.66602229391528789,
                                 0,
                                 0,
                                 0.29060484883338683,
                                 0,
                                 0,
                                 0,
                                 -0.10783181814072927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61094265594244546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16883740878917816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27984511972728848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.020588969037935403,
                                 -1.1794255347179079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06022611686992424,
                                 0,
                                 0.72071124395323338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1468250131828428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27599307536852463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.4041212202334097,
                                 -0.44360012911434643,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44142879602827634,
                                 0,
                                 0,
                                 -0.14705460917086299,
                                 -0.052616238192354212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047916140731832063,
                                 0,
                                 -0.52889608398339238,
                                 0,
                                 0,
                                 0,
                                 -0.80240185236601735,
                                 0,
                                 0,
                                 -0.36598346812317528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33526823989877219,
                                 0,
                                 0.60291188191378742,
                                 0,
                                 -0.23537760811534214,
                                 0.83225479756392662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10011602188833357,
                                 0,
                                 0,
                                 0,
                                 0.029495967824951518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77453217336723434,
                                 0,
                                 0,
                                 0,
                                 -0.06889388128270281,
                                 0,
                                 0,
                                 -0.55876919717321427,
                                 0,
                                 0,
                                 0,
                                 0.26876997576842149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34173306542110748,
                                 -0.47022754548536244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51820581019636269,
                                 0,
                                 0.38784694614328219,
                                 0,
                                 0,
                                 0,
                                 -0.3258218188040447,
                                 0,
                                 0,
                                 -0.51897780766115742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24233004337563957,
                                 0,
                                 0.2807283223089822,
                                 0,
                                 -0.80788446012779769,
                                 -0.15077050003848816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32124246274089924,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20395536019454125,
                                 0,
                                 0.23790850400357011,
                                 0,
                                 -0.13759803308216259,
                                 0,
                                 0,
                                 -0.2319850413826155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61666108441428147,
                                 0,
                                 0,
                                 -0.053834951958576738,
                                 0,
                                 0.58539359552876691,
                                 0,
                                 0.58466144803003672,
                                 -0.080732794897439397,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2493398169761713,
                                 0,
                                 -1.0014909080607395,
                                 0,
                                 0,
                                 0,
                                 -0.32185223359564075,
                                 0,
                                 0,
                                 -0.27378076462800272,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06939374015535274,
                                 0,
                                 0.029832593779328759,
                                 0,
                                 -0.077693082365068972,
                                 -0.69160119485139693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013652939158247362,
                                 -0.33766604051168675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4526755438803437,
                                 0,
                                 -0.47346258231097416,
                                 0,
                                 0,
                                 0,
                                 -0.15123886525340477,
                                 0,
                                 0,
                                 1.0800210890264086,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24545119149760219,
                                 0,
                                 0.24958940223301845,
                                 0,
                                 -0.33821561444035919,
                                 -0.32485131077814056,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18075153157463808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57235186726198184,
                                 0,
                                 0.50651096267026452,
                                 0,
                                 -0.52476528199773886,
                                 0,
                                 0,
                                 0.059727839957214035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.063354578420217758,
                                 0,
                                 0,
                                 0.31339765558757221,
                                 0,
                                 -0.044843721737652206,
                                 -0.099485218531023517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.7796568886117423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043661161756008662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4908656740385457,
                                 -0.11246200098272793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32113688949649266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15503546467187052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12719761926253736,
                                 0,
                                 0.52854204041328268,
                                 0,
                                 0.31292147171802293,
                                 0,
                                 0,
                                 0.077617358823710611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40620912858076391,
                                 0,
                                 0,
                                 -0.3602314981402352,
                                 0,
                                 -0.53076472340958436,
                                 0.25305035053573549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11628421718274723,
                                 0.3617369115962093,
                                 0,
                                 0,
                                 0,
                                 0.56474836208984802,
                                 0,
                                 -0.46083729535879564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3127495046637032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13614988691953345,
                                 0,
                                 0,
                                 -0.56860491553908277,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2424145343301996,
                                 0,
                                 0,
                                 0.097528094866994319,
                                 0,
                                 -0.015570650781998277,
                                 -0.46475870580941614,
                                 0,
                                 0,
                                 0.2840086948061295,
                                 -0.48908323544042209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22917837410598493,
                                 0,
                                 0,
                                 -0.035297956173756764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099542837365317355,
                                 0,
                                 0,
                                 -0.16540185133229568,
                                 0,
                                 0,
                                 0,
                                 -0.15597559185924714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017106645613946023,
                                 -0.14017537540782612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0649656857641621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14509692498783622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10037688367283389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40567109107927918,
                                 0,
                                 0.67679532222008498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057096777307234697,
                                 0,
                                 0,
                                 -0.17776324333411003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42230357274000319,
                                 -0.58834709853704004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28713598341771385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33408061335428507,
                                 0,
                                 0,
                                 0,
                                 -0.016145892710699453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49631638335913569,
                                 0,
                                 0,
                                 0,
                                 -0.18741122560752876,
                                 0,
                                 0,
                                 0.25947195763427466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41264898819142209,
                                 0,
                                 0,
                                 0.0076539892740826038,
                                 0,
                                 0.74212100405977566,
                                 -0.091333861752781714,
                                 0,
                                 0,
                                 0.30515357271158039,
                                 -0.031670176077987222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27013446270538072,
                                 0,
                                 0,
                                 -0.032152368630714454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27440147073096433,
                                 0,
                                 0,
                                 -0.31480528007003594,
                                 0,
                                 0,
                                 0,
                                 -0.075403768178032918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72582432313190848,
                                 0.22163376508738888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046491726811022274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41014155257752166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43466043354424122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.213421051343927,
                                 0,
                                 -0.11363503858981079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37218047248089559,
                                 0,
                                 0,
                                 -0.57472124365579036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52357910958311815,
                                 0.079975425638491401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18437678179834852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030377681233414399,
                                 0,
                                 0,
                                 0,
                                 0.018474517164209378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4640981860865922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32094082165068544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41752169403489259,
                                 -0.52282303797376306,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12731936199810845,
                                 0,
                                 0,
                                 -1.0080526285683928,
                                 0,
                                 0,
                                 0.21251293051540143,
                                 0,
                                 0,
                                 -0.08708605640588013,
                                 0,
                                 0.91097173121510688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.00088320830153261823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19816555687146095,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58081812529529664,
                                 0,
                                 0,
                                 0.81129591983826677,
                                 0,
                                 0,
                                 0,
                                 -0.43173385709594808,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43588875433119495,
                                 -0.15083352669542668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093258911030137309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092587862899768877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35894750172878748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.606827748879471,
                                 0,
                                 0.054390659975175726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10301828596052236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86341975776254365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047012495660395281,
                                 -0.32170429368847048,
                                 0,
                                 0.23459763999165609,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28836378872451252,
                                 0,
                                 0,
                                 0,
                                 0.54980017715487017,
                                 0,
                                 0,
                                 -0.013957830085756934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061011795571179556,
                                 0.42393983716486539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16187290895035733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6272254238674263,
                                 0,
                                 0,
                                 0,
                                 0.25861336603884533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16607852165116732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056193180291706037,
                                 0,
                                 0,
                                 0.10852793583376164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0060986321722463349,
                                 0.41662647866749081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66777055916505035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37111626847152629,
                                 0,
                                 0,
                                 0,
                                 0.27030585846879762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39336895665103722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37548549488122918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.092476649701534797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87713222713470229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76640909903177656,
                                 -0.27750320152386071,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10217405081053607,
                                 0,
                                 0,
                                 -0.1121979837562652,
                                 0,
                                 0,
                                 -0.063061999494577525,
                                 0,
                                 0,
                                 -0.22746018619851521,
                                 0,
                                 -0.24621754433414611,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33580464981091412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69771736318144562,
                                 -1.1486427969091699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25170898570055905,
                                 0,
                                 0,
                                 0.34745162975395605,
                                 0,
                                 0,
                                 0.38245900499938751,
                                 0,
                                 0,
                                 -0.37475595022399533,
                                 0,
                                 0.10833251509008472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030043384377200288,
                                 0,
                                 0,
                                 0.10816463576551406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11428059343145303,
                                 0,
                                 0,
                                 -0.59159734781450624,
                                 0,
                                 -0.21046796862089134,
                                 0.091606952108930939,
                                 0,
                                 0,
                                 0.18563285259270149,
                                 -0.50879470905135904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44090609143241111,
                                 0,
                                 0,
                                 0.28971009263747904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78894089731265926,
                                 0,
                                 0,
                                 0.12175498933631639,
                                 0,
                                 0,
                                 0,
                                 -0.12905667393052422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17341174067019208,
                                 0.26379800291214234,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13235187519632113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43315931326693841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30625406849379672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70159539908093937,
                                 0,
                                 -0.10673518697760605,
                                 0,
                                 0,
                                 0,
                                 0.15052273514314779,
                                 0,
                                 0,
                                 -0.012871478146873123,
                                 0,
                                 0,
                                 0,
                                 1.0194052025313862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16442649732409489,
                                 0.16970809751524288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15986193727967357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08883881510181868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27284198042254887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062880034441659918,
                                 0,
                                 -1.0388243450917063,
                                 0,
                                 0,
                                 0.30096872211076786,
                                 0,
                                 0,
                                 -0.19011005979823825,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042167671843747423,
                                 0,
                                 0,
                                 -0.69793369515930559,
                                 0,
                                 0.28393021799885587,
                                 0.169584858051578,
                                 0,
                                 0,
                                 0.076965513593836479,
                                 0.27077998503392037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43830511891005436,
                                 0,
                                 0,
                                 -0.060449792996622759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0094862122131183502,
                                 0,
                                 0,
                                 -0.72676743392884224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28948542000725463,
                                 0.16789208881011689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28545201431442535,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057432441925492933,
                                 0,
                                 0,
                                 0,
                                 0.13821918175707054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50580991173488388,
                                 0,
                                 0,
                                 0,
                                 -0.52973141870695717,
                                 0,
                                 0,
                                 0.084819248518110596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41032530719591065,
                                 0,
                                 0,
                                 -0.048474156831760151,
                                 0,
                                 -0.013954485715899176,
                                 -0.30209285901228322,
                                 0,
                                 0,
                                 0.4438722894905438,
                                 0.21421240657329155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32272102921880974,
                                 0,
                                 0,
                                 0.32087453492636864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24858686957489132,
                                 0,
                                 0,
                                 0.55060168517974228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10635266133103648,
                                 0,
                                 0,
                                 -0.0098951787186716267,
                                 0,
                                 -0.35059286596101841,
                                 -0.081790472596927677,
                                 0,
                                 0,
                                 0.46894519904029403,
                                 -0.041001468977105021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17610883813493058,
                                 0,
                                 0,
                                 -0.49134862095794019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30108960130198903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33895634559890409,
                                 1.1643121127484202,
                                 0,
                                 0,
                                 0,
                                 0.17640795006288063,
                                 0,
                                 -0.52489603404860719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63352048687288998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0677813474766475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43927411074632017,
                                 -0.69931192018938249,
                                 0,
                                 0,
                                 0,
                                 0.73463068613354865,
                                 0,
                                 -0.52527622803880081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1102648338859098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41758135841788224,
                                 0,
                                 0,
                                 -0.058755307451439961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37111561016840078,
                                 0,
                                 0,
                                 -0.099942629256063897,
                                 0,
                                 0.21909245329768448,
                                 0.14108340852489754,
                                 0,
                                 0,
                                 -0.18526032870399672,
                                 -0.39389283500996525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12992730515020537,
                                 0,
                                 0,
                                 -0.63261220898318671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35641890838061752,
                                 0,
                                 0,
                                 -0.42385043217519225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28554711785674958,
                                 0,
                                 0,
                                 0.028936270180986975,
                                 0,
                                 -0.27004973124387177,
                                 0.50100950348386419,
                                 0,
                                 0,
                                 0.4054964820233054,
                                 0.23670777615425739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18205149036752907,
                                 0,
                                 0,
                                 -0.18276710685772224,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1912128878032458,
                                 0,
                                 0,
                                 -0.31267537676484813,
                                 0,
                                 0,
                                 0,
                                 -0.38318053325233276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53773884752486101,
                                 -0.058419751153637525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23791290517408648,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.87047777903969914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31174392878460533,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42202009159163789,
                                 0,
                                 -0.21526982076210055,
                                 0,
                                 0.31435144595821574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76523305907743977,
                                 0.16427851911905195,
                                 0,
                                 0,
                                 0,
                                 -0.28725558238087884,
                                 0,
                                 -1.1442675761346079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92278365598126855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14244306108202781,
                                 0,
                                 0,
                                 0.1655595087765738,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42453651362360728,
                                 -0.38806730586348814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22960998487459594,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20225023694841462,
                                 0,
                                 0,
                                 0,
                                 0.67443769623766436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27014890064047736,
                                 0,
                                 0,
                                 0.97124175411312486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63142416663359646,
                                 -0.41421602147967218,
                                 0,
                                 0,
                                 0,
                                 0.86856974654426122,
                                 0,
                                 0.33633568431690003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52402322898556786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26629947356974426,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2798595182794279,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58018077721184957,
                                 0.47038932167891345,
                                 0,
                                 0.044779770951510096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53933492777931558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.082629829059818999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12888832103370257,
                                 0.19258815933427811,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76073174627388962,
                                 0,
                                 0,
                                 -0.10316150243006818,
                                 0,
                                 0,
                                 -0.34864436528801213,
                                 0,
                                 0,
                                 -0.92983659647387906,
                                 0,
                                 -0.26592489279872911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23950329917105084,
                                 0,
                                 0,
                                 -0.010889466117273683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49712624888007517,
                                 -0.082074792390072537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49819378793103508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21784146482974001,
                                 0,
                                 0,
                                 0,
                                 -0.6060467668644669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1603252088204524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51760812554861402,
                                 0,
                                 0,
                                 -0.3523579245968772,
                                 0,
                                 0,
                                 0,
                                 0.41407533215648795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023353044349075369,
                                 0.7148715904699503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2719269246954949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047586207690533455,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19940940608155311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16562513005398188,
                                 0,
                                 0.20495011078955677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29423937895810459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083633809305314832,
                                 0.48791295177021798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21558900098528586,
                                 0,
                                 0,
                                 -0.9748948380345992,
                                 0,
                                 0,
                                 0.9195445247162114,
                                 0,
                                 0,
                                 -0.05673451594585624,
                                 0,
                                 -0.82911715425432242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23827271860780358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12532246082601908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080897597319099568,
                                 -0.59465030715985634,
                                 0,
                                 -0.31459231094953632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6843965672136828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.91837922780015324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14781425162487846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25708717157033667,
                                 0.23863276743451961,
                                 0,
                                 0.0021031641329011391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10810507010731688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34978657651619377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0695737169956161,
                                 0.65812923136426849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13325717395347925,
                                 0,
                                 0,
                                 -0.57138126042746151,
                                 0,
                                 0,
                                 -0.59488652600659231,
                                 0,
                                 0,
                                 0.36992215780236504,
                                 0,
                                 0.18654789780214504,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089881094221613889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2673751764774035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75967756079598892,
                                 0.44775711578456601,
                                 0,
                                 0.2088438800089551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31499159762659057,
                                 0,
                                 0,
                                 -0.39796629363649061,
                                 0,
                                 0,
                                 0.6073612275311504,
                                 0,
                                 0,
                                 0,
                                 0.50727592955174561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30045375804228192,
                                 0.95938965460445835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071981653141928142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11436869116528398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052341959676387009,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63750216533554571,
                                 0,
                                 0.16460632029601502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11342686003061123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48237922353079771,
                                 -0.13080477866905862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89858210827329665,
                                 0,
                                 0,
                                 -0.40357992478042126,
                                 0,
                                 0,
                                 -0.8192764771421891,
                                 0,
                                 0,
                                 -0.25106034886856343,
                                 0,
                                 -0.43550271556601938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38277854677580497,
                                 0,
                                 0,
                                 -0.25326019871610572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55485530814768658,
                                 0,
                                 0,
                                 0.087136384788434273,
                                 0,
                                 0.18040614858648915,
                                 -0.14232244057561635,
                                 0,
                                 0,
                                 0.29924002984215803,
                                 0.24048895742955209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47400884964003687,
                                 0,
                                 0,
                                 -0.22139718642984052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14468023384544329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25703566978911924,
                                 -0.56153025476575735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.071212843131087,
                                 0,
                                 0,
                                 -0.2964095078150305,
                                 0,
                                 0,
                                 -0.59681324404547664,
                                 0,
                                 0,
                                 0.63524550056205886,
                                 0,
                                 -0.70713738365837508,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44413108670007884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56808980349182481,
                                 -0.85319565358327865,
                                 0,
                                 0,
                                 0,
                                 0.27056781232686483,
                                 0,
                                 -0.31414222226496735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28498147599340257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25400120366402912,
                                 0,
                                 0,
                                 -0.062631510080574701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22206244077300308,
                                 0,
                                 0,
                                 -0.36395683467809969,
                                 0,
                                 -0.21798167684509864,
                                 -0.5910889176843217,
                                 0,
                                 0,
                                 -0.28392168150066988,
                                 0.33319000811376964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27950610243975499,
                                 0,
                                 0,
                                 -0.2883253254360032,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32569770189235903,
                                 0,
                                 0,
                                 0.17087335644719898,
                                 0,
                                 0,
                                 0,
                                 -0.23820821727523361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32975482187701488,
                                 0.35471775150610307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41895455499479251,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92727989438344116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46830519364330325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.064619668946356332,
                                 0,
                                 -0.42754517193194552,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68923283542487601,
                                 0,
                                 0,
                                 0.26533592499860637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1805475251116678,
                                 0.32958876765402684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17040282584928915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51446066483592401,
                                 0,
                                 0,
                                 0,
                                 -0.13486452539045668,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03786082355215814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25431910895018023,
                                 0,
                                 0,
                                 0.33260459717622648,
                                 0,
                                 0,
                                 0,
                                 0.27817894336788163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43653093785506958,
                                 -0.42238076548048342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034235564094091779,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11284220372093674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73549428105599812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10474016847389578,
                                 0,
                                 0.64371434465817579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10098969030648554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25911525382817935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10691987462886895,
                                 -0.25337563663140961,
                                 0,
                                 0.89463411951408456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21600714584844721,
                                 -0.22273219585764112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33662769166067874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057154198454328738,
                                 0,
                                 -0.26934400830536354,
                                 0,
                                 0,
                                 0,
                                 0.22770829192458053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68676306216097505,
                                 0.10646353291274741,
                                 0,
                                 0,
                                 0,
                                 -0.33035075846263656,
                                 0,
                                 0,
                                 -0.16818933384734655,
                                 0.29834717978830078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41017065654959062,
                                 0,
                                 0,
                                 -0.38343960783918274,
                                 0,
                                 0,
                                 0,
                                 0.031817193055932787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.086471225398605633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15541137747923356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67917245267244641,
                                 0,
                                 0.2164280309389664,
                                 0,
                                 0,
                                 0,
                                 0.37944101485566634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.055816320969088278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42668978595309809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033472012532271403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63432063701815378,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.93445001056920751,
                                 0.6379971099567201,
                                 0,
                                 0,
                                 0.12107623973838728,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63510875308290571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25666908508773273,
                                 0,
                                 0,
                                 0.10182076809067805,
                                 0,
                                 0,
                                 0,
                                 0.36470005537001482,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79079796539548897,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21266379433322233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22831959692242251,
                                 0,
                                 -0.073408767989573673,
                                 0,
                                 0,
                                 0,
                                 0.2502826092806823,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18429360771403175,
                                 0.16409570113604199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46623991399106013,
                                 0,
                                 0.5171492260273769,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35410924275355316,
                                 0,
                                 -0.573491178521359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.88200534326586599,
                                 0.040069698188274841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3065364035399058,
                                 0,
                                 0.19602997740825023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11412032868444848,
                                 0,
                                 -0.27394383654438348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66619582806373756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10373298118882621,
                                 0,
                                 0.27710126030883797,
                                 0,
                                 -0.28527672021736983,
                                 0.74766100264054758,
                                 0,
                                 0,
                                 0,
                                 0.18972547591630054,
                                 -0.74625982886747289,
                                 0,
                                 0,
                                 -0.007149947595784154,
                                 -0.61169564382388986,
                                 -0.091188825451528746,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04995486963186218,
                                 0,
                                 0,
                                 0.51328348856880335,
                                 0,
                                 0,
                                 0,
                                 -0.12684475767222464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076126724998908615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19952146756359129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.025796581762174354,
                                 0,
                                 0.78101596255931183,
                                 0,
                                 0,
                                 0,
                                 0.24839381460279533,
                                 0,
                                 0,
                                 0.11707129969520344,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57679256145082203,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28762315440606334,
                                 0,
                                 -0.066121577465390782,
                                 0,
                                 0,
                                 0,
                                 0.53530539608920424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11434544968614585,
                                 -0.18817955154887189,
                                 0,
                                 0,
                                 0,
                                 0.06231298987494524,
                                 0,
                                 0,
                                 0.372647259293727,
                                 0.29785622161053543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24869617218962109,
                                 0,
                                 0,
                                 0,
                                 -0.33142418479648333,
                                 1.2567159189738557,
                                 -0.17318159802220989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38722737159692339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076372084246325106,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71657584127718721,
                                 0.5166770160502232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36771650274530698,
                                 0.043390645932773614,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.71662529038355416,
                                 0,
                                 -0.14033012453408672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51005818555801752,
                                 0,
                                 -0.26362496492269971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30976981424859606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21694507423003007,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.034405562395685409,
                                 -0.096655503989207012,
                                 0,
                                 0,
                                 -0.83334480587564275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2259717471107778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018552938481446513,
                                 0.23894021038956981,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11436084018329459,
                                 0,
                                 -0.63655739285021762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34923873080581935,
                                 0,
                                 -0.63428066112576587,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088129891738254529,
                                 0,
                                 0,
                                 0,
                                 -0.35111997155114749,
                                 0.50144706204825895,
                                 0.022000866689023568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2844439619173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15411979739819817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34549005558946644,
                                 0.16643373634519842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93571253119024766,
                                 0,
                                 0,
                                 0,
                                 1.0252210236001009,
                                 -0.33372911213306922,
                                 -0.015890751259885955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.071581130962539805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86761389910296782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01187607178375194,
                                 0.311935135601768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37301460667126279,
                                 0,
                                 0,
                                 0,
                                 -0.61291679721837067,
                                 -0.33668938568114992,
                                 -0.8208392433404984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12093052458283161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57362175440400232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55154605259832623,
                                 1.062895688046384,
                                 0,
                                 -0.48827782191489716,
                                 0,
                                 0,
                                 0.26229915149506505,
                                 0,
                                 0,
                                 0,
                                 -0.64605659667091242,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39161441444453982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15460263265414922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14506308201524995,
                                 0,
                                 -0.17373116816209816,
                                 0,
                                 0,
                                 0,
                                 -0.21657598544147705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090380773676106391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80039943754583676,
                                 0,
                                 0.37600120444443186,
                                 0,
                                 -0.32000795407445481,
                                 0.053463313557748249,
                                 0,
                                 0,
                                 0,
                                 -0.32456236504111274,
                                 0.49241266051161531,
                                 0,
                                 0,
                                 0.84208423140050537,
                                 0.39786711303093086,
                                 -0.38619011852070584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14365505521540498,
                                 0.76161848175376667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18947389401917494,
                                 0,
                                 -0.25579218657291997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41679539709291358,
                                 0,
                                 0.35249412916779554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25409047765533566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53209457513682723,
                                 0,
                                 0.54135741352584965,
                                 0,
                                 1.0521578305579036,
                                 0.10488647437673612,
                                 0,
                                 0,
                                 0,
                                 0.79584933199230967,
                                 0.33459404834168638,
                                 0,
                                 0,
                                 0.045718592603971972,
                                 -0.014217579315453976,
                                 -0.51390005850446152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17862258479747711,
                                 -0.57656667967493935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35514111393486647,
                                 0,
                                 -0.45144371190751004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55293557309149743,
                                 0,
                                 0.00067251106327506638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39697540695204969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87054167293487095,
                                 0,
                                 -0.03680168048333704,
                                 0,
                                 -0.71923125271696331,
                                 0.47267237962883768,
                                 0,
                                 0,
                                 0,
                                 -0.631707282175209,
                                 0.41127714057973175,
                                 0,
                                 0,
                                 -0.54700145718421112,
                                 0.35569975582966384,
                                 -0.8382063552029051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0049514024301913623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46666880689834589,
                                 0,
                                 0.84582646487349922,
                                 0,
                                 -0.6362812724909187,
                                 -0.51650465195954343,
                                 0,
                                 0,
                                 0,
                                 0.56774451183368779,
                                 0.066059822059559209,
                                 0,
                                 0,
                                 -0.76688435834135793,
                                 0.14755366083879878,
                                 -0.30989678200507187,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11622438711644768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.081369580915266221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13507271693371173,
                                 0,
                                 0.62070561959401438,
                                 0,
                                 0,
                                 0,
                                 0.37699457736212355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33503717870057242,
                                 -0.014338107851153782,
                                 0,
                                 0,
                                 0,
                                 -0.42691020807727542,
                                 0,
                                 0,
                                 -0.23183612501655992,
                                 0.29286525852945355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58380259338381746,
                                 0,
                                 0,
                                 0,
                                 -0.24892257596411976,
                                 -0.18556264670384026,
                                 0.22708543597634984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24984257716058891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89259318823915057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14114815387096352,
                                 0.25653259192471539,
                                 0.053025631845826968,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11324621465195711,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24916730802279,
                                 0,
                                 -0.040738391307860874,
                                 0,
                                 0,
                                 0,
                                 -0.12208181277875099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18030808434330542,
                                 0.55283532343290642,
                                 0,
                                 0,
                                 0,
                                 -0.46909768237967153,
                                 0,
                                 0,
                                 0.58738517762114861,
                                 -0.050037602776359699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5154737858700057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51916609086571697,
                                 0,
                                 0.53259196761952643,
                                 0,
                                 0.31151861385926172,
                                 -0.61905170107595353,
                                 0,
                                 0,
                                 0,
                                 -0.24992384167430232,
                                 -0.60896393011586891,
                                 0,
                                 0,
                                 0.15194255864565739,
                                 -0.34683829145805234,
                                 -0.31691333968677204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59081921058007281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4162532058029787,
                                 0,
                                 -0.058712567799125287,
                                 0,
                                 -0.42841964403898597,
                                 0.27789674320787139,
                                 0,
                                 0,
                                 0,
                                 0.77406999141135346,
                                 0.61704739653502738,
                                 0,
                                 0,
                                 0.60250889546726505,
                                 -0.89630985215559555,
                                 -0.028315041939896191,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23490280746592521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088698053267940183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25548044842043749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59631893617461518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13894214879303657,
                                 0,
                                 -0.085998456035665485,
                                 0,
                                 0,
                                 0,
                                 -0.15138234233179704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028181200778309309,
                                 0.52766524929192349,
                                 0,
                                 0,
                                 0,
                                 -0.045571834284388282,
                                 0,
                                 0,
                                 -0.4966409445123901,
                                 0.039526989248407987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25699865235251274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43556467288326178,
                                 0,
                                 -0.28875154219858878,
                                 0,
                                 0.29365607858688303,
                                 -0.33989061182217772,
                                 0,
                                 0,
                                 0,
                                 0.0071921674015317794,
                                 0.41415590583579898,
                                 0,
                                 0,
                                 -0.60423433708969998,
                                 -0.74699491342069912,
                                 -0.42576910425664471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0430559329453872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39182122502843642,
                                 0,
                                 -0.48170997419795203,
                                 0,
                                 -0.12502800078726861,
                                 -0.59621865399739371,
                                 0,
                                 0,
                                 0,
                                 -0.13250934514071361,
                                 0.48126303882214461,
                                 0,
                                 0,
                                 0.25851131035444813,
                                 -0.19100149846678699,
                                 0.17681323872641003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.073289537279360842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1149508706430928,
                                 0,
                                 -0.79485459387864466,
                                 0,
                                 -0.301151374015248,
                                 -0.16869099456204772,
                                 0,
                                 0,
                                 0,
                                 0.64558983755451138,
                                 -0.76787958657427791,
                                 0,
                                 0,
                                 0.35598174364275281,
                                 0.1268867171856502,
                                 -0.66240004260132479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29008775961986161,
                                 0,
                                 0,
                                 0.40218494620558948,
                                 0,
                                 0,
                                 0,
                                 0.24406230277070318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16994255054445895,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80013224131321503,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14943119579342284,
                                 0,
                                 -0.0076526363280867236,
                                 0,
                                 0,
                                 0,
                                 0.055223490808817721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2723427837547967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51580070326302796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.079650426210097491,
                                 -0.27981125972113147,
                                 0,
                                 0,
                                 0.48514472724425739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51079542134753742,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11937911373719175,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84983261220168971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41742048992820668,
                                 0.36185821440848942,
                                 0,
                                 0,
                                 -0.68770729386154239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19292228709308124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26031520401754554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35891595514605673,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39834577921683006,
                                 0,
                                 -0.15174661587313129,
                                 0,
                                 0,
                                 0,
                                 -0.36068976485801529,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041752767825401507,
                                 -0.43078419997184036,
                                 0,
                                 0,
                                 0,
                                 -0.52213635102544798,
                                 0,
                                 0,
                                 0.17788291410050544,
                                 0.0049808853869508403,
                                 0,
                                 0,
                                 0,
                                 -0.14445736050203992,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.030649708630375062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58670643347144336,
                                 0,
                                 0.42510182349389314,
                                 0,
                                 0,
                                 0,
                                 -0.52001962156433179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17918842851973471,
                                 -0.23966885616645195,
                                 0,
                                 0,
                                 0,
                                 0.067222665709147006,
                                 0,
                                 0,
                                 0.039078004417209357,
                                 0.29536524742316955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65906985342151647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38105440384528616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35713016664447633,
                                 0.93057107564202002,
                                 0,
                                 0,
                                 0.42791392597204858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42054090847224757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32253415407257663,
                                 0,
                                 0,
                                 0,
                                 -0.25289910267216731,
                                 0.27867704860474241,
                                 -1.0825375043985734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11255273628903822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.474438664733079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.070659557250072891,
                                 -0.54162397428846709,
                                 0,
                                 0.18103372864085454,
                                 0,
                                 0,
                                 0.56762369210366748,
                                 0,
                                 0,
                                 0,
                                 0.14875255763436182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37882302054142497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.071776506135858023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57545735578397261,
                                 0,
                                 -0.35636786060644282,
                                 0,
                                 0,
                                 0,
                                 -0.12686544734454419,
                                 0,
                                 0,
                                 0.2843478457853027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.098090629152690581,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35285075658140497,
                                 0,
                                 0.13833739949357993,
                                 0,
                                 0,
                                 0,
                                 0.13372604123938137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20562316686720936,
                                 -0.19714977237771028,
                                 0,
                                 0,
                                 0,
                                 -0.38347467661163204,
                                 0,
                                 0,
                                 -0.23469766937946887,
                                 -0.68170099114625438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25738061222094577,
                                 0,
                                 0,
                                 0.071176851443476852,
                                 0,
                                 0,
                                 0,
                                 -0.43806549087855867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088881951682864974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12969155125122733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13334360906831871,
                                 0,
                                 -0.35419133190747931,
                                 0,
                                 0,
                                 0,
                                 0.7542120288712113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19610690607553841,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.86333744878303076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35093798411843286,
                                 0.0084997368025487574,
                                 0,
                                 0,
                                 -1.0646863049019806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.84695706334803467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71814663220637631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16102428202678312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33964982225721052,
                                 0,
                                 0.25692459053135419,
                                 0,
                                 0,
                                 0,
                                 -0.22864322290424866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35039030960486317,
                                 0.20424574815793708,
                                 0,
                                 0,
                                 0,
                                 -0.051700211899984971,
                                 0,
                                 0,
                                 -0.025051178838867844,
                                 0.23852978160386895,
                                 0,
                                 0,
                                 0,
                                 0.41215819438626322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11678823726347055,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26758728410385968,
                                 0,
                                 -0.48975999013383797,
                                 0,
                                 0,
                                 0,
                                 -0.10475534351083579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41330433794591159,
                                 -0.21305007652118693,
                                 0,
                                 0,
                                 0,
                                 -0.23607778137996549,
                                 0,
                                 0,
                                 -0.31391850132078425,
                                 0.35150574773355903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5846378316170634,
                                 0,
                                 0,
                                 -0.14604890564454012,
                                 0,
                                 0,
                                 0,
                                 -0.39863230156755591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16648370650600947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45246796063318334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30598171696394155,
                                 0,
                                 0.23472003137427802,
                                 0,
                                 0,
                                 0,
                                 -0.3111241343467408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1448344277684783,
                                 0,
                                 0,
                                 0,
                                 -0.92343185502095426,
                                 0.25442677871395569,
                                 0.61327403400323566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53543153270393762,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13545621941991523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0577771963176048,
                                 -0.29350808853116794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28163964478530662,
                                 0,
                                 0,
                                 0,
                                 -0.06585941820713509,
                                 -0.51590076420170261,
                                 0.092226865524411922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74208245222034874,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20209326889576965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3447095390852,
                                 0.22534702037997201,
                                 0.49901169084200697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020759762938149615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23099268757776228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60745114341511641,
                                 0,
                                 0,
                                 0,
                                 -0.15941153258006363,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067110224764972776,
                                 -0.99779793960400565,
                                 -0.086080692318651564,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31783892813896941,
                                 -0.42886862749155852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36773500993393121,
                                 0.66747335181184941,
                                 -0.087739366118216144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054318686671853654,
                                 0.20746313540767938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90110754144738525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039024340889406678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0765451123965333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12108712820469922,
                                 0.47759939079697666,
                                 0.59671560970764626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48484978288488556,
                                 1.0614956504976425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37205867202352799,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46338005624415052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52907837109539857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.066820378798099739,
                                 -0.28793510580073245,
                                 -0.76957462700437962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56012501892386557,
                                 -0.058276023655922687,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8806726352561226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12311350792358805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26882061857234307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39317068151347356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40706809376528164,
                                 0.62043061451112136,
                                 -0.18079218605344333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1093397286186196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30975979400377895,
                                 0.074999114321154123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23361459900458684,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21619151440214379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2173630491222435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74763348345556735,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30316459188014411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.011964184874921346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22347544353857118,
                                 0,
                                 0,
                                 -1.2296375546721794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23140019420694691,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17151802824286713,
                                 0,
                                 0.74681058835774006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12634561239774511,
                                 0,
                                 0.12571012030140152,
                                 0,
                                 0,
                                 0,
                                 -0.43892077152053671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.054703106933959161,
                                 0.30569912616965794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30330419328586083,
                                 0,
                                 0,
                                 0,
                                 -0.26511237301246382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17551779574928927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55695887073384776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17357262829994036,
                                 0,
                                 0,
                                 0,
                                 0.87655089338083358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11723432934082315,
                                 -0.058594173400448805,
                                 0.95317731930766003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.013440089852845309,
                                 0.34082016851782571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.073513576542915515,
                                 0,
                                 0.28789016690361052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11802378109587844,
                                 0,
                                 0.16898195696821183,
                                 0,
                                 0,
                                 0,
                                 0.74126050441236502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4387391510003088,
                                 0.1306879336345865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33195176932686365,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34229915285672635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.074248785067466849,
                                 -0.051060681772005817,
                                 0.38314117896113475,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14364326715029835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42784380655914334,
                                 -0.480941494171019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022817639684333937,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21901224972388381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49440733165767348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042128335857637991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069397359919626256,
                                 -0.18472569724394466,
                                 0.63216730333737092,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11056639411744906,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68404249390456628,
                                 0.063200051155604453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23524003311671637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10667586497241664,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093804084842788377,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039931893888075075,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25924128712595962,
                                 0.31499372454103225,
                                 0.54276067071674672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55258532557522133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23732749724802721,
                                 0.071093996372922463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11560891427336496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34599334952795979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19386373676957244,
                                 0,
                                 0.56159384947831392,
                                 0.67547965064854976,
                                 -0.95996002590141227,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25353633030731004,
                                 -0.39938978064354391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0017486038979806361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44138616735494707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06031052160639247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74082506476726628,
                                 0.21588011781951666,
                                 0.16905978057186072,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62126425675924268,
                                 -0.8524250738915824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38198401491276229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22915750233892745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37816166071822588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.093947602051542123,
                                 0,
                                 -0.26279273645368129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45309935238977578,
                                 0,
                                 -0.52414392880687322,
                                 0,
                                 0,
                                 0,
                                 0.16296872406239635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12585306834286888,
                                 0.58044972831819408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25053594064785245,
                                 0,
                                 0,
                                 0,
                                 0.076689316026952642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70939027527666487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42508355820961469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50925360512033635,
                                 0,
                                 0,
                                 0,
                                 0.30365849439572706,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60389035695835291,
                                 0.42292917336778973,
                                 -0.59403703799288199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29202609132832824,
                                 0.8634188205079758,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18551917815846539,
                                 0,
                                 -0.26842375873044821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16070350496165206,
                                 0,
                                 -0.07607036161155388,
                                 0,
                                 0,
                                 0,
                                 -0.41917069516759786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63589827276535138,
                                 -0.23545098393746527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47582680991245646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13195594882303768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37223080892258736,
                                 -0.40996329172235257,
                                 0.16348137582544398,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23299454750457246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30851703673692271,
                                 0.55796560906750914,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29818734496239357,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2945087316844453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11309228045039067,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1201647409845284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017562445855847805,
                                 0.75709728610661098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029508392276699713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60162077653837076,
                                 -0.22189499974604754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76670833036507802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.92220653984299739,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.475071093326077,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83730100727685464,
                                 0,
                                 0,
                                 0.16536135180101497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21059900375243312,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69024216310243169,
                                 0,
                                 0.24003779757267102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28379150328601899,
                                 0,
                                 -0.47472008197115578,
                                 0,
                                 0,
                                 0,
                                 0.0066973209089681296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29978877950984884,
                                 -0.14832501008410781,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21939089179873761,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55305793756565147,
                                 0.53353871785133311,
                                 -0.41102318259488868,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61270775684121093,
                                 0.28570466482355389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056820517685117228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53087279703354828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28971135408115928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34840178261786109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46453507709682262,
                                 0.15889097160312357,
                                 0.08110666680627393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62063705941112413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14710110770468066,
                                 -0.27874520519064749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13158842619191985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30906266950909195,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18339982373758557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54987863635526379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21708786932764954,
                                 -0.046931425323901002,
                                 -0.0031599381896083578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29280612906368764,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0083598367747463858,
                                 0.31080797665489307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15021046267456384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65917523143789036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093870736121482404,
                                 0.45356161398005179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11192864235289526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28823073886489997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55358909599211736,
                                 0,
                                 0,
                                 0,
                                 -0.020729326817676877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0776189095853843,
                                 0.16075597751738166,
                                 -0.45222843511449046,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18690572937200395,
                                 -0.63766451749605713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56316614607359661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.1780185362273905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3501250683936783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83443093226597242,
                                 0,
                                 0,
                                 0.51035228433915236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31917917764328613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09772565191765531,
                                 0.61264935283867528,
                                 0.63323643327416934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044486680848612979,
                                 -1.1110091418636427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33229176197469162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75449635877645749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35943275297266991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27122348785349437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16109521787140263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40916043342553865,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.98755479387909506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53132492649105922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13510602100081953,
                                 0,
                                 0,
                                 0,
                                 0.01561548525232008,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.845332323075073,
                                 0.33061661102330142,
                                 0.43599745988456839,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53441185900074095,
                                 -0.28374592851432545,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24619536612132356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31426011773172335,
                                 -0.17036946359815786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81994990825086889,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29736084274892227,
                                 0.22552459541245073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59491011951729167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57505584552884381,
                                 0.25866717550633289,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17766671044705723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46560350359821273,
                                 0.011486251372598982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.041751870074861627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44053962264049795,
                                 0.47167706476398613,
                                 0.22531452469100371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25785627984978282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18831389808003138,
                                 0.22088050947378166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27094178007799929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36381667006033219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41764043318245736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36957121562029188,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.92955555518493471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3707198955814692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021032556443915738,
                                 0,
                                 0,
                                 -0.78143848122091686,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34902614450104036,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44613131091511171,
                                 0,
                                 -0.015056289722723527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70358546026238356,
                                 0,
                                 -0.45310910875969146,
                                 0,
                                 0,
                                 0,
                                 -0.12063722211245309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24507217575815321,
                                 0.15867942562968718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.024635876669600182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46953759079967605,
                                 0,
                                 -0.050490791796462771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020891887502248522,
                                 0,
                                 -0.042827232873133274,
                                 0,
                                 0,
                                 0,
                                 0.15997733625722121,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40140090469502848,
                                 -0.52643635380006704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55755162893010524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47918037544839293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16016207910581171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6381296277922478,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.084608304784632,
                                 0,
                                 0,
                                 0.52894878076106666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0643215762740441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057896862530771143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61194909953646814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44176993915367396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38861800253863843,
                                 0,
                                 0,
                                 0,
                                 -0.43600632672522666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13849432112553933,
                                 -0.3606965816718708,
                                 0.029622233021090974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60620038125702236,
                                 0.47127528057408341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53978668163450982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62092387782542446,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1206838715584122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46043217688656818,
                                 0,
                                 0,
                                 0,
                                 -0.16466511225945982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15205612553377176,
                                 -0.073284228817725117,
                                 0.55925826499618669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53779031276119182,
                                 0.82673771794285267,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69949656497656498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73750921988005824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3875929449257498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11707784872895177,
                                 0,
                                 0,
                                 0,
                                 -0.44399308817129818,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.90161885809299946,
                                 0.028903754884761684,
                                 0.57287479656530549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20029737675901516,
                                 -0.45619807000439522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50118905141311143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30695388261695566,
                                 0.2316841595219932,
                                 0.15792424782219855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1648069958160967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03857875878839627,
                                 0.30678375254124923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42513317721225635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14223737590560967,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50223062836948662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24574646062669031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5074428917133732,
                                 0.42507255413720424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44001198340697856,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.539832589443758,
                                 -0.12803883118414627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01783405521435736,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22231404426949158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53508373230614092,
                                 -0.5362536991702469,
                                 -0.60590302456556155,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08413827795708867,
                                 0.20370455581960695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56521125878773337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81330467745952473,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9325754043185126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15882590995777707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.086251815972515633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29692604979120796,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3802259397219524,
                                 0,
                                 0,
                                 0.43070796229685299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0906434077219189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36940592424075946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27848810510790339,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16027214646905619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95178236490746437,
                                 0,
                                 0,
                                 0,
                                 0.50983426521181274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64012339352711767,
                                 -0.45519722692421105,
                                 -0.86806211031666058,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.091809322095142851,
                                 -0.098002649894902788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26127726534464923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40498946667004065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16949602935752578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54115618424385581,
                                 0,
                                 0,
                                 0,
                                 -0.3298215042749601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061071877603134699,
                                 0.17427896880270877,
                                 0.2331768409419343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3637580629009494,
                                 0.31379811544844327,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16124783154695943,
                                 0,
                                 -0.39735085774815532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40370279350941057,
                                 0,
                                 0.49257214020781881,
                                 0,
                                 0,
                                 0,
                                 -0.12420790085178998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2706539292402767,
                                 0.41568612195106558,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38604671976597549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48613462753906989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2907816413056401,
                                 0.38736638990812755,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30156991918157633,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14595031950637619,
                                 0.64561639464731324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52374805719671647,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47769306269934264,
                                 -0.011394790374296453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10339720038101745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14185072253788852,
                                 -0.68304821253902748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17544907844738802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25882242038930309,
                                 0.086246312004110995,
                                 -0.13142007998036384,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17599008827852325,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20716718667540379,
                                 0.35424741394877601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7023234468193591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069588594641902021,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4243066469739657,
                                 0.029685879197188618,
                                 0.36996253328135409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52677032981416028,
                                 -0.11621327566593233,
                                 0,
                                 0,
                                 0,
                                 0.2139665174956335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090591504625439953,
                                 0.13233837849390698,
                                 0,
                                 0,
                                 -0.55719171742270057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26263380200403541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34686150704473939,
                                 0,
                                 0,
                                 0.29643948456961294,
                                 -0.26029500566059222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19481528508069629,
                                 0.16215119730052246,
                                 0,
                                 0,
                                 0,
                                 0.067398064866849128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.026184605499425587,
                                 0.16623084736400245,
                                 0,
                                 0,
                                 0.51187508774888901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053185033454444704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69456357186322049,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.062554731901464322,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093359468503519963,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7937224131002022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30823424957461798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021291896068831584,
                                 0,
                                 0.16821164177717166,
                                 0,
                                 0.26959556515914485,
                                 0,
                                 0.18147426284316837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12176714139360753,
                                 0.35469136374158583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20895760317520268,
                                 0,
                                 -0.1691139183306079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.050392820714735158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24929251133512006,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.60150353591993055,
                                 -0.78867227336145607,
                                 0,
                                 0,
                                 0,
                                 -0.45629069279806378,
                                 0,
                                 -0.038786333201610457,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91291001514774428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20325144319070737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54033684453118602,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2322130970005776,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.06846100081361528,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23044432169195572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05746968469200342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8871329509265885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51872818275556287,
                                 0,
                                 -0.55236100415567002,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0029171447671285707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13345803525804456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74553996913973708,
                                 -0.28762943428190141,
                                 0,
                                 0,
                                 0,
                                 0.29508068683535166,
                                 0,
                                 0.078821029274251428,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54439486831166595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39996989567884661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21203766941342725,
                                 0.095700440394766245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29732610123557013,
                                 0.89460681773174777,
                                 0,
                                 0,
                                 0,
                                 0.096403175383002027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.025660898654026376,
                                 -0.026400261643450378,
                                 0,
                                 0,
                                 0.013691033509603615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13487701215756948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16771703277927974,
                                 0,
                                 0,
                                 -0.52613275873504906,
                                 -0.20260992694551885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40530272209941914,
                                 0.10594682018655177,
                                 0,
                                 0,
                                 0,
                                 0.4222495062295003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18341942006599857,
                                 0.0078283672824386863,
                                 0,
                                 0,
                                 -0.072435845464028925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49816186401623741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2030460673571495,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098392823114506631,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32783066841804209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53511721796233358,
                                 0,
                                 0.40515818665177861,
                                 0,
                                 0.55575360638819982,
                                 0,
                                 0.004426936936409942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26220788272602202,
                                 -0.23389670687215583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.029281733089827733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079556644991813585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.702593828866523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2741167837028444,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79382067428443448,
                                 0,
                                 0,
                                 0.37981450228786851,
                                 0,
                                 0,
                                 0.054739917767409337,
                                 0,
                                 0.56035294517546097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30573310795089004,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49440377164200178,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30017367783798987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0846552531715659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63669426490907688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85252736303765586,
                                 0.17996235622405299,
                                 0.038739396055223349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15469084846565734,
                                 -0.035118752810273358,
                                 0,
                                 0,
                                 0,
                                 0.18435855624741176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5719252704201998,
                                 -0.75916188123327999,
                                 0,
                                 0,
                                 -0.00049810942455569274,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035335096979366182,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.047833595114179894,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65964904496285381,
                                 0,
                                 0,
                                 -0.37975510640134991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18016996890596262,
                                 -0.49482146975226438,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21578373517707661,
                                 0,
                                 0,
                                 0,
                                 -0.31109013428808824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80334447197272296,
                                 0,
                                 0.43090078763169065,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46957645297003908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51466516183786337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10503864719399056,
                                 -0.53924478847188562,
                                 0,
                                 0,
                                 0,
                                 0.27012693988479841,
                                 0,
                                 -0.63339051239720379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0016459765108145369,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33454211505608233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24697713413023206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033432981914477161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11216335010311737,
                                 0,
                                 0.0095885122511869397,
                                 0,
                                 0.37534479204853805,
                                 0,
                                 -0.14233938360222453,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65226233503685371,
                                 0.58191202729762215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47513505810407075,
                                 0,
                                 0,
                                 0.011745350749772732,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4960646806284798,
                                 0.59417064035609579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41544542772675297,
                                 0,
                                 0,
                                 0,
                                 0.048937742581074639,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39216554196332232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14027444608190034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12000065305594518,
                                 0,
                                 -0.41394178629892153,
                                 0,
                                 0.32034280338070309,
                                 0,
                                 0.32383762882950562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55038090899744585,
                                 0.3610704111143076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7092567003651804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.70531099788734974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86930984089872743,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3928993522455454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054204810051697638,
                                 0,
                                 0,
                                 -0.23733561116085683,
                                 0,
                                 0,
                                 0.048001057564362855,
                                 0,
                                 0.62075075093301901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27918381443491164,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14896832710771374,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53255584590929883,
                                 0,
                                 -0.75616818827641807,
                                 0,
                                 0.0094011408908245414,
                                 0,
                                 0.037867115755793712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14896599057893656,
                                 -0.14403336782850723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4422198797303506,
                                 0,
                                 0.038411721582332463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2804030195654954,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67479070523562956,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51894605545008643,
                                 -1.2132170769390758,
                                 0,
                                 0,
                                 0,
                                 -0.150125260840761,
                                 0,
                                 -0.021340314843045376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21578207357748563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24451711310500893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0079680278851851031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46481642768737291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059891997215030593,
                                 0,
                                 -0.16337639284435418,
                                 0,
                                 0.30804154710954768,
                                 0,
                                 -0.77579797601046918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14250882524541683,
                                 -0.19116077634786591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.614279382097217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2787578734256308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.038884257881709891,
                                 0,
                                 0,
                                 -0.009185878786806146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74111232151675321,
                                 0.25293429340745616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5298430521707721,
                                 0,
                                 0,
                                 0,
                                 0.32318221532253816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53968160903865581,
                                 0,
                                 0,
                                 0.1012917374661042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28169031801046274,
                                 0.24343929820843133,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67092009580429046,
                                 0,
                                 0,
                                 0,
                                 0.33126702621821091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53129316635026824,
                                 0,
                                 -0.11714708466582595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.9345436895794903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53078699760148729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11471016862474372,
                                 0.16427349658853294,
                                 0,
                                 0,
                                 0,
                                 -0.92448330584837435,
                                 0,
                                 -0.55650688121370406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0033929796496373309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011249318930003822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71505112056424691,
                                 0,
                                 -0.47143224978829484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21941840653929667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5731630150692022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040369906998033986,
                                 -0.12257230800377418,
                                 0,
                                 0,
                                 0,
                                 -0.025290216399383225,
                                 0,
                                 -0.7606253504919902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3593043430457406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29022252658333114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47899012313344258,
                                 0.15809448113801078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19744446410247707,
                                 0.21698416102191892,
                                 0,
                                 0,
                                 0,
                                 -0.070268417408242828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37638482214563468,
                                 -0.26907360459848206,
                                 0,
                                 0,
                                 0.072671373675250464,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64059731670453846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15766519652742053,
                                 0,
                                 0,
                                 0.34179319476040104,
                                 0.30656572002832866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.078265911282977219,
                                 -0.033583179106918305,
                                 0,
                                 0,
                                 0,
                                 0.57566153227712613,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31661181186208903,
                                 0.44029644662044043,
                                 0,
                                 0,
                                 0.21501518602613984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015870583095186463,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33161405706128305,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13725221903145704,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10914717837249667,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52210736507662014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058070181773265991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24156574740434528,
                                 0,
                                 0,
                                 -0.33225588294313635,
                                 0,
                                 0,
                                 -1.3858894037286695,
                                 0,
                                 -0.21721033764732484,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099917074465213598,
                                 0,
                                 -0.013311619077062027,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77697458848895218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30838986924815459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65940126079434136,
                                 -0.055738540919138262,
                                 0,
                                 0,
                                 0,
                                 -0.33203994974984913,
                                 0,
                                 -0.16762882375955393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12653326890336708,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.85705214503359184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.022529378878844694,
                                 -0.48146890475331822,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33033331715594844,
                                 -0.1994482386903304,
                                 0,
                                 0,
                                 0,
                                 0.53179265229331041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47190245478007697,
                                 -0.1928385401539216,
                                 0,
                                 0,
                                 0.077138634373206991,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.066726920851842147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25631136376368979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.277690863127247,
                                 0,
                                 0.20752830990597149,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15034606125569674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43751581720388544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089702860759646036,
                                 -0.034926133769559053,
                                 0,
                                 0,
                                 0,
                                 1.0693554028447845,
                                 0,
                                 -0.27930666673049509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.088780085681262583,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042578777150950223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1816750857043472,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51678273598049995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48110615302450427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.088944875259545114,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.95361850591026909,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30554335719657372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065941293039155038,
                                 0,
                                 0,
                                 -0.023617421998553607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29776360358884274,
                                 0.47819764848374857,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15709494131254248,
                                 0,
                                 0,
                                 0,
                                 -0.80813302619486649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12724748469377786,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4853209911036771,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057038373566656669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099521849667932011,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21850213834281992,
                                 0,
                                 0,
                                 -0.38251926784581053,
                                 0,
                                 0,
                                 0.16457702013977407,
                                 0,
                                 -1.1801398162201355,
                                 0,
                                 0.42781853618780125,
                                 -0.29762047892809618,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40326026661436815,
                                 0.23901216621553414,
                                 0,
                                 0,
                                 0,
                                 0.18126636841123217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.051610910413374012,
                                 0.026074538436049521,
                                 0,
                                 0,
                                 -0.56714251901294388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3412117051242442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18539299840154591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12741241613018561,
                                 0,
                                 -0.38161810468479085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52562451266834553,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14754687831722749,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68087194593854516,
                                 0.44862962761818298,
                                 0,
                                 0,
                                 0,
                                 -0.2398047023123748,
                                 0,
                                 -0.8693591960040532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33826846105223757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61934850240991712,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20492275439002894,
                                 0,
                                 0,
                                 0.91910060756590661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.064796164627144881,
                                 -0.22405696485917698,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15904785676108821,
                                 0,
                                 0,
                                 0,
                                 -0.18320603350483655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80113098294607443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.05216613016183852,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44608492163463842,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.89522142389545278,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.034586304313351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20935773649329098,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.096967583919907396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.9374836854753692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28341870639767586,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59017264385074319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44368369889465437,
                                 0,
                                 0,
                                 -0.30821892461961664,
                                 0,
                                 0,
                                 0.32822867302698117,
                                 0,
                                 -0.5850076847598128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1240303602959385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18141748689206716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57027189840012638,
                                 0,
                                 -0.16479937102731901,
                                 0,
                                 0.52831954559893435,
                                 0,
                                 0.23550517856192832,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27404271300645788,
                                 -0.4354901312721674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22834501139598637,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71103153041965672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27166638716333857,
                                 0,
                                 0.10232760114976086,
                                 0,
                                 0.029213304840537621,
                                 0,
                                 0.42796854676205276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26543445639677293,
                                 -0.32179684555355836,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26222473209266922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74881946643097153,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47668021936330152,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42156130690590843,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.90671804462370265,
                                 0,
                                 0,
                                 0.49249763863424312,
                                 0,
                                 0,
                                 0.22877409885202402,
                                 0,
                                 0.033457122278202946,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20219234184642557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72789082515160319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0045567595480156,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73677336194574705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57995859965423957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42802971216939112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.014445933410457801,
                                 0,
                                 -0.99912253788104044,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23028957938801314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01349669629016266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32369927866857423,
                                 -0.14923494576600527,
                                 0,
                                 0,
                                 0,
                                 0.029112564234879609,
                                 0,
                                 0.062951650929289574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45388377634255772,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63202455372601718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.96679251788700404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2029436571713385,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55220331213093143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14700825104024881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52056927618424365,
                                 0,
                                 0,
                                 0.040708241280876842,
                                 0,
                                 0,
                                 0.30675451844369667,
                                 0,
                                 0.52658559257093596,
                                 0,
                                 -0.16519648597895875,
                                 0.551631647946632,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30184241978792087,
                                 -0.04801747978867614,
                                 0,
                                 0,
                                 0,
                                 0.27588904231144018,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40304302344648635,
                                 -0.27136818194823581,
                                 0,
                                 0,
                                 0.20729924215719125,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3592972456854211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30121670290478186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39547976465691442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030295983896637069,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31572061338662694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42253609039859907,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46959094854998817,
                                 0,
                                 0,
                                 1.4130376010107681,
                                 0,
                                 0,
                                 -0.26991931038894795,
                                 0,
                                 -0.2984839182788358,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11051835533783849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.759388675326651,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81996148452017947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48975719186234934,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16360595796844671,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57993149134526467,
                                 -0.27829364943935364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3511267605002838,
                                 0,
                                 0.64426040034713183,
                                 -0.81278660078773912,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66600974942176894,
                                 0.15981541883985043,
                                 0,
                                 0.55106772864010789,
                                 -0.46360565767330031,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76986140125656743,
                                 -0.22664508154707469,
                                 0.56487438311739835,
                                 -0.39705116668342821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021516216712465216,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.79173247615098319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29601799005544016,
                                 -0.35043798004252469,
                                 0.92287377249297653,
                                 0.6883527779246803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34002826215064741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32483349322960886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.3359410536213769,
                                 -0.17701673347015776,
                                 0.89925760408399802,
                                 -0.18113978593607466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16639554254423733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34519192676455324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14022301444456764,
                                 0.8510038021164853,
                                 -0.16580259190246663,
                                 0.21377069926881404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69464753212643759,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46828408906413199,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57891599986739994,
                                 0,
                                 0.17745306667241145,
                                 0,
                                 -0.19552258852124693,
                                 -0.48546156773592636,
                                 0,
                                 0,
                                 0,
                                 0.56561331431470119,
                                 -0.73558032799895368,
                                 0.049079964746366112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33676080569351113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68383597923636497,
                                 0.48163466270814215,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.032827331677471025,
                                 0,
                                 -0.098190593465971587,
                                 0,
                                 0,
                                 0,
                                 -0.35927929125289554,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.076642159644903771,
                                 0.18636905056090292,
                                 0,
                                 0,
                                 -0.55093414163046206,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49444280911261229,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12650623364235808,
                                 0.16835631807667861,
                                 0,
                                 0,
                                 0,
                                 -0.47669919655959919,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.08591577334196307,
                                 0,
                                 0.45554927113634103,
                                 0,
                                 0.67025816203659516,
                                 -0.20361257585740886,
                                 0,
                                 0,
                                 0,
                                 0.36950748044858334,
                                 -0.12094773784275549,
                                 -0.11550509256882674,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76083774887218214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55406501228530103,
                                 0.063704314627704081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45621895509255866,
                                 0,
                                 0.38123993416066299,
                                 0,
                                 0,
                                 0,
                                 0.26646514877816063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.083626695219287131,
                                 -0.39511868401853684,
                                 0,
                                 0,
                                 -0.040467909210719299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14993550240010353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38656732044593789,
                                 -0.19534676196805181,
                                 0,
                                 0,
                                 0,
                                 -0.44798610054800209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41197328104164521,
                                 0,
                                 0.53946974808880099,
                                 0,
                                 -0.21810173492333665,
                                 -0.12172822808792869,
                                 0,
                                 0,
                                 0,
                                 -0.68007872283136805,
                                 -0.71984704381760256,
                                 0.88986190459723091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24968103568897404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077304810883829317,
                                 0.36249484548057376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80605855265980941,
                                 0,
                                 -0.68799206773767974,
                                 0,
                                 0.79873135977541876,
                                 0.40683807156897495,
                                 0,
                                 0,
                                 0,
                                 0.15623565247743726,
                                 -0.14637478507063817,
                                 -0.32334131841628871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15595929045014151,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16904062745843637,
                                 0.1390522871158118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.7234330683285437,
                                 0,
                                 -0.30049292678649436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38687806227636656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.288785272688317,
                                 0,
                                 0,
                                 0,
                                 0.38143203205957443,
                                 0.088241898928780677,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0074320804966599846,
                                 0,
                                 -0.096407973835901439,
                                 0,
                                 0,
                                 0,
                                 0.33649427131340204,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17001214808056347,
                                 -0.076090893360475392,
                                 0,
                                 0,
                                 0.20936793147327915,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27328798329282572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50049603891918093,
                                 0.44354824900026252,
                                 0,
                                 0,
                                 0,
                                 -0.52628445813987901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54306839120310801,
                                 0,
                                 0.72283326861707775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028513558459475355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0038140760232523996,
                                 0,
                                 0,
                                 0,
                                 -0.42382234967006072,
                                 -0.046215083951398922,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24679492428489411,
                                 0,
                                 -0.27916054250443584,
                                 0,
                                 0.037579224332124093,
                                 -0.78156501978179671,
                                 0,
                                 0,
                                 0,
                                 -0.54174774723888253,
                                 0.31808083982176089,
                                 -0.29192000955807135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020812205946430719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41973550552610306,
                                 0.5319983695822379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39229078108362481,
                                 0,
                                 -0.58186150776889434,
                                 0,
                                 -0.020917449122673598,
                                 0.79223592748747995,
                                 0,
                                 0,
                                 0,
                                 -0.03391735699231721,
                                 -0.38759596183901135,
                                 -0.38669194600083784,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42744814335015302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56763605521122606,
                                 0.44377037673701603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65620909229896929,
                                 0,
                                 0.099419386493293224,
                                 0,
                                 0.73881254215461223,
                                 -0.23197224414907219,
                                 0,
                                 0,
                                 0,
                                 0.31207120133571264,
                                 0.20479037487926602,
                                 0.67316369877257265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87489161870115884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.095756274619963722,
                                 0.50153835056357221,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15270563495480952,
                                 0.85575621926947054,
                                 0.82010159840183849,
                                 -0.63143588058305045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.8716267663190701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058598476518218701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30134945613860886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43342936789029629,
                                 0,
                                 0.19898124424629285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056381257013293801,
                                 -0.2151642882388487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43865407844264315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66110239688818617,
                                 0,
                                 0,
                                 0.052779314053710974,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36437344976940539,
                                 0,
                                 -0.36115956319318082,
                                 0,
                                 0,
                                 0,
                                 0.50264419371213143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15607234850945501,
                                 -0.035305270202737507,
                                 0,
                                 0,
                                 -0.55976106541294812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02794900636331292,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14216704977282299,
                                 0.018997721691681929,
                                 0,
                                 0,
                                 0,
                                 0.35192833459650891,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.046721056161919523,
                                 0,
                                 0.18718822521866993,
                                 0,
                                 0,
                                 0,
                                 0.34285470260910683,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50218610255767593,
                                 0.51470515712478238,
                                 0,
                                 0,
                                 -0.058443794128901425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11636398196980885,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37574805653399856,
                                 0.41147280046527895,
                                 0,
                                 0,
                                 0,
                                 -0.025755832206320523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018504340554021535,
                                 0,
                                 0.15261216746128911,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12303000737810291,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11167973601115624,
                                 0,
                                 0,
                                 0,
                                 0.3273249232210737,
                                 -0.91739673217794315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46813851741193618,
                                 -0.045246988669684421,
                                 0.11615834632622318,
                                 1.1942004415976026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71224550176222368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52365623621578805,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56661045215432715,
                                 0,
                                 0.54557052474632184,
                                 0,
                                 0,
                                 0,
                                 0.14649479325069803,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20551201846780906,
                                 -0.27055131407204447,
                                 0,
                                 0,
                                 -0.40318281212330442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053711445842227423,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0040121205123277021,
                                 0.22506469815406144,
                                 0,
                                 0,
                                 0,
                                 0.16822590595626205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57666063434338266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57164841549880507,
                                 0,
                                 -0.50479709329927669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069949386998923641,
                                 -0.090611497600547319,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0036466826921031578,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25069552301084064,
                                 0,
                                 0,
                                 -0.099476593536968735,
                                 -0.51158127230862793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0379908186421898,
                                 0,
                                 0.60993902202889827,
                                 0.021597887553451073,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02819719500175244,
                                 -0.013107913568890309,
                                 0,
                                 -0.53243075287954134,
                                 0.030651558312991212,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31877102608293917,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45440088840511061,
                                 0,
                                 -0.18198784333438828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33120178920994581,
                                 -0.20268331052278696,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.70718031616425392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.020336945123443334,
                                 0,
                                 0,
                                 0.086559516967809502,
                                 0.67128908558838962,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26878241839729355,
                                 0,
                                 0.10888530156518472,
                                 0.3556106043050084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3181529266876173,
                                 0.73034204045641182,
                                 0,
                                 0.47879650733342466,
                                 0.2932305084112054,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3626981224214218,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4653096568149252,
                                 0,
                                 -0.0038262364209168398,
                                 0.22595232899972201,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73036562812204153,
                                 0.61819396935707782,
                                 0,
                                 -0.09552675006096592,
                                 0.21628130060731321,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.016167054171100249,
                                 0,
                                 0.22497637496199219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33187149576669017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79475550414104568,
                                 0,
                                 0,
                                 0,
                                 0.34217433892186255,
                                 0.30044296927514846,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49113619216009391,
                                 0,
                                 -0.86764083115029855,
                                 0,
                                 -0.20290393929335671,
                                 -0.47216554955680928,
                                 0,
                                 0,
                                 0,
                                 1.0188722005156872,
                                 -0.14343333460704394,
                                 0.69012276970193132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20910597973629572,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16002095085372969,
                                 -0.48618759032390341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.040578297587271342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3291869184047419,
                                 0,
                                 0.64079988129109244,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32560616066390141,
                                 -0.05305037189606597,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5006652762160827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34412058432873488,
                                 0,
                                 0,
                                 0.038032584260816626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49949951476792875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041461867852814291,
                                 0,
                                 0.19344686798638169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.039923350574669961,
                                 0.55016031399593268,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10365153424162146,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24568285027068634,
                                 0,
                                 0,
                                 0.57964257007403908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36405264338951476,
                                 0,
                                 0.54911150880227855,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24049066265425462,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51958296174623975,
                                 0,
                                 0,
                                 0,
                                 0.43425315984478036,
                                 0.22263019549454324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22041598559544787,
                                 0,
                                 0.10857151875262659,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81633419055647982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0501337228561681,
                                 0,
                                 0,
                                 0,
                                 0.51194094427539272,
                                 0.092900954490430232,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13799200145688398,
                                 0,
                                 0.41373812890590772,
                                 0,
                                 0,
                                 0,
                                 0.05167694867051334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43642005354555957,
                                 0.65608333135523533,
                                 0,
                                 0,
                                 -0.035051551613346388,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.074614172243331972,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23453317870434603,
                                 -0.34975489715067598,
                                 0,
                                 0,
                                 0,
                                 -0.045502466048213848,
                                 0,
                                 0,
                                 0.62148546357956214,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20009475692610446,
                                 0,
                                 0.57363388359152145,
                                 -0.13550552065600355,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14936892835100496,
                                 0.017866371655617927,
                                 0,
                                 -0.92460924400272471,
                                 -0.63702417104204923,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48643045985778582,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30142181024014436,
                                 0,
                                 0.6471919056481239,
                                 -0.61119206332045617,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61715746387636972,
                                 0.15024064681332894,
                                 0,
                                 -0.099063331385603082,
                                 0.90995396209806012,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12012543025945549,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65702865745927108,
                                 0,
                                 0.036681027604778219,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1157762528798726,
                                 0,
                                 -0.87103821358629652,
                                 -0.41952369595865246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57829418894608908,
                                 0.64708591765249435,
                                 0,
                                 -0.29493213220475878,
                                 0.23107431244812343,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.022922027365382847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37002067029810115,
                                 0,
                                 -1.016290852089307,
                                 -0.030824211502853499,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88020179859770686,
                                 -0.60959761877292862,
                                 0,
                                 0.054605199132255089,
                                 0.44175788063112209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15211914646088159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.083601606316769245,
                                 0,
                                 0.25897993076831649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5510217240791212,
                                 0.48303116348779335,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0077262687260063675,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.070816665904750428,
                                 0,
                                 0,
                                 -0.60065064010181102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.015724796253911724,
                                 0,
                                 0.062702599388518826,
                                 0,
                                 0,
                                 0,
                                 -0.12010130350284756,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47519414029232798,
                                 -0.11172287573234641,
                                 0,
                                 0,
                                 -0.36412108404947979,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6061224884214943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22380062611676782,
                                 -0.40050841258415548,
                                 0,
                                 0,
                                 0,
                                 -0.18067367312085308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40940468212299164,
                                 0,
                                 -0.44273014551738393,
                                 0,
                                 0,
                                 0,
                                 0.13844679353341854,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33504148671421624,
                                 0.1433368006000881,
                                 0,
                                 0,
                                 -0.12074397737429571,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25396824071458196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50979100303107228,
                                 -0.21219554138727711,
                                 0,
                                 0,
                                 0,
                                 -0.31689001833508995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.47320319162012692,
                                 0,
                                 -0.19414533294926745,
                                 0,
                                 -0.23031299293514013,
                                 0.39960088749348077,
                                 0,
                                 0,
                                 0,
                                 0.26495287277457408,
                                 0.60296947823310698,
                                 0.45771733663312947,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46377045165464359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58792922407659121,
                                 0.68037207652774256,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.94797165518790794,
                                 0,
                                 -0.53933530067220659,
                                 0,
                                 0.48349937619728955,
                                 0.043133225940356831,
                                 0,
                                 0,
                                 0,
                                 -0.35551577520792899,
                                 -0.23872344362317846,
                                 -0.34890299257223367,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19092246246867717,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11778545977017975,
                                 -0.50694241916151794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44794836394553228,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14099071081598491,
                                 0,
                                 -0.27773019735455551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30977349975223833,
                                 0.35663247539952458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14180203266717081,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53028570258569951,
                                 0,
                                 0,
                                 0.42174961017863766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38448909943570098,
                                 0,
                                 -0.038425594178441602,
                                 0,
                                 0,
                                 0,
                                 0.50868725062339459,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33304510728445497,
                                 0.022788747413855587,
                                 0,
                                 0,
                                 0.1526518868946819,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45133255609592837,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24015000845939163,
                                 -0.4343655394221218,
                                 0,
                                 0,
                                 0,
                                 -0.084506766122336097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41269407449474349,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1297439473733957,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0095768493639186159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37673091441342449,
                                 0,
                                 -0.28322418373704356,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61240166933225659,
                                 0.48827944943485091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16089882083057089,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18623860561524308,
                                 0,
                                 0,
                                 -0.32208739453828167,
                                 0.21446701225961895,
                                 0,
                                 0,
                                 0.087588204390297283,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23491885300873247,
                                 0,
                                 0,
                                 0.79446857695850148,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23109294359019161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27806362705724197,
                                 0,
                                 0.04935105823617994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35609853076398945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83881729766806901,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64434224784193894,
                                 0,
                                 -0.16325946581450604,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54768651246906663,
                                 0,
                                 -0.672111484524337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25437403045520163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.94776894530800448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46267538289169424,
                                 0,
                                 -0.37073052857562616,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44822545757496546,
                                 0,
                                 0,
                                 0.65082272081087622,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.069510411530087246,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.183417726422824,
                                 -0.69222947525715262,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51308493899554486,
                                 0,
                                 1.2358390646865192,
                                 0,
                                 0,
                                 0,
                                 0.24000368811020864,
                                 0,
                                 0,
                                 0.41865933811338879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.089058703289969704,
                                 0,
                                 0,
                                 0.012822585960954661,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10230374024943333,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.45641971017529653,
                                 0,
                                 0.46226025897757406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57145180271480589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76661343417221561,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12703871053146332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65209722080280452,
                                 0,
                                 -0.492510200190309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.058440167054757908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2398800027048737,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05848611693980045,
                                 -1.1041500152306172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47239792445269169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28332317807289814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16892488341404982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.067178822898261104,
                                 0,
                                 -0.54396327438825109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22035795747189976,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21155340362466607,
                                 0.47152569128205102,
                                 0.16110215037434666,
                                 0,
                                 0,
                                 -0.16130924019744003,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0029535254777413034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0196324549261655,
                                 0,
                                 -0.37064387333434062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.69855527166565445,
                                 0,
                                 -0.0030020421303676064,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22061571422769913,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.607044865566847,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03932380766445992,
                                 0,
                                 -0.75549400436950787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16562173032338498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34058944330896601,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80991746768612405,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.057399573276789538,
                                 0.26269526622894618,
                                 0.35228685476255317,
                                 0,
                                 0,
                                 0,
                                 0.17782852609589539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40116336551605603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49477670684240987,
                                 0,
                                 0.042104220853803269,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.028110106665819895,
                                 0,
                                 0.20862557791759584,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27820491767898925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.65802291123584422,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.77746952804046054,
                                 0,
                                 0.082984212045921282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32789322348734873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085441132598763403,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1464593199551414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3278801810244566,
                                 0,
                                 -0.77542475396326138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30334933975875239,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14283212833522507,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42623161704789658,
                                 -0.11436998476225929,
                                 0,
                                 0.11040075675807458,
                                 0,
                                 0,
                                 -0.33130158915753916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41500868009543934,
                                 0,
                                 0,
                                 0.29324883000877094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.097537925511632179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49025640459174902,
                                 0,
                                 0.073848337385941112,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60374272913373506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.021071850219086672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21265303264636129,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4336653229225797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24349119321984006,
                                 0,
                                 -0.48163825484804079,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21548546962641557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26574203355444009,
                                 -0.39563921650834605,
                                 -0.37173626406095056,
                                 0,
                                 0,
                                 -0.25146496206287638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11952668161111829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42610634694512872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20289458502549385,
                                 0.52741088687973292,
                                 0.48067825688534571,
                                 0,
                                 0,
                                 0,
                                 0.50375262838207024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57347351829497384,
                                 0,
                                 0,
                                 -0.31929646547988522,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40326633496652409,
                                 0,
                                 0,
                                 -0.018320678596341136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11304678156445275,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28136915350521352,
                                 0,
                                 0.49420070814758943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26464313984113225,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32812481559737722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1703935372582101,
                                 0,
                                 0.29135443259023347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20605345951574389,
                                 0,
                                 -0.67078725624170266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0043908342627705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32073714499640626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.71528247443102322,
                                 0,
                                 0.79092095767915715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10085273177836518,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028745035670755318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13415762728328401,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.1004088304499433,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1439945035479917,
                                 0,
                                 0.20024890882124222,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.033247202799751796,
                                 0,
                                 0.62288644835417128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3896592013988342,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22770976336396886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.89033330393920607,
                                 0,
                                 -0.48300047259295159,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22775356656911699,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21794498162241435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3106142967525074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51048718877527299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16855251143057351,
                                 0,
                                 -0.264898752658557,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15432061612027828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25763045303897636,
                                 -0.57236858968327631,
                                 0.27376706697673858,
                                 0,
                                 0,
                                 0.064013773168521748,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4885967867771534,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44363127778035172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0014112606529642,
                                 -0.18093954962064301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8226803529735992,
                                 0,
                                 0.56172501437909639,
                                 0,
                                 0,
                                 0,
                                 -0.12243218977987,
                                 0,
                                 0,
                                 -0.70690175150291334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.062497060156480183,
                                 0,
                                 0,
                                 0.1210315002516193,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40041509449522467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53275085045609027,
                                 0,
                                 -0.081975564438574983,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1259764117608099,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45345801157740734,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13278770697791337,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26918501402495826,
                                 0,
                                 0.16920411348989778,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21275260379521235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48101610065989348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.66955008919211634,
                                 0.74854496504871526,
                                 0,
                                 0,
                                 -0.4646170863651124,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.01660913086952354,
                                 0,
                                 1.0546487184558579,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80510411249194869,
                                 0,
                                 0.35624900076148414,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31625040169913116,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15389752408957053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051431679501748678,
                                 0,
                                 0.062697778886818115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42444890992044598,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72111526780200619,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21111884241970935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24658763719687449,
                                 0,
                                 -0.17364437289240936,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0331908088715964,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18996936571358866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40747445869607718,
                                 -0.62895952875557037,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15933917482856905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29768326572393938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087186831930062311,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.61684728987425275,
                                 0,
                                 0.076088338499984393,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.076235275782342238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62427491356525844,
                                 -0.30763071186441554,
                                 -0.006678199621780366,
                                 0,
                                 0,
                                 -0.04349602874952066,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39196861883500528,
                                 0,
                                 0,
                                 -0.26428007126658726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18699431920909337,
                                 0,
                                 0,
                                 -0.41719582752127693,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66450796677420176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32752071974933694,
                                 0,
                                 -0.13273049027486034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03223924692294719,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13737345919025376,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027180783089539265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47711836071161606,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20541428751598179,
                                 0,
                                 -0.30140988777062716,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68220586428607122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.089826183534116588,
                                 0.058526447873005108,
                                 -0.37597349714224809,
                                 0,
                                 0,
                                 -0.038076994135348097,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.003154011325174828,
                                 0,
                                 0,
                                 0.011424034729551863,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74115778234935159,
                                 0,
                                 0,
                                 -0.30489279023943905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33177558097227988,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.054766006581964302,
                                 0,
                                 0.3890553893703933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30519931874347539,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.012119505740044362,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29570576052566933,
                                 0,
                                 0.57809514440158016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32991430896037893,
                                 0,
                                 -0.081290210632484025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27297254813939331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53301092368635317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19127310303357525,
                                 0,
                                 -0.74364852767676826,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.80002136009930236,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48877659061580692,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26870731289354627,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.75834664054413348,
                                 0,
                                 -0.30766272721368326,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49746273494120996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.5360657646211654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50225552897067027,
                                 -0.19033298975940172,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22703694665001245,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.24081457495503733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17018298167894105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23892403403130211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88008824975092004,
                                 0.15024680954714587,
                                 -0.34089566859597864,
                                 0,
                                 0,
                                 0,
                                 -0.024774396316380252,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79272328942513948,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22601036490004198,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.079717806145882419,
                                 -0.04644299147776583,
                                 -0.39734258702643432,
                                 0,
                                 0,
                                 0,
                                 0.39257622167135903,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.02546988543754615,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.033480710511147871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29141276968720614,
                                 -0.79178309341938158,
                                 0.41499182558815334,
                                 0,
                                 0,
                                 0,
                                 0.33789087334958379,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.2653303615778295,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55403143022708301,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42554635449121192,
                                 0.12938972527973788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15342417212274814,
                                 0,
                                 -0.80471874076080718,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66845995024666527,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19997362006791652,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53762810736298194,
                                 0.59315326702012028,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.7820742465938012,
                                 0,
                                 0.32575974797059348,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069690273272045938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20478480954046302,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17430920341451775,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32159429208061541,
                                 0,
                                 -0.13773012506771498,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25891059267483729,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43089722715099243,
                                 -0.018862612727278245,
                                 0.63685832548542165,
                                 0,
                                 0,
                                 0.37653530097863258,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4600989323777806,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23060949584438448,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29951196645853112,
                                 0.034313717961929058,
                                 0.44557062479681825,
                                 0,
                                 0,
                                 0,
                                 -0.66761530979836869,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38058903233740726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3194478083831318,
                                 0,
                                 -0.08677840221613925,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54363329960616358,
                                 0,
                                 0.51201723485870132,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27981717524260985,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46343963245964864,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58413947174588043,
                                 0,
                                 -0.21435944153434119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77792022998671551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44924771715075656,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54468972114396019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.087413759241331809,
                                 0,
                                 0.50359194804262331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.67964605925519506,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49328327654268722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48703434196284706,
                                 0.25272990652031918,
                                 0,
                                 0,
                                 -0.092315443275514025,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.62145617917245144,
                                 0,
                                 0.31569341763445391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.097946771169856034,
                                 0,
                                 -0.99332535657716881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34027049798250486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32221490901851624,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45527425781074082,
                                 0,
                                 -0.46434869247507665,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14302629026949409,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22525312913209297,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65309023853204995,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27831137410973361,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12924201769839819,
                                 0,
                                 -0.09146187287543471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35737697711846933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3159007809792872,
                                 -0.38932084938721245,
                                 0.18256107431385005,
                                 0,
                                 0,
                                 -0.088302304856387431,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.78047999130965517,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19124870514083406,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015906685895994723,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10020015545596533,
                                 0,
                                 -0.42118489622441835,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16843529342810551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26886569257239967,
                                 0.10626855297421101,
                                 0.22683258197694467,
                                 0,
                                 0,
                                 -0.056390345076690315,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11202169672814359,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41861333330116296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3906601471458741,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54846266343684824,
                                 0,
                                 0.17838965277767929,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43073402588237053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21654926631656068,
                                 -0.17793626995321579,
                                 -0.11692962267581612,
                                 0,
                                 0,
                                 0.22182260041609567,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62185443637108795,
                                 0,
                                 0,
                                 -0.18883097812547386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11763554784075698,
                                 0,
                                 0,
                                 0.025770949822475971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44928682651854629,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027370032518305019,
                                 0,
                                 0.59874079278176173,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.045159158441379445,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4413437973213285,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.67153686092853715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.011649059638424466,
                                 1.1127533574380142,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.83871435690380414,
                                 0,
                                 0.14366041111197878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.085686284880907168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.09162114136320347,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16385614174055635,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23262788902620976,
                                 0,
                                 -0.26223156971520867,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.03635414639862744,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12576525177656683,
                                 0.02417616470667025,
                                 -0.33980368120729504,
                                 0,
                                 0,
                                 0.83746278110009875,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051660355572065331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3795436965124068,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35127915562190115,
                                 -0.53438260223922862,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60496658874848097,
                                 0,
                                 -0.10978379818257317,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18208441299231559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25576496080576488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36000081426160385,
                                 0,
                                 -0.10018295350727158,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58433308373826798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.53724030163241887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15404493976010894,
                                 0.94029897900152115,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10148414945743642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61207720707854396,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0052365890776563673,
                                 0,
                                 -0.78614193690731526,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059584925915289952,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42630609204851999,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024346225175179079,
                                 -0.099561670275530936,
                                 0,
                                 0,
                                 -0.33528471919599662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48994705746461364,
                                 0,
                                 0.5994807973663866,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72294362146911118,
                                 0,
                                 0.20192283846948592,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84284676278738502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52128721151107382,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092950202747754118,
                                 0,
                                 -0.37023693002320024,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74551794864084908,
                                 -0.37330648316213982,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23279264958623286,
                                 -0.10362841411218504,
                                 0,
                                 0,
                                 0.7107150421212628,
                                 0,
                                 0,
                                 0,
                                 -0.56690941829856101,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.64017673888632587,
                                 0,
                                 -0.27237557595314216,
                                 0,
                                 0.053897429480415052,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8785645630748955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48746207998824381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.73414961883771368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17667960292733798,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14692220937696629,
                                 0,
                                 0,
                                 0.18696553691782783,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.203378123911585,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57611088010981149,
                                 0,
                                 0,
                                 -0.24237610664364648,
                                 0,
                                 -0.31646574279032902,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.037886153294112802,
                                 0,
                                 -0.17863232133408014,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51974346861970855,
                                 0,
                                 0.64065431111240334,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.080500953108881751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14033775563399387,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.29136792929756966,
                                 0,
                                 0.12695200227279824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3893155357621837,
                                 0,
                                 0,
                                 0,
                                 -0.20927263242315652,
                                 -0.63928953978670688,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29267613811432147,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.078205861064622809,
                                 -0.76985951142808873,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42136917146892794,
                                 0,
                                 0,
                                 -0.21976278407636102,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44392889434999383,
                                 0,
                                 0.25075787243266701,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28500609362746598,
                                 0,
                                 0.46890842121086196,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33524891723939843,
                                 0,
                                 0.19038983886322161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32036561652028916,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14196632191691341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19661415377905411,
                                 0,
                                 0.35896828238875667,
                                 0,
                                 -0.33368592361773669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.79873842745495793,
                                 0.30881943316766591,
                                 0,
                                 0,
                                 -0.49730000374516797,
                                 0,
                                 0,
                                 0,
                                 -0.14307850343160544,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.49029890810144622,
                                 0,
                                 -0.049386776980848653,
                                 0,
                                 0.27147606707880223,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58293889977364588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19228997240893048,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49762022134202483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55150992473039373,
                                 0.8274195031326872,
                                 0,
                                 0,
                                 -0.35262264128671039,
                                 0,
                                 0,
                                 0,
                                 0.51757635600474128,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23163231960896721,
                                 0,
                                 -0.45357875723150998,
                                 0,
                                 0.023449337113908019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32478777919106389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46250148947981817,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85381455242994719,
                                 0,
                                 0,
                                 0,
                                 -0.0078139211686838739,
                                 -0.26507596660848276,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32511228761302791,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.021817944086093444,
                                 0.1907165734345829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.56213003768040226,
                                 0,
                                 0,
                                 0.84041925779113646,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59061524236754237,
                                 0,
                                 0,
                                 0,
                                 0.20679542343093271,
                                 0.20159101410442418,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3960543672356226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41314371922660909,
                                 -0.87809964132292162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58170371216256889,
                                 0,
                                 0,
                                 0.36282076104829802,
                                 0,
                                 0,
                                 -0.65274163135790109,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11523305964400669,
                                 -0.15783550846579675,
                                 0,
                                 0,
                                 -0.18106336108837115,
                                 0,
                                 0,
                                 0,
                                 -0.72414441493003678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55473851431416243,
                                 0,
                                 0.20338662327608142,
                                 0,
                                 0.56385679154395074,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28631715705937144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39758805473491787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2988189230563329,
                                 0,
                                 -0.4569582192188163,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59363773617491522,
                                 0,
                                 -0.2040492278413118,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.065679024045899592,
                                 0,
                                 -0.242279418746676,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31983571348473189,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.09320845035925035,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34361428129325433,
                                 0,
                                 -0.12565056236691502,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.027064005860270662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27966670771900803,
                                 0,
                                 -0.80480269966157958,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36819133680050309,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.015875602860261365,
                                 -0.18650724068480509,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30306664300800912,
                                 0,
                                 0,
                                 0,
                                 0.10438127516331039,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34989552144252722,
                                 0,
                                 -0.0054430111145632523,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17280989002564257,
                                 0,
                                 0.10192418143550168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20702567531360822,
                                 0,
                                 -0.19301425752657797,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12455330468865548,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.86107449998098928,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0058990222346598786,
                                 0,
                                 0.013414481548037165,
                                 0,
                                 0.74306013537478965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58358390245619285,
                                 0.65291916073527378,
                                 0,
                                 0,
                                 -0.2900549252509414,
                                 0,
                                 0,
                                 0,
                                 -0.25120037497194353,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76800910304795722,
                                 0,
                                 -0.17050272264020935,
                                 0,
                                 -0.11644530946009871,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19539107173499942,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13849963781448471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16512200956769174,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24747424876502722,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36947756926453423,
                                 0,
                                 0,
                                 0.29292736525029411,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.82958602532846137,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030953662660986314,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0132720760429375,
                                 0,
                                 0.74621915298032038,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17510617633619241,
                                 0,
                                 0,
                                 -0.4180066461706623,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0095413286740609,
                                 0,
                                 0,
                                 0,
                                 0.20503658074957207,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.028678996099804469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.171697576936788,
                                 0,
                                 0.35517834629630324,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.76424367171339413,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10493007255106311,
                                 -0.29715356744529575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37896241638847949,
                                 0,
                                 0,
                                 0,
                                 0.12866364684318754,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.01858019484213308,
                                 0,
                                 0.95942192545794136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25720302254706484,
                                 0,
                                 0,
                                 0.53382353445723951,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13256015251244177,
                                 0,
                                 0,
                                 0,
                                 0.96450222799198282,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092774181163811087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74621662139787182,
                                 0,
                                 0.23170491023259263,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39012166296753104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.069896734531823296,
                                 -0.27554106512748094,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.098434731497993991,
                                 0,
                                 0,
                                 0,
                                 0.37171736505254127,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.084141562173051881,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.03836295335861141,
                                 -0.43910108428801414,
                                 0,
                                 0,
                                 -0.11550739821383302,
                                 0,
                                 0,
                                 0,
                                 -0.00088460590864178346,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42582604560557014,
                                 0,
                                 -0.91341710062813819,
                                 0,
                                 0.51821703412127085,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26463263553965105,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13384396978115454,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.633981828802334,
                                 0,
                                 -0.12546624545799751,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.43513406679879901,
                                 0,
                                 -0.2053654399761469,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11058429351792309,
                                 0,
                                 -0.39948149911888053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099411426119116908,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32342520897923804,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21694935999331405,
                                 0,
                                 -0.13206349084712243,
                                 0,
                                 -0.67703451129943437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2498059282651387,
                                 0.16287981827602624,
                                 0,
                                 0,
                                 0.45681079533581781,
                                 0,
                                 0,
                                 0,
                                 -0.089459038201968877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52584991421440808,
                                 0,
                                 0.10574057715439053,
                                 0,
                                 -0.86587382960352399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20764163153414883,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.69176334141755091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044691446835853355,
                                 0,
                                 0.099611378964948788,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.18323689616708061,
                                 0,
                                 -0.44589088964705087,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17173314265646306,
                                 0,
                                 0.15424976671148138,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0040294050645797996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17159619711043933,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55736602809458313,
                                 0,
                                 0.60189879474389474,
                                 0,
                                 -0.23817059315391381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39412364983307496,
                                 -0.016390190884414721,
                                 0,
                                 0,
                                 -0.2017528177561228,
                                 0,
                                 0,
                                 0,
                                 -0.027086343695948041,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11811813960873097,
                                 0,
                                 0.42488410145197908,
                                 0,
                                 0.48005532383170341,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16193446797619029,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.2647560616243607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1648083624418723,
                                 0,
                                 0.16783956144039927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.96958279103200495,
                                 0,
                                 0,
                                 -0.12073927175068816,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.47940261367589776,
                                 0,
                                 0,
                                 0,
                                 0.98657504053052969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.87624214059630956,
                                 0,
                                 0,
                                 0,
                                 -0.015551806199628912,
                                 -0.16901552242661511,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32064725434947167,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.05739230785307306,
                                 -0.13057022925583833,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.38768397159574053,
                                 0,
                                 0,
                                 0.59983708703534977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.06713686924035045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2050484546822684,
                                 0,
                                 0.081849877574227126,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10829214765291487,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19722483912972191,
                                 -0.81786126025972217,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20015250684412964,
                                 0,
                                 0,
                                 0,
                                 -0.43262625454248471,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.074661596198343172,
                                 0,
                                 -0.063213029676875185,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6952014797967343,
                                 0,
                                 0,
                                 1.4433656624471705,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1657274155935855,
                                 0,
                                 0,
                                 0,
                                 -0.11493085244968421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25015938550953493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4114153240320596,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53577932651770088,
                                 0,
                                 0,
                                 0.49358865753390307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48673108241628626,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.023692125972051621,
                                 0,
                                 0,
                                 0.032112291492964296,
                                 0,
                                 0.19641171786724984,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30222538684494765,
                                 0,
                                 -0.20811769011530407,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.030595927315515331,
                                 0,
                                 0.28812414252265733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74832474152773143,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.04332409488531884,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.058248217962059035,
                                 0,
                                 -0.42015080302000091,
                                 0,
                                 0.15936853884467331,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.59848026383034014,
                                 0.22739188442611857,
                                 0,
                                 0,
                                 -0.40509363538162535,
                                 0,
                                 0,
                                 0,
                                 -0.73416399546465827,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54506131128620705,
                                 0,
                                 -0.11699044560754919,
                                 0,
                                 -0.76819735805173905,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32412012755465563,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.041061105068794436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34461194275353113,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78547747914394117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49944851115341743,
                                 0,
                                 0,
                                 0.01860011031025878,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.077336652384344368,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.092152056246079042,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62056214602704851,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30068999317590633,
                                 0,
                                 -0.26736189858435166,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23078705198124486,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.042330889740026585,
                                 -0.26458148502214435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48010601225894589,
                                 0,
                                 0,
                                 0,
                                 0.3121635041055591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1695697973810017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20190686341811945,
                                 0,
                                 0.13439436033456481,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20388883428350202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.81804977233276244,
                                 0.10346409484916241,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26802416356580827,
                                 0,
                                 0,
                                 0,
                                 0.34510867896042408,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23748073064578701,
                                 0,
                                 0.030071625364751997,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30644964462274288,
                                 0,
                                 0.5614448283750183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49668860245202068,
                                 0,
                                 -0.044714451560253284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.018844710346824389,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.043665971038571436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.53097478297111755,
                                 0,
                                 -0.025921220096866211,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.28116412563978482,
                                 0,
                                 0,
                                 -0.46427019248668649,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.768325242008015,
                                 0,
                                 0,
                                 0,
                                 -0.49271144522842875,
                                 0.6666123499113209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66141998356624787,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.24143644542008336,
                                 -0.65136117346110645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33067937106237605,
                                 0,
                                 0,
                                 -0.066815548608019859,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25114453038963408,
                                 0,
                                 0,
                                 0,
                                 -0.1123426040420623,
                                 -0.49361094269608685,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.57750933127413961,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17443842196591347,
                                 -0.47435264437694707,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58415722629490696,
                                 0,
                                 0,
                                 -0.52139417253107023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.057249154499689238,
                                 0,
                                 0,
                                 0.20843124372955235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11129262286075943,
                                 0,
                                 0.79871164702356323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30609279098261327,
                                 0,
                                 0,
                                 -0.014506395327853607,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.73259446347851553,
                                 0,
                                 0,
                                 0,
                                 -0.55545735761461179,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061716534007023122,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.50125579265546183,
                                 -0.68273972449173548,
                                 0,
                                 0,
                                 -0.63696542991770622,
                                 0,
                                 0,
                                 0,
                                 0.26040672683556543,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19576775368565935,
                                 0,
                                 -0.091742600977585714,
                                 0,
                                 -0.47539951649779849,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63397891337143519,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22711550050643076,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63588872144575026,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.059037923651176646,
                                 0,
                                 -0.26588805943331645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14218143757658169,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.38721100101857253,
                                 -0.066476954602813332,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.58224602247974611,
                                 0,
                                 0,
                                 0,
                                 0.088803494705563299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.49274197595802777,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.093348189506163123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.36177719863842434,
                                 0,
                                 0,
                                 -0.26295514087726612,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16544097001462996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72186743832719669,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.72591267583175889,
                                 0,
                                 0.42156521757281096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.56550759359448588,
                                 0,
                                 0,
                                 -0.55337671475403694,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.59067709505760058,
                                 0,
                                 0,
                                 0,
                                 0.17222233401859202,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52302597138133344,
                                 0,
                                 0,
                                 0,
                                 0.14141663099311452,
                                 -0.044641492700301308,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.44227814500609458,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0924180139748556,
                                 0.055259793935520551,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.032235081346690619,
                                 0,
                                 0,
                                 -0.18533190499240537,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40880910892500721,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39844200321890616,
                                 0,
                                 0.074254292813728959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.037359969114752645,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35217149358035721,
                                 -0.21671991207251814,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.27099540317860737,
                                 0,
                                 0,
                                 0,
                                 0.65021444579003573,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25077638683860481,
                                 0,
                                 -0.48945699897438727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32098680597204887,
                                 0,
                                 0.12962631695602514,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.052980082342783882,
                                 0,
                                 -0.25267206011232168,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42274720709460512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19208905632983442,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.26079633305077987,
                                 0,
                                 0.47689552861845658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30382726243386227,
                                 0,
                                 0,
                                 0,
                                 -0.88854310547027859,
                                 -0.031344082247708904,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25819436216443492,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.39298310114578694,
                                 0.30482693598852828,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.2082105922837176,
                                 0,
                                 0,
                                 0.3508637469728238,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.090630885611527212,
                                 0,
                                 0.56869610302014795,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15448505146229402,
                                 0,
                                 -0.28259663912721678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.5273877130913065,
                                 0,
                                 -0.35372787597388117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15529954354692177,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.1878370240315318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21743117320990596,
                                 0,
                                 0.23389329264570302,
                                 0,
                                 0,
                                 -0.098118780051905802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.33554357471544521,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41774291942577596,
                                 0,
                                 0,
                                 0.7524070132774493,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.012866481352767016,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37012458411519117,
                                 0.18641262766482453,
                                 0,
                                 0,
                                 0,
                                 -0.83445881563622093,
                                 0.37662903201349063,
                                 0.31782647540093878,
                                 0,
                                 -0.088969544984147053,
                                 0,
                                 -0.10067999496197595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41945453750493084,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21336850844341648,
                                 -0.30785617194930226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33471318052543975,
                                 0,
                                 0,
                                 -0.41447885067146562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.93187000755979432,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.64796954076404911,
                                 0.08426946887729625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44253410755033307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52643307726571253,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.059476981739407714,
                                 0,
                                 0,
                                 -0.54618219288605918,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.35400592625024208,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66528474985607589,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28914963608619265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.3417420261168198,
                                 0,
                                 -0.2493045178597682,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.061803767839023249,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20423340989026467,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41003220904355364,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0086922491534574577,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22127945592947207,
                                 0.46830928238741643,
                                 0,
                                 0,
                                 0,
                                 0.43697443600605779,
                                 0,
                                 -0.4460962193542084,
                                 -0.30629695186423733,
                                 0,
                                 -0.0047651050728519662,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.19498600323316737,
                                 -0.29260659112429371,
                                 0,
                                 0,
                                 0,
                                 -0.247354333389048,
                                 -0.3485879117535195,
                                 0.29139816816808928,
                                 0,
                                 -1.0260381252512674,
                                 0,
                                 0.33761272683488386,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.2408716529245731,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22131434390899352,
                                 0.039149031686337023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55461659288608045,
                                 0,
                                 0.50811254247389903,
                                 0,
                                 0,
                                 0,
                                 -0.31812362924652449,
                                 0.40255204848261461,
                                 -0.1698770129286967,
                                 0,
                                 -0.44875278553176046,
                                 0,
                                 -0.50906286665816625,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024188025369722286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.48503367948358822,
                                 0.68600678994862996,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.34981463516358802,
                                 0,
                                 0.27523918273746428,
                                 0,
                                 0,
                                 0,
                                 -0.25168403832622405,
                                 -0.35994159040984364,
                                 0.38756876160293063,
                                 0,
                                 -0.23067036863017024,
                                 0,
                                 0.28285150669821135,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46135017053251443,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.50489908708054632,
                                 -0.77398259541555525,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35418948851927978,
                                 0,
                                 0,
                                 0,
                                 0.83121495412894375,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11086513045191117,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.4403574299269053,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48952220781162925,
                                 0,
                                 0.4273428398251638,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.85178825155568338,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10150304049552017,
                                 0,
                                 0,
                                 0,
                                 0.27439311079442968,
                                 0.1786992523161805,
                                 0.69084470467032877,
                                 0,
                                 0.42770510034326248,
                                 0,
                                 -0.083104433907080943,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32079879483909063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74027733408705032,
                                 0.60030820000825336,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29784813852875658,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11245098690964955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12393199490546483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6019649559284479,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12618394654660672,
                                 0.27853309209626792,
                                 0,
                                 0,
                                 0,
                                 0.033288012901654243,
                                 0,
                                 0.17129797895128177,
                                 -0.20206605467500363,
                                 0,
                                 0.19490034053012634,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.63785800431652384,
                                 0.59580050291752129,
                                 0,
                                 0,
                                 0,
                                 -0.30832508975624684,
                                 -0.54567480367639243,
                                 -0.67838933652270772,
                                 0,
                                 0.10169013430715904,
                                 0,
                                 -0.26583339260059757,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27173499191674899,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13075756361358426,
                                 -0.18902483771252307,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.8636865944123171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54436679729553705,
                                 0.482328587151794,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.14894207046187305,
                                 0,
                                 0,
                                 0.30843182253595308,
                                 0.50302652865726949,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.30761179856780235,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.042596334300991051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.065075645713682392,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21535988584405863,
                                 0.098332825666436488,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.21235412968081513,
                                 0,
                                 0,
                                 0.87689838049263402,
                                 -0.22813680537447351,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.11181876134970162,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13303845199933809,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21830405812983456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.91220508738091655,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0064569917233352134,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.83447357347555318,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.024171725392923116,
                                 0,
                                 -0.94782712788442636,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.044824913936277078,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54961041793134713,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20456679552968293,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51620424660876307,
                                 0.96322707512382888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.40577369348917935,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41206548931035181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.52834332041828569,
                                 0,
                                 0,
                                 -0.29139331328121754,
                                 0,
                                 0,
                                 0,
                                 0.38504559867310045,
                                 0,
                                 0,
                                 0,
                                 -0.043182443878102272,
                                 0.84227756647815566,
                                 -0.013842816416386773,
                                 0,
                                 -0.035088485216553333,
                                 0,
                                 0.29690626395282371,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.72018389558217233,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25617302298580946,
                                 0.074760086880764243,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31420117255358931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13957305423047286,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.54477726144742877,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.32007074225721893,
                                 -0.292287690499484,
                                 -0.6735411475890144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20543136659352088,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.3102045450060697,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.25982611529870603,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33202849517590449,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18391985501920111,
                                 -0.58434602609155117,
                                 0,
                                 0,
                                 0,
                                 0.09606413371420354,
                                 0,
                                 0.1177504570275183,
                                 -0.53375160862481685,
                                 0,
                                 0.030640454102622644,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20447667868162436,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39824050989750015,
                                 -0.089197794195310653,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45830636602491132,
                                 0,
                                 0,
                                 -0.078160399389926694,
                                 -0.063995025619030588,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1299528586739184,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57342058631295456,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51720421404559391,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41579070405640034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.14502518378405294,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65054054981348874,
                                 -0.77751678935991575,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.10802592285351435,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.16317528088014965,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.090712793431516808,
                                 0,
                                 0,
                                 -0.73089212651327062,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.10047203939641726,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22167500217986205,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.23314785988403747,
                                 -0.17050497277751209,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.93595701322454183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45826872901955978,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.78541129086590711,
                                 0,
                                 0,
                                 0.1824861261427872,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0012726715066236757,
                                 -0.64354663158531689,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.099082572645355943,
                                 0,
                                 0,
                                 0.090833391678059372,
                                 0.45384986267499766,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.26644432295002057,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.30049677901203975,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44778059667391412,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.42698730946782282,
                                 0.2841047563581266,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0020866046903664863,
                                 0,
                                 0,
                                 -0.12811243216496213,
                                 -0.16870621230981381,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74972732288662192,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20543921737639304,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29629556018083247,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.32232543797620022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.15356584679059879,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74649471805223888,
                                 -0.11549855520107061,
                                 0.19021446861654678,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51550753469608568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.087227471657968764,
                                 0,
                                 0,
                                 0,
                                 0.66630291305033584,
                                 1.0073831559656574,
                                 -0.20000763306742045,
                                 0,
                                 -0.56276364004190349,
                                 0,
                                 -0.048005069095149427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.77813950568305945,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.026410770783884749,
                                 -0.62318505404934621,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.080470269643053149,
                                 0,
                                 -0.32617874281965314,
                                 0,
                                 0,
                                 0,
                                 -0.43674746985743057,
                                 0.30959007458654081,
                                 -0.60954363219468644,
                                 0,
                                 -0.054827260481406348,
                                 0,
                                 0.8492767725774768,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.6650604127477372,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41097875783901344,
                                 0.25732429290769082,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20023913072562508,
                                 0,
                                 0,
                                 0,
                                 0.0039452912882630559,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.76284168038688893,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55036436035580838,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.017791688171083918,
                                 0,
                                 -0.5101174800471977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -1.0392865222136483,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.12876063568468971,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.46556280438424119,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.81713066949877144,
                                 0,
                                 0,
                                 0,
                                 0,
                                 1.0791087530468562,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34282078142462813,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.84680531505328593,
                                 0,
                                 -0.47013876662426424,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46163528810748733,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.68458699492531672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.22780279887490987,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.52871338510415788,
                                 0.31833753022959199,
                                 -0.12519671385328265,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.28791611157287977,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.23189050052559226,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.22194176612165023,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13552715913518698,
                                 -0.648171587171259,
                                 0.58245372682690399,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.34528580486733063,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51603238378049821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17179332750139281,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.20580151466587049,
                                 0.49395305174249404,
                                 0.30341778460356955,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57078139312488829,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.55755884215860418,
                                 -0.20565408504512284,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15440065738208175,
                                 0,
                                 0,
                                 0.037558880931519489,
                                 -0.66400147417695532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.33717744082645296,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.25639896631186299,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.035458258007485886,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51475900121792595,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.88006790574492821,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.54636297670162037,
                                 0.57268087838133541,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11530954302401404,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.62165412811852183,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.45998835740635846,
                                 0,
                                 0,
                                 0.12105331299979666,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15305106039778288,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36400909954454019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.20616086213569329,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.55115648799175843,
                                 -0.079018419185640995,
                                 0,
                                 0,
                                 0,
                                 0.37895787383462892,
                                 0,
                                 -0.086695041943738671,
                                 -0.20643517772046552,
                                 0,
                                 -0.54391064474938,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.044426230385813434,
                                 0,
                                 0,
                                 0,
                                 0.42688185421842051,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.12849188001281989,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.41643811931675812,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.0117208385365497,
                                 -0.10989878689036149,
                                 0,
                                 0,
                                 0,
                                 0.24912723214939608,
                                 0,
                                 -0.41097515203531926,
                                 0.61728726110724186,
                                 0,
                                 -0.020255403825041096,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.056631203196595745,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.29648557401863546,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74092513522682257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.0063747926007681338,
                                 -0.36847412776806349,
                                 -0.25134013878696176,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.40514264427157931,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.053213323265323464,
                                 -0.44906722306883695,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1970714283720984,
                                 0,
                                 0,
                                 0.26929991643621343,
                                 0.073368594955588437,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31151445398473715,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46816985698467017,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.60211307722297591,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.74999512126541257,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.37817328684687973,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15759679087926923,
                                 -0.27442733961939858,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.17331188168669998,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.43424243358393994,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.19754649321067683,
                                 0,
                                 0,
                                 0.95296523209750394,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13759550153385802,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.13516116395669497,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.4803852028388727,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.31638298387322034,
                                 0.21691757832254638,
                                 0,
                                 0,
                                 0,
                                 -0.60398308321322391,
                                 0,
                                 -0.13180561339295294,
                                 -0.025494597549042403,
                                 0,
                                 0.065624253588118714,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.44469401237963913,
                                 0,
                                 0,
                                 -0.57371355798118939,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.077241686970958123,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.046313821835814034,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.74844712695346238,
                                 0,
                                 1.0620786111126022,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.37357811727726181,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051864253621543441,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13037953279561323,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.18826281619769672,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16522371103748013,
                                 -0.29961408732282718,
                                 0,
                                 0,
                                 0,
                                 -0.2533732517433912,
                                 0,
                                 -0.71298548600321354,
                                 -0.2629832084091912,
                                 0,
                                 0.24963169755624887,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.35182162010035328,
                                 0,
                                 0,
                                 0,
                                 0.3489804225414091,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.41691565094966532,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.02245924735404959,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.51773454573653777,
                                 0.22006858230796539,
                                 0,
                                 0,
                                 0,
                                 -0.29664584767823382,
                                 0,
                                 -0.20854006259177227,
                                 -0.14920329768394597,
                                 0,
                                 -0.47846702162882171,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.068777282874739373,
                                 0,
                                 -0.26964619288033848,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.95555872042702417,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.1391597589390155,
                                 -0.48530759543469709,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.65208645141824373,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.46738001556879782,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.61340866220628021,
                                 0,
                                 0,
                                 0.35823388362480568,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.187827671281425,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.6142871087385019,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.13876884970978512,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.21323049629261651,
                                 0.078830961490367807,
                                 0,
                                 0,
                                 0,
                                 -0.25585653646150491,
                                 0,
                                 0.06948342610775092,
                                 -0.060321853306391504,
                                 0,
                                 -0.51297555548620566,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.42350985228654642,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.051634324499265041,
                                 -0.10445472599494213,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.80633667727152269,
                                 0,
                                 0,
                                 0.17667308299628046,
                                 -0.10049952158891574,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.17936076202965104,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.48399186216151524,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.16885595028931136,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.58568688027701654,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.66888247039512427,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.51022824625698904,
                                 -0.043168695165292703,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.31461418255623186,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.57311566925779045,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4978725601324186,
                                 0,
                                 0,
                                 -0.33522163576233421,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.27228674398114161,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.3076793463880283,
                                 0,
                                 0,
                                 0.86573948285102043,
                                 0,
                                 0,
                                 0,
                                 0.40987264802230189,
                                 0.057088486286903342,
                                 0.17725590729171675,
                                 0,
                                 -0.5504531515569544,
                                 0,
                                 0.5420555358699366,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.4728804979666888,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.63687719838130274,
                                 0.38642442924622927,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.36755613147916466,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.68196399705051824,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.11643614314601969,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 -0.15944486264100793,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.39555312799174425,
                                 -0.38968892976497782,
                                 0,
                                 0,
                                 0,
                                 -0.10290086999980956,
                                 0,
                                 -0.085647313350954463,
                                 0.2471662787597701,
                                 0,
                                 -0.32573931963292496,
                                 0,
                                 0,
                                 0,
                                 0,
                                 0.050040013851881379};

const double rot_23_20[4000] = {-0.21491131759980447,
                                0,
                                -0.051560805316393989,
                                -0.1389799742101778,
                                -0.0040307328954268251,
                                0,
                                -0.51219689299520077,
                                0,
                                0,
                                0,
                                -0.013336438375133042,
                                -0.44394035078854277,
                                0,
                                0,
                                0,
                                0.68718001720275046,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2570504034060908,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4597407161890511,
                                0,
                                0,
                                0,
                                0,
                                -0.13819169887110661,
                                0,
                                0,
                                0.15727494136663117,
                                0.38117109941617822,
                                0.16894434574707926,
                                0,
                                0.87864848670350859,
                                0,
                                -0.26476047367069488,
                                0.067410527992737987,
                                0.14179992459600688,
                                0,
                                0.055744217115377165,
                                0,
                                0,
                                0,
                                -0.095648369680576287,
                                -0.33528995150320878,
                                0,
                                0,
                                0,
                                0.092476756821548392,
                                0,
                                0,
                                0,
                                0,
                                -0.010512429696704812,
                                0,
                                0.27240534650868681,
                                0.75873005655196846,
                                -0.18765030071561345,
                                0,
                                -0.23258752490698531,
                                0,
                                0,
                                0,
                                -0.49888524308075577,
                                -0.08463703385966008,
                                0,
                                0,
                                0,
                                -0.068220319074858482,
                                0,
                                0,
                                0,
                                0,
                                -0.2206876632296004,
                                0,
                                -0.45350715310458911,
                                -0.12468137292971843,
                                -0.40277759697308546,
                                0,
                                0.51041406310803683,
                                0,
                                0,
                                0,
                                -0.51489554243857893,
                                -0.14326071443296692,
                                0,
                                0,
                                0,
                                0.14727325711326772,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49852042757871223,
                                0,
                                0.27479741160784532,
                                0,
                                0.11090158539972071,
                                0,
                                0,
                                0.039867626703462986,
                                0,
                                -0.77042475946329447,
                                0,
                                0,
                                0,
                                0,
                                0.26176490705049421,
                                -0.16499515089655836,
                                0,
                                -0.58605862760328342,
                                0.097351863293489493,
                                0.58786271019532121,
                                0,
                                -0.28820073322772843,
                                0,
                                0,
                                0,
                                -0.2948987263113011,
                                0.30906384847498991,
                                0,
                                0,
                                0,
                                -0.093308895718889895,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30106470057292911,
                                0,
                                -0.13731229817852514,
                                0,
                                -0.058270979912801224,
                                0,
                                0,
                                0.86200268641113376,
                                0,
                                0.054424913745088892,
                                0,
                                0,
                                0,
                                0,
                                -0.37563169344677805,
                                0,
                                0.22643219375606044,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.9882643523126099,
                                0,
                                0,
                                0,
                                0,
                                -1.0539563128951248,
                                0,
                                0,
                                0.45410519456685772,
                                -0.082875634079714142,
                                -0.13065297802059089,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21449012932050565,
                                0,
                                0.71339711671553974,
                                0,
                                -0.14076269975735831,
                                0,
                                0,
                                0.16053148017192248,
                                0,
                                0.50872573059514592,
                                0,
                                0,
                                0,
                                0,
                                0.37506289545527405,
                                -0.19781520393120455,
                                0,
                                -0.47804985635254671,
                                0.47743550405503882,
                                -0.1566953101696805,
                                0,
                                0.036176295633099154,
                                0,
                                0,
                                0,
                                0.58897372276892812,
                                -0.32022595246256808,
                                0,
                                0,
                                0,
                                -0.17057540287196174,
                                0,
                                0,
                                0,
                                0,
                                -0.12079542686587458,
                                0,
                                0.20104351784328889,
                                0.33595704236622659,
                                0.51152707461740343,
                                0,
                                0.57253640981778675,
                                0,
                                0,
                                0,
                                0.096265175373921902,
                                0.0095214864880801484,
                                0,
                                0,
                                0,
                                0.48301894697582082,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33581883618875036,
                                0,
                                0.62704725347293311,
                                0,
                                0.061535608439709205,
                                0,
                                0,
                                -0.05480184322106274,
                                0,
                                -0.21342955018323262,
                                0,
                                0,
                                0,
                                0,
                                -0.66460168910031869,
                                0,
                                0.28990936597579586,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64529915934073234,
                                0,
                                0,
                                0,
                                0,
                                0.48976937957580224,
                                0,
                                0,
                                -0.30446347442264943,
                                -1.0874416839724859,
                                0.55102818025261668,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70559666510629049,
                                0,
                                0.051268312191385217,
                                0,
                                -0.1079608335443845,
                                0,
                                0,
                                0.45941825169330652,
                                0,
                                -0.27837294744265167,
                                0,
                                0,
                                0,
                                0,
                                0.44642215101794203,
                                -0.22810220652998556,
                                0,
                                0.18696279843730418,
                                -0.18610336880029818,
                                0.38812133703369101,
                                0,
                                0.088097247049344296,
                                0,
                                0,
                                0,
                                -0.18315931458696577,
                                -0.68165590424542288,
                                0,
                                0,
                                0,
                                -0.47093357067289005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43250678049464497,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60494450755159002,
                                0,
                                0,
                                0,
                                0,
                                0.61268519669758326,
                                0,
                                0,
                                -0.41492628754920557,
                                0.77216188235873595,
                                0.95401895580741902,
                                0,
                                0,
                                -0.57913101636284237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44693221777720016,
                                0,
                                0,
                                0,
                                0,
                                -0.36535938374800409,
                                0,
                                0,
                                -1.118083747472006,
                                0.2171470365029062,
                                -0.074614857519465658,
                                0,
                                0,
                                -0.097110783099396497,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65401348403887594,
                                0,
                                0,
                                0,
                                0,
                                0.81927297238314001,
                                0,
                                0,
                                -0.95051671568173735,
                                0.10685544646927897,
                                -1.1116217147446472,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.064733833746028924,
                                0,
                                -0.029657567021131967,
                                0,
                                -0.97419147036258058,
                                0,
                                0,
                                -0.12459218605302924,
                                0,
                                -0.14709887504965341,
                                0,
                                0,
                                0,
                                0,
                                -0.093379048471139176,
                                -0.25941323533020322,
                                0,
                                0,
                                -0.42132810174042956,
                                0,
                                0,
                                0.63093083732621413,
                                0,
                                0.17459689098586087,
                                0,
                                0,
                                -0.5196561552059612,
                                0,
                                0,
                                0,
                                0,
                                0.23788040807259517,
                                0,
                                0,
                                0,
                                0,
                                0.4357168955205899,
                                0,
                                0,
                                -0.2818412159224597,
                                0,
                                0,
                                -0.33742838599996244,
                                0,
                                -0.014598982899242479,
                                0,
                                0,
                                0,
                                -0.4679405853574844,
                                0.28101482130368011,
                                0.14043512279547085,
                                0,
                                0,
                                0,
                                -0.54679568858339922,
                                0,
                                0,
                                0.94778543554314287,
                                0,
                                0,
                                0.48422962788918356,
                                0,
                                0,
                                0,
                                0,
                                -0.40083062141732334,
                                0,
                                0.86694163016651993,
                                0,
                                0,
                                0,
                                0,
                                0.048573730180202224,
                                -0.3844575488255928,
                                0,
                                -0.66257339903356471,
                                0,
                                0,
                                0.47647028146454956,
                                0,
                                0,
                                -0.057550818545107421,
                                0,
                                -0.11212315545045004,
                                0,
                                0,
                                0.091643460049517234,
                                0,
                                0,
                                0,
                                0,
                                0.55649828328663586,
                                0,
                                0,
                                0,
                                0,
                                0.30817009928281991,
                                0,
                                0,
                                0.79898645285496173,
                                0,
                                0,
                                -0.16908313012156087,
                                0,
                                0.22616566757267681,
                                0,
                                0,
                                0,
                                -0.33338436945704297,
                                0.075652687331888999,
                                -0.15079317012025564,
                                0,
                                0,
                                0,
                                0.21749661360177491,
                                0,
                                0,
                                -0.36910202346814674,
                                0,
                                0,
                                -0.91018557147433965,
                                0,
                                0,
                                0,
                                0,
                                -0.77178057647429599,
                                0,
                                1.2173780800639935,
                                0,
                                0,
                                0,
                                0,
                                -0.81030219315545893,
                                0.22757555184793932,
                                0,
                                -0.47899234430199256,
                                0,
                                0,
                                0.10895243416883771,
                                0,
                                0,
                                0.19517585776928675,
                                0,
                                -0.44383148950435292,
                                0,
                                0,
                                -0.090044774106353503,
                                0,
                                0,
                                0,
                                0,
                                -0.71798860249538266,
                                0,
                                0,
                                0,
                                0,
                                0.28510042962060916,
                                0,
                                0,
                                -0.013449183925299337,
                                0,
                                0,
                                0.11804784588551175,
                                0,
                                -0.75244179102542641,
                                0,
                                0,
                                0,
                                -0.2287960654337497,
                                -0.41044869212444079,
                                -0.33334732889725782,
                                0,
                                0,
                                0,
                                0.080602180954128314,
                                -0.24338307146231494,
                                0,
                                0,
                                0.26794644291227065,
                                0,
                                0,
                                -0.13270261444714421,
                                0,
                                0.84773328882176502,
                                0,
                                0,
                                -0.12814329456188611,
                                0,
                                0,
                                0,
                                0,
                                -0.34100874982526341,
                                0,
                                0,
                                0,
                                0,
                                -0.22669596551111881,
                                0,
                                0,
                                -0.23649729371903938,
                                0,
                                0,
                                -0.25396413559592124,
                                0,
                                0.45426911376800605,
                                0,
                                0,
                                0,
                                -0.24494748336727495,
                                -0.46777431978709083,
                                -0.57816926149466519,
                                0,
                                0,
                                0,
                                -0.093423661855414619,
                                0,
                                0,
                                0.33034311252091209,
                                0,
                                0,
                                -1.0824223957112344,
                                0,
                                0,
                                0,
                                0,
                                -0.35193402165653809,
                                0,
                                -0.89080245564211968,
                                0,
                                0,
                                0,
                                0,
                                -0.61529330961048001,
                                -0.32133475434645575,
                                0,
                                -0.44751113725357911,
                                0,
                                0,
                                -0.70357911179119836,
                                0,
                                0,
                                -0.31446781601200036,
                                0,
                                0.10559218362517546,
                                0,
                                0,
                                0.4409836822698463,
                                0,
                                0,
                                0,
                                0,
                                -0.014279037318915999,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44515438964976883,
                                0,
                                0,
                                -0.90930965621537674,
                                0,
                                0,
                                0,
                                0,
                                -0.044040750699878894,
                                0,
                                0.14602900011865272,
                                0,
                                0,
                                0,
                                0,
                                1.4423674615205193,
                                0.63066889587287756,
                                0,
                                0,
                                0.3454249469142695,
                                0,
                                0,
                                -0.11325700093413789,
                                0,
                                0,
                                0.78628701126330958,
                                0,
                                0.29292455471658607,
                                0,
                                0,
                                0,
                                -0.032324536118029455,
                                0.19788304673448204,
                                -0.33210782214132206,
                                0,
                                0,
                                0,
                                -0.11534391012862819,
                                0,
                                -0.18980125024325123,
                                0,
                                0,
                                0.12415113974632015,
                                0,
                                0,
                                -0.22274942413360937,
                                0,
                                -0.25394753633157313,
                                0,
                                0,
                                0,
                                0.32066162662190772,
                                0.54582312096685726,
                                -0.61931421386239738,
                                0,
                                0,
                                0,
                                -0.22396086507077739,
                                0,
                                -0.51563137969313955,
                                0,
                                0,
                                -0.1193893120154168,
                                0,
                                0,
                                0.18151740597575244,
                                0,
                                -0.13291838375447007,
                                0,
                                0,
                                0,
                                -0.66367855994869918,
                                0.37182482829636021,
                                -0.0014286171210159959,
                                0,
                                0,
                                0,
                                0.30088142551525598,
                                -0.069036663362914086,
                                0,
                                0,
                                -0.12949596841349031,
                                0,
                                0,
                                -0.66634868886431564,
                                0,
                                -0.17365625348646219,
                                0,
                                0,
                                -0.70891719070241266,
                                0,
                                0,
                                0,
                                0,
                                0.041522048080841131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.020674014283969637,
                                0,
                                0,
                                0.54402106557568364,
                                0,
                                0,
                                0,
                                0,
                                -1.4716173823324101,
                                0,
                                -0.43455406689235399,
                                0,
                                0,
                                0,
                                0,
                                0.15080075645416022,
                                0.811744259720377,
                                0,
                                0,
                                0,
                                -0.48417941884173682,
                                0,
                                0,
                                0.0046160313387580438,
                                0,
                                0,
                                0,
                                0,
                                -0.72489188364946977,
                                0,
                                -0.29668082515582439,
                                0,
                                0,
                                0,
                                0,
                                0.40559368835793097,
                                -1.2798601906520666,
                                0,
                                0,
                                0.40160930373705783,
                                0,
                                0,
                                -0.42846220964338155,
                                0,
                                0,
                                -0.27983345875208415,
                                0,
                                0.090252098036029377,
                                0,
                                0,
                                0,
                                0.1148981124843419,
                                0.229547632276277,
                                -0.13524613689104822,
                                0,
                                0,
                                0,
                                0.69605508901395541,
                                -0.62973991947841768,
                                0,
                                0,
                                0,
                                0,
                                0.23401400235137293,
                                -0.024948097363925892,
                                0,
                                0,
                                0,
                                0.37812873883026671,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50036068444523318,
                                0,
                                -0.3933198638371278,
                                0,
                                0.36587471784455566,
                                -0.61329417186202295,
                                0.14079323907535474,
                                0,
                                0,
                                0,
                                0,
                                -0.41572406212031798,
                                0.23613437674724647,
                                0,
                                0,
                                0.026126855651223302,
                                0,
                                -0.17762860336140784,
                                0,
                                0,
                                0,
                                0.45756173398454153,
                                0,
                                0,
                                0.51552551007291658,
                                0.36597940740050355,
                                -0.26240373807201689,
                                0,
                                0,
                                0,
                                0,
                                0.10972402478743915,
                                -0.11979193357722395,
                                0,
                                0,
                                0.52925150023286516,
                                0,
                                -0.4610139322917397,
                                0,
                                0,
                                0,
                                0.11138372788299682,
                                0,
                                0,
                                0.079671332251132598,
                                -0.31806959940897772,
                                -0.62873742094014873,
                                0,
                                0,
                                0,
                                0,
                                0.28116879379790588,
                                -0.079196989827050493,
                                0,
                                0,
                                0.20705496612114099,
                                0,
                                0.57023125527479723,
                                0,
                                0,
                                0,
                                0.20930830601659989,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.080665725382837006,
                                0,
                                0,
                                -0.41317786988314109,
                                0,
                                0,
                                0,
                                0.91873766939607671,
                                0,
                                -0.049941252765149359,
                                0,
                                -1.0068385816197443,
                                0.18329899738276978,
                                0,
                                0,
                                0,
                                0.27283427292050599,
                                0,
                                0,
                                0,
                                0,
                                -0.46817028932434968,
                                -0.016391482246309159,
                                0,
                                0,
                                0,
                                0.77089218809169491,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21942531814083349,
                                0,
                                -0.25236307796834173,
                                -0.23116762193685714,
                                0,
                                0,
                                0,
                                0,
                                0.11286275381517998,
                                0.51041551104472016,
                                0,
                                0,
                                0,
                                0.38598444724469394,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.041723031091299212,
                                0,
                                0.72289330513986083,
                                0,
                                0,
                                0,
                                0,
                                0.50251537798476598,
                                0,
                                0,
                                0.20258217629417857,
                                0,
                                0,
                                0,
                                -0.62934211533047213,
                                0,
                                -0.43491819182126301,
                                0,
                                -1.2463941884561145,
                                -0.17224271434371002,
                                0,
                                0,
                                0,
                                0,
                                0.56291050545022214,
                                -0.21349159737564027,
                                -0.10281612295946449,
                                0,
                                0,
                                0,
                                0,
                                -0.16615689230717656,
                                -0.2252702518768985,
                                0,
                                0,
                                -0.24914855997180885,
                                0,
                                0.084176253684463367,
                                0,
                                0,
                                0,
                                -0.69243519530792053,
                                0,
                                0,
                                0.0054499693834737795,
                                -0.12994585744662529,
                                0.5790679035936509,
                                0,
                                0,
                                0,
                                0,
                                -0.024667888481368236,
                                -0.2617074739605682,
                                0,
                                0,
                                0.65716110354785018,
                                0,
                                0.35518093287179958,
                                0,
                                0,
                                0,
                                -0.14370531393435845,
                                0,
                                -0.26571706741572521,
                                0,
                                0,
                                0,
                                0,
                                -0.69585770027403415,
                                -0.39832935065633757,
                                0,
                                0,
                                0,
                                -0.10988876968021027,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35617691135308704,
                                0,
                                0.38415191731418569,
                                0,
                                0,
                                0,
                                0,
                                -0.77726193868264626,
                                0,
                                0,
                                0.051398828668799135,
                                0,
                                0,
                                0,
                                -0.054184567113350998,
                                0,
                                -0.31718572049355487,
                                0,
                                0.43193429752364881,
                                1.2236672237090012,
                                0,
                                0,
                                0,
                                0,
                                0.28310358879529418,
                                0.14484452132445291,
                                0.26486646957900739,
                                0,
                                0,
                                0,
                                0,
                                0.20280489390049219,
                                -0.62050049823053688,
                                0,
                                0,
                                -0.41391492711495398,
                                0,
                                0.12717294936658177,
                                0,
                                0,
                                0,
                                0.46375527674924016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22060652254752122,
                                0,
                                0,
                                1.2912090025196732,
                                0,
                                0,
                                0,
                                0.32779105478234311,
                                0,
                                0.39903572972917845,
                                0,
                                -0.32372617083251143,
                                -0.50464238962385422,
                                0,
                                0,
                                0,
                                0,
                                -0.23054097590094136,
                                -0.55135018995554197,
                                0.02567868293308212,
                                0,
                                0,
                                0,
                                0,
                                0.53716085666755731,
                                -0.27171996263425496,
                                0,
                                0,
                                0.028959436344814127,
                                0,
                                -0.51084946416560495,
                                0,
                                0,
                                0,
                                -0.13425752749090547,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39524232767967937,
                                0,
                                0,
                                -0.23118722994987506,
                                0,
                                0,
                                0,
                                -0.5053544040550858,
                                0,
                                -1.3650858315368557,
                                0,
                                0.12103488590468062,
                                -0.85773608760284237,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.93953483977817809,
                                0,
                                0,
                                0.098140947151357974,
                                0,
                                0,
                                0,
                                -0.51375522225850867,
                                0,
                                0.91679184509010625,
                                0,
                                -0.55251293916485522,
                                -0.18136716932967153,
                                0,
                                0,
                                0,
                                0.58268746996540421,
                                0,
                                0,
                                0,
                                0,
                                0.34514311170205753,
                                -0.30477503292062985,
                                0,
                                0,
                                0,
                                0.24191708895223638,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57158363882428553,
                                0,
                                0.25145971844299547,
                                0,
                                0.37924516510157091,
                                0.036462401338919606,
                                0.31512912275580812,
                                0,
                                0,
                                0,
                                0,
                                0.61497156311795109,
                                0.58781646018510314,
                                0,
                                0,
                                -0.10118567648325412,
                                0,
                                0.1427279866024844,
                                0,
                                0,
                                0,
                                -0.034773559403395715,
                                0,
                                0.25577407283111453,
                                0,
                                0,
                                0,
                                0,
                                -0.33162376138125849,
                                0.69787593850667728,
                                0,
                                0,
                                0,
                                -0.20775100015663997,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49616635873889098,
                                0,
                                -0.21962000227178829,
                                -0.69346885222834431,
                                0,
                                0,
                                0.34038329181982879,
                                0,
                                0,
                                0,
                                0,
                                -0.026568686757888087,
                                -0.42629358481023727,
                                0,
                                -0.047872426417031377,
                                0,
                                0.1140167788070244,
                                0,
                                0,
                                0,
                                0,
                                0.2292744289189701,
                                0.3910878306159587,
                                0,
                                1.1749962104607363,
                                0,
                                0,
                                -0.14332222995409605,
                                1.0449767132159884,
                                0.050149181860240463,
                                0,
                                0,
                                0,
                                0.54394180180580332,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.074101583924054124,
                                0,
                                0,
                                0,
                                0,
                                0.33862571653072437,
                                0,
                                0,
                                0,
                                0,
                                -0.23271144436548771,
                                0,
                                0,
                                0,
                                0,
                                -0.87336905847758872,
                                0,
                                -0.15166906501257132,
                                0.1283230986489384,
                                0.17010047774976808,
                                0,
                                0,
                                0,
                                0.17244455956287841,
                                0,
                                0,
                                0.48480214724789727,
                                0,
                                0,
                                0,
                                0,
                                0.64278816377017578,
                                -0.1506711535254526,
                                0,
                                -0.41724761169461921,
                                0,
                                -0.28929627006664527,
                                0,
                                0,
                                0,
                                0,
                                -0.17822705793582361,
                                -0.098987607272182226,
                                0,
                                -0.26798517719688358,
                                0,
                                0,
                                -0.58940749043655172,
                                -0.09218964489431504,
                                0.13737250495024328,
                                0,
                                0,
                                0,
                                0.94275059967630659,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57586731517017875,
                                0,
                                0,
                                0,
                                0.024219746381903384,
                                0,
                                0,
                                0.95066779433424209,
                                -0.55127663398948934,
                                0.30309097763551313,
                                0,
                                0,
                                0,
                                1.1754088741323379,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.81926258173782984,
                                0,
                                0,
                                0,
                                0.60476613115144984,
                                0,
                                0,
                                -0.18916177666737466,
                                -0.68347333728002935,
                                1.1772298364991023,
                                0,
                                0,
                                0,
                                -0.59446523252736272,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65876313134937059,
                                0,
                                0,
                                0,
                                0,
                                -0.32068860719332576,
                                0,
                                0,
                                0,
                                0,
                                -0.79312658835826177,
                                0,
                                0,
                                0,
                                0,
                                0.087615378848625317,
                                0,
                                -0.41403334345475229,
                                -0.12770500785318445,
                                -0.26963011501258272,
                                0,
                                0,
                                0,
                                -0.32420668515213835,
                                0,
                                0,
                                -0.47894575312001569,
                                0,
                                0,
                                0,
                                0,
                                0.36694488495402133,
                                0.051647335396775081,
                                0,
                                -0.030811700047065849,
                                0,
                                0.15402074951999883,
                                0,
                                0,
                                0,
                                0,
                                -0.65972824880872682,
                                0.26128888343121875,
                                -0.13780885235759249,
                                0,
                                0,
                                -0.027156782611783753,
                                0,
                                0,
                                0,
                                0,
                                0.32785699432374582,
                                0.66598591257983863,
                                0,
                                -0.28784698495994909,
                                0,
                                0.34238905281450371,
                                0,
                                0,
                                0,
                                0,
                                0.46318813794344948,
                                0.12088996450902814,
                                0,
                                -0.30801926327699464,
                                0,
                                0,
                                0.04382887082210643,
                                0.55874517316822125,
                                0.94307014013375157,
                                0,
                                0,
                                0,
                                -0.51285319289983178,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.65387311588443975,
                                0,
                                0,
                                0.48576397717987679,
                                0,
                                0,
                                0.36955829396276058,
                                0,
                                0,
                                0,
                                0,
                                -0.12110011439535016,
                                0.032230389360363272,
                                0,
                                0.07709490082844514,
                                0,
                                0.45935577567891811,
                                0,
                                0,
                                0,
                                0,
                                -0.23786419228394701,
                                0.5815713746210428,
                                0,
                                0,
                                -0.67693341708842647,
                                0,
                                0,
                                0,
                                0,
                                -0.17077890237655619,
                                0,
                                0,
                                0,
                                0,
                                -0.18836753676456774,
                                0,
                                0.45985374426793407,
                                0.059457937696240581,
                                0.51196940724321149,
                                0,
                                0,
                                0,
                                0.19967147511863387,
                                0,
                                0,
                                -0.22105582268827997,
                                0,
                                0,
                                0,
                                0,
                                0.43140893061325108,
                                -0.095506130159822872,
                                0,
                                0.52083709999985284,
                                0,
                                -0.36194601486294614,
                                0,
                                0,
                                0,
                                0,
                                0.35696793058218534,
                                0.43165754145274027,
                                0,
                                0,
                                -0.21289041696132435,
                                0,
                                0,
                                0,
                                0,
                                0.06342980195016501,
                                0,
                                0,
                                0,
                                0,
                                -0.049461302205344074,
                                0,
                                0.017886639574630568,
                                0.88862173523015731,
                                -0.39779314973490859,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26153046524903584,
                                0,
                                0,
                                0,
                                0,
                                -0.18641769611643416,
                                0,
                                0,
                                0,
                                0,
                                0.40052159028407375,
                                0,
                                -0.32899673080385861,
                                0.40883553934962763,
                                0.67900468843937478,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45883774502769581,
                                0,
                                0,
                                0,
                                0,
                                0.49885395438221747,
                                0,
                                0,
                                0,
                                0,
                                -0.1766458023189301,
                                0,
                                -0.69681320190834062,
                                -0.08303180359661344,
                                0.13025358995423014,
                                0,
                                0,
                                0,
                                0,
                                0.38077504999840833,
                                0,
                                0,
                                -0.8595213177768003,
                                -0.31191594938652489,
                                -0.26926136203069712,
                                0,
                                0,
                                0,
                                -0.19834533061205423,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.96837976917159208,
                                0,
                                0,
                                -0.22514540017069323,
                                0,
                                0,
                                0.2977883204773642,
                                0,
                                0,
                                0,
                                0,
                                -0.26754238668617769,
                                0.55972733232382188,
                                0,
                                0.086991349387452843,
                                0,
                                -0.5826362784714153,
                                0,
                                0,
                                0,
                                0,
                                -0.24789472784431449,
                                0.25937179066523963,
                                -0.19681661429139286,
                                0,
                                0,
                                0.38060829497846593,
                                0,
                                0,
                                0,
                                0,
                                0.26762079942865752,
                                0.16097327290512015,
                                0,
                                0.67455541683060183,
                                0,
                                0.28438971182219219,
                                0,
                                0,
                                0,
                                0,
                                -0.14292118502043821,
                                -0.40316035961188018,
                                -0.25684547137493935,
                                0.26544070989542035,
                                0.42017422625850637,
                                0.79570242891921572,
                                0.23136196709535864,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.018829172745843344,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40552348354042256,
                                0.4771589759914151,
                                -0.68340451489918119,
                                0.27838227658854842,
                                0.17146529013394957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18420436288029154,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5269050758412881,
                                0.66998322148382461,
                                -0.024066633805996419,
                                -0.25721164729990853,
                                -0.43584553677288262,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12959613299985243,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18700826046148855,
                                -0.0022560667477071611,
                                -0.31999527705278152,
                                0.1679142352034923,
                                -0.12775871091312513,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.90449342990856196,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67270250706423207,
                                -0.29763925341044284,
                                -0.44040622827839321,
                                -0.024933841284626661,
                                0.46187905157043013,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22576671852060715,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.010415458501430941,
                                -0.35549879141219637,
                                -0.09303249601823918,
                                0,
                                0,
                                -0.69474445952497876,
                                0,
                                -0.28486485379720744,
                                0,
                                0.027446101596478915,
                                0.53376188948495507,
                                0,
                                0,
                                0,
                                -0.12403302013712103,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32275738630189443,
                                -0.11615270945124023,
                                0.30061941222927152,
                                0,
                                0,
                                0.34148213132301125,
                                0,
                                0.15019153982092465,
                                0,
                                -0.40772857176803556,
                                0.39301714346025662,
                                0,
                                0,
                                0,
                                -0.57627387475859693,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46450301539352656,
                                -0.22165094922588885,
                                -0.41131015259243908,
                                0,
                                0,
                                0.42306264041109076,
                                0,
                                0.054518493504012638,
                                0,
                                0.46524823950027971,
                                0.25262036973908669,
                                0,
                                0,
                                0,
                                -0.32203186854905658,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3320940809493157,
                                -0.11554320759918385,
                                0,
                                0,
                                0,
                                -1.2753882384900939,
                                0,
                                0,
                                -0.12933184940790185,
                                0.046509329717393466,
                                0.10885033691193419,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58264285440091945,
                                0.89831418699168464,
                                0,
                                0,
                                0,
                                0.14879556151941103,
                                0,
                                0,
                                0.38894861147839938,
                                -0.43468202465603528,
                                -0.27971805697143293,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35665026684151963,
                                0.23958107883360436,
                                -0.40714935601326863,
                                0,
                                0,
                                -0.069799491844634423,
                                0,
                                -0.47223437912426725,
                                0,
                                0.066829256254649,
                                -0.37326609763771124,
                                0,
                                0,
                                0,
                                -0.52721901397701543,
                                -0.066718788154246811,
                                -0.40544889823910529,
                                -0.24388124671290634,
                                0.44089254287357116,
                                -0.70530519354561738,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28255987210101569,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49848513599658917,
                                -0.16586318727932761,
                                -0.60985807751076504,
                                0,
                                0,
                                0.23904715340348126,
                                0,
                                0.063184502613793839,
                                0,
                                -0.17277235228277865,
                                0.25023466081659812,
                                0,
                                0,
                                0,
                                0.44550151905767521,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62647562054898565,
                                0.21636735087361511,
                                0,
                                0,
                                0,
                                0.4467845784900954,
                                0,
                                0,
                                -0.11777735312012391,
                                0.75578990467451346,
                                0.53127712691423734,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19078435494886251,
                                0.80871251565704594,
                                -0.081459786064850062,
                                0,
                                0,
                                0.038569773326539894,
                                0,
                                -0.17471225546258248,
                                0,
                                -0.10696593032448565,
                                0.50253729722122387,
                                0,
                                0,
                                0,
                                0.083380184749047973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27431567362763176,
                                0.2676965007062565,
                                -0.13235214462631137,
                                0,
                                0,
                                -0.34510994361047637,
                                0,
                                0.74347842247470619,
                                0,
                                0.35022550710651579,
                                0.044213873193165498,
                                0,
                                0,
                                0,
                                -0.19773364470821558,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40468718078348853,
                                -0.47931349910308008,
                                0,
                                0,
                                0,
                                0.099949775858861278,
                                0,
                                0,
                                -0.066848017189869158,
                                -0.74963095121532286,
                                0.88223228901591244,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.9337312324372109,
                                -0.23667685545582728,
                                0,
                                0,
                                0,
                                0.75917708686023999,
                                0,
                                0,
                                0.092522373977819372,
                                0.13715526943434653,
                                -0.93472431209378171,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12621365964328146,
                                -0.57056865363264997,
                                0,
                                0,
                                0,
                                -0.56210024956706039,
                                0,
                                0,
                                1.2290058151070227,
                                0.15230438950758063,
                                0.3371502010861463,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43888669832132721,
                                0.020321771542042483,
                                0.41224582752269184,
                                0,
                                0,
                                0.19782335814931346,
                                0,
                                -0.28816683225456802,
                                0,
                                0.66942673059116142,
                                0.20093569188137364,
                                0,
                                0,
                                0,
                                0.1622879083148426,
                                -0.20293805000696863,
                                0,
                                0,
                                0,
                                0.2795812558941162,
                                0,
                                0,
                                -0.81909790237599212,
                                0,
                                -0.44860116700102803,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61118818456643176,
                                0,
                                0,
                                0,
                                -0.58727097366719683,
                                0,
                                -0.44861758659651668,
                                0.1341649297452302,
                                0,
                                0,
                                0,
                                0.14645857737524423,
                                0,
                                -0.14889898144878572,
                                0,
                                -0.65057034403768665,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27576245853583264,
                                0.0071088640554275301,
                                -0.4876307712114864,
                                0,
                                0,
                                -0.24023207248082115,
                                0.49447062356367955,
                                0,
                                0,
                                0,
                                -0.40690078646863703,
                                0,
                                0.40811526229228468,
                                0,
                                -0.28353244749774892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25850742957687906,
                                -0.32321862882226521,
                                0.33760037691206057,
                                0,
                                0,
                                0,
                                0,
                                -0.42809888571473703,
                                0,
                                0.0035598764001658623,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53367932469612855,
                                -0.0010039367689153034,
                                0.64745691297852193,
                                -0.33571355002293035,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17429610866881573,
                                0,
                                0,
                                0,
                                -0.48691082300559474,
                                0,
                                0,
                                -0.091330389084187974,
                                0,
                                0.52040890335445766,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52668688685014753,
                                0,
                                0,
                                0,
                                -0.8026512115783534,
                                0,
                                0,
                                0,
                                0.2622561833340048,
                                0,
                                0.4528174306923014,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49823633240877707,
                                0.40063310392929696,
                                -0.42870161368095394,
                                -0.36557717146402186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.673723654336152,
                                0.21051895882604257,
                                0,
                                0,
                                0,
                                -0.15573513825586358,
                                0,
                                0.32077044091245105,
                                0,
                                -0.17747561129971379,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56519788938267779,
                                -0.031340539880657929,
                                -0.15067388726367617,
                                0,
                                -0.17087209084614935,
                                0,
                                0,
                                0,
                                -0.26472956411937654,
                                0,
                                0,
                                -1.132885019067333,
                                0,
                                1.1508832005428524,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45716339891860103,
                                0,
                                0,
                                0,
                                0.76442248818948988,
                                0,
                                0.056066985590848856,
                                -0.048012755558585363,
                                0,
                                0,
                                0,
                                -0.010377322496389948,
                                0,
                                0.1976954160064858,
                                0,
                                -0.35187981471995355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15615709290950855,
                                0.85832683307211188,
                                0.26538784458478692,
                                0,
                                -1.078529475950327,
                                0,
                                0,
                                0,
                                -0.54647156908029482,
                                0,
                                0,
                                0.40130657307931372,
                                0,
                                -0.42498666228694576,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1462773934832938,
                                0,
                                0,
                                0,
                                0.37278541205336635,
                                0,
                                0.0081849437446803591,
                                -0.22498245697384509,
                                0,
                                0,
                                0,
                                0.48918477450390541,
                                0,
                                -0.038175843609684915,
                                0,
                                -0.31182689020602328,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29519882525240071,
                                -0.27909692032965666,
                                0.66804439619287592,
                                0,
                                0,
                                0,
                                0,
                                0.5334922507145281,
                                0,
                                -0.51818819568172148,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36228362538192027,
                                0.36514787138727678,
                                0.24046646620103737,
                                0.3527895941179805,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.023797359398191102,
                                0,
                                0.20464077115032842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53580177418001296,
                                -0.59646939015500944,
                                -0.18479122751850757,
                                0.52966854550229581,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35170050711725365,
                                0,
                                -0.43422461342684465,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.094565519749794269,
                                -0.55544346939269662,
                                -0.14970353368464684,
                                -0.589817348993394,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58230532863744955,
                                0,
                                0.54405499306105687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19917663392042084,
                                -0.20461172763406632,
                                0.53163089181403567,
                                -0.027494964072066835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.01764777214509014,
                                0,
                                0,
                                0,
                                -0.28831777560575472,
                                0,
                                0,
                                0.71273138396356617,
                                0,
                                0.81098122070390577,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0803757404777832,
                                0,
                                0,
                                0,
                                -0.027816567065494027,
                                0,
                                -0.33197083674865724,
                                -0.35444870249354909,
                                0,
                                0,
                                0,
                                -0.65097313331182627,
                                0,
                                -0.12597624724741019,
                                0,
                                0.097592765121802733,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5119092140576128,
                                0.090765778269710301,
                                0.21145124246163818,
                                0,
                                0,
                                0.39943456865563559,
                                0.023390748516839893,
                                0,
                                0,
                                0,
                                -0.32527011607974671,
                                0,
                                -0.70939428349912459,
                                0,
                                -0.37307731784060483,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26697434106119677,
                                -0.098750281613573299,
                                0.10320076734201254,
                                0,
                                0,
                                0.11901318695742175,
                                -0.71699163284932865,
                                0,
                                0,
                                0,
                                -0.14054216683925178,
                                0,
                                0.38565037711297562,
                                0,
                                -0.30838861800372575,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30467457201858,
                                -0.2487707070000803,
                                -0.2312218556208836,
                                0,
                                -1.2948341590291597,
                                0,
                                0,
                                0,
                                1.2620680581455921,
                                0,
                                0,
                                0.23533844769658296,
                                0,
                                0.48736560320083855,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44142437639209264,
                                0,
                                0,
                                0,
                                -0.30432523818438068,
                                -0.077914095432649669,
                                0.19395574319218906,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52973283878185107,
                                -0.55122141271370095,
                                0,
                                0,
                                0.43003680797504729,
                                0,
                                0,
                                0.42179485625631025,
                                -0.085550614938420644,
                                0.041075204244424124,
                                0,
                                0,
                                0,
                                -0.34528013273016156,
                                0.0020917856657817618,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42931807923969101,
                                -0.076509949852314518,
                                0,
                                0,
                                0.02869109275097384,
                                0,
                                0,
                                -0.78359206776955248,
                                -0.27121649783469259,
                                -0.047025233798288213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10932955706375155,
                                0,
                                -0.056967752141350733,
                                -0.96064906456861598,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0400558431161206,
                                0,
                                0,
                                0,
                                0,
                                -0.056172708359952583,
                                -0.011212043742905201,
                                0,
                                0,
                                0,
                                -0.24654490546384905,
                                0,
                                0,
                                -0.0089099368564144535,
                                0,
                                0,
                                -0.31899812742222394,
                                -0.71797139693014811,
                                0,
                                0.027556690611834411,
                                0,
                                0,
                                0,
                                0,
                                0.56668696765396476,
                                0,
                                0,
                                0,
                                0,
                                -0.16066555894711843,
                                0,
                                0.10352190538344824,
                                -0.61965099337268392,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38532963794050723,
                                0,
                                0,
                                0,
                                0,
                                1.3454611980140092,
                                -0.53254028096143602,
                                0,
                                0,
                                0.50201622872632834,
                                0,
                                0.30131651706296259,
                                0.45492137618547401,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55990717742930185,
                                0,
                                0,
                                0,
                                0,
                                -0.73049270264691379,
                                -0.85649211191197627,
                                0,
                                0,
                                0,
                                -0.54611890162151555,
                                0,
                                0,
                                -0.020582800780540415,
                                0,
                                0,
                                -0.59326588546489289,
                                0.43560364678025676,
                                0,
                                -0.39951875251721336,
                                0,
                                0,
                                0,
                                0,
                                -0.00055861088926870139,
                                0,
                                0,
                                0.294427355414762,
                                -0.55995422297630915,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2037921968717798,
                                0.051672153571457005,
                                0,
                                0,
                                0.015689304247929386,
                                0,
                                0,
                                0.11557349125553065,
                                -0.28575206347661031,
                                -0.67845773756661665,
                                0,
                                0,
                                0,
                                0.014804995528648727,
                                0.29336672167431044,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16468410767937169,
                                -0.35716474818110883,
                                0,
                                0,
                                -0.62100239492399423,
                                0,
                                0,
                                0.12556116440432544,
                                -0.59552268073431136,
                                -0.054519925524093904,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16195146263862881,
                                0,
                                0,
                                -0.28246155845215892,
                                0,
                                0,
                                -0.28387948916896905,
                                0.20274410251998609,
                                0,
                                0.87856244907551684,
                                0,
                                0,
                                0,
                                0,
                                -0.0205543022977423,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.045992614761716573,
                                0,
                                0,
                                -0.65796815133662556,
                                0,
                                0,
                                -0.11230284408853963,
                                -0.40470838207159132,
                                0,
                                -0.17689493555136765,
                                0,
                                0,
                                0,
                                0,
                                -0.59772064518547607,
                                0,
                                0,
                                -0.31224760000212048,
                                0.068974890493595287,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23348976270294902,
                                0.68984253242909088,
                                0,
                                0,
                                0.059283242762592836,
                                0,
                                0,
                                0.34780554899026112,
                                -0.45737256799054604,
                                0.18349616673902774,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57276687714221941,
                                0,
                                0,
                                0.38546791455909513,
                                0,
                                0,
                                -0.65733419092915835,
                                -0.12335593787474633,
                                0,
                                0.039195431915362101,
                                0,
                                0,
                                0,
                                0,
                                -0.27296773332709179,
                                0,
                                0,
                                0,
                                0,
                                0.16975040503822189,
                                0,
                                -0.69828425014965878,
                                -0.79987972095063398,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67433294522997012,
                                0,
                                0,
                                0,
                                0,
                                -0.4423319137495772,
                                -0.52807663566767316,
                                -0.6007411497418802,
                                0.10999067927266683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14676391157517613,
                                0.024543960532638371,
                                0,
                                0,
                                -0.36910514913378523,
                                0,
                                0,
                                0.2005504788117268,
                                0.45426555839557675,
                                -0.4712258126708857,
                                0,
                                0,
                                0,
                                -0.33384535094487006,
                                -0.73789076917427454,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0039921536515798786,
                                -0.2508188324258005,
                                0,
                                0,
                                -0.22023532754107686,
                                0,
                                0,
                                0.13326866742297422,
                                -0.0049453577101106552,
                                0.46351901433810933,
                                0,
                                0,
                                0,
                                -0.46686524513807709,
                                -0.037759192556124845,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62477511090582383,
                                -0.14376821865513423,
                                0,
                                0,
                                0.48999828849458105,
                                0,
                                0,
                                2.2362209382005387e-05,
                                -0.25932581529463655,
                                -0.24949878687301044,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53344565090257323,
                                0,
                                0,
                                0.58155380491072939,
                                0,
                                0,
                                0.1448725374906159,
                                -0.27323214135111423,
                                0,
                                0.18688316713200556,
                                0,
                                0,
                                0,
                                0,
                                -0.4966505171480341,
                                0,
                                0,
                                0,
                                0,
                                -1.2705120567388597,
                                0,
                                0.85414980391542139,
                                -0.65019776319620981,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.061763310212785749,
                                0,
                                0,
                                0,
                                0,
                                -0.29506857768016537,
                                -0.33557448791885791,
                                0,
                                0,
                                0.83236128609959026,
                                0,
                                0.96095738266449371,
                                -0.037740607211913586,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15601661466727537,
                                0,
                                0,
                                0,
                                0,
                                -0.084871314648316543,
                                0.27522594342636458,
                                0.31048508454322221,
                                -0.54140359749363776,
                                -0.25073601640656323,
                                0,
                                -0.49141019703637345,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45982871450581614,
                                0.17178437932163335,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2426921218580991,
                                0.079226507858109432,
                                0,
                                0.52487098484444528,
                                -0.06867670070657228,
                                -0.41745033155995814,
                                0,
                                0.44295834181720489,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32078415980674657,
                                -0.0020136066638182099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.090839054554610055,
                                0.48801518676822386,
                                0,
                                -0.23929601732386849,
                                -0.30961012951001204,
                                -0.52567882757724638,
                                0,
                                0.4443167039441015,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20206083939268471,
                                -0.28502342057934443,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.046207304766351855,
                                -0.49892020656854175,
                                0,
                                0,
                                0,
                                0,
                                0.094875012106144907,
                                0,
                                0,
                                0,
                                0.14367528166122201,
                                0,
                                0,
                                0,
                                0,
                                1.1933354102208846,
                                0.98821676584599261,
                                0,
                                0,
                                0.2986413894837362,
                                0,
                                0,
                                -1.080349221989114,
                                -0.22521972573782237,
                                0.051295467258913381,
                                -0.14094844892302044,
                                0,
                                0.16294310487198962,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43928908276648043,
                                0.37889316231046449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.6411626595991694,
                                0.3906449113330645,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.345717333087048,
                                0.30802569587997253,
                                0,
                                0.3078865439342417,
                                -0.32501188051900554,
                                0,
                                0,
                                0,
                                0,
                                0.75536894816128841,
                                -0.12079156435891771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10629123192340269,
                                -0.54950976216086611,
                                0,
                                -0.57357929759451132,
                                -0.53129416836469678,
                                0,
                                0,
                                0,
                                0,
                                0.27299887887962043,
                                -0.030758794990001937,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75180184661540705,
                                0,
                                0,
                                0,
                                -0.7202477807166352,
                                0,
                                0,
                                0,
                                0,
                                0.31232598163571135,
                                -0.46281392302029339,
                                0,
                                0,
                                -0.15572351842601151,
                                0,
                                0,
                                -0.48811015211516173,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37882013881954563,
                                -0.49915918346838462,
                                0,
                                0.28919868682155608,
                                0.085007281494222348,
                                0,
                                0,
                                0,
                                0,
                                -0.16305557040414975,
                                -0.69991869140475305,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16676141508678569,
                                0.33422736076761511,
                                0,
                                -0.66506563671602192,
                                0.46090317270388026,
                                0,
                                0,
                                0,
                                0,
                                0.1909865439229308,
                                -0.41141561229971696,
                                0,
                                0,
                                0,
                                0,
                                -0.022483588847332328,
                                0.44843892357865694,
                                -0.079473825406646131,
                                0,
                                -0.019830396815564449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51330803991926521,
                                -0.59900559202448478,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25212172949997597,
                                0.32531442771741559,
                                0,
                                0.2770863546273562,
                                -0.27810026263654308,
                                0.1454317150801038,
                                0,
                                -0.23040381897430748,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12976985025462212,
                                -0.59374845905089546,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63368968779289392,
                                0.026589948782331389,
                                0,
                                0,
                                0,
                                0,
                                -0.022146083147736882,
                                0,
                                0,
                                0,
                                0.65736305223167835,
                                0,
                                0,
                                0,
                                0,
                                0.35193979059922964,
                                -0.41055875411544213,
                                0,
                                0,
                                1.6632197096958037,
                                0,
                                0,
                                0.3107804269337513,
                                0,
                                0,
                                0,
                                -0.58541008759583635,
                                0,
                                0,
                                0,
                                1.1797519015800741,
                                0,
                                0,
                                0,
                                0,
                                -0.25911268237911644,
                                0.13107557231641931,
                                0,
                                0,
                                -0.34195936414353678,
                                0,
                                0,
                                -0.42985435561549695,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83297563301416033,
                                0.074894611434827618,
                                0,
                                0.19033437653714136,
                                0.016172320279013427,
                                0,
                                0,
                                0,
                                0,
                                0.20470396939714086,
                                -0.47132786684085426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.063397376026423841,
                                0.48649991779966717,
                                0,
                                -0.11847914982659644,
                                -0.62623818769252415,
                                0,
                                0,
                                0,
                                0,
                                -0.49992266421696213,
                                -0.32119208556258855,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11322521723257813,
                                0,
                                0,
                                0,
                                0.0052162601792364593,
                                0,
                                0,
                                0,
                                0,
                                1.3270776497449048,
                                -0.29035658491092842,
                                0,
                                0,
                                -0.56918389615070819,
                                0,
                                0,
                                1.0400076133959089,
                                0.4477682202636506,
                                0.56793008977354043,
                                -0.37974533682932049,
                                0,
                                -0.24103168800814861,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.03886906848979968,
                                0.16402881645235889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23299888062278584,
                                -0.43812270324713709,
                                0,
                                -0.49228468797019764,
                                0.051905558617642691,
                                -0.54312888177736807,
                                0,
                                -0.47619397074541348,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41232927705049693,
                                -0.086239835089319095,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.014410544923824497,
                                0.23569368533211998,
                                0,
                                0,
                                0,
                                0,
                                0.49796593202393813,
                                0,
                                0,
                                0,
                                0.22575816023686082,
                                0,
                                0,
                                0,
                                0,
                                0.16915065430040405,
                                -0.80816153403328161,
                                0,
                                0,
                                0.021921190891199857,
                                0,
                                0,
                                -0.47517060934170441,
                                -0.21707905706112243,
                                0,
                                0,
                                0,
                                -0.083621003249575762,
                                0,
                                0,
                                0.27519900325289282,
                                0,
                                -0.30358811757224752,
                                0,
                                0,
                                0,
                                0,
                                -0.41390711529791246,
                                0,
                                0,
                                -0.71263315867963994,
                                0.31435457183382204,
                                -0.00024187135665949128,
                                0,
                                0.019253375165092609,
                                0.41753502593789654,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.044747368167805057,
                                0,
                                0,
                                -0.1664656445331501,
                                -0.22027966329962939,
                                0.86432490524606065,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14268444315578302,
                                0.38634419970932554,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26711671622193361,
                                0,
                                0,
                                0.77738873778460338,
                                0.38988609326749385,
                                0.051803026835961552,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.99751968247975042,
                                0,
                                0.41281120025973284,
                                0.49682736194916072,
                                0,
                                0,
                                0,
                                -0.79266648212959656,
                                0,
                                0,
                                0,
                                0,
                                0.66994895344775984,
                                0.57734944424520573,
                                0,
                                0,
                                0,
                                -0.58540385774733472,
                                0,
                                0,
                                0,
                                -0.35156037640335791,
                                0,
                                0,
                                -0.2359968504499525,
                                0,
                                -0.079467288693880742,
                                0,
                                0,
                                0,
                                0,
                                0.42829298963974283,
                                0,
                                0,
                                0.009925755003629258,
                                0.21889141447727686,
                                0.49015426629196768,
                                0,
                                0,
                                0,
                                0.092450020397278232,
                                0,
                                1.1504564610422152,
                                0.065501436161512133,
                                0,
                                0,
                                0,
                                -0.25067948299226223,
                                0,
                                0,
                                0,
                                0,
                                -0.21593274463872753,
                                0.57759570508314151,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.0193940262868662,
                                0,
                                -0.26561068041695957,
                                0.39429912530674366,
                                0,
                                0,
                                0,
                                0.88916051008747388,
                                0,
                                0,
                                0,
                                0,
                                -0.12371800516800041,
                                0.42693350345194958,
                                0,
                                0,
                                0,
                                0.20866997241353638,
                                0,
                                0,
                                0,
                                -0.31881438336906903,
                                0,
                                0,
                                0.4005213963031225,
                                0,
                                -0.14740910870105323,
                                0,
                                0,
                                0,
                                0,
                                -0.35688117075550485,
                                0,
                                0,
                                0.27193188989996919,
                                -0.28666204652255284,
                                0.62384384716402086,
                                0,
                                0.18818163075668115,
                                -0.28143129888128116,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1139879158566123,
                                0,
                                0,
                                -0.30350910881768267,
                                0.83749514076053522,
                                0.28084686745913034,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.091847805332407786,
                                0,
                                0,
                                0,
                                -0.55138955301212711,
                                0,
                                0,
                                0.09356186811779732,
                                0,
                                -0.55236056336490591,
                                0,
                                0,
                                0,
                                0,
                                0.12038625951188517,
                                0,
                                0,
                                0.29812795007693144,
                                0.13537398086702418,
                                -0.50197438736064337,
                                0,
                                0,
                                0,
                                0.10654069549781953,
                                0,
                                0.029592273668344687,
                                0.66501210066337735,
                                0,
                                0,
                                0,
                                -0.53267700415438135,
                                0,
                                0,
                                0,
                                0,
                                -0.79835798110441314,
                                -0.28552439485309644,
                                0,
                                0,
                                0,
                                0,
                                0.24576907096386752,
                                0.50845767722391255,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62521728501588936,
                                0,
                                0,
                                -0.4012828104953699,
                                0.0056130889436305023,
                                -0.35932200041248485,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2846421702480153,
                                0.56207881713403107,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63032468213359993,
                                0,
                                0,
                                -0.258433394292086,
                                0.31290638007334082,
                                -0.20258038247311203,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.89578710068067502,
                                -0.15078885660840274,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35418530405152093,
                                0,
                                0,
                                -0.21914024535928192,
                                0.011210885674806548,
                                0.035111682913710196,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14752929497813871,
                                0,
                                0,
                                0,
                                0.61763695921922235,
                                0,
                                0,
                                0.10836996200839769,
                                0,
                                -0.6386339868750891,
                                0,
                                0,
                                0,
                                0,
                                0.28998714367807654,
                                0,
                                0,
                                0.097793383618310886,
                                0.158244812352829,
                                0.24179488385270173,
                                0,
                                0,
                                0,
                                0.56008019458471936,
                                0,
                                -0.63753203720851648,
                                0.21951698459658434,
                                0,
                                0,
                                0,
                                -0.021403219800016093,
                                0,
                                0,
                                0,
                                0,
                                -0.12340183848501805,
                                0.66161946621224943,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20795003506652326,
                                0,
                                0.67614274814990383,
                                0.90460600330068897,
                                0,
                                0,
                                0,
                                0.019042683674459354,
                                0,
                                0,
                                0,
                                0,
                                0.63436486432100747,
                                -0.023242892009153263,
                                0,
                                0,
                                0,
                                -0.23620948790090648,
                                0,
                                0,
                                0,
                                0.019873839088179981,
                                0,
                                0,
                                0.69309297469617692,
                                0,
                                0.11810128330708593,
                                0,
                                0,
                                0,
                                0,
                                0.48612350804064436,
                                0,
                                0,
                                -0.17112272801142939,
                                -0.39851388460090342,
                                -0.15834125906406329,
                                0.35246782636446922,
                                0,
                                0,
                                0,
                                -0.085875823818692382,
                                0,
                                0,
                                0.374257507163481,
                                0,
                                0.3839505909268966,
                                0,
                                0,
                                0,
                                0,
                                0.20288687328060412,
                                0,
                                0,
                                0.084677794765389378,
                                0.72289266554712606,
                                0.099989090116339899,
                                0.59699786089675322,
                                0,
                                0,
                                0,
                                -0.27293724435214484,
                                0,
                                0,
                                -0.25924733598805338,
                                0,
                                -0.073947474763390017,
                                0,
                                0,
                                0,
                                0,
                                0.37658637985757476,
                                0,
                                0,
                                -0.53217607079642426,
                                -0.21526255007528453,
                                0.15828697736044431,
                                0.49644487204708676,
                                -0.33565267540143018,
                                0,
                                0,
                                0,
                                0,
                                0.57979022380120582,
                                0.15243187681006087,
                                0.13655083754733482,
                                -0.42987682963690449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22741265446264608,
                                0,
                                0,
                                0,
                                0.16226784810128639,
                                -0.56319682663138881,
                                -0.55963556966434558,
                                0,
                                0,
                                0,
                                0,
                                -0.1086799252332511,
                                0.17933075684714708,
                                -0.23575787207952589,
                                -0.4843159241760433,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.099363370026100822,
                                0,
                                0,
                                0,
                                -0.16009293918788656,
                                0,
                                0,
                                -0.33575997459696244,
                                -0.57761367414862164,
                                0,
                                -0.04717909874117375,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33631964971589545,
                                -0.062457380384029204,
                                0,
                                0,
                                0,
                                0,
                                0.65908268402962333,
                                0,
                                0,
                                0,
                                0,
                                -0.4676255260424127,
                                0.5625683517283292,
                                0,
                                -0.37174964298944269,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25370174274085633,
                                0.33287476574014208,
                                0,
                                0,
                                0,
                                0,
                                0.3891981963320863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3598422320698262,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47887321475312872,
                                0,
                                0,
                                -0.079316181654725579,
                                0.25328266542099243,
                                0,
                                -0.23108463048717617,
                                0,
                                0.97146806123388929,
                                0,
                                0,
                                0,
                                -0.31214212177041611,
                                0.39923093169481588,
                                0,
                                0.69861531796079956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50142578884698696,
                                0.060034801372768704,
                                0,
                                0,
                                0,
                                0,
                                -0.0093057728637456552,
                                0,
                                0,
                                0.15576184262620985,
                                0.27058216800312629,
                                0,
                                0,
                                0,
                                0,
                                -0.46075916297159386,
                                -0.41391226809451531,
                                0.20744476443122023,
                                -0.66049013814610835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18702427321772744,
                                0,
                                0,
                                0,
                                -0.068136151550974508,
                                0.10557350832666167,
                                -0.056300646839074514,
                                0,
                                0,
                                0,
                                0,
                                -0.18539085166131261,
                                0.30417618407734448,
                                0.57055969190534772,
                                -0.097352075427738397,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.70068226154912949,
                                0,
                                0,
                                0,
                                0.18116327552438571,
                                -0.52074337485333588,
                                0.29877411188456415,
                                0,
                                0,
                                0,
                                0,
                                0.51597263570173568,
                                -0.37930477902368231,
                                0.14446802896294347,
                                -0.1636463153070726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16121224888415467,
                                0,
                                0,
                                0,
                                0.39474038852699256,
                                0.048717386201634461,
                                -0.43588210343352835,
                                0,
                                0,
                                0,
                                0,
                                0.14986180443519251,
                                -0.61331737410942888,
                                0.32332514122338346,
                                0.21997395714387166,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15534323403971026,
                                0,
                                0,
                                0,
                                -0.48161959806928106,
                                0,
                                0,
                                0,
                                0,
                                0.66567670198511875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1916316967708842,
                                0,
                                0,
                                1.267378774424555,
                                -0.18101609828127213,
                                0,
                                -0.019939417173705669,
                                0,
                                -0.25057338016784442,
                                0,
                                0,
                                0,
                                0.7156671848929923,
                                0.15880201339517841,
                                0,
                                -0.0068559603542741564,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27994944456188608,
                                0.46930774756897786,
                                0,
                                0,
                                0,
                                0,
                                0.40488756881116561,
                                0,
                                0,
                                0,
                                0,
                                0.19593308189477737,
                                0.12565913399342668,
                                0,
                                0.46148335257795131,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56144015728389329,
                                -0.42195159926842141,
                                0,
                                0,
                                0,
                                0,
                                0.48948434338649754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58969438863326429,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5257961345395944,
                                0,
                                0,
                                -0.064014223741899634,
                                -0.33556037635988456,
                                0,
                                1.4997456582317237,
                                0,
                                -0.055537650019435877,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.40632609121001367,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73598956508688884,
                                0,
                                0,
                                0.35218131806425979,
                                -0.29173595472242353,
                                0,
                                -0.57903070408998925,
                                0,
                                -0.79759782892921027,
                                0,
                                0.35423124773324371,
                                -0.079345256132557329,
                                0,
                                0,
                                0,
                                0,
                                -0.031633988241502015,
                                -0.33721628242323198,
                                -0.64256582965581177,
                                -0.090889901196000045,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53058255335464366,
                                0,
                                0,
                                0,
                                0.22547584706612389,
                                0,
                                0,
                                0,
                                0,
                                -0.72272538020016086,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33840431759019274,
                                0,
                                0,
                                -0.014298726861285416,
                                -0.99679810833107729,
                                0,
                                0.0079394110083633729,
                                0,
                                0.36690109850980912,
                                0,
                                0,
                                0,
                                0.14349080303427386,
                                0.38663375283845947,
                                0,
                                -0.39811943458057536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42131930350144309,
                                -0.69526712459291007,
                                0,
                                0,
                                0,
                                0,
                                0.10256371862036363,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19117360176547726,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66888411315224738,
                                0,
                                0,
                                -0.81043255413648663,
                                -0.47072209439386142,
                                0,
                                -0.069458102614491757,
                                0,
                                -0.6689805259985625,
                                0,
                                -0.043789075911254444,
                                -0.46065821439519283,
                                0,
                                0,
                                0,
                                0,
                                -0.34011198988012853,
                                -0.21682561665023969,
                                0.13747508290517585,
                                0.22691345327666473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28432013539063872,
                                0,
                                0,
                                0,
                                0.68699342031697574};

const double rot_23_10[1000] = {-0.66359541490672214,
                                -0.57773624205215346,
                                -0.093162658028862672,
                                0,
                                0.19107263267292507,
                                -0.42404900179483995,
                                0,
                                0,
                                0,
                                0.029263837811622832,
                                0.39205351628366653,
                                -0.54563182223781226,
                                0.71439882721894132,
                                0,
                                -0.080487262202465479,
                                -0.051593138865870192,
                                0,
                                0,
                                0,
                                0.17051163961553006,
                                0.38593424261770287,
                                0.073845284929875576,
                                -0.22792648639192797,
                                0,
                                -0.3421710115790042,
                                -0.81587402752354288,
                                0,
                                0,
                                0,
                                -0.10449746942998062,
                                0,
                                0,
                                0,
                                0.4396506581117553,
                                0,
                                0,
                                -0.19400257124794934,
                                0.38353844578718277,
                                -0.17365551303880788,
                                0,
                                0.013808264439026455,
                                -0.1697073973975376,
                                0.098652979597980972,
                                0,
                                -0.037141185637275281,
                                0.1039653612259549,
                                0,
                                0,
                                0,
                                -0.97421150512236854,
                                -0.50608177373292484,
                                0.40767378074121952,
                                0.52407119232673427,
                                0,
                                -0.53659632677521085,
                                -0.12159750716091594,
                                0,
                                0,
                                0,
                                -0.017639175387020093,
                                0,
                                0,
                                0,
                                0.4412467425890616,
                                0,
                                0,
                                0.15871699590971305,
                                -0.64307513561597973,
                                0.69338847331907105,
                                0,
                                0,
                                0,
                                0,
                                -0.39717392869543511,
                                0,
                                0,
                                -0.63617089425865236,
                                -1.1733817050296207,
                                -0.53732604743591228,
                                0,
                                0,
                                0,
                                0,
                                0.030291569437727719,
                                0,
                                0,
                                -0.14374163388486991,
                                -0.22617247661630724,
                                0.72464944619533611,
                                0,
                                -0.02608632185659987,
                                -0.4099452534659237,
                                -0.38029137067241336,
                                0,
                                -0.74203568844254353,
                                0.35535251965996795,
                                0,
                                0,
                                0,
                                0.098744570553343042,
                                -0.574457243468385,
                                -0.21342352182851504,
                                0.16787559842517141,
                                0,
                                0.32623474352845072,
                                0,
                                0.46829898245916235,
                                0,
                                0.52012884399257087,
                                0,
                                -0.61077214694240756,
                                -0.14115914034129801,
                                -0.51162514811646997,
                                0,
                                0.044281577529546201,
                                0,
                                -0.58154310535682352,
                                0,
                                -0.071539834607758354,
                                0,
                                0.44124358792574481,
                                -0.56722260872023911,
                                -0.33432675698334235,
                                0,
                                0.60835683097925863,
                                0,
                                0.019189362807365579,
                                0,
                                -0.036358800749531184,
                                0,
                                0,
                                0,
                                0,
                                -0.27082958073869812,
                                0,
                                -1.1476189080385677,
                                0,
                                -0.072275643538808887,
                                0,
                                -0.48479278636075651,
                                -0.066856871554616198,
                                0.082115059398949281,
                                -0.66637409994399177,
                                0,
                                -0.27535968726445653,
                                0,
                                0.64415486725734017,
                                0,
                                -0.23232387799787416,
                                0,
                                0,
                                0,
                                0,
                                -0.2320184431253664,
                                0,
                                -0.99352290354107331,
                                0,
                                -0.4870229084369096,
                                0,
                                1.4028738142060966,
                                -0.038317901870016505,
                                -0.77651057297816961,
                                0.19634096598684073,
                                0,
                                -0.59309772794199611,
                                0,
                                0.019417169859630296,
                                0,
                                -0.069795072529745983,
                                0,
                                0,
                                0,
                                0,
                                -0.1218139390942353,
                                0,
                                0.43944177582986987,
                                0,
                                -0.56524007933682197,
                                0,
                                0.057210063902667363,
                                -0.31035826585204729,
                                -0.055420724084482287,
                                0.34011600202340148,
                                0,
                                0.30647043568174331,
                                0,
                                0.16377706951225729,
                                0,
                                -0.81497260008045613,
                                0,
                                0,
                                0,
                                0,
                                -0.048084174526836568,
                                0,
                                -0.38423177822451415,
                                0,
                                1.2199078087652659,
                                0,
                                -0.29755875169488566,
                                -0.093042379840318601,
                                -0.96132408812664472,
                                -0.61781574515096238,
                                0,
                                0,
                                -0.64180147847733349,
                                0,
                                0,
                                0,
                                0,
                                -1.3806232960219504,
                                -0.086316374862741407,
                                -0.6063194921487417,
                                0,
                                0,
                                0.18736659872193639,
                                0,
                                0,
                                0,
                                0,
                                0.80433833244979014,
                                0.89437671745465919,
                                -0.63364294172932678,
                                0,
                                0,
                                0.027450306733913993,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2695428133867378,
                                -0.11345698911975399,
                                0,
                                0.42020132166988644,
                                0.69587328223714218,
                                -0.40954470726225073,
                                -0.29315275959865467,
                                0,
                                0,
                                0,
                                0.39691395249815831,
                                0.098885593793924489,
                                0,
                                0.027043252336511097,
                                -0.35789355931170497,
                                -0.31133751268292553,
                                -0.77905761632563786,
                                -0.55959314951857941,
                                -0.51331679734827729,
                                0.19709167821916651,
                                0,
                                0,
                                -0.63559490964052001,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20475341897867019,
                                -0.68140335086212245,
                                0,
                                0.03891256534757756,
                                -0.043582293114920956,
                                0.575235606579379,
                                -0.39931930050848791,
                                0,
                                0,
                                0,
                                0.67661227669849155,
                                0.21370552088474548,
                                0,
                                0.1484610147846796,
                                0.48006254200391324,
                                0.49234275887829748,
                                -0.040294763905680341,
                                0,
                                0,
                                0,
                                0.0598291661846879,
                                -0.019552664855070762,
                                0,
                                0.89002277444030975,
                                -0.39231084204284739,
                                0.058084253403800384,
                                0.21590749841179013,
                                0,
                                0,
                                0,
                                -0.51623475413316144,
                                0.68336393527476946,
                                0,
                                0.083690573511538927,
                                -0.037487570992569094,
                                0.39833517313911837,
                                -0.31533326871338901,
                                0.47049614840158649,
                                0,
                                0,
                                0.4800364390938352,
                                -0.73476544964934742,
                                0.060262917285720627,
                                -0.037665602242772517,
                                0,
                                0,
                                -0.057164750422612487,
                                0,
                                0.68336557817374366,
                                -1.4424755625609733,
                                0,
                                0,
                                0,
                                0,
                                -0.22977558326843206,
                                -0.2061040570048768,
                                0,
                                0,
                                -1.3822178526148883,
                                -0.39739757552455474,
                                0,
                                0,
                                0,
                                0,
                                -0.096047501708850902,
                                -0.41404151214973917,
                                0,
                                -0.39120056109059925,
                                0,
                                0,
                                0.2216574572085028,
                                -0.072381164161739203,
                                0.8119811493220217,
                                0.25911632305168181,
                                0,
                                0,
                                0.25716999050184208,
                                -0.061578312990671451,
                                0,
                                0,
                                -0.63888720592559867,
                                -0.48482059290029905,
                                0.011533353007993144,
                                -0.25191610170097839,
                                0,
                                0,
                                0.53794563075257196,
                                0.56182039714644338,
                                0,
                                0,
                                -0.15377727105134692,
                                0.33439852763891725,
                                0.52857113929494215,
                                -0.51449958590969991,
                                0,
                                0,
                                -0.069215199012435114,
                                0.37902536128447106,
                                0,
                                0,
                                0.25812723960132006,
                                0.32365006219870551,
                                -0.18312350015262419,
                                0.25598527231273199,
                                0,
                                0,
                                0.76543978533166201,
                                0,
                                -0.15014997229609572,
                                0.15303185264790975,
                                0,
                                0,
                                0,
                                0,
                                -1.6282741775509095,
                                -0.33028905784585205,
                                0,
                                0,
                                0.065318174180625188,
                                0.48891153564588874,
                                0,
                                0,
                                0,
                                0,
                                0.032481335708004162,
                                -0.0034382153182631109,
                                0,
                                0.40311440505678303,
                                0,
                                0,
                                -0.47114648040111307,
                                -0.057078504953130604,
                                0.15492033472270306,
                                0.73330759419044034,
                                0,
                                0,
                                -0.22476983095092767,
                                -0.094468696400354615,
                                0,
                                0,
                                0,
                                0,
                                0.12279994398210307,
                                0.76621793897770851,
                                0.16517945313446281,
                                -0.10590341746217241,
                                0.59195111586900129,
                                0,
                                0.6173885007597627,
                                1.1211824065536498,
                                0.55421015238464011,
                                -0.33723243753549109,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64247279190310791,
                                0.86975242870598046,
                                -0.64475255448441349,
                                0.27913274288945905,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67766379478897953,
                                -0.42384308916605484,
                                1.2562426850605692,
                                0.71491736093448721,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.049315050614362962,
                                0.50215699794774826,
                                -0.097915587812776261,
                                -0.11537939813851505,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.024765633251143206,
                                0,
                                0,
                                0,
                                0,
                                0.57906013569212311,
                                0.19147610212580288,
                                0.18306328328059146,
                                -0.57123016706363827,
                                -0.51729764693811986,
                                0.79268461471426599,
                                0,
                                0,
                                0,
                                0,
                                0.063994661904978878,
                                -0.191692408425711,
                                -0.24529580863526482,
                                -0.37249860991583261,
                                0.36315913491391449,
                                0.18671350614911494,
                                0,
                                0,
                                0,
                                0,
                                0.39199974696709544,
                                0.3305888408093563,
                                -0.63398521334332425,
                                0.50521745242268667,
                                -0.21213994994112934,
                                0.18572378234784598,
                                0,
                                0,
                                0,
                                0,
                                0.55752425120083848,
                                -0.28164411088260022,
                                0.55803387738882904,
                                0.47023297480758841,
                                0.20695197966866563,
                                0.54107132034261274,
                                0,
                                0,
                                0,
                                0,
                                -0.42546107220115581,
                                0.38844382604552724,
                                0.4070558804281188,
                                0.21762725745684491,
                                -0.40283989794023739,
                                -0.25921308890685657,
                                0,
                                0,
                                0,
                                0,
                                0.62002949125628359,
                                0,
                                0.46127832664523172,
                                0,
                                -0.22931730520542706,
                                0,
                                0.74845031488724911,
                                -0.076214250928277341,
                                0.59903634933535788,
                                0.26567056362894553,
                                0,
                                0.067204232963445659,
                                0,
                                -0.0084681148115424432,
                                0,
                                0,
                                0.39748669315343466,
                                -0.67498145147766497,
                                -0.40321527782347322,
                                -0.40660053462457091,
                                0,
                                0.039299056227311585,
                                0,
                                0.23864911078704609,
                                0,
                                0,
                                0.08633259861137535,
                                -0.24357796581832203,
                                -0.41168424898734213,
                                0.71907416965496063,
                                0,
                                -0.43980350657540834,
                                0,
                                -0.23073307144739033,
                                0,
                                0,
                                -0.31669477097563659,
                                -0.26268758566478922,
                                0.38394653685305147,
                                0.092784906655619726,
                                0,
                                -0.47568284822266271,
                                0,
                                0.66962788189898703,
                                0,
                                0.48362752971138817,
                                0,
                                0,
                                0,
                                0,
                                -0.51355550056595445,
                                0,
                                -1.1285785479413297,
                                0,
                                -0.53503251755971348,
                                0,
                                0.36619088652294501,
                                0.50029550882274121,
                                -0.15498493789492482,
                                -0.366874334935541,
                                0,
                                -0.67537263892256982,
                                0,
                                0.029382451657583041,
                                0,
                                -0.86228127503694574,
                                0,
                                0,
                                0,
                                0,
                                0.25810762443597546,
                                0,
                                -0.87119450633416984,
                                0,
                                -0.57419113508847608,
                                0,
                                0.19995447980068431,
                                0.39995104559652733,
                                -0.37101711133677867,
                                0.32221371612895772,
                                0,
                                0.34367088523317196,
                                0,
                                0.663680882661696,
                                0,
                                0.37178913467968427,
                                0,
                                0,
                                0,
                                0,
                                0.97228270291323182,
                                0,
                                0.22272547127523357,
                                0,
                                -0.41639594990968537,
                                0.85229341441677831,
                                0.40866543142825984,
                                0,
                                0,
                                0,
                                -0.27453491213648989,
                                0.11549569388690226,
                                0,
                                -0.12471528381568424,
                                0.048227850790907897,
                                0.31722592026716734,
                                -0.44456515683587117,
                                0,
                                0,
                                0,
                                0.025951444950773214,
                                0.20310264347155965,
                                0,
                                0.65785373076732601,
                                -0.47648068635936036,
                                0,
                                0,
                                -0.044074361267378771,
                                0.53041111623605675,
                                -0.30152180800113115,
                                0,
                                0,
                                0.0066266525376346488,
                                0,
                                0,
                                0,
                                0,
                                1.0166833197796183,
                                0.40830299062866826,
                                -0.49168836620262829,
                                0,
                                0,
                                0.06194591772112823,
                                0,
                                0,
                                0,
                                0,
                                -0.017262605744361004,
                                -0.68422132043502715,
                                -0.55264137803218749,
                                0,
                                0,
                                0.74046793794113241,
                                0,
                                0,
                                0.014859653657581691,
                                -0.1440989181005235,
                                0,
                                0,
                                0,
                                0.12740073781207789,
                                0.25604761221223515,
                                0,
                                -0.67207755220750476,
                                -0.66748417853875441,
                                0.033186321560134166,
                                0.19064611466966214,
                                0,
                                0,
                                0,
                                0.67529651481681541,
                                0.65640874244079095,
                                0,
                                0.075172275117930107,
                                0.26458275831925576,
                                0,
                                0,
                                0.19357948898769489,
                                -0.15642399553102912,
                                -0.69003042346304855,
                                0,
                                0,
                                -0.58898854021047864,
                                0,
                                0,
                                -0.053766698129834214,
                                -0.49266484845070591,
                                0,
                                0,
                                0,
                                -0.52315180985774878,
                                0.54687192787359273,
                                0,
                                -0.17314672356693808,
                                0.38942775933114238,
                                0.41079271193527533,
                                -0.57924545259131344,
                                0,
                                0,
                                0,
                                0.42191581796246924,
                                -0.38717998210132054,
                                0,
                                -0.25368419715993462,
                                0.32163191010462266,
                                -0.73472888518534663,
                                0.12395233029446931,
                                0.2809270803506263,
                                0.049385239816946425,
                                -0.57994458584902464,
                                0,
                                0,
                                0.16466522415764218,
                                0,
                                0,
                                -0.26447930302672762,
                                0.5484490365755873,
                                -0.070270766683665803,
                                0.1494531882541468,
                                0.21969568935115258,
                                0,
                                0,
                                -0.74411956062234241,
                                0,
                                0,
                                -0.17636881299908397,
                                -0.090711974430841613,
                                -0.7669042703887059,
                                0.58346215183629557,
                                -0.071059004682863205,
                                0,
                                0,
                                0.16445593569018144,
                                0,
                                0,
                                -0.053431725848133216,
                                0.54510447647271998,
                                0.22394400000787157,
                                0.25452805921307797,
                                0.48280158498110393,
                                0,
                                0,
                                0.593273412412614,
                                0,
                                0,
                                -0.5968314627631861,
                                -0.42319683680758979,
                                -0.10166348606888731,
                                -0.3136598001114046,
                                0.59620210366098314,
                                0,
                                0,
                                0.022842052378098956,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.75565367325688204,
                                -1.3623946871708701,
                                0,
                                -0.33864715600902517,
                                -0.094913466598397139,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2701528135503428,
                                -0.25867656007088718,
                                0,
                                0.13956541773532127,
                                -0.15846233712066041,
                                0.007447219275238115,
                                -0.44651579908687633,
                                0.51721702929788116,
                                0.68675305376150297,
                                0.14762919903717558,
                                0,
                                0,
                                -0.19907432641112038,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34462281018310981,
                                -0.6115860828130365,
                                0,
                                1.5645866781321536,
                                0.071552900594209462,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5583136294284532,
                                -0.5537081684870544,
                                0,
                                0.17411381576601995,
                                0.40155262092902411,
                                -0.60823228163541021,
                                0,
                                -0.41876018158764788,
                                0.10234338164444076,
                                0.56230894303340528,
                                0,
                                0.13809977423253078,
                                0,
                                0,
                                0.33008535118726845,
                                0,
                                0.82100395379741387,
                                0,
                                0,
                                0,
                                -0.50825824516169782,
                                0,
                                0.67266360245585455,
                                0.064657029864244181,
                                0,
                                0.56655418069591212,
                                0,
                                -0.38233275402510214,
                                0.58913906619128853,
                                0.33042782927629333,
                                0,
                                0.13338676637535965,
                                0,
                                0,
                                -0.24244299622488857,
                                0.48488172133997665,
                                0,
                                -0.30607115747817876,
                                -0.47423991642072083,
                                0.18854561242871989,
                                0,
                                -0.40195564295790814,
                                0,
                                0,
                                0.49918821868288699,
                                -0.069766118957207746,
                                0,
                                0.18407003408949923,
                                0.64602385711579724,
                                -0.25167265105688846,
                                0,
                                -0.45442107256201114,
                                0,
                                0,
                                0.5235135650150412,
                                0,
                                0.050597987249333398,
                                0,
                                0,
                                0,
                                0.26741775218833308,
                                0,
                                -0.30239868458286023,
                                1.2431531502774291,
                                0,
                                -0.26148019853471799,
                                0,
                                -0.40731791647949833,
                                -0.013595644764729742,
                                -0.105298154888113,
                                0,
                                -0.69145762476995642,
                                0,
                                0,
                                -0.52567483376810509,
                                0,
                                -0.65539942198406731,
                                0,
                                0,
                                0,
                                -0.64051780975093986,
                                0,
                                0.33144749431717102,
                                0.710829312493508,
                                0,
                                0,
                                0.068721978668207784,
                                0,
                                0,
                                0,
                                0.053907939148392703,
                                0,
                                0.78041310518450868,
                                -0.48107443400448074,
                                0,
                                0.026839572329731227,
                                0,
                                0.62047752541193602,
                                -0.002414347688962544,
                                0.68165227905835357,
                                0,
                                -0.34198819565333494,
                                0,
                                0,
                                -0.18076419233188906,
                                -0.17334236148039123,
                                0,
                                0,
                                -0.15480293272382345,
                                0,
                                0,
                                0,
                                0,
                                -1.1290253312951484,
                                -0.69726223724126524,
                                0,
                                0.039689095191287355,
                                0.33284180587764045,
                                0,
                                -0.69328594055211945,
                                0.05027767983471048,
                                0.52139613839336563,
                                -0.36416196176247223,
                                0,
                                0,
                                0,
                                -0.33641519004392528,
                                0.29122561103527367,
                                0,
                                0.035936526065392271,
                                0.70240183976284465,
                                0.18481200861897748,
                                0.52268270149985641,
                                0,
                                0,
                                0.87618751584539845,
                                0,
                                0,
                                0.53772069377107212,
                                0,
                                0,
                                0,
                                0,
                                0.1217472301820221,
                                -0.28892447513868202,
                                0,
                                0.57753182300867745,
                                0.20685320381632455,
                                0,
                                -0.42180887701982062,
                                0.19709797076852709,
                                -0.59464657169620594,
                                0.23085463270064921,
                                0,
                                0,
                                0,
                                0.5777693385374133,
                                0.51067542244922859,
                                0,
                                0.52379629125334182,
                                -0.075207142119805725,
                                0.353007628351729,
                                0.027570812850632925,
                                0,
                                0,
                                0,
                                -0.46582329756776181,
                                0.70768312391166865,
                                0,
                                0.057763024040433424,
                                -0.31322984905426599,
                                -0.40328010570770789,
                                -0.13456932276429812,
                                0,
                                0,
                                0,
                                -0.029963910492695228,
                                0.0033070901240616485,
                                0,
                                -0.24988261307530124,
                                -0.60123801257301779,
                                0.23051423768288054,
                                0.72251362988409074,
                                0,
                                0,
                                0.60446565960803267,
                                0,
                                0,
                                0.58537075984854814,
                                0,
                                0,
                                0,
                                0,
                                0.54654810448232238,
                                -0.13193507775103203,
                                0.65341200152465673,
                                0,
                                0,
                                0.41332093846078671,
                                0,
                                0,
                                0,
                                0,
                                -1.0707176129365761,
                                0.8666687766535599};

const double rot_23_100[100000] = {0.15003167810126883,
                                   0,
                                   0,
                                   0.19337646983909518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021005034321415525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54645352766596322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35622902583836846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1027101319837715,
                                   0,
                                   0.21448556065193172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57074449784715919,
                                   0.77345486414276832,
                                   0,
                                   0,
                                   0,
                                   0.31442968243071961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28485391922615172,
                                   -0.27736197325304712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61420953408105039,
                                   0,
                                   0,
                                   0.27467509760179892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52333381816950941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14006912657662657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15746275670494503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22494920285817938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14176249090743143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015424220938039978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17629361303409288,
                                   0.34324037106722405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090923150826797514,
                                   0,
                                   0,
                                   0.53268576597993889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042648534122970275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68703082972802332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18537838253430106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10964607059965568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18636889539150411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064299579299096202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080423636504285245,
                                   0,
                                   0,
                                   -0.33744423767995957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44445456889595025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19404680467812269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6448337337881993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090796941657815877,
                                   0,
                                   -1.1113341378193444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51690048549788858,
                                   0.12919721333111889,
                                   0,
                                   0,
                                   0,
                                   0.71197305137678235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0018715240165994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013242523333241864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6423505580451343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63840916072875964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76916105674709934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60319011271195189,
                                   0,
                                   0,
                                   0,
                                   0.032570902561304474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41205610090852862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2334660589617493,
                                   0,
                                   0.73672964382312478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0059927741469973164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073828301789010189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081693007682685781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013642593193806797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0066367820312745046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21875641288736145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0099673938025471,
                                   0,
                                   0.079364404618937345,
                                   0,
                                   0,
                                   0.077167682448076605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013492169996070207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26004014830345401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12979819101795564,
                                   0,
                                   0.21831926881770669,
                                   0,
                                   0,
                                   0,
                                   -0.24570212588895265,
                                   0.095051173676721432,
                                   0,
                                   0,
                                   -0.42740418667546459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27014012202263127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01366260644680603,
                                   0,
                                   -0.69155464738140093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047276843134201142,
                                   0,
                                   0,
                                   0.044249620475775103,
                                   0,
                                   0.13626723686502118,
                                   0,
                                   0.10504955340387304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17487758201666245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17226134825153649,
                                   0,
                                   0.0050777178695135816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06292484164324802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18784020659415784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0279272081836146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077822251220619934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20257412317344692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6612652911063952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20176061543387955,
                                   0,
                                   -0.1475345729969752,
                                   0,
                                   0,
                                   -0.35796451589848544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30315466772883659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36199641276904648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038872532312856603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3581060058900315,
                                   0,
                                   0,
                                   -0.059895451643060767,
                                   0,
                                   0.30274658177200597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36750468324233398,
                                   0,
                                   0,
                                   -0.82717945950961191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062520467889075518,
                                   0.41668285404997074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65041154404154156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073372745244407567,
                                   0,
                                   0,
                                   0,
                                   -0.18824467588107338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18118568426028198,
                                   -0.69106682160779764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18079276346396284,
                                   -0.22752404795890929,
                                   -0.21783482594327663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013075612293588224,
                                   0,
                                   0,
                                   -0.080300174944471087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18693018409094803,
                                   0,
                                   0,
                                   -0.77475395184274354,
                                   0.024059324638161697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44517609304657485,
                                   0,
                                   0,
                                   -0.0015522219618659266,
                                   0.1109814769265148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12332558938218081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2413490317446283,
                                   -0.64653070480707364,
                                   -0.10801989997536536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2690637864832594,
                                   0,
                                   0,
                                   0.026447560667706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24706171984113565,
                                   0,
                                   0,
                                   -0.02748646848813004,
                                   0.23183943497743095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38521565135529484,
                                   0,
                                   0,
                                   -0.13382645231021181,
                                   -0.38346662277886068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10046794524135792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22539443923227723,
                                   0.39512357655392155,
                                   0.10621457150738733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24922292965637638,
                                   0,
                                   0,
                                   0.61798679256045308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019449244437931917,
                                   0,
                                   0,
                                   -0.22743282356026565,
                                   0.40931644724270411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15651196164750802,
                                   0,
                                   0,
                                   0.098916521194147219,
                                   -0.18906539373565123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21932467857205143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32675345624750385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31732351086305266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62430620622829891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22195366456593951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11413893960728883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42638846146936993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057275606332830728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39420931907395323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038662262742496123,
                                   0,
                                   0,
                                   0.29505615882267233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59558639252327494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31808937895915218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36048973241962412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08556780419302959,
                                   0,
                                   0.97835355738175034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38388664974925968,
                                   0.35192634083287311,
                                   0,
                                   0,
                                   0,
                                   0.58660313319766544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17501410104616091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019341479966011821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31655249065056362,
                                   0,
                                   0,
                                   0.4211700016309885,
                                   0,
                                   1.1000869724038016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10452580505698761,
                                   0,
                                   0,
                                   -0.41933918732688841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39921569178410016,
                                   0.65322935672533489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50302696096717059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18486853708125825,
                                   0,
                                   0,
                                   0,
                                   -0.22336024768735277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26324372167426913,
                                   0.1965536445741119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20267870402683591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016962617216405421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30149294952259481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71071447137440713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27415565629767169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70311539984989313,
                                   0,
                                   0,
                                   0,
                                   0.63665245468532183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30475515301395145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18347300203859149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18214442025292696,
                                   0,
                                   0.15671798402676496,
                                   0,
                                   0,
                                   0,
                                   -0.10888530295038233,
                                   0.0031906065901756986,
                                   0,
                                   0,
                                   -0.24447983476549578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17235716554764288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20112194859436738,
                                   0,
                                   -0.11069779865312704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57570201963762457,
                                   0,
                                   0,
                                   0.070803266086871763,
                                   0,
                                   -0.64353606937303476,
                                   0,
                                   0.0096060547559269974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062258029812585991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27102147105021168,
                                   0.12905124831274983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31286079458900729,
                                   0,
                                   0,
                                   0.45303122728311263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030109673708858899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30396443518534566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091272058712618787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25347796746969259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51718072181698405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41643178288180344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12474436255366173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19211558882258731,
                                   0,
                                   0.16201263840643315,
                                   0,
                                   0,
                                   0,
                                   -0.078254987786196079,
                                   0.103379494153652,
                                   0,
                                   0,
                                   -0.11358471883189036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45168788918985153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46077993181757221,
                                   0,
                                   0.35295026679069064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32108228702100788,
                                   0,
                                   0,
                                   0.16719970065027126,
                                   0,
                                   -0.023646026912237578,
                                   0,
                                   -0.46697318677822419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031353563323497813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27085478692021903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029225104364788451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4229639741300133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62449604517325397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041190906625622484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44240914186209734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20340771862394108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34364589949653795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014528065095212166,
                                   -0.48027506655233104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43237836206581198,
                                   0,
                                   0,
                                   0.12001711081746148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20313303076767061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093070371439466018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40215656882950668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43684702632682909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19358363506064377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35749778269736088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45988049321596808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2413843626551262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10927913183436917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65699002779112603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092408443019920128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18123649900860317,
                                   0,
                                   0,
                                   0,
                                   -0.66253070721213969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25798893999939704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069734099780112427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014428682971328169,
                                   0,
                                   0.081000421606329531,
                                   0,
                                   0,
                                   0,
                                   0.11391379284052033,
                                   -0.51108642022061079,
                                   0,
                                   0,
                                   0.35195270460569816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31093754842266619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05260952067973311,
                                   0,
                                   -0.074641705551039605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3838717590402177,
                                   0,
                                   0,
                                   0.36554616325436917,
                                   0,
                                   0.18226202438008846,
                                   0,
                                   0.40848941251231341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065004902164751049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23754905120200306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069695303504113015,
                                   0,
                                   0.35831077175520731,
                                   0,
                                   0,
                                   0,
                                   -0.10691851785814495,
                                   -0.099834483334098251,
                                   0,
                                   0,
                                   0.10242342064823015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010056220963030656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37270838958194408,
                                   0,
                                   0.14016060774554276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025226045173440844,
                                   0,
                                   0,
                                   -0.44082573363915961,
                                   0,
                                   -0.14149271105041453,
                                   0,
                                   0.40858815741134463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48770025169833497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19385451118403496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4407090696858178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1242684417104748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24750742692693722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038856138786625805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10563966546117927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8128268591702642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13467119577836595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28343000933226303,
                                   0.52661379648677542,
                                   -0.2590718105804109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31469673157904515,
                                   0,
                                   0,
                                   -0.38077634943399996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14288579132913687,
                                   0,
                                   0,
                                   -0.28582824831859471,
                                   -0.11811692479172842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22042133669857261,
                                   0,
                                   0,
                                   0.050797261636729284,
                                   -0.27500384156260815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29722666402699754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3062590210156903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48150924461844286,
                                   0,
                                   0.0313563714994698,
                                   0,
                                   0,
                                   0,
                                   -0.1629828228803597,
                                   0.032971185295407497,
                                   0,
                                   0,
                                   0.35477357911416185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31743818849368044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2351141927491823,
                                   0,
                                   -0.17175385689890513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095023660798239401,
                                   0,
                                   0,
                                   0.080419191441721244,
                                   0,
                                   0.020415111314172577,
                                   0,
                                   -0.38537792226383433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4121668455864313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28609395952564143,
                                   0,
                                   -0.001835559699072755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88024925558933664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061344581616810903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75269022232078897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31827540613252969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36907559668170919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09482650131101597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17751696813834336,
                                   0,
                                   -0.66083413402402635,
                                   0,
                                   0,
                                   -0.089882656260324101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61958377704800505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21702990803118433,
                                   0.0047774600821947483,
                                   0.32456950901180109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22118020891783041,
                                   0,
                                   0,
                                   -0.44327238761087773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30312263979281218,
                                   0,
                                   0,
                                   0.1174953314717483,
                                   0.28223208103171726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40035658379978684,
                                   0,
                                   0,
                                   -0.10138927908087944,
                                   -0.48842526386937624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087469312066782406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24162885836564829,
                                   0,
                                   0.34340716377425246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21021628614724294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62364609424381223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058424511581661065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62221238600077544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88164117234019235,
                                   0,
                                   0,
                                   0.29573021652023074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061702546569578132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87414951782279315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37473862270678648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29045065623374861,
                                   0,
                                   -0.03858039368370525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26017004823923973,
                                   0.37442007719780429,
                                   0,
                                   0,
                                   0,
                                   0.21305333095564233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17660402473344292,
                                   0,
                                   -0.21514660810479153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55679999939920122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.534220807970473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56178287954343398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10726062055229967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13609124011527832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40129744482989305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84452340605762644,
                                   0,
                                   0,
                                   0.036631301204232303,
                                   0,
                                   -0.047535589608946299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14743975531800535,
                                   0,
                                   0,
                                   -0.73908125524311086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11059978586582836,
                                   -0.1957162415391471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43301151898738433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28021189613131942,
                                   0,
                                   0,
                                   0,
                                   -0.3306626421281923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21135323277960621,
                                   0.0052304859293484315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19997098934245361,
                                   0,
                                   0.22819306031989134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04687142219567822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53215970842023397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099998755437578121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76794104379223582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20147234600689073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56874171370267146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33209733425955862,
                                   0,
                                   0.05008276672305647,
                                   0,
                                   0,
                                   0.66039690906487269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032747429754268011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098121453057120722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40394145585878938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19158000207688669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011578614604894462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83035930940776159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15424067719186277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26317931454901666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088410397292750659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13976560638830393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27116337347785646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15083309695378078,
                                   0,
                                   0,
                                   -0.34367648338834977,
                                   0,
                                   -0.2258302191648035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14507184134275983,
                                   0,
                                   0,
                                   -0.25175856340853908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018563378898991928,
                                   0.35612521891689997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23528681854971584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51780000646644164,
                                   0,
                                   0,
                                   0,
                                   0.82748809027866665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82160204455004238,
                                   -0.50917374347301103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20532597920838105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50784147979210292,
                                   0,
                                   -0.20397045155009197,
                                   0,
                                   0,
                                   0,
                                   0.57269236956679959,
                                   -0.13156698438555597,
                                   0,
                                   0,
                                   -0.12211140525503153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022356192143489294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44209892337914058,
                                   0,
                                   -0.23947971612369656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056982094852924436,
                                   0,
                                   0,
                                   -0.16611048566660416,
                                   0,
                                   -0.091572321617935423,
                                   0,
                                   -0.055682087878204903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050092737311893093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0021593780747852891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049029727276283269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12956964485635603,
                                   0,
                                   0,
                                   -0.86825996492738833,
                                   0,
                                   0.573925137446756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18342174761239954,
                                   0,
                                   0,
                                   0.34899819512098013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12623928910957488,
                                   -0.01861042058636557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25957656768797671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72643310975391306,
                                   0,
                                   0,
                                   0,
                                   -0.59643854108296412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076893972861338283,
                                   -0.015732461356861245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073420195986436926,
                                   -0.15461573093997411,
                                   0.56125869284170793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032637491804258068,
                                   0,
                                   0,
                                   -0.040260901714719341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1061894707892868,
                                   0,
                                   0,
                                   -0.31038396719379663,
                                   0.28287836269134647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18251878563784638,
                                   0,
                                   0,
                                   0.11002382001808689,
                                   0.23466206451780164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60405858384466438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34374014881668763,
                                   0,
                                   -0.71171921072897626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16348335193171759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16657065295480328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078380012577346794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10329786886590688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028342426924958281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8421036484778851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40151031893918432,
                                   0,
                                   0.096915648705765481,
                                   0,
                                   0,
                                   0.0049848254372491796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24536488373163251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40501925065673405,
                                   0,
                                   0,
                                   -0.4573643482832136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99842733628657676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41422258074680773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065284339896824722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5652021944828145,
                                   0,
                                   0.21715445055991206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036178200449295511,
                                   0.8043811878882009,
                                   0,
                                   0,
                                   0,
                                   0.55791384346616257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10278831486960821,
                                   0.098494763638814847,
                                   -0.034845539821009047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032025027697646605,
                                   0,
                                   0,
                                   0.28752505246180027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064934073477802071,
                                   0,
                                   0,
                                   0.013192996506211321,
                                   0.0039143467432533885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23020317448102456,
                                   0,
                                   0,
                                   -0.84992549859317945,
                                   -0.072394207371964503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33137484348952534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19419924634065494,
                                   0.062965894523757573,
                                   0.23313218351345877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3244801479781344,
                                   0,
                                   0,
                                   -0.04892680933831612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78691556373166627,
                                   0,
                                   0,
                                   0.29351633026130741,
                                   0.035791164255292357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20938577752429444,
                                   0,
                                   0,
                                   0.087230203329867084,
                                   0.1735464441902603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089729071367116095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17637522918672471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085657690515947404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43354647272910368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5548402904376819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32251271103510915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48352875956556035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33749368690891512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11843879375604026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049014866646603747,
                                   -0.70651724082292311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14284156768485859,
                                   0,
                                   0,
                                   0.14979264711704149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20372381958983551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10805919456785687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36973409685377234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26131559530825205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13830667827755067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42224556424924209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12179687593168857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30344013502924444,
                                   0,
                                   -0.35070502463457875,
                                   0,
                                   0,
                                   0,
                                   -0.64755750504118725,
                                   -0.16091782092759954,
                                   0,
                                   0,
                                   -0.029648261977874228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11600783590014734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34144995333689449,
                                   0,
                                   -0.018287773800470107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048077483412160865,
                                   0,
                                   0,
                                   -0.11111332825035318,
                                   0,
                                   0.0061357525130575213,
                                   0,
                                   0.13633001550905319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40041208309554571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0065271861488566812,
                                   0,
                                   -0.850786147254186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35930088993729731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29349602173965006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24444996387230458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033578242322235163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48872734924239153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23496445595311855,
                                   0,
                                   0.48000271131921024,
                                   0,
                                   0,
                                   0,
                                   -0.23002077328506282,
                                   -0.059989258570693219,
                                   0,
                                   0,
                                   0.31074849282625649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3914524837991899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02411825523917524,
                                   0,
                                   -0.035364469122151299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14812323495628144,
                                   0,
                                   0,
                                   -0.20103090627262141,
                                   0,
                                   0.188987913630492,
                                   0,
                                   -0.22079845599128467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14342975955213344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068119741149695434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55128769386777865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24846353877848038,
                                   0,
                                   0,
                                   0.088806977134090859,
                                   0,
                                   0.33338778916976763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71535688667252084,
                                   0,
                                   0,
                                   0.030082953792448686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072955065476136977,
                                   -0.16280437248945426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0648712759773101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021818967218981598,
                                   0,
                                   0,
                                   0,
                                   0.74774673676913772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79691815541358091,
                                   0.13185050855094002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44054646028401978,
                                   0,
                                   0.027131468949457498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58554773930526449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27583639925799214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30676514460021348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50746182194614853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30529896379882582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050010515583518184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.677433915044093,
                                   0,
                                   0.45285292969541951,
                                   0,
                                   0,
                                   0.28610448965272217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53393066313652093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34435468605255593,
                                   0.14106695616318293,
                                   0.29947558002681468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40552614793270175,
                                   0,
                                   0,
                                   -0.28987311891074036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24901439335153527,
                                   0,
                                   0,
                                   -0.19036203606074006,
                                   -0.099502512232425705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4562602916830143,
                                   0,
                                   0,
                                   -0.33721353956722977,
                                   -0.075997820849078482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2958846780385947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38156232431099291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16312302571713355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25186236275056983,
                                   0,
                                   0,
                                   0.66636581074237655,
                                   0,
                                   -0.25659208367504915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87123946243017225,
                                   0,
                                   0,
                                   0.5755905404893904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1414537557722933,
                                   0.5658848250272196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014428855333362689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20097320034130725,
                                   0,
                                   0,
                                   0,
                                   -0.43417607150785209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014494766264467662,
                                   -0.26413478482980823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38345227806151588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10506539489867472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39508256567823247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54638010546747018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72951799818540108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17862243343919498,
                                   0,
                                   0,
                                   0,
                                   -0.42780937877660952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55996677105054626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4988341084415393,
                                   -0.034846070109926797,
                                   -0.447035168972023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24570980502211293,
                                   0,
                                   0,
                                   -0.227332963502762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18244531296256247,
                                   0,
                                   0,
                                   0.13276874702372521,
                                   0.34016467949812379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25408058535185579,
                                   0,
                                   0,
                                   -0.18633094765397917,
                                   0.38733693856188395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14874254707126461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54590947011998359,
                                   0.19141763212631666,
                                   0.015731397679845799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11363350999631858,
                                   0,
                                   0,
                                   -0.21681881272167713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069454222723712253,
                                   0,
                                   0,
                                   0.025648751065143888,
                                   0.55238753304448807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082619501994306177,
                                   0,
                                   0,
                                   -0.12848765609695323,
                                   0.35924571041709286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37704829537726348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35651799604192397,
                                   0,
                                   -0.23805672858527166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68420452197033332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20881733212349776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38277040977000532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39745467640751364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4322769312860732,
                                   0,
                                   -0.17273276242384195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34748364926287806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30799065999319503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35661201512791063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031132367145140921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56693552029743988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56135555793767722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20833709653415389,
                                   0,
                                   0.04118820599763813,
                                   0,
                                   0,
                                   0.32693717322167209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79586014564667029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50995675698566356,
                                   0,
                                   0,
                                   0.18426886350340671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037223710949791128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62338875932043025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42842742082298169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19559117801345399,
                                   0,
                                   -0.20627909230950917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016644302523049104,
                                   0.38129592705305032,
                                   0,
                                   0,
                                   0,
                                   -0.77567264182134654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43241136751846576,
                                   -0.055896534919162424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036502418470291217,
                                   0,
                                   0,
                                   -0.18465778392107729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1243267339473568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15687958698403751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60367289366417798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44382878393805142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23561487095214179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34274976567433496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2366400178060519,
                                   0,
                                   0,
                                   0.13948635648034566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75064823939883829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032413831969431935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7029614967810579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76858025157584131,
                                   0,
                                   -0.25005442764250352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69043980319780318,
                                   -0.47741492493720239,
                                   0,
                                   0,
                                   0,
                                   0.053119412159032153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66848664269690872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73582707862206276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88271791275507738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69647312868919042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19409785019907971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81071618945781243,
                                   0,
                                   0,
                                   0,
                                   -0.27199568761106963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41471352826877839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62351984516519665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46732215888184908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080233778664148686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32756335927179636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41436064193867322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044340327146439033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32275071261846006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035622468078639169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0035187625961065165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025824121105399417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.361893095639997,
                                   0,
                                   0,
                                   0.079687962186433869,
                                   0,
                                   -0.26135606030119141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47741982865165328,
                                   0,
                                   0,
                                   0.11496905541421973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022063804964965211,
                                   0.47370674741641322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51526699018352351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18451432206661703,
                                   0,
                                   0,
                                   0,
                                   -0.076086218459234953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88760961448576936,
                                   0.087403835026705123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17156313772698767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16916109534877849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55592853911457574,
                                   0,
                                   0,
                                   0.23038253947220944,
                                   0,
                                   -0.10346272295043682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34689898007556336,
                                   0,
                                   0,
                                   -0.059836670093486199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21347013590233643,
                                   -0.61406966619342562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61482419068649774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1427012910541221,
                                   0,
                                   0,
                                   0,
                                   -0.26920819438231902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27404556930142532,
                                   -0.50961384284983446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24654039370840444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19627777307341587,
                                   0,
                                   0.50788782230058493,
                                   0,
                                   0,
                                   0,
                                   0.1275658523595391,
                                   0.20110084225989761,
                                   0,
                                   0,
                                   0.025568191592125505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029843212866495286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26435778466965976,
                                   0,
                                   -0.037817519956979989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38936377349010115,
                                   0,
                                   0,
                                   0.47044341947103097,
                                   0,
                                   -0.11138763973020382,
                                   0,
                                   0.1340311484879389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33147544040851279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2396042550195874,
                                   -0.1867342612628434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15473868236916613,
                                   0,
                                   0,
                                   -0.17063764076489107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17154170177378053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57918286228726867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35984569227929053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26770040880324664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53627213279737884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032237826034137031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28417939967128614,
                                   0,
                                   -0.42270513114118136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065404977678131415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65926194319957465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1409246803123152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4778937351451894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79953134842948193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49708008324931829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36300180874507137,
                                   0,
                                   0.40166561956965818,
                                   0,
                                   0,
                                   -0.73302311549267674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68498217634445713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39868764435561488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061455740880305476,
                                   0,
                                   -0.058734476120443774,
                                   0,
                                   0,
                                   0,
                                   0.053038224436045674,
                                   0.42936603254954792,
                                   0,
                                   0,
                                   -0.015927714843227102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23437102407928992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16398970751904535,
                                   0,
                                   -0.12029947739833871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46762020231521012,
                                   0,
                                   0,
                                   0.02299942575229081,
                                   0,
                                   0.56890083026175275,
                                   0,
                                   0.083984897537005707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014355137043885833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61797834268533181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40347454264127658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31890199793663593,
                                   0,
                                   0,
                                   -0.26080957269786381,
                                   0,
                                   -0.57709897637960339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045305371323720658,
                                   0,
                                   0,
                                   0.28839596082813218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69776866236319557,
                                   0.18525021115842455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41055449426711066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32004091590785161,
                                   0,
                                   0,
                                   0,
                                   -0.44638525051024225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16979014722034497,
                                   -0.010168691408258962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44132050298147396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34995901052374212,
                                   0,
                                   -0.1192732278994818,
                                   0,
                                   0,
                                   0,
                                   -0.10554629637952842,
                                   0.48937813913569511,
                                   0,
                                   0,
                                   -0.016868795172353582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12221272192862706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11946797717757708,
                                   0,
                                   0.3438695736148713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033936862427643058,
                                   0,
                                   0,
                                   0.18531504094510556,
                                   0,
                                   -0.047654007487937716,
                                   0,
                                   0.429675986294136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21859253972710355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60445075411412685,
                                   -0.11586381518785076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072426327460282311,
                                   0,
                                   0,
                                   -0.040419225824816357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61988849613130403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073213768259336343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099078627369906802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26210645986276859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38126905860577254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028828912635474196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015242494293651244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078170056532904597,
                                   0,
                                   0.097607886466729257,
                                   0,
                                   0,
                                   0,
                                   0.18001870236772574,
                                   0.3711186099192304,
                                   0,
                                   0,
                                   0.29591699433271301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46458177538908163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15722978754141195,
                                   0,
                                   -0.13682730211080918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082761020536917432,
                                   0,
                                   0,
                                   -0.4935882811348008,
                                   0,
                                   -0.12317910683548143,
                                   0,
                                   0.089660236345418698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43983771428819779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74814571812351094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80314099715619025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65415250769183875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29102461724240675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23568037758027402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55582313976235143,
                                   0,
                                   0,
                                   0,
                                   -0.21998861642581963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16753055200353498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38692510171266398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1552959297941952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22373777687398411,
                                   0,
                                   0,
                                   -0.34535493053842747,
                                   0,
                                   0,
                                   0,
                                   -0.30670199363115247,
                                   0,
                                   0.25084563051985026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43378026257078733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5762227956508047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033991260465861442,
                                   0,
                                   0,
                                   0.29788996453556726,
                                   0,
                                   0.024755425302199929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050245454289699135,
                                   0,
                                   0,
                                   0.054532245143692176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2686700494043649,
                                   -0.47678861486187196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61378065294146733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90133761648121302,
                                   0,
                                   0,
                                   0,
                                   -0.22954461435700926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10223498580270171,
                                   0.54375576049770202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39334209546147625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50933148669002482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17504688654171205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20159923147609618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066567580553574673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24358233186966069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078005800093468108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66688175110461978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16915706983197148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56976851512010729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62434283658436351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2078263845044952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55625845220965364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33464616167453148,
                                   0,
                                   0,
                                   0,
                                   0.71300396605799432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4342646515309192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23915065348013412,
                                   0,
                                   -0.14481973425836009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2546806648290933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74333059487924147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075773643299149429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10503535077960703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69069846885447039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064779079309919441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13403901072048371,
                                   0,
                                   0.12221408573896128,
                                   0,
                                   0,
                                   0.044846484521915031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80350818293642379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6510840355047427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48103751747708717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10172393042040605,
                                   0,
                                   0,
                                   -0.42569156644771555,
                                   0,
                                   0.020295309845905052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1315868647775143,
                                   0,
                                   0,
                                   -0.040734278536454713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.266346742535855,
                                   -0.077919079911211539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079838790854893579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35509797930429848,
                                   0,
                                   0,
                                   0,
                                   0.26703907977669444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076447922419082631,
                                   0.21285796143076724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8985866888601769,
                                   0,
                                   0.72038665797277734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083363370505064385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1232965077305519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13470367376466208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12617158838105544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04699216570805663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18294270699365778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11114435497441641,
                                   0,
                                   0.86655908462480269,
                                   0,
                                   0,
                                   -0.22432923816894867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32422940010195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31273299489699435,
                                   0,
                                   -0.23211885409712868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21751418731306996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40555011282210662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6878373930095808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40424660364768494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2205738386706739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39891186299138659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82889583726881777,
                                   0,
                                   0,
                                   -0.32703999409203499,
                                   0,
                                   0,
                                   0,
                                   -0.19381348890667044,
                                   0,
                                   0.39443744313121842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35059265949996027,
                                   0,
                                   -0.1353965877925194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47600172830471077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17215336302657264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016157448246119789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30737020141804883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4438083824357355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063949448977192846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051607558981511426,
                                   0,
                                   0.68511048851558209,
                                   0,
                                   0,
                                   0.30285916343451169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21179118090680615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44503848072806351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23645865474405631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39262740468480178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20870916914788903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11886461326795905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54075745705976952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035199918764239474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49043429849253406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44592018906761804,
                                   -0.067101658876118353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51138465553079626,
                                   0,
                                   0,
                                   0.36972168111797105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4567273393953985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027544534733942624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33337080373941536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079591655251704474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25593546133173384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078177466577771595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1322530013036019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3163539894713448,
                                   0,
                                   0.29230708586780563,
                                   0,
                                   0,
                                   0,
                                   0.088485074155410209,
                                   -0.24327879186434637,
                                   0,
                                   0,
                                   -0.53227299255816729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20484103228332917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31889571238645442,
                                   0,
                                   0.34409702495014338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021025642536185857,
                                   0,
                                   0,
                                   -0.22468917824035331,
                                   0,
                                   0.33976182335780036,
                                   0,
                                   0.019177675199521252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13366703502498112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67566388934024557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61670430972707213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1192083712064873,
                                   0,
                                   0,
                                   0.4627420584762571,
                                   0,
                                   0,
                                   0,
                                   0.88212764240526242,
                                   0,
                                   0.352628339867609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83542230725808064,
                                   0,
                                   0,
                                   0.46175753367229688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12579865509681076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37885841921566177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40755295112737089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14590354595999824,
                                   0,
                                   -0.075785706878720646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043874373119500425,
                                   -0.61431747890424071,
                                   0,
                                   0,
                                   0,
                                   0.34231145504583721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14556407489712664,
                                   0,
                                   0,
                                   0.98270315753541859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56922209517081468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075501406295901061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78086037358291793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20593051198759926,
                                   0,
                                   -0.17903105041705439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72071027716854186,
                                   0.1173627122690014,
                                   0,
                                   0,
                                   0,
                                   -0.50871702470312818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54597614055125643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1662183436493993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66504250861701186,
                                   0,
                                   0,
                                   1.2628722609787584,
                                   0,
                                   0,
                                   0,
                                   0.3600414808085674,
                                   0,
                                   0.67421791121393615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82793532446372142,
                                   0,
                                   -0.037366028392374587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035178041882097645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17736456941456252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039966511524605175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52804722446919206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33242859371519007,
                                   0,
                                   -0.12116514931690618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28699077937008932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66150089746302032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71750027287525386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75195306495783076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40485260592731342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22074146536339895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19333471438419142,
                                   0,
                                   0.14851541177427158,
                                   0,
                                   0,
                                   0.43895424030746694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34037773547320449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29274279689441129,
                                   0,
                                   0,
                                   -0.7421371574509148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41809079395562004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44402643484532645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30235320222338846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27878876814907155,
                                   0,
                                   0.62566353281171483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49591493791572261,
                                   -0.74584227539107539,
                                   0,
                                   0,
                                   0,
                                   0.1530935477326697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70628773305286929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98368953339619991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19222941411780731,
                                   0,
                                   0,
                                   -0.82515241977584874,
                                   0,
                                   0,
                                   0,
                                   -0.34317701670888573,
                                   0,
                                   1.0315520910518599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055833038220687935,
                                   -0.053387680233262229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1311741798455679,
                                   0,
                                   0,
                                   0.44404582156961642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053707537466437145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17161895967289803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13861452530307583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51992424868263754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2590744057555841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6250253953025624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40081210576553183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39960125807433583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72546339478473187,
                                   0,
                                   0,
                                   0.62337943406878482,
                                   0,
                                   0,
                                   0,
                                   -1.1731941095029046,
                                   0,
                                   -0.26938072011176828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88384702956826222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63978976629829953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29058680362436357,
                                   0,
                                   0,
                                   -0.20235753213802166,
                                   0,
                                   -0.10748298965294026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3567085169148298,
                                   0,
                                   0,
                                   -0.12284729256025961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18050999915474814,
                                   0.20177854116021554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49439989109736981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12720969955492217,
                                   0,
                                   0,
                                   0,
                                   0.34669524480402059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15176803946802947,
                                   0.35603527198560897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33624305935033116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26807615709793792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16515683466359152,
                                   0,
                                   0,
                                   0.46338327504933513,
                                   0,
                                   0.129206247261206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075834544143107807,
                                   0,
                                   0,
                                   0.62803268511251464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48148557912983581,
                                   -0.17834906358006503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.00078220653449856403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16061577307984876,
                                   0,
                                   0,
                                   0,
                                   0.56986816090401959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26507290752812129,
                                   -0.75068295365573323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04495195822312454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63047813556019472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53725079285159616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69160317622127554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10427694007527433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52427645802403966,
                                   0,
                                   0,
                                   0,
                                   0.11529745864132261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60389694797156146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10828360863330472,
                                   0.037901300961883044,
                                   -0.31110271015975643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61012409113148425,
                                   0,
                                   0,
                                   0.0078209442415451136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23768164467726638,
                                   0,
                                   0,
                                   0.12076827687143665,
                                   0.41528769835916285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10175854714776988,
                                   0,
                                   0,
                                   0.2289420708563101,
                                   -0.33972894982333679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30986163859543125,
                                   -0.4839419877507587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53213103845514798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2535623754439138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20272545618610574,
                                   0,
                                   0,
                                   0,
                                   0.24808747667067893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61071409886595274,
                                   -0.39801176325297594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22097736633643866,
                                   0,
                                   0,
                                   0,
                                   -0.36088372129827645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38346099429946634,
                                   0.28430425127561165,
                                   0,
                                   0.17183261989587412,
                                   0,
                                   -0.25315202666842018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088508678475908834,
                                   0,
                                   0,
                                   0.59006256276478808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15938239585221176,
                                   0,
                                   0.049598457618738448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27949217444118507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28561147845131918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068695989314651221,
                                   0,
                                   0,
                                   0.26924391544264709,
                                   0,
                                   0.18110395421766054,
                                   0,
                                   -0.004580806787490066,
                                   0,
                                   0.4200902599397987,
                                   0,
                                   0,
                                   -0.38727519499545004,
                                   0,
                                   0,
                                   0,
                                   -0.26442713943677321,
                                   0,
                                   0.15550093650804461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18104671246914184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31810726475695866,
                                   0,
                                   -0.16805248960201435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15419951398271972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11987852437421606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51587754164528832,
                                   0,
                                   0.087396564871068838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37670024729433937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62020271907760161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40760167306606532,
                                   0,
                                   0,
                                   0.6110548455177387,
                                   0,
                                   0,
                                   0,
                                   0.2295308042225413,
                                   0,
                                   -0.32991457348071895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24908863363796918,
                                   -0.24945075597043523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84071594030355312,
                                   -0.17045930019583416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40946436477081549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14498758454475066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10038649444108866,
                                   0,
                                   0.25287454200069148,
                                   0,
                                   -0.56381111037047482,
                                   0,
                                   -0.28549781068127811,
                                   0,
                                   0,
                                   -0.083774073216898975,
                                   0,
                                   0,
                                   0,
                                   -0.19810535760067732,
                                   0,
                                   -0.20947189213848505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34176166986321826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11340616828725705,
                                   0,
                                   0.20157497227474749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066432313144822466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15043682700532815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10145329482552976,
                                   0,
                                   -0.47834194713639905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38296497242795446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24525898610252533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14332260527160565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58262729351754405,
                                   0,
                                   0,
                                   -0.29777981210313975,
                                   0,
                                   -0.071361036857880061,
                                   0,
                                   -0.39728564132325572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.426132411835283,
                                   0,
                                   0,
                                   0,
                                   0.13305054370978314,
                                   0,
                                   0.16904873065075671,
                                   0,
                                   -0.14963028515714272,
                                   0,
                                   -0.11794922419259984,
                                   0,
                                   0,
                                   -0.32131736200772232,
                                   0,
                                   0,
                                   0,
                                   -0.28390040311069009,
                                   0,
                                   0.15405392223388253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29398778487066257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23555051012102071,
                                   0,
                                   -0.027548492359265854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17205180495647979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34533162297711179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64643717145101753,
                                   0,
                                   -0.020818041149857028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54486146211105313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32879645094459914,
                                   0,
                                   0,
                                   0,
                                   0.18286686472738706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84816421720820256,
                                   0,
                                   0,
                                   0.35648663927822188,
                                   0,
                                   0.32880036462839801,
                                   -0.56140899116584875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022222169361377615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59998006953771488,
                                   0,
                                   0,
                                   0,
                                   -0.030463383579185724,
                                   0,
                                   0,
                                   0,
                                   0.049351884813167282,
                                   0,
                                   -0.03673692595826536,
                                   0,
                                   0,
                                   0,
                                   -0.20355010847880395,
                                   0.23566953355419951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41015450494804828,
                                   0,
                                   0.037668344314397223,
                                   0,
                                   -0.041016861341967303,
                                   0,
                                   -0.45075228632139652,
                                   0,
                                   0,
                                   -0.28123117597916764,
                                   0,
                                   0,
                                   0,
                                   -0.32245405801110005,
                                   0,
                                   0.1358644466887251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16812906379504855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077864558858413341,
                                   0,
                                   0.025249662066136616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15980957218648018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12450068334196131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25174216874304967,
                                   0,
                                   0.53346618780656885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.420075987828055,
                                   0,
                                   0,
                                   0,
                                   -0.72068079264240559,
                                   0,
                                   0,
                                   -0.12272579684814983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26109181334287668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57747403331433511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71897002235803331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18915764574510807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15113129799749145,
                                   0,
                                   0,
                                   -0.9519821186563987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20014021678788821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23314871400412707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29799456465198021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62502011387891454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086518590910393767,
                                   0,
                                   0,
                                   0,
                                   -0.57298900296766908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36109404557246177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2269790305842469,
                                   0,
                                   0.53066413522669131,
                                   0,
                                   0.12451576604599693,
                                   0,
                                   -0.14124624657509383,
                                   0,
                                   0,
                                   0.19797332843726143,
                                   0,
                                   0,
                                   0,
                                   0.070950963171272682,
                                   0,
                                   -0.11114641197067472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21696063812551808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058220567296941861,
                                   0,
                                   0.30052800825486747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49023557273476481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17891251064957578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08406599786069073,
                                   0,
                                   0.39326083242102416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42444963245684958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33766424383704907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096139157231839967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1463674405163211,
                                   0,
                                   0,
                                   0,
                                   -0.67726314613765637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68500120730834169,
                                   -0.18117158457176577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40001859335819029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41243276701978288,
                                   0,
                                   0,
                                   0,
                                   0.38628298635282543,
                                   0,
                                   0,
                                   0.9193957694766024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21977269221130247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41815785922500115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21385871226769204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68081329003099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46780689296899275,
                                   0,
                                   0,
                                   -0.21164013267859857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5327555372585463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78030962822932082,
                                   0,
                                   0,
                                   0,
                                   0.077572723817099301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2259986174495629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1427073299311771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51161814835383734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14883322085966899,
                                   0,
                                   -0.10177683937671922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11273790672921502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052240586678555592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062902325925381211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093994098085025471,
                                   0,
                                   -0.069844102689468307,
                                   0,
                                   0.23735942255808865,
                                   0,
                                   -0.30666518434640588,
                                   0,
                                   0,
                                   -0.49644170319390646,
                                   0,
                                   0,
                                   0,
                                   0.51961071842565998,
                                   0,
                                   0.38483956619743881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27558233996598397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15230621871976829,
                                   0,
                                   0.084056203543716929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043463572220880903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20230990373854427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076559680013148793,
                                   0,
                                   -0.12831486824522431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26900596091622159,
                                   0,
                                   0,
                                   0,
                                   0.30509108919053546,
                                   0,
                                   0,
                                   0.13792982919256408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30900876298379643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43492967045163589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016551212537092033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81060868380119344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94348239623253627,
                                   0,
                                   0,
                                   -0.59673360227196937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0056933634045602532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16679296753478359,
                                   0,
                                   0.063055718680469885,
                                   0,
                                   0.31572960404739608,
                                   0,
                                   0.34032725457251978,
                                   0,
                                   0,
                                   -0.19902994769100377,
                                   0,
                                   0,
                                   0,
                                   -0.33815837381873359,
                                   0,
                                   0.19098925127633631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.125230021312673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34045528400787761,
                                   0,
                                   0.50908020133958343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041809410861241826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26405338049224464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06885090168989097,
                                   0,
                                   -0.30868703890649846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03479076966210834,
                                   0,
                                   0,
                                   0,
                                   -0.018128582635177803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30598671153741747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17523342979784479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41575618203394532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33524677038934292,
                                   0,
                                   -0.39286572691742883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39257727671262294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44437290591676776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2880191959496029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51272043962331704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36901629904769839,
                                   0,
                                   -0.99453488480522334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94875428791547378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028229815496241248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60468430753840607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28396555451226335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6748963005225207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12770814721216925,
                                   0,
                                   0,
                                   0.65983361961839349,
                                   0,
                                   0,
                                   0,
                                   0.056269605518626489,
                                   0,
                                   -0.43483642490247965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11712519422110897,
                                   -0.8873693473594958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72772080133506489,
                                   -0.069381156416674167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16107852627379157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0029604621451473712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19130578967278478,
                                   0,
                                   0,
                                   0,
                                   -0.094957747547733673,
                                   0,
                                   0,
                                   -0.69165246836485328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024158316234871489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057029768837874445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40143317143823831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.090796166672326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84360553475420785,
                                   0,
                                   0,
                                   0.36459257022553532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14371854439060544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042197281823019434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072140481587505578,
                                   0.14189680806570015,
                                   0,
                                   0.047527445711337303,
                                   0,
                                   0.0054657504716869344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6780462847507791,
                                   0,
                                   0,
                                   -0.10393245613226523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45694495149689074,
                                   0,
                                   0.26562802075313552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26421425010994598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30993622908718704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23412905370345705,
                                   0,
                                   -0.081012629888468801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14180433446044746,
                                   0.49314968566571077,
                                   0,
                                   -0.30366681911508875,
                                   0,
                                   0.44750582831786617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39449340439372749,
                                   0,
                                   0,
                                   -0.17713777658664859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29404737439745998,
                                   0,
                                   0.25379713788791886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11334486427130407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25922312707486256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14047596656780481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083328772039913818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25951148728837103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16616079557145513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30961952609740107,
                                   0,
                                   0,
                                   0.15203635348711331,
                                   0,
                                   -0.83010023958273216,
                                   0,
                                   0.2999835187182206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0080542380425710491,
                                   0,
                                   0,
                                   -0.05921848755777831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14638963651789333,
                                   0.60317118016085813,
                                   0,
                                   0.10233932623464194,
                                   0,
                                   -0.35280265292970348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047519134011448402,
                                   0,
                                   0,
                                   -0.32394029133371133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43420803767696592,
                                   0,
                                   0.24530335987248325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1259571246166333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32062117230026649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041663541652444458,
                                   0,
                                   0,
                                   0,
                                   0.63320468061513691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78238094119169566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92404056229199449,
                                   0,
                                   0,
                                   -0.15761334241223821,
                                   0,
                                   0,
                                   0,
                                   0.16297382037764824,
                                   0,
                                   0.27152167318403403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3682833626449431,
                                   0.04823127673539316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042079044883666539,
                                   -0.29737434086938819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3715554343404725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19428511039859053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13685531230346223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52132945224238492,
                                   -0.0099325499731875572,
                                   0,
                                   -0.25674550397181761,
                                   0,
                                   0.045751934913209058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27140221151057953,
                                   0,
                                   0,
                                   -0.12901469438446705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095269674296562551,
                                   0,
                                   0.18113746146010545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15614578215618991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094431140684402295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68984511930657233,
                                   0.24018079962915109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1066997237983933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070654954817859217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32010845023129492,
                                   0,
                                   0,
                                   0,
                                   -0.16959460775472338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64461526151116488,
                                   0.45406876937565771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10752265235568301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78677761327597673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015076663603945051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062132535662593157,
                                   0,
                                   0,
                                   0.54128268157055792,
                                   0,
                                   0,
                                   0,
                                   -0.24119798000423426,
                                   0,
                                   0.87649463759906654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011932748535785298,
                                   0.17487105574809075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18977289958182353,
                                   0.50233413446751296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25880368950483246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07476802980479802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35218105989528059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53351830884597595,
                                   0,
                                   0,
                                   0,
                                   0.252052192900588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068317258294003688,
                                   0,
                                   0,
                                   0.2125676805432315,
                                   0,
                                   0.54322925099780206,
                                   -0.62774545584159691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066533077037050234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6016471090535882,
                                   0,
                                   0,
                                   0,
                                   0.038420091694334572,
                                   0,
                                   0,
                                   0,
                                   0.055178814390898973,
                                   0,
                                   0.39706885678311044,
                                   0,
                                   0,
                                   0,
                                   -0.029274375357597433,
                                   0.40760985220102525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26993648955963262,
                                   0,
                                   0.29012993887326333,
                                   0,
                                   -0.24716967590918554,
                                   0,
                                   0.2534022519895523,
                                   0,
                                   0,
                                   0.011520143441531256,
                                   0,
                                   0,
                                   0,
                                   0.19506522456074588,
                                   0,
                                   0.082917676997213252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12281488080825992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034007920320672652,
                                   0,
                                   0.33014923410439295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68816360962261169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012903714710493078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073513379822621697,
                                   0,
                                   0.26118276479781688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82875621580594461,
                                   0,
                                   0,
                                   0,
                                   -0.32693854240067893,
                                   0,
                                   0,
                                   0.43691010197884195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88219407381787818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12062948241353921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21475258404376366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4613988404796755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42976113506790553,
                                   0,
                                   0,
                                   -0.25996972003079888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0033070486851085601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25568831481308757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079783748121594722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099123720681326605,
                                   0,
                                   0,
                                   -0.41385349685868095,
                                   0,
                                   0,
                                   0,
                                   -0.36747408212473215,
                                   0,
                                   0.6530420344222384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13454620821344049,
                                   -0.67326088352006275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48249226339427681,
                                   -0.23242607813036253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25919741046374412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55827537001775041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37712814820503038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043630777707250289,
                                   0,
                                   0,
                                   0,
                                   0.45154042831953284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13677726248632205,
                                   0,
                                   0,
                                   -0.27586296217798134,
                                   0,
                                   -0.54497018652392193,
                                   -0.51868168768722533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086764287206595569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44608905379511027,
                                   0,
                                   0,
                                   0,
                                   -0.32538167254833039,
                                   0,
                                   0,
                                   0,
                                   0.23673899360248488,
                                   0,
                                   -0.16689707860602082,
                                   0,
                                   0,
                                   0,
                                   0.13856774284078549,
                                   0.66949965488529906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13839618638876541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067014041189572271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60727799431634721,
                                   0,
                                   0,
                                   0.43806509727781984,
                                   0,
                                   0,
                                   0,
                                   -0.93682397006870488,
                                   0,
                                   -0.39938059183378893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90260025757113627,
                                   -0.24129969171659249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071856229835420338,
                                   0.53214305456856237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21547290423736618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031673065292838844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.4096699269916089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37457075322778782,
                                   0,
                                   0.63215441694903785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3662613931060652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29452170196972638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75332320642026651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23704114676159105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17146902016837506,
                                   0.17296225584765285,
                                   0,
                                   0.2755156370791238,
                                   0,
                                   -0.13796938451518362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20661996555857742,
                                   0,
                                   0,
                                   -0.094879393364217343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37375453572615275,
                                   0,
                                   -0.067228834033820253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62432484321117521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44771488120238767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058423516867691247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3300188618498851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43023955741768372,
                                   0,
                                   0.088248184793003032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23931418576021865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0315150530750838,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2486136567056407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62086329708268373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13283958410435695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11184486085022929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0062940642451914377,
                                   0,
                                   0,
                                   -0.75283865418460871,
                                   0,
                                   -0.077658433805106855,
                                   0,
                                   -0.049718680907176335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095208740568117706,
                                   0,
                                   0,
                                   0.24812322403826492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4978217720472991,
                                   0.14543771199284941,
                                   0,
                                   0.013531100267485236,
                                   0,
                                   0.094757058329395322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29381148622230724,
                                   0,
                                   0,
                                   -0.097159447249064043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22008737092465613,
                                   0,
                                   -0.049722604433928855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44650734340631071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52117657939099771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20645691957781123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33095108817888852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37152534822252481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50860358003807371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26741378783850978,
                                   0,
                                   0,
                                   0,
                                   0.64977951833652248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0062557859627770662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078916285752482607,
                                   0,
                                   0.64863478534758445,
                                   0,
                                   0.25113339932331274,
                                   0,
                                   -0.069407420782105211,
                                   0,
                                   0,
                                   -0.017038515357182364,
                                   0,
                                   0,
                                   0,
                                   0.038880901228855347,
                                   0,
                                   0.034183211676860441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057684698708791532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30351626118563746,
                                   0,
                                   -0.54904487443599037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21797331035238959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0094444902388134064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0012566379295063518,
                                   0,
                                   -0.24017945862194387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25066949672404298,
                                   0,
                                   0,
                                   0,
                                   0.4560987214537231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29262464503649593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0041484613339240195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49699919187460029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1189633126084091,
                                   0,
                                   0.4290628882546012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031628808284992045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10721497747812536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43097738412694658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23903493647802718,
                                   0,
                                   -0.035631195629452897,
                                   0,
                                   0.0088833668543667442,
                                   0,
                                   -0.23252829474648801,
                                   0,
                                   0,
                                   0.52933394515033572,
                                   0,
                                   0,
                                   0,
                                   -0.29248552131781119,
                                   0,
                                   0.6948097634949213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061719874978602443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090015392842547767,
                                   0,
                                   -0.014963868800656328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067260110612574295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037950209554103762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082192088097956292,
                                   0,
                                   -0.11868390937094615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42277712339043977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0730253903849446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28909341568417646,
                                   0,
                                   0,
                                   0.22648869898645246,
                                   0,
                                   0,
                                   0,
                                   -0.24868725926780477,
                                   0,
                                   -0.23775710221715188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030971596635434293,
                                   -0.079980547632426721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55567521478717141,
                                   -0.10078086152838628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2005600326612091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17047992387497882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51931970711147346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18165441053625794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050533249609176871,
                                   0,
                                   0,
                                   0.61023664427917934,
                                   0,
                                   0,
                                   0,
                                   0.068767685965146597,
                                   0,
                                   0.015663909617820174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76262343497646023,
                                   0.38844134753452259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27867203189772533,
                                   -0.51532571642496894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28424750553525796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56074982821304997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60972500032484866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21110602359400854,
                                   0.2623523656231872,
                                   0,
                                   0.50137000902804851,
                                   0,
                                   0.37300251159033565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015051963369651594,
                                   0,
                                   0,
                                   0.21006271247569963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10892718981005876,
                                   0,
                                   -0.11051589755778658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20468471251337644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050843650468476248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10688984063571216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10420418760369858,
                                   0,
                                   0,
                                   0,
                                   -0.12913173480197826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086814221125949387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018147569895851229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36680544265906367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54352496322325028,
                                   0,
                                   -0.099256013139362192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015161846758820288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71080481189341405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13895935487263061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48518060550620834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014361080180233673,
                                   -0.17169401599289535,
                                   0,
                                   0.056395746014539276,
                                   0,
                                   -0.51955449853161983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27820337664712813,
                                   0,
                                   0,
                                   0.053878556156007562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22650403614669806,
                                   0,
                                   0.52274957846243753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039786577965433223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22676427583407616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062618853634220706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4984985889166198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1367972758747994,
                                   0,
                                   0,
                                   0,
                                   -0.74394597849626054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066226817507989477,
                                   0,
                                   0,
                                   0.61209351925781996,
                                   0,
                                   -0.28799967479696165,
                                   -0.67744774178305922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12909794235004002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30483132965336335,
                                   0,
                                   0,
                                   0,
                                   -0.38540522275999889,
                                   0,
                                   0,
                                   0,
                                   -0.22618889719339638,
                                   0,
                                   0.12460790104069012,
                                   0,
                                   0,
                                   0,
                                   -0.11452658469467701,
                                   -0.10384026230098856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80794968418130786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68358064716615574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12294022966402002,
                                   0,
                                   0,
                                   0.3622167383868351,
                                   0,
                                   0,
                                   0,
                                   0.27230611282791284,
                                   0,
                                   -0.64030054025507854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.510700026441537,
                                   -0.45562316043233347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20473282024941092,
                                   -0.26825942396831326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42941223135770101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69645441886013648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14886428664004053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44401975849994157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048999240456887125,
                                   0,
                                   0,
                                   -0.31679167014435206,
                                   0,
                                   0,
                                   0,
                                   0.87244021060362031,
                                   0,
                                   0.10662397809602389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78945501627075898,
                                   -0.53655272743645566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20351373173688359,
                                   0.48541273801666707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024586996312444667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19046486455239581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6036103338733273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50013619731854186,
                                   0,
                                   0,
                                   0,
                                   -0.10534730032760337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50815309056205449,
                                   0,
                                   0,
                                   -0.21397003638092216,
                                   0,
                                   0.13246550343396168,
                                   0.31939303730093183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43183683835247261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0082327409841765481,
                                   0,
                                   0,
                                   0,
                                   0.050043643660575968,
                                   0,
                                   0,
                                   0,
                                   0.38452906056572289,
                                   0,
                                   -0.19957222992346157,
                                   0,
                                   0,
                                   0,
                                   -0.66522115568384232,
                                   0.091515110748095069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17047542407915389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52567068588559829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3105819731156334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50132300995198864,
                                   0,
                                   0,
                                   0,
                                   -0.35512895467427352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46979353231588061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029069319529879137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018596232666252363,
                                   0,
                                   0,
                                   0,
                                   -0.02232735933812266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14732559865615324,
                                   0,
                                   0,
                                   0.38387154698615261,
                                   0,
                                   0.27876608908672029,
                                   0.15813594620839891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80162470113725004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14014526232734709,
                                   0,
                                   0,
                                   0,
                                   0.13426208757163685,
                                   0,
                                   0,
                                   0,
                                   -0.18881970573559639,
                                   0,
                                   -0.95570296914236574,
                                   0,
                                   0,
                                   0,
                                   -0.63405537631915632,
                                   0.24701378581989092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05769942799864855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2231857377496328,
                                   0,
                                   0,
                                   0,
                                   -0.20184271273577986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20564658293919505,
                                   0,
                                   0,
                                   0.50170743817943453,
                                   0,
                                   -0.48472681701013015,
                                   0.48905977373827836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5250917870852605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3762766693508191,
                                   0,
                                   0,
                                   0,
                                   0.43888825867513498,
                                   0,
                                   0,
                                   0,
                                   0.61674741551615875,
                                   0,
                                   0.72269541462335751,
                                   0,
                                   0,
                                   0,
                                   -0.055807854141653394,
                                   -0.050295194228302406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053421179780683892,
                                   0,
                                   0,
                                   0,
                                   -0.33157910144826203,
                                   0,
                                   0,
                                   0.35121466103465993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49220578853101771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70757705637397061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66558325398958984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056884403778588152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41396752095485478,
                                   0,
                                   0,
                                   -0.48435613335466599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52368320811959079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19834392377400506,
                                   0,
                                   0,
                                   0,
                                   -0.23866474376709135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58820787916586859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20580193419301429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051724771910655443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40241826424140092,
                                   0,
                                   0.35468572166613999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12414984803684333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44344199514884852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11350780742688757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0093717525386604536,
                                   0,
                                   -0.075693580955174811,
                                   0,
                                   -0.42115695407355008,
                                   0,
                                   0.1053478179339951,
                                   0,
                                   0,
                                   -0.12176736775198449,
                                   0,
                                   0,
                                   0,
                                   0.13221433085896561,
                                   0,
                                   0.30691021831400878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27032048664229014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67120271421866096,
                                   0,
                                   -0.031738988492614598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16966817478410651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33475724443973126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013783346126982947,
                                   0,
                                   0.11651699779784419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2079470463857413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11845869361602991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41227780005649062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13511477899212745,
                                   0,
                                   0,
                                   -0.18396330637146621,
                                   0,
                                   -0.22832291801857446,
                                   0,
                                   -0.30973963593166864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75669285766022498,
                                   0,
                                   0,
                                   -0.036824565474297993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21090236593125036,
                                   0.071038265217298058,
                                   0,
                                   0.43026495648068736,
                                   0,
                                   -0.19447235642171962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26230815789979628,
                                   0,
                                   0,
                                   -0.36588824029563644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32681673362347574,
                                   0,
                                   -0.39875889379527502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40060728352793218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061315006810607579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30565821695027051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050995089508102269,
                                   0,
                                   0,
                                   0,
                                   -0.22196333109670655,
                                   0,
                                   0,
                                   0.48715215956195246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071109825863004864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40735458874748998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0143404724296414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23513372014946377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5339446314427384,
                                   0,
                                   0,
                                   0.49171273192037296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30039144902114046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60782241152360239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16916722163170136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036768104709511806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20545132579368736,
                                   0,
                                   0,
                                   0.50076799756715396,
                                   0,
                                   -0.016307542992761895,
                                   0,
                                   -0.55420696524984547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013868767191350655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066304895104825359,
                                   0,
                                   0,
                                   0,
                                   0.42012821398756783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060023621599421151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24954646551787332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064355634571954562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21590286463950198,
                                   0,
                                   0.40921784161678049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16290212663333853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16414077197848087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69392034027604843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15455245441592502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81696686212122849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29520518958456871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050657231757247047,
                                   0,
                                   0,
                                   0.023160029377147617,
                                   0,
                                   -0.11791806884877695,
                                   0,
                                   0.43983465698787316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10521807132532941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25170069236959391,
                                   0,
                                   0,
                                   0,
                                   -0.26324195140443701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.002646301759425429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55483959413632444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30983733510128919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4166058531922851,
                                   0,
                                   -0.21628581100990563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46361162203250839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094617635287652727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1388130475679332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13653701419393866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21914008408109967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10123526637719185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7082429578236823,
                                   0,
                                   0,
                                   -0.059717501542159851,
                                   0,
                                   -0.47773487743008475,
                                   0,
                                   -0.3837491794366325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20595721647169637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022278715691252393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15973239005354972,
                                   0,
                                   0,
                                   0,
                                   -0.55960099174392464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67306431626772034,
                                   0,
                                   0,
                                   -0.037132792451085139,
                                   0,
                                   -0.53486070862201052,
                                   -0.022002647052407689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14067482087353561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53023098085939391,
                                   0,
                                   0,
                                   0,
                                   0.10346520524834563,
                                   0,
                                   0,
                                   0,
                                   -0.15588066482667184,
                                   0,
                                   0.057454155824758379,
                                   0,
                                   0,
                                   0,
                                   0.42751125216674901,
                                   0.6544165058993332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27792097335559007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60196140305381196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30263539818635821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59149286813850965,
                                   0,
                                   0,
                                   0,
                                   0.002108166940283554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34488543045565478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73780283730949092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27442423603010291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97798612325029155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20270898175923774,
                                   0,
                                   0,
                                   0,
                                   -0.4269543160572673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5502064811418037,
                                   -0.88498843235272873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45942765369459759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38466725588768641,
                                   0,
                                   0,
                                   0,
                                   0.36465233442094824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074758807782503961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45761576820199568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24483415675886119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29561488803981822,
                                   0,
                                   -0.30774712196830933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29309832295079508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073734175841719762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41312847102445571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49439034090205181,
                                   0,
                                   0,
                                   0,
                                   -0.65564800184904692,
                                   0,
                                   0,
                                   0.31041003973848136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53588081144966415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12243414259225283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43198377091251017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16416883788979877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066768393054049788,
                                   0,
                                   0,
                                   0.51656959316644657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13336154147634441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1723889887397079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024636874526704045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39957005983207855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55125281181687991,
                                   0,
                                   0,
                                   0,
                                   -0.16626654315436232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6917330426921412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42601363385615443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26119672194226567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80036962900431519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088675753613197641,
                                   0,
                                   0,
                                   0,
                                   -0.051128765589647067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017299852259406417,
                                   0.48513759410531526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33603428263663293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14689924974158119,
                                   0,
                                   0,
                                   0,
                                   -0.79812271104634358,
                                   0,
                                   0,
                                   0.11095994323097971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35758741428999702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50442291764689373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10352965595370228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65235449818958047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28858127393999827,
                                   0,
                                   0,
                                   -0.12819935866508647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.83238196387262908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039685236716215197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39417960741132807,
                                   -0.23722481173045595,
                                   0,
                                   0.096178530544714647,
                                   0,
                                   -0.020352316139891639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13381730177867049,
                                   0,
                                   0,
                                   -0.53565738510830319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3376458162973367,
                                   0,
                                   -0.014794100697844925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0065746528533745137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33442743545348697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49614814166557003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090322761711791225,
                                   0,
                                   0,
                                   0,
                                   -0.46406332164552483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60497186789588397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20394492156561317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07758289943096075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27582496299726855,
                                   0,
                                   0.22398146598832847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46754845914200283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13393304659636943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0098338203539014429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19776174721405826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46627077015476937,
                                   0,
                                   -0.50134439939618791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6825393997857101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25428229754295423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92822831286105978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58218394720442279,
                                   0,
                                   -0.18592793747814321,
                                   0,
                                   0.28034686123081803,
                                   0,
                                   -0.3495540815310062,
                                   0,
                                   0,
                                   -0.1505199655414165,
                                   0,
                                   0,
                                   0,
                                   -0.26949722531712822,
                                   0,
                                   -0.32354909185720943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095324573234185472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30406617384700257,
                                   0,
                                   0.10232067916924434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21329023496113758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23702714070125441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099032179251867358,
                                   0,
                                   -0.047399470796051897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1889564818022168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72257658893952115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57839567337251685,
                                   0,
                                   0,
                                   -0.078769022602135919,
                                   0,
                                   0,
                                   0,
                                   0.062900284283236754,
                                   0,
                                   -0.13105183996301864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034165468357699069,
                                   0.33439076051172267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37567456424328394,
                                   0.94423057048950454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085365155239215437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54609527028717764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22051547209342065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19125298877494226,
                                   0,
                                   0,
                                   0,
                                   0.51405870242785268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43387654782894985,
                                   0,
                                   0,
                                   -0.27243581890025892,
                                   0,
                                   -0.18857003324966257,
                                   -0.067137091774183921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73718967267789182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21113716450496545,
                                   0,
                                   0,
                                   0,
                                   -0.65107476251834218,
                                   0,
                                   0,
                                   0,
                                   -0.20482597637441341,
                                   0,
                                   0.42478944923812867,
                                   0,
                                   0,
                                   0,
                                   -0.95198595947485454,
                                   -0.14489463698822563,
                                   0,
                                   0,
                                   0,
                                   0.67725361582817434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35585797629589233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1294327297904545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28586962566698626,
                                   0,
                                   0,
                                   0,
                                   0.78952271436718868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1277156785901799,
                                   0.21633936462778064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62900797014334953,
                                   0,
                                   0,
                                   0.38500477374127107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2728304490216803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16606169838662121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44105096111736297,
                                   0,
                                   0,
                                   0,
                                   0.81284391326752026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52733901458298993,
                                   -0.015611035279924896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1275137810228901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76123842442580758,
                                   0,
                                   0,
                                   0,
                                   -0.19359826598444377,
                                   0,
                                   0,
                                   -0.26121140840910079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0413165280025556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46905215306138548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13697592210401996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24366444482765656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082180174328923716,
                                   0,
                                   0,
                                   0.39143063199426564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11979068463663173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24405306062316304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0736116721378,
                                   0,
                                   0,
                                   0,
                                   0.2542957425841807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099275787813713573,
                                   0,
                                   0,
                                   -0.097011033056045776,
                                   0,
                                   -0.28693135327773189,
                                   -0.057730063228321159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035310662784878523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39765319637429591,
                                   0,
                                   0,
                                   0,
                                   -0.07749670487513137,
                                   0,
                                   0,
                                   0,
                                   -0.21983651448699401,
                                   0,
                                   -0.16436948525565001,
                                   0,
                                   0,
                                   0,
                                   0.78185544931606377,
                                   -0.38777216300315154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83671569443081795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36588793190485891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054467207062758011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12623851868063762,
                                   0,
                                   0,
                                   0,
                                   0.3093615972290053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22677175727051718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30561597078282238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3546176186165713,
                                   0,
                                   0.77893071884938503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15334817258785044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69166339864617932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57340577074663179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26970773084868421,
                                   0,
                                   -0.18952504749146495,
                                   0,
                                   -0.18790362625636636,
                                   0,
                                   0.13621700335048112,
                                   0,
                                   0,
                                   -0.10557432364169009,
                                   0,
                                   0,
                                   0,
                                   -0.21637972006137665,
                                   0,
                                   -0.044161981911367776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12529796842413582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13465693148816898,
                                   0,
                                   -0.38838073277597956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033735370935392979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68625345131477189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30865538715331731,
                                   0,
                                   0.15980320217747487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38751667129358319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057907019790470506,
                                   0,
                                   0,
                                   0,
                                   -0.20462861279039329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2676975777554354,
                                   0,
                                   0,
                                   -0.053730389516637896,
                                   0,
                                   0.76106893538687048,
                                   0.88907479161172864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035463356639060799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4292101627180957,
                                   0,
                                   0,
                                   0,
                                   -0.40250575126957217,
                                   0,
                                   0,
                                   0,
                                   -0.30213571956781193,
                                   0,
                                   0.41912846667209169,
                                   0,
                                   0,
                                   0,
                                   0.27814007212065645,
                                   0.45117495409237862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30875136952560978,
                                   0,
                                   0.020255652720093276,
                                   0,
                                   -0.26642170718655744,
                                   0,
                                   -0.14201430537357029,
                                   0,
                                   0,
                                   -0.078462367540334074,
                                   0,
                                   0,
                                   0,
                                   0.23417207275346003,
                                   0,
                                   0.034419434201297047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69061194842202345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13935571888257486,
                                   0,
                                   0.013966362020176926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26772519447047177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21141518133062412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3274548746012873,
                                   0,
                                   -0.17543180618548179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34064855209062594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34881581799044259,
                                   0,
                                   0,
                                   0,
                                   0.082577173052395009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37145567690376891,
                                   0,
                                   0,
                                   -0.18689338783246751,
                                   0,
                                   -0.0077036817382993561,
                                   -0.0043064014320807337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25833260254453605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39178285665553231,
                                   0,
                                   0,
                                   0,
                                   0.9700708799781258,
                                   0,
                                   0,
                                   0,
                                   -0.49828295977833675,
                                   0,
                                   0.50727655205496247,
                                   0,
                                   0,
                                   0,
                                   -0.39233217055919201,
                                   0.39270006574039462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012205348400009492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37060972989136531,
                                   0,
                                   0.74772709606553589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71313829882790558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46168610668968929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69306733081250282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23020814136175213,
                                   0,
                                   0,
                                   0,
                                   0.34331004323528053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20236768007452532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53394826239039284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12271957192825642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10150913459652149,
                                   0,
                                   -0.39551805783911731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52014302918434818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16478721713696839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15357952812031525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29060123157336742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17586086068461632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68593022719196561,
                                   0,
                                   0,
                                   -0.43786099257296479,
                                   0,
                                   0,
                                   0,
                                   -0.45691135602230504,
                                   0,
                                   -0.24537295787929983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17633822285440912,
                                   -0.35799972794251378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40124370458014919,
                                   -0.57344862541038122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39121312308196726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39004931415027089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67694483352174017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21660701696796913,
                                   0,
                                   0,
                                   0,
                                   0.073316534595379734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3018065884441305,
                                   0,
                                   0,
                                   0.22153409350121195,
                                   0,
                                   -0.37157032220365671,
                                   0.69633112411582632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42607577594116508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4366873026997638,
                                   0,
                                   0,
                                   0,
                                   -0.44698017161764875,
                                   0,
                                   0,
                                   0,
                                   0.2243823818578165,
                                   0,
                                   -0.25762957416782162,
                                   0,
                                   0,
                                   0,
                                   -0.2092301540041776,
                                   0.20077630017860726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.590876219407384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084146831970308103,
                                   0,
                                   0,
                                   0,
                                   -0.66341844854632359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21734072955754313,
                                   0,
                                   0,
                                   -0.7038448244057276,
                                   0,
                                   0.49402666724050998,
                                   -0.39993794148629702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26909007671290197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22155256529070294,
                                   0,
                                   0,
                                   0,
                                   -0.19780918834225469,
                                   0,
                                   0,
                                   0,
                                   0.6906710455513192,
                                   0,
                                   0.0094889358693205448,
                                   0,
                                   0,
                                   0,
                                   -0.25964725704022118,
                                   0.14027857851062253,
                                   0,
                                   0,
                                   0,
                                   1.0308948944485021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069759666822420435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18973847225191209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79976426577117954,
                                   0,
                                   0,
                                   0,
                                   -0.73783067711852979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53542207393695873,
                                   0.1189755893189884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096044239352563204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075525072110468577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31104376118680849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8189141511020207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0010380049610087816,
                                   0,
                                   0,
                                   -0.18092108516682165,
                                   0,
                                   0.072648381930064343,
                                   0,
                                   0.076812107510467076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42780363657270859,
                                   0,
                                   0,
                                   -0.33366701208181793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11212991466353023,
                                   -0.28500514495438467,
                                   0,
                                   0.52401049467023286,
                                   0,
                                   0.36571005342497576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086740158007045404,
                                   0,
                                   0,
                                   -0.042308189591428985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098019306534706807,
                                   0,
                                   0.56381183241786126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076306298012446608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042092947390007185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20526704765491449,
                                   0.34811674470500464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22534881842786578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0016071866901652132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43067828794390617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079962811647212501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012246965928776358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85969180379754573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1560616214891053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36342224936064549,
                                   0,
                                   0.48606667357231192,
                                   0,
                                   0,
                                   0.051444464499557918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3061293367809903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11138972330960724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86345640454591943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19981845003294865,
                                   -0.3251864853441172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073290641364781695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70755893629756927,
                                   0,
                                   0,
                                   -0.49249662819371276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99636851140270233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65007368975291357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29590682588676176,
                                   0,
                                   0.57527461527303148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11433980539954512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10948633937586384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65082534029144523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.009297741578512847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44678822615753183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24781045982482711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65669663019683755,
                                   0,
                                   0,
                                   0.35475893161551164,
                                   0.13230855828094676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75349661618763153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27512247908418019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1518558996362086,
                                   0,
                                   0,
                                   0,
                                   0.28557898348758387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14121085768587582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13913606177598806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10774651685493151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4643264932445374,
                                   0,
                                   0.24394754931031531,
                                   0.47305326548498505,
                                   0,
                                   0,
                                   0,
                                   0.07217554064585735,
                                   0,
                                   0,
                                   0,
                                   0.34652156303993992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036063830529784985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17934919930556431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40165906560381742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64703825245568236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64658168339846234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36356092392801731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27792828663669689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.004303150006880252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088855279144236271,
                                   0,
                                   0.59312612315392343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039147790490804774,
                                   -0.0033237856580241587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11188024159842538,
                                   0,
                                   0.402704731818882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41299850138086414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25920053434883666,
                                   -0.34715105991245732,
                                   0,
                                   0,
                                   0,
                                   0.16895285643944538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012184573336140423,
                                   0.052992050541997293,
                                   0.30550451582635796,
                                   0.14885925158291335,
                                   -0.17300634039881338,
                                   0,
                                   0,
                                   -0.26536751573375966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45979532161761721,
                                   0,
                                   -0.24915774165656618,
                                   0,
                                   -0.43551175327269548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099420629134400862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026878795912328501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24234548255425434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3463973155881887,
                                   0,
                                   -0.35876038100536095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11432778062224649,
                                   0.10674527084181223,
                                   -0.4354327588341011,
                                   0.037980339927308732,
                                   0.068284150256054083,
                                   0,
                                   0,
                                   0.10287042321750312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2359284718552625,
                                   0,
                                   -0.34672254973728189,
                                   0,
                                   0.5119861320284862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4600227234591126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061852556556843678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30480749497445331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14428937874632877,
                                   0,
                                   -0.045421520385800704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21262580755766577,
                                   -0.2797261020009072,
                                   0.064995361916196273,
                                   0.40742106758899593,
                                   -0.29325046567979207,
                                   0,
                                   0,
                                   0.00042279800715447347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48558047808398397,
                                   0,
                                   -0.082995776156384551,
                                   0,
                                   0.2153159655813161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0050632735679796911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045772295130802623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063679509018641847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57017947866929852,
                                   0,
                                   -0.0036213200333894188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38357989996807806,
                                   -0.30279779363141462,
                                   -0.30264097663160849,
                                   0.22223944356086345,
                                   0.064535461189183102,
                                   0,
                                   0,
                                   -0.2788039250393396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28608390044140347,
                                   0,
                                   -0.071278614005548677,
                                   0,
                                   0.087933206919788648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45180807854837768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4602838413424466,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10434437160036733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059779277431689204,
                                   0,
                                   0.11485477356394534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051704758634543505,
                                   -0.030235136076749533,
                                   -0.20677886607850565,
                                   -0.53681750407127948,
                                   0.023625908229836411,
                                   0,
                                   0,
                                   0.20868778094909307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17654819434014468,
                                   0,
                                   0.15852444105426633,
                                   0,
                                   -0.043541467213856967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36618168480290053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099806093759324338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43386586874098187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35439614347826032,
                                   0,
                                   -0.3244865559296814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5337466897346953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24788454950861111,
                                   0,
                                   0,
                                   -0.27630562124739999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26254735145637914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0045500762004659218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55128384134287844,
                                   0,
                                   0,
                                   -0.43632905996813792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1186346818203895,
                                   0,
                                   0,
                                   -0.13318110661005361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6404930935273796,
                                   0,
                                   0,
                                   -0.8962040889627465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29266455829546484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029687191700980879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31741112882569694,
                                   0,
                                   -0.45231855165988699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12817377301301683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037864755950652008,
                                   -0.40060487146174517,
                                   -0.28132357957233523,
                                   -0.075780570546288922,
                                   -0.66252552579901458,
                                   0,
                                   0,
                                   -0.091758489623188513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16962018281616356,
                                   0,
                                   0.28442537380471589,
                                   0,
                                   -0.079667098923275392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084568020956502371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27257167982670849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20468298982404456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20418520580094518,
                                   0,
                                   0.1574395485012704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45363075905364891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0912216478748593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068932466569401607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64415382480084926,
                                   0,
                                   0.60643169726139223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29232737887146265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56044654844720654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35883137583918079,
                                   0,
                                   0,
                                   -0.66860601896672556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0135013104780788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048755117639469658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50068162497775681,
                                   0,
                                   0.10784389983896225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64379466804723895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21400205605481737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46672477038420823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062290183781106595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72208124994545919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012029705930137066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1975057659397868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13401628692581227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17793574111192897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38046601304489069,
                                   0,
                                   -0.63973755872744398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61060656951293912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22194942496811251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01666137820950235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09216923741925398,
                                   -0.20076730905879495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44337408311831494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23267014044433063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38216234182901615,
                                   0,
                                   0,
                                   0.31878075144117096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17444939939690693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29801797023733007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26379566239892621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037434040030480009,
                                   0,
                                   0.25610662427777781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35592371594601541,
                                   -0.22422102286694229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095836668689079182,
                                   0,
                                   -0.15767804714804551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17584885563176278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56631581232495698,
                                   0.35796215115568503,
                                   0,
                                   0,
                                   0,
                                   0.28953085207060264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42769769230305699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083305017375915863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74017973069431409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16389744405153425,
                                   0,
                                   0.35891674400310603,
                                   -0.26524894657272891,
                                   0,
                                   0,
                                   0,
                                   -0.34383162554116564,
                                   0,
                                   0,
                                   0,
                                   0.07409027093767559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38198028355166591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16980987497375902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010884053417790491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17633373657815921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19033695245622523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7445220774488357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48516054052333596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16345729715699814,
                                   0,
                                   0,
                                   0.35685792290856377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70053363366491417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21228263814306397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16356129508290129,
                                   0,
                                   0,
                                   -0.19640836534725611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097023456969409588,
                                   0,
                                   0,
                                   0.2209568990460398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073180328166240885,
                                   0,
                                   0,
                                   0.45669711377100169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8104761406307861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53369710047530028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13345889031929895,
                                   0,
                                   0.2183567900699977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3142970897258954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32015795917851125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31217657883216898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55132458820214947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20955233332217765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37214275878160979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050435904393827252,
                                   0,
                                   0,
                                   -0.025819900913681096,
                                   0.098831729017327841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014730185220120567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6118918471382695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84706975906251136,
                                   0,
                                   0,
                                   0,
                                   -0.83469376095941672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53342508099283725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64311811478949832,
                                   0,
                                   0,
                                   -0.26990609375852542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016286828552407508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37306857946074073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1841203594509512,
                                   0,
                                   0,
                                   0.17717983495542564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15578526087236508,
                                   0,
                                   0.71578804954364539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1990396739301053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53119438785726869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19569839332112873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12680350384418687,
                                   -0.33389550596796935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015114832383869195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2124682380619084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71211592684085978,
                                   0,
                                   -0.09226105641690116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1382482423057087,
                                   -0.21900059407973305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058272505287604123,
                                   0,
                                   0.229058122740363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25162347923431133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16483772520580239,
                                   -0.45772811473933206,
                                   0,
                                   0,
                                   0,
                                   0.12676581051585786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21446567077029222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07421049003675606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38545334407951415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63937124072531948,
                                   0,
                                   -0.17410633018138758,
                                   0.22383756276204392,
                                   0,
                                   0,
                                   0,
                                   -0.76768547904492268,
                                   0,
                                   0,
                                   0,
                                   -0.039732181247967263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012819413330377496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21732820488095647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32913672925943555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53631137291121067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.005834694374904012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34030926090909908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15174776785750868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52033979124480079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0033776896596436901,
                                   0,
                                   -0.24047811075974751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20848722691441751,
                                   -0.46308591161810297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11448341142594828,
                                   0,
                                   -0.27376039641609962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4107764457198767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029801983400729086,
                                   -0.29500454325672965,
                                   0,
                                   0,
                                   0,
                                   -0.21391158799216486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013773496789632661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17431235593391858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35434416917528266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65932117494654496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5174758813107766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45724940547926096,
                                   0,
                                   0,
                                   -0.35549175608827177,
                                   -0.21304999395819141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19921559625725566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41242692978578066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55641137307418054,
                                   0,
                                   0,
                                   0,
                                   0.27292387485472691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17921157734323565,
                                   0.048228002850438018,
                                   -0.31925012794437441,
                                   0.55654013515191603,
                                   0.18540697131773673,
                                   0,
                                   0,
                                   0.47622819641696695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026414710211774224,
                                   0,
                                   0.21776867980161868,
                                   0,
                                   -0.32598332261864005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10684427374060024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31967597925712621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022612247944223972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029671811645809017,
                                   0,
                                   -0.15278887993511595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099725124778217558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45876433966321944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38280164701715846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4618841811828106,
                                   0.25138019191563599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.269929414032958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3144545509546598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22512911691932969,
                                   0,
                                   0,
                                   -0.032738010237328877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36472679047799961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30519305122541207,
                                   -0.14395416598857255,
                                   -0.26603693087775965,
                                   0.0070712021711280427,
                                   -0.16018258373625308,
                                   0,
                                   0,
                                   0.11834266389399602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13194466284467074,
                                   0,
                                   -0.46544757582336904,
                                   0,
                                   -0.11943405359224375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066773325725844393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18536153355393414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1904837747304384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41556711624186132,
                                   0,
                                   -0.52870814077305206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02219998199224002,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41848506874964703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02097481278104291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1614214659797405,
                                   0,
                                   0.48319578769911981,
                                   -0.19581536568312541,
                                   0,
                                   0,
                                   0,
                                   -1.0124655322150669,
                                   0,
                                   0,
                                   0,
                                   -0.32342673986071624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41666515868981913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16748148696815746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27085733323951083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18758945637326468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068969968614991634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29148744596842135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36572635439481055,
                                   0.081486199556294645,
                                   -0.50302038620581302,
                                   -0.073404689062166517,
                                   0.26574359822523053,
                                   0,
                                   0,
                                   -0.45859316224693658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030966406945037116,
                                   0,
                                   0.28399415711326093,
                                   0,
                                   -0.25275554000640355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25725895797399667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041168402044293777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22891980033538237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22938398269916019,
                                   0,
                                   -0.043172552436750236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78842162807476546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037523231292260512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33531843510522968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28469331638444201,
                                   0,
                                   0.50583178342779977,
                                   0.13010439289462405,
                                   0,
                                   0,
                                   0,
                                   -0.014514200354486763,
                                   0,
                                   0,
                                   0,
                                   0.22422398723683687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61571455406537923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.532833363402478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057713041838943505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40873825005452608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12556196258742425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11316769952158028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14751601671409076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092535401517080229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041808964198488757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2047916028630523,
                                   0,
                                   0.020549105614309601,
                                   0.48024670620903132,
                                   0,
                                   0,
                                   0,
                                   0.0085489656876530651,
                                   0,
                                   0,
                                   0,
                                   0.3201804539496681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13489787164952433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1456505926745672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058993772875334326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17014271012985488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036613100106887231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19722592780149439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14043661720284523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061378740657040978,
                                   0,
                                   0,
                                   0.44222257417469335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16602930301630675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40759186780152279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11620288689084363,
                                   0,
                                   0,
                                   -0.40906227423445096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63750881276468885,
                                   0.41325087255096093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26003613405862597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.434836657957544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28258817163456984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6184156928245963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56162806650435371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17599738195630971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23815160922059816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74525994117827199,
                                   0,
                                   -0.30888434278120225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0088380895661648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22072936912906788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42414637290532203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68500174091295485,
                                   0,
                                   0.2242349957477742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69937296281677108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36988361381143603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0060878008118159417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79283357523339826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13431980760188525,
                                   0,
                                   0.011233004050376732,
                                   0.78878629764865327,
                                   0,
                                   0,
                                   0,
                                   0.08411004148599785,
                                   0,
                                   0,
                                   0,
                                   -0.25699455490560075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14924398154158963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13696231786194327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67658431531813767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21816515265880779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040810879402750203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015045410364328434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069205791023288013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37978286297530978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32287401523345555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33292171427772527,
                                   -0.54543459251620119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30269149917613886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19178522594750799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21306155897705553,
                                   0,
                                   0,
                                   0.13620503586186991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38215361694233541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28839594836972832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41426935395938752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0713793710889771,
                                   0,
                                   -0.19048624773877829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15056132888452961,
                                   0.082988142611376658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40215132608257409,
                                   0,
                                   0.49148740528533769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063221216080374024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066766534705662225,
                                   0.153148768318215,
                                   0,
                                   0,
                                   0,
                                   0.48895614567056878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041404393731841377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40868616910250133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058837197000125144,
                                   0,
                                   -0.44809600651604892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46677130740688466,
                                   0.043781849548573969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042463002269443322,
                                   0,
                                   0.015070532262350474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60740769526414773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095969773287173557,
                                   -0.03355561026494628,
                                   0,
                                   0,
                                   0,
                                   0.1609553623020317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56365785839588078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0063950537682062603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073352227644018969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31396926583696688,
                                   0,
                                   0.24952624879330365,
                                   0.14890138110465526,
                                   0,
                                   0,
                                   0,
                                   0.035587407823967972,
                                   0,
                                   0,
                                   0,
                                   -0.40508410899383018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86837678192747447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10134202202363524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29118419166762066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10767874384094429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68765498790086799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13521310186637769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25831790642988089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57532169231999097,
                                   0,
                                   0,
                                   -0.12037245374149226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36534794395932557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11287827567015157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62562573085066164,
                                   0,
                                   0,
                                   0.094407958906950057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20309170062566395,
                                   0,
                                   0,
                                   -0.55491666855517108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078240567830464444,
                                   0,
                                   0,
                                   -0.095194039322231139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38035342220587109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4059242536573085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21646479910830954,
                                   0,
                                   1.2934924542509689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4449775515317429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16293365155852202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64738448156766271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17114673139210165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40268840435339426,
                                   -0.39634543542724193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30577269612462471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0013185575341935901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014726667388604869,
                                   0,
                                   0,
                                   0.073674839699213512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32659387982310478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14935986543166169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10005938424292789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47947617610902921,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47902133383678536,
                                   -0.082547437288099601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074146583187559609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30733636781838858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33038525169928584,
                                   0,
                                   0,
                                   -0.52385393892731513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13407500304369249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52560070002660775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43840445116139592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3814901816125873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037375275810907195,
                                   0,
                                   0.67159682835020817,
                                   -0.20070057449212769,
                                   0,
                                   0,
                                   0,
                                   0.33965877542769157,
                                   0,
                                   0,
                                   0,
                                   0.34598509506974318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42952647035955582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27169523311610738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18026542156041145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54204437471038547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15278844027095301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13212389012724995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019568543219153665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36058245750123902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063971822561804795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97454676492347503,
                                   0,
                                   -0.67981339346369751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21522627474240641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0093665593243621829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028387684656605634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019372015746371804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15071626897788143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53790122525428297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60328640897315744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047329554025729775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27104727675062928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42769518753006913,
                                   0,
                                   -0.55117313206740948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1569010203695864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77097104508244219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.025881673030551972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80598318596564089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1875768463761058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090522467599814457,
                                   0,
                                   0,
                                   -0.43234721181894986,
                                   0.022230842321908764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12265787685975005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10989808592719533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090943633292269233,
                                   0,
                                   0,
                                   0,
                                   -0.32136541481131353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15629230181795106,
                                   0.68463951792235389,
                                   -0.20840722885603247,
                                   0.089893043255705463,
                                   -0.41653988898739264,
                                   0,
                                   0,
                                   0.099131002488901582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0081980930201094766,
                                   0,
                                   -0.11209995242203936,
                                   0,
                                   -0.14659484363274566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19482994066469078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26701300817168039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073381186407085935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045575323614080281,
                                   0,
                                   0.34807249626902581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3105555680606833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2202707699839935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.416585746584894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13382464853555226,
                                   0,
                                   0.46869884581727367,
                                   0.32549266063387033,
                                   0,
                                   0,
                                   0,
                                   -0.34481667842841635,
                                   0,
                                   0,
                                   0,
                                   0.87278681199485819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14744594719957368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14144217499241507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6694749717760754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096221561994991114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50769472924834358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17308936103655392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45143036793201241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61135014788310271,
                                   0,
                                   0,
                                   0.30100807610826602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15295468230781742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72979134422049308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18309060853298939,
                                   0,
                                   -0.41642368423663606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52311786368077684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4286386679916479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12125909166261162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76439846270576839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27145459749217093,
                                   0,
                                   0.2689326144420166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78713527476534884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8860838948335652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032579695460062438,
                                   0,
                                   0,
                                   -0.80847430847034585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31736781507142114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41117452323856657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10402545599344984,
                                   0,
                                   0.44842832464879845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22533830363256083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059399570337227398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1442446637464463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52384632511522722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088786098599664465,
                                   0,
                                   0.83939240694444761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39901874792457903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11898509746892064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078065351221991527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0091740176563085973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18385821506094785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3164388225972033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6271066121073382,
                                   0,
                                   0,
                                   -0.22018992656608294,
                                   -0.65619969443332204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41102680061124175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79128008140029793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2474274220447199,
                                   0,
                                   0,
                                   0,
                                   0.4427284277405229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16274514767789997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73604645039350813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27287380499406655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34909630721247875,
                                   0,
                                   -0.46392950184271053,
                                   -0.1062857395124813,
                                   0,
                                   0,
                                   0,
                                   0.035068368016227591,
                                   0,
                                   0,
                                   0,
                                   0.51243625887079647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13994471130982852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22613518457325099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13359430009630541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0048132581860266949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19008436047358496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13466741656552755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37922880056923575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10110101723815491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55737358286224792,
                                   0,
                                   -0.30304039120959403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010015934910934415,
                                   0.058221187531970114,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028229198501896091,
                                   0,
                                   0.29628244854791885,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27898233701622105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34310106577490412,
                                   -0.37915468401655561,
                                   0,
                                   0,
                                   0,
                                   -0.10994247971133703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36944167007848183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29187497418376385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0065627487859212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048456556752502357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07770399047114912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03195122300335488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.122383435078709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92798356677746663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074638745822437402,
                                   0,
                                   0.11599877559223773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13218461688884353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20034136689122398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033694399447167976,
                                   0,
                                   -0.37725644420480298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65898695369018934,
                                   0.18588324322359168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34628399648302188,
                                   0,
                                   0.19086197813376224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18267304174283228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33886947002919998,
                                   0.14836652232055725,
                                   0,
                                   0,
                                   0,
                                   -0.059673759027066925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64777734764046335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30960963502900085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40714890302065448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66693189163112809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065400585331467587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17082978670161711,
                                   0,
                                   0,
                                   -0.13190777427931638,
                                   0.63385372822535702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094493265191865003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37757900578022818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16194828230679864,
                                   0,
                                   0,
                                   0,
                                   0.30188392475750642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39640530579184846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47181714084602783,
                                   0,
                                   0,
                                   0.1590230582364375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12580102055924292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59973095389756026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2415920738317494,
                                   0,
                                   0.002824736843084194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24205434352032837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15685619617358196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7743746163212315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27459792899608571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12019767303604087,
                                   0,
                                   -0.17990005637498924,
                                   -0.17837865857278279,
                                   0,
                                   0,
                                   0,
                                   -0.10209587889553802,
                                   0,
                                   0,
                                   0,
                                   0.43027343621720732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71491537551075657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19641989268816085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14417381265369411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36108387548853815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58718059678029766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.308777256666591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22197789767515028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018061697361792497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24771389329258936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095027311795436872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4385725986904162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3265526275583042,
                                   0,
                                   0,
                                   0.90007557557631346,
                                   0.20232010083990096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075690288617517809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28489429757904028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34956847168954502,
                                   0,
                                   0,
                                   0,
                                   -0.49297577203549925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47885682217488668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14849595826523609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078745966435406087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25371842913294734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19501308061923714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22222653579871671,
                                   0,
                                   0,
                                   0.37300984885569077,
                                   -0.12985461372346968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75586872342706457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44027590939683309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20544860771374923,
                                   0,
                                   0,
                                   0,
                                   0.64805528446246963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57666827630234463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0092170231248986899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15462431128748005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03176449906329544,
                                   -0.46097753345461068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32572906543520336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21917389196444034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037644979469845657,
                                   0,
                                   0,
                                   0.24692415534290094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46197997385190709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14189942565864225,
                                   0.22846778518639899,
                                   -0.047691661753271941,
                                   -0.18658901918367657,
                                   -0.25454561717725499,
                                   0,
                                   0,
                                   -0.0068450187022883486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22345559374565327,
                                   0,
                                   0.034627139658945379,
                                   0,
                                   0.28272617142387008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22568322469306712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38916368237657012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61100045647485857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22477361586412684,
                                   0,
                                   -0.26162031069627267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38770795608145692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55544384944688574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58701397670215283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25268305658332468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30664021672059849,
                                   -0.19672903309969658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0061476031710959167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2000741822848604,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071987680566309858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21497340132501819,
                                   0,
                                   -0.1404222221821857,
                                   -0.063999035909741708,
                                   0,
                                   0,
                                   0,
                                   0.34822668558639169,
                                   0,
                                   0,
                                   0,
                                   -0.14360567414004308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020301270107089067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92339566873681866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37549608400519796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20636950117505962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26956757005353865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43874982016606751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33168099727657169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24879674247126632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32884792955274544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6648495598034333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45328110956046852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3144406385799236,
                                   0,
                                   0,
                                   0.12993074886224057,
                                   -0.75337149411552129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23559508870367021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43884893398594926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12929395468319652,
                                   0,
                                   0,
                                   0,
                                   0.20607561217491119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27476209431922377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45397098907482508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4489989803908076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58931226478649235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21684238028222647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27177014141935274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27676176726087465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3159581771094413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54994584536834679,
                                   0,
                                   0.11907411867599223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24631955667387356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30768557084251102,
                                   0,
                                   0,
                                   -0.57457842220314992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51997736261319272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38549205756171384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15099873392306246,
                                   0,
                                   0,
                                   0.047055636239770576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26555690089359379,
                                   0,
                                   -0.15890774135094832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24757653011344022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063486555278289752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.256362302671783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91199862932942888,
                                   0.1093641561238992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85456135727858917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46334938447756513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73313629773642242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31540709321500787,
                                   0,
                                   0.44720211348923244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1773984385782303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17771466069771241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26074677836721466,
                                   0,
                                   0,
                                   -0.42580243060584128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014108211858643777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49483187353352287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31823406862862308,
                                   0,
                                   0,
                                   -0.56048059969659314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24218145522654969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13018878886680266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2810030667097525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22992506031736534,
                                   0,
                                   -0.10059164559511795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014753642709002028,
                                   -0.39182226464899933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31691015871970796,
                                   0,
                                   -0.23859105145719595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23101208853779104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5566750679596093,
                                   -0.051101797633616677,
                                   0,
                                   0,
                                   0,
                                   0.40514039243793398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16323684357459567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27175647462332597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60285302903775251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016574889340277316,
                                   -0.03176213695588051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083069852345416015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3099236682877875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62034305323486971,
                                   0,
                                   0,
                                   0.029917832060918054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21473927347793081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45194945443644852,
                                   -0.082482538226325133,
                                   -0.15896756106507387,
                                   -0.24355594279944059,
                                   -0.0076326177178601337,
                                   0,
                                   0,
                                   -0.075426562405454561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34348988727090379,
                                   0,
                                   -0.47842331781551944,
                                   0,
                                   -0.40752600513331727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1123889348061817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25056770471410605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13654372691689554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11373179145000739,
                                   0,
                                   0.28045416738328216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55782416237379406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086943260865320143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035295775395904741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19549658261783281,
                                   0,
                                   -0.18994882976877842,
                                   -0.065156476024784776,
                                   0,
                                   0,
                                   0,
                                   0.30448581831588706,
                                   0,
                                   0,
                                   0,
                                   -0.52742636919414143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41185715151912045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50201087704587144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64759312326949825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41077392275675662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60728036484539172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47001416876561047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083602753203794247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058543947901010307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48843078359748304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26902256601683172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026654932756367482,
                                   0.82336803981496065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54994762058716029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70244475610300217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34386664557575242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11917079322725471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13233763859842745,
                                   -0.23274402408262135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94920622967303847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048783892794227846,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018007095283163438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21780245876379123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10847397490586286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084168596739016666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21007285292900849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43961189832093739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28126597677194881,
                                   0,
                                   -0.16649173089008468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58386793168568163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75223593954471624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24744415498136552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46747542579442802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68643403142108805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077069507325433412,
                                   0,
                                   0,
                                   0.36865304328264181,
                                   -0.013100629768166644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36460273772851043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5179902625574635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60169707136221018,
                                   0,
                                   0,
                                   0,
                                   -0.17087233250515754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25186946102232316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16068560520184683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13668057368202613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060528671737474948,
                                   0.34762516676792848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45537943916983559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3838848250140845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50618786961415341,
                                   0,
                                   0,
                                   0.16321344031996579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36048658234411185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56316873352787233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10584693886559682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26062545916428892,
                                   0,
                                   0.08309543912439922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26527153277382082,
                                   0.13919142385784825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24317582608310551,
                                   0,
                                   -0.32935693061330573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066757562914577032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15684232114669788,
                                   -0.47231969735522544,
                                   0,
                                   0,
                                   0,
                                   0.29548473736023184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33287851489846199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061932281022126293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1717686313039124,
                                   0,
                                   -0.016546379852855841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11256020280532469,
                                   -0.68053207629897461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45543187580543204,
                                   0,
                                   0.35418456309248364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053579060233597112,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048199990922104585,
                                   0.19304322625979883,
                                   0,
                                   0,
                                   0,
                                   -0.066781697454489017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067073099216968357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24491099152443996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27798691479182552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4670093278266495,
                                   -0.31324277633076925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03391655659424607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16732602673550212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0392484875732209,
                                   0,
                                   0,
                                   -0.6549036810025588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28711796250700805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0019449830619695969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84384576482531726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23132108843078142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58978151637712073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0389194986095558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13444877809955999,
                                   0,
                                   0,
                                   0.024774689591011534,
                                   -0.036225938404054386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37239702352062443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051979940581781015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19368561875341506,
                                   0,
                                   0,
                                   0,
                                   -0.37297731507614429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2073971798598914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0091372661884153716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72720684867902552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67782960374935231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13244193576883673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45936739001785643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3778778850543521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54722893408582296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12183256093077639,
                                   0,
                                   -0.56788214492536659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34582547891165732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36262048210431874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1137094989263758,
                                   0,
                                   -0.16655544381048545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22592368634348625,
                                   0.067342766738419629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55729076254646104,
                                   0,
                                   -0.16943198445414809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14704511634912995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031829846493652697,
                                   0.038628116262324957,
                                   0,
                                   0,
                                   0,
                                   0.53782550115287842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11368192964336726,
                                   -0.16300343592417882,
                                   0.048707525727704676,
                                   -0.18186747363635017,
                                   -0.13564110276922772,
                                   0,
                                   0,
                                   0.50085850430049939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19789200659135586,
                                   0,
                                   0.15746334880237403,
                                   0,
                                   -0.17574827877662436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42255765987899929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47823163528607499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33786308161964618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19488496280305223,
                                   0,
                                   0.039558236672888755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13959944503867863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22254940032336662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1631903300623978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46760341419706375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16418548857794105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31597184936482203,
                                   0,
                                   0,
                                   0.048097920037997691,
                                   0.44088150177321511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1692917617414296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22202681775808986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025689092181959108,
                                   0,
                                   0,
                                   0,
                                   0.32517614365250758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51920162159914562,
                                   -0.26547059495227349,
                                   -0.016489747142870537,
                                   -0.12897179537045608,
                                   0.21985809664319717,
                                   0,
                                   0,
                                   0.26789466718807214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35936212779288429,
                                   0,
                                   -0.29587298208841545,
                                   0,
                                   -0.055315206887305388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26638930116527509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21156190576263584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050811880172074587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18306893946549951,
                                   0,
                                   0.38908193503633537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19269034225816628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68967965785328622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38096878326647476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22676840438163334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77870110800976455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79996132438834144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24345536977022381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19386874164917067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15185144864451233,
                                   0,
                                   0.0097653174766308415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36937749932086339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084748867524677071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08031378712994397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22949168830434002,
                                   0.051228851615580134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46735419311672211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62951453793937862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067030267186009657,
                                   0,
                                   0,
                                   -0.28548246602723526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30648811947307131,
                                   0,
                                   0,
                                   0.48742421052081442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68522733801098679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64537841934481077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0087871556271877857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28452691126990415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8926254101690243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29698370660440732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090041287469711878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068917302677737241,
                                   0,
                                   -0.27771217546635513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12839390648910501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028501932539704601,
                                   0,
                                   0,
                                   -0.044270997004198787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0918471919863076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4933557216093426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32626571403414562,
                                   0,
                                   0,
                                   0.49704171765465194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61270479309246617,
                                   1.0416266376595602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31681059203937323,
                                   0,
                                   0,
                                   0,
                                   0.59102282607737788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57871239845370781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43292603236817828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45212283870773412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32019275781023582,
                                   -0.12400888956509053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40558579827403413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41753235783776432,
                                   0,
                                   -0.158710232694424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22134535506749045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14460644260006694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21213748125006729,
                                   0,
                                   0,
                                   -0.11465821716618654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53349832231088146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045927369726760259,
                                   0,
                                   -0.30997365501911034,
                                   0.18425041957924457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30193157858876757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12695687619565443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17403083645162323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43005924588693301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24600201128080784,
                                   0.067862265882192602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028570068888259997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2745264145527565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28521907390697149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5813246300255932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17632163235219325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013169265656741279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13911448350769998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30036907951417813,
                                   -0.25925965774022852,
                                   0,
                                   0,
                                   0,
                                   0.30244119252596169,
                                   0,
                                   0,
                                   -0.80916977919931199,
                                   -0.78625170133006972,
                                   0,
                                   0,
                                   -0.53122874375482176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18093056948425612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03417577641323067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72366619137171917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11012690760193949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28341853661930527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69265346516674153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27680369416987599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40288997292546036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24004066305293714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29178891000169654,
                                   0,
                                   0,
                                   0,
                                   0.43525933637919023,
                                   0,
                                   0,
                                   0.12210720168388089,
                                   0,
                                   0.25797568532685949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67759617198883937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34343625209666234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096137233706883096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57451686873676511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52363465367540929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87539173599912312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47902224994788456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17197843436863902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3634737006969182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073679195079359994,
                                   0,
                                   0,
                                   -0.229485138389037,
                                   0.66359494230901417,
                                   0,
                                   0,
                                   0.16425534544621034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34826302808553089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0565100232923683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16307820785536351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041101744134236173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64325972870051884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40036127748150385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44258584693947151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083778193307391974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27823146368299556,
                                   0,
                                   0,
                                   0.53190445157502542,
                                   -0.63616446602202359,
                                   0,
                                   0,
                                   -0.31724277086724895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22517372184099269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26654880780313861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46883591062730834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08976304350910766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53399593923514965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049923397081938103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030791101018857084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014623968040687219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35956733164231169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26341576590279969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012791067453855484,
                                   0,
                                   0,
                                   0,
                                   0.51741178109723185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033439063754260326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21260023158350985,
                                   0.1470390404712498,
                                   0,
                                   0,
                                   0,
                                   -0.10804620767769973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7468304395286739,
                                   0,
                                   0.61672568424351015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3569342494516895,
                                   0,
                                   -0.12487368468575594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2037695831336149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22678010180426186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16934540843040052,
                                   0,
                                   0.46631563120539288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64303846601769288,
                                   0,
                                   0,
                                   0,
                                   -0.22677987288113474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22350222686580903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055175054664893336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49053472516737706,
                                   0,
                                   0,
                                   -0.032622626406930144,
                                   0.39406005975425523,
                                   0,
                                   0,
                                   -0.5764404194790228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76585723972946051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75748009559631557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32365213712632757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024968755642088853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30410350218468918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10123944581617858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35833463408595145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25530762225885317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47503394277830197,
                                   0,
                                   -0.55041033435801545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35126291862294351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22065693341225068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1231813055516694,
                                   0,
                                   0.34406050548739392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080548447808009349,
                                   0,
                                   0,
                                   0,
                                   0.11956602500399878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38001833428048654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023807774685538192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48080483585949801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77289758537210518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93661977798247664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39372620289920418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15607821269548033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046229595035519086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15596303533120681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50091883232804357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0012711824305052556,
                                   0,
                                   0,
                                   0,
                                   0.35460216585137083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73019641649145717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58482768880441327,
                                   -0.55931913956515811,
                                   0,
                                   0,
                                   0,
                                   -0.13167300812562852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11908553836439845,
                                   0,
                                   -1.1682680918661681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73223858747266479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060593032084497983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11341582687766461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20215878043268537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63592899732333419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044923530023895653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30291680524731984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43814339191431878,
                                   0,
                                   0.07133959786362129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40003901503397882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05808928663184007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037758400608752588,
                                   0,
                                   0,
                                   0.23564633134530152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20091129158963802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39851112663122729,
                                   0,
                                   0.33690190908603712,
                                   0.34344641100847606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24533073842452249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0046788766238216317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0093144082420981399,
                                   0,
                                   -0.10647034002242706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32472021880002377,
                                   -0.39705510701507113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78642338181932947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77889315133333104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30485339638057568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085389704046617457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26617418812196758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15757703160824907,
                                   0,
                                   0,
                                   0,
                                   -0.088115092973702375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33944024628275454,
                                   0,
                                   -0.34294213247137073,
                                   0,
                                   0,
                                   0,
                                   -0.38368857553513774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16032600120673351,
                                   0,
                                   -0.088038198529415218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0068527327042529826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068803168501140752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17613799689224635,
                                   0,
                                   0,
                                   0.29968096229149116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44729301799001148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31119291359203555,
                                   0,
                                   0.19681160803341155,
                                   -0.21507518902484576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5583991381501302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26023892080836464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56234699577792935,
                                   0,
                                   0,
                                   0,
                                   0.24572416292203625,
                                   0,
                                   0,
                                   -0.64095967773985718,
                                   0,
                                   -0.071477806577494307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27120407614439096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023027472779532061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.256204792013836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3044198331613488,
                                   0,
                                   0,
                                   -0.45101959354512233,
                                   -0.058620689609645532,
                                   0,
                                   0,
                                   -0.63438427456847912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17214100358583206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52701391185560764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062141131976252734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59016106682317393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45549712417846833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62555341518142127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073959325149733662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58840396754407021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21281082155436168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47211684884469202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19647214367726984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11458369863230139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34056560076587733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1351400137393746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64805324174762036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26246831213093402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079194124813583663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22877322171548142,
                                   0.064247698745222168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18744116312677744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1276803347961738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0041060136875974429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25004936369513892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1102924611608827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22156314920639913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10302782708366609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044996826477310944,
                                   0.51042003588406326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057884435615960433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61978212901159946,
                                   0,
                                   0,
                                   0,
                                   0.20343223094787924,
                                   0,
                                   0,
                                   -0.52494105833069116,
                                   0,
                                   0.089434293892512895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11032474900333064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51539517033709337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098840743562525687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36049605177245658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19438395104927353,
                                   0,
                                   0.087671333558660844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2105289418938126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041095664597292046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22041615166048192,
                                   0,
                                   0,
                                   -0.61727473793104404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24499204704672334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3724428416058978,
                                   0,
                                   -0.039408442333648444,
                                   0.094555351822056335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37379142474612242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070063901632805375,
                                   0,
                                   -0.0035331460197831474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0016443908727005491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0075352019224689754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060086030232557937,
                                   0,
                                   -0.26649106043489945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066712055484536792,
                                   0,
                                   0,
                                   0,
                                   -0.69447934178985682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5160601021244412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40904912105085656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37133010608272221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42341535854361267,
                                   0,
                                   0,
                                   0,
                                   -0.5253955166140587,
                                   0,
                                   0,
                                   -0.23650922867925508,
                                   0,
                                   -0.18243350041023859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11377018916254701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49268057008275129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24879015291260317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091047366386984768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77815302099059513,
                                   0,
                                   0,
                                   0,
                                   0.34144627921340837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16623631545934459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17001019588625202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16991059825502747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56968067705040359,
                                   -0.28556773965363913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58982302543425924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089667437671721723,
                                   0,
                                   0,
                                   0,
                                   -0.14021942329597009,
                                   0,
                                   0,
                                   -0.44053295781168089,
                                   0,
                                   0.31799714236431115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32072962833694146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44169137483188442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17679600689864039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23216516885048824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44482460976286659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34031213900761548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19989802118208477,
                                   -0.040810201129333701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016389274454924316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1189276301438261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62928540016745482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15606154941949432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22649403224834316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26223907308327082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036943337592052775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14020889776360071,
                                   0.12220238408945433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43640919858363697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41144310194129691,
                                   0,
                                   -0.37150945598909474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030122465577131087,
                                   -1.0414216462949302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022376113407958635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17117931782011292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31028186378486744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48770341676017637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01630010620848572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26809398002013762,
                                   0,
                                   0,
                                   0,
                                   -0.15804746670428566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61442824082924463,
                                   0,
                                   -0.017470233357081019,
                                   0,
                                   0,
                                   0.71413254941477411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083770562123055919,
                                   0,
                                   0,
                                   0,
                                   -0.80317651281207769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35977332720598659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67699325696793278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2045919360846136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32836270892653735,
                                   -0.26769769036736241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15464392550741501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014114775133427477,
                                   0,
                                   -0.14066616923405975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12293621918810892,
                                   -0.62905285464623062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39762959185583829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48381444516117261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4982301975220349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44999539304888519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3504847403291465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029944806533808065,
                                   0,
                                   0,
                                   0,
                                   -0.10200030384089229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0045484767489024844,
                                   0,
                                   0.1816911910941903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082809929181981018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27994189641466699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84857965190765683,
                                   0,
                                   0,
                                   0,
                                   -0.40749961555212294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14988225559626589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46090838286480329,
                                   -0.52007665914187584,
                                   0,
                                   0,
                                   0,
                                   0.22621785482322779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33171339228627378,
                                   0,
                                   -0.011367523668314762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17728520941937351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022030023992515982,
                                   0,
                                   0.10738638422994956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1315174408312037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7837119543020965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11377229320280799,
                                   0,
                                   0,
                                   -0.042146312287305421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042624669211133233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02403722718977136,
                                   0,
                                   0.32742792571988677,
                                   0.38483777660867385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22940635253741967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032519000961918301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10414737067866706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10864399369706865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32866964572977603,
                                   0.22158020373966719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25964120369166799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30687888101503441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31346818099026741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12604001777058929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045782415961471021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26889597109718893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62297825560016373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16401992114066011,
                                   0.2324407375475005,
                                   0,
                                   0,
                                   0.34555577955745165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50607958627321836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20662602370557825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053204509657775803,
                                   0.088305982416977957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10242936717771217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062061661586266255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27624735755714203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033583871610420743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40997872493985948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15664505750471161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15206910974596669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46051140690804271,
                                   0.22705015405586904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26237357225455404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16748070677881155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24506578319219302,
                                   0,
                                   0,
                                   0,
                                   -0.22085262635260741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3796348696185623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43271311561135473,
                                   0.050742987191857408,
                                   0,
                                   0,
                                   0,
                                   0.9905541410264036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3831630441698195,
                                   0,
                                   0.25245231755661585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15520705295925649,
                                   0,
                                   0,
                                   -0.39389089165519653,
                                   -0.075337940734513234,
                                   0,
                                   0,
                                   -0.29353370596744749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0072895276331263054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058664551902067673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30827954129474794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31761333195427383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.614830128920135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44130191547808223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079000743880968949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95260895350926467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51948311664854729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47213264570687619,
                                   0,
                                   -0.21456762429121687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39481817174877321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081004610391725809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32559007716629074,
                                   0,
                                   0,
                                   0.13998191697428028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060620302093960673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3356841240850148,
                                   0,
                                   -0.064477799031158703,
                                   0.17205851508778242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15172886519529966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54064866075144391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11134010091223666,
                                   0,
                                   0,
                                   0,
                                   0.31070385019329982,
                                   0,
                                   0,
                                   -0.10405919449511587,
                                   0,
                                   0.19262237467187066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12852173656573632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2296458390647553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69395877520121441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031808794487195313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086389330855360463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36592691032677416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38346810591765124,
                                   0.069519245016457135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20863102269380548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73816722439427618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081707670546142697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12383088227488308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095564016755592868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15824313909874682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14986181162094417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19630399382092978,
                                   -0.012111488293871719,
                                   0,
                                   0.097764813188541244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24493376188503457,
                                   0,
                                   0.25119917358726968,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0042121390991010435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17587464945142439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6740557712113483,
                                   0,
                                   0,
                                   -0.23689133910766991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43280509971392472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052092622620427832,
                                   0,
                                   -0.017776739194261142,
                                   -0.11232431377932264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35066149703794647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32364209040082248,
                                   0,
                                   0.51431139862502384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32903582604115744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4580455858196924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32639498509915316,
                                   0,
                                   0.073196149211603292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41591363999538816,
                                   0,
                                   0,
                                   0,
                                   0.049617329145932636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016424893797183537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15831005678270971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03380021013680938,
                                   0,
                                   0,
                                   -0.11386570775236815,
                                   0.1236952577522067,
                                   0,
                                   0,
                                   -0.62317912262079467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11599949412103433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18271508414184115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21910036905599045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.23752962663917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035251818357907277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27900442697989086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57216951126855253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17860340430907923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077321392886842505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38033429257902773,
                                   0,
                                   0,
                                   0,
                                   -0.78118552036933475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1711591984583834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29316219822136153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20290816114434665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89872812500547883,
                                   -0.25297656992767215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18762469647264091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43079837538558058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27736755003813729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58610049151682864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.4445076739882883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40260837182964593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70456303430105538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30499087723288903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30222026757103682,
                                   0,
                                   0,
                                   0,
                                   -0.31149468866039015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29265420427035788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34111829566712959,
                                   0.29867372422170285,
                                   0,
                                   0,
                                   0,
                                   -0.55148540815438585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.008654966726204083,
                                   0,
                                   -0.40695916291234679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44154713853198391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29225847945853878,
                                   0,
                                   0.25977395085707783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54210499681247737,
                                   0.34779956382256555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44451314830149097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11627266146518611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047419731928519566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5008251343752893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64429393933957146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098142808338052001,
                                   0,
                                   0,
                                   0,
                                   -0.042222142032837653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087288333805806834,
                                   0,
                                   -0.056072002255591197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12920770839585141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29569055421357754,
                                   0,
                                   0.25805822425229213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03625862071102802,
                                   -0.037274273858139667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22784242164204638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03220143809508616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022388962977942323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054281704985556734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1044649347610733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86364148471979785,
                                   0,
                                   0,
                                   0,
                                   -0.6231451770222729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037798542032085249,
                                   0,
                                   0.410567730330063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16506584645838673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54478007235238413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069322712190433164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66350476784988377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35926315849082952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3191452751756389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17093057127907429,
                                   0,
                                   0.21801030817392278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52485310347039738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20049849093781766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31152661058304759,
                                   0,
                                   0.33313866263524933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098224269705879608,
                                   0,
                                   0,
                                   0,
                                   0.032325077262555568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49572456516271429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37830921256621158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69935421594605141,
                                   0,
                                   0,
                                   -0.043168757187257809,
                                   0.42311038738097811,
                                   0,
                                   0,
                                   -0.076060085903573771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60919486507119491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082682222740882716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63531994798793534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36950225591142594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12276669459531923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34166135992994895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31993795240984596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38042492337654099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084565949045438238,
                                   0,
                                   0.43534538341078055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43691216026421487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55656785600718173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42740874270962115,
                                   0,
                                   0.024203853808592857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12091169517827366,
                                   0,
                                   0,
                                   0,
                                   -0.16025576372128389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043355546184125654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27788067973913849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20956475540765412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53733487127941648,
                                   0,
                                   -0.0046527813835628012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57822763095743679,
                                   -0.2164849406744716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41827170229018185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28394608749511341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028284517592748228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27789765248538023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4862044353446931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11621936981521752,
                                   0,
                                   0,
                                   0,
                                   -0.16479133436181184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14391994736721275,
                                   0,
                                   -0.26139790013994452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15695531540106861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14630987942602408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14696319212789929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25326808200497331,
                                   0.044437880442400803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43437001797195623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021296360391971955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018461954330321849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045054589912796671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49223886392776961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44888064499518682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25248681423116404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39344529299226011,
                                   -0.11134402484735409,
                                   0,
                                   0.091392982649841456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12205009381371558,
                                   0,
                                   0.16027753261419914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47926390721795309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42263966760557631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16410621790830404,
                                   0,
                                   0,
                                   -0.19825847710881697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028423869554726207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21020809875894969,
                                   0,
                                   -0.079919939769721976,
                                   -0.65107286762966798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035047354873881442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32508680690797087,
                                   0,
                                   0,
                                   -0.15632451073929987,
                                   0.74788025457788765,
                                   0,
                                   0,
                                   -0.036041709567863955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19668987023163109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27951715913375991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51373121263510368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12985241298469449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67690793080131817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69515262038153025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86958207869718629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39611666729716177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21008928911161662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11775442744779738,
                                   0,
                                   0,
                                   0,
                                   -0.41558784650407443,
                                   0,
                                   0,
                                   0.036248707651815981,
                                   0,
                                   0.81201407030440165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19850113002159486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25682690453486995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056917049849295992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38160384115815738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52280498449532908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049087685281399646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26824017503835923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53234691306372439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47254399625940297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46971607349236555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16850301434947818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041277314513904137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025758541587556194,
                                   -0.37507845295354886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18674969062212138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072119004046482929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043415541600472951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41213098232968376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18015881008610124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.262176784170984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25282276832830225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37772553017839444,
                                   -0.29718535385447131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4122978728064135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17310655477092834,
                                   0,
                                   0.36520652563288619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32692987906047377,
                                   -0.14316092947827733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27608767520673427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44551549833105752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34344343540003514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20586851408242637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59114049246539979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0015355143197648691,
                                   0,
                                   0,
                                   0,
                                   -0.08602155147233069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5394220854444205,
                                   0,
                                   -0.16119171368801977,
                                   0,
                                   0,
                                   0,
                                   -0.11401552203935528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28859789548367093,
                                   0,
                                   0.84371098690882484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090520877068193478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.007332040218469893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046584713167702241,
                                   0,
                                   0,
                                   0.3147543531152488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085341382443361841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12277226654829569,
                                   0,
                                   -0.20136365695850272,
                                   0.08657669205209978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10943597571098658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37164067532124989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65924656439520812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50694551324191517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.4468747713490417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42203882377978341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16897347929569181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14163797339546369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24603698608728591,
                                   0,
                                   0.0020588917065911538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43518615118367893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16337689100303843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08239777498266837,
                                   0,
                                   0,
                                   0.29209126825357323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075414892990344068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5438993352181567,
                                   0,
                                   -0.55546172921441994,
                                   0.02319447412908299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02499881475184736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21469904297471534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23078590996459739,
                                   0,
                                   -0.17007413656527143,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26399494367070409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23517848941126523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30280210400994401,
                                   0,
                                   0,
                                   0.38216970087800362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35958042381741412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065413830170963111,
                                   0,
                                   0.22421290184046916,
                                   -0.39166578641116323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41439276319029811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20622133392706962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28207721698146693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080705991924379661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09914609832959885,
                                   -0.75460627931106161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043352910347189133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013831190296718037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13401654462970108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30339653300759173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07755275031433273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15504024024145591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046335111210733096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067268517540612277,
                                   0.37858498923833667,
                                   0.40281731522833553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067909265634551602,
                                   0,
                                   0,
                                   0,
                                   -0.33089589865755481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17655409355541246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19953297513879986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15072111734605437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73185845650615522,
                                   1.0006622682131172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68738933138970815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48845130789881475,
                                   0,
                                   0.22531618525340227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07912003061933337,
                                   0.27060953592923126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45597054678246512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21373046566156903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16702658808308168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41397236356375899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25778555285836791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53111909696165949,
                                   0,
                                   0,
                                   0,
                                   0.031906654427696704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.006197398041984,
                                   0,
                                   0.21567495277387649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076197109451461395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2903761813918842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17050405849786116,
                                   0,
                                   0,
                                   0,
                                   0.050488314543553389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82867807322531317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30999521949314346,
                                   -0.8505542620265234,
                                   0,
                                   0,
                                   0,
                                   -0.15663190304401881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32438511462289232,
                                   0,
                                   0.15934306965069547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15693502249423152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0182846995178489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17078858588068338,
                                   0,
                                   0,
                                   0,
                                   0.37747445369677796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046802703261747625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54534397144384683,
                                   -0.20495114625802771,
                                   0,
                                   0,
                                   0,
                                   -0.17761506240313907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0040471460194675957,
                                   0,
                                   0.071011246116675197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3605874100936208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34300270845260217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22950408134915207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15722479007695223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31479393778024151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030839122551557518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10479054907481086,
                                   0,
                                   -0.26292933082420666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044873754313893281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14873955994744292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23460642891817846,
                                   0,
                                   -0.42191589351679082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24374465726466518,
                                   0,
                                   0,
                                   0,
                                   -0.31388698016825661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06958734876071368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70704872974482946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0131290531591328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87373127413004026,
                                   0,
                                   -0.49709028406220579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51070023037591683,
                                   0.055688293525626043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22895923545299079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031029710063039825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10940475373232994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13645264302156462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11738994898882663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35475393394340038,
                                   0,
                                   0,
                                   0,
                                   0.0072441663462210291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065520569051969721,
                                   0,
                                   -0.085215637904351896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32149725857105549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11708407216356584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37512175504626388,
                                   0,
                                   0,
                                   0,
                                   -0.40317232980959194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90879673231251268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34441734720887429,
                                   -0.40378694708852103,
                                   0,
                                   0,
                                   0,
                                   -0.4479715799070163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22674896716687626,
                                   0,
                                   0.10746443583272244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28287069661306879,
                                   0,
                                   0,
                                   -0.61909322161285729,
                                   -0.10203409361259187,
                                   0,
                                   0,
                                   0.85629470766320626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49073760801397626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032523486866571839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28633621649345042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16103012073480075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.394651372397058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44358982230099936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43535047893423801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59244042232098737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032508245142576386,
                                   0,
                                   -0.20657618360528973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29660687272330705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51712268738340961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41776307191292894,
                                   0,
                                   0.39684887852171763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19160075269770119,
                                   0,
                                   0,
                                   0,
                                   -0.37947297628760457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2935485362803415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044515566425463907,
                                   0,
                                   0,
                                   0,
                                   -0.052384795296690094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70078829855057878,
                                   0,
                                   0,
                                   0,
                                   -0.60614940604653034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50549876349825384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41106794196138313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99189629818420355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56026318986228885,
                                   0.20921255867122907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088200317237832296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25390186035989948,
                                   0,
                                   0.6863098500192728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11013278038393076,
                                   0.34828786454467442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40320295991771121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20275921953739862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76899036782423891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42271417434563791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0046614832902926451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12475934802814292,
                                   0,
                                   0,
                                   0,
                                   0.14724976342179041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36394684973645969,
                                   0,
                                   -0.024762929938873454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22156227906266523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030193747920302563,
                                   0,
                                   0,
                                   0,
                                   0.37925215494198239,
                                   0,
                                   0,
                                   0.19117850599123631,
                                   0,
                                   0.29910964846123367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53236128777469705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24365223086546975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58084037718847037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1179064950913826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41703587839767442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43792274867630288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13456065673946288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26241993884280734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73036429683529791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.091366263191114017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075055792518724934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45099837333344245,
                                   0,
                                   0,
                                   0,
                                   -0.33567576589059378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22738848151419724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27632127912402121,
                                   -0.09796173391322148,
                                   0,
                                   0,
                                   0,
                                   0.19613067424873667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66356808727736216,
                                   0,
                                   -0.59353706075550972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11501403677619987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058211019650318149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13562849341012786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62617802291948965,
                                   -0.099747872693747242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35966093985596154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17947824223024439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34756941677815911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013803561533608621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28650099370392751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14737021902243927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21717548506929776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35644664624202593,
                                   -0.048537955805089537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63398395407400487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45815865319972515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14532689511596572,
                                   0,
                                   0,
                                   0,
                                   0.33525296659374337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32387468724161472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.918731310662253,
                                   0.29440661101045096,
                                   0,
                                   0,
                                   0,
                                   0.27273866152639148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24114243695584461,
                                   0,
                                   0.2692146981788196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6871807958119811,
                                   0,
                                   0,
                                   0.49535048665988834,
                                   -0.21771327312841204,
                                   0,
                                   0,
                                   0.33447360440730384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39446630824063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5855534809375772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9271575087549806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013230326350596535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11732000881917759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014941320897831442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18015782724403603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079426743506399777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35158322551900761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13711778861422608,
                                   0,
                                   -0.52294986176178271,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48680742967634505,
                                   0.70434909169172644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13303262587668613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099968502059703826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081596045281859056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41527701492559121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56014674385250418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42983191355922984,
                                   0,
                                   0,
                                   0,
                                   0.64591955010262048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027968236453382256,
                                   0,
                                   0.061134619540388124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35113396849456008,
                                   0,
                                   -0.2233878814779135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22640465750227301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21736155209112898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45615339800041432,
                                   0,
                                   -0.29075217692209837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45753480409437641,
                                   0,
                                   0,
                                   0,
                                   0.42246458376706786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20958063978657415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062820859203865972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27083682054284242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14437516970537484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10895023979790192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15581014269177271,
                                   0.1170871060064612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65814122441178902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15575240501357673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080208586124647652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19197264363093902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072236592094200483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033642548215176774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54126986540989874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23462492265696944,
                                   0.029654971778903257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3516336815734783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018533494217268801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77651618547986656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40688971927552464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15566577005341473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28851655350177019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34586022305686542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019239055154830643,
                                   0,
                                   0.21006211948618231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025714613126214161,
                                   -0.063822581041455329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33960911844103525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5699588289950519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31818426778989384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52090680331025174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40386781879546296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26230133854251569,
                                   0,
                                   0,
                                   0,
                                   0.41866525032804414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43496661813833237,
                                   0,
                                   0.36516565502492954,
                                   0,
                                   0,
                                   0.65159525425647136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38200169784021676,
                                   0,
                                   0,
                                   0,
                                   -0.10755193301745457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12591092136375559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66818399354738756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59894685524051328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79353243420033803,
                                   -0.43691926943481663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17660218525843352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98737733621612089,
                                   0,
                                   0,
                                   0,
                                   -0.62895460423536609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60350379162663081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22323944249935146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077659404598865611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29791908318400201,
                                   0.13209429203549045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26116531016299982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27356743399516958,
                                   0,
                                   0.25912553542357281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27648041233665621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23856830784741256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41602933651989771,
                                   0,
                                   0,
                                   -0.11511319402601421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28112906815115202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35802746807598279,
                                   0,
                                   0.48238934462611127,
                                   -0.13132334646697122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1138299719959552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04465006177795737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071286018853474437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43712686060253991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077495155857172413,
                                   0.00034575182271361256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0095033643235070686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42036309173854836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12292504720805694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19618736717123006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.566550556927504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45130929140951104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12171148322782638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093361624994519721,
                                   0.13135441818481247,
                                   0,
                                   0,
                                   0,
                                   0.29274171956153372,
                                   0,
                                   0,
                                   -0.74071967981818387,
                                   -0.22128565752963858,
                                   0,
                                   0,
                                   0.092731270835662058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61008622289709979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60961486632020856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50489160526550969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50450030494574905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22214676894805901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017725547881963663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84006299232352488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33269453058700166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39167619044396873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50195188129795443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43031138820802928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51310295753928459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30005832965853485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23697369821605041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22148164473819237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47990069048910255,
                                   0,
                                   0.0097699819881314487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16253513566751115,
                                   -0.5381757523693097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17654953092306316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14854758556994468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18957274400722554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17633316265506221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26548187341688761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0082897176800584005,
                                   0,
                                   0,
                                   0,
                                   0.63254923767193461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38613916572799134,
                                   0,
                                   0.7344301494326585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60463705877302609,
                                   0,
                                   -0.13477586308208983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34527331844384218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057148641012678872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35865768579798896,
                                   0,
                                   -0.23704611798888364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.269908828994049,
                                   0,
                                   0,
                                   0,
                                   -0.042231485661556899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39558220300194008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27896973128353042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35400716615283434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084572561438482699,
                                   0,
                                   -0.41962150515191632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43903175487562118,
                                   0.5896677833002254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068176135099658364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36846120440387037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25567467901725188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19536998465746502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06823334242684484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52194589054340423,
                                   0,
                                   0,
                                   0,
                                   -0.22536965372144033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15592027902379904,
                                   0,
                                   0.63337993142293414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053063854724991762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40069197629693898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2035630344531415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27513672239589992,
                                   0.098724892249330079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17413942467506233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068880457808636303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3877523559633842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43136937603784498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11374178037879619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1510708432419367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056488127121120973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1415198225428082,
                                   0.52845680268543704,
                                   0,
                                   0,
                                   0.096667410201470738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33059417554091269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46039781822569981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12870414012305442,
                                   -0.42705720302282363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15490567866659105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086632355298496361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16880609702282928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13148900476210681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15539384362126499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46525600170258274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21684878420847759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31263152581219777,
                                   -0.088295473296967478,
                                   -0.41288709436153959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25369488741522461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60025494434861049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40444258361402041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25173421135172641,
                                   -0.34517347375985064,
                                   -0.056829106240393265,
                                   0.23566705812506672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74322922426636795,
                                   0,
                                   0.021204761963526719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11162707529216664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.94273862631671812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31479848743402261,
                                   0,
                                   0.10796268031722689,
                                   0,
                                   0,
                                   0,
                                   0.36743538081396399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47642065697631725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52520708930786697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23715528844468703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20795264440907962,
                                   0,
                                   0.0043220223843969952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12141018369951012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62240565368815559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21545115458745637,
                                   0.2980941538783502,
                                   0.4961677298200492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054050837402603323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29699093156965772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47181405713012275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13129910451404136,
                                   0,
                                   0,
                                   -0.55568063553628722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19111814267841254,
                                   0,
                                   0.096746769611002537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068765681975695603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45988568209471758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37369214624392028,
                                   0,
                                   -0.6459165337875058,
                                   0,
                                   0,
                                   0,
                                   0.71513883340657525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46141053571473134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030971786622054465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35100102704934777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033385045280060519,
                                   -1.1347531174590706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29530646181167391,
                                   0,
                                   0,
                                   0.043768251450026212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97029032418809991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39033912916096486,
                                   0,
                                   0.040028962857657974,
                                   0,
                                   0,
                                   0.31555190083778839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53727516347766646,
                                   -0.62068909703555408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28517351346400122,
                                   0.080184105174349318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2247217761593277,
                                   0,
                                   0,
                                   0.43339028986240269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16934556404858797,
                                   0.45377960083290281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75732937436609804,
                                   0.25314477911134958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069408140690345344,
                                   0,
                                   0,
                                   0.35065453560709364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19079092002760942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32445823241961241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48693782161703819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49782558916813091,
                                   0,
                                   0,
                                   0.1750546482362792,
                                   0.084612123828096714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32626939882271738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013761137698564463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23760245250399029,
                                   0,
                                   0,
                                   0.41531622238456056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8723984878786688,
                                   0,
                                   -0.6852383720237355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80541371412642182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39921071000439123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3960923435867888,
                                   0,
                                   -0.56276625945722814,
                                   0,
                                   0,
                                   0,
                                   -0.013887325996425177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0040110577870401398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42281955673386046,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48439562632214633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42929446058801846,
                                   -0.35440910134802184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.156743114219875,
                                   0,
                                   0,
                                   -0.70022548806140716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21509644188223098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10263083305444728,
                                   0,
                                   0.64201829476063199,
                                   0,
                                   0,
                                   0.31580505095252553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092022233426795469,
                                   0,
                                   0,
                                   -0.082467489440023287,
                                   0.11133338350025941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12526996689014935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.056166065490943558,
                                   0,
                                   -0.50703842838837421,
                                   0,
                                   0,
                                   0,
                                   -0.46228660601679372,
                                   -0.02106208808789381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050834709987690685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080945383389021699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47219064571869485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44578500078432659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10090416361378129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20308120673083302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24110082541967406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71963013893924233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68876407933082817,
                                   0,
                                   -0.246161367499421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055476122473735248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32100360630080071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28661842973744239,
                                   0.25088584873679554,
                                   -0.72480933998710362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.008420069855611105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55387276861421042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41365522485101769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049128215381917292,
                                   0,
                                   0,
                                   -0.039064814212486816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13965231353779495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34058719995215225,
                                   0,
                                   -0.049632938361127088,
                                   -0.50360285246815317,
                                   0.012292065140908609,
                                   0,
                                   0,
                                   0.0014179458174846116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22854006321563763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30556729684478684,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.98223852965956726,
                                   0,
                                   0,
                                   -0.095071668775191825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25695717222713549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37404156602772592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37098746615986955,
                                   0,
                                   0,
                                   -0.019045082253706686,
                                   -0.38758883093004493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087121962722928076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3236467050128653,
                                   0,
                                   -0.37179051483221748,
                                   0,
                                   0,
                                   0,
                                   0.15090599061104745,
                                   -0.089082350474212951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041750256412298264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34593405404791588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044015422986606073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026332378234639763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0013857448870739399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55358871126226872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15775537817636739,
                                   0,
                                   0,
                                   0.041345798976965664,
                                   -0.096750202211755745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18047060961792449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10304305712164522,
                                   0,
                                   0.037694683866326184,
                                   0,
                                   0,
                                   0,
                                   0.12272185990023413,
                                   0.30806021862445282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22938547473927928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12483892194446328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21020247074292914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56671897078969224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.591421340739817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16166596331624228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3051055678409344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45484812875477326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27202353585589129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0099848631423795076,
                                   0,
                                   0,
                                   -0.44851841955888544,
                                   -0.26043053102897551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40213798437115028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41540138136893662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032375430515717216,
                                   0,
                                   0,
                                   0.14701361125828652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22128309186747697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12274986955769976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13018920385706956,
                                   0,
                                   0.18231646140996757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3871083420317316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32132952041202756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1397041822456129,
                                   -0.23149191117436302,
                                   -0.04525359054710467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18419961678754057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051310733894549161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31062745827719795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12420829281072561,
                                   0,
                                   0,
                                   0.061418122248707317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55841553313798475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40661411454486673,
                                   0,
                                   -0.27089511349205875,
                                   -0.47458870293791316,
                                   -0.25603698242140455,
                                   0,
                                   0,
                                   0.151577468142026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15670674882763785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71603512247500323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09260219446045885,
                                   0,
                                   0,
                                   0.061950897900355892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34328545195728943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32436247238676491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26162253374661548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1400500454615011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78145900027076198,
                                   0,
                                   -0.54814923317615749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22396242479618172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17225379092138068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020138028534095957,
                                   0.031588747708459243,
                                   -0.57997448417670383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25150933150018323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07307496058110835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38379170410379171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68087887581429507,
                                   0,
                                   0,
                                   -0.014967244422318001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41808260859550717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0060292501368091793,
                                   0,
                                   0.48217385806083723,
                                   -0.16812213070776622,
                                   0.49330863648374357,
                                   0,
                                   0,
                                   -0.2959199621622785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.380098608947532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36542017352251721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00036692673187599043,
                                   0,
                                   0,
                                   0.87012643313083948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0054452147833812647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37344459802648811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27424019201467364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5250778497707066,
                                   0,
                                   0.78978026355558051,
                                   0.31939346835102367,
                                   -0.36219405505913266,
                                   0,
                                   0,
                                   0.43077128448818491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26360369169892151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80281747290984973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36599081309713377,
                                   0,
                                   0,
                                   -0.09804782687685118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26997825946495518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42934459804553138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17529726846344348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11067371545861099,
                                   0,
                                   0.62183144644456811,
                                   -0.58736724763048076,
                                   0.070907097766158861,
                                   0,
                                   0,
                                   0.62362728339881723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050671839744756017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11823651330957138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46220147663790756,
                                   0,
                                   0,
                                   -0.5964508287093977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37569771068431157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4218363653501882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26885396735563027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22707739657422388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91503401156435615,
                                   0.58734378424990641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57621202781978986,
                                   0,
                                   0,
                                   0.38578051394244922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29074524543547942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69758481020873786,
                                   0,
                                   0.32535040391760839,
                                   0,
                                   0,
                                   0.60047912970124129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49913954983211661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012387678714971692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19049215123095664,
                                   0.011746218295341365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52677601003518559,
                                   0,
                                   0,
                                   0.11337001067736349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75003190313754808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23857374937929587,
                                   0,
                                   0.41521161768404802,
                                   0,
                                   0,
                                   -1.1350289485080456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63123063151802061,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3373482046994345,
                                   0,
                                   0.43558192698009712,
                                   0.75970885416136158,
                                   -0.69980712801673772,
                                   0,
                                   0,
                                   -0.31906056064758881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080266479548998945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55076198040020363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055283699155436947,
                                   0,
                                   0,
                                   0.046388835742904033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40904859945067551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44927654733491196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052331712603812933,
                                   0,
                                   0,
                                   -0.28738224243951005,
                                   -0.33242813427552326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062941636514532287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085661675815714572,
                                   0,
                                   0.42532252862189168,
                                   0,
                                   0,
                                   0,
                                   -0.41670202120513533,
                                   -0.10438460925152168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029428119835112301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2451883846755693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20981465836355423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25683294817635205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40696598524112421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30139476081403438,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45300540513379428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11815564882478446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44488876392522297,
                                   0,
                                   -0.1003004580909849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37432625861289448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053381085011684808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13323145895365987,
                                   0.51858366976520598,
                                   0.23102315065183818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036370372900712933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26500511165413509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65246894399420141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18988245467229292,
                                   0,
                                   0,
                                   -0.37676097131577746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33929497860407937,
                                   0,
                                   -0.47875549322669181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051970608696667052,
                                   0,
                                   0,
                                   0,
                                   0.23715793145176792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16527402662710378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14298413874278024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39315750340265365,
                                   -0.52734247061765038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27767078423052005,
                                   0.12317595051449688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055607579401276967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14470249785281578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7131158072803131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44052722174848935,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10662234594167293,
                                   0.5353973939148331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29372710310727529,
                                   0,
                                   0,
                                   -0.40146466509907602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45037847244939316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94840828681947664,
                                   0,
                                   0.20509682175223273,
                                   0,
                                   0,
                                   0.50293542549541304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29115798615315075,
                                   0,
                                   -0.29791229497822264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56198262699944257,
                                   0,
                                   0,
                                   0,
                                   -0.10604652431990874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15576321656577419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38411169171765225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17900921076562887,
                                   -0.25793501026784132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11498446961313404,
                                   -0.36642744057251597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086919405445782555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27199399684701808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082826933110394657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4117675755734751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019203548719825492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38042189814031863,
                                   0,
                                   0,
                                   -0.024917920257642515,
                                   -0.35057425907508233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37321778667876948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35303402329926231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49653884913277851,
                                   0,
                                   0,
                                   0.21094782652440913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85214604129726956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38970671905492626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051622242687750036,
                                   -0.17789255107939903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37472926023009712,
                                   0,
                                   0,
                                   0.18651269637286247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078317171666042767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32323597715863628,
                                   0,
                                   -1.0537143252295258,
                                   0,
                                   0,
                                   0.36348583860394962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39719690069772995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12753816015722172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061287497246440774,
                                   0,
                                   -0.54665160338098073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038197562234975842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13738045677330743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058003786601206572,
                                   -0.58268154408828476,
                                   0.060313800199932682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027254311846168642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88836741237891204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22721937654141877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051615311901659092,
                                   0,
                                   0,
                                   0.55955871176178462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16350677108572115,
                                   0,
                                   0,
                                   0.21878353353431734,
                                   0.25298148859841768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027781502063307269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031144844011657923,
                                   0,
                                   -0.25715444572398033,
                                   0,
                                   0,
                                   0,
                                   0.03723053929320172,
                                   0.0097830141450457944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24048162003424317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33091227401699408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57975294434633873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36301471581173922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39531874963011504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023306829351406842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061136731833470112,
                                   0,
                                   0.070388961036990272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32924042689437499,
                                   0,
                                   0,
                                   0,
                                   -0.21937606146964805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15923830570623509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26677843308293137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43296505852016959,
                                   0.39308928754079964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49144812465929277,
                                   -0.25789974473651711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29371972816930964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044410163409929468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49678487383662073,
                                   0,
                                   0,
                                   -0.34951714179687571,
                                   -0.14154130614943225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026013081597706496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4153439342061071,
                                   0,
                                   -0.26252412598016139,
                                   0,
                                   0,
                                   0,
                                   0.28414991584914251,
                                   0.1778645874352936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23661570939283938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40692739977254611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045651432747716131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0047085074406488375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18023539715157347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018908306502088329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47860574926957289,
                                   0,
                                   0.62323487470927563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41633090849976145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11133750859933599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76071349170777658,
                                   0,
                                   0.3673380088195719,
                                   0,
                                   0,
                                   0,
                                   0.34124134008304469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52295261026765194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037269041308242157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097298912813887042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36697492454570624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7905751842647305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22846179254977722,
                                   0.14425332655356077,
                                   -0.3309866547883839,
                                   -0.21658311194511609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36297818737629972,
                                   0,
                                   0.32278395970634116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021952549647503206,
                                   0,
                                   0,
                                   0,
                                   0.42531077036445775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27918866176709745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098531559496144616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42295697645407265,
                                   -0.081805084289394966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3116490720724811,
                                   0.16699210225050137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16268549340589489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39745270925742432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29863878178203757,
                                   0,
                                   0,
                                   -0.42999223096898298,
                                   -0.01573202756254944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44075032560210531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092244840120992627,
                                   0,
                                   0.16827013012769432,
                                   0,
                                   0,
                                   0,
                                   0.030294762485994026,
                                   -0.084687371567837705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30339311056883261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57499290726322516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050078175079495961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.011546042112753386,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044410003908373262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24335557576234865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061190953877967087,
                                   0,
                                   0,
                                   0.21886702127594285,
                                   0.26398747940355399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35953471167049134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0058210353037601659,
                                   0,
                                   -0.15010268177430394,
                                   0,
                                   0,
                                   0,
                                   0.18505262993524882,
                                   -0.4566066320621221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51592279697603227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37979128464245998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11075868237809774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088603651235216213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16673672204152332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16050708590316126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48829679307405638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13900584256434287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16111180819119245,
                                   0,
                                   -0.42064538074481816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1203159003084365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47203435021289969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30261902618543335,
                                   -0.23522204696123275,
                                   -0.3067656019524484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96857601111784086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20605732828573881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54726038479693384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023946138237621949,
                                   0,
                                   0,
                                   -0.23627406509602414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49299641886106571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13600487140255021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14878212089488327,
                                   0,
                                   -0.4875988598685318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079251892723867456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06353627495819017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76880592734841646,
                                   0.19230671107262889,
                                   -0.15992384676289079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1264316445409561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13227902069064529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033437687496477672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1587937491060972,
                                   0,
                                   0,
                                   0.19190944064205895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2835109004091903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00013118051324489954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45495289218421558,
                                   0,
                                   -0.49814545973327384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26166246003516458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82483696291836917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92098122195808618,
                                   -0.17747128730159084,
                                   -0.41925029799136948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17280524430001737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38792915425252217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37299170870919607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036353139984327577,
                                   0,
                                   0,
                                   0.19623598903482284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22077458841895736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66780386153389304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088542549702346859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085452055960219292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5595918326390924,
                                   0.13330309761014197,
                                   0.054890023307038377,
                                   0.39525826620800053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62219662112941676,
                                   0,
                                   -0.43645418966406474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41493614591891481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53495398511784975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075509696196431247,
                                   0,
                                   0.099867565468335848,
                                   0,
                                   0,
                                   0,
                                   0.47012793814800385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61996925454514518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24945883257078477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06973080579078389,
                                   0,
                                   -0.0039321986802858724,
                                   -0.048746357818181853,
                                   0.78792671699444872,
                                   0,
                                   0,
                                   -0.40257882439481091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50203139149194165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23730905181270287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078227799598969985,
                                   0,
                                   0,
                                   -0.65328826276378804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073775452195825986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74589301093192761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057883397142882154,
                                   0,
                                   0.19189163613803428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16267167825339082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34767242933150688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29283509690291293,
                                   0,
                                   -0.7490547926052914,
                                   0,
                                   0,
                                   0,
                                   -0.043729589506326369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99966033435198254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27810408388268915,
                                   0,
                                   0.61819860945867033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19199453882115081,
                                   0,
                                   0,
                                   0,
                                   0.21571528528810605,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23135598624756651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036972970314901113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35111400082392219,
                                   -0.21951668699102478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32672488877888611,
                                   -0.16200855222872462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11393207101436352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2911287678159441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50357967832402162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2218892923850794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34597312830336285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43248910379846733,
                                   0,
                                   0,
                                   -0.03204655740926813,
                                   0.043349605499850348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13978599179010742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17246762025935608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57926499937461717,
                                   0,
                                   0,
                                   -0.051856589876161083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0234165125266912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11753775918024946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061095784201793873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39902369479520461,
                                   0,
                                   0,
                                   0.85662830181981886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3915033598836985,
                                   0,
                                   0,
                                   0.7070223188075917,
                                   0,
                                   -0.95359047575212275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79880837250085623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040095714903536514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.314644892334907,
                                   0,
                                   -0.31820737564083584,
                                   0,
                                   0,
                                   0,
                                   0.028629669553112032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60053860079090593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040539845185562473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073053488282074405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65202240772602238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094005196777488087,
                                   0,
                                   0,
                                   -0.097214515022977177,
                                   -0.37621351304963707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034204011635107355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013791012071906361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46260898421018865,
                                   0,
                                   0,
                                   0.43897045865747092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020392794830824165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58455963370066455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19908612331040096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13225742517472336,
                                   0,
                                   0,
                                   -0.31094330711614704,
                                   0.37015853396853743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11393824477581874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5900431306934304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033935483141200214,
                                   0,
                                   0,
                                   -0.068987972364263836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20432930257804841,
                                   0,
                                   0,
                                   0.065939403628117066,
                                   0.13312059455918876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099552677614362289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086973334916492923,
                                   0,
                                   0.081518691803205645,
                                   0,
                                   0,
                                   0,
                                   0.1420930977823292,
                                   0.69448589788169734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47063126809857636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0049570507019190552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10184774385662206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0048425494439056291,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42143965337540124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0057250705421316578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03159900775533981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6096115062035562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1193218872583219,
                                   -0.65940224906697709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57911678894702923,
                                   0,
                                   0,
                                   -0.13049927502583308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42059078740939659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49495415675494769,
                                   0,
                                   -0.52337100804150671,
                                   0,
                                   0,
                                   -0.17978033445055464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17668709006422678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4297587162892233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23936558904887847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66322079475952567,
                                   0,
                                   0,
                                   -0.15988606351900675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99747820264637155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078872334198282532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51193561097899232,
                                   0,
                                   -0.4613831768215475,
                                   0.12639658630764569,
                                   -0.25387761248065116,
                                   0,
                                   0,
                                   0.45128679166639901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58932594480146316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057000006026514373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24138066030039201,
                                   0,
                                   0,
                                   0.65377796520442166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76751911421022634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21434910701021692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11156386656126116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058937993846539687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0070746986679847967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26559020866664201,
                                   0,
                                   0,
                                   -0.776582367709159,
                                   0.15096694844207609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027985069968443715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51357819149958805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041473598767077652,
                                   0,
                                   0,
                                   -0.14613223662121932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55478828118640067,
                                   0,
                                   0.16401186245567198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19912067931874117,
                                   0,
                                   0,
                                   0,
                                   -0.24207003618644873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14502680028940373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.306827642354705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065921522913789721,
                                   -0.33812576973074526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.467191817129465,
                                   0.30230109284706969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062836066119099185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14003553296001606,
                                   0.20437377342077212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16145685078908212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24087288703905035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23128076401749792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22287133498185657,
                                   -0.46462008380054665,
                                   -0.46036878387482205,
                                   -0.58580682410004381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20088406404208636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28774103366213366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088136934079194901,
                                   0,
                                   0.55150923225328663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016131161138808973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55459040211505983,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58082286070919609,
                                   0.027874896551838502,
                                   -0.47816859100062453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0083219176491698705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21146549571191287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26603955555900805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26916495595740886,
                                   0,
                                   0,
                                   0.77303646056137643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37599312720327527,
                                   0,
                                   0.055698812095048816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3603894197684272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083634761893281756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66324896908472775,
                                   0,
                                   0.83477975935188298,
                                   0,
                                   0,
                                   0,
                                   0.33543941417307949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21100518485073039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47082013353625873,
                                   0,
                                   0,
                                   0.070509540818543742,
                                   -0.18848547466305457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66846250371656635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11425190349678199,
                                   0,
                                   -0.085971194276919544,
                                   0,
                                   0,
                                   0,
                                   -0.038363998952638735,
                                   -0.20580833604688545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3962902864121518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16379943462600957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13904563284958116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073082324772598795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032149292062462365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13088149257692896,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20187745775769833,
                                   0,
                                   0.045737543793076235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50116617352478632,
                                   0,
                                   0,
                                   0,
                                   -0.058997478951172869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27162184084743451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021597450095287074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16867784870990538,
                                   0.013593924673624774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039830430091146979,
                                   0.72357314846316623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20231044920413524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18316485804943405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019290174162177702,
                                   0,
                                   0.28317807667185019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24990879360793167,
                                   0,
                                   0,
                                   0,
                                   -0.41010148284401787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040158182617876459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38949815507771346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19684550761943698,
                                   -0.40723474214304228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20813226888726022,
                                   -0.071175930385699165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51382225419818051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13598635914562734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58683539729012169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035022032185355302,
                                   0,
                                   -0.35690267915506291,
                                   -0.14783781018488987,
                                   -0.19990019626373856,
                                   0,
                                   0,
                                   0.29673479523249097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23326254733289878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47192581683182611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18384679411519181,
                                   0,
                                   0,
                                   0.16132337123799309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79466011801488434,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10290163567072214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32848182610219651,
                                   -0.022933938947624709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26733464723787076,
                                   0.51089353328913911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066145459746715832,
                                   0,
                                   0,
                                   -0.7447942578654525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035925128220600178,
                                   -0.29230566864542323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30508817132488675,
                                   -0.34588078621791207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81836698170447586,
                                   0,
                                   0,
                                   -0.17558460621280902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097451924569718296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082362109649395721,
                                   0,
                                   -0.23888690177488858,
                                   -0.67606050458216671,
                                   -0.76881454501452184,
                                   0,
                                   0,
                                   -0.56504808891356928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63814191932830078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084989681681696058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37974913632668117,
                                   0,
                                   0,
                                   -0.0064703804850582414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27751205923889932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2116863397532574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20322037188677761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21087657859405101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56878263244867888,
                                   0,
                                   0.34140653113449382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21703128334032701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30886459752822609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42214633586421224,
                                   -0.49602425300825104,
                                   0.083034214098403086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16538265045585868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0085038461667894492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02313291200412565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5035080042783644,
                                   0,
                                   0,
                                   -0.52835751535341191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0832248965553188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23111282802434185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30080596535801574,
                                   0.35905923549642732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47456171588615587,
                                   0,
                                   0,
                                   -0.31198754135414475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53019377366813569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20771465917400159,
                                   0,
                                   0.77645425073959928,
                                   0,
                                   0,
                                   0.44221330791723867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075884991735466964,
                                   0,
                                   0,
                                   -0.40178722176743026,
                                   0.30327763994085488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19218355519328018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18767024717190353,
                                   0,
                                   -0.26010211267353395,
                                   0,
                                   0,
                                   0,
                                   -0.43421000860374648,
                                   0.10425473037431612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20942329721654188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042574182915211096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43442640213836115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30149494806897337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26197784398945628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087678206047483317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055034559248109224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02040560112111621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071293974340958938,
                                   0.0010210400564944905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38677521302107709,
                                   0,
                                   0,
                                   -1.5743660636131696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0021048908300346642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30506124126860051,
                                   0,
                                   -0.40325900631879918,
                                   0,
                                   0,
                                   -0.16638152837552009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075894067511300067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24761043608662897,
                                   0,
                                   0.10794347611240296,
                                   -0.7897111887876308,
                                   -0.16839104082007583,
                                   0,
                                   0,
                                   -0.20101633673789454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40668544740222023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39775590491046442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58090668343953156,
                                   0,
                                   0,
                                   0.48391612663795125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045278966905476753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64772998301998508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56311913780964962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17152753995205181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19051783000807007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49261418002017532,
                                   0,
                                   0,
                                   -0.19088268913954248,
                                   0.10901137773834638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27821763513878456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049541765128080076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046791209107838558,
                                   0,
                                   0,
                                   0.49410608985219717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048422501101188037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.348117475484562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58761185646538172,
                                   0.096319100594086188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096533736182471588,
                                   0,
                                   0,
                                   0.23978640382195121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53549364478353489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49427229789143184,
                                   0,
                                   -0.23308375272190049,
                                   0,
                                   0,
                                   0.16559189562583015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37417454542236589,
                                   0,
                                   0,
                                   0.49582318128801789,
                                   0.090531471710826261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22105910421943387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37786051895881811,
                                   0,
                                   0.16429658608790992,
                                   0,
                                   0,
                                   0,
                                   -0.46446717146967559,
                                   0.16860441931236519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084521676770902832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10020013088163426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1525573346465785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15006696358901009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052705475230660256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27821733024176343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27998846402790828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14298763806944886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47356888972900957,
                                   0,
                                   0.362299554755596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36524446908948638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24612609965870702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57372305432083037,
                                   0.37405185892074228,
                                   0.068370099434231293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38999442788343069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33848602937544731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23175752647638942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80706137577102077,
                                   0,
                                   0,
                                   0.0015609197027765965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041451882678844754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63657879059335254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90446823169058133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057808501034295065,
                                   0,
                                   0,
                                   0.32829013375691918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080264056186300489,
                                   0,
                                   -0.35610508648821587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33654621829641301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42427196029755349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035003018693650446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58224379847849672,
                                   0.29615273264903463,
                                   0.26959544986053646,
                                   -0.28159885334912449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74314416888594237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29827098912274519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29216353537955797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37653166518873304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036976580018284758,
                                   -0.18541766604222437,
                                   0.30088111552852054,
                                   0.073205949015077973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068010680401630469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50155813673326988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046075986491021834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076093603533640225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33114036403089986,
                                   -0.23224503809511352,
                                   -0.50920251957934592,
                                   0.55948355243191017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2322190058871027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01876190270409972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41433639894422536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042809884441032162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26756568546818538,
                                   0.6711041670498451,
                                   -0.49976754296146247,
                                   0.021798865712269591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028602516766954612,
                                   0,
                                   -0.090780591945634134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10980609503038732,
                                   0,
                                   0,
                                   0,
                                   -0.25568821582169377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3638692634372403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036859811959077268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061626091696972668,
                                   0.35644442741111515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055704538152886215,
                                   0.3240407555074124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34594528581259515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64893258413011989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075491192927421957,
                                   0,
                                   0.17128558432992791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25069816765047681,
                                   0,
                                   0,
                                   0,
                                   0.027532712247670288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63207786063518079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32360536933991635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3755815636195402,
                                   0.069768602220927387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34935526874853834,
                                   -0.040390927000347826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20911410115284373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28943642313870288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20866098799022703,
                                   0,
                                   0,
                                   -0.18571555448610944,
                                   0.18465252007972954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17481477750430452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65452694729150018,
                                   0,
                                   -0.16397101131089895,
                                   0,
                                   0,
                                   0,
                                   0.034848277278415288,
                                   0.20420139042442245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15878753485693009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075095364120863733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15822959047246024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23382989645302782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060524817957872595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49485337772117766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51502163458690908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015592305689268456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010855225186031825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22063397369493004,
                                   0,
                                   0,
                                   -0.046238216529682512,
                                   0.25047840710565528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.464056093341222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0045469348394230613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37078858741853793,
                                   0,
                                   0,
                                   0.51766987126067887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.422601847463973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0601461354571573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069648889092797206,
                                   0,
                                   -0.46555580616133441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050181633119861041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019321322741990603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086963171921633997,
                                   0.05724305702944428,
                                   0.75608695148445626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.138153162362747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23853392637527185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24895053899136507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014924906127238031,
                                   0,
                                   0,
                                   0.23629092547429334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71840357274714062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73550745918713245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22815705496605537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53115900583760034,
                                   0,
                                   0,
                                   0.24682624323192437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2347890474120957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11489271137563586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29810628848585841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25999064700522145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17912871519767032,
                                   0,
                                   0,
                                   -0.13692502753802632,
                                   -0.65135807931646417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51508598183082477,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24144463923709464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062014477117209019,
                                   0,
                                   0,
                                   -0.16667148518921898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52501176134797989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23785733029797804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64125694506203779,
                                   0,
                                   -0.17196855709907366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084231662117209338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18525114871794268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48225083929990353,
                                   0.59613330860031699,
                                   0.44864176824270724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11060289618533474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58001584117882543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19446937067215769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32541503185449216,
                                   0,
                                   0,
                                   0.55618474913169902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5547999531361989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11999801685600181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2586044227705887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71582748764796478,
                                   0,
                                   0,
                                   -1.0440030315094038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16690518954679723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11629705803039921,
                                   0,
                                   -0.0082463424732082471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27093742311282565,
                                   0,
                                   0,
                                   0,
                                   -0.5565469763126536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060418402389751505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20912919066001182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.076505289374235286,
                                   -0.18149180210825738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27185166398687649,
                                   0.0052392558499557984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61181127587871376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.262361998903614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53452326108747628,
                                   0.43734461991183299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16253555772694495,
                                   -0.64923050931819204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23314222451450747,
                                   0,
                                   0,
                                   -0.14401808283629808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84708857342035282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80517320108510226,
                                   0,
                                   0.034172352440843878,
                                   -0.011591300753716994,
                                   -0.11176283735424156,
                                   0,
                                   0,
                                   -0.44924642799421854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66550456641998723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.095827102708271231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23376653038995879,
                                   0,
                                   0,
                                   -0.091041079002780245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13469725516983777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16447400664128908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084196904802912628,
                                   0,
                                   0,
                                   0.23373135189738736,
                                   -0.61320677963713677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20517468265867619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25514061318128667,
                                   0,
                                   -0.31764982622449839,
                                   0,
                                   0,
                                   0,
                                   -0.17430713720667224,
                                   0.18101920269704072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12406300214710313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.061461382544454587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25918185596058874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31654828627716131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046501065193920992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31984797299525758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53642467978871144,
                                   -0.36275368040227096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39263707481474885,
                                   -0.35685046619713745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46500279341626993,
                                   0,
                                   0,
                                   -0.28796632552966295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41530839773598938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3221961489522256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27681733435695177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54635517458197114,
                                   0,
                                   0,
                                   0.046500076521150568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38810500382915392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46724138626366835,
                                   0,
                                   0.20951927001225673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1847876785805522,
                                   0,
                                   0,
                                   0,
                                   -0.22543552563648306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39949474873385643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59467216118047184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31857829408879468,
                                   -0.027696307071583149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045308122213199728,
                                   -0.056937259071279694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13047361971995122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12252023829138337,
                                   0.46986695128949274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52654147365173154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1826619733218515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0277805115695573,
                                   0.054488484783334734,
                                   0.19668443569159555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27649043587710287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037559982718657015,
                                   0,
                                   0,
                                   -0.25952543880032586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033137143797743768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.175131536004072,
                                   0.42464131240848463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24054582919462505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48199813966711064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13339386280375495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27099598657347018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54526193310215265,
                                   0,
                                   0,
                                   0.046288753666784511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43885097754374436,
                                   0.55362815547725663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15393796640626517,
                                   0,
                                   0,
                                   0,
                                   0.34837785647297054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69967691306431157,
                                   0.56452790072483205,
                                   0,
                                   -0.72862586471075408,
                                   -0.095651182338490029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27794513889916589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37721287486974875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40742525062177454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35229091046236116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036989076962869682,
                                   0,
                                   0,
                                   -0.087023957543166858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53046742427778781,
                                   0.23189053049005826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37583895954912394,
                                   0,
                                   0,
                                   0,
                                   0.34504896228919107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57527812187357796,
                                   -0.19541889898360121,
                                   0,
                                   0,
                                   0,
                                   -0.026611136846796259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064684265715579448,
                                   0,
                                   0.056921328867375116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26456147231232341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38903080856479705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14194118379129683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43222811923657473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48981606622294477,
                                   0,
                                   0.17559175966431348,
                                   0,
                                   0,
                                   0,
                                   0.32252118727912404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090004621838623663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29745191446041519,
                                   -0.12448882622520381,
                                   0,
                                   -0.27697195501629657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24823461252731699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19459156943187528,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2958526099214881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69703976380617982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26630433229755568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10505286435213267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032842593874810408,
                                   0,
                                   0,
                                   0.018190062247385647,
                                   0,
                                   0,
                                   0,
                                   -0.066214441384544825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44711591291847125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17882747133481233,
                                   0,
                                   0,
                                   0,
                                   -0.086490616498604289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46318692914693249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30940946928768609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4735595432884111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57719522115229538,
                                   -0.45867080825068351,
                                   -0.52830912594837665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68507249100544421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11310278084985084,
                                   0,
                                   0,
                                   0.013751341280670869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037856129958971252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57233581496611019,
                                   -0.40888835555409125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27619374851976425,
                                   0,
                                   0,
                                   -0.55904602070490017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22947738927387229,
                                   0,
                                   0,
                                   -0.26630726588569853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16568377933970041,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0490589650331241,
                                   0,
                                   0,
                                   0,
                                   0.08663271544676461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1437146356382239,
                                   0.18822849691548657,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56281102856788756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35537039173272184,
                                   -0.15019212564648254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19877953246533941,
                                   0,
                                   0,
                                   -0.10570897277424215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43757921200583449,
                                   0,
                                   0,
                                   0.12143729813730576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67873817658665703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57114264109616653,
                                   0,
                                   0,
                                   0,
                                   -0.19598248685675035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78014417305383432,
                                   -0.72772735255625043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59304832062965207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17024853569480886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093278172105677348,
                                   0,
                                   -0.23523859115900447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0059873697515728233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041607637338899883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010815815347129182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016783421342932058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050294444249989211,
                                   0,
                                   0.1622118677155788,
                                   0,
                                   0,
                                   0,
                                   -0.43899908268619692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50697452280592037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17731614072614713,
                                   -0.62671312225830766,
                                   0,
                                   0.044897448260242133,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.05303772881847317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48033619016711865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2113075769578128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06222875610294043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076859700446556822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21919146350432028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014541128737212533,
                                   0,
                                   0,
                                   0.32882150089038015,
                                   0,
                                   0,
                                   0,
                                   0.45096052812681747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14952331259836363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51654662524970696,
                                   0,
                                   0,
                                   0,
                                   -0.25121796010097081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14832380041922211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20873898081640094,
                                   0,
                                   0.29007804696476619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35554156382875446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22378745419800539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38559361968711886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2256984718951974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11244169306458109,
                                   0,
                                   0.13705830606181094,
                                   0,
                                   0,
                                   0,
                                   -0.47623451139386408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19777420745050822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021938745722871383,
                                   0.40956078686174158,
                                   0,
                                   0.092771436805100416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13385443303932595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2466766552394124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069952101113611886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65980499661218406,
                                   0,
                                   -0.39220434228465162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38839430199807973,
                                   0.068849690954155537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046918755658617951,
                                   -0.39560421047609506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11348553941377598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20698031986717474,
                                   0,
                                   0,
                                   0,
                                   1.2675455048153361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13065469403454569,
                                   0,
                                   0,
                                   -0.38431346309185505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16250271804926153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.001529363605004691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45630683342171596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46977465112014916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70543474200317491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34286486441574165,
                                   -0.10948272019185215,
                                   -0.47087087597312105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32339934693229877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38644980333442058,
                                   0,
                                   0,
                                   -0.75773849521251091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45545731638494907,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36608840526845932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.049655065272729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1484691558385135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044627615067026838,
                                   0,
                                   0,
                                   0.42863630188705654,
                                   0,
                                   0,
                                   0.59291475476863931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34421018435239203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15555274001811431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21000124376011764,
                                   0,
                                   0,
                                   0,
                                   0.19753379396730134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39236044646667634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13663458020980468,
                                   0,
                                   0,
                                   0.39704963224646789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24058739384715455,
                                   -0.23743408641137764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6872834200417004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41555481116950294,
                                   0,
                                   0,
                                   0,
                                   0.26399893405014874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34791755869125029,
                                   0,
                                   0,
                                   0.20606029823544739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099799714668454859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89242675298621321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51794725772681216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3687901329546574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29072500918465555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19779435122634192,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10034876363312768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10565622090778094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19403008770416186,
                                   0,
                                   0,
                                   -0.046537372909564112,
                                   0,
                                   0,
                                   0,
                                   -0.27961028930440707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27542604203206306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50557717289701787,
                                   0,
                                   0,
                                   0,
                                   -0.037210617385246281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32481728484159861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1902338185040621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29281168964379578,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22487910675907596,
                                   0,
                                   0.045041660478640708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20944126932520846,
                                   -0.25921619064357304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75098805355544973,
                                   0.051154221642868043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20568978237824251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34958291420841747,
                                   0,
                                   0,
                                   0,
                                   -0.68160389621075279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067516518008456441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11160585384920141,
                                   0,
                                   0,
                                   0.017668293944154354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1479093414962554,
                                   0.3970852348561742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46511024746069274,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032814078695083154,
                                   0.027762658642103782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036020983842772622,
                                   0,
                                   0,
                                   -0.3594987477019338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5927410859081863,
                                   0,
                                   0,
                                   0.098775658768769786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.037766078883222878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10960744483120519,
                                   0,
                                   0,
                                   0,
                                   0.93103789830560524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26978406581533831,
                                   -0.3035114283661059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80971478374652195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50823074561726833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053159751725914806,
                                   0,
                                   0.23815042746105916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28068659091573145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0031121410189154097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19099352870587699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31232049081609875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00099468012660750005,
                                   0,
                                   -0.16317338961329303,
                                   0,
                                   0,
                                   0,
                                   0.14515587383591555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46205842803069574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41708320234509055,
                                   -0.12844450005466923,
                                   0,
                                   0.13300943128470405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14781628036228675,
                                   -0.86023434609809057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2896833796311733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10517169588409336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10286481498570707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054068924186074792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039725762772769263,
                                   0,
                                   0,
                                   -0.61245559183337628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66898136305089217,
                                   -0.37005910437114392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3304270897297662,
                                   0,
                                   0,
                                   0,
                                   0.3746284647750211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21931682492782245,
                                   0.38016125294847569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28200217860451893,
                                   0.1741639869519219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34409361952799294,
                                   0,
                                   0,
                                   0.82704194342709336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4076765852812404,
                                   0,
                                   0,
                                   -0.27965514551592285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76118532847791154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35436880650490837,
                                   0,
                                   0,
                                   0,
                                   0.33733047607093453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26200000070073759,
                                   -0.069134289489015954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12801528470412626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1168411986785179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067397623037899673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36770087893262848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10443885921247832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046893094694691051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30461227981357164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017358119196626276,
                                   0,
                                   0,
                                   0.7409002387555923,
                                   0,
                                   0,
                                   0,
                                   -0.37181283155590233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14338317173768175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088486332322385633,
                                   0,
                                   0,
                                   0,
                                   0.15760350545063845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22406352852863357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43902663333624753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17911486080732625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69937132904308441,
                                   0,
                                   0,
                                   0.42375071124611535,
                                   0,
                                   0,
                                   -1.0532734360934071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26904960590995525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18552357276802142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14585820739301525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1774899378464786,
                                   0,
                                   -0.11514687297740277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22022234475071087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36377065887463228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17373873963731379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48752225452643383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28912930217838312,
                                   0,
                                   -0.2595456892920448,
                                   0,
                                   0,
                                   0,
                                   -0.13232516007059705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13115769688268181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21168909249984741,
                                   -0.033894965858101825,
                                   0,
                                   -0.50362752407561828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16756931631478755,
                                   -0.47478632135006543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17810630921329654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33813382383531404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22734532764854637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26954706431053232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8298186877944369,
                                   0,
                                   0,
                                   0.28048593859940013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055460227889647801,
                                   -0.0040707137320172837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69866330774123975,
                                   0,
                                   0,
                                   0,
                                   -0.54365116270448599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.039442557162092884,
                                   -0.20092790647654396,
                                   -0.48500706843587443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47913451686790676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67436671880951071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31695304450528161,
                                   -0.97412287446224455,
                                   0.42957634168442882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25911726107408084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59986384819403649,
                                   0,
                                   0,
                                   -0.81702463891943233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12108080963897377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33590619148241629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78794533370255437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19357464899298971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39357982549669851,
                                   0.68771999834313446,
                                   0.68216276514550256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59561778579394797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26309895434827957,
                                   0,
                                   0,
                                   -0.20046042248317975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28945370973085349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51794406560732464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21797919391272785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17132292613575933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86471968128081156,
                                   -0.23484453363090924,
                                   -0.40718855734036047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12654725220011176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53157646867767261,
                                   0,
                                   0,
                                   0.83041292770015618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014844346132040449,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57331026970272037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21627718505227006,
                                   0,
                                   -0.22261239699179636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044123587415964963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1673746267944014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19440834345793453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082909863518611265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23325409501285144,
                                   0,
                                   0.2850247816659911,
                                   0,
                                   0,
                                   0,
                                   -0.29069705362721343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47915813235194182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019202134361818446,
                                   -0.14530586096453368,
                                   0,
                                   0.17066640402793878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69417387487226778,
                                   0,
                                   0,
                                   0,
                                   0.55180503777227652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33360496287036628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2197707958306846,
                                   0,
                                   0,
                                   -0.17553705182865009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06889084616630943,
                                   0.11526191736770991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072096067414816334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3016424991867851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11409388907438939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4703650623581897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0980841881322572,
                                   0,
                                   0,
                                   0.41664173587891917,
                                   0,
                                   0,
                                   -0.59529800729503368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86555376655579497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33158411282259498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0014977551539861,
                                   0,
                                   0,
                                   0,
                                   0.26578944577805957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6898766250999363,
                                   0,
                                   0,
                                   0.20754917471870099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60272728075006743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26519042000366033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10996389727407663,
                                   0.055366870086155845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048713115604478108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21983542241060072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057156402805556394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67854970851298502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036462614497950047,
                                   0,
                                   0,
                                   0.4218950750645194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5948565465934883,
                                   -0.0010459913858780479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40358968888024316,
                                   0,
                                   0,
                                   0,
                                   -0.35058057111943802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32189579003810198,
                                   0.51465966117004902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79042468562862522,
                                   0,
                                   0,
                                   -0.36009681129581,
                                   -0.034639203462850363,
                                   0,
                                   0,
                                   -0.47896701969214561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084436875381398852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088432101354586706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10181684332619556,
                                   0,
                                   0,
                                   0,
                                   0.34700969376557445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0271826003065911,
                                   0,
                                   0,
                                   0.23951068827181132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.99386369989271717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38531425501593619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10064812741743134,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51618274700964362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35189797145778756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20228783355352031,
                                   0,
                                   -0.2402817919026777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43390606235893303,
                                   -0.20299154809236586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4328667951432138,
                                   -0.27706746044426755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085541552322447117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25316557865500655,
                                   0,
                                   0,
                                   -0.40137979977570626,
                                   0.6171230671804776,
                                   0,
                                   0,
                                   -0.30091872489494731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35128687463767572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42427116185871461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32350152774690699,
                                   0,
                                   0,
                                   -0.50822637379112556,
                                   -0.66933957923585974,
                                   0,
                                   0,
                                   -0.13630050476787836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19454970433137411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36415632239671125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060495336532329608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50401935334085024,
                                   0,
                                   -0.018996390545600858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043380418076120579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.004207065773195625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08867862886149705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26016579014067281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42771367860493165,
                                   0,
                                   0.67291953728878195,
                                   0,
                                   0,
                                   0,
                                   0.11602935563827226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061869869331208277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082691742240119243,
                                   -0.00062009716682984856,
                                   0,
                                   0.067864201343481284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11433379464562098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32959795518059193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14566311124113263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18173889603517471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29389868186124973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038189755850886388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49183918096942325,
                                   0,
                                   0,
                                   0.15626052240027635,
                                   0,
                                   0,
                                   0,
                                   0.21125697980502914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26435933826552066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14620479826415536,
                                   0,
                                   0,
                                   0,
                                   -0.57792470556723541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15065836086924078,
                                   0,
                                   0,
                                   0.26163993087322857,
                                   -0.40682336308271566,
                                   0,
                                   0,
                                   -0.097176388593083196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84082216193271475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16406156657095647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018115213432802965,
                                   -0.30950830240294125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37363714343692916,
                                   0,
                                   0,
                                   1.005404702544302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75730569459372887,
                                   0,
                                   0,
                                   0.2701993252789045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26230838019536901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11024921492665227,
                                   0,
                                   0,
                                   0,
                                   0.51765874800158318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17641211618421274,
                                   -0.23265833841661504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40098537675325402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5144946929424562,
                                   0.23916850137064433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32076997270481794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081566065534126958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31078370982069697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48363827396554376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47636388015919406,
                                   0,
                                   0,
                                   0.33162387126348492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31909287136920089,
                                   0.43575722209543571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19454971904938884,
                                   0,
                                   0,
                                   0,
                                   -0.04518083530353742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71435082838775876,
                                   -0.22549815701607381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28535577924370253,
                                   0,
                                   0,
                                   0,
                                   0.39381472595479383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46873722417761532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0020813534861258004,
                                   0,
                                   0,
                                   -0.26289578075549608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028040752207430904,
                                   0.55885164008212473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40192971097620617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23638000788563707,
                                   -0.36415789231355328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29907479742737542,
                                   0,
                                   0,
                                   0.060174594535797786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4232775438731109,
                                   0,
                                   0,
                                   -0.28322579790438102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32700972510979182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10758549447381362,
                                   0,
                                   0,
                                   0,
                                   0.28348027408535087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37892087238384869,
                                   0.56333037553173448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57160833209738682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3506634298659696,
                                   0,
                                   0,
                                   0,
                                   -0.44838514237011173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059026345588929052,
                                   0,
                                   0,
                                   0.69723152502843977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3280513764086053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30781245302665666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3049332078956789,
                                   0,
                                   0,
                                   0,
                                   0.14774083173417613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5177430599526468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017680954633022619,
                                   0,
                                   0,
                                   0.76684574429396013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16634159447461727,
                                   0.0093311419085380098,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03176320625566828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.474465541910286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24901636062347535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39658159730343856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064230703201542033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45055377930653795,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17434782232452445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093602517837872268,
                                   0,
                                   0,
                                   0.13575670475513468,
                                   0,
                                   0,
                                   0,
                                   0.1090202801768974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14402841000196814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45697863364463903,
                                   0,
                                   0,
                                   0,
                                   0.22231620209640646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040372728793497681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42961173720222401,
                                   0,
                                   0.24876489539354199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62682750130650033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026281554375218976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40226980141022378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27644186097144563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11247173658176114,
                                   0,
                                   -0.21472699688362459,
                                   0,
                                   0,
                                   0,
                                   -0.17974430905940739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.015647696084657547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10040063677997405,
                                   -0.10858707806019413,
                                   0,
                                   0.083026559541748257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52235830646641734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27535264064166637,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075366553604415548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26149830941186086,
                                   0,
                                   0.085529713043656641,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52734727397689884,
                                   -0.22791047883283524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12872608766532379,
                                   0.47064503813363739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042783368477504281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14278010426723844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049714682188615841,
                                   0,
                                   0.17511783210913351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1009901015332595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087772166573220345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15060449445792295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28102332758511872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34796377544387092,
                                   0,
                                   -0.35029554729815304,
                                   0,
                                   0,
                                   0,
                                   0.17694622869727461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16007511719481918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5698881368142934,
                                   -0.23772256457533686,
                                   0,
                                   0.38067437815539351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10379598806243003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11929161741994303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035964374163996574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10482239822311362,
                                   0,
                                   -0.28531665242885884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079271470835126617,
                                   -0.20342556814826612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30348291630902302,
                                   0.16941132432795356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84429919707247558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59303692315338219,
                                   0.35462666385900482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31971627788277596,
                                   0,
                                   0,
                                   0.027189775913280707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53109427098087636,
                                   0,
                                   0,
                                   -0.76854794613636734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16005717398034228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41310018229720119,
                                   0,
                                   0,
                                   0,
                                   -0.78169369940850453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57433301258501446,
                                   0.093935383113659426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65294972462699585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39404479864783626,
                                   0,
                                   0,
                                   0.28747663053562844,
                                   -0.057826592981070457,
                                   0,
                                   0,
                                   -0.78083809913898783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062747970851585511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38091537614762977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037984385296889647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30104614104426425,
                                   0,
                                   0.19013453717820111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44185689396029493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15476337050883998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31733562962200712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14521603332413086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1585926426314348,
                                   0,
                                   -0.04509570692520716,
                                   0,
                                   0,
                                   0,
                                   -0.41467288403762537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064109702487183534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44582811277509032,
                                   0.32382002428675455,
                                   0,
                                   -0.15468494883428496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0746301963424343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30887742571885601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.084864838217778182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42013510790183778,
                                   0,
                                   0,
                                   -0.1334378279435767,
                                   0,
                                   0,
                                   -0.73677451535502181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43201198837984994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60658830105904771,
                                   0,
                                   0,
                                   0.2868920292584306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35491996927350877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014204469187671463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24899362430104097,
                                   -0.17787765638109082,
                                   0.44140729782916505,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23042713876411941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29135923741241249,
                                   0,
                                   0,
                                   0.33484223262746565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2195881216559969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41414778499184735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30092226845719944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32272811075596908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10144547579455668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27885289513419442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55543657116665623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043473466440574884,
                                   0,
                                   0,
                                   -0.010729206448068324,
                                   0,
                                   0,
                                   0,
                                   0.14866103720046239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11977225026412716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030188773521808848,
                                   0,
                                   0,
                                   0,
                                   0.44480573812683494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43729063239546284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25871297450168285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1456925640972064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49126603210264175,
                                   0,
                                   0,
                                   -0.16395867030729944,
                                   0,
                                   0,
                                   -0.57436696283898125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73485615957562378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50695993188146793,
                                   0,
                                   0,
                                   0,
                                   0.075385823863716589,
                                   0.69270044137208431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044161320980219354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43737648298190629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30166232772652302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39476928250932075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2138114749264613,
                                   0,
                                   0,
                                   -0.8314165569142028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18395650848305051,
                                   -0.13331523707686566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38108468329469719,
                                   0,
                                   0,
                                   0,
                                   0.27488711649317771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13983644912918611,
                                   -0.19813728610113807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047840028941947381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26629462625211664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082122840132926395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38249193743569154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43831030635129975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047303813701791195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.028469325400094322,
                                   0,
                                   0,
                                   0.12573730087433277,
                                   0,
                                   0,
                                   0,
                                   -0.15087676634798111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72956540766335731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040332401638810522,
                                   0,
                                   0,
                                   0,
                                   -0.078256811309243376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16016678811476387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5655948343171695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65870026973936746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.091066966941542649,
                                   0,
                                   0,
                                   1.4159942854006298,
                                   0,
                                   0,
                                   0.31844162889739613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045743996834143569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49618708608564488,
                                   0,
                                   0,
                                   0,
                                   0.34193014156855295,
                                   0.56091613976701205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93967318495596608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39796426998038836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56921772849761298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10040406286463366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32507179990114621,
                                   0,
                                   0,
                                   0.38714327627380579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3512089753776696,
                                   0.078802649278005843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27125727630206009,
                                   0,
                                   0,
                                   0,
                                   -0.00037390493857446423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45312404303780673,
                                   0.19158441211836075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33044395464396048,
                                   0.32019560905842159,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49024655298181558,
                                   0,
                                   0,
                                   0.029839317834106302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49671045892640042,
                                   0,
                                   0,
                                   -0.67644312100114234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071272133735570634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14692410751308449,
                                   0,
                                   0,
                                   0,
                                   0.5575796755871385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97591580412069112,
                                   -0.13918226425184285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7725131947600663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070348964390085825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16717117564005524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0083050146955161164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24496401484171137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41331145292118876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032398104302837037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77425934516174522,
                                   0,
                                   0,
                                   0.037712952620300687,
                                   0,
                                   0,
                                   0,
                                   0.10705406026585815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20391282589118725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099121136806119364,
                                   0,
                                   0,
                                   0,
                                   0.26718284492075928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40278559474632869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81273219228398541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2175318615877497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34211856459051149,
                                   0.68059007810054895,
                                   0.42820124105646618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68720720615741726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63567728415548941,
                                   0,
                                   0,
                                   0.16416491296129798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28963611966722458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58492303267597412,
                                   0,
                                   0,
                                   0,
                                   -0.017983995796736985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25965685307823771,
                                   0,
                                   0,
                                   -1.3656890097216745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55263655039361836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034842283934533758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1871650740696877,
                                   0.051106436220922952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36321705815956662,
                                   0,
                                   0,
                                   0.13306453182302164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088030820376472169,
                                   0,
                                   0,
                                   -0.58567821718938118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26395296782309408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.070790497007913525,
                                   0,
                                   0,
                                   0,
                                   -0.31535450976542878,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29194332426092628,
                                   0.19427544355683696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5073175587207831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42680448946925681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25639639351095744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84551383247547129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33972867968847298,
                                   0.28810227144150463,
                                   0.025372731343012052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90609625121472903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48788282971286012,
                                   0,
                                   0,
                                   -0.59276403744733164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46274785441145622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61015973265632328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13140549181445504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19965708560442136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23338932486997546,
                                   0,
                                   0.16700527477019256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10094815486272388,
                                   -0.05916308513125787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0065937441765032967,
                                   -0.63355734096614591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27034094104033085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19978025681450876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55912025871016124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45162997199756993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2115130626346215,
                                   0,
                                   0.29866690702026888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067508800494628651,
                                   0.46858024856188202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0043671736583166809,
                                   -0.078000195684022777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28166481222780348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15445658744403765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29413355757166426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078535887505025603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40863497020217082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39800509298568132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26255180566172726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31773634462982636,
                                   0,
                                   0,
                                   -0.17002769514097149,
                                   0,
                                   0,
                                   0,
                                   -0.43736211893852595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027786371048569541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36142453126812524,
                                   0,
                                   0,
                                   0,
                                   0.19127332431306257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16885947600700876,
                                   0,
                                   0,
                                   -0.54756938307237446,
                                   -0.03308488476406439,
                                   0,
                                   0,
                                   0.20569224557056776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34741782119588899,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71242627415906312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1041397630095441,
                                   0,
                                   0,
                                   0,
                                   0.092762153599978775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38436441740127414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61638003581241985,
                                   0,
                                   0,
                                   0.20286100291896597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3654707987551104,
                                   0.47706312315442789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2248978078719876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12715135162779623,
                                   0,
                                   0,
                                   0,
                                   -0.064970035644878299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063760560890178966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.046884153129470127,
                                   0,
                                   0,
                                   0.17586788037478607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8530550927130528,
                                   0.38710947948178737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2546794920129497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29282697823496145,
                                   0.040291944720521972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28918394447999879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63660072528832512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0008917782747617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018394961193803586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23709173824711474,
                                   0,
                                   0,
                                   0.26923438570657138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15559530252103052,
                                   -0.15014211266264321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11522798875531165,
                                   0,
                                   0,
                                   0,
                                   0.64336083775772313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23691148114476626,
                                   0.29187518612406999,
                                   0,
                                   0.84942758258728168,
                                   -0.29458366567120242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28825744602947201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71616642461431823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17969487224788627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30342954658787868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71119806285210174,
                                   0,
                                   0,
                                   0.18238892730363582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2008822705130649,
                                   -0.045291133546339971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14455937834682392,
                                   0,
                                   0,
                                   0,
                                   0.2666345122271277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35024836443264029,
                                   -0.32145768435274358,
                                   0,
                                   0,
                                   0,
                                   -0.18912855820072788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2818781091401027,
                                   0,
                                   0.011219411216990282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14444369731925127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62405659547787939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51675104390587712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015819895279423742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32642218725671251,
                                   0,
                                   -0.091443464211968084,
                                   0,
                                   0,
                                   0,
                                   -0.14857439465648845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18187861437825809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065879551627918295,
                                   -0.0092733111776851646,
                                   0,
                                   0.18045242069355036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91211322755262503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063481727336208743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86681022773682004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61240979748232527,
                                   0,
                                   0,
                                   0.23586770551053235,
                                   0,
                                   0,
                                   0.2097503615497317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70112495799177388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4828210829600057,
                                   0,
                                   0,
                                   0.11646884474000758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35851404395626552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047512693027865704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23470717596381363,
                                   0.59139296826783105,
                                   -0.68687342903663295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16552972090759649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1597754018143833,
                                   0,
                                   0,
                                   -0.17766976451983202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52899272503457384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39469858223021592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1881442807024952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45837814540565436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067733738888454464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14486065716834162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55786382617406893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080191563161217921,
                                   0,
                                   0,
                                   0.48790182497438828,
                                   0,
                                   0,
                                   0,
                                   -0.10089701252078456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.007595164573290375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082172514292640844,
                                   0,
                                   0,
                                   0,
                                   0.021227890262077165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12145425946324176,
                                   -1.0865511568248321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33926177412482328,
                                   0,
                                   0,
                                   -0.047040509895641569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70508691701508031,
                                   0,
                                   0,
                                   0.48921602611836862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0079562124829508085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22511910008678715,
                                   0,
                                   0,
                                   0,
                                   0.18181634156550627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18918403014830548,
                                   0.19813564619902674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045174040277204432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14616268300813925,
                                   -0.080922403084658173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57458954452939093,
                                   0,
                                   0,
                                   -0.13306464671058743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76332943683507803,
                                   0,
                                   0,
                                   -0.028878264462405358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2591650272823123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34627821174507684,
                                   0,
                                   0,
                                   0,
                                   -0.20879434050220186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1635849986565738,
                                   0.21686379202996964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15458641306380161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11745730879649321,
                                   0.066627397801974686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57552032273317977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31624302847146341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0264894674544016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48937693803970816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19431964304663241,
                                   0,
                                   0,
                                   -0.4512369754247616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48329219529606388,
                                   -0.24016218154552013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072819916007938232,
                                   0,
                                   0,
                                   0,
                                   -0.49626417625903424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0066171145927392564,
                                   -0.14218783200006091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23886343529005585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32998885164295111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37730053149841347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18684064264662065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037904170941879145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33640589714648045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022993025887789273,
                                   0,
                                   0,
                                   -0.11530203011932838,
                                   0,
                                   0,
                                   0,
                                   -0.51138861600591734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040750125467322096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24044504090444918,
                                   0,
                                   0,
                                   0,
                                   -0.45537336555708119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14570393449240809,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10634026281311854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72448080424608774,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075731545299709102,
                                   0,
                                   0.30325684493064198,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30862922389382164,
                                   0.39199908142720175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14158083569670937,
                                   -0.12227624328625819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24693684398362542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1926722460267406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43465176941348926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048768780131077216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51113436866664796,
                                   0,
                                   -0.46347966504482146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46052396969204762,
                                   -0.081056487297820765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20424570583073082,
                                   -0.17284001068143381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072544123554654699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031411431521499444,
                                   -0.37412416679342131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64271380558590552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5680215705295012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43523161119587594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27298146824394443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21655196203877697,
                                   0,
                                   0,
                                   0.60061443492326072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055748147899727124,
                                   -0.050508619356065758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4876437276098099,
                                   0,
                                   0,
                                   0,
                                   0.74280264504306392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49220377006529575,
                                   -0.2422252594852092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03369495506249745,
                                   -0.56958425614282759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48166977240484454,
                                   0,
                                   0,
                                   -0.15383474384522544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15460096573143156,
                                   0,
                                   0,
                                   -0.90859833458255546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35481342671692773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28211828365819591,
                                   0,
                                   0,
                                   0,
                                   0.013141006810641209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47538718457106244,
                                   -0.90902651644798016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27496295484281541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38780040829245294,
                                   0,
                                   0,
                                   0,
                                   0.046523271464839339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30104593112121314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7335778770011806,
                                   0,
                                   0,
                                   0.28631709593338894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16052064711861186,
                                   0.28778092859607213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16768736932607872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31199279534089541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050899914963169993,
                                   0,
                                   0.56329375878237908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20441710389624115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0021878925776991562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24124813042383797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14926803440222289,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23554950369109254,
                                   0,
                                   0.044964435573936701,
                                   0,
                                   0,
                                   0,
                                   -0.17929803670881067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37368679522885995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27240009749559951,
                                   -0.39376844343711964,
                                   0,
                                   0.044121578034124004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075744346903424645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44012074476536905,
                                   0,
                                   -0.53825813402523537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032009660787897978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27120457159842321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23381362616604318,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32021207993847545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21003422888228812,
                                   0,
                                   -0.32716063625308167,
                                   0,
                                   0,
                                   0,
                                   -0.19300393597757334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099715473451837455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18606109569706006,
                                   0.049574572271626524,
                                   0,
                                   0.20889005582786768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33504565049442603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1278837281411479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086480454180733177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16611839987334351,
                                   0,
                                   -0.5232780734661272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10270513059807737,
                                   0.6404957578869378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27558235475976517,
                                   0.2481998068309034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.064529777398583371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4172344955592972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23448728446435743,
                                   0,
                                   -0.039204596258048986,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10210678669344998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37566281690291253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23157153486756843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22500254937406053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24276460236832009,
                                   0,
                                   0.088059349050888969,
                                   0,
                                   0,
                                   0,
                                   0.11343973729038463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13782910001848861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08274405258952286,
                                   0.23339306206814298,
                                   0,
                                   0.59474429993645095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58505666047054738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022214169504346182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40366188651441298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0084836864428403935,
                                   0,
                                   0,
                                   -0.58343455371721842,
                                   0,
                                   0,
                                   -0.15813449065989688,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65725221036589321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3497295706810941,
                                   0,
                                   0,
                                   0,
                                   -0.35287712097021851,
                                   0.34191035669473008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.047635338625246826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32941397283708257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11136578006970554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2984308850961746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41915861885663136,
                                   0,
                                   0,
                                   -0.01719404805184984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25000687125776089,
                                   -1.1474429124258239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37683075855916859,
                                   0,
                                   0,
                                   0,
                                   0.3900362770945407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042600947261026111,
                                   -0.086660422658681541,
                                   0,
                                   0.16606085120443304,
                                   -0.014142120263197694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34137167437219357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38084012375179943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093337386377571913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39585740585768447,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1691351509732483,
                                   0,
                                   0,
                                   0.17911974274433418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56444941828992934,
                                   0.086451914268590779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84488540174667492,
                                   0,
                                   0,
                                   0,
                                   0.30659562748037833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49822934738737895,
                                   -0.72974353310514473,
                                   -0.44353402020083255,
                                   0,
                                   -0.17165079353900956,
                                   0,
                                   0,
                                   0.42789009367714315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046324526758778781,
                                   0,
                                   0,
                                   0.73188266899564924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58856032750343068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049493136702626589,
                                   -0.00037259430103414977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66599385299354208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13561983475086067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28429830421668884,
                                   0,
                                   0,
                                   0.20930015654937514,
                                   0,
                                   0.48786804998724548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20397440534020253,
                                   0,
                                   0,
                                   0,
                                   -0.79438118943606262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13739782757813135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11907348637339633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2615947308908052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3330875425246016,
                                   0,
                                   0,
                                   -0.39562956597672327,
                                   0.27723141657342609,
                                   0,
                                   -0.24131861510246333,
                                   0,
                                   0,
                                   0.41277687344663089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24294196129117565,
                                   0,
                                   0,
                                   0.58156785480992312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065109956368249955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067060199314855143,
                                   -0.27428512201431043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035798733208983011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93670642604321808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010463331085079158,
                                   0,
                                   0,
                                   0.695936707760477,
                                   0,
                                   -0.3670089103792526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65384331806465334,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42180717738902085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070550959139948313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024432901900004356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29966849635799037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21342128614494973,
                                   0,
                                   0,
                                   -0.4735261510514554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035219553177875951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.4377514833272569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29366857497871157,
                                   0,
                                   0,
                                   0,
                                   0.33559282287693282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51685981771296097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2457762316275958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26684481050245185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70566470220876454,
                                   0,
                                   0.33158851427073199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47837892128710402,
                                   0,
                                   -0.35896954838661427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42467796540167929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47799043811065578,
                                   0,
                                   -0.21493429349409188,
                                   0,
                                   0,
                                   0.20264707903333298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47094769455033048,
                                   0,
                                   0,
                                   0.4138714776059994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030306984649710746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3306942507347117,
                                   -0.32380870614692103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13675075635968106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074857469481563577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41847105205343055,
                                   0,
                                   0,
                                   -0.085044322596023375,
                                   0,
                                   -0.023161950477942311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.80982722051603895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27684332150027813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91059675548506869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055872495417601531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43586730249478861,
                                   0,
                                   -0.28504472560654526,
                                   0,
                                   -0.66402404583635344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10431203705025321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38707483729111969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67753222494053233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.02403417705015351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59601123034607939,
                                   0,
                                   -0.10554895290835702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23677353885053304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062251323916426321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4597274536441468,
                                   0,
                                   0.25136716794482572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094296459688344048,
                                   0,
                                   0.7647472133125679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085388896387530236,
                                   0,
                                   0.25398207222306807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28189163655607907,
                                   0,
                                   0,
                                   0,
                                   0.83412683188186043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25803979008152439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090843520163709279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95881190952613027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3756712449802363,
                                   0,
                                   -0.69077771427287515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41603854372496873,
                                   0,
                                   0.31474303907095147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53845562158097326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39323847318733884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21440333208646761,
                                   0,
                                   0,
                                   -0.010603396052004624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52282900053338843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0076145440178615187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16306722898770443,
                                   0,
                                   0,
                                   0.34652502062927087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036954173477975319,
                                   0,
                                   0.42354090285347124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4454785279776311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67511070097461401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29164869734759774,
                                   0,
                                   0,
                                   0,
                                   -0.086324969809943669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42206636888247584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21547820515530042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29867379742171513,
                                   0,
                                   0,
                                   0.28266095548652664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069677320807533569,
                                   0,
                                   0,
                                   0,
                                   0.091452998858965975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11116273781301581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16419949560953728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074183825859458069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96927677960152969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062917266783752909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49988137786895293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1306352147739207,
                                   0,
                                   0,
                                   -0.16771290243650244,
                                   0,
                                   0,
                                   0,
                                   -0.7082855100359785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11458121550079553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10246024495575977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40788534196063925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96121159063924289,
                                   0,
                                   -0.38711526512961592,
                                   0,
                                   0.15741142907881245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21415064319995458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4172640650812432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54814783815393764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1362066822735829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19460283418084906,
                                   0,
                                   0.10933448140302229,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59572205071015705,
                                   0,
                                   0.018077568018182624,
                                   0,
                                   0,
                                   0.62878431721332739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57151973516235532,
                                   0,
                                   0,
                                   -0.25020260253016302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34027330388425875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2296715450574506,
                                   -0.60564558572253646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53424842273764406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022000454380800474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018012255906494204,
                                   0,
                                   0,
                                   -0.38255726297970255,
                                   0,
                                   -0.047896764510485954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083491341755451587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57123636670251432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13029866165226744,
                                   0,
                                   0,
                                   -0.21013925379546611,
                                   0,
                                   0,
                                   0.18804687256232303,
                                   0,
                                   -0.37354198028670405,
                                   0,
                                   0,
                                   0,
                                   0.0012058636793246813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28597236447117513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10350092387410965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060214929101040371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39399455157359664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25704472750764712,
                                   0,
                                   0,
                                   0,
                                   -0.068988080476609023,
                                   0,
                                   0.2232635473867752,
                                   -0.25617950171475512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24932904486104018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49410364008212726,
                                   0,
                                   0,
                                   -0.11169383919539053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014525337776209679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096248874615257066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69636036390804745,
                                   0,
                                   0,
                                   -0.072989588584523965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29499018457806381,
                                   0,
                                   0.3045737126797215,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041432877199814158,
                                   0,
                                   -0.2935096847723635,
                                   0,
                                   0.47338729214701958,
                                   0,
                                   0,
                                   -0.19150655517651771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10449240756328068,
                                   0,
                                   0,
                                   0.75032457097556648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082652348093931224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15796655113763708,
                                   -0.21120971316309892,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22554037732143734,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06799990603188992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5191114291272233,
                                   0,
                                   0,
                                   -0.2269793579423765,
                                   0,
                                   -0.01509287258480959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68191558429753429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0095810288332434032,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58089261839903661,
                                   0,
                                   0,
                                   0,
                                   0.21122271283957345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29964856323898315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13863835422535298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022829149310010573,
                                   0,
                                   0,
                                   0.19910779873995982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20907078367814202,
                                   0,
                                   0,
                                   0,
                                   0.19851674758995988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41488117212136988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0861637769258667,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4538853599417948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0545391653947895,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069252118488182551,
                                   0,
                                   0,
                                   0.64088741541226613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0082946707648887674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13275773195523946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070637532779700765,
                                   0,
                                   0,
                                   0.080985418897803849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14056941190154509,
                                   0,
                                   0.44753389245504199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57637217469491941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17424986617898963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63525534522601101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8165716187839277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54944793351191423,
                                   0,
                                   0,
                                   -0.72516237170472175,
                                   0,
                                   0,
                                   0,
                                   0.43465660179408216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26392333634342841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96795479387630823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24753272700337467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86185551157583251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06589750693738422,
                                   0,
                                   0,
                                   0.24506113029992013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054915891034947928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23240704491443862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49235356675011704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068938695630140184,
                                   0,
                                   0,
                                   0,
                                   0.0062511937386075253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3219974145817569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11681509408858871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06194553910114968,
                                   0,
                                   0,
                                   0.22388254497671278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080605978468489381,
                                   0,
                                   0,
                                   0,
                                   -0.11127423158115181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24348759505821621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6560042647840828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.270186077407915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46353564899311028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18620189580734597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33280748097944646,
                                   0,
                                   0.13919288862670928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6856144154017314,
                                   0,
                                   0.32522880695446255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10718246587191001,
                                   0,
                                   0.18165652204121202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33564829953553643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21058752579856244,
                                   0,
                                   0,
                                   0.04242849195577536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.093584332205140036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44847823981776458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28443696384367201,
                                   0,
                                   0,
                                   -0.13489009885387743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69660918314205111,
                                   0,
                                   -0.2117088712552902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04601577846281589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22645333523907324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87741257728747923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38070209333888055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4092538642300359,
                                   0,
                                   -0.39564359144304356,
                                   0,
                                   0.62374080440164037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16357871684382649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40748146494631826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58219206057453632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18967658244991376,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10090201923310005,
                                   0,
                                   0.32560129294197154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10298464294811535,
                                   0,
                                   0,
                                   0,
                                   0.60486601534594031,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014997659079259824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31363890170436642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058468577583842475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0557878043840478,
                                   0,
                                   -0.15040893074918191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67793089215235958,
                                   0,
                                   0.28660750126406626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24734726959212078,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04812882760138408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20199896722601038,
                                   0,
                                   0,
                                   0,
                                   -0.12731709603383115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19478302087290211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19526487081744454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47960219665304027,
                                   0,
                                   0,
                                   -0.3069463856976537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29727351766817045,
                                   0,
                                   0,
                                   0,
                                   0.60069941677190664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11173406183529606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2647225590544664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092700469601692065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28721901698968372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15686162233931913,
                                   0,
                                   0,
                                   0.49171294767782336,
                                   0,
                                   0,
                                   -0.023029230165251671,
                                   0,
                                   0.070391513204794101,
                                   0,
                                   0,
                                   0,
                                   0.099805059270478669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27312389486868677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087802097531486517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10190672546733037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44022543743079201,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13055600717798796,
                                   0,
                                   0,
                                   0,
                                   0.44654037380819389,
                                   0,
                                   0.03695287290948962,
                                   0.36245510945527165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076391831371609251,
                                   0,
                                   -0.17179655747805353,
                                   0,
                                   0,
                                   0.60097415470095561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29612627089800575,
                                   0,
                                   0,
                                   -0.13686454769698506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31055529796297487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089477960894960795,
                                   0.77739864423027716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18943192273378784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26835320135723278,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.117318045019839,
                                   0,
                                   0,
                                   -0.27982965647164537,
                                   0,
                                   -0.43296607555202532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36565979182770075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18013856750337154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50721371084788469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63225079457948641,
                                   0,
                                   -0.27101832924795138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14311414051267052,
                                   0,
                                   0.34856242400145443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.286537030013298,
                                   0,
                                   0.11406776837380744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10232815031753928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52390470930180533,
                                   0,
                                   0,
                                   0.29942059125794224,
                                   0,
                                   0,
                                   0.23715310123367994,
                                   0,
                                   -0.19338275174153424,
                                   0,
                                   0,
                                   0,
                                   -0.088465038137411231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31022973407432974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10253979248446646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57090777058373177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.017840393561569745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18043072521219949,
                                   0,
                                   0,
                                   0,
                                   0.21231096691174312,
                                   0,
                                   0.10870700437221936,
                                   0.038422708300001454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077359664749075491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24070559325103069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1364844202631616,
                                   0,
                                   0.5419866871961595,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19150463286589742,
                                   0,
                                   -0.3505359406370101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10328689074309245,
                                   0,
                                   0.67341003978882585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14313947846049674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35809713666094645,
                                   0,
                                   0,
                                   0,
                                   0.11270646594948362,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47124295328515264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052259550181465553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23213441899188875,
                                   0,
                                   0,
                                   0.4710086692300951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080566799912907439,
                                   0,
                                   0,
                                   0,
                                   -0.31366891274073261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45440419437483248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018456249581326974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16228137692158345,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015956193312318841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.068718162199845348,
                                   0,
                                   0,
                                   0.1994511701148998,
                                   0,
                                   0,
                                   0.35793022047272777,
                                   0,
                                   0.18835674260476601,
                                   0,
                                   0,
                                   0,
                                   0.19082999469250489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018902152773054421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26766156588651413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31472926526438649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18899754834409915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26740590277816284,
                                   0,
                                   0,
                                   0,
                                   -0.057927234066334862,
                                   0,
                                   0.64134697047872968,
                                   -0.24954367548855197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69850926012124992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39842655760391965,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54800391290272532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010666152062896825,
                                   0,
                                   0.59692941658141174,
                                   0,
                                   0.1131393341339751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25447433038055928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85096912020742599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45443840951918779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14500941009863055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28937386206876031,
                                   0,
                                   0.77694963816793661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12141096253030428,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44789244901060898,
                                   0,
                                   0,
                                   0.21741563822451748,
                                   0,
                                   0,
                                   0.10522842649667258,
                                   0,
                                   -0.0075441533117933945,
                                   0,
                                   0,
                                   0,
                                   0.38962433829162357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44629402086384906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10661251638354631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13930687686798096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1313305788682545,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29610819575558078,
                                   0,
                                   0,
                                   0,
                                   -0.21875509179513236,
                                   0,
                                   -0.42984523165985633,
                                   0.0833404224440598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33919448530096019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0077984541498692383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51723020470700565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020453477468928546,
                                   0,
                                   0.44708556120764703,
                                   0,
                                   0.19936655648716436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36170959441934813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74662627007619009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24124836012221679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3286976538703042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48478309723847751,
                                   0,
                                   -0.68005532343544906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027613966159274916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72519161222207951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19750584380668751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.88862461714778562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054210764871138295,
                                   0,
                                   0,
                                   0.59128484241310675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85805454427386174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076341653457189462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3626624301384872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25934706001222851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36927995273605696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14139091121742109,
                                   0,
                                   -0.13627426013686672,
                                   0,
                                   0.3205225980950529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66114072475511299,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27843906624518949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27575798197407475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9994774130304146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28331425295265866,
                                   0,
                                   -0.24569116781126654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043661905628960877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33317927386908724,
                                   0,
                                   0,
                                   0.0413256689959145,
                                   0,
                                   0,
                                   0.24302645214468127,
                                   0,
                                   -0.49230144930669756,
                                   0,
                                   0,
                                   0,
                                   0.18478129614474956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087297765128767371,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11115818104781841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56694407193186813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11797599823409166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17460931800549712,
                                   0,
                                   0,
                                   0,
                                   -0.02182080389146419,
                                   0,
                                   -0.17054601765619776,
                                   0.36665956183216902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33101200939191699,
                                   0,
                                   -0.46382390469917251,
                                   0,
                                   0,
                                   -0.077448494215238126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48072864493970807,
                                   0,
                                   0,
                                   0.52981635469834165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36577027850345806,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5842526133997088,
                                   0.25593122747883629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084073100209986443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17651755543523223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.073190296053410278,
                                   0,
                                   0,
                                   -0.090522896047048482,
                                   0,
                                   -0.02954163156434176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46671507373462889,
                                   0,
                                   0,
                                   -0.44975528386900249,
                                   0,
                                   -0.25209852530946142,
                                   0,
                                   0,
                                   -0.0015849410521641821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098318106378902814,
                                   0,
                                   0,
                                   0.36658101461151971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34528517149930366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.97892640114945317,
                                   -0.28013745911243326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15016998474163321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5656632587729914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17594583733370006,
                                   0,
                                   0,
                                   0.12137554536894057,
                                   0,
                                   -0.11985460086022964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29175843972729509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33107477555782933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3219276826967884,
                                   0,
                                   0,
                                   -0.51199340146980665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28845119543854858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11826031146577635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0034573128056746005,
                                   0,
                                   0,
                                   -0.30980208258328196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16559899042757564,
                                   0,
                                   0.24463770351313216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49413086175698173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59809028063078662,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34383646527611977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10507591312590883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75080139662434142,
                                   0,
                                   0,
                                   0.36375144949821736,
                                   0,
                                   0,
                                   0,
                                   -0.091578089763617865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40621221186138973,
                                   0,
                                   0,
                                   0,
                                   0.91787505842687533,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29010067170911613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27179301900899117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92170695798489821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27254064930391486,
                                   0,
                                   0.07351589431074039,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73043861776006858,
                                   0,
                                   0.43309338873837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26560191022565421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016708385017693478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79947858985321085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35915137272896674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35140485746682631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26531879070310249,
                                   0,
                                   0,
                                   -0.1941279762215723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10190280366851832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079635807172192624,
                                   0,
                                   0,
                                   0.084686930764512766,
                                   0,
                                   0,
                                   0.42776775137381767,
                                   0,
                                   0.45292263713748465,
                                   0,
                                   0,
                                   0,
                                   -0.50716793761387979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3732044040545765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1640517297155013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16970433834124579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14200420470993536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2110473651343277,
                                   0,
                                   0,
                                   0,
                                   -0.10045923351639968,
                                   0,
                                   -0.065605879237941131,
                                   0.23803816108507642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.95897122668250501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6383422624523446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20678056546519472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16062306134725379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25747199049367164,
                                   0,
                                   0,
                                   0.778059027951292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61408733676860028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34788934268340954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52748718860284904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064716233442284943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61225803912177157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51090876412494646,
                                   0,
                                   -0.44952398887031153,
                                   0,
                                   0.48294959003835147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45522448437932411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27018644830823801,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1940388984677924,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26027180796502636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67945788619476677,
                                   0,
                                   -0.32506410495078664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16389345912846764,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48016277274674551,
                                   0,
                                   0,
                                   0,
                                   -0.21126931310823469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24142053488058962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47000118225542298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27175714707967308,
                                   0,
                                   0,
                                   -0.3044394767592733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43975578972172552,
                                   0,
                                   0,
                                   0,
                                   -0.16233142667078693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1719987215449974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013961901190020854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052081220255132982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31038781002944016,
                                   0,
                                   -0.80501130376412688,
                                   0,
                                   0,
                                   -0.16298372086218993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30168538038422099,
                                   0,
                                   0,
                                   -0.10919473934162938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10610766702481828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056835933968579777,
                                   0.1318577613786929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28065874266942942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47022653260180702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56847809111475256,
                                   0,
                                   0,
                                   -0.24940200983945049,
                                   0,
                                   0.52527142979919739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086726884399680154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098898742694252306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35079038798314016,
                                   0,
                                   0,
                                   0.21717218617446765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21133945134548168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55345303072784335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41087014129465438,
                                   0,
                                   0,
                                   -0.42767974838486339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15603501507166775,
                                   0,
                                   0.044769831350067055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3015812645273816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1107082892124083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19169047694914915,
                                   0,
                                   0,
                                   0,
                                   0.53369272394950928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19904045182831862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52438126104306482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33567954861919824,
                                   0,
                                   0,
                                   -0.13564430770192337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22594833923211907,
                                   0,
                                   0,
                                   0,
                                   -0.13504326381592768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31410856765732853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1453364425732237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17726070421945356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70022530944377814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32880567083374401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69713207371340957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58224615391709666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25266393057558756,
                                   0,
                                   0,
                                   -0.46804924063865128,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.035433154590434474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0013868429049473316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3066730860775001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4351921036728435,
                                   0,
                                   0,
                                   0.35957505934330808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.042357402472319193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37413007662536246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3669458710970136,
                                   0,
                                   0,
                                   0.30877538113760816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42011369848592922,
                                   0,
                                   -0.19442939350090385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034755532946377531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86788943597226065,
                                   0,
                                   0,
                                   0,
                                   0.10128413864840066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32219669782033544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4731108934406853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27043973731847387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01918010228507569,
                                   0,
                                   -0.10663500533731492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35452301962847438,
                                   0,
                                   0.57091103302403723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66204996524587267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48561189887608308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18944372500557102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81247571901986992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1982472385329932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038794738668026012,
                                   0,
                                   0,
                                   -0.74083673145231843,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1237822296577855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1117426413618237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50147018109405017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39578670001013389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31057109431543195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46962615073402586,
                                   0,
                                   -0.62089143169197614,
                                   0,
                                   -0.34391498927824432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11672069622334783,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32228586465530751,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090449091701782169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5148611535308234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61470331398263067,
                                   0,
                                   0.56462410861252277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069294512944594211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11385972764162616,
                                   0,
                                   0,
                                   -0.074940318533533362,
                                   0,
                                   0,
                                   -0.36059303443755042,
                                   0,
                                   0.16679495598821523,
                                   0,
                                   0,
                                   0,
                                   0.14149016067761297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40202623597035708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48685122265904668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0067830078830427437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038301640606727035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44218416418479634,
                                   0,
                                   0,
                                   0,
                                   0.38899906753639002,
                                   0,
                                   0.17570642784115809,
                                   0.14446013807196778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58998946394649088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56038493421481383,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5515799845991427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57007717583600204,
                                   0,
                                   0,
                                   -0.79637144596436815,
                                   0,
                                   0,
                                   0,
                                   -0.016986835271293355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29189277403266828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099158496682718256,
                                   0,
                                   0,
                                   0,
                                   0.33618102925353816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26880409908056546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15021536399298446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0038841710882393382,
                                   0,
                                   0,
                                   0.0086988742624718209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031025040571800125,
                                   0,
                                   0,
                                   0,
                                   0.39871245091661328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55429539816815254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4223607276283094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22687290667047344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25850465800511047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1569531682853964,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1831031439077482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010694864097832235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6555606646127714,
                                   0,
                                   0,
                                   0.56610368784651488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33852846877203541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29062749970635932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0080776850375490136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62143030260625409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78121524875184867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60583863577696528,
                                   0,
                                   0,
                                   -0.065523096145509552,
                                   0,
                                   0,
                                   0,
                                   -0.39570132486777837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11456429221377191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047389190157636304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12919644100828342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30007993050187848,
                                   0,
                                   -0.64325923044348865,
                                   0,
                                   0.26622551116658527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01750819645580954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63335217016688417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0499170094587575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43258540734894008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2819991998273178,
                                   0,
                                   -0.32897774091724241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27589124312462715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065614260825780701,
                                   0,
                                   0,
                                   0,
                                   -0.33546676101368328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11641665600477799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.186296100983323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32237561987789948,
                                   0,
                                   0,
                                   0.4598391755242483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28787376175380835,
                                   0,
                                   0,
                                   0,
                                   0.070835721655781989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30558473600024355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43730915071712001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26625802143215876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.358459143865686,
                                   0,
                                   -0.29511530381783352,
                                   0,
                                   0,
                                   0.11765581717966575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20284370990895356,
                                   0,
                                   0,
                                   0.19552441114648375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5860111088339004,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20433513915440771,
                                   -0.0046142120065085562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38379086028002957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014769463340682109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034373071904513421,
                                   0,
                                   0,
                                   0.33331707973643804,
                                   0,
                                   0.57324346679701532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28101341771464733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20611859833849827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53067762934069929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28026781120728006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13137270723105132,
                                   0,
                                   0,
                                   -0.36572075826604789,
                                   0,
                                   0,
                                   0,
                                   1.1739809997959982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068644981169098188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15523659477721158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17350640642346743,
                                   0,
                                   0.41923429245804211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30309517753030862,
                                   0,
                                   -0.087680716810205644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79411395285361319,
                                   0,
                                   -0.18749943013308037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74686794783701993,
                                   0,
                                   0,
                                   0,
                                   -0.26823052026192623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58591676256399883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62439922256808922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23846489026041287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75843194919508627,
                                   0,
                                   -0.13168269249086242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1586141826753793,
                                   0,
                                   -0.34638104796037966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20034873750888077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29618216060129676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48120853387706813,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087797006853909759,
                                   0,
                                   -0.34358877353906614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28913362143636567,
                                   0,
                                   0.059599763228916365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5071652717751729,
                                   0,
                                   0.45889641449265539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48735097798947752,
                                   0,
                                   0,
                                   0,
                                   -0.38863007332505634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16523534058215053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57960498240837932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060554407211230163,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097132634752893215,
                                   0,
                                   -1.159448077308822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21603254210841985,
                                   0,
                                   -0.089417129588287639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31070002079343073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25402635654683137,
                                   0,
                                   0.48131159868491619,
                                   0,
                                   0,
                                   -0.60472794371070249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.083121504983005148,
                                   0,
                                   0,
                                   0.11968850822365244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18563945925935746,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50280269990367188,
                                   -0.011734368514157444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73008283438067856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51359293282953944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3899174985875834,
                                   0,
                                   0,
                                   0.37551578913356309,
                                   0,
                                   -0.16906099109303069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10520725240468423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19073661510983975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30521009099263086,
                                   0,
                                   0,
                                   0,
                                   -0.19845827571205901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19969352072219188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39331661500673559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061943363494501767,
                                   0,
                                   0,
                                   0.0055786208454706304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50050245737664423,
                                   0,
                                   0,
                                   0,
                                   -0.24237495712607199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.022275572350940402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097744324610915104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55976656729805385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10650669679915803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54752823081682633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59205685900366378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18329804070413575,
                                   0,
                                   0.17548226713043427,
                                   0,
                                   0.75788738291510005,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19050455358779425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35106544544176732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43797633873277597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070794522343210139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30261366577956439,
                                   0,
                                   0.1068284632319272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35912888301431883,
                                   0,
                                   -0.29551890847219603,
                                   0,
                                   0,
                                   -0.34560865005706076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81052054984863753,
                                   0,
                                   0,
                                   -0.12000436120797904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013108923229411484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3847317287726012,
                                   -0.14516990455643664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043726881254920066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40641870131872265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19586955499703965,
                                   0,
                                   0,
                                   0.18169468979188402,
                                   0,
                                   -0.31495435262069077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20966918213987859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12459877396976821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14703409348090141,
                                   0,
                                   0,
                                   0.41267694493797791,
                                   0,
                                   0,
                                   -0.54095393392365421,
                                   0,
                                   -0.1087686019708078,
                                   0,
                                   0,
                                   0,
                                   -0.39932575628641498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22819106154935478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15391557985007462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28857455975131097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10752592874207727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17755806789181608,
                                   0,
                                   0,
                                   0,
                                   -0.28725337680692536,
                                   0,
                                   -0.024914625781392627,
                                   -0.20825622738074429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023380692282479187,
                                   0,
                                   -0.46525556165914439,
                                   0,
                                   0,
                                   -0.16421775856803839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4855376986443839,
                                   0,
                                   0,
                                   -0.053262476528255984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47654661439809709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32757559529344432,
                                   0.14281076555207423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17267075348810473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45838387519862461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91351563981902961,
                                   0,
                                   0,
                                   0.60316277587445688,
                                   0,
                                   -0.22575287062589325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012581047597284813,
                                   0,
                                   0,
                                   0,
                                   0.073330470704297934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48511881669878737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64293826471416504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22330925692103312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48325906086833187,
                                   0,
                                   0,
                                   -0.25001283842920413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45055710480775041,
                                   0,
                                   0,
                                   0,
                                   -0.57635551907150495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77552622829729168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27232696476470353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64038933530168829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15414354524081944,
                                   0,
                                   0.21380419315978882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15378512356492716,
                                   0,
                                   1.0178833531204923,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17143828149878196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15988607713393169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12962039221653732,
                                   0,
                                   0,
                                   0,
                                   0.50321210195312616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35742410426109167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41277879583285682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16767762243115555,
                                   0,
                                   0,
                                   -0.12477238910923816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24499557912035788,
                                   0,
                                   0,
                                   0,
                                   -0.27903838162564287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0039072787438334741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17390060005293811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44096301458203857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11538587024662207,
                                   0,
                                   0,
                                   0,
                                   -0.48295184524756629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98776588173057001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067712122213944598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58228949081741588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16082777196952941,
                                   0,
                                   -0.016977016517390076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18307833465014622,
                                   0,
                                   0.7619446015632696,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27177724698875788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2289730694756669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14177201423844463,
                                   0,
                                   0,
                                   -0.23698758686545962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33392976366215577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30883880951606651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26854050230899051,
                                   0,
                                   0,
                                   0.63306339597200401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24794831600594722,
                                   0,
                                   -0.22332417333209931,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28316620080434213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30186757724059732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33624557349586315,
                                   0,
                                   0,
                                   0.19815264222210022,
                                   0,
                                   0,
                                   0.004569962786112769,
                                   0,
                                   0.32895153734362009,
                                   0,
                                   0,
                                   0,
                                   0.23913949452973771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096978639057336724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32045005729457132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14604409319105235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27050371186645183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22652498527725642,
                                   0,
                                   0,
                                   0,
                                   0.26935736095650947,
                                   0,
                                   -0.27301475204393455,
                                   -0.43143304409634042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40572652385344787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47290570893689454,
                                   0,
                                   0,
                                   -0.098264871177002874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16235330816691265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34234346757945844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054626195925129184,
                                   0,
                                   0,
                                   0.10315353934289544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32240161407936557,
                                   0,
                                   0.54066130353306074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22056841809951949,
                                   0,
                                   0,
                                   -0.078558530451099631,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054722509115489759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32687486372733465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68167837166050527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16151504042334874,
                                   0,
                                   0,
                                   0.62706803225808849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51508207199298583,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029221088382900329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18216409496345648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63058014596445178,
                                   0,
                                   -0.15794992928970158,
                                   0,
                                   -0.087133272628219766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1395219219686716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087535647798987426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13874232988044094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08079980217101454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20847599505655182,
                                   0,
                                   0.22847419660935125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67457205918370633,
                                   0,
                                   0,
                                   0,
                                   0.20770701471325473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48122162167280608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21702057246071521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27405469603265542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28473911172729927,
                                   0,
                                   -0.86981850317212883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15406742945427995,
                                   0,
                                   -0.23843863574112689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50340309083064017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0256277634784832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53175563087527888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63979300807315365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17318262170190224,
                                   0,
                                   0.62218329875146416,
                                   0,
                                   0.12879446567322586,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21097870307764108,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41475265168416331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077003712003117772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8650434924756506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24568138288629521,
                                   0,
                                   -0.064360575755770866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14774166945590694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0085976874126984116,
                                   0,
                                   0,
                                   0.19976971995364265,
                                   0,
                                   0,
                                   0.27810049783841706,
                                   0,
                                   0.034788477287113331,
                                   0,
                                   0,
                                   0,
                                   0.0072450248626632074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31436468510965077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54065580652215239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.058638708580631749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32949896088077385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28902854611070161,
                                   0,
                                   0,
                                   0,
                                   -0.10180091770259088,
                                   0,
                                   -0.35127658748026203,
                                   -0.37302792720187872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42523292879524849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61690712495765643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46402774597515262,
                                   0,
                                   0.39658173806158575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18860732390330776,
                                   0,
                                   0.094607527470430997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024158243209746272,
                                   0,
                                   -0.144557268398671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17071784806555135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12554570523956862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31452720968864911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071606584515792382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1479404597320753,
                                   0,
                                   0,
                                   -0.069987063618732193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87721138193076642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36736232945032388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64604916434482829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10007118124762451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079914005228976751,
                                   0,
                                   -0.31488358247150305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50283964555592098,
                                   0,
                                   -0.21172172685449353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0056391744555805354,
                                   0,
                                   0.41153701915819996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.63054535732886863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18482936139721212,
                                   0,
                                   0,
                                   -0.25635898515979477,
                                   0,
                                   0,
                                   0.076833830202655246,
                                   0,
                                   0.2103966962221534,
                                   0,
                                   0,
                                   0,
                                   -0.23933318745476084,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17566873192940705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42942344188824033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074084423681328115,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25141615771271864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17071743540330409,
                                   0,
                                   0,
                                   0,
                                   -0.032258573732085127,
                                   0,
                                   -0.13887883723942451,
                                   0.248284467108499,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12859876153628189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11100137715184247,
                                   0,
                                   0,
                                   0,
                                   -0.26712377683762389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13053385552945432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.040141602707924398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54781775124019794,
                                   0,
                                   0,
                                   -0.41959557137814235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45964920861950082,
                                   0,
                                   0,
                                   0,
                                   -0.36801085276712886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.088757746748664768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18469759579064599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12755489253926258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055324853273703872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41414088350186418,
                                   0,
                                   0,
                                   0.2917941713628957,
                                   0,
                                   0,
                                   0.10875476376366426,
                                   0,
                                   -0.36234755229573445,
                                   0,
                                   0,
                                   0,
                                   -0.40534075096923455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14021161806483512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021560951559630184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.08575527264750829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53595437649862188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22022758147274429,
                                   0,
                                   0,
                                   0,
                                   0.24733536709398585,
                                   0,
                                   0.0055528491960865067,
                                   -0.091799458334131126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13968152290799815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088700571544726992,
                                   0,
                                   0,
                                   -0.35003238978305889,
                                   0,
                                   0,
                                   0.094244162416608379,
                                   0,
                                   -0.1022090484242431,
                                   0,
                                   0,
                                   0,
                                   -0.21052924834122541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16881207774074131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090584002438917066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26539839853934549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1355448669595064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45887155436779792,
                                   0,
                                   0,
                                   0,
                                   0.55679605041154379,
                                   0,
                                   -0.24237115518437852,
                                   -0.28566933456260035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42044067011270336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31848150687954058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26141946008443517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52915991157334652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1534003197734459,
                                   0,
                                   0,
                                   -0.59153796873672737,
                                   -0.67567512703888022,
                                   0,
                                   0.59311948244479118,
                                   0,
                                   0,
                                   0.17126753667444117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039199452327259521,
                                   0,
                                   0,
                                   -0.32201923895276685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2054901550446506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022385375044976757,
                                   0.37653905928943632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45642145444545934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21478103698802539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6568521714128861,
                                   0,
                                   0,
                                   0.62559534536893779,
                                   0,
                                   0.3076045763456422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17199584942070262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48691036167464619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030450488622295629,
                                   0,
                                   0,
                                   -0.26544466839737446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67088131054980416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31475592621523574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15499598050990346,
                                   0,
                                   0,
                                   0.25337620970911506,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1135976543738391,
                                   0,
                                   0.20223170305728677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018756948094777383,
                                   0,
                                   0,
                                   -0.42468835399040317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046803117414783629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51795257835879227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11627632728218006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73177902539897344,
                                   0,
                                   0,
                                   -0.012396388851384554,
                                   -0.33509031013653257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61613105039888494,
                                   -0.20772615222820107,
                                   0,
                                   0.09137958064591363,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41021899636334547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37071558887265821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57381586898641712,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34283641118085711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20138209513890221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39088386484667181,
                                   0,
                                   0,
                                   0,
                                   -0.076838528039439732,
                                   -0.095333084835613785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1007074069338873,
                                   0,
                                   0,
                                   0,
                                   -0.23035547666162987,
                                   0,
                                   0,
                                   0,
                                   -0.083913152257988899,
                                   0,
                                   0,
                                   -0.40006430511304092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12113397298618502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2388670463257885,
                                   0,
                                   0.31874317480104242,
                                   0,
                                   0.073113872897596938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37874993237580679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16777311545152507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62734492862145264,
                                   0,
                                   -0.20521828427048833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016369550519760079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66918613632456292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0082988397338165584,
                                   0,
                                   0.0008235911058917661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28376829795907277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46304552038880831,
                                   0,
                                   0.1172862648469068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042721823982097798,
                                   0,
                                   0.088529765767520585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48321637105117976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12424336683950397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087386795148336791,
                                   0,
                                   0,
                                   0.035707223303417718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35780864172840188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1808239011637191,
                                   0,
                                   0.31611732478842869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15508766596063356,
                                   0,
                                   0,
                                   0.14210173979169929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45111330164709013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28085393867826541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53924346862134998,
                                   0.27123760802311581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023902872593385444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15311994488305769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19313702419817341,
                                   0,
                                   0,
                                   -0.2912116919719458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84066696180128786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38177491847001566,
                                   0,
                                   0.63661783932347049,
                                   0,
                                   0.34774917526933502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48441961686323848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28563670834412008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15042020873277887,
                                   0,
                                   -0.065874808011145369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10083537426035277,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37534128219740837,
                                   -0.35896152804373432,
                                   0,
                                   -0.27161036690930157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28103495531133754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14845336095250006,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0054271540167618038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31927920856026487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53597670619757076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3782705056630502,
                                   0,
                                   0,
                                   0,
                                   0.229035114072691,
                                   0.73811306416727529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49884889126165455,
                                   0,
                                   0,
                                   0,
                                   -0.46093793528661769,
                                   0,
                                   0,
                                   0.13822503996876409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2402819326820102,
                                   -0.22029318665839273,
                                   0,
                                   0.81550419494826987,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7169434788950646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078026715835677982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024911703405228941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045923362167430537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032072113899668298,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52828014588183392,
                                   0,
                                   0,
                                   0,
                                   0.21285361395668947,
                                   0.31060036925561596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72151459151602737,
                                   0,
                                   0,
                                   0,
                                   -0.4737663663849575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14427126627998019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084176921223749354,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59239147886504162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11616009093061544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53294622603001507,
                                   0,
                                   0.40025520301009543,
                                   0.19635200522346952,
                                   0,
                                   0,
                                   0,
                                   -0.27260419278751669,
                                   0,
                                   -0.2260084620718297,
                                   0.6434713260936622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18374977479504934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71170451153571834,
                                   -0.0098959727637107642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54819269927897063,
                                   0.57810018011130015,
                                   0,
                                   0.45228917348086817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.214235119391262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6483483245925209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029995518750493541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.052292602748356926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038559987450932975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030748549036739341,
                                   0,
                                   0,
                                   0,
                                   0.44363138491359144,
                                   -0.32315323374887178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.016277841604582222,
                                   0,
                                   0,
                                   0,
                                   0.37606688347497796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50035002241567716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045390501763945594,
                                   0,
                                   0,
                                   -6.1084477232090095e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20475513166471698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24217473255997299,
                                   0,
                                   0.24685629085136412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14862179362243275,
                                   0,
                                   0,
                                   -0.66622881007498203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15520359905509792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17766792561206665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067239001776185081,
                                   0.20709176597838977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026318640930226699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12796168449879436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45968214713432198,
                                   0,
                                   0,
                                   -0.47334335700195884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75811535850141365,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1561942777906036,
                                   0,
                                   -0.51713867057251817,
                                   0,
                                   0.44881494688902834,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60406734130375905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31362536331323237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39222137581983874,
                                   0,
                                   -0.15292997009757725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012572938993762856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20775813671534973,
                                   0,
                                   0,
                                   -0.03372940676549048,
                                   0.020014506047435904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38255141887528671,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46423711875984364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67202377682645997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25989147907860105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044367222597343187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051607313668747656,
                                   -0.13015269548928626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22923243020266093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32381975519031919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36588412985405455,
                                   0,
                                   0,
                                   -0.15432437769528753,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24249869037486757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1203613772679763,
                                   0,
                                   -0.21501038862237182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26286394059930757,
                                   0,
                                   0,
                                   -0.32505364097089628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0093561990952086664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1769998143566669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094457695933974933,
                                   -0.46455741267369288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42647388609984982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071707725493842731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039301845231167656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3615528360289853,
                                   0,
                                   0.084846879985797485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59137190519049565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.048730236595667629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34396261020507513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36640009566018206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50584705707487665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1627356670097142,
                                   0,
                                   0,
                                   0.20329415862425218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.3377740081964311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63413059981134023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029594884909449615,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05423841296246476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10860883885023674,
                                   0.43200885719726601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57101674511752154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26184491840379187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13128729960221841,
                                   0,
                                   -0.47633979849009145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067254123215748862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22177645252908182,
                                   0,
                                   0.070469988749346416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43535911577054043,
                                   0,
                                   -0.20502910032690205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26644461689716481,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033283289201529606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073950196796242651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76777719232243857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03972754533842876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49674935921871999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39446618392502458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57569132434671244,
                                   0,
                                   0,
                                   -0.10239958531727636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20926352641944307,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37114434435662969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3557535629044066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20013738752198018,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031432914547203074,
                                   0.39937867863489285,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28224231689649176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1275596810577847,
                                   0,
                                   0,
                                   0.49484040375933619,
                                   -0.71787615074350652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08096899280389537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11618131573957113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079785756247812256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21587157821596675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23798083328956138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.013505764696199213,
                                   -0.040461233767847132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11126470278994394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52005658457940207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29823770289945156,
                                   0.60449592193143797,
                                   0,
                                   -0.34774277322864938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050919871251594077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15020569235854511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12018529231671998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41308875956455066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25114913329577648,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49841501642507086,
                                   0,
                                   0,
                                   0,
                                   -0.89992277996102199,
                                   0.40536311391297319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27514793403997218,
                                   0,
                                   0,
                                   0,
                                   -0.17818568953916153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48473436441680195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011577731388536256,
                                   0,
                                   0,
                                   -0.045215200291795876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1847580635956303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067116848942093882,
                                   0,
                                   0.16461625871386409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40740285930528153,
                                   0,
                                   0,
                                   -0.077494358683504322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46374432208635136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22263565779887495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25518368679373182,
                                   -0.17409668792357444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37436540733199503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15789137055655222,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16026300551223999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5145452138308283,
                                   0,
                                   0,
                                   0.3100058351352778,
                                   0.10851810161098664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24158962347074261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12626684867329904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.024394763966793794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2005618458958614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34341045526948055,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45669010599325222,
                                   0.15504433761503936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36880188948135317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32892662875994327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10371932125265604,
                                   0,
                                   0,
                                   -0.087581684092047141,
                                   0.0045235289955639184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045642125088128635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36470059073646732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22861283145357708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20672323068571469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43448120464330903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45722600931006951,
                                   -0.47628787503339093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1363482146210607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2684076780429413,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2070340594116433,
                                   0,
                                   -0.11428268818992154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50586092046723996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44820122693330861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54296155374422994,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039351543795068999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34481629930635294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15594219467043541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20963758329179488,
                                   -0.66287894936148872,
                                   0,
                                   0.8278631903687752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29375086901649794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33563214641948635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22994032234966241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77078319178666421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2097146870010542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075463295792299129,
                                   0,
                                   0,
                                   0,
                                   -0.28717746925206433,
                                   0.166946270068208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3191160829989233,
                                   0,
                                   0,
                                   0,
                                   0.11801393175067251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16959486580023825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15478420895680339,
                                   0,
                                   0.076257540050844591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2389199281249908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10052717548039697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01159335287881523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90353519189086118,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24034459398052652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30072872072122492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12160430692263202,
                                   0,
                                   0,
                                   -0.61857210430978737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2693040084529717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046460601140322924,
                                   0,
                                   0.35367480756703396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049725779302070991,
                                   0,
                                   0,
                                   -0.19696907158128601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13703047363493268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094389412021653393,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28579457076379722,
                                   0.26652474159764589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17120137643535288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24777814463337161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21286401836215485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17664629545825544,
                                   0,
                                   0,
                                   0.47756930112330875,
                                   -0.022239546557370815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28043773478064915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023647358418870723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39188125728588019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60806481621967123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19640094865617153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18242752188437922,
                                   -0.042948815599170284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13675513102072767,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16939887945434284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69148888900805749,
                                   0,
                                   0,
                                   -0.071082636281809511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23666572847720674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22504740718099164,
                                   0,
                                   -0.08901503899137958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3316069804621809,
                                   0,
                                   0,
                                   -0.37987930466006503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18250510775437384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19233867524250794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07952773201725398,
                                   -0.051857667046776482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10548114633272308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16970506528188062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43013226407101635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20334501361939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097030476115644151,
                                   0,
                                   -0.039467915538295574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2309365164868874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.76330080147956036,
                                   0,
                                   -0.19229684931962832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056664014802076702,
                                   0,
                                   -0.15425328508130265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25044292406164315,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13114486849870863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041176864073180407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055928261744193977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16101896069202454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58167943337174777,
                                   0,
                                   -0.36593937681397631,
                                   0.027876285626046979,
                                   0,
                                   0,
                                   0,
                                   -0.1244359493588255,
                                   0,
                                   0.46166700122568655,
                                   -0.13823585653741541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81961478548310551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64972590354719695,
                                   0,
                                   0,
                                   -0.02265113603682985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059753076568703101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70039453038194766,
                                   0,
                                   -0.09879575514581547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24983141529458852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.048680008264271726,
                                   0,
                                   0.1680700905323711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.063740691102893918,
                                   0,
                                   -0.59879827707401023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19987023169969706,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74863408670237575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45930427828556009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64814520597296199,
                                   0,
                                   0.094431149894680141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17439590001393857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13888065497521107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10255154902004993,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29241249870746105,
                                   0,
                                   -0.39232672410600372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22542004976444563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47283530821749242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34337116318479927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0062474216187741877,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59810336767885974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23177086821300463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20510458007088775,
                                   0.39792460041184613,
                                   0,
                                   0.11686339632604165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25316423834379465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35889471309031007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57967168718330131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31324075362967918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72739348869079989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017564357795859058,
                                   0,
                                   0,
                                   0,
                                   0.60196550992110254,
                                   -0.1214029027734181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54695434092926232,
                                   0,
                                   0,
                                   0,
                                   -0.58937259185011404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43162116223709618,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50259271160828012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44757688458765255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35720116389059137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15316785250807352,
                                   0,
                                   0.51992270391316087,
                                   0.66171605907613673,
                                   0,
                                   0,
                                   0,
                                   0.62774794579743909,
                                   0,
                                   0.24580132032082819,
                                   -0.22221374653000178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40029096517068674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038333653073838306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29354046120749566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89370090167388172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060273283500519165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16590953689720692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22134305260669435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18703236593368472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42769726025077787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16484552773715866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23487387880324487,
                                   0,
                                   0.39601909998924856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61691742840354835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22935732676115253,
                                   0,
                                   -0.20601438282090262,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10610399627310821,
                                   0,
                                   -0.010186879785499758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30151034107908314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19448509623319749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64808682994476685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40506402697486166,
                                   0,
                                   -1.1037201539711932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.90827338625935183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10428646776372769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020177219838671559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28222589599363762,
                                   0,
                                   0,
                                   0.28444962788807149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37847904258109294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23798653602367745,
                                   0,
                                   -0.1169406129289797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19653018261453381,
                                   0,
                                   0,
                                   -0.45460740578397346,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31926407400893519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2240132703126263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39008067229768073,
                                   -0.1444615649697254,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16884524210520532,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1628694505863397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62890071943342529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.01760811622383723,
                                   0,
                                   0,
                                   -0.15268386174029142,
                                   0.17688248303239612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076567578991494162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14156220301306205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27722389299213263,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36165803499176324,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54129540511072893,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095118099688644597,
                                   -0.0062354443211751903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11804635977840872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.108216503210666,
                                   0,
                                   0,
                                   -0.62783742368491036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22387982758092678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41687256065369255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17740206008271847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22788427215594526,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2188331088158135,
                                   -0.87653150173368977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054354422580648015,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11728198277800012,
                                   0,
                                   0,
                                   0.34341859540586184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19146934834533463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59029213214094955,
                                   0,
                                   -0.081793266334680592,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.172651431769726,
                                   0,
                                   0,
                                   -0.074145627062603373,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11822966118784203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36250428003290014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29541643552951435,
                                   0.3048125049793845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099238592748352117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32067931326358901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3019935706795458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12241510681779727,
                                   0,
                                   0.82060643248081588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23510862529033996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14395620228396275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040768797708269695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084686594447170388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36822023281528388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.98478526672782585,
                                   0,
                                   0,
                                   -0.29178734056013939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17288238469338485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14238990190968676,
                                   0,
                                   0.15847883395887835,
                                   0,
                                   -0.57412050700820461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35764810290199928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069522064812201773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76886520953338311,
                                   0,
                                   -0.49722158212272494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080420024296833412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16953044418029148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46782310293251433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0077960643688732012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069482719862511588,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86083968633630492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.005159941133957513,
                                   0,
                                   0,
                                   0.10018080244788805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56600830203276808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75595933982262742,
                                   0,
                                   -0.97074591600248505,
                                   0,
                                   -0.13504139989280184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60597065061891919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24220846978573454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48486219698513316,
                                   0,
                                   0.23506549579566799,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36088084732283221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71542634198911392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27902468714765161,
                                   0,
                                   -0.050904221924752524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54158638489121369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32034350948598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00074359835906662175,
                                   0,
                                   0,
                                   -0.35354448813760747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.014140201711428074,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12607860225500322,
                                   0,
                                   0.16020995543322678,
                                   0,
                                   -0.35867709119792524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24057319558702972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2088062884483022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56325995953327646,
                                   0,
                                   0.45786124853992305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.92646438435780454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20967134767675955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85300493804869104,
                                   0,
                                   0.12069706654125323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081349767696119457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51280993375581319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75902416921100702,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36267415086367999,
                                   0,
                                   -0.11751762881831666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24748749169308165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45514069411949815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.019986130108202452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056898148154712502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080618999730343824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015432563477070213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066296593017884653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35682553950356999,
                                   0,
                                   0.5179602264236316,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24167622957370996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020579999739685384,
                                   0,
                                   0.55532646345391867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12812212507087142,
                                   0,
                                   -0.46422399903737177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02493428127100461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36286292833145872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12237928017119645,
                                   0,
                                   0,
                                   -0.18800932122038083,
                                   -0.2827223474633459,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31902403444905247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16815077820844848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12790660641884832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015131265471250863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13355493132987317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35025646341405131,
                                   -0.37849719646850571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5546689687530737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2839130700433683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45060158419265711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23733424406071127,
                                   0,
                                   0.2285225734839465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32066808969885385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041124439362781193,
                                   0,
                                   -0.20577381599319849,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51574878720401163,
                                   0,
                                   0.18613712485462425,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40036923411027181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49857080122293757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1297318843738024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29476619462306552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10445170006919682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049124185397775647,
                                   0,
                                   -1.0342221810544281,
                                   0.53574899384750119,
                                   0,
                                   0,
                                   0,
                                   -0.34358044342515609,
                                   0,
                                   -0.34569441778063847,
                                   -0.056121484184814913,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19701567467961761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45651985056868527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40162281256092869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094048077584223011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45943495379863264,
                                   0,
                                   0.45550321374646308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48708220712724237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2921374720107439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41151268129284391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15751420325358298,
                                   0,
                                   0,
                                   -0.40705227331935601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36829570428371394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10530720800402026,
                                   0,
                                   -0.24243486200052411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10241617431892557,
                                   0,
                                   0,
                                   0.098997085618674777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13411491478164922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19345193705737168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20031178885524126,
                                   -0.19046286572431204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39857470078682367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35169073545743057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76850537727970081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31118720752077456,
                                   0.48580851015838705,
                                   0,
                                   0.28251787242069515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18434132222699268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14750145931505054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2418924553007748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092977380591206193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19255349853735368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25813844246249562,
                                   0,
                                   0,
                                   0,
                                   0.47629475419843087,
                                   0.38367460945789245,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24468976628921463,
                                   0,
                                   0,
                                   0,
                                   0.64135429211395689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13680400462516368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29144678564910226,
                                   0,
                                   0,
                                   0.38793050614188429,
                                   0.2348664534138451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62487678912176714,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1283441951878142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099806591143151976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19810435033494411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074541211289833223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27421324164214911,
                                   -0.36935907823958164,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13177921266043319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.021957720804696601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50215226783204581,
                                   0,
                                   0.075330156185289654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19530703483339756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53253944743805748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59669358773262304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15048144550048814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20311406146080743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84698291417782612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27553114300492643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097428838634137468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37616791297778301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2144757221966147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098529282763143322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20107460384628278,
                                   0,
                                   0,
                                   0.41833207417624457,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47864940427936042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1233326194000107,
                                   0,
                                   0.043904565102979853,
                                   0,
                                   -1.3167446310474682,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023596048858324517,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50705239886993136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53256744450880011,
                                   0,
                                   0.20554368107287282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069168764951183542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29794036508682298,
                                   -0.42119915056803081,
                                   0,
                                   -4.9330535918301263e-05,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045668068834730832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23270775561747059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16713072431051776,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30477734124963096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53701017575737808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42456706598162935,
                                   0,
                                   0,
                                   0,
                                   0.25638177804518897,
                                   -0.7921472895661732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54083213190728263,
                                   0,
                                   0,
                                   0,
                                   0.12018573274396399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10218007596883757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10964966611115588,
                                   0,
                                   0,
                                   -0.039652224230133704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36085805167755441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28438365301294011,
                                   0,
                                   0.089002893422905016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31991714528899606,
                                   0,
                                   0,
                                   0.013679191403925123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12118333358223335,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5631814341039203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086950915316646879,
                                   0.27142442617462431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49114149786999317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010261257124889879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1143834329958318,
                                   0,
                                   0,
                                   -0.39134761006823726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40286434496053686,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44108910824382674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2240941999016918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68830763839680187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70998525187660655,
                                   0.13623407409120381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.97856721804716151,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37489815702847396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3154668094207102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13180956182248879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12936074953900131,
                                   0,
                                   0.099111224427191807,
                                   -0.038458844488342747,
                                   0,
                                   0,
                                   0,
                                   -0.32025837343755287,
                                   0,
                                   0.21288345657518248,
                                   0.53245410454547337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8186168660167199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34174039446783844,
                                   0,
                                   0.46138776160464368,
                                   0,
                                   0,
                                   0.81677217676915514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25232062110734754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19388119032430173,
                                   0,
                                   -0.38784994265918815,
                                   0,
                                   0.0029728189691771295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13782078490702435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.81738730610065824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33638073476895741,
                                   0,
                                   -1.1810197116603616,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092293437795268191,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45398215479802956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10147047111779313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48403604877437534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.032070421407014708,
                                   0,
                                   -0.018461071282233236,
                                   0.30118490569710715,
                                   0,
                                   0,
                                   0,
                                   -0.23931741353986172,
                                   0,
                                   -1.047757555857739,
                                   -0.51504043055173576,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34739020377924529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13659413793890535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.71262666945075548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33722860609207317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61037437633416802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18471047573913213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25690021327625062,
                                   0,
                                   -0.32468899175547328,
                                   -0.21664005517291737,
                                   0,
                                   0,
                                   0,
                                   -0.077133147773884594,
                                   0,
                                   0.23519081161399333,
                                   0.9453275365949777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22531454500750125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13941299850488817,
                                   0,
                                   0,
                                   0,
                                   0.068199801391896214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11052265374214608,
                                   0,
                                   0,
                                   0.43276577131143107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14250897736837798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19688596998048122,
                                   0,
                                   0.51852163972398713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31506878543834765,
                                   0,
                                   0,
                                   0.014267746838008469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12657829347489433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41916995293227871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19957055053679543,
                                   -0.25740892656232778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22114032053982693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14738218736214803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.09419325535542869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38300852663891904,
                                   0,
                                   0,
                                   -0.086784331508166251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17630945174789195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31453673326666093,
                                   0,
                                   0.1107142688981034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.045046020801065567,
                                   0,
                                   0,
                                   0.10083127158117079,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33877425000014666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012758252069945769,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17647933972191088,
                                   -0.087646485166343102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21496211459492093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69459493309786169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14052402142831441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43909238505923648,
                                   0,
                                   0,
                                   0.17985841860415311,
                                   0.11628217309591567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38595888368358283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.061880764228806687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27448345451299611,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29222733891900926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16987450730660422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52612700304782278,
                                   -0.11023900324857563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33200783058090444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47516269300997027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16001831132413852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092287544360171628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14370995639014739,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59380416943624459,
                                   0,
                                   -0.054467816076447295,
                                   -0.67358795721125575,
                                   0,
                                   0,
                                   0,
                                   0.87318581457176947,
                                   0,
                                   -0.21357063963345529,
                                   -0.4503777308419708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26911077055797594,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08289342293546681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032212242798358465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29049154364335661,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28029668424819099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71162586654739135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55759777979548397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13668996054169655,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16630598215445194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38814507845527202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65563967392513567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28316090734428401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59654155121706098,
                                   0,
                                   -0.39750936696756667,
                                   0.50790453627766796,
                                   0,
                                   0,
                                   0,
                                   0.68190203607132838,
                                   0,
                                   -0.47337237524210435,
                                   0.35525261745926817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081389632032907083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023009245903650888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25642977428819996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23667629463550219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35565976256657955,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.82202651731977405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4004717008177382,
                                   0,
                                   0.47861944497993097,
                                   -0.10159042523667333,
                                   0,
                                   0,
                                   0,
                                   0.012541234498163981,
                                   0,
                                   -0.46083365939575877,
                                   -0.39992997127358021,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32730193929159934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27802383651730073,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46833054239034089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56416161344905291,
                                   0,
                                   -0.35654601488662724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36306487838743617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22712855349422253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3327755016436747,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12138232431702992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1624389958160693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12940698741439327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36309739188615314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17884940042418807,
                                   0,
                                   1.4695932359177037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33781805499348494,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20689024741222978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13800506233859205,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32978964468680855,
                                   0,
                                   0,
                                   -0.030428446470939674,
                                   -0.26820064954572598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099635894703727926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24863691795857409,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018444804217877329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2307145165555442,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41450158033851736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1964205271531646,
                                   0.57346943947771623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36709549876332564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16269592337481009,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32858731887055831,
                                   0,
                                   0,
                                   -0.20637428095399107,
                                   -0.35459641566622169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0086760503922786759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6525457407868972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15861700335297962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34642118846118564,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11787670306515938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.071935233551552485,
                                   -0.3267759941012941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017919041338211303,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65682035244177595,
                                   0,
                                   0,
                                   -0.9772651219472549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28361426135714607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55346170833230302,
                                   0,
                                   -0.62583459052447221,
                                   0,
                                   -0.21032537342402308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020010493079501347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33198856645139219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24165714634431884,
                                   0,
                                   -0.42120439263480042,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28213540675295939,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078891587502847804,
                                   0.050382004896320443,
                                   0,
                                   0.37585048886320516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.050941791744860826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17816111636590451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21867332966769851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92484155550255109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52130807439116822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21287414028312521,
                                   0,
                                   0,
                                   0,
                                   0.25167104009127828,
                                   0.47484334053893174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7244074569925405,
                                   0,
                                   0,
                                   0,
                                   -0.18105063511508632,
                                   0,
                                   0,
                                   0,
                                   0.84663350133103898,
                                   0,
                                   0,
                                   -0.52830219594277283,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46295195445466053,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63878215016634887,
                                   0,
                                   0.18062926285756997,
                                   0,
                                   -0.48459499005353807,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50267296128940109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.035116318932111944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49798862470026034,
                                   0,
                                   0.3501459764125982,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21486595545353337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26866987295278077,
                                   0,
                                   0,
                                   -0.068806848978589158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046125536871144804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28614775124178332,
                                   0,
                                   0.39557716576644064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36484511722773716,
                                   0,
                                   0,
                                   0.090090426392567119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26626217784258216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20842159289298839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14176902740203234,
                                   -0.51052930334544167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19441789544848984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2496498474232432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18030790957757814,
                                   0,
                                   0,
                                   0.24213068414133546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41538746261528275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.2667113429801273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0011834744124469831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63382984728843683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36407185400960906,
                                   0.52505177048058405,
                                   0,
                                   0,
                                   0,
                                   0.64331885718323023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6551508629749071,
                                   0.11034549321139948,
                                   0,
                                   -0.086484980734236772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012144545068965416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078115514896608521,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068888547262395516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3704852435606541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39713368068215454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41637062399211239,
                                   0,
                                   0,
                                   0,
                                   0.26710153697122757,
                                   -0.35454009577273643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14327570026304504,
                                   0,
                                   0,
                                   0,
                                   0.45964150043873148,
                                   0,
                                   0,
                                   -0.15876825956620269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20594638878605701,
                                   -0.084985744742886907,
                                   0,
                                   -0.59575245373197117,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81572082590634754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63876998248841244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080806790023821129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43736543280560969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48725632384651996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42867718715829883,
                                   0,
                                   0,
                                   0,
                                   -0.50512847447810572,
                                   -0.1012429346272538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092249147111268831,
                                   0,
                                   0,
                                   0,
                                   0.057986044156214202,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36031906797530028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35225810806989827,
                                   0,
                                   0,
                                   0.37031536061976611,
                                   0.30722739773721647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22567141097319554,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25539087723713644,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36273013612059818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065184686052990756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25526619246912557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13699537459466993,
                                   -0.034090376585886331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42130423450854998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18004754877060331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.044932577235115775,
                                   0,
                                   0,
                                   0.13970140699241487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33058022659968866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34674719918966762,
                                   0,
                                   -0.32883008547992804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43665875621155648,
                                   0,
                                   0,
                                   -0.023154098313986873,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39358762111313556,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085217457283358944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40553709595296927,
                                   0.073394126650391869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2547970119618016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14231150901466796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75050138741411354,
                                   0,
                                   0,
                                   0.39565979723645195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28213162506483269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74913504332709868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1441957597074543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27642257599946574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86705929802307358,
                                   -0.51063973180732281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10054545420497432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27609208720236411,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3502677454459357,
                                   0,
                                   -0.50487741145718823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2167512432598182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060857791872409625,
                                   0,
                                   0.39443777678323261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026040773723196398,
                                   0,
                                   0.080378494409980961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5680407737335319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43340645414074286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.082381718501251866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31617755899178945,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56826164431088211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58523871998906252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19994547603429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17537950762875643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28710710919249766,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33642612426463936,
                                   0,
                                   -0.11286143320124749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099078228467837121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28878716516006109,
                                   0,
                                   -0.59405442145846599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14293924389630744,
                                   0,
                                   -0.53863598239880284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.064928955103421976,
                                   0,
                                   0.51934594129472866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24399232157543038,
                                   -0.67673260015818082,
                                   0,
                                   0.040532067345991574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27152436234034261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2702521209056814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74683639052532869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1305270823948925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10003468124396131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.721836020441323,
                                   0,
                                   0,
                                   0,
                                   -0.24088973836925898,
                                   0.16614000323246911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19495885777301084,
                                   0,
                                   0,
                                   0,
                                   0.72684534913446086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099109336623065855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.93056940991939818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098948539628366264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16426556622199406,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24837430235566738,
                                   0,
                                   0.43175588653075264,
                                   0.64043962274943989,
                                   0,
                                   0,
                                   0,
                                   0.22412871272338647,
                                   0,
                                   0.57203365833075182,
                                   -0.13537044072653473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2400691762609736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52553821716501692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.78626275019934955,
                                   0,
                                   0,
                                   0.68836463499525347,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35361894805219962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50061856482206513,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25763443758824101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.90109258610653509,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47212384298713234,
                                   -0.52035153593584071,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49798109112082278,
                                   0,
                                   0,
                                   -0.63379161749815516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19485486834107141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018489456419114397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60866984760047138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69864112674741308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54092302956551608,
                                   0.44149699409183929,
                                   0,
                                   0,
                                   0,
                                   -0.11575333228684831,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059532691378084687,
                                   0.12075665526642204,
                                   0,
                                   0.40890885792779003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32692346111734372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30130941651730808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7800356600514502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33676149953929502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39327472673067232,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73451186515049149,
                                   0,
                                   0,
                                   0,
                                   -0.44297013741971097,
                                   -0.11476795185575145,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32309800348198031,
                                   0,
                                   0,
                                   0,
                                   0.33857340101108208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42837830735486382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21316454262267223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089663728232675613,
                                   0,
                                   0.12963798236454463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44786704645192493,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097902796556306487,
                                   0,
                                   0.11999247258201487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69755551893265932,
                                   0,
                                   0.14466495449006497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1188596631563052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28111235893679704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.025944654407163599,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52706989855593034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054982117487305388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54942721775021797,
                                   0,
                                   0.5854403799828789,
                                   -0.26177961332974842,
                                   0,
                                   0,
                                   0,
                                   -0.43434678649194525,
                                   0,
                                   -0.082982149703432651,
                                   0.27298044096301288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7539770202813888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49519470589525472,
                                   -0.082160126358972088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46254949187546113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16215855899138817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11324156857727917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3070632094563302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38454727786049536,
                                   0,
                                   0,
                                   0,
                                   -0.10846548536639659,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19327443303337452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91785841153561321,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55567002703521684,
                                   0,
                                   -0.0040840664885842502,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27472964399075711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081374119499771011,
                                   0,
                                   0.23813518871402473,
                                   0,
                                   0,
                                   -0.32953653697987573,
                                   0,
                                   0,
                                   -0.54294398269107824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34631762253394954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38015222731048054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17141291839357384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43718234193754441,
                                   0.052249141070034186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21352989013998436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.015213358624375745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21672779565656625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.085429830775531998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.64039699378563064,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18650886057645472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2536204729278591,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14329580313549309,
                                   0,
                                   -0.31113936960198824,
                                   0,
                                   0,
                                   -0.070817601535021979,
                                   0,
                                   0,
                                   0.20406769862265178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33440948700315642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30952490007387123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42794686235517715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55382536264739057,
                                   0.3351855669037116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16172218414287035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89884700553621188,
                                   0.45379063191267199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23267041543002392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69034872651623469,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070593938378150464,
                                   0,
                                   0,
                                   -0.50847612089279959,
                                   0,
                                   0,
                                   -0.069731278941092836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31933052190338057,
                                   0,
                                   0,
                                   0.37708395508453962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65476003187944054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14473094275063947,
                                   0.34722435948780828,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40661027846716019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26887045694037748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25269836922853944,
                                   0,
                                   0,
                                   0.177543031234284,
                                   0,
                                   0,
                                   -0.50447965543191808,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15603473372340032,
                                   0,
                                   0,
                                   -0.43060043342323967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68496011327887374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078526965214909539,
                                   0,
                                   -0.039685344137890932,
                                   0,
                                   0,
                                   -0.66110322445187786,
                                   0,
                                   0,
                                   0.45537508281779498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16623042271551414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41647132091058731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11487990087100483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077563829459134537,
                                   0.1929366366147785,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30052562315533404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35083506872302206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29933915740747552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.86590369131065803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12835265181906649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060999461716934392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037476190190160456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.096771925616314647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080975383876035895,
                                   0,
                                   0,
                                   -0.23229588149169647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057243691106152933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78776053089203601,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27353710797264152,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14598122095612606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5665833271239501,
                                   0,
                                   0,
                                   0,
                                   0.47454306168884147,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32094404956334227,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38375868629842563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28843393408796708,
                                   0,
                                   0.54616733654397387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20842045015314284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090524834252841302,
                                   0,
                                   0.42162066148218968,
                                   0,
                                   0,
                                   -0.16445273993764215,
                                   0,
                                   0,
                                   0.25118471669902614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41569253733760403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.036922929133457329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4256944539955288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34732816468073019,
                                   -0.30418023793438392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39415857092270146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42713889192629462,
                                   0,
                                   -0.22656647549176109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33935795556120069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15523284294335973,
                                   0.06825310701876397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15714357179882743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36223112450478961,
                                   0,
                                   0,
                                   0,
                                   0.069071913698079024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15043633488101685,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55961586201960012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26293379747483131,
                                   0,
                                   0.23809420473417728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56063793700678966,
                                   -0.010464026698501216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60534720623594673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.89435179938220144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.9467539905338106,
                                   0,
                                   0,
                                   -0.055254154422714544,
                                   0,
                                   0,
                                   -0.21189563840157691,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29635338516866239,
                                   0,
                                   0,
                                   0.38250700147726402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045032564966701653,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.043208395223263515,
                                   0,
                                   -0.19699773303340914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12418045265987294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16502452046046917,
                                   -0.45247188345205125,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50721468471417741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31900011024822733,
                                   0,
                                   0,
                                   0,
                                   0.36134792452060294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.098247572842041941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24575232713877909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38347397479909701,
                                   0,
                                   0.072394991376946938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57432712686983323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45149455883166234,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.99045476191787984,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14899148115964644,
                                   -0.01621436620868677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10918234741017185,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61322958062592281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13232574582461581,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60502179306495374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67370547508316569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024717814462923468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16745923412318497,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11128571169628777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023915763295487155,
                                   0,
                                   0,
                                   0,
                                   0.055743165836122155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.099813207565376566,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36815091854182536,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30331112429061691,
                                   0,
                                   0.63930664565559858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36804409738064237,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024844107632522414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15801408865472433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12499119846606803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17601976972464678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13688581632133837,
                                   0,
                                   0,
                                   0,
                                   0.03219873547482377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15003151102301543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11174183720915866,
                                   0,
                                   0,
                                   0.19580199707955054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50729237396667759,
                                   0,
                                   0,
                                   0,
                                   -0.30884841332314272,
                                   0.63211626221131456,
                                   0,
                                   0,
                                   0.062469815283665242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28016712402583638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18584414799682014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32655105034689391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11105342531024348,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41694962015249148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30298861877605049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28776697970995552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66714471740272374,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23011410968618035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42435893511653289,
                                   0.42917428165325378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9812227303640908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36781224677308433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37445955220186744,
                                   0,
                                   0,
                                   -0.012276672988964454,
                                   0,
                                   0,
                                   -0.16110425600123282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.900922588684401,
                                   0,
                                   0,
                                   0.53481636893143636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19401418654529207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029423751801781525,
                                   0,
                                   -0.20022577287274981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26550443963894399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5862013510201054,
                                   -0.31746630737531195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060057917212597782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0061397251268524916,
                                   0,
                                   0,
                                   0,
                                   -0.54721152129108597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12008816599306001,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17155292257839538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31132847966309979,
                                   0,
                                   0.016501551406936772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38635654182519474,
                                   0,
                                   0,
                                   -0.57250628045886398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46236651562636988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16438037040548231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21174944961413047,
                                   0,
                                   0,
                                   0,
                                   0.44044496005578782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92755499975921152,
                                   -0.15617011422693475,
                                   0,
                                   0,
                                   0.0886434515671774,
                                   0,
                                   0,
                                   0,
                                   -0.18861339301441998,
                                   0,
                                   0,
                                   0.31681175495580421,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24439624664123341,
                                   0,
                                   0,
                                   -0.45945082863496389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31505607260945251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22711600882660193,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20331911920949927,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34206556665305121,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4900618770002636,
                                   -0.69204439640060378,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66615197434087492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18212628222871788,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.097902896732867256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.030766632534314109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.5752025063167761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.069799519445127023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49047292729894049,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52984825923458057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10056816393530663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.62551850528191966,
                                   0,
                                   0,
                                   -0.028507116362081669,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17839922496453187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010047565953566651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62161309709621693,
                                   0,
                                   0,
                                   0,
                                   -0.22530792471643268,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22231105980950175,
                                   0.55708757031446798,
                                   0,
                                   0,
                                   -0.017075812742669269,
                                   0,
                                   0,
                                   0,
                                   -0.29302411099116854,
                                   0,
                                   0,
                                   -0.28934561787395358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14116584147361116,
                                   0,
                                   0,
                                   0.27486384634286398,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12293753439784019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25755655099404473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034645490258017338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066951386089090431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73388871038647985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11243312907703519,
                                   0,
                                   0,
                                   0,
                                   0.29638453484763239,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3924343894834636,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.057178087176020277,
                                   0,
                                   0,
                                   0.17933980146013384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14970457494901818,
                                   0,
                                   0,
                                   0,
                                   -0.044532260122267839,
                                   -0.21823293556437454,
                                   0,
                                   0,
                                   0.089498356697105361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13941730395841384,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0032076321920980061,
                                   0,
                                   0.018371021797541978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069804984067213069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28715877744067875,
                                   0.19530827062958844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28557680117740292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010727076219630507,
                                   0,
                                   0,
                                   0,
                                   0.3867347865067276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40538893594701519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35685037422636173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28680650743867386,
                                   0,
                                   0.51865274558493868,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50910886085117968,
                                   0,
                                   -0.36504597570208086,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042638328083146035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20486189361310475,
                                   -0.073818148914154724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39242445360673417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35079194349392678,
                                   0,
                                   0,
                                   0,
                                   0.15168607621809455,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10951802743063103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11317763191496862,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4470854322976458,
                                   0,
                                   0.18320670905541567,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092812354046185097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54221027236990837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18337143532827219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7145612353422337,
                                   0.43297815353821745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27892988539644137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1794386464512375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68972010613398826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18898933957222624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46741675972346169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62198874930490844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59718280793761591,
                                   0,
                                   0,
                                   0,
                                   0.044266687718214258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018648116741165087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32825579404270061,
                                   1.0920157556849501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47199851910432211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31096671401428816,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39989043111023787,
                                   0,
                                   0,
                                   0.32195017820048932,
                                   0,
                                   0,
                                   -0.16988429081719944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74252427880139904,
                                   0,
                                   0,
                                   0.28959964320108156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32215386376400851,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14031875521078474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10986416264895013,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073165085278463077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51924853079015276,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31135969868508062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7324288818066812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21431627926619107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11806756473159949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6218944443533958,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28243744644339186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10664945946096248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16518643857009196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08535380362631971,
                                   0,
                                   0,
                                   0,
                                   0.31675380240164397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34165152565313478,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11240992031892726,
                                   0,
                                   0,
                                   0.094886564189348099,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26912957290910056,
                                   0,
                                   0,
                                   0,
                                   0.15354986203495208,
                                   -0.16299396402301891,
                                   0,
                                   0,
                                   -0.32181878377022327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1506307234178971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.068996808684206268,
                                   0.044387233296029213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.010322837960827919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0023977832956237725,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.023809686561424091,
                                   0,
                                   0,
                                   1.0239422316607354,
                                   0,
                                   0,
                                   1.2267095068918861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29201933729467833,
                                   0,
                                   0,
                                   0.3442050122899396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36512524811452951,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.065611676479778863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.036919098371234416,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42772153164390453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48962700186782077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37175678992821837,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16435918806955341,
                                   0,
                                   0,
                                   0,
                                   -0.63624988550749328,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037878750047030944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62270208135535587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1395134086538487,
                                   0,
                                   0.58955508941851598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35633358768510165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63399850122761969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39950324749339461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1468681898264546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52950959014907417,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49776489351295322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20648527793708865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20707127884809681,
                                   0.36497059415763639,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54485049380299833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.027548631664058867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.1256512741833056,
                                   0,
                                   0,
                                   0.1813831735850831,
                                   0,
                                   0,
                                   0.50426697788148755,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42031481590093844,
                                   0,
                                   0,
                                   -0.62415782168213552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20873745624814297,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.8371813932833991e-05,
                                   0,
                                   -0.043715071247244885,
                                   0,
                                   0,
                                   0.29509528423286735,
                                   0,
                                   0,
                                   -0.018975506924133731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54257034778012025,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.072032179625752812,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31901029365242928,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30795236782671181,
                                   0.62120063850595553,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16906808329914286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054244694707210772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58051674639446293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31297003297975179,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58394167388331786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2423814005007949,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33051857892369718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11077595505574418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2021314267246187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54205086562885407,
                                   0,
                                   0,
                                   -0.22666508912970218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19944292048016124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55842636436537252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28511487675829678,
                                   0,
                                   0,
                                   0,
                                   0.82489408012486498,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.082956728703383859,
                                   -0.52910385849537656,
                                   0,
                                   0,
                                   -0.21897766004580785,
                                   0,
                                   0,
                                   0,
                                   0.38012592974970161,
                                   0,
                                   0,
                                   0.14828775366308491,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33854260738940589,
                                   0,
                                   0,
                                   0.11470590100928392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36440429439189109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18373614857128504,
                                   0,
                                   0.22319254402341845,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79714967066283882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15569073543870168,
                                   0.0088369830973201724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052216810003126779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12893927941096145,
                                   0,
                                   0,
                                   0,
                                   0.1206496229447267,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25493424104701745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31614300700829279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24039830316271976,
                                   0,
                                   0.0048315991314868724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0063691865272314241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35849618662036087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5297856280878106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24115813123212076,
                                   0,
                                   0,
                                   0,
                                   0.12988658156191749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71814994087866912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39707075110534246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59440904786465676,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17970001919745482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59075641313623328,
                                   0.37335487282852609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20336120404174066,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84993657634847408,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74885723498872359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18192408614044658,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61244037566166865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29359301619528716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70033931186561127,
                                   -0.79817909014231558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2232226847230514,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59414782656543941,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092713881307589341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36039272318943799,
                                   0,
                                   0,
                                   0.070400719385815463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61486535717595692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30989104735356543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16501659411389666,
                                   0,
                                   0,
                                   0,
                                   0.14780778857859975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24342424421415271,
                                   0.16726908105312546,
                                   0,
                                   0,
                                   -0.67376616612664331,
                                   0,
                                   0,
                                   0,
                                   -0.53710267316006488,
                                   0,
                                   0,
                                   0.31896274812138825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1040076852388445,
                                   0,
                                   0,
                                   0.022040089212991869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041163462023644126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29765017575141023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.80840673381787798,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51559286081656996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70096033196055652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11654706897025228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15944658434587175,
                                   0,
                                   0,
                                   0,
                                   -0.096480349601713519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40056168646912821,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1723355784327904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21006651436789942,
                                   0,
                                   -0.36694661118651456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41219452695761866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074904549200379977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19487111256185607,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60404995053264043,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.2994150395002668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60355299838349352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35442949090407905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17232549463522817,
                                   0,
                                   -0.38427219656767875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29577436173428689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24663671769707318,
                                   0.38373642221290905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012941027217537954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44739138714347382,
                                   0,
                                   0,
                                   0,
                                   0.036541432462716711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11815653297422875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16652486708563552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4838252428780706,
                                   0,
                                   0.2227843227989515,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70925177980917531,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20068428621126519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91714260131226544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33057642492226957,
                                   0.12651788219299898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35360667015579944,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56981779595913551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0813593118276621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.058853961325066123,
                                   0,
                                   0,
                                   -0.27157767379117698,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17752028862955724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54350076575412865,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26316839500282441,
                                   0,
                                   0,
                                   0,
                                   0.0072998230297288882,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051795466097363435,
                                   0.56780012400208524,
                                   0,
                                   0,
                                   0.1937096754160354,
                                   0,
                                   0,
                                   0,
                                   0.024717428808876247,
                                   0,
                                   0,
                                   0.75683114130532236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16298856846637069,
                                   0,
                                   0,
                                   0.28862177957064394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32256109692015034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84212784776030758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29511954775518745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24283807571743485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22086742233757378,
                                   0,
                                   0,
                                   0,
                                   -0.2345246398738155,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20241191808594727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17620557340329973,
                                   0,
                                   0.47639751575643985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097579245290459471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25490213700576281,
                                   -0.16702491261502092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14360699212308142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.041046122798623907,
                                   0,
                                   0,
                                   0,
                                   0.35065209215791876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66695907505126628,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11204254909301761,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.026630184754427362,
                                   0,
                                   0.19037101520081062,
                                   0,
                                   0.34126531866089643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07398682550197011,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28162449817636859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.040533481705667729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24887292477177508,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.82932074613366824,
                                   0,
                                   0,
                                   0,
                                   -0.02358387066196424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38806567502722067,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28494412035811473,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58586639365906479,
                                   0,
                                   -0.55339090506104116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23664805853329757,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50302449257123671,
                                   0,
                                   0,
                                   -0.15492523363032423,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40738059852235647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63456523646310781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055880885507394083,
                                   0,
                                   0,
                                   0,
                                   -0.096318300036679974,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24702225619867807,
                                   0.055258805237201079,
                                   0,
                                   0,
                                   -0.53823435734962133,
                                   0,
                                   0,
                                   0,
                                   0.19521919888207634,
                                   0,
                                   0,
                                   -0.00060392727393156209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.84856128560401989,
                                   0,
                                   0,
                                   0.17542806691836818,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018453274878686081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1665817702588302,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46466421035008826,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24139080147034811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0014224151882783129,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0424666174700052,
                                   0,
                                   0,
                                   0,
                                   0.24057078929876047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32589002720387833,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42909249312869135,
                                   0,
                                   0,
                                   0.38204418977138443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17828723328545637,
                                   0,
                                   0,
                                   0,
                                   0.12805834543969441,
                                   0.17141158827708353,
                                   0,
                                   0,
                                   -0.12478634496912738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33010171549137668,
                                   0,
                                   0.43825895241626106,
                                   0,
                                   0.09498636927794879,
                                   0,
                                   0,
                                   -0.33790861571725778,
                                   0,
                                   0,
                                   -0.24375045977324183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20589268912898101,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54312264910759167,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28780107758527967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19940474910201289,
                                   -0.096231193959554137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3950746672944212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42325671500179479,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31469627621093027,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69273881315206243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17708421890492326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30977155858831729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31597950649239587,
                                   0,
                                   0,
                                   0,
                                   0.060875633164448995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15704295751506606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17120648098096181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71705770606436492,
                                   0,
                                   -0.034114521714938666,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79434439298127402,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28157491278130181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25124042474390701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14203298809028891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15143359669592543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61242974581793519,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23289892904784842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42050312658233668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45645736862581904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28056406283779567,
                                   0,
                                   0,
                                   -0.0030153388039987875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13165815027591146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081814563522167288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29381781681808206,
                                   0,
                                   0,
                                   0,
                                   0.47314964398544557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.49897169318053664,
                                   0.13656711162099408,
                                   0,
                                   0,
                                   0.08149085107505423,
                                   0,
                                   0,
                                   0,
                                   0.31407411149037306,
                                   0,
                                   0,
                                   -0.22257432589890183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40175433292765378,
                                   0,
                                   0,
                                   -0.55180312111057361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12088499317577525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39229699693045772,
                                   0,
                                   0,
                                   0.16419976210685236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65130105257650162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.060067796942329096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50175639120050641,
                                   0,
                                   0,
                                   0,
                                   0.34493216534395188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62312019544300712,
                                   0.50703975576322879,
                                   0,
                                   0,
                                   0.28108600440495957,
                                   0,
                                   0,
                                   0,
                                   0.42815251459003212,
                                   0,
                                   0,
                                   -0.38640403911344495,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06001013550870761,
                                   0,
                                   0,
                                   0.48527990505494439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3435598194909007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42408344717149105,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36042619938023823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.03535558910413375,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.034253280059099556,
                                   -1.0468802982875614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70665126557900626,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29206109002398728,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32518043572059169,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012278687617010176,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22975617888043157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5372704975942314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16129742138818295,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29755945197330308,
                                   0,
                                   0,
                                   0,
                                   -0.088890427071344869,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11070238168581853,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53022461913175856,
                                   0,
                                   0,
                                   -0.26790579234206524,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34589321181084914,
                                   0,
                                   0,
                                   0,
                                   -0.13711673780134498,
                                   0.069245298402765054,
                                   0,
                                   0,
                                   0.10258589948222419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13043458659851426,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05069855897703162,
                                   0,
                                   0,
                                   -0.040497465290952571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47048571792751182,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45020469276167552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16010874282079643,
                                   0,
                                   0,
                                   0,
                                   -0.50361056049635389,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12690912581171906,
                                   0.045105976909492432,
                                   0,
                                   0,
                                   -0.22692477734735805,
                                   0,
                                   0,
                                   0,
                                   0.73978548982262615,
                                   0,
                                   0,
                                   0.28958976710757822,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05318915568492727,
                                   0,
                                   0,
                                   -0.28937795242866665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38766096826115037,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46001843133295262,
                                   0,
                                   0.046383288170262257,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098355329339534836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36983172387268243,
                                   0.18730968694884836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24818398418751336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.009977841579842061,
                                   0,
                                   0,
                                   0,
                                   -0.11979656220073856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40623168702149814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52929140146577547,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16647706502243753,
                                   0,
                                   0.23614231252730494,
                                   0,
                                   0,
                                   0,
                                   -1.5095952018169929,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52231893920074579,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54280892938386038,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17777839022323194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16940134936385023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24345036995412173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.074168266443599681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17632715844218275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12342579782760563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.069124508691596781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43124374556057782,
                                   0,
                                   0,
                                   0,
                                   0.041583567512495312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47988600939456139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15068180302868478,
                                   0,
                                   0,
                                   -0.033459599148834035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.04775405925167725,
                                   0,
                                   0,
                                   0,
                                   -0.048320046534934213,
                                   -0.23726040367524631,
                                   0,
                                   0,
                                   0.38816312345070419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.53851814808966836,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59635586575675881,
                                   0,
                                   0,
                                   0.22935245934964305,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16316171052771197,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3784637130270771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42127671786755555,
                                   0,
                                   0,
                                   0,
                                   -0.029651856657866689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15779760433509188,
                                   0.32996871594425897,
                                   0,
                                   0,
                                   0.058921838351761888,
                                   0,
                                   0,
                                   0,
                                   0.51231029205049117,
                                   0,
                                   0,
                                   0.30466997839731758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19361569126196188,
                                   0,
                                   0,
                                   0.64152825260323154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.89707027781993087,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43799428162846732,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3987114565771317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2844674069841156,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18130207785551555,
                                   0,
                                   0,
                                   0,
                                   0.63800037796859366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35826464003002312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21093171631372573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31646385634845214,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016350712861299743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39734028222027906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.93193769516604874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041700523491187212,
                                   0,
                                   0,
                                   0,
                                   0.7947204112250138,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39540897384750695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45268840834174412,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.051733970880032364,
                                   0,
                                   -0.33403413241741026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19325489259003367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44609320076205783,
                                   0,
                                   0,
                                   0.076395711519314777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31639543836475148,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21909172629401624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29487555527066661,
                                   0,
                                   0,
                                   0,
                                   0.13354358541192718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30590816779546487,
                                   -0.85712640711738897,
                                   0,
                                   0,
                                   -0.70180857215865122,
                                   0,
                                   0,
                                   0,
                                   0.23450134100472572,
                                   0,
                                   0,
                                   -0.14254977407831612,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37781992449146085,
                                   0,
                                   0,
                                   0.14247226667318677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.06118664434080287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.033126010608847789,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57802823101941281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18057543969814396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23546838936680733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067792723012302131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45865894854395772,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50878452902429372,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32079214205648832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23084237732968768,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56503841355581286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31125787180194231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70444031923086881,
                                   0,
                                   0,
                                   0,
                                   0.078348620087299287,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1678906061957052,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018980773034921489,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16639609729348934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10450198708015496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067427515040544561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10289171211201072,
                                   0,
                                   0,
                                   0,
                                   0.63054084739507998,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0039629803884798902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32317288617528261,
                                   0,
                                   0,
                                   -0.38255178301653736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.080922933390154189,
                                   0,
                                   0,
                                   0,
                                   0.1754617826477857,
                                   0.16636271562579186,
                                   0,
                                   0,
                                   0.43348453082383337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21117157271587467,
                                   0,
                                   -0.64568390226133643,
                                   0,
                                   -0.13755695887497404,
                                   0,
                                   0,
                                   0.13587742627678173,
                                   0,
                                   0,
                                   -0.10922377738796563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29844327359305961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051872260415947904,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12856449908125023,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29331982850261795,
                                   -0.45745954969126451,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36081042409136349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67641031574288912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16154503554972119,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65348389197371537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47019801045935455,
                                   0.016456310188866452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25832720753658217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55765128157620081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3651548916541979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66310141113137866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.55640044235534136,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012331017041889727,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70914362686601096,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.062516004497472216,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46313920422047206,
                                   0,
                                   0,
                                   0,
                                   -0.14098233893155404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045932596892077196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22725374353080796,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.65963475117402015,
                                   0,
                                   0.23595226121979132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12018112299079624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051943643210790424,
                                   0.32966594182774095,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3674873471273381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01433877671585914,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2611497550874311,
                                   0,
                                   0,
                                   0.5463587728406013,
                                   0,
                                   0,
                                   0.11775608964288743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79184497281162436,
                                   0,
                                   0,
                                   -0.27927430064589687,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.77577578955297954,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15785554462133733,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28314839809240794,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4286760955479999,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22756469557721559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42966158711045799,
                                   0,
                                   0,
                                   0,
                                   0.12637767672350786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.196167226594716,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.098394621264116494,
                                   0,
                                   0,
                                   0.24995952140490976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066794662497577664,
                                   0,
                                   0,
                                   0,
                                   0.25404316017781325,
                                   -0.080368414151543582,
                                   0,
                                   0,
                                   -0.23922333697600329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46416607347721872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30768768434604221,
                                   0,
                                   -0.26111464133550177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.020304087809851989,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33509421972916414,
                                   -0.61788776707092874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48602624513856701,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26628386100146617,
                                   0,
                                   0,
                                   0,
                                   0.13329837091741881,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0087568743388064044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.059678118163567391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0097996538805540552,
                                   0,
                                   0.11845038232964056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.66548460837637657,
                                   -0.20281693026332462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012156339718948306,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60349339412758418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31487966500197073,
                                   0,
                                   0,
                                   0.14981148260423705,
                                   0,
                                   0,
                                   -0.74318014332248827,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57792858782863532,
                                   0,
                                   0,
                                   0.47289003897867721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33867665852695883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3458584807545752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19329467849921356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39831752234481915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0528959122115613,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14883851723090219,
                                   0,
                                   0,
                                   0,
                                   0.041160737104510792,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35141023288489898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49883089667285563,
                                   0,
                                   0,
                                   -0.33405088692123019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13871619114436309,
                                   0,
                                   0,
                                   0,
                                   0.11522847218640003,
                                   0.111433294320005,
                                   0,
                                   0,
                                   0.083680100491915238,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34909341276233258,
                                   -0.10949627787956445,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02896850594776415,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5642165210908433,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06865023574758912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.078036328788678111,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32087805045125845,
                                   0,
                                   0,
                                   0,
                                   -0.11469925079136063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.9178374626591963,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.075200366755361472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52696279771599019,
                                   0,
                                   -0.54011080656862775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.288861452474106,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16173515346842338,
                                   0,
                                   0,
                                   -0.74150606612317582,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013921010527564448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33592311036994627,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87338658733301111,
                                   0,
                                   0,
                                   0,
                                   -0.25165691539649104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24331759755586563,
                                   0.05834180108637621,
                                   0,
                                   0,
                                   0.27530545791231187,
                                   0,
                                   0,
                                   0,
                                   -0.34675395180642238,
                                   0,
                                   0,
                                   -0.45206129863090516,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16340996454069673,
                                   0,
                                   0,
                                   0.013176443276686149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076779401878064646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39661769530765623,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27182338629569358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31157927430469501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16819389006006538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40305219346605847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14187524438315444,
                                   0,
                                   0,
                                   0,
                                   -0.62891539153252141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16748951773301252,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19072510609912863,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28479493499268937,
                                   0,
                                   0.28053896342457196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61814842255580793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.099679271201028236,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29608660057747432,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30932779473663952,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.085594536049421854,
                                   0,
                                   0,
                                   0,
                                   -0.71622981020271848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53516494432103501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35338843337180731,
                                   0,
                                   0,
                                   0.1268169110501654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.77405853867625585,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.097121570998806694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0012140657216384958,
                                   0,
                                   0,
                                   0,
                                   -0.070511473019536211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16768257907324122,
                                   0.53661797730650518,
                                   0,
                                   0,
                                   -0.89816772052347582,
                                   0,
                                   0,
                                   0,
                                   0.51270812567727997,
                                   0,
                                   0,
                                   -0.093886452821572333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.092345999976966422,
                                   0,
                                   0,
                                   -0.33482863641811855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16016571799114132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.088370974837540181,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039886954080429915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44512858825992446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12297809036429017,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96254185023076488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54292541199125322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39375494451815252,
                                   0.79975182505048437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27291203297160149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12257318481564745,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0030005792565886147,
                                   0,
                                   0,
                                   -0.79954072765735518,
                                   0,
                                   0,
                                   0.64798757228186932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22296365037275628,
                                   0,
                                   0,
                                   0.56384316144704161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.055110704930677518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25429979969324401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41588314649999286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1306298853548282,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2505312682533184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44458489950204244,
                                   0,
                                   0,
                                   0,
                                   -0.3661825078022527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11574385949386187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28507505654243037,
                                   0,
                                   0,
                                   0.10901142373117947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1566088997252158,
                                   0,
                                   0,
                                   0,
                                   -0.30672022232372836,
                                   -0.093083021462643648,
                                   0,
                                   0,
                                   0.34202524926611311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.00030573599156438758,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41327958624824879,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.059816758955352024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2479625383484787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3444249190614016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29513945964978044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038043267130964439,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18689650629644933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.72251165994861188,
                                   0,
                                   0,
                                   0,
                                   -0.57000463333257612,
                                   0,
                                   0.31573233466669426,
                                   0,
                                   0,
                                   -0.24847258829674621,
                                   0,
                                   0,
                                   0.084161161020091663,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.086326425718387972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5218642642679534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.235000396258429,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22977402277096184,
                                   0.19456051745205391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2844581477752981,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.079998040217335448,
                                   0,
                                   -0.56858621923141694,
                                   0,
                                   0,
                                   -0.36886458148336565,
                                   0,
                                   0,
                                   -0.43682515042420805,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33273234879255187,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071784342340563911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29945029864672867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22806750625853195,
                                   0.02700000437686681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.291812708085603,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37934488483256218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40202111528799911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38209193672994091,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22357436783806139,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48317290167957172,
                                   0,
                                   0,
                                   0,
                                   -0.23432808662232932,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18604167773895366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065177919662784051,
                                   0,
                                   0,
                                   -0.033683617752950208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10258499679995733,
                                   0,
                                   0,
                                   0,
                                   0.27624221795525583,
                                   0.23151730294139941,
                                   0,
                                   0,
                                   -0.12850892565610367,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11484131134721069,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1964196585033483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25954823802064103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17102703283824619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15336692690602977,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1158403366161339,
                                   0,
                                   0,
                                   0,
                                   0.029244246393525325,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075438755044794054,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.093919080524605847,
                                   0,
                                   0,
                                   0.48633257578461131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49417907973352693,
                                   0,
                                   0,
                                   0,
                                   0.19773164610459804,
                                   0.35842197249653618,
                                   0,
                                   0,
                                   0.40220415784460523,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049312521101582366,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.070321051591358458,
                                   0,
                                   0,
                                   -1.1072904382726414,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027506678358647361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42623532076943471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37423690684518546,
                                   0,
                                   0,
                                   0,
                                   0.027057111237716973,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18411103089358868,
                                   -0.088674276140066746,
                                   0,
                                   0,
                                   -0.010937628721661893,
                                   0,
                                   0,
                                   0,
                                   0.45911697513532246,
                                   0,
                                   0,
                                   0.01795503997931535,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47129124866957667,
                                   0,
                                   0,
                                   0.34191011777485703,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58991595316866707,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.51019497381532275,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.09395884335510471,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14436795872952754,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6227508073671717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.71089345610451349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.04685659343842255,
                                   0,
                                   0,
                                   0,
                                   0.12223832852302441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75884484183834555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0019235188129549646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38037829869244721,
                                   0,
                                   0.051442706035793248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12816111445428804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2915624823802026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.055595998721390288,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.075663798935606624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42048283223710314,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13967326598683166,
                                   0,
                                   0,
                                   0,
                                   0.089569429427429681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37713624478037711,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15312651943666425,
                                   0,
                                   0,
                                   0.3626440400203092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20449548411158455,
                                   0,
                                   0,
                                   0,
                                   -0.096660097295637321,
                                   -0.44181500529469697,
                                   0,
                                   0,
                                   0.30405551122515068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2565857928925937,
                                   0,
                                   -0.13490647051885471,
                                   0,
                                   0.46293896494045528,
                                   0,
                                   0,
                                   0.069011014502426915,
                                   0,
                                   0,
                                   -0.35143203463393857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15425862471867557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.067157099901589329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.49703562133993195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22372246290210457,
                                   0.33491460006463541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44905570464130656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38389056066250771,
                                   0,
                                   -0.3262979070776072,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19582634809658606,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26105709696804424,
                                   0.12363935583965642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34276826139240996,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58437333877408959,
                                   0,
                                   0,
                                   0,
                                   -0.15212271970334218,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19306297182258647,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.017652353535138249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16686812734981335,
                                   0,
                                   0.2771619850104573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75403122398577571,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23210821128969472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14250713421450917,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045449690104636065,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53104614657299487,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.063512756466978737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12936560660129962,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2289309801629946,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.086333307551529598,
                                   0,
                                   0.36733620994455157,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10651881465552902,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11554335221300566,
                                   -0.19709250313772775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20014302702359107,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11336561122353934,
                                   0,
                                   0,
                                   0,
                                   -0.4455719324013736,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22538799753500782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18055795025826177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23770097853508632,
                                   0,
                                   0.63460434280948574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18930526872083336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20978286115201905,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23448494731400116,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.01148843090480748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.060261971149449117,
                                   0,
                                   0,
                                   0,
                                   -0.36077277932657681,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0096324441046819614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05390700119174472,
                                   0,
                                   0,
                                   -0.013444607885713403,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37784882447058432,
                                   0,
                                   0,
                                   0,
                                   0.71699847105623582,
                                   -0.057293171774196981,
                                   0,
                                   0,
                                   0.26057891593665122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.005573286148505871,
                                   0.37033676041397906,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11401622360095454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33853453484554719,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.030694936420623473,
                                   0,
                                   0.078463318792445419,
                                   0,
                                   -0.48203054141985624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35587270175704955,
                                   0,
                                   0.6432233184462085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70914442655074861,
                                   0,
                                   -0.6754771668087598,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25375976353004304,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35076353360254048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48044766289251417,
                                   -0.21262304995561787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5523161447206858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56632228409853536,
                                   0,
                                   0.21313902422410574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14688696527828546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15199328950930047,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089896854178888208,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2114231298400199,
                                   -0.84803633693208724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38771236094418871,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20439749653395861,
                                   0,
                                   -0.094220259350903654,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12980883115856093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066152419753724184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11803172215558638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57689083564397103,
                                   0,
                                   0.12631934671265349,
                                   0,
                                   0,
                                   0,
                                   0.26136380483553179,
                                   0,
                                   0,
                                   0.36202659794253422,
                                   0,
                                   0.73381302717647545,
                                   0.26975145214516627,
                                   0,
                                   0,
                                   -0.59957944214250647,
                                   0,
                                   -0.29356431836759195,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14106439612477462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.077900965532249539,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48285986443158113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44485813578524369,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19166806407477444,
                                   -0.39976229434488558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12303344389130476,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.032335240945951242,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21143349522983113,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22280173175153856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28878444039811713,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26990969685631033,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45846816807269214,
                                   -0.37534287289083779,
                                   0,
                                   -0.10889479652556763,
                                   -0.44186641320466891,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0038960654015692334,
                                   0,
                                   0,
                                   -0.41836617371306484,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2127061260451143,
                                   0,
                                   -0.53493628044097985,
                                   0,
                                   0,
                                   0,
                                   -0.18150439849415689,
                                   0,
                                   0,
                                   0.19114653272284868,
                                   0,
                                   0.037737948115544491,
                                   0.33947604640802864,
                                   0,
                                   0,
                                   -0.59001712454707722,
                                   0,
                                   0.63410828957672161,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052839980389221629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26773634138947311,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14534312799406093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48627179916065255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087398152306299326,
                                   0.51294788078495046,
                                   0,
                                   -0.22817929480461172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96147043717006542,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.074797953337051762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.029943650848911492,
                                   0,
                                   0.53208641630722353,
                                   0,
                                   -0.42534746261300349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.92177422807139231,
                                   0,
                                   -0.10653956397651709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.362887525823893,
                                   0,
                                   0.092300643022359102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.74106921948253313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.090386788631330511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81312134776587131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38166425041885832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17507947266301035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051186215296325943,
                                   0,
                                   -0.14550034235252093,
                                   0,
                                   -0.37245519697086127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23551314747906063,
                                   0.0053223462742897024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0074016853059805394,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21970966432711256,
                                   0,
                                   0.052237219001015453,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.056741477558851137,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39479880262685058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.85695022700879475,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31330645522332029,
                                   0,
                                   0.43275971321896384,
                                   0,
                                   0,
                                   0,
                                   0.14764307342185423,
                                   0,
                                   0,
                                   0.32228648644557689,
                                   0,
                                   -0.86524733309535473,
                                   0.076315514981732918,
                                   0,
                                   0,
                                   -0.39012808207529676,
                                   0,
                                   0.0060706732858224165,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45346756066603622,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27643512626477762,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.08838683929139235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37532493532312683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87151012891769264,
                                   0.15433320873348552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30637309156546333,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15953857375361424,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22047952137812646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0006982086871952925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25960164199193575,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34947191918346765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23255994627505022,
                                   -0.14058530020266102,
                                   0,
                                   0.45921430146299108,
                                   0.52912372499105942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17325193587207713,
                                   0,
                                   0,
                                   -0.21870836984348255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16085137162316002,
                                   0,
                                   -0.37867878080851075,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12130710234143102,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.30607147229300596,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080948376313590226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.092013819653861989,
                                   0,
                                   -0.31423113091204774,
                                   -0.49270788539884891,
                                   -0.053034983684622436,
                                   0,
                                   0,
                                   0,
                                   -0.00064561054464262399,
                                   0,
                                   0.54731457869290889,
                                   0,
                                   -0.10985519280512286,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22606688416661092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.016487495820215841,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24669320293561967,
                                   0,
                                   0.41360865173703476,
                                   0,
                                   0,
                                   0,
                                   0.039068609213577438,
                                   0,
                                   0,
                                   -0.40316122857097919,
                                   0,
                                   0.64876377668729224,
                                   0.76268974841454196,
                                   0,
                                   0,
                                   0.0088252905647701746,
                                   0,
                                   0.063277751045275915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1665015025794854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23023388298593919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94172743549346472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029606200702015861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36418301724076657,
                                   -0.47631338745799967,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3049595121678656,
                                   0,
                                   0.35912732216441395,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11189935974604488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066544194027957124,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28914144592467544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0058698190894601321,
                                   0,
                                   -0.12262596084472477,
                                   0.063802668880984181,
                                   0.6721077846965855,
                                   0,
                                   0,
                                   0,
                                   0.36896391794882932,
                                   0,
                                   0.2035528408481096,
                                   0,
                                   0.11261856853649854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1195117298656969,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.045492054427431206,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11481509160286724,
                                   0,
                                   0.24061476243168525,
                                   0,
                                   0,
                                   0,
                                   0.69748760841648338,
                                   0,
                                   0,
                                   -0.029458795127463681,
                                   0,
                                   0.12597546521786745,
                                   0.25465967506138454,
                                   0,
                                   0,
                                   -0.045232156331599251,
                                   0,
                                   -0.11944215015035016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32049439163190852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.70660018463333829,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24306193190348563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011621495147631847,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42637264465970165,
                                   0.76897267235448474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31381674537495008,
                                   0,
                                   -0.55564911619107993,
                                   0,
                                   0,
                                   0,
                                   -0.082230462703828278,
                                   0,
                                   0,
                                   0.3285118900228613,
                                   0,
                                   0.047987781583351763,
                                   0.44172153997649288,
                                   0,
                                   0,
                                   0.18501055049753187,
                                   0,
                                   0.14180795819944272,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022672091786361464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.54590953781461482,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2755586668834718,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.91814417305655549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20282635112565253,
                                   -0.21513702839482188,
                                   0,
                                   0.36755019431417901,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12828269234509063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13893831104304247,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52238843594874074,
                                   0,
                                   -0.10357161918010518,
                                   0,
                                   -0.54604888908633664,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.096352076481869581,
                                   0,
                                   0.92604731983033273,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3387586554765048,
                                   0,
                                   0.96716810656446461,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62586382800474127,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.076493276618407546,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41749774500684744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38784994922380212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69659542522319584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24454254746388449,
                                   0,
                                   0,
                                   -0.14116330367491742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.52278503373873608,
                                   0,
                                   -0.79376171671822071,
                                   0,
                                   -0.50410160472504295,
                                   0,
                                   0,
                                   -0.48459952910404264,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88848700032264194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1273730576030831,
                                   0,
                                   -0.0076626109667988496,
                                   0,
                                   0,
                                   0,
                                   -0.75299339202549009,
                                   0,
                                   0,
                                   0.18516483139277767,
                                   0,
                                   -0.058895393957228176,
                                   0.62488234805431209,
                                   0,
                                   0,
                                   0.10857214811400404,
                                   0,
                                   -0.54463176639855559,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48570810963230104,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63977524935042784,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16893817890724744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66188364142063749,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23065848062272717,
                                   -0.10370132241493142,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19315231967223565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25096324715853802,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.010886167158956831,
                                   0,
                                   0,
                                   0,
                                   0.82267055664426747,
                                   0.1957618827961462,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.066585100148145782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33081342117604823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.052243227051026103,
                                   0,
                                   0,
                                   0,
                                   -0.25884107441154447,
                                   0,
                                   0,
                                   0,
                                   -0.029705387609468364,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15221738770265525,
                                   0,
                                   -0.84905568761161332,
                                   0,
                                   0,
                                   0,
                                   0.17342364892827725,
                                   0,
                                   0,
                                   -0.25899403225972423,
                                   0,
                                   0.078620819875117223,
                                   -0.18119592929405287,
                                   0,
                                   0,
                                   -0.20982593024932883,
                                   0,
                                   -0.513191903989617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6798561394579874,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31604215712354966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27206113908507512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21227575458544029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011804861781829983,
                                   0.059798825549704504,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23611149286845248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20499784490640391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34519434813468991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24145223179550529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.083902444202650472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16169718734989391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41923000865530891,
                                   0.0088615721498268296,
                                   0,
                                   0.41303623987129146,
                                   -0.50173204531690474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17222503019548155,
                                   0,
                                   0,
                                   0.252498630426226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13346592632751464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45777228376779938,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050379757773723048,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1214470970268462,
                                   0,
                                   0.43776780610199612,
                                   0,
                                   -0.8940208638134246,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038717714240826206,
                                   0,
                                   0.081730735734425103,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0939038605618276,
                                   0,
                                   0.095690832957547656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30029177389748352,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35246932181607538,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23726302389528087,
                                   0,
                                   0.071678108323695672,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.094154283356867804,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16405994839708221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.020863002754843492,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.06233575718448222,
                                   0,
                                   -0.35626830105073659,
                                   0.016742379367791285,
                                   0.22972600216615416,
                                   0,
                                   0,
                                   0,
                                   0.01704117193490641,
                                   0,
                                   -0.22345106349022612,
                                   0,
                                   -0.80264218575873392,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.094757216577785922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12268319195521619,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5101824952093329,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.36791205711777358,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45174135020030742,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29423790547325801,
                                   0,
                                   -0.62896467274506429,
                                   0,
                                   -0.13481806088414361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.60238610664101955,
                                   0,
                                   0.50694203804654814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70305442711775012,
                                   0,
                                   0.089778289867954775,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.067763136210519381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6149883519077235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25507347084735793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16921813434338534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57492592505955309,
                                   0,
                                   0,
                                   0,
                                   -0.34002301119091016,
                                   0.50978798511973689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.054790626171323076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27999992164572568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32644014259305154,
                                   0,
                                   0,
                                   0,
                                   0.084914464856751304,
                                   0,
                                   0,
                                   0,
                                   0.071329435620384629,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5936094851823166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67820303880618082,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21068768228774548,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.4337719664075218,
                                   0,
                                   0.10863732013747755,
                                   0,
                                   0.8399972058684908,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21913330155800217,
                                   0,
                                   0.19501410624180859,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.07106950793126901,
                                   0,
                                   -0.38128550293752589,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042899650325121552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.52470623774024894,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23276272645729537,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50386028456906162,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47916696388932056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.6053115456279734,
                                   0,
                                   -0.019023139511756607,
                                   0,
                                   -0.30916241753458668,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23209234650334495,
                                   0,
                                   0.53917025090983695,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33940168784224012,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32574483110620317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057570887415799465,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16345737114236372,
                                   0,
                                   -0.051309988091799374,
                                   -0.15581677883876613,
                                   -0.17127058424392161,
                                   0,
                                   0,
                                   0,
                                   0.068307290271851506,
                                   0,
                                   -0.14089844843873919,
                                   0,
                                   0.061780431480178387,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42537371102796379,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37224936852864787,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35639704779686743,
                                   -0.37094702324076301,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62132853521328779,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40639736740774945,
                                   0,
                                   0.17729584515873609,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38950436336531008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.021917211915884284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.023316333222064948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54199106454944468,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25008258648912401,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44531117992707997,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21984148517624655,
                                   0,
                                   0,
                                   0.96928660873525141,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.8179268987487408,
                                   0,
                                   -0.57773533060912685,
                                   0,
                                   0.27128776695037837,
                                   0,
                                   0,
                                   0.0087908782732375249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38017422568740122,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48695023960409961,
                                   -0.22675755488225569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20924359916633961,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089292005389694701,
                                   0,
                                   0.2611347473215474,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34222899958693059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57138333208669501,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38459533646584632,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080145802535119909,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38701740746850427,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63994699257652077,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50113041560995586,
                                   0,
                                   -0.014993093997550774,
                                   0,
                                   0.06098870247414756,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12477564741620532,
                                   0,
                                   0.69446253696097593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23694565148954513,
                                   0,
                                   -0.12504787277036189,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14801218626081036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58495393387259709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31256925913548722,
                                   0,
                                   -0.31769506015696869,
                                   0,
                                   0,
                                   0,
                                   0.478487018275914,
                                   0,
                                   0,
                                   0.66955617343355134,
                                   0,
                                   -0.31094670641503935,
                                   -0.083559456802137555,
                                   0,
                                   0,
                                   0.11861767769497206,
                                   0,
                                   0.49365983389316814,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.043388386055988507,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018163761109048562,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.68586930189337791,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15203798056682705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.14983233500886001,
                                   -0.5942510708163411,
                                   0,
                                   -0.37716203768399431,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11516651543569678,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.065632547736621916,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34261884095549811,
                                   0,
                                   -0.097898505750120629,
                                   0,
                                   -0.26257181351893855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67639453645702208,
                                   0,
                                   0.081626944932415652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11785970411978167,
                                   0,
                                   -0.53033664542648573,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0863868555348057,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084490556894537022,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.051491068581510646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0475797055191349,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67931262335340503,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.019068222788601763,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24677861015974512,
                                   0,
                                   0.2165477460515336,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.6806885273588511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.039542469463084332,
                                   0,
                                   -0.42253772238668935,
                                   -0.21040607049517443,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10582860932008399,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.61032536752130284,
                                   0,
                                   -0.23473681884448391,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48646045009553085,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24169433711753407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20816607227247988,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25586435154984744,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.31380654530253377,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.255582335338152,
                                   0,
                                   0,
                                   0,
                                   0.058861280012242806,
                                   0.0026397480659483552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25750354567012823,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25358002554156933,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21582490646751079,
                                   0,
                                   0,
                                   0,
                                   0.74638433193804277,
                                   0,
                                   0,
                                   0,
                                   -0.1816151712802912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1600132971780896,
                                   0,
                                   -0.82861717512559174,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0098552624473900036,
                                   0,
                                   1.1375366881214861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16659764980641173,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1017495107776265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37595144337999947,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37791844212599529,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.39188625060975552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31260850846769356,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17903350952236483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20140816742564721,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16401581671813872,
                                   0.25421050177772603,
                                   0,
                                   -0.018461075455691946,
                                   -0.27274507840103279,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.46905509824588326,
                                   0,
                                   0,
                                   0.075189502347830839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72752150277255989,
                                   0,
                                   0.14247662262368058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.062380649202737809,
                                   0,
                                   0.56547645907385058,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.91478152979706051,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4438584088665759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20803244371960153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0772861602910693,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22915809123962994,
                                   0,
                                   0,
                                   0,
                                   0.13565704784312224,
                                   0.4690187295267097,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44577182787260738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59877302200363269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25046081672986586,
                                   0,
                                   0,
                                   0,
                                   0.03659520304270876,
                                   0,
                                   0,
                                   0,
                                   -0.19632379815903472,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48661119787298368,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22476948384904266,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44028097881432926,
                                   0,
                                   0,
                                   0,
                                   0.08459716990513369,
                                   -0.37372451692411435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39405097711139864,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1443633975055752,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38514322531852974,
                                   0,
                                   0,
                                   0,
                                   -0.21608312568899288,
                                   0,
                                   0,
                                   0,
                                   0.029495777747786014,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.73108632136748231,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28505927773808898,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64348745235168203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30300190424041334,
                                   0,
                                   0,
                                   0.12970717612909019,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.343457518284147,
                                   0,
                                   0.049940662276908104,
                                   0,
                                   0.31175299619881958,
                                   0,
                                   0,
                                   -0.11225223246234144,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43486203980735633,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.96549756664248454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.67444770961345435,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19954969136674602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35034298585122259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18335748559921788,
                                   0,
                                   0.092397382068262146,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.87179128570506381,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45735544466888317,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21671026540907803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.41662976038817995,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19585737980587803,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25035303568979561,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26735244656037177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.58800781269787217,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28593259392292969,
                                   -0.12933980231167755,
                                   0,
                                   0.18273338605001166,
                                   -0.31787001379542856,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12596489096855359,
                                   0,
                                   0,
                                   -0.11136788995170677,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.74619098028788544,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.087919891762874708,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38051996051777709,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48166935254684123,
                                   0,
                                   0.6180853246625041,
                                   0,
                                   0.36070554965047652,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24663158467121815,
                                   0,
                                   0.956889842991972,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14051289250354726,
                                   0,
                                   -0.35554966673842209,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32991238807390777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095688979207814204,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23876449063592581,
                                   0,
                                   -0.10742117375756496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55711403543824467,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36149304940376731,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.031238838527812715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14612659860207239,
                                   0,
                                   0.057104348703872015,
                                   -0.17440587198564528,
                                   0.35792937140288761,
                                   0,
                                   0,
                                   0,
                                   -0.46590571042762363,
                                   0,
                                   -0.15054586176415446,
                                   0,
                                   -0.13270937665316024,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.022844043539088976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22002845752701897,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.012158841002377269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.049959025669100765,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.79637308462412992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.88267637449717196,
                                   0,
                                   -0.59761142163163061,
                                   0,
                                   0.24021419606240405,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40484873236209373,
                                   0,
                                   0.41145344820243634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0062087034710317998,
                                   0,
                                   0.40104270344498183,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11843534614490811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13454774654494842,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.03823251218212656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.081841833986502063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29230858554115624,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21888082715392398,
                                   0,
                                   0.89446490395405143,
                                   0,
                                   -0.24170146697895911,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60861108581537093,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84867191467568059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33462421754020255,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47332670061494597,
                                   0,
                                   0,
                                   0.55948817383391525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.73669496382149102,
                                   0,
                                   -0.18947081651685055,
                                   0,
                                   -0.0029478259884327951,
                                   0,
                                   0,
                                   -0.10341196884781646,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.046854650474515723,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.07961195955131975,
                                   -0.034630604283528876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2964114005998244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20848463889052987,
                                   0,
                                   -0.79346050091977971,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.014480049075712903,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44700308813695294,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17758405035200184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.029239992080423396,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.50830338594598135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24950314817807737,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25363119225881253,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35035769701816089,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.090722506536002875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0053937953106753117,
                                   -0.32552147113343466,
                                   0,
                                   0.60251627302130673,
                                   -0.044003481205411976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.087315886648557314,
                                   0,
                                   0,
                                   0.068054743684113919,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38429128344919228,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.089726373538043872,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.033025413970646463,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.79552056062753929,
                                   0,
                                   0,
                                   -0.21057924332739608,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.595275841136927,
                                   0,
                                   -0.56952505039788326,
                                   0,
                                   0.30289666376780544,
                                   0,
                                   0,
                                   0.13032307486342781,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45748612518141385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17685899589767567,
                                   0,
                                   -0.054409972465276166,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.034087903127921759,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38613544249414344,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15332401606666241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1512638957882205,
                                   0,
                                   0.66998809139202953,
                                   0.30777021924421694,
                                   0.13356420127015978,
                                   0,
                                   0,
                                   0,
                                   -0.047554764558717301,
                                   0,
                                   0.22369118719639824,
                                   0,
                                   -0.34261643855538587,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15153849080550186,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1225307225045543,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.59695766595872557,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.75913297699867177,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.85003107275562817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25867146609389946,
                                   0,
                                   -0.030708325900216021,
                                   0,
                                   -0.18077563184153486,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41349294398551922,
                                   0,
                                   0.14759146120812705,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3092155762780821,
                                   0,
                                   -0.52919475772680991,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25819266266693153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.095771499013322076,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27790007248026821,
                                   0,
                                   -0.29777141222831793,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14662223447878692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.24644903193371331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3608269121521771,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2271910512976284,
                                   0,
                                   0.27115640095532834,
                                   -0.27581501295378852,
                                   0.28337215573577268,
                                   0,
                                   0,
                                   0,
                                   0.14351599539848472,
                                   0,
                                   -0.4597342220976624,
                                   0,
                                   0.17183760076059992,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12252102363087056,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25231972673899045,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16658311624779101,
                                   0,
                                   -0.30922396235814625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38333898630113555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.057847274961142149,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39522788117951446,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.3308001866923877,
                                   0,
                                   -0.30215617108116588,
                                   0.40763406581352862,
                                   0.13603173378803715,
                                   0,
                                   0,
                                   0,
                                   0.37600068344804011,
                                   0,
                                   -0.012570478244563581,
                                   0,
                                   0.11051535868705331,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.053378254892217258,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16773714513872404,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32660997392641961,
                                   0,
                                   -0.16419445262863638,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48584672642897886,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013664069089012937,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10488975073857212,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25469139228578613,
                                   0,
                                   -0.17433493072795073,
                                   -0.0052297025852453324,
                                   0.0020558913201199004,
                                   0,
                                   0,
                                   0,
                                   -0.19331443753518274,
                                   0,
                                   -0.42034660907528421,
                                   0,
                                   0.013822238201637867,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45267037056719284,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32353560306143153,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37898980060437326,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34704186363698697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10102800599314936,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.3625130190165224,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.077738012600075609,
                                   0,
                                   -0.51910268373630464,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38625152089061887,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0184830136493319,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26753963866598773,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56517699252557008,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12914869227014666,
                                   0,
                                   0,
                                   0,
                                   0.24902663718242685,
                                   0.2794094417006926,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.21200939494569337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19812601945752131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28751115108376935,
                                   0,
                                   0,
                                   0,
                                   0.35549559507501044,
                                   0,
                                   0,
                                   0,
                                   0.39873868480834035,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.53591484890325503,
                                   0,
                                   0.31690935912985502,
                                   0,
                                   0,
                                   0,
                                   0.030934171016065048,
                                   0,
                                   0,
                                   -0.402911641927649,
                                   0,
                                   -0.2791208675031534,
                                   0.31240089407160654,
                                   0,
                                   0,
                                   -0.68751761876188511,
                                   0,
                                   0.027400782713113456,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084233800000224748,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.078104025677048855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29579455832372353,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25203047262051448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.94885536707628304,
                                   -0.45057722274786621,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.089241310933757742,
                                   0,
                                   -0.1500164007100912,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23751117052068388,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19867572708044634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25373533898627132,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21148864290407413,
                                   0,
                                   0.11224303534637037,
                                   -0.32927430615485498,
                                   0.20464477472572803,
                                   0,
                                   0,
                                   0,
                                   0.19921895044449045,
                                   0,
                                   -0.062243967403705774,
                                   0,
                                   0.10452397579349154,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50348024177529782,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54190287911364565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37674729713744537,
                                   0,
                                   -1.2036190679833454,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.44375759049763103,
                                   0,
                                   0.032910838666448866,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15639498389195966,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45527142756008199,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22047704265450341,
                                   0,
                                   0.19493858571944123,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038943785605948092,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45565692024617488,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47142284255858824,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.028764653629579272,
                                   0,
                                   -0.17775192717765342,
                                   -0.026495395201954236,
                                   0.22376276204906945,
                                   0,
                                   0,
                                   0,
                                   -0.30501867006231853,
                                   0,
                                   -0.097979875113578169,
                                   0,
                                   0.29755911091578158,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15108686475856223,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42989467873248194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.69388445648964081,
                                   0,
                                   -0.11023556498143094,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0808797195611135,
                                   0,
                                   -0.37838286006403704,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.64545962278390256,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.066378396328929584,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24557719606821179,
                                   0,
                                   -0.22685758189433081,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1799600591035786,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.18767891361265715,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.36152990344711483,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.57993148072460565,
                                   0,
                                   0.12473748820989677,
                                   -0.039089246099094657,
                                   0.21316260152342698,
                                   0,
                                   0,
                                   0,
                                   0.080066183681012953,
                                   0,
                                   0.091687878071256168,
                                   0,
                                   0.050636938203430959,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.46887006670233028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23205146599572593,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.050706101161572724,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35860271059318249,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68800424042886243,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41025039041575817,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.018789494917767026,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15264861092317875,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1718357775504048,
                                   0.20846166043113068,
                                   0,
                                   -0.0648569090813291,
                                   -0.1280987064116976,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30677631644042419,
                                   0,
                                   0,
                                   0.12574546574349915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.63573600459704549,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15131897528884797,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.038562444690198226,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.026738981172548665,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51540760036309441,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.072344252296295777,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11194204071832087,
                                   -0.21052400966339363,
                                   0,
                                   -0.27318896477600552,
                                   0.16991836378284975,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.041931813181389409,
                                   0,
                                   0,
                                   0.37114345294224876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.48564477425052244,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15232499795562029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43040814198257055,
                                   0,
                                   0,
                                   0,
                                   -0.092137239479962232,
                                   0.40936300681662496,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.16541179818558643,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.080976235620291839,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.38016363063547076,
                                   0,
                                   0,
                                   0,
                                   -0.32127989410517399,
                                   0,
                                   0,
                                   0,
                                   0.31299259923959699,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12992204431074889,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.1061754235434207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15244306212700942,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.55982766717333743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.031244196276165925,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.38237715920069359,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45005684692956399,
                                   0.28915606082971651,
                                   0,
                                   0.23536595814530159,
                                   0.15908291775340178,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29337841219915695,
                                   0,
                                   0,
                                   0.1872828110984126,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.3062440102657219,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.081942479697956525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.073364721284075743,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10981047904118717,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.31567938067757689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27514035492939221,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.32861969762081966,
                                   -0.33549414723778953,
                                   0,
                                   -0.056781859861725799,
                                   -0.05355499762142861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0072135164246388828,
                                   0,
                                   0,
                                   0.69282901611531522,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22083044070766389,
                                   0,
                                   0.34521459392176829,
                                   0,
                                   0,
                                   0,
                                   -0.25023744061272413,
                                   0,
                                   0,
                                   0.75414377059616278,
                                   0,
                                   0.33063750851218371,
                                   0.085989153870063756,
                                   0,
                                   0,
                                   0.3198015793054117,
                                   0,
                                   0.20466145605825634,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.81833584805581527,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34681132647137985,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.054373348681120322,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11908586086350341,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.25484354267749826,
                                   0.12091489556852883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.41246016274663649,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11830711610249343,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.047074281273676674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37077674268617583,
                                   0,
                                   0,
                                   -0.13151579864674448,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.56553863133340254,
                                   0,
                                   0.30528621926002264,
                                   0,
                                   0.94443622212740141,
                                   0,
                                   0,
                                   0.41401519292905059,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51482688764434292,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39395921091685437,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70311767699108296,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22707171229563203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34800078740819235,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29753559509936311,
                                   0,
                                   0.61391295887774888,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19532354194314858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37028298384215674,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.11980396588789689,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33899437236174551,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40751658026113313,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34567712288775237,
                                   0,
                                   0,
                                   -0.80157307186484572,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25085024519395027,
                                   0,
                                   0.044856677312944904,
                                   0,
                                   0.38900197986522511,
                                   0,
                                   0,
                                   -0.17409340010472327,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19509904430182534,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.5825166892378193,
                                   0,
                                   0.16388322876447692,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20534228179380956,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13877177089276943,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.044132030123261876,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.40582223279776591,
                                   0,
                                   0.010117510583905299,
                                   -0.060295315959828531,
                                   0.27180567585439819,
                                   0,
                                   0,
                                   0,
                                   -0.44302347157413458,
                                   0,
                                   0.32388425097734375,
                                   0,
                                   0.10121056704421934,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.038888223953505552,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12333419829946518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12685966126542422,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.84761034841802485,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.45268825056554729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.17279664413993395,
                                   0,
                                   0,
                                   -0.15571443654554265,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.13097668668491375,
                                   0,
                                   0.028335202386346903,
                                   0,
                                   -0.25871159808569522,
                                   0,
                                   0,
                                   0.55132802103639922,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26312210734907338,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.86663639674564097,
                                   0,
                                   0.10065055765041038,
                                   0,
                                   0,
                                   0,
                                   -0.25632833061048621,
                                   0,
                                   0,
                                   -0.020082305848303436,
                                   0,
                                   -0.067534964417632862,
                                   0.16282674256823315,
                                   0,
                                   0,
                                   -0.14727700679943995,
                                   0,
                                   -0.33710493957120269,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33661965545385342,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.70467281931551007,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.51434710575863418,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30685167557669735,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17338603217103127,
                                   0.18985371159282194,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33257127683854293,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.2192463890310741,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.071535085348259683,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29261326330170312,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.28100236180705063,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.20005928492829811,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.2125787015494609,
                                   0.16359084463338797,
                                   0,
                                   -0.13610553003595183,
                                   -0.11428031206887385,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.7162561756213065,
                                   0,
                                   0,
                                   -0.12264684523823852,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.42429205562574213,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.69296443901622062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.049383884858136419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0085774353779809881,
                                   0,
                                   0,
                                   0.41585659101773248,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.127120767953458,
                                   0,
                                   -0.21360378719181156,
                                   0,
                                   0.2638445237213522,
                                   0,
                                   0,
                                   -0.64328562505472109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.54591768831680088,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.83149046649584135,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76692881608467645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.66204377779264778,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4529031811480016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27691845732047493,
                                   0,
                                   -0.31375911767873854,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.018745270274242574,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.76585410515478525,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13450538092842029,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.37303165413015016,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.15736364646052883,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.29533367706968172,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.4126742445124339,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.30634886718323034,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.23128110656698858,
                                   0.5841685069595407,
                                   0,
                                   0.23221195906838665,
                                   -0.095721211140154694,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.042277670133647957,
                                   0,
                                   0,
                                   0.083693420317128855,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.57038343730520835,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.353774068004308,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.78251869926794337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.18499447249467171,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.19921892622326731,
                                   0,
                                   0.37790378515968109,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.084465250963757857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.96256083225153832,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22160628009926225,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35871055399680241,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.0081161936152710328,
                                   0,
                                   0,
                                   0,
                                   0.27549887536664153,
                                   0.010261024356881233,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27960299325712251,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.43906149938329436,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.61814574259234589,
                                   0,
                                   0,
                                   0,
                                   0.21692211891272692,
                                   0,
                                   0,
                                   0,
                                   -0.21455629724211261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47415134811897625,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.33458714377543597,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.26510213926020332,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13444480014263027,
                                   0,
                                   -0.13304965998852478,
                                   0,
                                   -0.74644168007176825,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7268699541042043,
                                   0,
                                   -0.30311193837837541,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.1357806063690437,
                                   0,
                                   0.060760736341101511,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.87593027334747953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1439087875718614,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.079472075530383407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.68658639071055738,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.24716104749375184,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.58266223325901323,
                                   0,
                                   0.034214962128223954,
                                   0,
                                   -0.34717256833441978,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.42861022178124003,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10671615003097848,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.20593743805586068,
                                   0,
                                   0,
                                   0,
                                   -0.017411889523154006,
                                   -0.032169491805339068,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.56234759998720651,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.11857707940801419,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15227042496267743,
                                   0,
                                   0,
                                   0,
                                   0.079173636088250926,
                                   0,
                                   0,
                                   0,
                                   0.63356654636459175,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.22816255231670673,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10202793297507168,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.72314186861881857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47486672366649779,
                                   0,
                                   0.39940885127446374,
                                   0,
                                   0.1719655568464355,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12172877883890597,
                                   0,
                                   0.25925420759898382,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.013906906033683844,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.35105920562696635,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.40612211145530203,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.37971290927468021,
                                   0,
                                   0.22236015487310931,
                                   -0.4969056203331883,
                                   -0.085576987756100772,
                                   0,
                                   0,
                                   0,
                                   0.32377544728806668,
                                   0,
                                   -0.039262610559458289,
                                   0,
                                   -0.19491682260535656,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.027587859121182577,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.19133197350075309,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.34639324225817819,
                                   -0.033268701490876948,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.12521889269613729,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.011559238276914983,
                                   0,
                                   -0.39832079837908518,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.67280495906447857,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.48111185080598196,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.14246734289768645,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.10886144100001036,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.5203115568190062,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33652922078775965,
                                   0,
                                   0,
                                   0,
                                   0.17851330446412481,
                                   -0.30878806926352675,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.32487834188824083,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.34035742705698568,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.024159347980605678,
                                   0,
                                   0,
                                   0,
                                   0.19428992768725573,
                                   0,
                                   0,
                                   0,
                                   0.46608445285516337,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.13029215284772211,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.62638746947205259,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.35182397011524458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17659832991618524,
                                   0,
                                   1.0447939579213508,
                                   0,
                                   -0.027782965602409858,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.10026443846507879,
                                   0,
                                   0.16666612884728979,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.16716619861062212,
                                   0,
                                   0.12020018650769444,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.05320188914710261,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.7676445552930351,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.27211746047066188,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.22529530711675361,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.39608075702845602,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28060074587288458,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.47870223935529527,
                                   0,
                                   -1.0409044554714044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.25738177003670915,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.75894887285473323,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.17109913171668512,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.103733047170953,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65672228502061569,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.47405798246670605,
                                   0,
                                   0,
                                   0.43209824164824617,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.8795044369880276,
                                   0,
                                   -0.8270545968083588,
                                   0,
                                   0.052944073155206911,
                                   0,
                                   0,
                                   0.44301240891575044,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.1339325705211884,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.33563925251263471,
                                   0,
                                   -0.49945913390035357,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.27517649260008248,
                                   0,
                                   -1.1918125735851697,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.26245204944852407,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   1.0276063276299918,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.65885830863795625,
                                   0,
                                   0.077349612810619917,
                                   0,
                                   0,
                                   0,
                                   -0.50019182169845977,
                                   0,
                                   0,
                                   -0.68818491137458337,
                                   0,
                                   -0.042057756022527773,
                                   -0.50111482282541542,
                                   0,
                                   0,
                                   -0.29179098544428028,
                                   0,
                                   0.54319004995615028,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.12113841312999722,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.44722458331910558,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.02672139805196555,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.0021704750219688207,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.012048530360080138,
                                   0.041473592105262726,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.50150437785687429,
                                   0,
                                   0.06646839874905501,
                                   0,
                                   0,
                                   0,
                                   -0.3869042648853212,
                                   0,
                                   0,
                                   0.47492500870474158,
                                   0,
                                   0.2236215780754737,
                                   -0.53489444512717854,
                                   0,
                                   0,
                                   -0.71135261440296449,
                                   0,
                                   -0.07917747882644452,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.29846016063444397,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.28618273374057679,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.23323158261972565,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.59902272078713281,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.053346602168509491,
                                   0.42583337242734642,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.60560161823312819,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.037343509356119131,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.43885691972597957,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0.45632946856341861,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -1.0415678848078127,
                                   0,
                                   -0.52973700603666563,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.15137877288760815,
                                   0,
                                   0,
                                   0,
                                   0,
                                   -0.21228794060580217};

const double rot_23_30[9000] = {-0.39357911359063485,
                                0,
                                0,
                                0,
                                -0.1808595840670526,
                                0,
                                0.52752025885976228,
                                0,
                                -0.82764636670456293,
                                -0.24419916950329112,
                                0.64719056018188459,
                                0,
                                0,
                                0,
                                0,
                                -0.082318320545244031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63830195080196361,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.586743814692541,
                                0,
                                0,
                                0,
                                -0.2256592097051176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28655087242507837,
                                0,
                                0,
                                0,
                                -0.68717670706866207,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.076558267477473269,
                                -0.21124682116153637,
                                0,
                                0,
                                0,
                                0,
                                0.018401500985289462,
                                -0.11007997920881971,
                                0,
                                0,
                                0,
                                -0.059664480970950784,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30312198997925743,
                                -0.26689359264167645,
                                -0.013979706099193818,
                                0,
                                0,
                                0,
                                -0.27152583166759509,
                                0.86426100953460672,
                                0,
                                0,
                                0.23760103106838534,
                                -0.0034998362423455109,
                                0,
                                0,
                                0,
                                0.55334126723375809,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64156985461504923,
                                -0.25668507595186452,
                                -0.18724864912231215,
                                0,
                                0,
                                0,
                                -0.3469507564878917,
                                0.066415002558268682,
                                -0.06478614168734223,
                                0,
                                0,
                                0,
                                0.22090749541177379,
                                0,
                                -0.43625621118193003,
                                0,
                                0.64586472258442118,
                                -0.36882384370917948,
                                0.53781216108083885,
                                0,
                                0,
                                0,
                                0,
                                0.85434955433384518,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38042418187863403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69081272139271443,
                                0,
                                0,
                                0,
                                -0.20586570260384071,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3012801676538383,
                                0,
                                0,
                                0,
                                -0.57743532107168849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16639662147120232,
                                -0.16884303768203421,
                                0,
                                0,
                                0.43419318689281888,
                                0,
                                0,
                                0,
                                0.45883327935724738,
                                0,
                                -0.089655372572946035,
                                0,
                                0.066711383407704827,
                                1.021172102038153,
                                0.2554891187405321,
                                0,
                                0,
                                0,
                                0,
                                -0.3909781517666101,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42982874583495084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12941285473695655,
                                0.55495027541688735,
                                0,
                                0,
                                0,
                                -0.58894507428824672,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13760913271772579,
                                -0.056771153574700216,
                                -0.43828094025191433,
                                0,
                                0,
                                0,
                                -0.33357600640589646,
                                -0.053887219188077526,
                                0.090297378858706284,
                                0,
                                0,
                                0,
                                0.52017356963523731,
                                0,
                                -0.46948655865294731,
                                0,
                                -0.5775110864150077,
                                -0.43851763515311559,
                                0.24617719439394009,
                                0,
                                0,
                                0,
                                0,
                                0.070096746412252997,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.88287459427212667,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0550771727814303,
                                0,
                                0,
                                0,
                                -0.079239804060792979,
                                0,
                                0.14870815346982386,
                                0,
                                0.29358132311288998,
                                -0.76455491989546842,
                                -0.12070991810949687,
                                0,
                                0,
                                0,
                                0,
                                -0.46014413834803536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7056596280220232,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50376648871066954,
                                0,
                                0,
                                0,
                                -0.36777557508500236,
                                0,
                                -0.34784419414467671,
                                0,
                                -0.53956835878149811,
                                0.3958801385795126,
                                -0.78808404003222332,
                                0,
                                0,
                                0,
                                0,
                                0.52229844824689786,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4877965199386961,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59600634356690829,
                                0.41932612292255772,
                                0,
                                -0.70673369449047418,
                                0,
                                0,
                                1.1045599159138797,
                                -0.049722090979046486,
                                0.91668715681366475,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.64874019101085123,
                                -0.66949137682396254,
                                0,
                                0.40725716491213093,
                                0,
                                0,
                                0.31785994037377585,
                                0.16541921556230377,
                                0.3041926024851565,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.035446406368048827,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.055747437580890957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41178866731748026,
                                -0.21742668330298245,
                                0,
                                -0.9208904283876056,
                                0,
                                0,
                                0.29181595532566784,
                                0.65356368665432563,
                                -0.49311611803924937,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56764626588720435,
                                0,
                                0,
                                0,
                                0.62467456665949994,
                                0,
                                -0.85843478296269549,
                                0,
                                -0.092871677839751476,
                                -0.30731726948866245,
                                -0.28611045227069898,
                                0,
                                0,
                                0,
                                0,
                                -0.73813754501429907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.095062660418935407,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18212293158062623,
                                0,
                                0,
                                0,
                                0.1295536141540663,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49324079546978172,
                                0,
                                0,
                                0,
                                -0.14932234935100844,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46996000332556093,
                                0.68088255066124914,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66263245220260114,
                                -0.97379811132449368,
                                0,
                                -0.40427311308491465,
                                0,
                                0,
                                0.12210939730498677,
                                -0.13345805026117918,
                                -0.61057225018929318,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37705473217670937,
                                0.39148626347471899,
                                0,
                                0.23708988213045243,
                                0,
                                0,
                                1.2378786277062188,
                                -0.48001573417406596,
                                -0.58036400548259648,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44024115633525873,
                                -0.39843919476309758,
                                0,
                                -0.77728991273450787,
                                0,
                                0,
                                0.1034232941488389,
                                -0.9395140012872043,
                                -0.4236302824236074,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23055433546852738,
                                0,
                                0,
                                0,
                                0.63767667001215778,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41680263937531414,
                                0,
                                0,
                                0,
                                -0.069566935376941294,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57656594183697962,
                                -0.17094115638002649,
                                0,
                                0,
                                0.18796841223072003,
                                0,
                                0,
                                0,
                                -1.1996218257274345,
                                0,
                                -0.73240545968220627,
                                0,
                                -0.12913536725123237,
                                -0.007352166685050926,
                                0.4947223825162545,
                                0,
                                0,
                                0,
                                0,
                                -0.15399662278984852,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41273982154130051,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.049680831384510127,
                                0.62567007121543217,
                                0,
                                0,
                                0,
                                0.53586505052337707,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.53464276770727603,
                                -0.13289810902326432,
                                -0.045413378023409903,
                                0,
                                0,
                                0,
                                -0.0055579438579882318,
                                -0.11540954258083674,
                                0,
                                0,
                                0.11759836525053813,
                                -0.15916782804855592,
                                0,
                                0,
                                0,
                                0.19648329912836618,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1641799704463536,
                                0.81290861551835347,
                                -0.37919222120129975,
                                0,
                                0,
                                0,
                                -0.28808857757016471,
                                0.08759732383260066,
                                0,
                                0,
                                0.46981740563525509,
                                0.030424527809634255,
                                0,
                                0,
                                0,
                                0.012398777138968003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.068107975874087193,
                                -0.0064546296548486821,
                                -0.40981298070517047,
                                0,
                                0,
                                0,
                                0.73949055108172979,
                                0.24231985242632442,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12937572978629752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23745136348668316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.242434745638858,
                                0,
                                0,
                                0,
                                -0.67498914281780242,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42176319395353301,
                                0,
                                0,
                                0,
                                0.22776775160717294,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44401114945374764,
                                0.24229488211639966,
                                0,
                                0,
                                0,
                                -0.18278624176398894,
                                0,
                                0,
                                0,
                                -0.16634667482881127,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48189598858169047,
                                0,
                                0,
                                0,
                                0.33962001127064806,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46477349880608981,
                                -0.61264840858043512,
                                0,
                                0,
                                0,
                                0,
                                0.82544236548852135,
                                -0.16849005005283252,
                                0,
                                0,
                                0,
                                -0.13192286621097543,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21914514466666024,
                                -0.061263216908490542,
                                0.34976782995215588,
                                0,
                                0,
                                0,
                                -0.2325487640460315,
                                -0.21132468609905128,
                                0,
                                0,
                                -0.089879886113526986,
                                -0.48351665615438888,
                                0,
                                0,
                                0,
                                0.009103825874957977,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33482482713624501,
                                -0.42116558448705066,
                                -0.58010257634678686,
                                0,
                                0,
                                0,
                                -0.10331902629799952,
                                -0.34837972809199697,
                                0.17683319924613683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36907565814580456,
                                0,
                                0,
                                0,
                                -0.62868992426419812,
                                0,
                                0,
                                0,
                                -0.27089342999428306,
                                -0.59920989065451424,
                                0,
                                0,
                                0.069472396424999291,
                                0,
                                0,
                                0,
                                0,
                                -0.22732682215937389,
                                0,
                                0,
                                0,
                                -0.26613647845577765,
                                0,
                                0.19976515524482644,
                                0.22030528002859073,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0096136812190815314,
                                0.75082604846713363,
                                0.45659161265506382,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12940354876628532,
                                0,
                                0,
                                0,
                                -0.67965934117762017,
                                0,
                                -0.087419444239083155,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51712166825937844,
                                -0.053023049941917588,
                                -0.86252979426260223,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0011247579607265579,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.074817800621487796,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0083188376794933183,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.62091639755016304,
                                -0.57028470452898938,
                                -1.0952687641070493,
                                0,
                                0,
                                0.95927543070360788,
                                0,
                                0,
                                0.16294728565430275,
                                0,
                                0.015299119036926573,
                                0,
                                0,
                                -0.23849248226329023,
                                0,
                                -0.41769897839141529,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.77221325582458089,
                                -0.32536866207294468,
                                0.060353155910105816,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2560471045102308,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32593261184872119,
                                0,
                                0,
                                0,
                                0.34529287705307266,
                                0,
                                0.47193202983074783,
                                -0.10682316048725947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26008496556530414,
                                0.45113653951841926,
                                -0.45941811585190973,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24119776412427169,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32268277093284142,
                                0,
                                0,
                                0,
                                0.16926179486957735,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36011514929491129,
                                0,
                                0,
                                0,
                                0.19690587902935841,
                                0,
                                0.43003466148682479,
                                0.65412916222081929,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21813538876252764,
                                -0.30844505032016084,
                                -0.12598129037073172,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24522989353486269,
                                0,
                                0,
                                0.16233360022891502,
                                0,
                                0,
                                0,
                                0.39113522376424625,
                                0,
                                -0.24621507351761121,
                                -0.014961412293273482,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69869486954158744,
                                -0.046011275113624919,
                                0.51888453253364186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.016811199200132049,
                                0,
                                0,
                                0,
                                0,
                                1.1310483180464326,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.57674669045340288,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.050310297857925193,
                                -0.12432709050820184,
                                -0.7209595599922175,
                                0,
                                0,
                                -0.92329699173708213,
                                0,
                                0,
                                -0.23388077124315773,
                                0,
                                -0.059126039321749854,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22188887145243089,
                                0,
                                0,
                                0,
                                -0.065589331548954216,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45340024993966971,
                                0,
                                -0.39044191378495896,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50059179648151275,
                                0.7497345327563476,
                                0.51276254515442277,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21081823284502957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.727783871895471,
                                0,
                                -0.30104376250083081,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8492033892004538,
                                0.22528102727807414,
                                -0.7198539268244506,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38245809285184662,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25130734829929124,
                                0,
                                -1.2478492007800119,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39683275651399164,
                                -0.79359795707294012,
                                -0.14007302741354313,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30682379031060469,
                                0,
                                0,
                                0,
                                0,
                                -0.3660500656805552,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59978339205483,
                                0,
                                0,
                                0,
                                -0.4877630773861088,
                                0,
                                0,
                                0,
                                -0.43824213791385785,
                                0.24680858515058748,
                                0,
                                0,
                                0.12403129936412303,
                                0,
                                0,
                                0,
                                0,
                                -0.57202043231952093,
                                0,
                                0,
                                0,
                                -0.34703335412744668,
                                0,
                                0.091964064919052874,
                                -0.25878695396237966,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39993350596745764,
                                -0.091742688588311222,
                                -0.087703103654854092,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54852259284276728,
                                0,
                                0,
                                0.52272266505248854,
                                0,
                                0,
                                0,
                                -0.62546348444733157,
                                0,
                                -0.10763778205416712,
                                0.44620211985860275,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29293209420908517,
                                -0.057427828287736932,
                                -0.13412397701603368,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13333346422189538,
                                0,
                                0,
                                -0.20110566050508447,
                                0,
                                0,
                                0,
                                -0.13100157600315407,
                                0,
                                -0.34105889565529268,
                                -0.19257228842983576,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36613925366886446,
                                0.21518220137884417,
                                -0.45922746685614407,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63066523975738642,
                                0,
                                -0.27504788229748733,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27521632522784456,
                                0,
                                0,
                                0,
                                -0.51244989873819125,
                                0,
                                0,
                                0,
                                0.48647265431512909,
                                0.3509415366135954,
                                0,
                                0,
                                -0.47558819638196159,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44242966456460009,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.051444926459515483,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.021822757693776534,
                                0.6173704764200455,
                                -0.093325811064294523,
                                0,
                                0,
                                -0.29261308496374472,
                                0,
                                0,
                                0.60274795212159249,
                                0,
                                -1.1938165763960027,
                                0,
                                0,
                                0,
                                -0.74155518602166037,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10996180550651383,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.39717447574691184,
                                0.35315236135911049,
                                -0.23527974726177459,
                                0,
                                0,
                                -0.19795873548076179,
                                0,
                                0,
                                -0.66832907606382108,
                                0,
                                0.044336237255779481,
                                0,
                                0,
                                0,
                                -0.020905858919915046,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.80034007664865059,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.6148168894183359,
                                -1.0488385746496058,
                                0.71441534360548709,
                                0,
                                0,
                                0.21364276315971073,
                                0,
                                0,
                                -0.47115311889149747,
                                0,
                                -0.57468337356593246,
                                0.29183776531097261,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43333515215865748,
                                0,
                                0,
                                0,
                                -0.26076146484085366,
                                0,
                                0,
                                0,
                                0.67043063606772602,
                                -0.16057897818543182,
                                0,
                                0,
                                0.42870966525462223,
                                0,
                                0,
                                0,
                                0.68260251213866208,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35035783012282296,
                                0,
                                0,
                                0,
                                -0.077564052319265456,
                                0,
                                0,
                                0,
                                -0.14464976108116762,
                                0.060886882898742042,
                                0,
                                0,
                                -0.61697346230730599,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29210821532778553,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.71558897013608913,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43090926884144393,
                                -0.38773330609598861,
                                0.2002723512934117,
                                0,
                                0,
                                -0.29265682871999371,
                                0,
                                0,
                                -0.52529344185994098,
                                0,
                                -0.74541765714905328,
                                0,
                                0,
                                -0.60441640254000351,
                                0,
                                1.0070660986336426,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4458771936095553,
                                -0.62269439616501943,
                                0.19321302565097989,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54652988620645238,
                                0,
                                0,
                                0,
                                0,
                                0.45603789388995969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34317495870588355,
                                0,
                                0,
                                0,
                                -0.17383479799106347,
                                0,
                                0,
                                0,
                                -0.16584373243267905,
                                0.65374325722936244,
                                0,
                                0,
                                0.4349223610036313,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.010131672296686975,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46619391003268934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.95580926707170943,
                                0.15707819594599112,
                                0.039104837625127079,
                                0,
                                0,
                                0.18918697293743267,
                                0,
                                0,
                                -0.20520197554315439,
                                0,
                                -0.22263400656102525,
                                0,
                                -0.21252172526035973,
                                0,
                                0,
                                0,
                                0.29897722865944953,
                                0,
                                -0.59620291662728853,
                                0.45694035242138092,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12919692401780111,
                                0.2783210825440362,
                                -0.24243701973418982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38505136133751283,
                                0,
                                0,
                                0,
                                0,
                                -0.59523069058975031,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21404714976648015,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30958696747112019,
                                -0.71898264876623486,
                                0.059872860137276232,
                                0,
                                0,
                                -0.45325613805335235,
                                0,
                                0,
                                0.35214937775017802,
                                0,
                                0.64251621902339007,
                                0.40561614559052772,
                                0,
                                0.29350520966085852,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19949851443787045,
                                0.055644066203271114,
                                0,
                                0.25303709107498495,
                                0,
                                0.27611820180056051,
                                0.3108504218571318,
                                0,
                                0,
                                0,
                                0.68522791783292336,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18130485815408931,
                                0,
                                0,
                                -0.42477017149886981,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25828058795726916,
                                0,
                                -0.12373036626291112,
                                0,
                                0,
                                0,
                                -0.68683771811362493,
                                0,
                                0,
                                0,
                                -0.48263312478517983,
                                0,
                                -0.042606498400475368,
                                0,
                                -0.65171220203437474,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18210629561420702,
                                0.0088660596266520158,
                                0,
                                0.16259182101620687,
                                0,
                                0.30097374176516123,
                                0.64026846506871715,
                                0,
                                0,
                                0,
                                -0.11510682535359271,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21980389443688003,
                                0,
                                0,
                                0,
                                0,
                                0.11663836131842628,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33119884801983873,
                                -1.183130541990536,
                                0,
                                0,
                                0,
                                0,
                                -0.28808548760066821,
                                0,
                                0,
                                -0.26806334064826925,
                                -0.28729823956154593,
                                0,
                                0,
                                -0.52439745692288176,
                                0,
                                -0.45944092606832698,
                                0,
                                0,
                                0.7640573836932858,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17694413572795123,
                                0,
                                -0.33390370580384898,
                                0,
                                0,
                                0,
                                -0.053146365689307529,
                                0,
                                0,
                                0,
                                -0.24393626580156291,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27353503372617904,
                                0.066423738283106631,
                                0.68408445777889226,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.017339024709473849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58876335604727903,
                                0,
                                0,
                                0,
                                -1.0889468929204571,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34605758347018944,
                                -0.41142622194535011,
                                0.96821404449122062,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.86873261320701523,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75858843276336052,
                                0,
                                0,
                                0,
                                0.20025098265222302,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36096009258460088,
                                0.56591290893798063,
                                0.72812620493629143,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52769809913278942,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1331276206431018,
                                0,
                                0,
                                0,
                                0.96768798016363355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69609972590734848,
                                0,
                                0,
                                0,
                                0,
                                0.17052204630482815,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7842243345666452,
                                0.10980528128823216,
                                0,
                                0,
                                0,
                                0,
                                -0.12649353399314039,
                                0,
                                0,
                                -0.98422666788444579,
                                0.037618323919686517,
                                0,
                                0,
                                -0.20184540260862879,
                                -0.43588277018669397,
                                0,
                                -0.10153953446402447,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63339067290778284,
                                0.43831948769206558,
                                0,
                                0.058583209306050849,
                                0,
                                0.41484431582892867,
                                -0.17331711837247252,
                                0,
                                0,
                                0,
                                -0.028663451796484295,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46917953191230433,
                                0,
                                0.04076612600201699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19616910997066414,
                                0.49990698769711978,
                                0,
                                -0.56726497482740523,
                                0,
                                -0.14258261302303654,
                                0.28664259491149535,
                                0,
                                0,
                                0,
                                -0.25600008462935375,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33071214738866161,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11633307782693653,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16263582519478523,
                                0,
                                -0.18982385728087692,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50268596094884488,
                                0.28661780735202758,
                                0,
                                -0.48269222339103302,
                                0,
                                0.2437057650341686,
                                -0.25382374801100616,
                                0,
                                0,
                                0,
                                0.49584551148159867,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.02638464864949755,
                                -0.77038110534272675,
                                0.33632512926247654,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69811967397193875,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34432372810526257,
                                0,
                                0,
                                0,
                                -0.97209687353898733,
                                0,
                                0,
                                0.34500577062112042,
                                0,
                                0.018661230056063655,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.064650933359866256,
                                -0.46423290101290804,
                                0,
                                -0.27020391806492117,
                                0,
                                0.68177894794388771,
                                -0.23236115496789791,
                                0,
                                0,
                                0,
                                -0.26288105604747714,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50074958610425369,
                                0,
                                -0.29860587952129763,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16602143569403358,
                                0.38908110227760589,
                                0,
                                0.48738834704850614,
                                0,
                                0.018554485907193351,
                                -0.47774305616348872,
                                0,
                                0,
                                0,
                                -0.1225033141342774,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.78620117873200446,
                                0,
                                0,
                                0,
                                0,
                                0.53627236663778355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.51575169676242427,
                                0.13949667492785217,
                                0,
                                0,
                                0,
                                0,
                                -0.47200825973585869,
                                0,
                                0,
                                0.66153485452678362,
                                0.10611458887620157,
                                0,
                                0,
                                -0.37069584218269758,
                                0,
                                0,
                                0,
                                0.30479326765902903,
                                0,
                                0,
                                0,
                                0,
                                -0.76742741613994958,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74044044277422527,
                                -0.27492214721213187,
                                0,
                                0,
                                0,
                                0,
                                0.27721150625468699,
                                0,
                                0,
                                0.028684133900939733,
                                0.11205249579411265,
                                0,
                                0,
                                -0.98209440960096517,
                                0,
                                -0.20740212137629535,
                                0,
                                0,
                                -0.041742168202384043,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.73132251143684601,
                                0,
                                0.20300592813249121,
                                0,
                                0,
                                0,
                                0.18229728806205703,
                                0,
                                0,
                                0,
                                -0.58818842866581988,
                                0,
                                0.16524970449904747,
                                0,
                                -0.59296453009279892,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45048367336921979,
                                -0.32518933441968384,
                                0,
                                -0.20190405023654548,
                                0,
                                -0.34086454021005097,
                                -0.18592707717395532,
                                0,
                                0,
                                0,
                                0.34767686106682971,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.72033709373165244,
                                0,
                                0,
                                0.40900327480768989,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28255141228516606,
                                0,
                                -0.05878582950600271,
                                0,
                                0,
                                0,
                                -0.47009984235005053,
                                0,
                                0,
                                0,
                                -0.097702899026738566,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.018454799134789701,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12873331999384732,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53972283594553527,
                                0,
                                0,
                                0,
                                0,
                                -0.10830480316873137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0156813143691223,
                                -0.13979956462597723,
                                0,
                                0,
                                0,
                                0,
                                -0.55690644088069818,
                                0,
                                0,
                                -0.18345114285974162,
                                -0.66532970375714806,
                                0,
                                0,
                                0.062050525651045962,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.2756970270127987,
                                -0.16463278683035967,
                                0.0085338240755446493,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25700740302179176,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37130902965839374,
                                0,
                                0,
                                0,
                                0.57607158104707812,
                                0,
                                0,
                                0,
                                -0.44019104084507327,
                                0,
                                0,
                                0.055374548572065002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42329465586229298,
                                0,
                                0.16835895782147559,
                                0,
                                0,
                                0,
                                -0.51283294242237643,
                                0,
                                0,
                                0,
                                0.5767536525556376,
                                0,
                                0,
                                0,
                                0,
                                -0.11534205754573457,
                                0,
                                0,
                                0,
                                0,
                                0.26048841795182315,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24295586254943605,
                                0.28608402879824224,
                                0,
                                0,
                                0,
                                0,
                                -1.1042516962785072,
                                0,
                                0,
                                -0.44184005630674006,
                                0.29394096267058778,
                                0,
                                0,
                                -0.4336010956762163,
                                0,
                                0,
                                0,
                                0.083936337591603849,
                                0,
                                0,
                                0,
                                0,
                                -0.78433943956437679,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.56899021959632967,
                                -0.17512355917649999,
                                0,
                                0,
                                0,
                                0,
                                -0.59454899714797715,
                                0,
                                0,
                                0.19124084000440528,
                                0.013196240117436087,
                                0,
                                0,
                                0.30641785014382084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.044875408151492491,
                                -0.6386503409337051,
                                -0.2779859572548643,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.051817369811487698,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.3788096437582615,
                                0,
                                0,
                                0,
                                0.4720726376080196,
                                0,
                                0,
                                0,
                                -0.019320012054457686,
                                0,
                                0,
                                0.25237707461134617,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3288398222778387,
                                0,
                                0.89453182862798486,
                                0,
                                0,
                                0,
                                -0.090584893578177839,
                                0,
                                0,
                                0,
                                -0.13929861900255258,
                                0,
                                0,
                                0,
                                0,
                                0.84721674074763897,
                                0,
                                0,
                                0,
                                0,
                                0.17914293094190425,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54653617519671505,
                                -0.20056450865743181,
                                0,
                                0,
                                0,
                                0,
                                -0.36106143861217954,
                                0,
                                0,
                                -0.055625038761614023,
                                1.0608031732217165,
                                0,
                                0,
                                0.51939950494698572,
                                -0.3980373232878982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58585147019708239,
                                0,
                                0,
                                0.046329370925399814,
                                -0.55257299807826921,
                                0.17009823015289113,
                                0,
                                0,
                                0,
                                -0.070829905438286489,
                                0,
                                -0.31842491515722271,
                                0,
                                0,
                                0,
                                0,
                                -0.23561898336879805,
                                0,
                                0,
                                0,
                                -0.30925311114374637,
                                0,
                                0,
                                0,
                                -0.12208629132836549,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12157073298737017,
                                0,
                                0.24241256048348792,
                                0,
                                0.23565059637274935,
                                0.41176894090547894,
                                0,
                                0.88410744378858974,
                                0,
                                0,
                                -0.52034624200457846,
                                0,
                                0,
                                1.0127585119629385,
                                -0.32058752873250257,
                                0,
                                0,
                                0,
                                0,
                                0.43581118953481224,
                                -0.17704801446339172,
                                -0.81845149066361966,
                                0,
                                -0.5776943808310171,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19926783673893106,
                                -1.2887891594926335,
                                0,
                                0,
                                0,
                                0,
                                -0.27525927664605976,
                                -0.29816998093461999,
                                -0.00092630127734917231,
                                0,
                                -1.1028005353095596,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44483641833665755,
                                0,
                                -0.077239952698995001,
                                -0.75772384165950357,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.32227300760415989,
                                0,
                                0,
                                0,
                                0.25011247546033627,
                                -0.2357816544986209,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42767426358716693,
                                0,
                                0,
                                0,
                                0.30441212251476257,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43876371040181317,
                                0,
                                -1.1158566161227479,
                                0,
                                -0.49436230272910181,
                                -0.93540319143491535,
                                0,
                                0.37486291979799757,
                                0,
                                0,
                                -0.31743958708574144,
                                0,
                                0,
                                0,
                                0,
                                0.26589904051486341,
                                0,
                                0.26941118913504053,
                                0.35304674908682609,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.79434126514578129,
                                0,
                                0,
                                0,
                                -0.047258206680106246,
                                0.3144231555870568,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21664447269666229,
                                0,
                                0.23568018567127236,
                                0.40703381978989384,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.0089700252006320487,
                                0,
                                0,
                                0,
                                0.10921734516073656,
                                -0.84843067026312102,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16342279868504811,
                                0.32726623198812105,
                                0,
                                0,
                                0,
                                0,
                                -0.99574655328725648,
                                -0.33851935299154767,
                                -0.84834642788444825,
                                0,
                                -0.16522348287624947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1253444011872946,
                                0.84624564437355743,
                                0,
                                0,
                                0,
                                0,
                                0.43194538870831212,
                                -0.13291250015948297,
                                -0.12977806033589381,
                                0,
                                -0.7553393248477025,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77215346474878777,
                                -0.50240091520182339,
                                0,
                                0,
                                0,
                                0,
                                0.00030935011097323051,
                                0.53325252060694572,
                                -0.40967403593446949,
                                0,
                                0.64526304361071718,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10950552311705804,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28424869246515139,
                                0,
                                0,
                                -0.42065416803579592,
                                0.10921557430187191,
                                -0.024904736211444119,
                                0,
                                0,
                                0,
                                -0.15699455420267616,
                                0,
                                -0.32040381330459783,
                                0,
                                0,
                                0,
                                0,
                                -0.76837953575531237,
                                0,
                                0,
                                0,
                                0,
                                -0.34835352119437468,
                                0.1571725128479784,
                                0,
                                0,
                                0,
                                0,
                                0.51832527466073541,
                                -1.333997420625983,
                                -0.087370886356553684,
                                0,
                                -0.14370179453957066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.093988133756614564,
                                0,
                                0.30647797796809484,
                                0.08491934578875493,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14221177780127908,
                                0,
                                0,
                                0,
                                0.90700443592522029,
                                0.21712887396870756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52932606833156082,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4290384219549182,
                                0,
                                0,
                                0.32660417395294761,
                                0.406629481488544,
                                0.43650814131173976,
                                0,
                                0,
                                0,
                                0.090141172129068123,
                                0,
                                -0.20542437369309199,
                                0,
                                0,
                                0,
                                0,
                                -0.15118916151802686,
                                0,
                                0,
                                0.082105083215747249,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14038313873563316,
                                0,
                                0,
                                0.20823325821729469,
                                0.022731206258032668,
                                -0.10151903411349383,
                                0,
                                0,
                                0,
                                -0.76259481697803122,
                                0,
                                -0.4881280053201747,
                                0,
                                0,
                                0,
                                0,
                                0.31551166912839484,
                                0,
                                0,
                                -0.41217944110284438,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.019087716314840741,
                                0,
                                0,
                                0.65451814520914575,
                                0.33200085538656132,
                                -0.36370908909495603,
                                0,
                                0,
                                0,
                                -0.025030535857681391,
                                0,
                                0.096096636281220782,
                                0,
                                0,
                                0,
                                0,
                                -0.38597902055996675,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.76146338007366987,
                                0,
                                -0.26266738023511021,
                                -0.071335753325013421,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49437583517010208,
                                0,
                                0,
                                0,
                                0.16006525577083025,
                                -0.27579381058979718,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30955320244572665,
                                0,
                                0.83844114124896507,
                                -0.35104979318552298,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.021211920203793637,
                                0,
                                0,
                                0,
                                -0.27386867316930458,
                                -0.050033134210065083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1507879860363171,
                                0,
                                0,
                                0,
                                -0.713997169537683,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.3954140436177525,
                                0,
                                -0.069197532162289077,
                                0,
                                0.56894369422005364,
                                -0.41125317685528606,
                                0,
                                -0.17462612537534072,
                                0,
                                0,
                                0.36106856585110231,
                                -0.33618457251184852,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.072178927540327037,
                                0,
                                0,
                                -0.075451637853267625,
                                0.18301245416036471,
                                0.64874640472607981,
                                0,
                                0,
                                0,
                                -0.45081471522962957,
                                0,
                                0.46133102995450298,
                                0,
                                0,
                                0,
                                0,
                                -0.07517648089757871,
                                0,
                                0,
                                0,
                                0.21810982874274215,
                                0,
                                0,
                                0,
                                -0.33467376395207638,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10041664200954117,
                                0,
                                -0.53595900337984659,
                                0,
                                0.17183857501669436,
                                0.59541392910327873,
                                0,
                                0.2868063588733481,
                                0,
                                0,
                                0.59010260294279782,
                                -0.50946712467536504,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.01671624960791699,
                                0,
                                0,
                                -0.24450332569359118,
                                0.50113365696294687,
                                0.15355253741106145,
                                0,
                                0,
                                0,
                                0.30241426310977926,
                                0,
                                -0.48819329295074154,
                                0,
                                0,
                                0,
                                0,
                                0.27546603764908029,
                                0,
                                0,
                                0,
                                0.78413185953635367,
                                0,
                                0,
                                0,
                                -0.58703297089926532,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.036676092806687016,
                                0,
                                0.036982527313375022,
                                0,
                                0.32345074319252753,
                                -0.1294719376586895,
                                0,
                                -0.37658933591325106,
                                0,
                                0,
                                -0.48559322640056696,
                                0,
                                -0.38698504034946068,
                                0,
                                0,
                                0,
                                -0.75981560398158099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21893408376382423,
                                0,
                                0.2678547567116828,
                                0,
                                -0.42874002014868212,
                                -0.21955804531480541,
                                0,
                                0.17013750981691486,
                                0,
                                0,
                                0.15944466248239186,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19864087632212685,
                                0,
                                0,
                                0.024262778801103002,
                                0,
                                0,
                                0.41625318917285609,
                                0,
                                0,
                                0,
                                0.26582946859524181,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35008636591648407,
                                0,
                                0.60640533861053458,
                                0,
                                0.394052084255053,
                                -0.041533015881783923,
                                0,
                                0.75769033470975045,
                                0,
                                0,
                                0.61760896886211525,
                                0.013371192304341398,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60526504198490849,
                                0,
                                0,
                                -0.42071778628256706,
                                0.34931036153377082,
                                -0.43916545129785933,
                                0,
                                0,
                                0,
                                -0.29213819833534632,
                                0,
                                0.23470252013218781,
                                0,
                                0,
                                0,
                                0,
                                0.034028845136667388,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20256913611961061,
                                0,
                                0,
                                0.45698436887468752,
                                0,
                                0,
                                -0.61017573842972628,
                                0,
                                0,
                                0,
                                0.039624290724594016,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63530843978269291,
                                0,
                                -0.017496474209410903,
                                0,
                                0.69520171402813158,
                                -0.14391439153738528,
                                0,
                                -0.1476220419229361,
                                0,
                                0,
                                -0.1202983629801348,
                                -0.53158309532973536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14041568225874812,
                                -0.66671435408106849,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.78624735164683091,
                                0,
                                0,
                                0,
                                0,
                                0.38736050524335891,
                                -0.81318235560143304,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60717023016306615,
                                0,
                                0.66450765851687676,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43335892810514792,
                                0,
                                0,
                                0.24562208048426384,
                                0.32052699464247514,
                                0,
                                0,
                                -0.28366902965901014,
                                -0.52923172565865884,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85014328834518194,
                                0,
                                0,
                                0,
                                0.28298629800093761,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.33283591558889358,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.011463733421990197,
                                0,
                                0,
                                0,
                                0.57182173258759672,
                                0.62484949794779654,
                                0,
                                0,
                                -0.3026393931872759,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18912835423933461,
                                0,
                                -0.21078362043775828,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.1342211267389097,
                                0,
                                0,
                                0.095232345445097039,
                                -0.25288952202323711,
                                0,
                                0,
                                -0.1522346673270441,
                                0.4139083938077267,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.98151699997621278,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35385226298224459,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39887000926582467,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22174502635093782,
                                -0.20776138755484053,
                                -0.08018863914812667,
                                0,
                                0,
                                0,
                                0.086111447970670468,
                                0,
                                -0.42111758896599283,
                                0.76228563029417717,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35505170426332183,
                                0,
                                0.096632454279428528,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22697424042969697,
                                0.28140277974238936,
                                0.75478203952844192,
                                0,
                                0,
                                0,
                                0.18968119452524848,
                                0,
                                -0.37412742618313372,
                                -0.22492461754665949,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2266280422881439,
                                0,
                                -0.14730106188040498,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.086677809711584342,
                                0.36311071639154885,
                                -0.22583443091769856,
                                0,
                                0,
                                0,
                                -0.76358853598090082,
                                0,
                                -0.13947549726273234,
                                -0.094089804463913754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38838136762538045,
                                0,
                                -0.21776714655002244,
                                0,
                                0,
                                -0.75321074488805018,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37316220032388014,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44972462192234341,
                                0,
                                0,
                                0,
                                0.16855658016448372,
                                0.1062342228218626,
                                0,
                                0,
                                0.22687943859266607,
                                0,
                                0,
                                0,
                                0,
                                -0.22734329458708746,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.47335172818559201,
                                -0.44108448003507755,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.025158040313590434,
                                0,
                                0,
                                0,
                                0,
                                -0.59679173445019906,
                                0.78119693500403953,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.070321233785795523,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54083002811195602,
                                -0.68207279567112289,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48616262454082865,
                                0,
                                0,
                                0,
                                0,
                                -0.34208643280750006,
                                -0.44007058016241962,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23535780242569404,
                                0.041400630092904962,
                                0.33631013359440903,
                                0,
                                0,
                                0,
                                -0.4873790619371402,
                                0,
                                -0.034646737227999505,
                                0.19028627871149872,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52267645281970643,
                                0,
                                0.53070697950341239,
                                0,
                                1.0592240418113268,
                                0,
                                -0.34841568224840247,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.076113807238199924,
                                0,
                                0,
                                1.0038808844170806,
                                0.70419145435088293,
                                0,
                                0,
                                0.28011388623793476,
                                0.034216190642793673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12205751922244781,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31400874798963418,
                                -0.28982233084132719,
                                0.2504968638942815,
                                0,
                                0,
                                0,
                                -0.093526973366161698,
                                0,
                                0.67461446921393642,
                                -0.019824110008122314,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50523792712355542,
                                0,
                                0.18746335308335771,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.080800912393515209,
                                0.76374743151650981,
                                -0.028291904906906775,
                                0,
                                0,
                                0,
                                0.23424875753158256,
                                0,
                                0.41176945025909917,
                                0.42121529987209005,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.068115454450463062,
                                0,
                                -0.053591388971991574,
                                0,
                                0.78498593954150331,
                                0,
                                -0.43696404464734373,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.018374815286004875,
                                0,
                                0,
                                -0.30181415070806511,
                                -0.6484886473630147,
                                0,
                                0,
                                0.33954010897084375,
                                -0.52030633195429321,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.086568598304281957,
                                0,
                                0,
                                0.068037181518127043,
                                0,
                                -1.4959321458885744,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.058596524802721595,
                                0,
                                0,
                                0.13006772203047806,
                                -0.25911392406715628,
                                0,
                                0,
                                -0.50136275137711417,
                                -0.24015626783821026,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.452564694500937,
                                0,
                                0,
                                0,
                                -0.29972200175042951,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.056850223530363064,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.83859012915324826,
                                0,
                                0,
                                0,
                                0.1311878157389969,
                                0.16359031640397478,
                                0,
                                0,
                                0.39966152481628714,
                                0,
                                0,
                                0,
                                0,
                                0.98985637542803939,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1778256867527932,
                                -0.1891072057483083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.022970972343750728,
                                0,
                                0,
                                0,
                                0,
                                0.26556369630776111,
                                -0.42548438787865084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.60649426938434847,
                                0,
                                -0.062787247604447649,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37499625950036347,
                                0,
                                0,
                                0.79311901697044962,
                                -0.51882486218534618,
                                0,
                                0,
                                0.6813187565305,
                                0.55468979267633478,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.85016042568832761,
                                0,
                                0,
                                -0.63492831117482162,
                                0,
                                0.32722111286147793,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5997247567525219,
                                0,
                                0,
                                0.82499563021599576,
                                -0.081414992612428821,
                                0,
                                0,
                                0.31323027543055815,
                                -0.95246930103765592,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39283585924414788,
                                0,
                                0,
                                0,
                                -0.084062607343755327,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32314873795307519,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.099303054867120863,
                                0,
                                0,
                                0,
                                -0.779634293831032,
                                0.45718535719716813,
                                0,
                                0,
                                -0.24859443185044899,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33582004389689579,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18872000579676157,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28818884450879445,
                                0,
                                0,
                                0,
                                0.13297216802312745,
                                -0.43764459383721993,
                                0,
                                0,
                                -0.74789201055107313,
                                0,
                                0,
                                0,
                                0,
                                -0.76848127867303806,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8811327910922615,
                                0.86073885086052981,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.73853647350379692,
                                0,
                                0,
                                0,
                                0,
                                0.19508601110242685,
                                -0.47835163717269136,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22149224754955507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31707896221735576,
                                -0.1010017565142769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65119547553891999,
                                0,
                                0,
                                0,
                                0,
                                0.91445411529831278,
                                0.64022803968123521,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37804421270439448,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77890816544666941,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.038328001960919386,
                                0,
                                0,
                                0,
                                0.043440912044082833,
                                0.41347836925795906,
                                0,
                                0,
                                -0.27579726725161779,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15831533798478947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.66169994078236227,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23200636668380015,
                                -0.25515746405322187,
                                0.36682362433561372,
                                0,
                                0,
                                0,
                                -0.25525271304444708,
                                0,
                                0.19331771421152372,
                                0.36216115134565863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.22267623720584767,
                                0,
                                -0.68061520015402777,
                                0,
                                -0.44718377358740946,
                                0,
                                -0.50831364593441197,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29151577427028219,
                                0,
                                0,
                                -0.7625185977328327,
                                0.80482018336183092,
                                0,
                                0,
                                0.50081368530904702,
                                -0.70093001322969006,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.43522117333705479,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.82307245378002669,
                                -0.10803621059456434,
                                -0.24831326331027953,
                                0,
                                0,
                                0,
                                0.0850078702651198,
                                0,
                                -0.0020817387852762048,
                                -0.11954811320388348,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29842498545253782,
                                0,
                                -0.37234465396558958,
                                0.0086239805087103688,
                                0,
                                0,
                                0,
                                0,
                                -0.17731443520735729,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.01103499015058395,
                                -0.67127537538093007,
                                0,
                                0,
                                0.22317686867618564,
                                -0.44773303096195449,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46831189587269484,
                                0,
                                0,
                                0.2194629897829827,
                                0,
                                -0.62668518076023982,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12555406081525963,
                                0.042429286732903318,
                                -0.49075647851725862,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.25115071513835124,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.31052178009877118,
                                0,
                                -0.17616646573226205,
                                0,
                                -1.1664767131531506,
                                0,
                                0,
                                0,
                                0,
                                -0.090773322581765098,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.088134162657287338,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.35163426423602451,
                                0.92887378076315863,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.015476074736341192,
                                0,
                                0,
                                0.12451256522582409,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -1.154427272548292,
                                0,
                                0.88697644101983242,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12711757489409767,
                                -0.94420687703877493,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14069462184036699,
                                0,
                                0,
                                0.10039963276835608,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45282012256565557,
                                0,
                                0.067530245299201139,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64883683908931489,
                                0,
                                0,
                                0,
                                0,
                                0.468789976842164,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.098815112744869177,
                                -0.0045704907513229726,
                                0,
                                0,
                                0.22019121737167807,
                                -0.052840091931008137,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20702602098729159,
                                0,
                                0,
                                0.50529731551997259,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30439416923047474,
                                0.42895167612671059,
                                0,
                                0,
                                0,
                                0,
                                0.32609521413848336,
                                0.093129939984650467,
                                0,
                                0,
                                0,
                                0,
                                0.77594735722099495,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.078987807304421273,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58617755229652169,
                                0.10268856856701893,
                                0,
                                0,
                                0,
                                0,
                                -0.014632368584590334,
                                0.19119582228664025,
                                0,
                                0,
                                0,
                                0,
                                -0.22752160603617957,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.74653526720830354,
                                0,
                                0,
                                -1.3650763542746833,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13847114312519487,
                                0.11789221838458849,
                                -0.30595223418813478,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44088293890868774,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.26403858875078928,
                                0,
                                0.083880099454058055,
                                0,
                                0.38576731059820568,
                                0,
                                0,
                                0,
                                0.21182416768774881,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68819496805261404,
                                -0.16952837877649715,
                                0.32996367547914535,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.84300783632347387,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.19881901131769261,
                                0,
                                0.42397999783004442,
                                0,
                                0.47894233868694669,
                                0,
                                0,
                                0,
                                -0.23719738242969918,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52569854557274054,
                                -0.30300980718719883,
                                0.23099343610933645,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13406434405268586,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30888955525264911,
                                0,
                                1.4080055937166838,
                                0,
                                0.042882182191156415,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.68687282147700179,
                                0.41691699926235248,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11487756363854254,
                                0,
                                0,
                                0.095454226127608358,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30596642668835039,
                                0,
                                -0.93230799333732195,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32901558752588012,
                                -0.38374435324902278,
                                0,
                                0,
                                0,
                                0,
                                0.27205653219786219,
                                0.78930830788583373,
                                0,
                                0,
                                0,
                                0,
                                0.14837946895370457,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1595311446031227,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56790159401498796,
                                0.65513220536150429,
                                0,
                                0,
                                0,
                                0,
                                0.31601787186124841,
                                -0.043579013268681244,
                                0,
                                0,
                                0,
                                0,
                                -0.23630666542469569,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30113503143288378,
                                0,
                                0,
                                0,
                                0,
                                0.75744687449389758,
                                -0.48651118860179254,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2758931155981284,
                                0,
                                0,
                                0.51726534886200648,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71051873078721928,
                                0,
                                0.81454110330903362,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.29117677942062592,
                                0,
                                0,
                                0,
                                0,
                                0.18076842979576382,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.13834047446348655,
                                0.32171223164647189,
                                0,
                                0,
                                -0.42651086638822761,
                                0.020046037873414871,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.75989227491090472,
                                0,
                                0,
                                -0.012344180764267659,
                                -0.22753851042940104,
                                0,
                                0,
                                0,
                                0,
                                -0.27278682036221413,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10901425173649308,
                                0.45816151224248208,
                                0,
                                0,
                                0.70142570579331887,
                                -0.17708353201880411,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.19707816113204502,
                                0,
                                0,
                                -0.29970168313033985,
                                0,
                                0.31077011136938804,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62478863804216322,
                                0.95377392117889748,
                                -0.65755925574070684,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17933234186591229,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26630240504023805,
                                0,
                                0.80741508408615903,
                                0,
                                -0.063001981633099752,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36189080960783521,
                                0.093903890763384484,
                                0,
                                0,
                                0,
                                0,
                                0.57047796979682286,
                                0.19420442278923605,
                                0,
                                0,
                                0,
                                0,
                                -0.50681966694607228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.49009229188301928,
                                0,
                                0.33860726356703463,
                                0,
                                0,
                                0,
                                0,
                                0.18124077703374397,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79715573005620843,
                                0.21552283259739652,
                                0,
                                0,
                                0.27084949898674454,
                                -0.075933244750507375,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.009199558631660212,
                                0,
                                0,
                                0.30229060823794857,
                                -0.21554356500134259,
                                0,
                                0,
                                0,
                                0,
                                -0.72002237196866792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10531286479186958,
                                0.24105111462623482,
                                0,
                                0,
                                -0.29938950626996058,
                                -0.20496944045348708,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18792157260090278,
                                0,
                                0,
                                0.44603951693176602,
                                0,
                                0,
                                0.28674644832109947,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11584022884337083,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60378055535372688,
                                -0.4292893327628981,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1565932699897858,
                                0,
                                0,
                                -1.0666875327310239,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.263557543135852,
                                0,
                                0.5707329734126122,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69412706266131907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.49621137430623485,
                                0.33064331575888051,
                                0.55460281637192277,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2559740431311549,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.67439178786059428,
                                0,
                                -0.16072672617209477,
                                0,
                                -0.32154568353558777,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.085931772147779112,
                                -0.2095437876306907,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.77836600317904281,
                                0,
                                0,
                                1.3464049755075778,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11630944813069026,
                                0,
                                0.037547900293352414,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60705265122346996,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.69830391811759673,
                                -0.62423986129391207,
                                -0.72117302167874087,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28359243341834522,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30674525590659169,
                                0,
                                0.42277111398549894,
                                0,
                                0.00056158771394915208,
                                0,
                                0,
                                -0.5281078514061186,
                                0,
                                0,
                                0,
                                0,
                                -0.12574842394572541,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55877396204230145,
                                -0.32565596772250843,
                                0,
                                0,
                                -0.060854107316380232,
                                0.080157512822860669,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18060138411558863,
                                0,
                                0,
                                -0.49423068703284434,
                                0,
                                -0.085439464431176448,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87271342192171197,
                                0.37641688229793491,
                                -0.72315186784324381,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.091106559512084684,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.37622914851247213,
                                0,
                                -0.53476374657527936,
                                0,
                                -0.17565615308886717,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.044851215410156603,
                                0.4692330354748081,
                                0,
                                0,
                                0,
                                0,
                                -0.62779028268589621,
                                0.5405079820803953,
                                0,
                                0,
                                0,
                                0,
                                -0.10684631895400563,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2830601937642408,
                                0,
                                0.0486506169328128,
                                0,
                                0,
                                0,
                                0,
                                0.27315302045785783,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.017754166287862552,
                                0.15921749019367526,
                                0,
                                0,
                                -0.24718742533179994,
                                -0.84307714990003357,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23137008121525404,
                                0,
                                0,
                                -0.26822063096520826,
                                0.29201189943333128,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.60118521100391309,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37255070505149623,
                                0,
                                0,
                                0.42962565562424804,
                                0,
                                -0.56223097535029221,
                                0,
                                0.41879047495338656,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.12992586883643886,
                                0,
                                0,
                                1.2598671466588012,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12445562068652188,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87372365558285203,
                                0,
                                -0.11134435052955169,
                                -0.24440474611130597,
                                0,
                                0,
                                0.38598298383174617,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.0019141656754394221,
                                0,
                                0,
                                0,
                                0.25297545164296864,
                                0,
                                0,
                                0,
                                0.036779690240725339,
                                0,
                                0,
                                0.28644626706484411,
                                0,
                                0,
                                0.57010748077428208,
                                0.12410851555319427,
                                0,
                                0.27130928277196503,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34657052090814694,
                                0,
                                0,
                                0,
                                0,
                                0.56431719377319212,
                                0,
                                0,
                                0,
                                -1.0861597012956834,
                                0,
                                0,
                                0.12720488485516884,
                                0,
                                -0.88094592200204214,
                                0,
                                -0.25153307455174312,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23089163229020424,
                                0,
                                0,
                                -0.42506098606470194,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.28217368463739501,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56688026643471923,
                                -0.20917633209579156,
                                0.46990178210151801,
                                -0.40700290666084893,
                                0,
                                0,
                                -0.55362952160734857,
                                0,
                                0,
                                0.45361274719544231,
                                0,
                                -0.50739597261185831,
                                0,
                                0,
                                0.29252075087182466,
                                0,
                                0,
                                0.88198935638748299,
                                0,
                                -0.25863705365316236,
                                0,
                                -0.62733212071276878,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.88755315079590535,
                                0,
                                0,
                                -0.31421224105213835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.27102121844798577,
                                0,
                                0,
                                0,
                                0.30935833108845173,
                                0,
                                0,
                                0.0085037840907801684,
                                0,
                                0,
                                -0.46590336757805728,
                                0.58888329177809062,
                                0,
                                -0.01807607692087641,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.097850497545554097,
                                0,
                                0,
                                0,
                                0,
                                0.5069730408123676,
                                0,
                                0,
                                0,
                                0.50660056330732772,
                                0,
                                0,
                                -1.3037007880860385,
                                0,
                                -0.60725359462024842,
                                0,
                                0.42647659552922224,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46499869720282461,
                                0,
                                0,
                                0.0834714029362503,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.043732327693780798,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.018608093824580382,
                                0,
                                0.23144985098449966,
                                -0.14904855372065068,
                                0,
                                0,
                                -0.004352208923617003,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.96017590875277592,
                                0,
                                0,
                                0,
                                -0.67367688686898841,
                                0,
                                0,
                                0,
                                -0.31085681375235491,
                                0,
                                0,
                                0.10052015574548978,
                                0,
                                0,
                                0.17532127803712458,
                                -0.39450726941727998,
                                0,
                                -0.24185083641699251,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17524543367758186,
                                0,
                                0,
                                0,
                                0,
                                0.40478002232700799,
                                0,
                                0,
                                0,
                                0,
                                0.78768864510154613,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.1129887479890907,
                                0,
                                0.54864174645556729,
                                -0.22131765292611932,
                                0,
                                0,
                                0.016980824461752704,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12846214756108437,
                                0,
                                0,
                                0.37681118489639548,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16503135082583351,
                                0,
                                -0.70858128162033773,
                                -0.56121672222238628,
                                0,
                                0,
                                -0.065181213501304958,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.09735374478319965,
                                0,
                                0,
                                0,
                                -0.041955452839700057,
                                0,
                                0,
                                0,
                                -0.63332676336325555,
                                0,
                                0,
                                -0.44863031151976179,
                                0,
                                0,
                                -0.1390677786616199,
                                0.13795769490886195,
                                0,
                                0.58809838250932378,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.013311901988747661,
                                0,
                                0,
                                0,
                                0,
                                0.10704535244201507,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.058726232681220153,
                                0,
                                0,
                                0,
                                0.54247997564813766,
                                0,
                                0,
                                -0.54133315638034285,
                                0,
                                0,
                                0.3232011230041012,
                                -0.19987854112437181,
                                0,
                                0.28070368717654054,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41829253985823855,
                                0,
                                0,
                                0,
                                0,
                                0.10512617852124895,
                                0,
                                0,
                                0,
                                0,
                                0.41359920865695488,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34499552698257774,
                                0,
                                -0.33478684634804939,
                                0.67232860051551779,
                                0,
                                0,
                                -0.31947693816304551,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20914178775054487,
                                0,
                                0,
                                0,
                                0.41032329960572828,
                                0,
                                0,
                                0,
                                -0.1325881508147366,
                                0,
                                0,
                                0.43165353779239934,
                                0,
                                0,
                                -0.21541588717880597,
                                -0.19413968830225919,
                                0,
                                0.1903674943500441,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.68507188923559115,
                                0,
                                0,
                                0,
                                0,
                                0.19512277167577041,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24993328171181806,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.59820960007571033,
                                -0.013494552673502073,
                                0.29047809114379342,
                                0.41493803581229299,
                                0,
                                0,
                                0.27667210301057438,
                                0,
                                0,
                                0.24412637030173509,
                                0,
                                0.80257884747085728,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.027514886709958289,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5283601231414925,
                                -0.33077861272317288,
                                -0.91628950364251049,
                                -0.77103326509888781,
                                0,
                                0,
                                1.1495992858615962,
                                0,
                                0,
                                -0.029435089752377325,
                                0,
                                0.11957299397012061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.24681413617968068,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51793298157674217,
                                1.036548018657216,
                                0.1859955965713708,
                                1.0186371905243299,
                                0,
                                0,
                                0.5900511863809117,
                                0,
                                0,
                                0.22639927057057868,
                                0,
                                -0.54949412439573087,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.79720601924886925,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.13030658869575668,
                                0.683839563263689,
                                -0.34035612385764152,
                                -0.4874266541070702,
                                0,
                                0,
                                -0.66228548256850195,
                                0,
                                0,
                                -0.27784473428013096,
                                0,
                                0.17727096774987913,
                                0,
                                0,
                                0.25974913543990152,
                                0,
                                0,
                                0.88431836371653338,
                                0,
                                -0.044067355235731687,
                                0,
                                1.1548658470206226,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.014962858804581933,
                                0,
                                0,
                                -0.87960101303595084,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.48489902938331214,
                                0,
                                0,
                                0,
                                -0.15668836759040231,
                                0,
                                0,
                                -0.47492615668584465,
                                0,
                                0,
                                -0.10177814197812954,
                                -0.1279192364239895,
                                0,
                                -0.56569056290841213,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.048506458700332725,
                                0,
                                0,
                                0,
                                0,
                                0.40704547869923452,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44391966761234636,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20957139136576947,
                                0.018444651667144801,
                                0.59695340361693849,
                                -0.29935439836428351,
                                0,
                                0,
                                -0.30509765151222751,
                                0,
                                0,
                                -0.83651494260210058,
                                0,
                                0.17256399660050009,
                                0,
                                0,
                                0.222996810244904,
                                0,
                                0,
                                -0.2835286136449276,
                                0,
                                -0.37460341129794233,
                                0,
                                -0.57944893331565228,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.99460804606560194,
                                0,
                                0,
                                -0.33563007903131098,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18553263487765165,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14275650693232189,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.56941142020281177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.018978119632594263,
                                -0.77847905987180599,
                                0.40443526105652983,
                                0.73799759405193921,
                                0,
                                0,
                                0.042219914802967079,
                                0,
                                0,
                                -0.63763713708580194,
                                0,
                                -0.48371076638340776,
                                0,
                                0,
                                0,
                                0,
                                0.0030104470416053436,
                                0,
                                0,
                                0,
                                0.26228713897120598,
                                0,
                                0,
                                0.039768661349741913,
                                0,
                                0,
                                -0.49660079974312804,
                                -0.60756913433841897,
                                0,
                                0.29440251030854869,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43906829372048234,
                                0,
                                0,
                                0,
                                0,
                                0.18549510931697699,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.50874785117353061,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.52092175377008698,
                                -0.052687386940346165,
                                0.88107250035838236,
                                -0.50504832149559853,
                                0,
                                0,
                                0.36019081353238225,
                                0,
                                0,
                                -0.066023864126392384,
                                0,
                                0.041799123370910948,
                                0,
                                0,
                                0,
                                0.22157144650749078,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27791544569099769,
                                0,
                                -0.13731704548306303,
                                0.3194986523322596,
                                0,
                                0,
                                0.86278371650077479,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.091312637995712612,
                                -0.2104374203700565,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61821569811039701,
                                0.34153880938673287,
                                0,
                                0,
                                0,
                                0,
                                0.021299884248324404,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.088981492407514962,
                                -0.25813261955967864,
                                0,
                                -0.60317719010357096,
                                0,
                                0,
                                0,
                                0.13435074022318064,
                                0,
                                -0.39648206164990957,
                                0,
                                0,
                                -0.50693005228077226,
                                -0.082154811092070817,
                                0,
                                -0.42304330113807631,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.63053542575614552,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.05033811803785565,
                                0,
                                0,
                                0,
                                -0.075598592144738519,
                                0,
                                0,
                                0,
                                -0.23130949734764542,
                                0,
                                -0.98582518560090748,
                                -0.029448440575676176,
                                0,
                                0,
                                0.31740007874952403,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.61771952644162809,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45426099062228126,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.34730128741240074,
                                0.22644429430404506,
                                0.44770874320906368,
                                0,
                                0.068238239030177839,
                                0,
                                0,
                                0,
                                -1.0007421022508816,
                                0,
                                0,
                                0.3744426018555474,
                                0,
                                0.024485614177249995,
                                0,
                                0,
                                0,
                                0,
                                -0.53093844356059139,
                                0,
                                0,
                                0.0134424201028851,
                                0.75067673761202802,
                                0,
                                0.11903089322781779,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17193775976599066,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33268176884740158,
                                0,
                                0,
                                0.60545701676838926,
                                0,
                                0,
                                -0.67575767633435824,
                                0.35740029515681598,
                                0,
                                0.18601195420807048,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.00079956945124667889,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.12015534246681853,
                                0,
                                0,
                                0,
                                0.26026579672811695,
                                0,
                                0,
                                0,
                                -0.26131773749436887,
                                0,
                                0.87323480032214595,
                                0.12493754126821344,
                                0,
                                0,
                                0.67388993093937999,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.87091473152371002,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30181668800696282,
                                0,
                                0,
                                0.31742074950042498,
                                0.52671895270309865,
                                0,
                                -0.56262052288148834,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17047819428277997,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.43024787273976212,
                                0,
                                0,
                                0,
                                0.95877055510774745,
                                0,
                                0,
                                0,
                                0.22538816213114285,
                                0,
                                -0.42324874401143964,
                                0.36215925696425344,
                                0,
                                0,
                                -0.19434041511666456,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.52760615911557929,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1833668753944101,
                                0,
                                0,
                                0,
                                0.65588109612526724,
                                0,
                                0.54756746497042452,
                                -0.49112873070636015,
                                0,
                                0,
                                -0.54964578336953274,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.7457567311871327,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.050139859303971634,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.023323281528460221,
                                0.53819176709964112,
                                0,
                                0,
                                0,
                                0,
                                -0.5949142659939104,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54722956820953006,
                                0.16974883827738124,
                                0,
                                0.14032217812350656,
                                0,
                                0,
                                0,
                                0.073508332168416624,
                                -0.24475666958940867,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.45689151062539185,
                                -0.059038040261018887,
                                0,
                                0,
                                0,
                                0,
                                0.10907645986973676,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.2186558834284979,
                                -0.27108659254216988,
                                0,
                                0.47202752744757648,
                                0,
                                0,
                                0,
                                -0.60979737063395201,
                                0,
                                0,
                                -0.1670284253575515,
                                0,
                                0,
                                0,
                                -0.063736826699840626,
                                0,
                                0.032725533636828286,
                                1.3671337101141698,
                                0,
                                0,
                                -1.0567863194925584,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15764695765854092,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.5440390728132477,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41725160880228584,
                                0.80745927246792326,
                                0.79362338121299059,
                                0,
                                -0.83271625706204055,
                                0,
                                0,
                                0,
                                0.4036143227788852,
                                0,
                                0,
                                0.39727774099985247,
                                0,
                                -0.12998048512721327,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25468097550956981,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.14945487691378639,
                                -0.69340457216763463,
                                -0.089780599738725111,
                                0,
                                -0.41594899441118394,
                                0,
                                0,
                                0,
                                -0.46415694215849568,
                                0,
                                0,
                                0.50388178254715055,
                                0,
                                0.44529529791174011,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11124455081290156,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.83752775611900943,
                                -0.11389180743700522,
                                0.87248135705212637,
                                0,
                                1.041067021557432,
                                0,
                                0,
                                0,
                                -0.36064561985188803,
                                0,
                                0,
                                -0.30516555817005397,
                                0,
                                0.12295950898095533,
                                0,
                                0,
                                0,
                                -0.54535211751002877,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.38389632498947152,
                                0.35496337203279982,
                                0,
                                0,
                                0,
                                0,
                                0.27170114211607538,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11576881352803078,
                                0.34659685893372305,
                                0,
                                -0.21698668153856987,
                                0,
                                0,
                                0,
                                -0.41806596692543341,
                                0,
                                0,
                                0,
                                -1.2106116419057362,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35201641910601533,
                                -0.33603752080900684,
                                -0.2943572070440722,
                                0,
                                -0.71372389179513474,
                                0,
                                0,
                                0,
                                0.18037349807322062,
                                0,
                                0,
                                -0.43193618851624394,
                                0,
                                -0.1627597261279535,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.57899693529688412,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17745351746771912,
                                0,
                                0,
                                0,
                                0,
                                0.27563681703590687,
                                0,
                                0,
                                0,
                                -1.1950778016879902,
                                0,
                                -0.67028761693509065,
                                -0.67648579151044941,
                                0,
                                0,
                                -0.36297414535890909,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10130381378812175,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.020910259371297993,
                                0,
                                0,
                                -0.19244877387959672,
                                -0.15557271770008543,
                                0,
                                -0.66698796605147259,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.63356539821665314,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30338968228627616,
                                0,
                                0,
                                0,
                                0,
                                -0.51228655569503068,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16957672839702204,
                                -0.49469614291919056,
                                -0.16178241476634339,
                                0,
                                0.35750591394571896,
                                0,
                                0,
                                0,
                                -0.28511388903428003,
                                0,
                                0,
                                0.76808257772434596,
                                0,
                                -0.80142223928756251,
                                0,
                                0,
                                0,
                                -0.49319623217475134,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20607154384377524,
                                0.04264773483900533,
                                0,
                                0,
                                0,
                                0,
                                0.2286760873832584,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10357581686779938,
                                0.22887472368729297,
                                0,
                                0.46952420188227439,
                                0,
                                0,
                                0,
                                0.61369035190615906,
                                -0.47111735644143959,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.026937329559584652,
                                -0.41839237195536794,
                                0,
                                0,
                                0,
                                0,
                                -0.68889502272826741,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34017371841012567,
                                -0.045236906526151394,
                                0,
                                -0.070600529165126491,
                                0,
                                0,
                                0,
                                -0.070322943327093268,
                                0,
                                0,
                                0,
                                0.15996128540027893,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.76978603083118347,
                                -0.5424445891435451,
                                0.15739344737641947,
                                0,
                                -0.31772234523762138,
                                0,
                                0,
                                0,
                                -0.16805311872875925,
                                0,
                                0,
                                -0.56241382594565548,
                                0,
                                -0.74996547663101731,
                                0,
                                0,
                                0,
                                -0.29388129237269106,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.079964970957919712,
                                -0.49468740447114684,
                                0,
                                0,
                                0,
                                0,
                                0.17387373272038123,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71041632050973869,
                                0.0073404189202168381,
                                0,
                                -0.33205592869955625,
                                0,
                                0,
                                0,
                                0.13147363370460508,
                                0,
                                0,
                                0,
                                0.27679688327463559,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50489335008218372,
                                0.46305058363770413,
                                -0.35869000676802193,
                                0,
                                -0.086894739352078032,
                                0,
                                0,
                                0,
                                -0.82618121378738429,
                                0,
                                0,
                                -0.31206654236347164,
                                0,
                                -0.37743251513692544,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30995114839362575,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24482347132700563,
                                0,
                                0,
                                0,
                                0.32062063670130281,
                                0,
                                0,
                                0.38522762560648205,
                                -0.019087326035091778,
                                0,
                                -0.10416700574731717,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37735118361881148,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77148757404821144,
                                0,
                                0.21053984482139745,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.4599496025005172,
                                -0.20646971566398054,
                                0,
                                0,
                                0,
                                0,
                                -0.052943045928875165,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.016487060355284106,
                                0.81021704545076989,
                                0,
                                -0.10438010526884085,
                                0,
                                0,
                                0,
                                -0.17626099123044334,
                                0.13949200959362304,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.4865246217676179,
                                -0.19525236425650416,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58561190247919814,
                                -0.27010261579028177,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.98124992756943485,
                                0,
                                -0.58621465282604257,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.38222515044059746,
                                0,
                                0,
                                0,
                                -0.40754605001633487,
                                0.08126051522769262,
                                0,
                                0,
                                0,
                                0,
                                0.49527210663197818,
                                0,
                                0,
                                0,
                                0,
                                -0.30375121622149875,
                                0,
                                0,
                                0,
                                0.16413243633343602,
                                0,
                                0,
                                0,
                                0.013649923476282532,
                                -0.9409335320222757,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.5329457228622333,
                                -0.34511261254891873,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.1032437621135218,
                                0,
                                -0.17871430197285321,
                                -0.30942401894373756,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.10359729367648864,
                                -0.53569925620473879,
                                0.029625020589777382,
                                0,
                                0,
                                0,
                                0,
                                -0.39904058432073541,
                                -0.38560271479616587,
                                -0.55468012716358805,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16008159417908935,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2453513071929958,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.20954880123798608,
                                -0.51813883183390885,
                                0.34328955833016195,
                                0,
                                0,
                                0,
                                0,
                                0.20479596772854547,
                                -0.079161084978620469,
                                0.27840790241778324,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64336971015889077,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.17358087491290369,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.06635123663491721,
                                -0.11085934250106234,
                                -0.30879404834619167,
                                0,
                                0,
                                0,
                                0,
                                0.21962092874371475,
                                -0.75714944070194179,
                                0.33826338304824144,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.11155341254841361,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.37360279338257835,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30642524472983418,
                                0,
                                0,
                                0,
                                -0.2372730857972869,
                                1.0377940634202656,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.2493226292948397,
                                -0.18129259994211674,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.0017352931895076,
                                0,
                                -0.35334733309302696,
                                0.074594810501711822,
                                0,
                                0,
                                0,
                                0,
                                0.68113468002477595,
                                0,
                                0,
                                0,
                                -0.43460892125931194,
                                -0.1517989926669738,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.27278329591872152,
                                -0.32878686435407284,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.35365933333125454,
                                0,
                                0.92175799525563307,
                                0.48915746857525011,
                                0,
                                0,
                                0.33396173303354965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.92037719326954837,
                                0.0044999136629585434,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22486657002257254,
                                -0.91369314950028491,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31861236844927321,
                                0.53599611050741858,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39772536432350009,
                                1.3700388210425112,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.041209210034570468,
                                0.49758569258626534,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.33200916827552501,
                                0,
                                0,
                                0,
                                0.76466199623035247,
                                0.11221322524191785,
                                -0.16098195692274936,
                                0,
                                0,
                                0,
                                0,
                                0.015727023308152698,
                                -0.063959176019116298,
                                -0.44613765569140451,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.20516521978753766,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.36237458858434152,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.023029456674842852,
                                -0.12673687478191048,
                                -0.85774433166287412,
                                0,
                                0,
                                0,
                                0,
                                -0.00071653712976968431,
                                0.16477130549342656,
                                0.070777573299911078,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.22903179555164316,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40381548434982673,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.53013363696883364,
                                -0.18918104213142961,
                                0.035029834106998337,
                                0,
                                0,
                                0,
                                0,
                                -0.43271602821810962,
                                0.083571146166294769,
                                0.52001235274426416,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45174713772615255,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11500499978652773,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45484680023961099,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.26352164003527012,
                                0,
                                0,
                                0,
                                -0.44287820286508534,
                                0.66414370259156519,
                                0,
                                0,
                                0,
                                0,
                                0.29156271179216037,
                                0,
                                0,
                                0,
                                0,
                                0.037867642813750511,
                                0,
                                0,
                                0,
                                -0.84684164501209724,
                                0,
                                0,
                                0,
                                0.54990357022942937,
                                -0.41676737481479215,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.59864241242350869,
                                -0.19473424011042423,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.08050747001087516,
                                0,
                                1.078907696103564,
                                0.069768898377121372,
                                0,
                                0,
                                0,
                                0,
                                0.247765925932079,
                                0,
                                0,
                                0,
                                0.97877948542679249,
                                -0.43148302499805097,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.21063218843597181,
                                1.1119604718952287,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.45087915057823919,
                                0,
                                -0.14252954711950647,
                                0.89093618194301993,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42708618202839871,
                                0,
                                0,
                                0,
                                0.24103690696832189,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.46511436697037473,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.030212857736958053,
                                0,
                                0,
                                0,
                                0.3559005715048677,
                                -0.26378442283234105,
                                0,
                                0,
                                0,
                                0,
                                0.51661506032901872,
                                0,
                                0,
                                0,
                                0,
                                -0.56534701713184587,
                                0,
                                0,
                                -0.0737739834264039,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62484275466461148,
                                0,
                                0,
                                0,
                                -0.50351894341493564,
                                -0.43870293492383472,
                                0,
                                0,
                                0,
                                0,
                                -0.16839484712676717,
                                0,
                                0,
                                0,
                                0,
                                -0.36025062843139344,
                                0,
                                0,
                                0,
                                0,
                                -0.26990816961122699,
                                -0.31581322627670022,
                                -0.1390432294718196,
                                0,
                                0,
                                0,
                                0,
                                -0.45252687110604911,
                                0.32611129614959344,
                                0.088034835082371893,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.23187135670028539,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.65987495908577687,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.048302820203978525,
                                0,
                                0,
                                0,
                                0.45372404795516769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.8292508739736737,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.41295993486995897,
                                0.22696787870187651,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.93466336258571636,
                                0.36824160092919994,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.51500823318054745,
                                -0.35099860346605932,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77935600265533256,
                                0.20543286400546124,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.71483937021946531,
                                0.68434361996833926,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11218241321168124,
                                0,
                                -0.37187647122510348,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.58791869556561938,
                                0,
                                0,
                                0,
                                0.35121505834653255,
                                0.0082037781021452871,
                                0,
                                0,
                                0,
                                0,
                                0.51771812159514274,
                                0,
                                0,
                                0,
                                0,
                                0.35299876053759022,
                                0,
                                0,
                                0,
                                -0.20558045455722684,
                                0,
                                0,
                                0,
                                -1.1318413301230466,
                                -0.85530509380133557,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44648016968509452,
                                0.6380685957812342,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.36111143626337716,
                                0,
                                -0.49478343153470561,
                                0.27483824220527758,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.042708273404992766,
                                0.51777133957549548,
                                0.060993730075493829,
                                0,
                                0,
                                0,
                                0,
                                -0.59859860381340835,
                                -0.3566450899039586,
                                0.13485409963075809,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.44228610889114406,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.16446874853048227,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3841425574917981,
                                0,
                                0,
                                0,
                                -0.4772868490376978,
                                0.12193643196783523,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.015656330070750277,
                                1.0859568836307965,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.23068502493225479,
                                0,
                                0.59440557439156283,
                                -1.0690515632089694,
                                0,
                                0,
                                0,
                                0,
                                -0.025711381685926848,
                                0,
                                0,
                                0,
                                -0.36517388054948707,
                                -0.47541699026493378,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                1.5341188092326736,
                                -0.39494362588197662,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.55682457404231644,
                                0,
                                0.16446994259066539,
                                0.046657203354787666,
                                0,
                                0,
                                0,
                                0.29899947203990607,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21787749351117341,
                                0,
                                0,
                                0,
                                -0.36635577538580288,
                                -0.53870222030168891,
                                0,
                                0,
                                0,
                                0,
                                0.32621576749004355,
                                0,
                                0,
                                0,
                                0,
                                0.57645064859493922,
                                0,
                                0.55993806181724359,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.063621634759794196,
                                -0.40148741826082934,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.54949806985143201,
                                0.85525703228898253,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50081901993306033,
                                1.2628705015978277,
                                0,
                                0,
                                0,
                                -0.36228102462146372,
                                0,
                                0,
                                -0.036278309366069073,
                                0,
                                0,
                                0,
                                0.44105271732654622,
                                -0.065843808634544754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.42789286758414191,
                                0,
                                -0.48446187728692119,
                                0,
                                -0.73038042194142616,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.32734078078651552,
                                0,
                                0,
                                0,
                                0,
                                0.15797735633635057,
                                0.22766363510628229,
                                0.071893845448263077,
                                0,
                                -0.50107555119870462,
                                0,
                                0,
                                0.44069224602190177,
                                0,
                                0,
                                0,
                                0.61498347500522432,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.082144830977632755,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.04356684089454145,
                                0,
                                0.67820883194964754,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.92542021467300994,
                                0,
                                0,
                                0,
                                0,
                                0.27842998693720733,
                                0.024193145058197203,
                                0.49198187569133789,
                                0,
                                -0.33857973334122848,
                                0,
                                0,
                                0.49274304962320692,
                                0,
                                -0.40992370676804746,
                                0,
                                0,
                                0,
                                0.53580023857756875,
                                0,
                                0,
                                0.19050620247124758,
                                0,
                                0,
                                0,
                                0.8652125540391814,
                                0.16964924942748386,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.28282997720482317,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.11925913860320361,
                                0.058249232683220943,
                                0,
                                0,
                                -0.084225123504281282,
                                -0.30627723260629203,
                                0,
                                0,
                                -0.35785545256599216,
                                0,
                                0,
                                0,
                                0.71926899089278806,
                                0,
                                -0.27905551422963715,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.3977490212383315,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.18112547696041481,
                                0.027060868047245501,
                                0,
                                0,
                                0.24750088170372242,
                                -0.85224773247781582,
                                0,
                                0,
                                0.25997654865112324,
                                0,
                                0,
                                0,
                                -0.032062761581317802,
                                0,
                                0.28512731240530542,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.17019099932267212,
                                0,
                                0,
                                -0.27898705505239413,
                                0,
                                0,
                                0,
                                0.78772738419072852,
                                0,
                                0,
                                0.70885452890770684,
                                0,
                                0,
                                0,
                                -0.14849640744398412,
                                -0.14368854707203221,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.81892497315290536,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.24924150302170495,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.29049749601983132,
                                0.13279160664572282,
                                0,
                                0,
                                -0.86110214991268141,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.30180943457109732,
                                0,
                                -0.057187584332341834,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.14083965012950428,
                                0.24784285804003148,
                                0,
                                0,
                                -0.5429366282613437,
                                -0.19277279532248037,
                                0,
                                0,
                                0.15918531755523396,
                                0,
                                0,
                                0,
                                0.043992023052048718,
                                0,
                                -0.50728328363243202,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.54971354765498792,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31708818435937741,
                                0.66558943524968095,
                                0,
                                0,
                                0.0080493795592567127,
                                0.20049808812347511,
                                0,
                                0,
                                0.5613249662369495,
                                0,
                                0,
                                0,
                                0.094224848871336919,
                                0,
                                0.0076923370442247355,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.30357585420498306,
                                0,
                                0,
                                0.75639777908390582,
                                0,
                                0,
                                0,
                                0.46141907963741846,
                                0,
                                0,
                                -0.93237305651871483,
                                0,
                                0,
                                0,
                                -0.30554363333427698,
                                -0.5460252606839856,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.69428347943283319,
                                0.32248645841829976,
                                0,
                                0,
                                0,
                                -0.26665100408828663,
                                0,
                                0,
                                0.56464045605499713,
                                0,
                                0,
                                0,
                                -0.25276361890101667,
                                -0.85599281412377703,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.77921846050994903,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.42272822187962217,
                                -0.67853493466220383,
                                0,
                                0,
                                -0.30255718829752248,
                                0.03870672645595144,
                                0,
                                0,
                                0.46674876443338909,
                                0,
                                0,
                                0,
                                0.053853588459006396,
                                0,
                                -0.15415603641936967,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.15275283418475874,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.39679728886637972,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.34827568910228485,
                                -0.69763642024016681,
                                0,
                                0,
                                -0.049326374817565764,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.25160638862714202,
                                0,
                                0.41087773732884486,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.50912443087749204,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.15775744558038488,
                                -0.44398061667838618,
                                0,
                                0,
                                -0.3794918057359033,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58400046096194869,
                                0,
                                0.18361793277628319,
                                0,
                                0,
                                0,
                                0,
                                -0.83939315404146631,
                                0,
                                0.85428271985516979,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.16699226953903024,
                                0,
                                0,
                                0,
                                0,
                                0.8440962294264478,
                                0.92215043369673055,
                                -0.23909370251845796,
                                0,
                                0.083024305685821809,
                                0,
                                0,
                                0.01343875463842539,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.48782543924051436,
                                0.15677610145812315,
                                0,
                                0,
                                -0.57711498995729782,
                                -0.019644877122398485,
                                0,
                                0,
                                -0.4072045643785786,
                                0,
                                0,
                                0,
                                -0.18171069193303885,
                                0,
                                0.4521400400563701,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.027111130096651129,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.036714712056869589,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.500414617973857,
                                -0.25055755125794749,
                                0,
                                0,
                                -0.1814602647541711,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.048298595768670925,
                                0,
                                -0.80634829416722842,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.44550589314208339,
                                -0.076337030419225529,
                                0,
                                0,
                                -0.28372447152883118,
                                0.1040395011842615,
                                0,
                                0,
                                0.27152870700028925,
                                0,
                                0,
                                0,
                                0.51540326925969748,
                                0,
                                0.59485597854945271,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.10559999766384495,
                                0,
                                0,
                                0,
                                0,
                                0.010950736694443521,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.061506163299453902,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.89937008920764228,
                                0,
                                0.027540816530471496,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.74503195070588679,
                                0,
                                0,
                                0,
                                0,
                                0.91533244545604264,
                                -0.35700603606783393,
                                -0.11635858582615016,
                                0,
                                -0.047704340664710965,
                                0,
                                0,
                                0.012449561419226648,
                                0,
                                0,
                                -0.019610925496949733,
                                0,
                                -0.33188925879454784,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.62061437445552647,
                                0,
                                0,
                                0,
                                0,
                                0.32566433443032061,
                                0.12888178129087891,
                                -0.23580374253566883,
                                0,
                                0.99113185208412491,
                                0,
                                0,
                                -0.38240984514589249,
                                0,
                                0,
                                0.27520843856407923,
                                0,
                                -0.19758089058983705,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.21647879662128905,
                                0,
                                0,
                                0,
                                0,
                                -0.13928098127398914,
                                1.0237224498481163,
                                0.90440604012718617,
                                0,
                                -0.55882161533713459,
                                0,
                                0,
                                -0.2362706830727474,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.1587473432796293,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.64216286472784634,
                                0.47609975352682432,
                                0,
                                0,
                                -0.2599557081329647,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.40240428608938561,
                                0,
                                0.32595855749445252,
                                0,
                                0,
                                0,
                                0,
                                0.36775559628292753,
                                0,
                                -0.0083988871386862785,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.18031543752633725,
                                0,
                                0,
                                0,
                                0,
                                0.20933435294449959,
                                0.31783614662841875,
                                -0.82488288828828349,
                                0,
                                -0.51485765224937985,
                                0,
                                0,
                                -0.82361331342170008,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.7033307966552319,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.3265576562157041,
                                -0.095398975739428057,
                                0,
                                0,
                                0.10747635864157652,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.58334105648906642,
                                0,
                                -0.1942857874844664,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.46630653671005196,
                                -0.024972223694145576,
                                0,
                                0,
                                0.36290815331052306,
                                0.29966460524906857,
                                0,
                                0,
                                -0.08079716021045133,
                                0,
                                0,
                                0,
                                0.41140121937900498,
                                0,
                                0.037237067469425969,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0.61908614496577441,
                                0,
                                0,
                                0,
                                -0.33924420508737335,
                                0,
                                0.24949313506407769,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.41213750454265941,
                                0,
                                0,
                                0,
                                0,
                                0.62000977139050928,
                                -0.6253847579888907,
                                1.0978863658458253,
                                0,
                                -0.38833781123848682,
                                0,
                                0,
                                -0.56950016504111789,
                                0,
                                0.24081339351655545,
                                0,
                                0,
                                0,
                                0.34105592685415975,
                                0,
                                0,
                                0.14716822139803099,
                                0,
                                0,
                                0,
                                -0.20784786370897587,
                                1.0987645578817218,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                0,
                                -0.31902210408424125};

const double rot_23_2[32]
    = {-1.2107125975322155,  -0.51761149145075969, 2.5080932042014417,    -1.4056037240749819,   -0.98943637273985763,
       0.14496780435460016,  -0.14496780435460044, -0.98943637273985763,  -0.38956521025079993,  -0.92099888542942887,
       0.92099888542942876,  -0.38956521025079982, -0.96236647399933539,  -0.2717549810437449,   0.27175498104374513,
       -0.96236647399933561, 0.99968191963599129,  -0.025220221111229235, -0.025220221111229124, -0.9996819196359914,
       0.59673718615877169,  -0.80243674557893441, -0.8024367455789343,   -0.5967371861587718,   -0.97240013782221613,
       -0.23331946331871928, 0.23331946331871928,  -0.97240013782221613,  -0.30230138900114234,  0.95321239511872713,
       0.95321239511872691,  0.30230138900114234};

const int shuffle_22_100[100]
    = {32, 42, 33, 58, 47, 96, 72, 5,  40, 73, 91, 53, 74, 4,  29, 11, 62, 35, 81, 100, 34, 15, 18, 93, 94,
       67, 7,  69, 71, 1,  23, 41, 98, 19, 6,  45, 99, 3,  22, 9,  64, 77, 10, 26, 13,  8,  43, 17, 54, 49,
       44, 28, 59, 70, 37, 48, 20, 89, 88, 79, 95, 65, 75, 90, 55, 31, 39, 16, 38, 78,  68, 46, 36, 83, 57,
       63, 50, 86, 60, 85, 66, 21, 76, 14, 25, 80, 12, 27, 87, 2,  24, 56, 30, 82, 97,  52, 84, 92, 61, 51};

const int shuffle_22_50[50]
    = {7,  23, 19, 33, 4,  26, 8, 11, 47, 22, 35, 50, 29, 41, 44, 30, 38, 10, 49, 18, 20, 48, 32, 45, 25,
       21, 2,  40, 28, 31, 36, 3, 24, 46, 42, 12, 14, 5,  1,  27, 39, 43, 34, 9,  37, 13, 15, 6,  16, 17};

const int shuffle_22_30[30]
    = {12, 10, 4, 11, 2, 15, 26, 20, 6, 5, 27, 30, 17, 7, 29, 13, 9, 25, 1, 3, 21, 19, 16, 24, 23, 28, 8, 22, 18, 14};

const int shuffle_22_20[20] = {11, 1, 5, 14, 8, 18, 4, 19, 13, 15, 20, 7, 10, 12, 16, 17, 3, 6, 9, 2};

const int shuffle_22_10[10] = {3, 4, 6, 5, 1, 10, 7, 8, 2, 9};

const int shuffle_21_100[100]
    = {9,  56, 18, 62, 2,  15, 63, 27, 24, 43, 81, 90, 47, 14, 61, 87, 45, 29, 59, 53, 52, 55,  35, 57, 32,
       91, 6,  30, 78, 48, 98, 33, 21, 88, 58, 50, 60, 20, 10, 16, 39, 49, 22, 3,  54, 26, 83,  5,  19, 96,
       41, 68, 80, 34, 82, 37, 95, 93, 42, 77, 17, 97, 4,  79, 40, 7,  64, 70, 11, 66, 38, 100, 84, 44, 1,
       65, 31, 92, 72, 51, 75, 89, 74, 46, 23, 8,  13, 86, 25, 94, 67, 85, 76, 36, 73, 28, 71,  69, 12, 99};

const int shuffle_21_50[50]
    = {41, 14, 22, 48, 27, 43, 39, 30, 15, 36, 5,  32, 35, 38, 47, 50, 40, 29, 49, 28, 1,  6, 45, 19, 42,
       13, 26, 33, 2,  31, 17, 4,  20, 11, 7,  12, 9,  10, 3,  34, 16, 25, 37, 23, 24, 18, 8, 21, 44, 46};

const int shuffle_21_30[30]
    = {29, 18, 12, 21, 26, 19, 9, 3, 20, 6, 2, 27, 5, 17, 23, 10, 25, 13, 22, 24, 16, 1, 8, 14, 7, 4, 28, 15, 30, 11};

const int shuffle_21_20[20] = {2, 16, 3, 1, 12, 8, 9, 14, 17, 6, 15, 7, 19, 18, 4, 13, 11, 10, 20, 5};

const int shuffle_21_10[10] = {5, 9, 4, 10, 6, 1, 3, 8, 7, 2};

const int shuffle_20_100[100]
    = {67, 22, 10, 32, 61,  73, 66, 92, 70, 51, 46, 5,  17, 65, 87, 23, 43, 77, 64, 93, 16, 48, 57, 29, 47,
       97, 40, 34, 20, 100, 36, 58, 38, 28, 60, 84, 6,  25, 41, 24, 69, 2,  35, 37, 99, 83, 1,  63, 94, 79,
       9,  82, 96, 95, 86,  27, 55, 12, 21, 26, 18, 39, 50, 85, 52, 19, 75, 68, 98, 72, 62, 54, 81, 49, 80,
       13, 45, 7,  59, 56,  30, 3,  42, 90, 74, 11, 33, 76, 4,  91, 8,  71, 14, 31, 88, 89, 78, 44, 53, 15};

const int shuffle_20_50[50]
    = {2,  32, 48, 18, 5,  40, 45, 30, 41, 43, 12, 15, 14, 27, 13, 46, 21, 34, 1,  39, 37, 44, 11, 17, 35,
       49, 26, 29, 22, 47, 24, 50, 3,  33, 6,  8,  16, 4,  10, 7,  23, 19, 28, 36, 9,  25, 20, 38, 31, 42};

const int shuffle_20_30[30]
    = {5, 24, 4, 12, 1, 23, 30, 15, 19, 20, 21, 2, 11, 22, 26, 6, 14, 16, 8, 10, 29, 13, 7, 3, 18, 9, 28, 27, 25, 17};

const int shuffle_20_20[20] = {5, 7, 13, 8, 17, 4, 18, 19, 3, 11, 12, 15, 2, 6, 16, 9, 14, 1, 10, 20};

const int shuffle_20_10[10] = {10, 9, 5, 1, 6, 7, 2, 8, 4, 3};

const int shuffle_30_100[1000] = {
    98, 71, 21, 96,  42, 5,  22, 95, 88, 66, 64, 1,   14, 20, 85,  44, 34, 26,  30, 49,  16,  65, 70, 74, 39, 99,  24,
    80, 45, 86, 40,  75, 35, 90, 81, 50, 46, 41, 52,  43, 8,  51,  67, 33, 47,  12, 56,  28,  3,  91, 19, 73, 15,  100,
    59, 93, 77, 58,  68, 37, 62, 82, 27, 29, 36, 89,  11, 18, 32,  38, 78, 92,  6,  10,  2,   17, 4,  54, 23, 97,  76,
    57, 9,  63, 72,  69, 48, 13, 84, 25, 60, 83, 61,  31, 87, 7,   79, 94, 53,  55, 84,  20,  9,  67, 11, 82, 88,  34,
    28, 1,  54, 96,  76, 33, 65, 80, 13, 62, 85, 73,  25, 35, 58,  3,  42, 23,  52, 83,  37,  57, 8,  90, 19, 38,  71,
    79, 16, 56, 98,  75, 6,  2,  53, 49, 51, 15, 36,  86, 77, 43,  89, 7,  17,  93, 10,  39,  29, 4,  18, 44, 30,  74,
    24, 94, 32, 14,  60, 81, 48, 99, 47, 31, 26, 95,  21, 40, 22,  27, 45, 100, 91, 59,  64,  5,  61, 87, 50, 41,  12,
    69, 97, 72, 46,  70, 63, 78, 68, 55, 92, 66, 80,  69, 91, 66,  48, 70, 56,  9,  68,  99,  55, 64, 61, 25, 71,  15,
    78, 22, 19, 74,  30, 17, 67, 28, 32, 83, 46, 10,  21, 42, 88,  63, 31, 41,  90, 93,  53,  33, 58, 20, 84, 26,  18,
    2,  39, 59, 82,  79, 1,  43, 57, 54, 7,  65, 60,  36, 50, 12,  37, 76, 5,   34, 100, 52,  14, 89, 3,  11, 29,  75,
    92, 24, 72, 81,  98, 87, 45, 95, 51, 16, 38, 73,  94, 96, 62,  97, 47, 6,   35, 4,   85,  49, 8,  13, 27, 23,  86,
    77, 40, 44, 36,  8,  72, 33, 19, 23, 39, 30, 61,  57, 1,  4,   35, 71, 77,  56, 24,  86,  15, 3,  64, 68, 89,  69,
    94, 45, 95, 97,  44, 82, 88, 92, 34, 67, 93, 76,  91, 32, 80,  98, 25, 11,  78, 50,  96,  41, 16, 58, 90, 55,  22,
    42, 27, 5,  52,  85, 47, 20, 87, 75, 70, 54, 49,  21, 46, 99,  40, 59, 37,  66, 13,  14,  6,  62, 84, 74, 65,  7,
    43, 83, 81, 26,  18, 9,  60, 48, 2,  28, 31, 73,  79, 51, 10,  53, 63, 29,  12, 17,  100, 38, 52, 23, 69, 43,  72,
    47, 51, 17, 32,  25, 81, 96, 54, 85, 97, 56, 73,  34, 41, 7,   74, 29, 79,  98, 42,  30,  5,  91, 66, 37, 95,  67,
    57, 45, 83, 6,   40, 26, 15, 11, 87, 9,  94, 65,  3,  2,  82,  39, 78, 18,  76, 20,  99,  92, 48, 89, 55, 70,  49,
    14, 88, 46, 100, 33, 16, 68, 27, 10, 84, 64, 93,  35, 77, 75,  31, 90, 24,  12, 38,  19,  1,  53, 59, 58, 60,  80,
    4,  61, 50, 63,  86, 22, 8,  28, 71, 44, 36, 13,  21, 62, 55,  2,  19, 28,  8,  68,  7,   51, 47, 30, 59, 31,  95,
    3,  58, 36, 37,  6,  69, 56, 78, 83, 26, 22, 35,  73, 15, 39,  5,  12, 72,  86, 92,  93,  63, 18, 10, 80, 76,  62,
    74, 23, 84, 100, 38, 25, 46, 66, 89, 98, 16, 71,  13, 14, 17,  52, 48, 43,  85, 54,  65,  49, 34, 27, 99, 29,  82,
    50, 32, 60, 4,   11, 96, 91, 87, 94, 67, 79, 70,  21, 44, 81,  1,  57, 40,  9,  42,  88,  61, 75, 97, 33, 77,  90,
    41, 53, 64, 45,  20, 24, 77, 84, 29, 66, 89, 69,  56, 88, 73,  10, 54, 2,   48, 92,  4,   96, 17, 37, 20, 8,   47,
    26, 9,  52, 23,  33, 64, 62, 44, 41, 40, 28, 16,  15, 1,  78,  55, 76, 81,  24, 18,  6,   45, 75, 99, 63, 3,   68,
    27, 61, 49, 12,  39, 82, 94, 74, 98, 14, 72, 42,  65, 19, 43,  30, 35, 38,  11, 53,  86,  31, 51, 13, 67, 57,  34,
    90, 32, 50, 22,  83, 25, 58, 60, 91, 95, 5,  100, 71, 7,  21,  36, 46, 80,  93, 70,  97,  79, 59, 87, 85, 40,  31,
    29, 22, 47, 99,  42, 93, 12, 87, 75, 82, 64, 9,   46, 66, 6,   3,  28, 89,  52, 84,  39,  85, 55, 86, 8,  21,  72,
    38, 1,  41, 32,  43, 16, 20, 61, 62, 15, 90, 4,   19, 51, 76,  10, 88, 44,  5,  68,  24,  77, 97, 71, 50, 7,   27,
    56, 2,  25, 60,  14, 13, 69, 59, 58, 98, 65, 33,  53, 83, 100, 81, 35, 74,  91, 67,  49,  26, 63, 34, 95, 45,  96,
    70, 73, 94, 92,  80, 11, 78, 48, 30, 54, 79, 57,  23, 37, 17,  36, 18, 99,  80, 7,   50,  69, 56, 13, 26, 100, 87,
    95, 33, 19, 75,  35, 43, 91, 89, 39, 82, 27, 28,  30, 3,  92,  76, 22, 53,  86, 38,  20,  81, 85, 77, 64, 83,  55,
    32, 1,  63, 16,  18, 14, 54, 2,  51, 4,  46, 15,  61, 88, 6,   21, 23, 34,  42, 11,  41,  73, 58, 36, 71, 74,  12,
    45, 97, 59, 62,  84, 24, 78, 29, 60, 67, 40, 25,  96, 48, 57,  68, 72, 44,  17, 79,  93,  37, 70, 90, 52, 65,  49,
    9,  10, 8,  47,  98, 66, 94, 5,  31, 98, 3,  94,  42, 70, 99,  8,  73, 47,  13, 52,  50,  89, 69, 30, 68, 66,  92,
    90, 36, 49, 85,  95, 88, 53, 59, 96, 16, 43, 28,  86, 6,  31,  56, 64, 46,  27, 48,  45,  10, 14, 62, 67, 87,  54,
    33, 17, 4,  21,  41, 57, 58, 82, 60, 12, 65, 7,   40, 32, 78,  5,  80, 25,  22, 2,   15,  18, 19, 93, 29, 11,  84,
    71, 63, 37, 75,  23, 34, 39, 20, 72, 77, 1,  38,  24, 97, 81,  44, 74, 76,  61, 100, 83,  55, 9,  91, 26, 51,  35,
    79};

const int shuffle_30_50[500]
    = {23, 30, 1,  27, 38, 32, 24, 40, 48, 15, 39, 11, 2,  5,  16, 13, 3,  8,  20, 37, 34, 36, 21, 45, 49, 46, 22, 43,
       19, 29, 26, 41, 10, 33, 28, 31, 14, 17, 9,  6,  12, 18, 25, 50, 4,  35, 44, 42, 7,  47, 13, 38, 5,  19, 3,  43,
       32, 22, 12, 17, 45, 47, 18, 20, 48, 23, 33, 30, 15, 7,  25, 4,  6,  42, 2,  27, 14, 26, 31, 9,  1,  40, 10, 29,
       46, 8,  50, 39, 36, 28, 21, 11, 37, 24, 34, 49, 35, 41, 16, 44, 26, 32, 23, 5,  25, 4,  43, 28, 35, 33, 30, 49,
       10, 21, 42, 22, 40, 11, 37, 47, 9,  19, 3,  12, 34, 44, 17, 2,  45, 20, 46, 13, 36, 1,  24, 14, 16, 48, 39, 15,
       31, 18, 27, 50, 29, 7,  41, 38, 6,  8,  2,  24, 8,  16, 29, 40, 20, 26, 4,  6,  15, 22, 9,  12, 45, 32, 48, 33,
       11, 3,  28, 21, 37, 41, 19, 30, 5,  49, 27, 13, 7,  50, 36, 39, 35, 42, 31, 25, 44, 18, 10, 14, 46, 38, 43, 17,
       34, 1,  47, 23, 39, 37, 43, 29, 33, 5,  12, 3,  19, 17, 15, 24, 9,  46, 47, 32, 1,  45, 36, 4,  50, 16, 40, 21,
       30, 23, 27, 8,  31, 7,  20, 26, 22, 42, 49, 48, 38, 11, 2,  10, 28, 34, 18, 35, 44, 13, 14, 6,  25, 41, 4,  21,
       46, 40, 8,  29, 18, 44, 5,  35, 9,  34, 13, 11, 12, 48, 22, 32, 3,  14, 42, 26, 1,  27, 36, 41, 19, 15, 38, 25,
       28, 10, 6,  45, 50, 23, 37, 47, 43, 39, 33, 7,  16, 24, 2,  17, 49, 20, 30, 31, 42, 9,  4,  39, 28, 29, 18, 20,
       48, 25, 41, 11, 6,  12, 30, 38, 49, 3,  10, 24, 21, 7,  45, 23, 36, 32, 1,  35, 19, 16, 26, 34, 44, 31, 2,  43,
       17, 46, 40, 33, 22, 5,  50, 37, 14, 8,  15, 47, 13, 27, 25, 1,  9,  17, 38, 30, 35, 40, 42, 7,  34, 39, 36, 31,
       3,  10, 21, 33, 12, 4,  48, 11, 49, 32, 14, 26, 37, 15, 6,  29, 13, 20, 47, 18, 46, 22, 2,  19, 8,  50, 24, 28,
       16, 44, 5,  41, 23, 45, 27, 43, 3,  35, 38, 6,  25, 19, 36, 16, 40, 8,  43, 47, 10, 4,  26, 2,  41, 46, 33, 13,
       28, 49, 45, 30, 37, 42, 27, 1,  15, 24, 23, 44, 5,  18, 9,  14, 34, 17, 12, 7,  11, 39, 21, 32, 48, 22, 29, 50,
       20, 31, 3,  41, 14, 24, 49, 35, 20, 32, 34, 8,  45, 21, 17, 40, 26, 10, 4,  30, 36, 29, 25, 19, 13, 16, 42, 50,
       11, 44, 6,  2,  18, 27, 9,  7,  37, 15, 23, 39, 31, 22, 43, 38, 12, 46, 33, 28, 1,  47, 5,  48};

const int shuffle_30_30[300]
    = {29, 18, 23, 24, 13, 8,  1,  15, 20, 10, 16, 6,  11, 21, 28, 26, 4,  14, 27, 9,  30, 19, 3,  25, 22, 17, 7,  2,
       5,  12, 18, 5,  14, 17, 7,  20, 1,  9,  16, 10, 19, 12, 3,  28, 21, 22, 23, 24, 27, 15, 4,  13, 26, 6,  11, 29,
       25, 8,  30, 2,  26, 25, 2,  11, 4,  13, 28, 18, 22, 20, 24, 29, 17, 6,  15, 5,  30, 1,  10, 16, 12, 27, 14, 8,
       23, 3,  21, 19, 9,  7,  26, 28, 10, 16, 4,  7,  3,  12, 6,  29, 11, 27, 18, 14, 13, 17, 1,  21, 25, 2,  23, 20,
       30, 8,  24, 15, 5,  9,  19, 22, 26, 11, 29, 24, 22, 12, 10, 3,  9,  18, 14, 23, 17, 28, 4,  15, 20, 7,  21, 2,
       19, 30, 16, 13, 6,  1,  25, 27, 8,  5,  9,  19, 21, 16, 27, 6,  4,  1,  5,  18, 17, 11, 10, 2,  23, 20, 13, 8,
       22, 25, 28, 15, 30, 26, 3,  7,  24, 12, 14, 29, 15, 5,  12, 6,  29, 4,  8,  3,  11, 2,  25, 22, 13, 10, 7,  18,
       1,  23, 20, 16, 26, 28, 14, 21, 19, 17, 27, 30, 24, 9,  27, 3,  13, 10, 7,  19, 12, 30, 15, 22, 1,  18, 17, 26,
       20, 28, 29, 6,  8,  24, 2,  14, 11, 21, 5,  25, 23, 16, 9,  4,  5,  19, 29, 2,  26, 17, 13, 4,  6,  14, 16, 9,
       23, 25, 22, 11, 20, 21, 3,  15, 8,  18, 30, 12, 1,  28, 27, 10, 7,  24, 14, 19, 11, 12, 28, 24, 13, 25, 2,  20,
       9,  6,  21, 10, 5,  1,  30, 16, 22, 29, 15, 26, 7,  23, 27, 8,  3,  18, 4,  17};

const int shuffle_30_20[200] = {
    16, 20, 10, 8,  9,  12, 17, 11, 15, 7,  13, 2,  18, 4,  6,  5,  19, 3,  1,  14, 10, 12, 5,  9,  6,  14, 3,  19, 13,
    2,  18, 15, 11, 17, 8,  7,  4,  20, 16, 1,  10, 20, 4,  18, 9,  5,  13, 11, 7,  8,  2,  1,  17, 3,  12, 15, 16, 14,
    19, 6,  12, 16, 19, 4,  14, 6,  2,  3,  20, 13, 5,  17, 15, 9,  18, 11, 7,  8,  10, 1,  15, 19, 4,  9,  14, 3,  1,
    7,  5,  18, 17, 16, 20, 12, 13, 6,  2,  8,  11, 10, 15, 18, 19, 20, 17, 11, 12, 2,  10, 14, 3,  7,  6,  13, 9,  8,
    1,  5,  4,  16, 20, 15, 5,  19, 10, 2,  6,  18, 17, 14, 13, 1,  3,  4,  16, 11, 9,  7,  8,  12, 19, 15, 8,  11, 7,
    5,  4,  13, 10, 2,  1,  3,  9,  6,  14, 20, 18, 12, 17, 16, 3,  1,  16, 14, 15, 6,  10, 18, 17, 12, 19, 4,  7,  20,
    5,  11, 9,  2,  8,  13, 7,  17, 12, 14, 6,  4,  15, 20, 3,  5,  1,  18, 10, 9,  19, 8,  13, 16, 2,  11};

const int shuffle_30_10[100]
    = {6, 5, 8,  3, 4, 9, 1, 10, 2, 7, 3,  4, 2, 7, 8, 10, 5, 6, 1, 9, 1, 4,  2, 8, 7, 3,  5,  10, 9,  6, 3, 6, 4, 2,
       9, 5, 10, 8, 1, 7, 3, 9,  1, 8, 10, 4, 5, 7, 2, 6,  8, 4, 2, 6, 9, 3,  5, 7, 1, 10, 5,  7,  10, 1, 8, 6, 4, 9,
       3, 2, 10, 9, 6, 1, 7, 3,  4, 5, 2,  8, 7, 2, 5, 9,  1, 3, 6, 4, 8, 10, 9, 1, 4, 3,  10, 2,  5,  6, 7, 8};

const int shuffle_19_100[100]
    = {58, 20, 41, 9,  29, 26, 27, 47, 6,  5,  35, 54, 95, 91, 77, 56, 23, 2,  8,  17, 57,  30, 83, 88, 69,
       37, 28, 94, 44, 65, 86, 76, 34, 3,  31, 51, 32, 80, 79, 85, 52, 16, 46, 50, 55, 81,  18, 68, 7,  43,
       49, 39, 11, 93, 63, 14, 74, 98, 22, 42, 4,  92, 71, 64, 19, 1,  73, 82, 89, 84, 100, 67, 15, 66, 12,
       75, 96, 72, 48, 38, 61, 10, 59, 21, 13, 33, 78, 99, 60, 87, 40, 53, 62, 24, 36, 70,  45, 25, 90, 97};

const int shuffle_19_50[50]
    = {44, 13, 20, 8,  34, 42, 28, 40, 31, 49, 19, 23, 2, 18, 50, 7,  3,  32, 14, 4,  46, 16, 25, 41, 38,
       26, 45, 9,  43, 27, 15, 24, 35, 17, 29, 1,  30, 5, 33, 10, 36, 39, 6,  21, 22, 12, 47, 11, 48, 37};

const int shuffle_19_30[30]
    = {22, 7, 15, 3, 9, 28, 29, 11, 24, 12, 23, 16, 13, 4, 10, 14, 21, 19, 8, 1, 27, 18, 17, 30, 25, 2, 6, 5, 26, 20};

const int shuffle_19_20[20] = {18, 11, 8, 6, 12, 15, 14, 19, 4, 9, 2, 13, 16, 10, 3, 1, 20, 5, 17, 7};

const int shuffle_19_10[10] = {9, 8, 1, 5, 10, 2, 6, 3, 7, 4};

const int shuffle_29_100[1000] = {
    71, 66,  54, 24,  52, 85, 44, 81, 78, 98,  32, 36,  40, 6,   67, 58, 39,  45,  49,  35, 29, 14, 16, 96, 51, 84, 33,
    1,  63,  37, 70,  92, 12, 62, 60, 53, 47,  99, 21,  56, 64,  7,  69, 91,  42,  46,  10, 59, 94, 26, 11, 23, 74, 80,
    65, 50,  34, 68,  57, 72, 15, 75, 77, 95,  89, 20,  97, 25,  27, 2,  31,  30,  61,  43, 22, 41, 19, 90, 18, 76, 86,
    4,  17,  8,  88,  9,  73, 48, 87, 38, 5,   28, 79,  55, 93,  83, 13, 100, 82,  3,   26, 65, 64, 70, 88, 74, 5,  57,
    94, 9,   54, 95,  21, 49, 13, 77, 33, 19,  98, 71,  85, 67,  68, 52, 20,  47,  55,  86, 24, 50, 83, 38, 53, 72, 23,
    62, 1,   48, 56,  2,  93, 87, 80, 82, 39,  15, 37,  63, 96,  11, 75, 8,   78,  46,  7,  90, 17, 12, 29, 32, 59, 66,
    99, 100, 79, 30,  97, 43, 25, 61, 3,  6,   18, 22,  73, 44,  91, 42, 89,  76,  58,  16, 51, 45, 41, 10, 27, 35, 40,
    14, 34,  31, 84,  36, 92, 28, 81, 60, 4,   69, 84,  69, 99,  22, 66, 38,  15,  92,  62, 37, 23, 41, 9,  72, 31, 81,
    36, 49,  5,  2,   25, 33, 8,  40, 4,  16,  11, 96,  39, 63,  46, 98, 79,  94,  64,  74, 47, 28, 19, 24, 97, 3,  93,
    56, 85,  52, 42,  80, 44, 59, 95, 88, 30,  51, 87,  21, 82,  91, 54, 61,  89,  100, 83, 43, 53, 32, 55, 12, 6,  70,
    67, 13,  65, 57,  90, 71, 34, 17, 7,  68,  75, 35,  50, 45,  14, 10, 18,  73,  27,  29, 1,  77, 60, 58, 78, 86, 48,
    20, 26,  76, 47,  36, 71, 46, 14, 99, 55,  54, 38,  23, 86,  32, 56, 58,  96,  33,  30, 35, 59, 43, 27, 74, 29, 95,
    53, 50,  60, 65,  81, 89, 21, 10, 37, 63,  44, 91,  6,  100, 73, 66, 17,  1,   61,  2,  75, 25, 28, 93, 22, 80, 4,
    34, 98,  31, 15,  64, 69, 87, 90, 5,  77,  85, 52,  8,  11,  24, 79, 48,  82,  18,  76, 19, 84, 57, 94, 9,  92, 40,
    7,  97,  70, 49,  62, 39, 26, 3,  20, 41,  88, 51,  68, 45,  83, 78, 16,  12,  72,  42, 13, 67, 22, 53, 50, 68, 21,
    67, 23,  17, 51,  38, 98, 59, 52, 43, 55,  86, 30,  8,  77,  69, 48, 95,  56,  96,  57, 97, 76, 75, 2,  61, 47, 73,
    62, 35,  63, 91,  3,  20, 85, 7,  24, 45,  94, 70,  6,  44,  32, 39, 9,   89,  83,  79, 87, 84, 18, 46, 10, 1,  4,
    27, 25,  58, 49,  66, 40, 65, 64, 19, 14,  12, 29,  60, 90,  42, 31, 13,  99,  37,  72, 34, 36, 80, 26, 88, 16, 100,
    74, 41,  92, 11,  82, 93, 71, 78, 54, 81,  5,  33,  15, 28,  27, 7,  33,  23,  67,  83, 39, 64, 25, 47, 28, 87, 77,
    14, 4,   55, 79,  88, 74, 94, 15, 19, 92,  44, 17,  76, 93,  85, 89, 56,  21,  54,  90, 22, 72, 91, 46, 43, 97, 65,
    86, 35,  29, 34,  73, 18, 49, 10, 13, 98,  66, 41,  71, 53,  69, 84, 63,  51,  48,  8,  95, 40, 38, 2,  52, 99, 24,
    78, 9,   82, 81,  57, 16, 96, 20, 1,  61,  62, 45,  59, 75,  36, 60, 37,  11,  32,  58, 12, 6,  26, 70, 42, 50, 3,
    5,  31,  30, 100, 80, 68, 71, 22, 12, 91,  57, 42,  16, 56,  17, 26, 19,  34,  37,  93, 87, 80, 8,  43, 40, 41, 97,
    27, 14,  82, 3,   94, 83, 95, 79, 66, 100, 58, 51,  31, 23,  50, 74, 99,  35,  24,  36, 10, 68, 39, 86, 44, 88, 25,
    81, 84,  45, 62,  11, 29, 63, 54, 90, 72,  52, 69,  9,  2,   77, 33, 6,   92,  5,   7,  60, 48, 1,  4,  28, 18, 67,
    49, 15,  47, 89,  59, 76, 98, 61, 53, 55,  65, 78,  64, 75,  46, 70, 20,  85,  30,  38, 32, 96, 21, 13, 73, 59, 68,
    21, 49,  25, 78,  6,  98, 74, 2,  89, 83,  61, 88,  38, 26,  8,  99, 85,  1,   60,  57, 29, 39, 27, 35, 3,  31, 11,
    4,  44,  51, 69,  19, 66, 63, 42, 91, 75,  41, 72,  58, 97,  12, 84, 47,  13,  95,  80, 5,  20, 28, 55, 94, 30, 62,
    96, 32,  56, 92,  86, 14, 17, 53, 73, 18,  24, 22,  36, 16,  70, 10, 90,  7,   76,  82, 34, 50, 23, 71, 48, 52, 81,
    37, 87,  40, 54,  46, 64, 43, 77, 33, 93,  9,  100, 67, 45,  15, 79, 65,  16,  56,  4,  36, 37, 98, 30, 51, 45, 89,
    2,  85,  63, 5,   57, 46, 53, 75, 54, 80,  97, 86,  44, 14,  95, 40, 82,  87,  88,  70, 38, 81, 49, 58, 50, 43, 25,
    33, 91,  90, 52,  72, 78, 17, 68, 28, 8,   9,  96,  60, 20,  74, 69, 35,  77,  42,  31, 32, 41, 3,  39, 64, 66, 10,
    67, 48,  76, 84,  27, 99, 62, 94, 73, 21,  6,  1,   29, 61,  19, 12, 65,  100, 23,  22, 24, 13, 79, 47, 55, 71, 92,
    15, 34,  7,  18,  11, 26, 83, 93, 59, 15,  69, 42,  56, 30,  34, 66, 95,  82,  57,  96, 58, 71, 86, 18, 10, 77, 37,
    64, 92,  24, 27,  48, 50, 59, 55, 14, 36,  31, 8,   19, 100, 89, 73, 12,  49,  5,   60, 76, 90, 13, 26, 72, 44, 47,
    81, 98,  2,  29,  46, 68, 97, 62, 23, 93,  88, 41,  67, 51,  99, 33, 83,  84,  32,  65, 91, 87, 9,  4,  52, 1,  17,
    3,  74,  16, 94,  70, 75, 38, 25, 61, 79,  80, 85,  78, 43,  45, 7,  40,  54,  11,  28, 22, 53, 39, 35, 6,  21, 20,
    63};

const int shuffle_29_50[500]
    = {38, 50, 46, 8,  48, 15, 49, 30, 19, 5,  23, 41, 6,  25, 13, 14, 3,  37, 7,  32, 16, 35, 29, 22, 44, 42, 47, 1,
       34, 2,  10, 11, 26, 18, 24, 20, 27, 28, 33, 40, 21, 45, 39, 43, 17, 4,  31, 36, 12, 9,  26, 29, 44, 16, 34, 3,
       1,  14, 40, 15, 49, 28, 12, 47, 45, 42, 7,  10, 37, 32, 23, 48, 21, 50, 22, 24, 36, 17, 19, 2,  35, 27, 30, 39,
       6,  43, 46, 11, 33, 13, 9,  4,  31, 25, 41, 8,  5,  18, 20, 38, 22, 14, 4,  5,  45, 29, 48, 50, 18, 16, 7,  24,
       10, 26, 20, 9,  3,  19, 28, 15, 37, 23, 21, 44, 46, 40, 43, 27, 32, 36, 2,  8,  35, 13, 42, 11, 1,  12, 33, 49,
       38, 39, 34, 30, 47, 17, 25, 6,  41, 31, 37, 48, 13, 46, 12, 43, 44, 25, 22, 47, 2,  23, 32, 39, 14, 1,  7,  40,
       49, 18, 50, 16, 6,  17, 29, 33, 27, 15, 9,  8,  5,  36, 21, 4,  35, 10, 42, 24, 28, 11, 41, 26, 30, 19, 38, 3,
       31, 45, 20, 34, 41, 18, 37, 11, 27, 1,  14, 17, 32, 13, 21, 44, 26, 5,  23, 30, 47, 19, 46, 34, 4,  16, 35, 31,
       12, 15, 45, 38, 10, 43, 25, 29, 42, 24, 3,  6,  36, 28, 50, 7,  22, 33, 8,  48, 40, 49, 39, 2,  20, 9,  10, 16,
       13, 19, 9,  41, 49, 14, 38, 4,  34, 36, 3,  2,  12, 43, 15, 31, 30, 32, 22, 25, 26, 50, 6,  24, 39, 33, 18, 46,
       7,  20, 45, 35, 37, 29, 11, 47, 44, 27, 42, 21, 23, 40, 8,  48, 1,  17, 5,  28, 33, 38, 2,  40, 21, 23, 15, 30,
       14, 19, 17, 34, 36, 50, 48, 18, 6,  47, 12, 29, 46, 3,  10, 24, 31, 44, 8,  49, 26, 39, 28, 16, 25, 37, 45, 41,
       5,  4,  42, 35, 1,  27, 43, 22, 13, 9,  7,  20, 32, 11, 19, 49, 48, 6,  30, 16, 39, 26, 12, 24, 42, 40, 9,  8,
       18, 43, 38, 35, 7,  3,  44, 20, 23, 22, 25, 13, 11, 46, 47, 32, 17, 31, 37, 45, 4,  27, 21, 33, 29, 10, 5,  1,
       2,  14, 41, 15, 34, 50, 36, 28, 29, 4,  13, 9,  7,  44, 1,  42, 27, 8,  26, 33, 5,  49, 36, 25, 43, 16, 41, 19,
       47, 14, 48, 28, 32, 50, 38, 18, 3,  2,  40, 24, 22, 30, 45, 23, 34, 6,  20, 10, 15, 21, 17, 12, 35, 39, 11, 46,
       37, 31, 38, 22, 27, 6,  20, 2,  3,  16, 29, 42, 32, 33, 34, 40, 30, 23, 14, 46, 8,  21, 37, 9,  41, 25, 44, 17,
       47, 45, 28, 5,  18, 12, 10, 7,  1,  43, 19, 26, 13, 50, 49, 48, 31, 36, 15, 24, 11, 35, 39, 4};

const int shuffle_29_30[300]
    = {2,  25, 20, 22, 17, 14, 10, 19, 3,  5,  1,  29, 30, 4,  13, 18, 9,  24, 16, 12, 7,  23, 26, 21, 11, 27, 6,  15,
       28, 8,  4,  11, 10, 28, 6,  9,  13, 24, 3,  27, 2,  16, 1,  25, 22, 5,  21, 19, 26, 20, 29, 14, 12, 18, 8,  30,
       17, 7,  15, 23, 29, 15, 3,  22, 8,  16, 25, 20, 18, 14, 9,  12, 2,  21, 30, 6,  4,  28, 10, 1,  26, 7,  27, 5,
       11, 19, 17, 24, 23, 13, 17, 29, 21, 28, 19, 10, 13, 27, 1,  6,  12, 14, 2,  20, 26, 3,  11, 9,  30, 18, 8,  5,
       16, 22, 24, 23, 7,  15, 25, 4,  9,  19, 5,  4,  23, 22, 30, 20, 2,  15, 29, 13, 21, 3,  28, 25, 17, 10, 7,  18,
       1,  8,  24, 16, 11, 12, 6,  26, 27, 14, 21, 11, 6,  7,  24, 1,  20, 17, 23, 30, 12, 8,  28, 27, 13, 3,  16, 4,
       15, 10, 9,  22, 14, 25, 5,  18, 2,  26, 19, 29, 12, 14, 9,  8,  5,  28, 24, 13, 16, 20, 18, 7,  30, 4,  25, 1,
       11, 23, 22, 3,  29, 19, 6,  21, 27, 26, 17, 15, 10, 2,  29, 15, 24, 14, 26, 12, 22, 30, 17, 13, 5,  6,  1,  11,
       7,  9,  25, 18, 16, 23, 2,  20, 10, 8,  19, 27, 3,  21, 28, 4,  12, 24, 10, 13, 11, 16, 18, 29, 3,  7,  21, 17,
       6,  22, 28, 1,  14, 2,  20, 19, 26, 4,  23, 15, 27, 25, 9,  8,  5,  30, 14, 16, 19, 2,  24, 1,  18, 25, 15, 21,
       5,  23, 11, 3,  10, 8,  7,  22, 17, 13, 6,  27, 28, 9,  20, 26, 30, 29, 12, 4};

const int shuffle_29_20[200] = {
    16, 2,  7,  4,  18, 5,  12, 10, 17, 9,  3,  8,  13, 11, 19, 15, 6,  20, 14, 1,  6,  12, 11, 13, 17, 15, 1,  10, 18,
    2,  9,  19, 5,  8,  3,  16, 7,  4,  20, 14, 11, 19, 20, 7,  4,  12, 9,  18, 5,  17, 14, 16, 8,  1,  3,  10, 2,  13,
    6,  15, 20, 1,  18, 9,  14, 7,  4,  12, 5,  10, 19, 16, 3,  6,  15, 2,  13, 17, 8,  11, 15, 10, 13, 3,  7,  2,  18,
    1,  11, 6,  12, 14, 16, 9,  20, 17, 4,  8,  19, 5,  16, 11, 13, 7,  6,  1,  5,  8,  20, 12, 15, 10, 19, 18, 4,  2,
    17, 9,  3,  14, 4,  12, 9,  16, 3,  15, 5,  2,  10, 7,  20, 14, 11, 8,  13, 19, 6,  1,  18, 17, 9,  5,  6,  14, 18,
    12, 2,  10, 4,  19, 7,  15, 16, 13, 17, 1,  20, 3,  8,  11, 19, 7,  5,  6,  17, 4,  10, 2,  3,  20, 14, 8,  16, 12,
    15, 18, 13, 11, 9,  1,  11, 17, 9,  2,  6,  7,  10, 12, 15, 8,  20, 5,  16, 19, 14, 18, 3,  13, 1,  4};

const int shuffle_29_10[100]
    = {1, 10, 4, 5, 2, 6, 3,  7, 8, 9, 3, 7,  9, 6, 10, 2, 4, 1, 5, 8, 2, 3,  10, 9,  1, 4, 6, 5, 8, 7, 4,  9, 5, 10,
       2, 7,  3, 6, 8, 1, 5,  2, 8, 4, 1, 10, 3, 7, 9,  6, 2, 3, 1, 9, 4, 8,  10, 6,  7, 5, 7, 2, 1, 8, 10, 6, 3, 9,
       5, 4,  2, 1, 6, 9, 10, 7, 3, 8, 4, 5,  8, 2, 1,  9, 6, 7, 5, 4, 3, 10, 5,  10, 4, 9, 7, 6, 2, 1, 3,  8};

const int shuffle_18_100[100]
    = {67, 19, 94, 81, 50, 77, 62, 30, 42, 69, 74, 53, 57, 85, 65, 49, 93, 9,  10, 52, 100, 17, 20, 37, 79,
       55, 66, 73, 41, 15, 35, 8,  12, 68, 61, 64, 1,  14, 23, 59, 51, 95, 91, 28, 87, 56,  76, 13, 70, 72,
       63, 5,  80, 83, 29, 7,  92, 25, 82, 6,  2,  18, 54, 3,  86, 33, 32, 44, 39, 45, 36,  11, 47, 46, 98,
       31, 60, 96, 43, 71, 99, 16, 27, 34, 21, 24, 75, 22, 26, 48, 40, 88, 38, 84, 78, 90,  97, 4,  89, 58};

const int shuffle_18_50[50]
    = {9,  21, 47, 10, 3,  32, 19, 31, 11, 14, 35, 15, 23, 37, 39, 36, 25, 17, 40, 2,  28, 42, 33, 49, 29,
       24, 5,  30, 38, 20, 6,  27, 4,  13, 7,  50, 12, 45, 41, 46, 48, 16, 18, 1,  22, 43, 8,  26, 34, 44};

const int shuffle_18_30[30]
    = {19, 28, 27, 6, 22, 26, 23, 17, 7, 18, 8, 10, 30, 21, 11, 4, 5, 25, 16, 13, 9, 20, 29, 24, 15, 2, 14, 12, 3, 1};

const int shuffle_18_20[20] = {5, 11, 12, 20, 14, 19, 1, 13, 18, 6, 17, 16, 4, 15, 3, 2, 8, 9, 10, 7};

const int shuffle_18_10[10] = {4, 7, 9, 3, 5, 2, 10, 8, 6, 1};

const int shuffle_17_100[100]
    = {26, 86, 18, 40, 23, 99, 44, 20, 85, 28, 52,  15, 62, 70, 91, 2,  84, 31, 5,  47, 4,  36, 93, 61, 6,
       38, 49, 51, 98, 25, 58, 76, 14, 89, 88, 90,  97, 56, 45, 94, 24, 79, 80, 48, 73, 72, 87, 66, 32, 8,
       81, 67, 71, 69, 95, 21, 55, 10, 11, 41, 78,  35, 9,  50, 92, 77, 7,  46, 22, 75, 17, 74, 1,  83, 16,
       39, 43, 68, 34, 19, 64, 65, 3,  37, 57, 100, 53, 42, 29, 60, 82, 33, 96, 63, 13, 12, 30, 27, 54, 59};

const int shuffle_17_50[50]
    = {29, 47, 34, 10, 15, 18, 25, 50, 20, 1,  27, 35, 39, 19, 2,  13, 36, 48, 7,  5,  42, 11, 16, 21, 14,
       9,  6,  24, 40, 44, 3,  43, 46, 31, 38, 37, 8,  23, 17, 32, 33, 26, 41, 12, 30, 22, 45, 4,  49, 28};

const int shuffle_17_30[30]
    = {2, 19, 21, 1, 20, 27, 4, 14, 10, 22, 8, 15, 13, 25, 28, 6, 11, 24, 16, 7, 17, 26, 9, 18, 30, 3, 12, 5, 23, 29};

const int shuffle_17_20[20] = {8, 7, 4, 15, 2, 17, 5, 11, 3, 1, 18, 6, 10, 9, 13, 19, 12, 16, 20, 14};

const int shuffle_17_10[10] = {7, 8, 5, 10, 3, 6, 9, 4, 2, 1};

const double shift_30[1000] = {39.480870151224316,
                               -68.958817048060027,
                               9.5726338523503802,
                               -63.335452420297784,
                               36.580645447391412,
                               -65.96295034395763,
                               69.038789194623334,
                               7.2554557438194518,
                               -7.8100138629786411,
                               71.788236098677402,
                               -32.417122664698816,
                               24.752551010018632,
                               58.999970375402981,
                               38.499494788139401,
                               -49.621007104508799,
                               58.451637412785814,
                               -9.2121954241979296,
                               -51.640127459925353,
                               29.067281327545373,
                               -48.240357293011357,
                               64.560751566969941,
                               -43.654146308527601,
                               13.289652365094568,
                               17.281533863757051,
                               7.9815325659621283,
                               -71.875978764066488,
                               -14.481199392197235,
                               64.036669043933088,
                               63.628781188565632,
                               -42.201764837048898,
                               72.350830765176752,
                               -35.526913264773832,
                               5.1497915318607195,
                               -32.847088181743288,
                               -54.631658826368302,
                               -50.495053709897824,
                               57.3724327287281,
                               54.632722350822959,
                               69.131972882471075,
                               -67.88790889695008,
                               32.919639393024127,
                               3.1454199530234792,
                               -36.466249182057346,
                               78.319428408674327,
                               57.906447014943396,
                               -15.923614442118348,
                               18.628879003207967,
                               -1.1592875087763428,
                               -48.766891097426971,
                               -14.928719225478826,
                               8.6237747165209377,
                               -69.087530216755454,
                               -57.22847326874966,
                               -57.88982020513717,
                               -52.894337314292336,
                               -13.05233842799259,
                               40.965493021057121,
                               -56.401473446442296,
                               -11.854072187012099,
                               22.198254416141758,
                               29.858484548901473,
                               70.824410740358502,
                               32.61197655554399,
                               -27.209754190727068,
                               -56.658308411757034,
                               27.147890322351138,
                               -6.0986457696344569,
                               74.122504498606759,
                               63.591252137301467,
                               16.205538213565184,
                               30.802263864781814,
                               -5.2664416662928399,
                               71.727558733886767,
                               32.088316500064877,
                               45.982385451360507,
                               -10.394266645336819,
                               -68.675862359870564,
                               -1.4783640657429267,
                               9.1932600531239483,
                               -62.542584230222872,
                               55.487000584227751,
                               48.516887612208585,
                               28.144722984610471,
                               0.73008444457056676,
                               -27.990828935862282,
                               -78.473603413193445,
                               79.346544855907567,
                               -20.91459943738505,
                               33.472711342504297,
                               -52.108703902517007,
                               -37.689304831690713,
                               53.442527341890255,
                               -34.331360813610466,
                               -21.481142099222104,
                               -75.82566046365362,
                               33.30178006189071,
                               -10.719248548681149,
                               -27.736984331896245,
                               -53.363525313786283,
                               78.814820049280058,
                               65.678831250621514,
                               65.767235804129584,
                               -69.213875124645767,
                               -13.329798011341957,
                               -14.278950310355693,
                               54.088268020685121,
                               -27.822198618302288,
                               -22.529890035784899,
                               38.618832498149082,
                               -49.874865676989927,
                               68.122670042803719,
                               -35.652286387099835,
                               36.687306314660525,
                               -62.901757829324545,
                               13.610540469230362,
                               79.667548617384469,
                               3.0977702709464108,
                               70.053385034399412,
                               9.8748102418753874,
                               13.858447049864255,
                               -5.3189661393602652,
                               6.2564039570143724,
                               61.649123200322592,
                               -47.673262054774284,
                               -69.113699489917295,
                               61.987290198710063,
                               66.261216097499727,
                               8.0581085131299588,
                               71.179393225791699,
                               50.157385888624717,
                               47.132815974430684,
                               73.821891505125464,
                               45.683596990168382,
                               -73.342546205248127,
                               -14.539962603762582,
                               31.118353339358535,
                               -12.605312180168708,
                               -57.945270443714413,
                               30.322744646700066,
                               71.203911472143417,
                               75.266888845241851,
                               34.756074953035373,
                               -54.09012822307362,
                               -77.547579540783929,
                               -4.4478962915557858,
                               26.090534423162971,
                               6.229367892636688,
                               31.051108725541077,
                               -68.798879011503701,
                               57.122089427513785,
                               64.219113445058809,
                               -39.746134832963904,
                               -74.09609388037066,
                               -1.5394525303585986,
                               53.44090339079942,
                               -42.82424181748641,
                               -54.274093292699547,
                               22.563369171970649,
                               -23.666090841662083,
                               63.789562971683331,
                               -63.203298569839973,
                               -39.867435160603705,
                               -17.295395388678983,
                               29.7121789686189,
                               50.73853693390992,
                               -30.121621231496633,
                               22.718046416920451,
                               -11.809374135319665,
                               -76.998225127873226,
                               -37.742384300009959,
                               63.851535307318052,
                               79.488138256695578,
                               -38.038031571514246,
                               51.471846811729066,
                               -67.806636224406063,
                               22.595265762167173,
                               -23.043238868265128,
                               75.544643736812631,
                               -75.55193522014234,
                               7.0863338646264378,
                               -66.521868890877101,
                               0.18701964344936606,
                               12.446330556489423,
                               74.106454326753862,
                               46.68544453081941,
                               -51.368230258306561,
                               -34.689533210668898,
                               -51.493421196205787,
                               52.170179980174112,
                               28.082803946137073,
                               -76.099864500632606,
                               73.766010409956024,
                               22.737141139944079,
                               -15.903829256343228,
                               -55.672850765870535,
                               -40.409793658771797,
                               19.541066161812157,
                               76.551554863084377,
                               9.1515742653135419,
                               19.024987628342174,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -26.145788673474808,
                               -44.858435256078842,
                               -52.161956424577667,
                               13.592027304813357,
                               -60.185527322334138,
                               -17.122311106220955,
                               -41.826098529357935,
                               -42.548009710845079,
                               -72.062174124872001,
                               31.816955891606909,
                               2.3591899213603416,
                               -67.43386424744655,
                               -30.351363561881055,
                               -9.6622560342152539,
                               34.609514378428642,
                               -58.778580148627796,
                               70.219964001855061,
                               -16.984064420274564,
                               -26.144591617211809,
                               -41.229341285180411,
                               25.075665751050636,
                               -5.6332760416897969,
                               -50.804819301346079,
                               -56.633817425091863,
                               -15.543598539242669,
                               38.524716782775236,
                               -73.853101287674036,
                               -42.958491792190713,
                               9.1436495126873947,
                               -74.092553230040835,
                               -1.1917437118912027,
                               -29.467280566498221,
                               -2.4215012325754817,
                               19.94917418650725,
                               -32.764670391858502,
                               -79.725602490693703,
                               -30.633938400700671,
                               -34.776067258725263,
                               -78.80613912626427,
                               -50.390361739711018,
                               -54.774868318113597,
                               28.170246821510016,
                               75.596148868443279,
                               20.033552637730207,
                               33.289277614991235,
                               -29.401777076388505,
                               -27.152231305882225,
                               56.403210311784747,
                               12.11876119319858,
                               -18.10288836436337,
                               -31.385466672096282,
                               -55.595403543182954,
                               24.016340170750027,
                               67.279932086702672,
                               -76.962492608684585,
                               -69.270590015923958,
                               -17.256726433109083,
                               -6.7010942862348593,
                               -47.546896045371554,
                               12.357886751072305,
                               -1.0975055831826932,
                               56.542185344853529,
                               -68.35000793754628,
                               76.262258317732943,
                               11.747543696201598,
                               6.2702459483197615,
                               46.886912612930843,
                               7.380533644330324,
                               12.121618913024966,
                               58.024562053878945,
                               -62.666358018081638,
                               42.691461250998856,
                               -30.343162018733118,
                               -58.383886860600597,
                               63.149276170782649,
                               47.153949235660441,
                               -61.46959851105396,
                               26.195698230939648,
                               72.348816693432525,
                               -75.613885671552438,
                               72.91465805479784,
                               66.610341944929218,
                               -69.770124982004873,
                               -33.607964447368786,
                               23.354016828575958,
                               64.828508225787147,
                               -20.887429717017998,
                               13.118455395370228,
                               77.395177538585529,
                               67.399903137704328,
                               21.175554121646744,
                               7.2715050434370792,
                               36.17290463995792,
                               36.185812270115697,
                               -1.0825711142976857,
                               -24.331506198385121,
                               66.970734347322235,
                               45.255259578279606,
                               -64.506258344298672,
                               -65.304481865186204,
                               4.1414145817852912,
                               -55.727990415222465,
                               -21.457195412734393,
                               -25.944530232699535,
                               62.598313912501155,
                               2.5539989483881893,
                               44.289942520001638,
                               -64.47860851397617,
                               9.5437200563498301,
                               32.965339203930981,
                               32.551963467506738,
                               59.985814772379818,
                               -54.700326643609287,
                               9.6813246140522118,
                               -64.199156956646462,
                               -2.5236281482073775,
                               -21.917955320234292,
                               37.139750732780563,
                               48.867612333569561,
                               52.09872015978776,
                               39.46606833893992,
                               -70.777615219475138,
                               69.912199279448828,
                               3.483138843923582,
                               -36.607492296666933,
                               12.259981125992645,
                               -60.144450140219369,
                               -25.897842023459297,
                               17.020103570097163,
                               -17.113700447906343,
                               11.544238762492649,
                               23.330949801440934,
                               65.680079543062121,
                               13.621419667741609,
                               36.117192295663308,
                               -27.374280996785238,
                               1.4171454824528933,
                               38.495310000642711,
                               55.707194849173739,
                               -24.803164770101063,
                               -21.306631576990789,
                               77.304357424083747,
                               5.528406333330393,
                               2.5788083540219446,
                               -25.52262434377765,
                               -39.311498122999872,
                               65.461390491624954,
                               45.033079940412669,
                               -27.854610522516332,
                               -43.443653527024537,
                               34.66740876453197,
                               -16.953759344329654,
                               1.4580832515138376,
                               -65.195837737954321,
                               -32.363239794911671,
                               77.316343235628651,
                               -37.342493209676505,
                               2.4162187385034706,
                               -70.221874438233215,
                               -7.6687863272318904,
                               -18.06048241972012,
                               -66.483640898249021,
                               75.324251838621123,
                               -76.37496747690372,
                               27.326866543113006,
                               46.216431435603688,
                               77.510359468012311,
                               52.95119464977499,
                               -50.253844431955578,
                               -52.638948480263416,
                               -5.4506316565392616,
                               61.263304115359922,
                               9.6217120833930974,
                               -22.205460353959513,
                               76.937021420189225,
                               -67.95116299681554,
                               36.421973738546065,
                               -73.007575059920271,
                               27.635154091489625,
                               -37.34496143221714,
                               42.23948218217906,
                               34.914331344443319,
                               -50.701863774858261,
                               -66.492404904250279,
                               68.510855812097972,
                               40.436526037349083,
                               42.581111637507533,
                               52.286368934095464,
                               -25.734267326349212,
                               -76.664983297320447,
                               37.513839543069508,
                               -46.108269492838602,
                               -52.896510301551274,
                               -74.79460621025018,
                               45.529298685570616,
                               48.220914094252194,
                               60.609869319525615,
                               -40.06211394341085,
                               -15.42630980930176,
                               -39.65060690613862,
                               25.233291047487299,
                               41.181604556272717,
                               -41.840247213014798,
                               65.299896579552069,
                               -46.146847288839055,
                               33.046248441405304,
                               -12.404854530106272,
                               67.574940823155259,
                               -24.574150958789382,
                               57.945890966651291,
                               -55.27920640591649,
                               65.891827182176712,
                               -15.917813477215274,
                               -64.736501437825524,
                               -30.585070064583675,
                               26.152586746277645,
                               -59.244495945992554,
                               29.027846457933634,
                               -71.114722943184972,
                               -4.0755431490730807,
                               53.932504187550002,
                               36.93398598422344,
                               -31.232773422106234,
                               40.648674777398448,
                               19.124924533448279,
                               67.96203292515149,
                               12.476914296734913,
                               -15.711832512877898,
                               -19.180274941405223,
                               -48.553353232015347,
                               26.184991771015813,
                               -66.316749222195838,
                               -40.560276867604919,
                               -60.899266074764626,
                               18.649346446346833,
                               14.608681165463345,
                               -71.084512694235883,
                               21.156745799263099,
                               -44.280638417741855,
                               -44.398588310123735,
                               2.8472449021728625,
                               -38.157274164612019,
                               -70.797935558595512,
                               54.84941822927879,
                               11.260986521851331,
                               65.3320875823633,
                               -51.260377288428998,
                               -38.805353193525399,
                               -15.662597260550021,
                               36.314796178984423,
                               49.993754727339599,
                               49.090373174469704,
                               -15.540067435086984,
                               24.131208264435049,
                               -22.795829273757285,
                               7.0452448614311187,
                               68.677261928944205,
                               -79.709490749418762,
                               45.091706456440775,
                               -27.700002469193308,
                               -73.571111353141902,
                               -21.290324151118767,
                               -38.634774176546301,
                               -41.119471186013755,
                               35.351444876062601,
                               -56.624106149557583,
                               -49.367166093048482,
                               -36.52989258746755,
                               -24.496231493908073,
                               -21.635312891945535,
                               32.629687066023877,
                               30.236531656185186,
                               53.998681650066978,
                               -11.132481799461072,
                               -60.688497507712285,
                               -42.905791090203472,
                               6.3247048482052364,
                               52.600144865730705,
                               58.593335439918434,
                               65.214234751071899,
                               -33.223868845651602,
                               -65.912862285652579,
                               -6.7215301836977766,
                               63.183185412863949,
                               -47.410071102587558,
                               -36.685451176230359,
                               -75.23179701273375,
                               24.870583417306939,
                               -53.972769243035735,
                               61.90019388354763,
                               51.906854160301364,
                               19.234772841294678,
                               55.959790185049719,
                               19.996052865867696,
                               62.007098499490645,
                               -61.504725461397449,
                               1.655617000137795,
                               -78.46488953801375,
                               73.681696923797787,
                               39.556038589049365,
                               59.697238793826884,
                               -14.440520881284032,
                               72.688879994476551,
                               40.300292188899235,
                               72.221324559772896,
                               -61.579807038054291,
                               5.8902960911857551,
                               49.782795833454813,
                               -43.79344921572352,
                               11.009411252543467,
                               -70.959233562771033,
                               -0.8269835267145087,
                               6.3098815612462982,
                               49.208444753936959,
                               -45.623223748524154,
                               -64.888798811959461,
                               -40.042617750914928,
                               -38.106311889202445,
                               -0.10063467846798169,
                               78.12882300626714,
                               -20.503468719435812,
                               17.853922591860606,
                               -13.410168278300237,
                               65.190382212052214,
                               -27.372838101755661,
                               -4.31374431854994,
                               -35.832911262736168,
                               -56.226078913313586,
                               -72.109047353857591,
                               66.31009745489537,
                               -77.667265332178388,
                               -49.109137832454721,
                               61.766090725228949,
                               -8.4900124729318129,
                               7.7906697006830026,
                               69.929541552688235,
                               68.524669114527612,
                               -29.556221365800205,
                               -30.632474851089952,
                               35.658268963469894,
                               -46.053280776890581,
                               61.784947996543963,
                               -23.084343647032206,
                               -45.431872224875534,
                               20.757875449121421,
                               38.289769404333541,
                               44.019237066145564,
                               -17.395238237700404,
                               56.800846935671089,
                               66.114913548334926,
                               -14.93040908789737,
                               37.534456606691002,
                               -38.857034962780702,
                               7.4578668166253195,
                               -7.0020770549168816,
                               -59.335215535057813,
                               -64.613038372890401,
                               -46.7745489193236,
                               31.571857395039508,
                               -45.384800644389941,
                               39.690288104292556,
                               8.6879790571005717,
                               -13.322604451026869,
                               -6.765297521558157,
                               72.53985355761499,
                               -14.301118546168407,
                               -28.93535966693349,
                               21.806747927443457,
                               24.218958895232571,
                               -73.581789897597446,
                               -39.796160086100322,
                               -62.494973502458414,
                               29.895812979099816,
                               -72.625391045428444,
                               10.268995173971222,
                               7.3728767065849929,
                               -32.370873312730453,
                               -53.910624120656678,
                               -53.44934816438024,
                               57.144166084742892,
                               0.42205963293902293,
                               28.73758088852534,
                               75.691698500927174,
                               -1.8620158670059688,
                               48.784245494414257,
                               -25.762969081403263,
                               -59.882247012845639,
                               44.610335204219204,
                               20.428227089774573,
                               -9.7574539189515495,
                               -15.826125629623153,
                               -66.352527592358953,
                               6.1224198667982925,
                               -58.00733281141823,
                               -47.455092527277387,
                               79.784618500894169,
                               -77.701357060428435,
                               51.038090485919675,
                               29.433897455303061,
                               10.906951401903193,
                               -36.321412181586865,
                               4.3345934865798128,
                               -15.688838935773029,
                               59.535868625545412,
                               4.5686821622086438,
                               -45.037115509848363,
                               -60.158543516893907,
                               -55.508521718617935,
                               66.508789231039103,
                               -5.2878617725884105,
                               -30.107429673952417,
                               -25.816148817726805,
                               -77.632025333327604,
                               73.851558630566117,
                               51.166214098433343,
                               -33.011852682457473,
                               17.093089964926154,
                               5.6687566523941992,
                               41.613756478330984,
                               28.950257124072913,
                               -79.873066817322211,
                               -58.105887547452227,
                               -70.914072693444865,
                               57.506129446301614,
                               73.804699845985269,
                               23.825093943432758,
                               -16.559156705943508,
                               -64.273377586535531,
                               -50.717625490738016,
                               23.817794158226672,
                               -56.981486454331218,
                               45.686508373893432,
                               -73.140093813846818,
                               63.907311620259748,
                               48.027906194174854,
                               50.469769208268104,
                               28.152552287018132,
                               -6.3954489498677241,
                               12.063985933964053,
                               -1.8006070539638994,
                               -74.9762282479943,
                               -49.959902157560876,
                               51.534093039390243,
                               39.720277562188251,
                               -36.293570087735091,
                               -76.821367087532394,
                               -34.97976022425695,
                               -69.280416895771793,
                               66.216581216029027,
                               9.782464239783538,
                               -61.469912418548454,
                               10.412501316581039,
                               51.961856654639149,
                               44.715663904631604,
                               37.298520012670885,
                               21.832265717568959,
                               -8.8209776190083389,
                               -27.988937091095416,
                               61.740183587783847,
                               72.368377895756325,
                               62.533478068582788,
                               -14.548138813558504,
                               -53.369727843385881,
                               5.5160375572337355,
                               -67.011573906255691,
                               68.674841146565896,
                               14.005164153159804,
                               -64.198421068788292,
                               69.605202042249743,
                               8.2506981685561023,
                               75.194136848681964,
                               -71.085907115185179,
                               45.050962519900935,
                               13.425338146990402,
                               -5.4059021610510758,
                               63.166242888772267,
                               17.34969753832754,
                               -17.320020609894065,
                               -39.324369552705519,
                               -29.991101607903193,
                               -53.142492020234599,
                               -1.6726768865661494,
                               36.009962128119142,
                               -28.092218887724442,
                               -72.073295048366816,
                               -1.5018297593991452,
                               10.194434060232103,
                               -73.012297074945423,
                               -13.262824723598891,
                               46.064460167752024,
                               -31.797197092567991,
                               -28.996493696560961,
                               -65.466628266642218,
                               71.916539698571682,
                               -16.597502749322864,
                               31.9084734117192,
                               -45.896547287782113,
                               31.451497984966956,
                               44.293559551210137,
                               -23.537001548103472,
                               -7.8370027655379602,
                               49.717480561644997,
                               33.824853523409672,
                               26.444390332588348,
                               -21.645329128807468,
                               30.987716796577551,
                               18.788903924138278,
                               46.638027008770493,
                               56.210960514456957,
                               -46.763892190515918,
                               19.429641939000334,
                               36.749214095383579,
                               75.810749821187017,
                               -31.779783466576717,
                               -10.35838009757571,
                               10.409958618558951,
                               33.738201465195473,
                               63.618869046256734,
                               -43.08795529488696,
                               -19.750911065783928,
                               -46.131911346258505,
                               48.662416946000306,
                               42.522052998641271,
                               -20.952610706715454,
                               47.421177623237881,
                               -41.87496928533195,
                               32.151785682329248,
                               36.882793062699228,
                               -0.33950470762162688,
                               46.760133573021669,
                               -26.909813937737141,
                               -4.3333488620380258,
                               -16.260157613448378,
                               -29.831105024561026,
                               -68.383601889533367,
                               36.28757546045221,
                               -42.442318015641959,
                               13.413754827551905,
                               41.646894673435554,
                               49.771786271041492,
                               28.963320806044962,
                               -77.019784928234856,
                               39.104698307068972,
                               -26.887474142348999,
                               -66.041439992280331,
                               57.079729077934765,
                               48.968990804907222,
                               4.6034428983947713,
                               16.125881948725279,
                               -57.067875596012442,
                               -73.861686057548752,
                               -13.892362266998463,
                               -22.590076239747859,
                               -42.024721058403813,
                               78.949943546014978,
                               56.536745646320831,
                               10.132768820199951,
                               61.670939986308966,
                               8.1314559769734309,
                               -65.635153876337085,
                               -42.936183598451933,
                               20.767861417407879,
                               15.551423742551608,
                               55.055257189990542,
                               -27.395438655106421,
                               48.739262995587531,
                               -79.140693321997745,
                               41.871909917764071,
                               39.070466810204103,
                               45.257502904800923,
                               -18.129018580437524,
                               -36.344629121906436,
                               -75.225700481656276,
                               18.765800819781433,
                               -28.259920185027493,
                               71.36697559641442,
                               -8.4455686516433151,
                               -37.222160591182025,
                               -0.38087042659084247,
                               47.40060682968906,
                               -15.070775552805479,
                               -62.096627298556491,
                               -36.660384997292127,
                               23.886333044457732,
                               -53.014708850676818,
                               57.82479825386396,
                               -15.90114455530591,
                               72.46852093047427,
                               -44.667532591405603,
                               -40.028583060979706,
                               70.557655595873598,
                               36.533125044678243,
                               64.153151401668396,
                               1.4011417105791981,
                               64.866751738604776,
                               -64.136476464486861,
                               -20.75072175902422,
                               -4.2740919380233162,
                               -30.675741267792468,
                               57.871289969749569,
                               -78.343527492440643,
                               23.127934488350327,
                               21.350903427006116,
                               -72.152872857318073,
                               17.574624625742558,
                               75.072599179554075,
                               -75.270140567070783,
                               -1.7393866156108597,
                               23.529875298934002,
                               -20.750811001738455,
                               60.385620874496283,
                               -50.587659350780243,
                               30.09596654638397,
                               -42.531782023926091,
                               27.252160217574229,
                               36.770508756479401,
                               55.014898952150496,
                               -8.1297394523547108,
                               -54.483368606945213,
                               -78.473564081418587,
                               -56.565292299150833,
                               -16.23195907500137,
                               -32.546849729268338,
                               -12.364759128508087,
                               -56.53101977843761,
                               -17.865127412010853,
                               19.018210535507805,
                               52.096936040217074,
                               -33.30423798943302,
                               1.9508890187169996,
                               -40.715831614196375,
                               3.0960760753346666,
                               18.857549089416473,
                               78.842415418529157,
                               76.212012403874581,
                               -4.7898614857726578,
                               -57.902906933341491,
                               73.249486811488651,
                               -4.3439329479288418,
                               23.941996078714407,
                               -13.111161232334444,
                               -19.876037830412201,
                               -8.8077860355739386,
                               -13.618573413212136,
                               71.493880421804434,
                               8.7349604684864222,
                               -72.859494446509615,
                               -49.198217581377889,
                               -39.283518214135313,
                               21.509338192995948,
                               -37.72985060919715,
                               64.18368651551684,
                               46.692046793681072,
                               50.161605122714889,
                               15.068388863778775,
                               -20.531651672334078,
                               19.38423874844667,
                               46.288572654149512,
                               -52.717575727200469,
                               -56.647953017061781,
                               68.008544364602102,
                               38.109491287491615,
                               19.513711650472921,
                               36.585102264791033,
                               -4.3116829244274406,
                               -70.941662012287352,
                               -39.939943807799196,
                               -51.569118271299054,
                               -39.75516163825209,
                               73.734190196111228,
                               -67.860301533430928,
                               12.906837999943102,
                               -11.423217707496965,
                               -38.316451114709409,
                               29.594721869743822,
                               -24.982782612058251,
                               53.871560657191054,
                               1.0211392951223992,
                               46.068953873961277,
                               -14.259112253123803,
                               -16.404360475815754,
                               -34.240985716958008,
                               -29.123643554508455,
                               41.286932613499864,
                               2.6689532949274515,
                               2.0375232405145507,
                               53.358957380687002,
                               -9.0451127115051655,
                               -72.465961213021529,
                               4.1414438009336596,
                               -61.316244255955894,
                               -48.868043087786475,
                               -0.67121737000871384,
                               -35.592312004615223,
                               26.039127988872067,
                               7.797451158537358,
                               45.602690533375878,
                               15.188791778284561,
                               63.993913927744785,
                               -50.184224352767984};

const double shift_29[1000] = {-37.238930070749014,
                               -67.086040025992361,
                               -67.797192246409566,
                               6.9561702758411528,
                               -57.603222215082006,
                               45.248381783649378,
                               28.368186873787696,
                               51.010363592288734,
                               5.7709805563262222,
                               -6.8509692678594778,
                               -8.3437753704369975,
                               -56.238545782233288,
                               -48.725594635310223,
                               63.494637117621494,
                               15.215243241127299,
                               53.701057725193721,
                               -67.262475062862663,
                               72.617246962822108,
                               -22.192489622909804,
                               -4.8075611326967724,
                               64.39775157319788,
                               63.54771593218144,
                               75.821022596314862,
                               75.034374810361868,
                               36.492551837459359,
                               -45.290956138795487,
                               -56.827637732976555,
                               75.19944098953566,
                               10.029702960493676,
                               65.433629633150062,
                               50.883794126291448,
                               -28.798609940206742,
                               -50.012568265533716,
                               27.279230030517446,
                               11.971490461287903,
                               -56.966690713321164,
                               43.575830601842902,
                               -4.8263032274765418,
                               -78.571497448010234,
                               69.469791945255864,
                               55.194478087011248,
                               55.484487297539651,
                               53.23639763167369,
                               55.466843016090664,
                               -73.670165550949235,
                               22.136236034127403,
                               36.572841938968828,
                               63.639511639008987,
                               74.197042906196586,
                               7.2758338435042074,
                               19.851016959276414,
                               50.73433228131649,
                               -70.87088140417805,
                               -68.819522550139695,
                               74.187010323848881,
                               45.399989147603556,
                               69.935816391880905,
                               70.187100368967677,
                               -20.405364886781307,
                               0.15715777160745859,
                               -36.30817177034109,
                               4.7008377646725457,
                               6.991843725350714,
                               -15.038845974270714,
                               26.74095986255216,
                               61.145692347318288,
                               36.260271077025067,
                               19.565769839880815,
                               1.4064515672791345,
                               -56.848080441420507,
                               74.459003331328731,
                               18.058228739621953,
                               19.551225600914428,
                               15.836397103067423,
                               -3.7205532923326032,
                               -19.445289958749228,
                               41.373329921850434,
                               0.073553429103339951,
                               73.319064341657935,
                               0.21528282716613667,
                               9.8205665728646192,
                               43.940598491374715,
                               46.442120655501199,
                               -50.207917480529929,
                               -30.160269298304229,
                               -55.438646435215169,
                               51.843441060824723,
                               -79.358904057890868,
                               13.698542652959652,
                               -59.013141667331055,
                               54.84655939290829,
                               -42.756728980771584,
                               44.13885477284844,
                               16.386043701990417,
                               -52.982623725358422,
                               35.178159369652597,
                               -41.826982926624076,
                               -22.103450128449055,
                               7.9911743022732171,
                               79.424447379483837,
                               -60.567256953575907,
                               -3.2697196855443327,
                               -54.096961168480846,
                               -73.394017268012576,
                               -25.629150024958221,
                               69.125965587267189,
                               -3.9699664942337556,
                               -73.597491422206332,
                               -37.725050749517251,
                               75.426583411919196,
                               -50.575380260377329,
                               -3.727719744501087,
                               67.252238753461526,
                               -47.970618781754631,
                               53.923219071296671,
                               27.627250041090594,
                               76.432796939034603,
                               -23.288967030383652,
                               40.46742170549534,
                               -57.790191593306432,
                               -28.595793237206173,
                               7.3165236459957956,
                               -63.457551568628688,
                               52.367189188102877,
                               21.478411814703147,
                               -61.618017033841838,
                               54.805722080979699,
                               9.634726888947986,
                               -64.821865024859108,
                               -31.741622304076159,
                               -5.5009147657369049,
                               -11.527449042974569,
                               -39.204914274857174,
                               -6.6066504534840984,
                               63.410487889570504,
                               -37.479246925432847,
                               -34.919849666290943,
                               -42.723312973201544,
                               32.184525222887018,
                               -35.025612058971632,
                               19.154019389591419,
                               -67.8935258160205,
                               -3.886344214316825,
                               -21.781286338128986,
                               28.275916007379031,
                               15.841000697580292,
                               56.633129642626145,
                               46.001691326874521,
                               -47.890582284797205,
                               46.981407105155448,
                               12.273629249701942,
                               -17.998937998004877,
                               -22.553704026895453,
                               38.004553871085989,
                               -74.659505723560486,
                               60.001083635834291,
                               -27.10509559814485,
                               49.041075538866252,
                               -14.044469778742082,
                               55.020115347585175,
                               -73.338178474351153,
                               63.981152562488504,
                               17.420998677144254,
                               36.14800608736347,
                               -66.843973480620818,
                               -32.616852573851759,
                               22.085226116246691,
                               -50.398973070163358,
                               -35.498498535418648,
                               2.5588923588299775,
                               38.503149873833308,
                               -34.45581127398664,
                               3.5504768751811309,
                               45.254296607284871,
                               5.9537502437766392,
                               31.277492957416094,
                               -45.955206921195483,
                               51.696563712562508,
                               -12.268596800901944,
                               -10.51871747004364,
                               26.455173388894405,
                               -24.932978475045573,
                               -47.270658278361402,
                               34.380685188446691,
                               17.395613101344114,
                               66.092342330947602,
                               32.218751139683029,
                               7.1302722491434825,
                               71.875924892774577,
                               -4.3456525918501772,
                               47.56473348664727,
                               -5.9320371102191807,
                               68.707038154778544,
                               -70.639680279414748,
                               -33.975074411028281,
                               -22.983591772036316,
                               45.625443197805311,
                               18.054013885992433,
                               -72.214272960270861,
                               4.2951935685574423,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               59.82079172250117,
                               51.045625446677654,
                               -19.174490508575964,
                               35.211704620012938,
                               76.936796235244799,
                               -18.432704462504127,
                               2.6019922174007259,
                               10.580439395552455,
                               -6.5564823685289575,
                               -38.295987134592373,
                               15.889805346323515,
                               48.538624057658538,
                               -69.342656806751762,
                               -70.297932140456581,
                               39.965958161126785,
                               -25.150851731197871,
                               -57.668646947877988,
                               -58.43632353772626,
                               79.03940651228362,
                               -43.781978748647553,
                               -51.034817365245061,
                               17.760457653820694,
                               -75.861021326502353,
                               -6.3852807038560151,
                               -64.643315496328881,
                               -6.4764700029650903,
                               -24.43934184580506,
                               -50.530433678673774,
                               -11.927248128247349,
                               -43.90303870648826,
                               -40.632701847606626,
                               11.178298628303599,
                               65.185801148505348,
                               -58.798466402626431,
                               -47.690694703399657,
                               50.665219301787978,
                               55.879085507835654,
                               49.093031828428977,
                               71.390300533153493,
                               50.278577139833246,
                               -44.428839512595616,
                               23.521822451535702,
                               -76.144489662324261,
                               -34.303355306825551,
                               -1.4923987609618479,
                               -45.143192902659415,
                               -41.332969310283183,
                               -17.162828010418828,
                               30.645525410681859,
                               -36.732277582958744,
                               -73.020409030894356,
                               69.534759933109072,
                               4.4274943450767257,
                               -21.663266265241425,
                               -32.832124681724217,
                               4.1619990906775026,
                               -73.707717805242766,
                               24.744662596782121,
                               -62.157023458242129,
                               19.094427506504253,
                               -23.454239540375106,
                               45.175748899025393,
                               59.742838064501044,
                               3.7365265700464363,
                               1.4811192239806505,
                               14.432151453190894,
                               -7.8250255710623904,
                               -9.4467803636719125,
                               -26.928513428152261,
                               52.810561756413065,
                               -19.827307033084693,
                               -15.147303571584226,
                               39.152836451311465,
                               53.848857422012053,
                               -30.579480525272899,
                               -68.574743614258779,
                               0.96269195424309473,
                               -13.764144323611346,
                               -27.182416820310916,
                               -56.162315216526878,
                               -10.149501019875149,
                               -3.2374987289455603,
                               -8.2567937630003492,
                               71.814728675318193,
                               -77.358049324286014,
                               57.202131555492358,
                               71.006096357158711,
                               75.682773371550411,
                               -52.282304529837802,
                               35.417826375056009,
                               10.681897574692288,
                               1.1492028303322606,
                               -6.4670330123626698,
                               -49.822678710975595,
                               -74.918163726077097,
                               -50.807792036869898,
                               -79.074258001075762,
                               -47.4558004014159,
                               68.717496828913724,
                               23.052679402536466,
                               -70.367934553653612,
                               75.943210040787932,
                               -3.7883652405806512,
                               24.956193132111768,
                               60.395886210942756,
                               -42.69477598512514,
                               -37.588097897966833,
                               45.817684958334553,
                               67.581360359306302,
                               56.062289371781716,
                               27.625400481785864,
                               1.9688784243662081,
                               30.373078305832287,
                               -60.051006000226387,
                               -71.311725283392164,
                               -69.083286406579717,
                               41.500949482676958,
                               50.608729945106923,
                               1.4345141564308008,
                               71.754148556713702,
                               6.1848187437203244,
                               -69.435787466152647,
                               8.9822517504531501,
                               38.621389102483299,
                               -3.2908109307745033,
                               51.964680399464797,
                               -1.9278960862506231,
                               18.991118648680597,
                               65.020094549034312,
                               31.347362717127666,
                               28.421818695970586,
                               -61.692888576527153,
                               -7.3282750430514447,
                               -28.45777720221961,
                               37.847541271690567,
                               20.765412572971197,
                               -56.031343797153447,
                               33.364791456915462,
                               4.3601825336175626,
                               -11.478965512387038,
                               -74.822767337238957,
                               -38.159215694857643,
                               -37.937413849326255,
                               78.81517932218496,
                               66.283645314967075,
                               -51.029204565300248,
                               -78.825370014966737,
                               -3.9765822080593392,
                               11.527498731345162,
                               -51.607317900553014,
                               -44.488354530008358,
                               -57.538496319301821,
                               43.506236022207176,
                               -61.761282621234713,
                               -19.973057817133125,
                               -32.29110874444477,
                               29.61683825315508,
                               -65.570846613865669,
                               35.995898767689283,
                               -61.740754055498556,
                               49.147831889280305,
                               -35.716178028171491,
                               -65.760259910037774,
                               -46.997763625259232,
                               -50.161676516002608,
                               -54.765995122734346,
                               73.321990086198923,
                               -30.979209210750163,
                               21.590012475559337,
                               -23.683606674666912,
                               27.340505031239175,
                               11.001471502585243,
                               -67.673568918096592,
                               -60.655626695852888,
                               -49.354439144985918,
                               64.86035104093537,
                               -28.832081073962492,
                               -20.004622113532033,
                               44.476647204311064,
                               -27.81701523441501,
                               79.300891156158826,
                               68.84779059547752,
                               58.044979152376115,
                               -45.333463671508227,
                               -38.130061923813486,
                               10.950254878034004,
                               -24.48152981901891,
                               -15.327631632835262,
                               22.158267946322745,
                               -32.73270472069936,
                               -59.263652849131567,
                               26.859319681449726,
                               -22.232209548569024,
                               35.202734086419298,
                               28.571456429439014,
                               15.184391382112743,
                               -0.52393705317576611,
                               -51.102035496579234,
                               -41.764866792268307,
                               -4.8508269421291335,
                               18.441312356609359,
                               15.197768130570013,
                               34.352308814303434,
                               -44.562330567377543,
                               42.559881795544833,
                               -14.694296730857801,
                               -78.166767450103492,
                               -36.925198969976293,
                               -77.767380812003097,
                               39.373471491435268,
                               -37.920517872870626,
                               -79.065757869469238,
                               46.788637701630016,
                               -9.1931055252734257,
                               74.579658398420278,
                               -7.9310649502965784,
                               -16.129820488163617,
                               17.282173134150671,
                               -45.926569926737088,
                               36.676837898444447,
                               -46.358027221218308,
                               -25.040853610661699,
                               31.499042597746651,
                               -22.765534314311601,
                               -17.67595081629787,
                               13.623448610993695,
                               -77.355598850060332,
                               -32.395739330571786,
                               24.30027371855482,
                               54.095444304189414,
                               77.47063201348243,
                               38.750875077450729,
                               -26.591771536245528,
                               -64.518233702692598,
                               69.679496766392234,
                               77.993457222012324,
                               -64.795460132256139,
                               79.492045990030704,
                               -51.779464412786112,
                               -21.073147702644683,
                               -15.750993747743005,
                               34.227835981753991,
                               72.242255863178571,
                               -2.721861765450603,
                               -44.092430926907518,
                               -67.194483675339683,
                               -55.1553027843877,
                               -67.538611652888051,
                               -74.093776693902043,
                               -21.17847456565687,
                               -63.976113949163427,
                               -73.404337722913624,
                               -58.822942693056049,
                               -40.877089739324028,
                               11.905595971499045,
                               -14.154905466691657,
                               -2.7669938491873687,
                               -29.242376398830139,
                               -36.090091049961579,
                               -38.32537826503615,
                               -9.9981853507092264,
                               -7.882563326229949,
                               -63.057692045065835,
                               -50.680630817458542,
                               58.500941058558389,
                               19.122946952687748,
                               -66.28392849129682,
                               48.115568139959024,
                               -9.3692526080892318,
                               -78.283425390311407,
                               -10.547954904565994,
                               -56.861773843486262,
                               77.091325340360754,
                               27.565471693672301,
                               -70.901837603263814,
                               52.374677949962397,
                               -70.329783611835808,
                               -33.798125837489799,
                               -50.460514929778455,
                               27.21321676886739,
                               -36.683549996235492,
                               57.389155620985022,
                               3.1073699859445565,
                               31.54303146441034,
                               38.626006647158462,
                               -45.204693518925374,
                               -32.740584892110419,
                               -55.25245320971576,
                               -22.181562175210864,
                               25.859444034648597,
                               -26.829365334960436,
                               50.455977989958051,
                               26.43218355496608,
                               -33.622992457400862,
                               70.250143372873524,
                               49.319780943819694,
                               52.620406085478081,
                               2.2474750485975381,
                               32.56781283148927,
                               -33.913119382650017,
                               77.398608097537846,
                               -34.211987617970934,
                               50.075178647328407,
                               -5.0474373919659516,
                               -8.4010700099632576,
                               -74.720915634037794,
                               61.674367808893912,
                               -50.890366894659316,
                               37.36918483060942,
                               16.289258986801741,
                               56.843277552903743,
                               -45.937053646211545,
                               -6.9935686517895039,
                               -19.740927109378013,
                               -13.269967882864677,
                               -34.757993955019955,
                               0.2332575986780121,
                               -78.469160611108933,
                               -0.58470676353919337,
                               61.43100194758911,
                               60.748659509507377,
                               70.966037037613006,
                               63.188527117944744,
                               16.558927921831849,
                               -52.284109877600713,
                               -29.394833775751135,
                               24.766547878109677,
                               -27.485212191992673,
                               -49.714232962894847,
                               14.380478412992696,
                               -61.101557407217058,
                               66.218986051950878,
                               61.844208029720633,
                               49.456550171731521,
                               -23.788066502457703,
                               32.080944597184043,
                               -13.468813151289666,
                               4.4602706639988821,
                               -41.785707007962017,
                               39.705980521769185,
                               12.998308046817566,
                               -12.83208210530538,
                               -53.566312069028022,
                               -61.759762627856531,
                               44.086551274063126,
                               -5.4243651741234835,
                               -8.3483505401279867,
                               7.0766637934333207,
                               43.646320683203164,
                               -3.5901354500293774,
                               32.567660024418885,
                               21.321478754360534,
                               -14.077731007224074,
                               19.986838036641547,
                               44.821635864865129,
                               31.924477336476993,
                               48.49864791365227,
                               -40.907284358882102,
                               -65.461665467517477,
                               -19.350857758029015,
                               19.474551446244362,
                               -79.888208099438188,
                               44.411571170180494,
                               75.118646373926254,
                               -30.987777835488611,
                               -30.985944893589895,
                               -56.934301643757493,
                               -74.143546511597265,
                               34.070776976099999,
                               -11.891613360903944,
                               63.119757745509247,
                               -70.785652460499151,
                               -30.192323997757494,
                               -22.202915634573866,
                               57.794862799105864,
                               -13.570972465106843,
                               -48.058922863865675,
                               75.258029531134156,
                               14.96156409435145,
                               54.729192711877417,
                               56.93935291308329,
                               -48.342534344157365,
                               69.903355371374374,
                               -11.459578628506989,
                               77.699444464922607,
                               -12.605580197582956,
                               23.908415444551927,
                               -29.046516439775363,
                               36.370009154789194,
                               59.323808383334871,
                               -44.93141539490172,
                               37.750221172481062,
                               52.893953816422751,
                               -3.917330134514259,
                               -9.1290014111178248,
                               26.393287268846272,
                               -20.371451719746048,
                               32.576215149789576,
                               55.828877789958277,
                               52.785631221820779,
                               5.6892913964091285,
                               27.933400003215638,
                               24.119575116181338,
                               76.619124718809104,
                               27.000167801899373,
                               56.876674637050826,
                               72.683126780431579,
                               -17.354539951557186,
                               -54.804053278858433,
                               -17.390536656612127,
                               74.219446534555317,
                               -21.236194389283618,
                               12.80626382002367,
                               15.833020356425065,
                               21.414115041077014,
                               -51.520285469153677,
                               61.781931470812168,
                               34.332824143287638,
                               -73.573125788975545,
                               28.619464401624349,
                               39.587698121707263,
                               -1.0702495821263884,
                               -36.005089900382316,
                               -38.808911754890339,
                               55.591383279628317,
                               67.495821878787623,
                               40.296973350765839,
                               -74.461388564036199,
                               -44.602799500315186,
                               -55.709605228110334,
                               -23.028136820813387,
                               -36.460406448702877,
                               21.890757338505388,
                               -38.974262813811094,
                               -51.022508459172855,
                               -65.488977981358033,
                               12.665998077703746,
                               -75.365914794070633,
                               -29.634521671068391,
                               24.82895266432503,
                               -16.714174939429363,
                               8.067595958278643,
                               5.3093918235094684,
                               11.184997237344076,
                               5.0996247464723439,
                               43.688082903709407,
                               72.312196656630221,
                               73.528760977184419,
                               55.963026218896168,
                               75.733182638844099,
                               -25.790562897707424,
                               43.095869861903132,
                               18.330641512993061,
                               -14.63811898553281,
                               50.67045011128068,
                               -52.72686084284183,
                               36.737135579396593,
                               -9.3449620800711326,
                               68.683904300775097,
                               38.156685439427058,
                               6.1184959897203353,
                               -61.217823361352799,
                               -6.8308333363058029,
                               19.515301650324279,
                               -42.580085642809919,
                               -70.305717719086104,
                               -27.317682521924553,
                               67.519488432077537,
                               79.139477675465884,
                               -45.967360749802047,
                               -35.216278425423525,
                               47.064289367164953,
                               -45.739281339637031,
                               -76.293392534335652,
                               23.816049753742472,
                               35.031797883578236,
                               17.332313645816491,
                               -64.570701510012412,
                               29.474353970278184,
                               45.587783705035527,
                               35.423701957343646,
                               -64.955636384461997,
                               31.701356757389561,
                               -78.583943487143841,
                               -14.678867364408122,
                               35.673523682585163,
                               -1.0735816437224539,
                               47.522819915507824,
                               -70.905300101930465,
                               10.491450009360715,
                               -68.867277687254756,
                               -66.717840516438002,
                               -76.74506959125911,
                               72.930683939489668,
                               -31.94868718062061,
                               69.86584623433447,
                               15.523793894407437,
                               -10.217965862124316,
                               -48.10307461174348,
                               -28.126482556926135,
                               33.351771207590204,
                               -51.994990055319164,
                               -42.963476607362999,
                               -27.44622620192975,
                               -33.421993462681435,
                               -62.593101250912596,
                               44.343217532355915,
                               -5.7354383297052713,
                               27.513318868259748,
                               -70.816866653241263,
                               -28.063576512408403,
                               27.490196616797526,
                               -26.105537302996336,
                               33.992124916474538,
                               -31.642776744392606,
                               69.144770026853408,
                               29.746828746705368,
                               4.4987676108050234,
                               -55.925064257675515,
                               0.90770314986335698,
                               -8.8572449936296245,
                               -53.882161109470424,
                               44.039602436735393,
                               2.1762615456260228,
                               64.137274205354174,
                               -74.048790718738232,
                               10.502580362288686,
                               49.986674466900027,
                               -16.288820101954641,
                               -76.336634853091695,
                               -64.084840972342249,
                               51.323018180837401,
                               45.595468426883336,
                               66.955804879319729,
                               28.474333679878434,
                               -14.145401963469547,
                               -20.228363311054576,
                               -58.332959675752122,
                               -9.8389269366092424,
                               8.3305587172425319,
                               36.06274306938532,
                               71.679710116296746,
                               -29.445501147929185,
                               18.236570787643537,
                               -50.630627911647153,
                               49.219188630853402,
                               -28.408419640487462,
                               -34.162276034724343,
                               -29.777355527119681,
                               19.61203279754794,
                               -4.4103362256375842,
                               -45.54923540567318,
                               -32.683874537173097,
                               79.922920188866343,
                               -50.528242345570121,
                               -26.270265608668211,
                               -59.508694344726663,
                               -52.465202708900073,
                               19.330308910473736,
                               -66.947502733730076,
                               69.800310326771211,
                               69.992689389288017,
                               -44.760119341812384,
                               57.588562587888624,
                               -11.730199264744114,
                               46.362686917974756,
                               12.019794656664155,
                               -32.931852339087577,
                               -68.032344240347996,
                               75.769264649852758,
                               -60.334490697469896,
                               -22.505332845358005,
                               -12.404590059103477,
                               -0.079670560364785814,
                               -41.334017021963945,
                               -33.376290906937754,
                               65.656527995271517,
                               40.223894659993178,
                               -79.02407913408733,
                               -47.915888742166743,
                               -64.777802410573869,
                               29.237778492808957,
                               -54.686220898676623,
                               -24.774909102506658,
                               55.072400079715599,
                               22.210572975625105,
                               -64.880379469058795,
                               -32.59505505649804,
                               61.351395805919303,
                               -17.515224986164846,
                               -1.0661843702068836,
                               64.794004199608764,
                               -62.303150126054234,
                               6.6675539513330371,
                               44.337926974832591,
                               -2.9840286300082788,
                               70.038561608841363,
                               54.429853702730419,
                               16.890087823930628,
                               33.540009743433515,
                               -26.818272395984707,
                               -23.147277019817039,
                               3.9317544368783697,
                               -59.625240315409229,
                               14.305935269450739,
                               20.596466203798464,
                               -22.190173640378255,
                               16.215359279989922,
                               55.648295965957786,
                               -59.653383810329444,
                               32.466735825554927,
                               42.93405945416324,
                               -33.302737592086501,
                               17.124039657159656,
                               -58.846084758467057,
                               10.14754971163954,
                               -42.881054473205474,
                               -46.83595859178687,
                               55.158641109121405,
                               -27.790140716080039,
                               -74.920999593959451,
                               -44.632296185443728,
                               -23.332603783464332,
                               -64.461416935345483,
                               8.56348279095862,
                               41.441776165315815,
                               -34.838269503880497,
                               39.413270540853794,
                               51.945660025390943,
                               45.512414356198306,
                               12.995515447969684,
                               -70.784635642938568,
                               -66.686653647814566,
                               33.148298667149589,
                               -77.188465205115321,
                               -24.630957865915803,
                               69.398470073602738,
                               29.8744768819667,
                               51.822014272399876,
                               -69.541185650263671,
                               -52.007167371109297,
                               -25.566678176580027,
                               43.372428537204243,
                               -79.806094061999573,
                               57.544693305723627,
                               -20.891301020905015,
                               25.646618966034939,
                               -59.156536044261983,
                               -0.57077250238408972,
                               -72.547523432254025,
                               72.487747359762665,
                               1.4855151195553997,
                               60.082328592884011,
                               8.192221777087429,
                               21.388093177667695,
                               -72.896712901818944,
                               -33.784482424048619,
                               41.028845376145355,
                               15.758494036068502,
                               78.276733344266589,
                               -59.701384859919116,
                               -29.190867078344098,
                               66.323638189715624,
                               -77.010259814572976,
                               47.118647177143757,
                               74.655126101181636,
                               -34.694083517581717,
                               15.159180613636247,
                               -63.401012443453588,
                               22.747439545674489,
                               3.6965102101654423,
                               75.287252653159669,
                               -60.558492113862961,
                               -38.24207097101641,
                               36.685831065893929,
                               6.7373987106352384,
                               -1.7957549347018738,
                               -55.413169993384528,
                               -32.595333408104779,
                               -73.079710133057119,
                               -56.492089319529008,
                               1.9279004428576716,
                               -71.854142989598913,
                               8.7637687255198724,
                               -56.711680134553816,
                               -23.483869240079102,
                               -55.840627443904545,
                               22.331863644050554,
                               -0.44785587286905937,
                               -79.605049979508308,
                               28.022399980028879,
                               -50.849397205418548,
                               -44.235585328197644,
                               -23.43332126423191,
                               5.4229690102552741,
                               -78.65596491389303,
                               -58.872622221443891,
                               -70.224848292951918,
                               -20.772457310751722,
                               -50.551729590286534};

const double shift_28[1000] = {8.3161609450885745,
                               -61.532324843396907,
                               10.037574874497658,
                               10.737703789689851,
                               -65.42982037746107,
                               -29.044271969336332,
                               -76.747308024162578,
                               -13.292714655662463,
                               -51.187739587927283,
                               -65.012928665081276,
                               -2.2924743060141282,
                               49.394980174964026,
                               64.267262065819153,
                               29.359091334719984,
                               -45.143262542262015,
                               49.084048210124948,
                               -37.180066646524999,
                               5.9992934208539896,
                               33.030143367137661,
                               -51.417804993572759,
                               53.65064405737094,
                               -44.087688954108181,
                               35.425856382323133,
                               -63.362386579342555,
                               -73.523219286470777,
                               64.739044581219773,
                               -75.861726645157361,
                               -8.6903348452971727,
                               23.328078361403509,
                               -55.049054680613622,
                               2.4581202875016892,
                               7.3000127265084149,
                               -39.607271450853034,
                               75.996204398267494,
                               13.434347423124684,
                               4.2133378521997251,
                               -12.777096685289866,
                               62.378945458177185,
                               75.040229664844091,
                               77.476707751450007,
                               -6.7537376090677466,
                               -19.752589328099837,
                               -30.146974180904444,
                               -35.055645543245987,
                               -69.300114711762504,
                               41.914962844658689,
                               50.592120114050815,
                               -43.69407619463243,
                               -44.941254527864082,
                               5.1023341489582954,
                               45.838102939201491,
                               75.978111450725308,
                               72.984527749705052,
                               -25.060452692811069,
                               -39.197723381166867,
                               44.485292755276973,
                               -38.459309084969682,
                               20.261472691371683,
                               -33.573691328263855,
                               -68.568823413434188,
                               50.167574425530795,
                               -19.453372025421132,
                               -59.719151668975655,
                               75.857696235992805,
                               -61.606727569683343,
                               72.839157984850857,
                               6.0703290060428081,
                               -12.3532618024313,
                               -30.017982777271726,
                               -29.943364673209743,
                               -9.4706177431902674,
                               -0.4044933767111818,
                               5.8785785816116949,
                               79.393198170705986,
                               5.2881623537994411,
                               -17.373011726199792,
                               -73.480923295339309,
                               55.306200108163466,
                               -22.384099209862782,
                               -75.68583770273311,
                               -59.593641395690511,
                               -59.328803129580379,
                               67.409892529882285,
                               48.791513277533973,
                               30.161906828425046,
                               50.189817861643007,
                               48.810752715276664,
                               -79.875912606944226,
                               31.782084686589037,
                               -67.431245312390786,
                               -66.066889314006232,
                               -18.036815497813897,
                               -45.044503369000694,
                               52.670695097881222,
                               47.603921763651677,
                               -12.80947929888028,
                               69.17807319560211,
                               3.8868971951763545,
                               -62.365944011910983,
                               -49.150037137986928,
                               -12.981948330205551,
                               -2.3494469898533623,
                               -29.378960509123033,
                               -64.05312396982076,
                               3.1950298664444077,
                               -42.246777797589885,
                               13.255076030083393,
                               -43.839305752111173,
                               -64.005160874005611,
                               27.208101090319374,
                               43.010428469792053,
                               -63.635866729160142,
                               -32.232358780646322,
                               46.333965011567017,
                               -58.404822693152013,
                               -37.102002453003692,
                               47.91761033086803,
                               -74.414414581273434,
                               -59.691223819728712,
                               41.872072386944673,
                               41.980936057848794,
                               -62.843174252681656,
                               -51.50253875164848,
                               39.487832964961534,
                               30.151595427113847,
                               33.65476658136312,
                               59.943896647288369,
                               3.5450249023251974,
                               58.479385793023553,
                               21.079100325332128,
                               -77.047993991264946,
                               -6.6298983791043362,
                               51.022563252190778,
                               -7.5650806704985492,
                               -5.7071018151123507,
                               -72.535923703622984,
                               5.1814171656359367,
                               -63.269498410517031,
                               -42.026005819199099,
                               -69.490300750450075,
                               78.040932663816974,
                               -50.73659868239497,
                               34.617841922889795,
                               73.019404273800276,
                               -2.8464245635088155,
                               -74.587975787073546,
                               -48.014003865014644,
                               23.011322987753744,
                               -49.019155639642335,
                               -24.38409223888042,
                               -13.203016538168729,
                               26.644584550855956,
                               -40.076416622476067,
                               -60.204558499287458,
                               -7.9349785266708484,
                               -42.131112202039894,
                               67.299116331275542,
                               1.803816656525882,
                               1.6581951743757575,
                               -46.283943005507538,
                               -62.865141671408367,
                               -57.853643577739319,
                               0.59523315555263423,
                               -32.838360569834045,
                               -23.200837040961584,
                               -63.64994751107146,
                               -52.335866942333304,
                               -59.83035181293949,
                               -15.27908292560798,
                               -14.723092765849673,
                               -78.180945319953892,
                               -16.140579003941742,
                               18.603790736286477,
                               24.252656975317841,
                               -62.422784379679968,
                               -55.433026861721117,
                               34.003139155506879,
                               30.639298790160414,
                               43.043956638440761,
                               45.195556824673375,
                               57.436393892896788,
                               43.869316987115205,
                               18.816739789306713,
                               35.275379244980364,
                               -68.633103291657619,
                               0.68002000617191349,
                               -30.24391617057319,
                               -36.625584102686226,
                               -12.013919397410239,
                               78.310375464308493,
                               62.056302244449348,
                               12.774713273476163,
                               -60.395828176315419,
                               0.45720326870010375,
                               -27.158798031496119,
                               5.6492133298119214,
                               -25.858259928278294,
                               24.46898684245318,
                               -33.806749606285827,
                               -32.673422180985995,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               69.687007448740019,
                               40.455199111343063,
                               48.877350910300493,
                               -45.778831949929497,
                               48.355583052516835,
                               68.131562253391877,
                               -61.133288076137589,
                               -19.447487209573367,
                               -4.2748244594593459,
                               -21.441016809984419,
                               -36.086116590020104,
                               19.449599971708906,
                               -15.161558366271064,
                               70.394484621605841,
                               30.730621626998165,
                               36.418668158919665,
                               51.320614826203467,
                               37.090422487696088,
                               65.478684061449499,
                               20.729978110881113,
                               -69.571178630767989,
                               -12.279337462702417,
                               65.116317278701587,
                               -25.800934276983682,
                               -63.177399593695846,
                               -53.018082887676215,
                               -7.4996520313711663,
                               -67.808814953153757,
                               76.227780934623482,
                               -45.247652802786703,
                               43.58994397335573,
                               -66.376736835835288,
                               -49.133681364282658,
                               -42.078127867742211,
                               -77.599639295074752,
                               20.737715841991285,
                               71.940886445437656,
                               18.152334336058075,
                               -69.041254841056869,
                               -5.0001154504908953,
                               -17.509808674317121,
                               24.963022830502553,
                               48.152265033324767,
                               57.216209246991561,
                               42.582658544956573,
                               58.616472459793755,
                               -27.633604526332515,
                               36.083619133817791,
                               37.720889308409767,
                               63.250566033211868,
                               57.138233329837625,
                               39.965540718699408,
                               40.550409961155985,
                               58.810164123905921,
                               -28.139078113785061,
                               -16.960761200598409,
                               37.717543373467691,
                               -39.458325772901595,
                               64.424325193224064,
                               -18.256147943522745,
                               -17.508895918976769,
                               74.626945408968339,
                               48.728471651963787,
                               29.982710763893582,
                               -41.434112649457987,
                               -12.986901846632804,
                               44.105468579745974,
                               -70.596667457951582,
                               -57.881824701132452,
                               57.573196033901979,
                               30.05923022186537,
                               54.009074592659353,
                               -17.872992438058837,
                               59.994140299987649,
                               27.943915510594636,
                               -44.871962343518931,
                               -49.622620152987217,
                               -73.964840930518221,
                               24.71636944645757,
                               29.704490676355903,
                               15.787667556751799,
                               -17.99289494679951,
                               9.1649017917899851,
                               -17.790576959888647,
                               -48.306110760808949,
                               -2.6632756121632077,
                               -59.490922802796831,
                               -52.513763273432744,
                               -66.611273936029789,
                               -3.3034307021409415,
                               18.590365884876249,
                               -43.207734878040043,
                               48.706943882136251,
                               33.152830590915812,
                               -79.431120192417922,
                               -62.588440892276623,
                               -39.64789086171028,
                               -9.4955275956623986,
                               76.16986875246036,
                               32.468256480714658,
                               -54.702017240787953,
                               -78.79723862854047,
                               -53.624321663754728,
                               58.314084205298386,
                               41.897197493052978,
                               22.746031047265188,
                               57.069224297062902,
                               16.078451108617003,
                               -42.833354677693919,
                               39.832241675423148,
                               57.887952827041829,
                               -9.0623723321926342,
                               17.839328475928767,
                               -79.592131895914164,
                               -5.7442488018457212,
                               -51.107513450758873,
                               -1.673324524927045,
                               -38.560921354146835,
                               -16.729400418541172,
                               -16.80013671491028,
                               66.923570259269212,
                               4.0776780640451182,
                               -6.805354710024945,
                               30.905491942021879,
                               58.363787905840667,
                               -23.957477530341727,
                               77.822871500294468,
                               -31.725241517587968,
                               -75.819732409950092,
                               -66.639952846384276,
                               -14.317351662326624,
                               16.615179386213956,
                               43.185705993455343,
                               -67.866367793292014,
                               -57.255198046469786,
                               -4.6259533756070503,
                               55.222853435789737,
                               6.071963981570752,
                               51.005705550263471,
                               -34.541530602278542,
                               54.660821453895799,
                               8.2923474219487936,
                               -63.097831181019366,
                               13.101260979193912,
                               -37.699105012799919,
                               -46.933849515833295,
                               15.920200455680563,
                               -67.636359637509003,
                               -66.83010359309398,
                               22.402973233944245,
                               -47.547813219647779,
                               -31.57662905625952,
                               -27.853199524182529,
                               43.254543276566636,
                               12.820029407679479,
                               -70.233542089750955,
                               23.80773389978426,
                               77.375153460987818,
                               38.495374314437193,
                               65.913057408239382,
                               27.624856333071108,
                               14.422712244780231,
                               38.736111611833756,
                               -15.45444666772643,
                               70.412850514856913,
                               21.265067366544649,
                               -14.875333657000619,
                               -33.600866356338763,
                               47.944965312749304,
                               -58.137615346138112,
                               -33.759641493402796,
                               23.220843041347152,
                               33.22066637406315,
                               -60.785188740886468,
                               -28.425586617810808,
                               -11.475628074563202,
                               -41.338535212214282,
                               74.329834144661206,
                               -78.247820678266663,
                               66.049506998301553,
                               43.743859652763142,
                               60.673366333277933,
                               -70.267239666125377,
                               18.025990261626529,
                               58.051133227026995,
                               -75.385422302755373,
                               -6.8145735054710812,
                               74.238376118104568,
                               -26.496326284148608,
                               56.578872915910281,
                               -11.044347719177031,
                               -66.404066245819749,
                               47.771293973746232,
                               -5.3932567461951848,
                               53.297312318629011,
                               51.066001781987993,
                               -15.059910932556804,
                               44.677964366440982,
                               32.513332000806862,
                               -12.437219843822698,
                               -32.505817370613492,
                               2.5148296846526446,
                               72.306307098415303,
                               27.571135761891558,
                               -3.2192769129551504,
                               -70.640720264927651,
                               17.710023341982627,
                               4.388133522803729,
                               45.76022444501352,
                               -41.648920449569204,
                               -59.676985504070444,
                               -65.826087396619116,
                               -57.353976719296014,
                               -40.209237978665996,
                               62.449354864176705,
                               -0.84615329568853426,
                               -20.777572660259629,
                               55.251679129238518,
                               -35.714636355993918,
                               69.504142272980587,
                               31.962454436759735,
                               30.595007389753398,
                               24.883791558600674,
                               -11.067618405028034,
                               72.108532272890059,
                               57.654504933707955,
                               -21.488272591908604,
                               69.824677986194644,
                               -50.040020533598394,
                               13.284125698180468,
                               -28.690419682785603,
                               56.7437927201006,
                               67.197059398794948,
                               18.278414482372384,
                               59.713916026267484,
                               -35.066410577216828,
                               25.553261477861881,
                               76.492646353312409,
                               -19.066044845421423,
                               -29.657790851546498,
                               0.81738452085776458,
                               73.767732627630494,
                               9.9949434529561518,
                               -76.784202369126078,
                               64.747075222303437,
                               -58.732701148862148,
                               -4.9054346522907082,
                               -24.542139947666374,
                               50.629135860902942,
                               -69.071570334907292,
                               23.935779168039701,
                               -48.692737999031685,
                               -61.353072327418737,
                               70.298173029202815,
                               32.588373832237814,
                               -1.2349837989384032,
                               -24.797810655999317,
                               -79.868198159310538,
                               -74.653334587647194,
                               48.946159742237917,
                               33.493917207108886,
                               -64.038934613002795,
                               25.375684909969408,
                               6.221689530428522,
                               12.367970446437385,
                               53.394736430212703,
                               25.042544281174379,
                               43.472280348858497,
                               -76.463930280904734,
                               8.7041299971512132,
                               50.043900752869433,
                               75.890661005005782,
                               -77.214583027480728,
                               6.7888713679710389,
                               70.895819820508549,
                               76.447265530702097,
                               -15.424705841051566,
                               -31.891651098200001,
                               -37.836909661991918,
                               55.261966339128499,
                               -29.177916839435092,
                               -76.71295627619385,
                               -39.711127423349268,
                               -33.732950088050877,
                               79.370584685144763,
                               -42.74369741004385,
                               31.653942609686219,
                               -2.0855163188392414,
                               -61.391203185038528,
                               47.775668468211876,
                               14.904221511369517,
                               29.068598901087128,
                               -20.828154742852117,
                               -54.175470764923148,
                               -45.792594151449407,
                               71.203816569227627,
                               28.449849865850787,
                               69.967232520646604,
                               -7.44195257169795,
                               69.562475666539967,
                               37.451701160405833,
                               -30.732384210334367,
                               -32.273266960880619,
                               40.071016207778072,
                               -39.738955282883069,
                               -6.8209742699414004,
                               68.174978510511096,
                               77.675184796958007,
                               48.91938638592984,
                               -2.832795232808456,
                               -20.432126239303358,
                               -28.080102065865404,
                               -78.728421617631824,
                               -7.1246592081677473,
                               32.860910856002867,
                               15.218763791961321,
                               -50.537204969181289,
                               -59.823955890019448,
                               -14.11700205964744,
                               10.066075952080109,
                               -19.31716365084803,
                               37.880745164157538,
                               -23.191969900077908,
                               5.3127993980959882,
                               -2.7576008369765006,
                               -67.224172274085262,
                               14.992304651920433,
                               39.059714628128702,
                               -6.5284505855946602,
                               -7.3254507375611517,
                               29.973272799161222,
                               -42.319960531293091,
                               -68.0147842822646,
                               42.443899717270455,
                               19.324732236357882,
                               -18.296972231727214,
                               -51.732396829700676,
                               37.006077325352194,
                               2.5710325837452697,
                               54.137412220977929,
                               19.450465184398027,
                               -65.733800035991905,
                               76.048023275976846,
                               -11.626402777034164,
                               -53.460273843586535,
                               22.665386380511208,
                               67.995551633725313,
                               7.6678506686187919,
                               19.837646520728942,
                               -43.33206955724431,
                               -50.759252784414393,
                               61.72296276121935,
                               -67.488960935801515,
                               -77.43014549923511,
                               -60.085308380144241,
                               54.430524665755698,
                               54.903807122900965,
                               58.574949166478753,
                               -54.50636811331465,
                               27.723593508876501,
                               76.970289305719319,
                               55.346966071746223,
                               -32.942959921746038,
                               -21.54654933936979,
                               55.419444457680541,
                               -78.389690288332602,
                               59.738648997470563,
                               51.833288858834734,
                               50.942904537515446,
                               45.496111167870957,
                               -24.913435160082088,
                               35.228817714511294,
                               -40.656275540863227,
                               -37.792204244483393,
                               -38.240498409669883,
                               56.779709418720465,
                               -21.117506963604253,
                               -3.0731244066232435,
                               -49.627224804017331,
                               -27.800483858755342,
                               -10.042887391947211,
                               28.889048696204227,
                               58.516038193888946,
                               75.078104954385566,
                               41.523520808670192,
                               34.11515517713903,
                               14.751249532545089,
                               35.74093373111689,
                               41.983212094285442,
                               -49.202813654562725,
                               47.247030261200329,
                               47.984207321957165,
                               20.182955400931235,
                               -43.083409256474525,
                               26.202974225563196,
                               -67.462031372777489,
                               -63.830909485938449,
                               -70.166241248567999,
                               52.374717970100917,
                               -77.842061842693482,
                               58.373277107322942,
                               51.059517173690111,
                               -7.8434102843588018,
                               -28.432736414540408,
                               64.600992699013105,
                               37.077203078102436,
                               -43.099294666540644,
                               -54.924456804416977,
                               22.281414434640023,
                               76.475412728957807,
                               14.701109178298843,
                               70.406045205285309,
                               61.897509885166997,
                               10.898374284127254,
                               15.612066562662426,
                               16.513289717091194,
                               -68.885532103985014,
                               -14.688257531643414,
                               22.752641832883107,
                               -2.7441657041846774,
                               -34.019421804380194,
                               74.413317065403845,
                               3.2622641297529977,
                               -38.012899932616207,
                               7.1781854932286553,
                               16.65486919003795,
                               37.774589316060876,
                               48.971032752336008,
                               -47.91410996154098,
                               72.316538368950418,
                               48.057346816258011,
                               -60.875437504568573,
                               13.940179147865138,
                               58.794724614114187,
                               65.676027497333422,
                               34.973523990735416,
                               47.633817006312761,
                               -30.352612008190135,
                               -61.487558908630234,
                               38.955550291290969,
                               34.346953047359989,
                               35.928094105050583,
                               -34.755503169032181,
                               42.473069555868548,
                               51.987250637803925,
                               -8.0826939271590827,
                               38.651691730764497,
                               68.25875135262595,
                               -23.568901428665285,
                               -9.7352905422258065,
                               -26.124182223275419,
                               -42.119613158396298,
                               49.465943943543905,
                               3.7864933621718571,
                               70.44997041544049,
                               -62.576597933711213,
                               -0.44783058244008167,
                               -1.4001438093067016,
                               52.911469530895118,
                               -9.2115285102116573,
                               -32.259974303479368,
                               20.964608567455066,
                               -66.030299401288872,
                               59.950510737472626,
                               46.522805962197417,
                               1.2020126521316339,
                               -41.349697956742347,
                               11.469731083264941,
                               72.882347942010142,
                               26.756911328948611,
                               40.435460033649214,
                               -60.984892858596993,
                               -15.895968167823483,
                               -31.274727838428298,
                               -6.7093373640908371,
                               41.886561491656565,
                               71.447052377248582,
                               37.583083428068967,
                               -8.5052522518561489,
                               -1.6183500519291467,
                               29.741617156531536,
                               -13.424207967604438,
                               34.075137175542118,
                               -62.660068074364531,
                               -13.009359848360472,
                               -21.168179839311765,
                               70.599301102337648,
                               58.976948771499039,
                               57.540231515189262,
                               -24.73204417178038,
                               -49.867276410523331,
                               -51.590433428491195,
                               -1.9968726635922547,
                               -74.020949436124369,
                               -60.427781547447104,
                               32.052882395497953,
                               11.428872335771308,
                               -20.607147516869745,
                               -24.524130146507424,
                               27.410693063323087,
                               -64.454349840663426,
                               25.866602939023331,
                               28.800014501332626,
                               -63.322010760638676,
                               17.709448247195272,
                               7.7295133530364897,
                               -18.395009029341793,
                               48.424824851692819,
                               -31.597686653688744,
                               -48.051413903808253,
                               20.304133906640288,
                               -34.187431916138522,
                               11.640286573297766,
                               55.001566693256777,
                               -28.014543001981643,
                               77.231188827582002,
                               9.3986228772029889,
                               66.577294483943234,
                               50.00964249367955,
                               63.816054890258826,
                               6.5464708682069652,
                               48.608544376403408,
                               56.786507552616811,
                               48.001135891095274,
                               -17.961810396233453,
                               0.11205953515507439,
                               -41.167344921921263,
                               21.942730972840629,
                               -26.155915330204408,
                               35.723829703201829,
                               -42.632950106941237,
                               -26.464390702417781,
                               -5.3232880099094491,
                               7.1795914460109724,
                               -44.593693683363213,
                               76.452759073908425,
                               -79.040219112915807,
                               -0.84849062879326098,
                               40.891130133140436,
                               10.627409341965494,
                               -50.574026624160638,
                               -42.032806677757847,
                               -76.33224451647051,
                               19.303462284160901,
                               9.8199372020865585,
                               74.168145833177476,
                               19.366041715441238,
                               50.25820229824248,
                               6.5341988287113377,
                               -49.204349708878802,
                               8.0651681465099969,
                               5.1981594892260468,
                               -6.0518602084048592,
                               30.936398943637805,
                               26.616240611401274,
                               4.1737166166702462,
                               11.018470298835714,
                               -59.705299124805542,
                               -2.1053418572602851,
                               -63.204548084015144,
                               10.74976637207206,
                               -13.404787161364981,
                               78.803428959001565,
                               38.212992083753406,
                               -69.082141270938195,
                               35.636591667697537,
                               -74.572748829460622,
                               -31.724060228944591,
                               11.033660702719002,
                               64.998417883737559,
                               6.6216559645293156,
                               -76.112573040174837,
                               70.846265895080606,
                               46.580491771392644,
                               49.906152420942306,
                               26.930693262390157,
                               51.01646350303912,
                               -61.804823020932361,
                               8.2224798058927213,
                               -35.180480165420121,
                               -45.790099116930335,
                               -43.346503802585474,
                               -61.190316176800877,
                               13.552691856354523,
                               -25.566917289065579,
                               31.42667370566739,
                               46.470422618011831,
                               -29.191405408748814,
                               -44.74699077984873,
                               4.5404609935395577,
                               -16.737266406842942,
                               -9.998675303121729,
                               -72.939890014295287,
                               67.410553124510457,
                               11.698941347082785,
                               -19.687926151947686,
                               -66.6792479860827,
                               -35.941434883438916,
                               18.216861403451428,
                               -16.171656672859939,
                               26.253662714605564,
                               76.156012163638223,
                               38.6843053777161,
                               -6.6718323525715224,
                               -48.790083886473575,
                               63.561144115090897,
                               -7.5903595032841462,
                               38.360979848448622,
                               70.152722216408648,
                               56.141068819851476,
                               65.144855567030845,
                               44.395662641728023,
                               -18.517625035568521,
                               -28.394194763290429,
                               -78.367261534782244,
                               -25.097806138029071,
                               68.580041859489725,
                               17.392135109471429,
                               0.39821152145661465,
                               -42.698324038397274,
                               -4.4092003845172876,
                               -67.358624941727172,
                               -71.87691913481261,
                               75.61248806476938,
                               45.659493397745237,
                               -47.999226487079845,
                               -50.442968120129336,
                               -47.976135627909564,
                               14.797424949149219,
                               -16.979215854111615,
                               -56.081422556748265,
                               65.09212906600564,
                               -23.381673333852859,
                               -54.662996175901242,
                               -19.838846007382852,
                               57.590027305118568,
                               -36.401494998889575,
                               -34.120243518590186,
                               -1.4508491001081261,
                               24.167826939747613,
                               -42.391180802050961,
                               -9.0015846229437937,
                               -7.3292319835101942,
                               -26.737336440451145,
                               30.915551829488805,
                               6.0175467104121765,
                               -40.009695492704864,
                               -10.059994802634131,
                               -11.510240630268152,
                               46.041480637638806,
                               -79.394749479459321,
                               -4.1678313821864172,
                               20.087292657892448,
                               -38.212105995614841,
                               -77.575476211106519,
                               20.233172664847263,
                               -48.276768739721348,
                               39.676737081531158,
                               28.596969751942183,
                               9.0004109600907611,
                               -65.591739666228534,
                               42.868949027612203,
                               -1.3220738210888339,
                               -55.312602977915908,
                               -7.1711574591858902,
                               -24.717555637660752,
                               70.099918331925338,
                               70.605422540759676,
                               20.769935044916735,
                               -64.755046150614504,
                               67.384578038433943,
                               -45.55622527280795,
                               62.418410010156549,
                               -71.200883541310048,
                               44.505708140841165,
                               15.216774479515882,
                               2.8491403348395377,
                               13.196888590610238,
                               57.008471599575643,
                               2.0142278468892627,
                               67.821361596166383,
                               11.56495560126562,
                               -2.4605948075520132,
                               -6.8905693824072802,
                               6.2296663189632895,
                               -52.501125368791577,
                               -34.195519448095766,
                               2.5049949875009663,
                               5.5312222885138933,
                               -38.971994502211857,
                               72.114728792656635,
                               67.788842679375136,
                               69.50634136471615,
                               22.152717297192645,
                               70.731056097722373,
                               19.482856001366581,
                               43.466395763501396,
                               -60.583741445085174,
                               -69.103295613058975,
                               57.542460414058993};

const double shift_27[1000] = {-14.928576548418416,
                               -31.233944892627768,
                               42.301693305954423,
                               12.500594324192891,
                               -70.402182241381624,
                               13.082337224208645,
                               -10.842718496026661,
                               48.301423395891433,
                               -61.997524298434904,
                               39.001213893417237,
                               22.248154447944977,
                               -66.74523510432401,
                               66.604553312407361,
                               69.710388931182393,
                               -5.4686185789827721,
                               69.517683355416352,
                               24.108366066186186,
                               -1.4091303212318671,
                               -77.112144018464221,
                               56.978686050379331,
                               -0.07052212446644468,
                               -57.964711452214885,
                               -3.301238970297609,
                               -58.537947152804669,
                               69.943795784271899,
                               68.039984899097135,
                               -63.971136235954461,
                               37.109128463531356,
                               -61.401556583058557,
                               -65.92885053823764,
                               78.010456962919278,
                               -22.713546472936724,
                               -59.678035303481771,
                               78.10411210540488,
                               78.597426780665486,
                               -22.401541805896741,
                               51.139339232804112,
                               -79.961341255285305,
                               62.937835250627508,
                               75.61330899348971,
                               74.666694788623843,
                               -51.343988170598635,
                               -42.963862682404965,
                               78.114552045584048,
                               -1.6981413059804744,
                               41.984040620177716,
                               54.846495494760362,
                               26.514175300967494,
                               -35.230931830102307,
                               -9.5507301933489028,
                               49.216671070881674,
                               35.888234471008381,
                               -58.920893538801657,
                               5.8499818183914734,
                               48.363165345863059,
                               -74.962702208062012,
                               43.770012424445319,
                               -11.907383220693157,
                               -2.3066967938967711,
                               -65.821739847859959,
                               33.718858910925988,
                               -54.549851597694889,
                               21.989885566064135,
                               -26.019827892227465,
                               -68.219463068085631,
                               22.793780400929627,
                               40.40044661574241,
                               1.6466469601639258,
                               77.920092112443555,
                               39.262707741568569,
                               9.2653861065537821,
                               -35.616621597165306,
                               17.003468827573911,
                               -50.011131705722221,
                               -4.0210988007009068,
                               77.207811172918937,
                               66.38513134092824,
                               -51.633307581213586,
                               5.2791469480553452,
                               46.562836782491559,
                               -29.392700372993218,
                               -72.125260444772607,
                               30.034587283734488,
                               -15.005318528499171,
                               -79.925962816733488,
                               -78.310637288250433,
                               -33.582412555169697,
                               18.207740062731823,
                               -36.085747029071904,
                               -62.246170559889414,
                               -61.16664846853584,
                               -17.570986526991941,
                               67.101831383411081,
                               21.841475522034131,
                               42.558570218059074,
                               1.6378717507638854,
                               -51.073730186677018,
                               -11.724727262312445,
                               -35.525404753628798,
                               71.259417710419797,
                               74.014550325099847,
                               34.747592405237185,
                               -17.935408929173253,
                               -8.165849746501582,
                               70.387661215042854,
                               -39.526044651435399,
                               -35.703239892085513,
                               -13.62625199421749,
                               55.106216343658659,
                               -72.551834621177861,
                               -38.954127468905654,
                               -0.12173865951274365,
                               -41.631097755805328,
                               -74.292609290554026,
                               68.520930404755575,
                               63.627155588167241,
                               -25.999423386367994,
                               -18.310661079845591,
                               44.73279333553085,
                               34.465456540360549,
                               31.166504956912966,
                               43.290466220613396,
                               64.488866094169268,
                               71.040809124616203,
                               35.761823682963922,
                               43.623993186692459,
                               -21.240527080735998,
                               -42.427420372749033,
                               -5.4974380734859789,
                               -37.98086745097153,
                               -2.8136325767107966,
                               -35.994589187177979,
                               -45.136818869799995,
                               24.547458216436389,
                               -12.978480244588823,
                               52.828044417878189,
                               36.613933289236897,
                               38.449106149826974,
                               -20.183718871360533,
                               36.736272327941236,
                               -43.345533684695404,
                               13.080726758652636,
                               19.825252445652517,
                               -30.094052472036086,
                               2.6096715993096637,
                               -33.755978060424901,
                               -17.741379009904172,
                               -23.868455520149556,
                               -57.408377706082376,
                               -18.404360063852771,
                               65.314970848348878,
                               78.124758209438809,
                               -43.487706925485497,
                               -14.926558307963221,
                               19.742305251942604,
                               13.334168976835588,
                               -30.881032202998476,
                               6.2663328894468613,
                               32.765684659554609,
                               -44.949152743555061,
                               -19.80717144134951,
                               -43.257141424311179,
                               -48.650635694812784,
                               -12.358953994461215,
                               8.7078501930482943,
                               -52.518770600354216,
                               49.643823096937027,
                               -8.6605115645582682,
                               -31.095106155188319,
                               60.678830148135056,
                               -43.474781338794102,
                               -54.917491624813238,
                               -68.497594852673728,
                               -70.888401422748316,
                               -60.742273323225639,
                               1.9156440038112965,
                               15.507592624647163,
                               31.648646162812625,
                               -25.98054860648103,
                               -62.989673059947393,
                               -45.050518334083549,
                               62.207024318371332,
                               9.8455793164324312,
                               34.509716606737115,
                               4.3195917899402794,
                               -41.922339038876224,
                               -23.172561926246672,
                               47.685420889197985,
                               -79.58452122478019,
                               -69.256225734845643,
                               36.008259778616271,
                               7.7457438443977509,
                               -35.709434104721687,
                               -35.891848044135898,
                               8.2531306159269615,
                               23.156621887224311,
                               -66.750461300666188,
                               66.361507419985685,
                               -13.053833432814098,
                               -7.9154150356842745,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -16.302978331167601,
                               68.872684733662908,
                               -57.687025038973403,
                               -35.091523140619415,
                               -10.737331665054349,
                               -57.937974587398145,
                               -68.86439123914289,
                               40.38881564221694,
                               4.9835461752139025,
                               78.827907079247097,
                               2.1757555163978353,
                               70.121787482762542,
                               -77.018136569134811,
                               -48.43165235190844,
                               63.575657425331492,
                               -8.5388843052164383,
                               -38.560937770011542,
                               -39.081791847129338,
                               50.645524442367169,
                               -31.523676210706185,
                               36.068877473952384,
                               -36.263770642931654,
                               34.552902471396138,
                               -30.396213195014361,
                               63.300818777727514,
                               -5.1759538113238577,
                               18.790091841509017,
                               13.337899852333527,
                               22.332160562802631,
                               17.722819762834256,
                               -46.148497783827864,
                               34.667246017512156,
                               16.489575098814068,
                               44.697794145049869,
                               -59.614819926512297,
                               -12.151008287679462,
                               -6.6911173153991221,
                               12.355265533720154,
                               37.169542496592754,
                               -2.7850542550480561,
                               -76.466151790930155,
                               -69.146928073646848,
                               -58.955671278641951,
                               -33.423294717570883,
                               -47.472471166525175,
                               73.106787104151067,
                               47.808507852365828,
                               2.243813910188349,
                               0.58773484919615626,
                               3.7887611182821015,
                               -23.004424991212062,
                               -11.034350521475787,
                               64.821563660575961,
                               -61.88284216244508,
                               36.619605427249091,
                               43.90167260182065,
                               -36.119783714533412,
                               -66.294570747802197,
                               -33.963854285594621,
                               -20.414088202375208,
                               -64.456540464184698,
                               40.882044314387933,
                               -28.788196732204533,
                               24.961300350728912,
                               -44.367190219928254,
                               -13.290640081535578,
                               -28.338586543569967,
                               -26.624071983649571,
                               -46.503972630683698,
                               -68.474841632674099,
                               -65.732885692313673,
                               11.113318735888676,
                               -22.855434071248069,
                               0.9519024001952161,
                               3.3032316886053348,
                               -1.6541336149993811,
                               -22.182958302933439,
                               59.648863566037868,
                               56.769588477987682,
                               56.810737592482781,
                               6.9916598490072861,
                               -29.106617635507192,
                               60.001455729914703,
                               11.122702401665482,
                               -29.351755031477296,
                               48.247574159606351,
                               -49.199719093981415,
                               76.861470095512871,
                               7.5457243121268007,
                               1.6310974205711553,
                               30.145953893998339,
                               -44.046060143938519,
                               -60.746120630590902,
                               -16.619574611954093,
                               -55.418219711838269,
                               78.747981593911447,
                               -33.451919013251597,
                               56.118961527242504,
                               72.10513856524247,
                               -32.447393488748752,
                               3.1241194407462274,
                               30.71619915501627,
                               -69.924649369130478,
                               23.199631594782787,
                               8.3707832018084556,
                               70.084165558671856,
                               22.146639540399935,
                               13.620602677125648,
                               69.20932015154132,
                               22.435832316202692,
                               39.320889031974858,
                               58.379273950488205,
                               -29.773573102008843,
                               62.724861761992557,
                               -38.419462940410668,
                               -49.133049233846862,
                               -54.10602416285942,
                               33.635767391389905,
                               -63.518876648667195,
                               22.439727533202145,
                               13.91187567033049,
                               62.01494677021681,
                               -20.221043567064093,
                               46.124730077900665,
                               -79.546674344942957,
                               -31.023488858115552,
                               -41.847754744322664,
                               -5.9976128154943975,
                               -41.248668760933228,
                               -21.856268424780534,
                               -59.094152592264415,
                               -65.479637972288572,
                               61.558307347135113,
                               -26.862426811530106,
                               56.738804349588847,
                               -77.492680325953003,
                               -21.818186081880398,
                               -9.6494522969207317,
                               77.64412553478455,
                               49.479578109099123,
                               26.363347365676994,
                               -36.380603094311574,
                               -79.180369817372778,
                               41.439939156677681,
                               69.922549599795786,
                               63.43309595731553,
                               -54.436522299497781,
                               -2.1627744274532592,
                               -6.6003305914332682,
                               76.304591158325337,
                               -3.3704872126632903,
                               -57.080011624306835,
                               -27.990980312994409,
                               72.073429022805513,
                               -43.818004924445482,
                               27.921668232261428,
                               77.941998853639561,
                               78.638314990567196,
                               10.931908460118546,
                               -59.239309720709613,
                               66.355944294951968,
                               64.613662640560364,
                               47.617275177532449,
                               36.497640331160866,
                               44.711882584935822,
                               42.833335475839824,
                               6.3382968043626029,
                               42.2623782161779,
                               -15.237811853254907,
                               -29.491155801553077,
                               29.391407850245518,
                               38.350889768392705,
                               51.650024963381668,
                               60.333985520364237,
                               79.045991777244495,
                               -76.475589466316634,
                               -67.28732048686895,
                               75.596436874114261,
                               -6.5915494782522295,
                               -78.482670235970133,
                               -59.296219202703035,
                               -1.1909144889351992,
                               -73.276254109822219,
                               -37.239111741792989,
                               20.915354388966993,
                               -12.438900469784866,
                               25.742772096118763,
                               -56.380238029532791,
                               -16.284238184693422,
                               -15.992109989054622,
                               -13.148752342989788,
                               40.186665177466971,
                               5.5323489329895406,
                               37.496761038131659,
                               -9.3773598739358626,
                               -37.559545390625253,
                               79.220857034149816,
                               34.978830846781456,
                               -66.451501779316899,
                               53.807359461376834,
                               -32.911656894114472,
                               -5.6048089630998117,
                               49.252943901072122,
                               45.331846538615906,
                               -43.937362691163322,
                               -0.66865098469871675,
                               35.498027535840649,
                               68.21522744311325,
                               -11.58371490114834,
                               -23.470554768616523,
                               53.310576995588292,
                               42.182562810001343,
                               60.175129840196405,
                               38.515817479344413,
                               43.056906180099176,
                               -47.612101655048839,
                               60.192601440932606,
                               67.500957736887358,
                               -26.950302458680223,
                               -36.837338544136884,
                               -25.933585991439713,
                               -75.888261765166305,
                               6.4825203230445467,
                               -15.037092855769153,
                               -19.071406938732789,
                               -70.365889029970276,
                               -15.368150394780319,
                               -20.58223424355613,
                               78.432821483936436,
                               -11.180840904051619,
                               22.286244316750818,
                               49.269294446466475,
                               -4.2387956121503336,
                               -78.839095816361734,
                               27.103274888304469,
                               -52.168262834132449,
                               -73.453657368079988,
                               25.160568301531551,
                               9.0355442623433113,
                               -63.833850086664619,
                               -31.085066464741747,
                               44.026944436975583,
                               61.901286527611283,
                               30.891854054906169,
                               55.476793237106051,
                               -68.774479225240654,
                               17.176723966062657,
                               -36.189008607170308,
                               59.198570102665641,
                               -71.217202297378009,
                               -39.933439310159855,
                               6.8259637254613974,
                               10.690306026758366,
                               31.824089023862626,
                               -57.479893247321471,
                               -12.898366683247588,
                               -66.145473800866156,
                               40.310782132072873,
                               -71.287091404859751,
                               14.423472472496281,
                               -61.714248136404777,
                               -18.951948122957369,
                               48.563380158546067,
                               -64.331020959287954,
                               72.144339339854895,
                               9.9384134139330254,
                               -58.291464967037513,
                               69.957754966280731,
                               10.923513304217707,
                               -43.076951517837273,
                               64.664430779527407,
                               27.868019981240987,
                               -0.45434590988565837,
                               45.891870201224492,
                               55.188803670416846,
                               -27.999030452038355,
                               -9.4321782308197193,
                               47.438676540429753,
                               29.838829943338986,
                               12.60113135819914,
                               -68.108223397268162,
                               26.985247320323509,
                               -17.835148058447412,
                               16.032943285184896,
                               -41.972685197301907,
                               -24.436545148005621,
                               71.573149086186319,
                               -28.959624629801517,
                               52.945231603534204,
                               -17.878366419714208,
                               -17.976709541437664,
                               -0.28091050758936298,
                               -28.139517699965324,
                               -74.735698406512981,
                               -68.618144482065716,
                               -70.984235760816432,
                               1.8955372842309544,
                               4.2622780103011717,
                               37.271475273551808,
                               17.670146679091772,
                               55.41243438468706,
                               49.408742682462147,
                               70.091999536919957,
                               -57.625819789569732,
                               17.995464933295018,
                               22.782327530983853,
                               67.530133204031088,
                               -16.161223889011481,
                               -34.155813150315637,
                               -36.815404733140561,
                               77.717322608879826,
                               -48.026078529513441,
                               -48.842598759744817,
                               -10.224331218238689,
                               20.55248707800369,
                               -20.334603118335174,
                               -15.638108401537512,
                               5.6212848275544349,
                               18.377100248848897,
                               10.830486946539159,
                               -56.994253938435605,
                               3.5472983623971288,
                               -64.885160177797502,
                               17.133945793647911,
                               -45.704351196829705,
                               -52.296856910398247,
                               51.056572704845451,
                               -61.93023012725898,
                               -72.254447387641534,
                               9.3272621946296059,
                               -16.71122614562811,
                               -0.087641229911366025,
                               14.68212937051115,
                               -7.4228534471569088,
                               -19.503093088292111,
                               41.391119148178028,
                               67.445967405437344,
                               70.279776228798696,
                               -3.0274130518658477,
                               -27.173904797898881,
                               46.121649055650238,
                               31.681536088340287,
                               44.51897494745895,
                               -58.222006063435288,
                               -75.775062903961341,
                               8.0410317300292942,
                               2.8940193020785419,
                               67.91391863177482,
                               -27.95647903090051,
                               -40.410935445429573,
                               19.522880430554871,
                               25.849150048163452,
                               -14.023285705368997,
                               52.600554183187988,
                               -22.252635559462639,
                               -29.721858817251992,
                               10.995051951732,
                               31.433704185455657,
                               22.521831289242161,
                               45.015552904099266,
                               7.3506899004138475,
                               61.033184086162009,
                               -71.792445114526288,
                               9.0909326299402977,
                               -1.6166732657278118,
                               78.199290195399726,
                               64.774120651229069,
                               60.602919807583689,
                               -65.66676003519234,
                               67.500426958747596,
                               -15.031758338418618,
                               -14.2785206195557,
                               8.5380773987563625,
                               -30.11904968879464,
                               26.65122093980402,
                               26.643176411664918,
                               54.642797444386872,
                               -38.726696479343111,
                               64.694618676075905,
                               -34.936309078958047,
                               71.533195769854288,
                               -34.198382859290604,
                               -6.2158798056666953,
                               -62.791136568334913,
                               -63.50798823506593,
                               5.1318797353479138,
                               62.015064152314864,
                               7.0556915033668872,
                               -0.77788805376441594,
                               -36.416599229948645,
                               57.379538490360162,
                               63.896441882698269,
                               33.875569841438939,
                               9.7360978811879537,
                               -38.61128557354769,
                               53.327294619913381,
                               -21.714992411810691,
                               -30.203372784083673,
                               17.374636562955878,
                               3.1683316915154478,
                               -48.339486074201034,
                               0.95259392057425174,
                               -3.5187660423458773,
                               65.386065020421455,
                               63.881533770678047,
                               -65.48860632514095,
                               -63.755879851956927,
                               -55.188005257164136,
                               -69.771736575608131,
                               2.5114759241471489,
                               -69.868759921740633,
                               -28.958720291660182,
                               24.77520070215003,
                               4.5052504136050047,
                               -66.700505285473199,
                               31.751963398650116,
                               78.949196471036856,
                               21.957798991500223,
                               -45.923544141914498,
                               -8.2995660447946591,
                               -78.511355799088534,
                               -15.813807064770044,
                               -51.507375773472404,
                               -40.414354371199849,
                               1.5395446097066152,
                               49.713471981048848,
                               -67.478294546551751,
                               19.528062221773371,
                               15.399576708081362,
                               74.362714913126268,
                               2.4351581960645046,
                               74.145234417508334,
                               -23.556348880803203,
                               13.857279327290462,
                               -42.280339051286745,
                               4.5175481027309008,
                               -52.90154661809563,
                               -39.108251814514006,
                               16.890912340659703,
                               14.654678231161478,
                               -51.430584950047589,
                               -29.196858260409073,
                               73.983744833757925,
                               14.472107662634263,
                               31.823658723599856,
                               -21.238083835024916,
                               76.143718433752539,
                               56.213866054761155,
                               45.22911879979673,
                               37.902515243561979,
                               5.6148530261389205,
                               61.515465595740324,
                               20.454252193013279,
                               -71.979754161937251,
                               68.662994506950056,
                               -43.72099884501651,
                               -57.329045281465355,
                               -29.557344960404915,
                               51.814843814809521,
                               -0.69103410616915539,
                               -3.8358151641537539,
                               9.4333243550119246,
                               -5.4540689350202882,
                               -54.092885800844748,
                               60.397585768104662,
                               -42.478784579423234,
                               -72.201289724685878,
                               -41.656388386554674,
                               54.581807965956223,
                               11.969460252043209,
                               37.558294883366514,
                               64.869743413025986,
                               -47.829595186523605,
                               -13.57752679684965,
                               -77.448677350508163,
                               -49.758584041663902,
                               -40.539076557725224,
                               -70.472455856283617,
                               -65.152801005532964,
                               -30.904829130635711,
                               50.344789804739889,
                               39.506572774014643,
                               -37.848468721088594,
                               -30.650760572259919,
                               41.344350883228451,
                               32.348124806193631,
                               -74.199488900527314,
                               55.034400989146249,
                               31.800569580924272,
                               66.72790220890424,
                               -37.986420656594618,
                               18.315993167101364,
                               27.562108822718379,
                               -51.802530451324031,
                               77.644235316313242,
                               -4.5797467679185146,
                               30.703557790411715,
                               30.977300473968675,
                               -26.262997016532111,
                               46.214613539904903,
                               22.774495381836186,
                               -66.237892399987132,
                               22.730755627492378,
                               58.826793356852214,
                               -21.56842061983798,
                               55.111934186481619,
                               -26.689716946025413,
                               28.594880168435004,
                               26.66506730815874,
                               -12.698829114400702,
                               -15.136291063715278,
                               -41.881512659284127,
                               -7.3380374102061339,
                               24.694552071376414,
                               -58.959673016458353,
                               45.55211986112738,
                               44.594752949846836,
                               58.521491049618632,
                               -4.295446751102789,
                               -74.500988324030587,
                               77.309419121478101,
                               -19.48441381086041,
                               -34.799709228555542,
                               13.787525035280225,
                               22.746800399569853,
                               21.57269680940853,
                               70.138230049208332,
                               -65.078576042361107,
                               60.468239190768934,
                               -59.086173986746481,
                               39.404204188263179,
                               2.6538786151363816,
                               45.187489091662329,
                               57.379730772778963,
                               -79.132769425415177,
                               28.779787493063644,
                               15.595736268454043,
                               -55.103960890732566,
                               -47.912155806310743,
                               -72.526935854751741,
                               50.625128292696928,
                               -14.348542546191457,
                               -24.116214834196107,
                               48.903169115565788,
                               -61.729581998470763,
                               24.509111190694732,
                               -69.429629335798396,
                               -54.838462762218519,
                               69.628351933167338,
                               24.66381667304444,
                               45.165314886766375,
                               -31.262847263580774,
                               -76.268937947533502,
                               -33.639041598344321,
                               -5.8754191470451982,
                               65.814693213645,
                               20.160487427266361,
                               -55.262171724891459,
                               -17.699622220826146,
                               78.211410478072793,
                               55.287548947941808,
                               -68.048922254269485,
                               11.825681746083847,
                               77.530185670972244,
                               -24.539528490583429,
                               50.860962972743536,
                               -3.7634872256797198,
                               -61.005566536850495,
                               -61.026677451110025,
                               -50.326107785866874,
                               -58.991672905889189,
                               -26.996464348675271,
                               41.03512136605309,
                               78.909932038570062,
                               -45.59856743735039,
                               -43.175153426661367,
                               26.45119895046021,
                               4.4288885534452653,
                               -36.479420878100157,
                               -11.237836324320243,
                               35.793686092075212,
                               13.152579560160875,
                               65.849950287998638,
                               69.043665572289669,
                               -11.100402887986325,
                               76.541597652949079,
                               2.8643938854676865,
                               -41.564227396069583,
                               79.227777460851911,
                               63.983820774087278,
                               10.329182068248251,
                               -63.131279511207637,
                               -6.1802641967203868,
                               72.410064339004578,
                               -28.624842133451899,
                               -57.77873562414392,
                               41.983697171942964,
                               -74.320237961364484,
                               0.16287291669353721,
                               -59.899092306110546,
                               40.593222861880946,
                               -36.104454225803835,
                               11.239721542813236,
                               -76.060983826111737,
                               39.243140566460596,
                               45.08762453519283,
                               57.013153316234607,
                               -70.935233923390797,
                               -24.195451429557597,
                               -52.213141795923697,
                               -25.550130272255192,
                               30.958336377247697,
                               38.345417879396784,
                               -19.603748121511209,
                               4.1759983331853743,
                               9.4591002480470845,
                               -79.108085597925694,
                               -78.292390888131536,
                               75.473646651035537,
                               -49.462866886851181,
                               48.775866118753449,
                               17.073148771952628,
                               61.066302447891999,
                               54.301439817418526,
                               -15.971923941690378,
                               4.9132012611523788,
                               41.33138351431829,
                               51.510177115014166,
                               38.590873147187239,
                               44.77453596660542,
                               -69.757513179345949,
                               -54.196179415868592,
                               71.514170595016068,
                               -35.062052489211325,
                               6.5036735622958073,
                               -37.892212800364234,
                               -35.50765288094275,
                               56.373152064286359,
                               -68.193978672175817,
                               20.277648357810101,
                               10.213329407252131,
                               62.55585352211633,
                               1.5197247408818839,
                               -65.374554683619294,
                               34.10083809749672,
                               -63.278812807456987,
                               -47.015217971395117,
                               -69.953079928027989,
                               26.906082024507327,
                               -62.777281106496176,
                               -49.682512968381687,
                               -68.999054930853788,
                               57.100279596534051,
                               35.392392876746655,
                               12.148362249835184,
                               52.255077108329083,
                               55.657894321366285,
                               49.934141681300183,
                               -51.950116104511714,
                               61.862795095891322,
                               -34.289408040648986,
                               29.043015780651153,
                               69.251943814650161,
                               61.95518583300148,
                               -63.041589652950073,
                               -21.497810882435768,
                               -44.586647295785639,
                               18.727482038843814,
                               46.832225818082954,
                               24.547406270012971,
                               53.574862238987457,
                               53.545371731565197,
                               71.049255974304032,
                               -44.135609336012031,
                               35.513015371137591,
                               53.217508407991176,
                               -49.209070465963876,
                               -21.057053535655484,
                               -63.518060066588028,
                               70.867480611963572,
                               -14.787359686979569,
                               -57.570529927250661,
                               44.269812095383244,
                               -76.211758381101816,
                               76.650731612398502,
                               -59.183923383426098,
                               -7.6635992443130565,
                               -65.031569880565613,
                               45.646737797660364,
                               46.635027087375128,
                               -69.467701049774433,
                               -77.144359364911452,
                               50.892614158271996,
                               -6.8817227023521959,
                               55.698817307008127,
                               43.084716607465772,
                               -5.9410316454925258,
                               -60.083376118434899,
                               -53.44545583320167,
                               -21.43096762015756};

const double shift_26[1000] = {-77.538973909795828,
                               -66.718765220722176,
                               -22.315358094832497,
                               -10.395271289137332,
                               44.712185542319119,
                               30.446801908527025,
                               -76.112475985253937,
                               46.091551068219417,
                               -11.112604763086098,
                               -38.458626947577919,
                               -34.224814574338609,
                               -39.78770995474931,
                               -78.47550596785112,
                               -74.269070241985872,
                               22.384408428789499,
                               10.36092987666974,
                               69.809126650946453,
                               -45.310315708037741,
                               76.154799130640569,
                               -33.055120255428847,
                               -55.438068324599918,
                               53.686552751889629,
                               15.680919684436128,
                               -32.885652341462951,
                               11.729459608724408,
                               -72.619952296468639,
                               47.651013306083541,
                               -22.60708364513965,
                               -39.084463631053531,
                               -43.64647421660851,
                               32.994130059067516,
                               -16.670901427217213,
                               -17.643019931501097,
                               -19.05942177445452,
                               71.406228098956305,
                               68.755872491132834,
                               5.7018335257213533,
                               67.529996910142302,
                               33.881294810360423,
                               -37.42035422934363,
                               20.383354998177737,
                               -44.539439780831174,
                               -12.427536306113776,
                               -12.784065832479119,
                               -63.000510382770528,
                               -27.802783159213583,
                               18.0058371381363,
                               -35.280083096762695,
                               -69.298500308923266,
                               57.892106823087985,
                               -73.408713222373507,
                               13.680534534997337,
                               2.1251469786149304,
                               33.367421027049502,
                               -10.596542185864797,
                               -51.177030233682487,
                               -12.175454823593485,
                               -62.9736193669684,
                               -60.826390667582729,
                               -75.62552764989772,
                               -2.539648256188185,
                               17.805902961824152,
                               67.30168184310827,
                               40.502287440633651,
                               42.77793392500412,
                               47.091747302543382,
                               -71.775690280694548,
                               32.903979798246105,
                               37.192795480243831,
                               45.34012055797902,
                               4.5013891386005227,
                               46.478410332212597,
                               77.970628450470613,
                               -40.219648172857589,
                               -2.830558322214296,
                               -46.56109099680603,
                               60.649304814895153,
                               -60.881484466377842,
                               14.995129208382624,
                               55.727077340093899,
                               75.217261872089637,
                               22.721656518510748,
                               -32.653959057957898,
                               -62.453974031305961,
                               16.046203921529795,
                               -5.3993540301948979,
                               -51.13976018146743,
                               18.716222751069772,
                               -78.928201107997396,
                               -12.160726671974992,
                               41.416983510813886,
                               -52.491945611258387,
                               67.791907954723229,
                               -43.533762405155478,
                               -3.0858217367827674,
                               64.894923350414814,
                               -6.9869357311950058,
                               -31.176349579915986,
                               51.229691047578527,
                               -59.514531947600538,
                               -48.611281284722914,
                               -52.858239253592913,
                               16.309321547570971,
                               43.143187730763614,
                               76.481675499556701,
                               -22.08790693686683,
                               23.823576902795637,
                               -63.307070457998364,
                               24.888134709183632,
                               38.374342829969585,
                               -25.925401322492888,
                               -12.029658353017144,
                               66.939924583280117,
                               49.627558702737005,
                               74.544616038097786,
                               58.197169223121449,
                               -37.98756743592763,
                               44.867960650473485,
                               -59.687999831842831,
                               -16.841772294015314,
                               -18.325078792031796,
                               73.194391168159171,
                               -4.5224450171144284,
                               56.915819677626764,
                               -65.705699493909407,
                               74.801063808676844,
                               -33.626788698072986,
                               42.851586031032568,
                               42.956379138887641,
                               16.135587711064954,
                               -16.711245271431103,
                               -33.084906252850054,
                               21.748489110611082,
                               38.469960523803323,
                               21.143870523541622,
                               35.52048315369332,
                               71.009337677619612,
                               -62.869467274425276,
                               75.089966368370582,
                               42.892403136008596,
                               42.481646187806547,
                               49.419305801354369,
                               -48.619565414666937,
                               -37.261209602694535,
                               61.246139319623936,
                               39.999187316646299,
                               11.513152396046724,
                               -16.406861280576663,
                               -56.266598601299023,
                               75.865504911690735,
                               38.979746768131321,
                               -18.403358421555616,
                               69.001542045485792,
                               -58.522513461003086,
                               -36.870844994087413,
                               -2.3157428733886469,
                               -24.017272728646951,
                               41.314380334170835,
                               61.07060512972194,
                               -55.599966192519112,
                               -51.828413303098692,
                               -49.935741386879052,
                               -44.904080080303189,
                               -62.122019007374313,
                               29.287058227299937,
                               22.161214060275736,
                               59.225691832200702,
                               -13.663166531241322,
                               77.838986817400709,
                               77.286914795093111,
                               -2.6120442527550622,
                               57.203323160203013,
                               -66.922603939452742,
                               -13.803674695751726,
                               35.130569428600964,
                               -52.819663778098288,
                               -75.349439438919461,
                               16.737239906041019,
                               -53.414516309180293,
                               -20.889852136701251,
                               24.286674693907422,
                               -67.658772578213785,
                               -77.138741261214108,
                               -77.821270213986963,
                               -77.2035413714963,
                               65.788619563332105,
                               68.15052849786197,
                               -8.0029139504066471,
                               68.444360022413235,
                               28.20778905957679,
                               21.368992650657376,
                               -78.071949520116092,
                               -9.116204039303959,
                               53.510731294085275,
                               -36.241298500100726,
                               43.500943429518344,
                               39.764910325828176,
                               -39.868187628546046,
                               -1.2601111090505039,
                               -25.465809428047319,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               2.0252210197949037,
                               -42.66340169681262,
                               4.6432351452892373,
                               -70.02795546556132,
                               -49.849349539791191,
                               37.000205535786669,
                               -30.918836916970939,
                               -40.141510992251831,
                               44.648699025795715,
                               74.435782218859373,
                               38.954813969878927,
                               79.725746953514687,
                               55.079240317514824,
                               -22.558982185727448,
                               -50.305915469473248,
                               -22.050860913017058,
                               -27.988040323991367,
                               48.390531490700432,
                               52.013680686420905,
                               -6.4146703068619626,
                               22.237345999197469,
                               -20.887184563210681,
                               68.318769624461666,
                               -11.527449600995514,
                               47.330808602583083,
                               59.181160838609827,
                               8.5717316649633037,
                               -34.829353426841365,
                               -54.416507256404806,
                               8.8820986246488189,
                               -54.348187746833915,
                               -48.766950167162143,
                               -64.375052356986629,
                               66.46413728156665,
                               -29.16774330392068,
                               -36.052689326028926,
                               46.625232960342544,
                               61.387498542045073,
                               -12.702208350121508,
                               -54.154513976840619,
                               -8.6209076817810004,
                               -10.959062089531747,
                               54.852015372876593,
                               57.551886111761775,
                               -45.144652835451637,
                               10.913031536506132,
                               -10.128975069165065,
                               -9.277693432960632,
                               28.639053598143569,
                               -9.0680273083341678,
                               -35.989273442022395,
                               -51.270086993961712,
                               -55.137054112497736,
                               -5.5599815395721759,
                               5.3247895676937684,
                               24.131859147408861,
                               70.167994657608659,
                               72.675107984062123,
                               -10.296355681068322,
                               -0.99819146033925499,
                               72.516193564870292,
                               -0.49464116618525367,
                               -23.505156732957275,
                               66.666598500150897,
                               70.061230143156735,
                               50.67201917479197,
                               14.281643764821549,
                               14.897167779008678,
                               26.054750433008429,
                               -56.926799652495774,
                               -66.628944988428046,
                               -14.852050503874743,
                               56.463523932595777,
                               -60.170496864882722,
                               -40.235368793353949,
                               63.793643751886229,
                               19.748445682445656,
                               -23.913284396793877,
                               41.242228658589283,
                               -45.232170167854214,
                               9.6937669821424208,
                               67.78038763408847,
                               -1.1370293555994966,
                               39.004388482132597,
                               74.753947316052788,
                               -64.837178249658621,
                               -33.230492726396534,
                               32.7802462886076,
                               35.426923462144792,
                               38.070193642934342,
                               -33.973810234740597,
                               -45.410334340011076,
                               -25.490390687591535,
                               14.385981782783368,
                               -57.487833534357733,
                               -50.429922660660331,
                               -65.241494432010995,
                               31.916009469346541,
                               19.870652608186383,
                               -70.060933483269508,
                               69.184976497879248,
                               42.833280569197626,
                               37.556954729120349,
                               53.409009718654382,
                               15.753024015408508,
                               -14.338963477582306,
                               44.897065412828596,
                               59.90963487993919,
                               -52.765783811340015,
                               23.412969076149523,
                               8.376326968296981,
                               22.115354926985265,
                               24.624222723423511,
                               -39.37717510511429,
                               40.51771754673193,
                               -67.040850958866756,
                               22.358733233588687,
                               29.192457993931257,
                               -32.059703828365123,
                               52.70120865990696,
                               -11.749695781523542,
                               -77.663343602554306,
                               16.859804765158536,
                               29.25495339524813,
                               70.789778744849571,
                               23.718976620119598,
                               56.353603097695554,
                               -61.267728243627133,
                               55.680269299133883,
                               76.549770320267697,
                               -34.914533102910951,
                               -74.210365579651452,
                               36.732062337740686,
                               -2.8950651229032083,
                               8.8201176078864236,
                               8.3914063346454348,
                               16.86993736063841,
                               29.652662366144419,
                               -55.762297314956037,
                               -21.434617150513013,
                               -66.933801495491807,
                               -69.83250136177594,
                               35.833222031983205,
                               7.9861908362759877,
                               21.686518662683866,
                               16.451143425747134,
                               -67.753027348199296,
                               42.703558770124786,
                               53.132564241126566,
                               45.433498860787637,
                               49.297096926384569,
                               -36.937700861266961,
                               -6.6046459609244721,
                               11.213707364392207,
                               58.515041063336071,
                               58.940773473003837,
                               -59.559024939896823,
                               -76.902048277483914,
                               40.019356130885541,
                               31.661518620315341,
                               54.336249832526036,
                               8.3877587552585613,
                               -51.405336543267566,
                               -25.283906562457574,
                               10.654230830699477,
                               -8.584399753403936,
                               -41.950407813352363,
                               -19.852562246614198,
                               56.336251053881121,
                               50.483861133096667,
                               -27.055604876448804,
                               7.9785740021631621,
                               40.710082467963971,
                               -73.753570105656721,
                               -79.763912026367493,
                               8.4043096831263533,
                               70.083721886814914,
                               -15.721809201113437,
                               60.233637924941128,
                               74.077085894065448,
                               -64.803768074001255,
                               10.278001345304313,
                               72.711446127836197,
                               -5.9639541434719785,
                               62.670741634001885,
                               17.506055312892254,
                               53.989762209488617,
                               -77.899452489700849,
                               -15.808185884808003,
                               -26.305370972899638,
                               8.0387515604696649,
                               -5.1015663023417162,
                               -78.597700443275428,
                               -3.399184502927767,
                               28.24172866079558,
                               -3.0036418851484203,
                               3.0063778977512037,
                               9.3567557860152846,
                               66.03308429397751,
                               -44.835797846331232,
                               50.982214499682527,
                               -11.394588739684083,
                               -41.720187867675762,
                               -43.562111972472003,
                               -26.517025653972119,
                               64.108511060288947,
                               -9.4328256048232877,
                               21.77050407700979,
                               2.4786473314093502,
                               -30.733676171153483,
                               21.815831020703449,
                               -61.973386971827033,
                               -9.6261269737674393,
                               67.005858038316717,
                               -38.16952367041425,
                               -33.630897246990145,
                               51.101668812922334,
                               -60.288380667608166,
                               -24.848865594664268,
                               64.511031787584486,
                               64.447323708476674,
                               -0.65988924870330479,
                               42.189986979075023,
                               -30.595379629498467,
                               -26.302569929723159,
                               -35.4998135322558,
                               -68.36558113474166,
                               20.056364488338197,
                               -27.204677886886682,
                               -57.956043236807652,
                               78.379463001510643,
                               -12.695385273468117,
                               66.178940827022984,
                               7.795771492986173,
                               -1.8835758295992342,
                               25.560184407633976,
                               -16.131084537877914,
                               39.47660439129622,
                               62.217689487545066,
                               16.597031494894743,
                               54.512913478547013,
                               29.123984608876469,
                               77.21481419053211,
                               20.406709087651834,
                               0.68352876576428834,
                               68.456461622093116,
                               48.261655787518301,
                               23.681952160240733,
                               39.953102738509877,
                               0.9346551341038154,
                               68.543315808300093,
                               73.003745903070723,
                               -73.597098495782006,
                               -38.939121822840242,
                               73.151261527966597,
                               45.654888002691322,
                               -73.076145043218943,
                               52.454011758700339,
                               -71.002486551522409,
                               -39.502184665456909,
                               0.61311531420436793,
                               51.054175484142206,
                               36.876301683933605,
                               20.474406983940277,
                               -52.234756265870558,
                               -43.287593495314951,
                               -49.995225114108429,
                               22.751169046788654,
                               15.479055752970545,
                               31.038031004977082,
                               40.504227987903057,
                               -44.065996235705541,
                               16.469185797563114,
                               13.223477419512539,
                               -25.756483767130931,
                               -24.468199576305661,
                               -1.3145309886526828,
                               39.076243979203817,
                               -37.140755356466187,
                               -1.2011806366570799,
                               47.08572165243811,
                               -22.748534300604415,
                               34.182321481380093,
                               -18.817861602164751,
                               34.032222297882804,
                               15.257994087916519,
                               9.3517287175792649,
                               -54.241627673319243,
                               62.492709924514294,
                               -69.163519931471271,
                               -67.154410634752168,
                               16.925244034844432,
                               13.940194243519294,
                               -56.531385514015128,
                               59.50940695648481,
                               54.698046308851438,
                               -23.304703502502484,
                               64.263607928223536,
                               -73.58211461611485,
                               39.047621866542755,
                               -9.4867754696960951,
                               65.228059753380052,
                               70.584555338756147,
                               -58.747699993630235,
                               62.404449066927782,
                               -46.405723152614179,
                               72.287650312118217,
                               2.6542579533654695,
                               55.101956697405498,
                               -55.1931697805434,
                               59.001561944524056,
                               58.733772341314207,
                               -38.078217449989978,
                               26.314311829482737,
                               2.6268770062605427,
                               -53.795051325515168,
                               -61.395733896957623,
                               -66.244763932376856,
                               14.179650918010083,
                               -53.102249242333926,
                               42.929046541286858,
                               27.788067306718595,
                               63.366110400258975,
                               9.5385468758404812,
                               -54.052702364301027,
                               5.7344060243666277,
                               31.356492470788872,
                               -0.61421394001775198,
                               23.734607527548953,
                               -29.995137211152986,
                               -5.5939489057492935,
                               59.177771997931011,
                               0.7673307426039262,
                               -72.986569767463095,
                               -73.943188201429365,
                               -70.172911595491286,
                               -34.411640797047106,
                               -65.577273520608486,
                               -25.962741352849484,
                               13.610394765007632,
                               -16.095000112634846,
                               0.40618528430333356,
                               -76.15388929685075,
                               38.713662762078542,
                               42.251829195500164,
                               -15.378082714197875,
                               38.878307773556109,
                               3.931529439692838,
                               -0.42075665668406792,
                               23.071357587979179,
                               8.6844697580017858,
                               -72.291226867571325,
                               -38.459848987987634,
                               68.262953845520315,
                               17.237164602587583,
                               -42.612400340669296,
                               24.932196644705336,
                               8.8253237120633568,
                               -26.556123829788966,
                               67.389184188639817,
                               47.169635779927503,
                               42.403751021793255,
                               31.604694368359617,
                               15.570470317426144,
                               -78.72072474456246,
                               15.805636384751526,
                               -17.847815687312448,
                               68.476939716346223,
                               -22.886489105493297,
                               -64.647190920639048,
                               72.404058946552894,
                               -61.720934995983889,
                               10.639508286551784,
                               45.259688110206326,
                               13.990680712993889,
                               76.719972925718267,
                               -31.602521253349401,
                               7.5393272425830826,
                               -29.895037069501775,
                               -69.310074218285166,
                               -63.834169934578043,
                               40.734606179130594,
                               -29.504060207852639,
                               61.363132387838306,
                               -4.0140683288143624,
                               -26.10403673375275,
                               34.657870361632391,
                               -18.544074999289649,
                               -28.305442623707187,
                               75.181962771510015,
                               -30.600414919295339,
                               -30.077437600752543,
                               27.316002195483655,
                               -31.284462686194679,
                               -72.182087368716253,
                               -40.101650857141209,
                               19.447930059977764,
                               -10.127812786606984,
                               -44.196812899200324,
                               67.366827829092216,
                               30.806804495784242,
                               56.317224787469655,
                               -12.041074019078604,
                               68.879738721428041,
                               -47.683808619357066,
                               12.784988857434186,
                               3.8001823556702963,
                               70.668336814711211,
                               -75.313175053696966,
                               14.370756991546202,
                               -52.757481372320527,
                               44.828179887568574,
                               -29.503949489743462,
                               47.682219627350136,
                               62.003376406103662,
                               -9.366280207619436,
                               -75.900972570953655,
                               -10.841105946105561,
                               -79.43515952084519,
                               32.656519107419186,
                               -70.482156774485517,
                               11.664753435735506,
                               -16.153760262651929,
                               -74.977409412261267,
                               -41.629401966232791,
                               -24.744903018019215,
                               -51.731239480168824,
                               73.873196641129041,
                               15.869277271489647,
                               -4.938359371095677,
                               10.042357540332439,
                               68.893015425296568,
                               58.066009891699451,
                               -54.343331782057014,
                               46.397529619480871,
                               -24.194048852061478,
                               -58.38286401889173,
                               0.078086389105658682,
                               -32.016379023453382,
                               75.04343640553617,
                               -52.711664161291822,
                               -49.739661417888072,
                               -33.223179817788306,
                               -62.416499477805516,
                               -72.249776441228278,
                               -71.527189194008187,
                               -51.338576646860169,
                               79.12516191656988,
                               -27.859173549418905,
                               -47.969207253890232,
                               -9.0930501136650843,
                               36.237577564217247,
                               53.617437890091608,
                               -68.471230722700653,
                               39.332814896837824,
                               -68.058096896834115,
                               40.76907057702811,
                               -20.765648174905849,
                               -41.697178956307489,
                               49.162140996033706,
                               -38.124280510232765,
                               77.710973364322768,
                               15.776903438749445,
                               -72.606189104312847,
                               50.231345566759181,
                               -73.911739197213194,
                               17.644214826749263,
                               -39.867966960375909,
                               -61.278429354732822,
                               -32.608060664581622,
                               -57.85358471042268,
                               -75.414573643214467,
                               -11.525405789062026,
                               74.556308223245807,
                               31.973696422867356,
                               36.408247709115408,
                               -59.325813688578791,
                               73.153599286642986,
                               67.951226695730767,
                               26.220606165391544,
                               -2.6588522835874215,
                               -2.3278812509048858,
                               -48.057222273285795,
                               31.682967328601343,
                               2.3637677858936961,
                               -33.501589854145507,
                               -18.132418557663737,
                               4.9151693042670708,
                               -44.148591463340878,
                               -47.839702871869385,
                               -5.3133820015407522,
                               67.025874420481415,
                               32.228757300394484,
                               28.410942394839005,
                               64.537490633191595,
                               -74.889328010177664,
                               -32.173428466716494,
                               59.135964615734096,
                               -17.850229664840342,
                               -10.198326835486599,
                               -24.181931560004635,
                               20.15842024780434,
                               -51.631098628676952,
                               16.098471892979365,
                               -77.730938064784937,
                               52.505426658547577,
                               -58.516443970083856,
                               -78.710923185217112,
                               -16.648278068671914,
                               49.671377836774262,
                               -69.777220029124763,
                               -66.71018315813717,
                               40.69881710460281,
                               -51.105319811257367,
                               -72.209627218052944,
                               79.204184295496461,
                               -11.792350308430697,
                               -31.572434093895009,
                               33.856559016453197,
                               -75.042866090697004,
                               14.943042869886799,
                               -47.539422321125343,
                               -56.813800140014358,
                               -52.507523265607446,
                               48.735271245865938,
                               -11.246360787999958,
                               -0.84986481789917789,
                               7.8260691229583585,
                               75.944332397404949,
                               -66.502189589580667,
                               -66.755997890168487,
                               41.486707064772816,
                               -57.168151068307033,
                               28.080806357227971,
                               56.673787525990313,
                               -59.627516300067832,
                               -8.2508167285889638,
                               -20.801764166757593,
                               11.679147243595459,
                               -5.1123972412397105,
                               68.799410212840741,
                               -21.063300712558366,
                               4.0339770061146307,
                               -74.761220613844955,
                               64.713968233229878,
                               55.691118952951619,
                               -44.055026231100967,
                               -60.751770246997324,
                               4.2297647174667929,
                               -23.11075844445346,
                               -31.006025330091575,
                               58.07174741967961,
                               28.185567724521455,
                               20.817671786908299,
                               -50.388211846153226,
                               -22.974511902484601,
                               5.5936212989450045,
                               -0.36286967763054179,
                               69.496111906856044,
                               -18.025853016131915,
                               -25.637644501360995,
                               -19.100651488730101,
                               -78.77431099279022,
                               -45.414080406193115,
                               -13.821790409329937,
                               -59.165219762521723,
                               35.392733325026569,
                               -79.100531692263758,
                               -7.1732719810021877,
                               -4.7027546118761983,
                               -47.848004441898524,
                               31.775964437304371,
                               -53.886692628269948,
                               -20.798502326347041,
                               68.919865898137914,
                               18.2614309898754,
                               10.976481961349876,
                               50.616947102395898,
                               -74.285926149654102,
                               46.234865385173549,
                               -45.314756665189051,
                               50.916763653838032,
                               52.162810465791964,
                               -43.117413734856292,
                               -17.177485486423137,
                               54.599047714645423,
                               -8.0055956393662875,
                               69.871537358660447,
                               2.1195940131593076,
                               14.841739701811566,
                               67.307482455180576,
                               48.23648701606848,
                               -56.473188664293637,
                               -67.194393792837928,
                               37.347387138024558,
                               -30.1626355486585,
                               -58.029731725873106,
                               -55.887496911596159,
                               -60.720475687253945,
                               58.724960312321464,
                               -33.979925179451911,
                               4.2235305734947772,
                               50.268732027850504,
                               -25.049970257920386,
                               29.545566433877308,
                               -60.508283780256406,
                               54.045567226738861,
                               -24.854456957292758,
                               79.933099547639898,
                               -65.42351353710751,
                               -4.606033865513961,
                               8.5104052027035468,
                               14.120079132553791,
                               -12.301732137891435,
                               -30.121355945004662,
                               23.828302642043514,
                               13.502849921338115,
                               69.944088627334892,
                               -13.555442024190093,
                               22.464292160317658,
                               52.400156678802517,
                               -58.779115903229922,
                               -76.427583471396105,
                               44.514440605935235,
                               27.707217515444228,
                               38.899597070601871,
                               77.525761516966767,
                               62.631868512873311,
                               -7.2374839290812254,
                               55.025891286583516,
                               26.34501330086897,
                               25.148169072484624,
                               -2.6363429203853883,
                               59.610820869879298,
                               -32.437020798574778,
                               -3.3219920981646354,
                               -67.153143506901813,
                               -32.665796528733615,
                               -65.50002669577735,
                               -79.969247159145098,
                               -38.775377715486002,
                               78.961343863255806,
                               -27.612049391904755,
                               64.786318550933998,
                               -1.9122848790964575,
                               -45.394113375786361,
                               -28.803093581962798,
                               61.638012594418036,
                               -42.677007920865478,
                               -72.761787735321604,
                               -63.755332677340562,
                               23.447064748152425,
                               -23.899538862320185,
                               58.13497128175409,
                               -23.001086040593904,
                               9.4265376530271077,
                               54.740382888666922,
                               16.700908426407779,
                               5.9686382340972468,
                               0.77947968006695056,
                               -77.885912465420063,
                               -75.42323604810187,
                               -1.2139234978483149,
                               -5.3421543405699641,
                               -34.837589199155396,
                               78.800064946754546,
                               69.781613273360875,
                               -60.772413732113982,
                               -77.247230210000765,
                               -21.177862074175074,
                               50.462632251406625,
                               76.264276383494376,
                               -37.085640854820625,
                               55.759244203975115,
                               -51.511761139368318,
                               -64.232694074742142,
                               -43.251259561840797,
                               -77.250590896576156,
                               25.123581769175637,
                               5.9296951141364023,
                               -19.915640831162818,
                               -42.695360706225514,
                               6.7931869882796025,
                               3.2949242265007612,
                               -58.10208799005278,
                               42.965049950861086,
                               -73.167969144787918,
                               -37.500900289930485,
                               -51.88534471271872,
                               -52.223764580146707,
                               53.630921391566559,
                               2.3172264959198099,
                               48.39333933514078,
                               45.399203769313445,
                               14.618632274693628,
                               22.10852934262418,
                               51.512011796885716,
                               38.962108365728518,
                               41.337540836309003,
                               2.5904222864628679};

const double shift_25[1000] = {19.419107570137005,
                               57.395917904260216,
                               77.132261791857971,
                               -53.908388106105662,
                               66.359595956285233,
                               30.293728030609302,
                               36.400677640773957,
                               -70.7101050647519,
                               -44.287893420348084,
                               -0.11600154318154132,
                               36.748562131159765,
                               -79.348826732315487,
                               -78.490269419336315,
                               22.748573073008497,
                               31.38552482647064,
                               37.176015513676802,
                               -5.5149711988954149,
                               -62.951434590332411,
                               18.664759499065504,
                               -7.4662022205906418,
                               -5.2806587570594008,
                               71.429876438698003,
                               -57.034015033426428,
                               51.478462841809772,
                               -0.86003994523603922,
                               0.67467867847950558,
                               -18.457781047307336,
                               -76.659353666041895,
                               39.630069978994506,
                               36.474124230247185,
                               5.5591745044207368,
                               -33.671967800792771,
                               47.513350841452905,
                               -64.616966231714613,
                               -60.054050654901133,
                               -25.49984406966017,
                               77.867300347166918,
                               -64.965254459636597,
                               73.408214602530023,
                               24.167556911666324,
                               32.764330519914985,
                               6.2001899065563233,
                               -21.91876765326564,
                               -20.164470286190344,
                               -5.2597336154883241,
                               -28.93949680284555,
                               -45.856542309149049,
                               -69.976408169743223,
                               51.482890588555534,
                               69.735022493135048,
                               -14.773998229614737,
                               -67.844993034829898,
                               -75.323530995278546,
                               -7.8499909676581634,
                               10.255717644358951,
                               -2.6063475354919863,
                               24.952637864147746,
                               -10.021926714039356,
                               -70.302566027395187,
                               54.001795410113914,
                               44.554474883543755,
                               -26.773557733043404,
                               17.158019987178594,
                               -39.606582711696383,
                               46.392833624042638,
                               68.849970198658596,
                               52.98876499139427,
                               7.1612757196767234,
                               48.894388349984013,
                               -68.814879204526179,
                               70.299713833480013,
                               59.388888130246805,
                               33.027916060940576,
                               29.543630974762578,
                               -62.363527116120174,
                               24.292028710621416,
                               25.084673173330401,
                               -77.633827612739921,
                               61.232666318025274,
                               0.60546074408666151,
                               24.297092596188897,
                               41.718960258640543,
                               59.484974804582947,
                               46.08966868018527,
                               53.132113034566686,
                               33.845385397634146,
                               27.258415788447778,
                               36.407487797301783,
                               9.4852330276663519,
                               26.451531951623622,
                               2.370608949662719,
                               8.2794781903610826,
                               -54.910187394518388,
                               23.283360672657636,
                               52.953349831815693,
                               -5.7083739568679555,
                               -77.394345950011243,
                               79.155126053675815,
                               15.419245904028781,
                               -25.18864597144043,
                               69.225294450498026,
                               66.476824497906279,
                               34.006706819926833,
                               -26.886843620323859,
                               30.419442275472466,
                               -52.243252465100646,
                               63.084340877167165,
                               48.661371610955669,
                               42.164622343152715,
                               -61.032406756275222,
                               9.9581742741474919,
                               -58.730232947947471,
                               4.781686944571506,
                               -70.369956544963728,
                               -60.050664681510767,
                               -46.961269158080874,
                               16.049949829739226,
                               19.855658594180071,
                               2.2199581789146077,
                               -78.406005073249929,
                               -48.18739388450323,
                               12.471732343624682,
                               68.801833857216636,
                               -51.952776445025677,
                               -32.429870674759883,
                               -17.415713149330848,
                               -69.962290444318086,
                               70.311535712658483,
                               -71.731679910071435,
                               61.591616021498233,
                               -30.140472804629411,
                               70.911177528590628,
                               53.834415236277678,
                               -18.548443736905625,
                               40.555561896687593,
                               -9.1165940110797159,
                               22.673265918139002,
                               65.491742992316631,
                               58.787873129205963,
                               57.524687173515709,
                               26.183100190720154,
                               -30.010335297436093,
                               43.95417556616303,
                               -55.385444109100696,
                               -77.071690921805327,
                               -69.450519582064587,
                               57.849946737447709,
                               -63.5179200436122,
                               31.187850035729351,
                               -67.998560264183311,
                               -30.168966071667239,
                               30.82936232650718,
                               28.899034331739607,
                               -70.510547636082123,
                               -65.802774728770785,
                               41.339943663794358,
                               72.443939514253046,
                               -50.6689023062602,
                               -53.160532693139366,
                               1.4916797891206137,
                               9.3766518829301493,
                               21.648093616542155,
                               63.508932781862583,
                               17.872645117000708,
                               51.799705793633279,
                               57.451223016048274,
                               73.468302763190195,
                               -33.927088132902327,
                               -48.245716229908481,
                               42.845647950291657,
                               -41.851571841379076,
                               -70.200427946939854,
                               4.2444480719389777,
                               65.914738520065342,
                               -67.362887779710292,
                               -59.030390965230673,
                               -53.181134109053161,
                               76.775305455713166,
                               3.2034532787677286,
                               62.029040354409005,
                               15.713618605171837,
                               -63.072394800521337,
                               14.95767478494254,
                               -2.3217288339494715,
                               -1.8990225223633068,
                               18.114010816066262,
                               72.643508834410625,
                               48.427363960740877,
                               -77.593028344830259,
                               61.875724778907568,
                               61.704852531286022,
                               38.708893177714842,
                               -43.61647455336302,
                               -67.533692926211458,
                               33.250695487293918,
                               -28.445515012387716,
                               -24.608657032712582,
                               -57.575356709997308,
                               -41.168027877116856,
                               -14.05053423912234,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -67.667812074628088,
                               -64.057853402604437,
                               -42.163603977245906,
                               -42.078330468578145,
                               32.005849980212894,
                               -64.421135883925785,
                               -2.8889369185804412,
                               21.76071465968316,
                               67.713094072098642,
                               6.2413030293991056,
                               57.144989454906899,
                               36.277524075819812,
                               79.925179728441663,
                               -60.823937516173288,
                               -34.560443628467468,
                               -61.840785211217515,
                               -25.607056404769068,
                               -32.022505787584997,
                               -59.099145801466854,
                               -24.762174518390953,
                               66.9541938869163,
                               50.047722561153542,
                               -31.93125738877977,
                               42.285334426482322,
                               -76.497571746644567,
                               62.714868742152881,
                               59.637547729782412,
                               -2.9060768165638837,
                               -34.096785591677545,
                               -33.163514329610244,
                               66.768977318539811,
                               52.020402081568719,
                               -21.351756491803833,
                               77.759581499082614,
                               -46.690545180032572,
                               -68.966870983979064,
                               2.4872927587460616,
                               27.106629843354611,
                               -41.055524578889333,
                               5.6651281709249908,
                               -57.129029928320534,
                               36.669083805727382,
                               -7.8588898441142643,
                               66.12871333535395,
                               68.472941301200109,
                               -53.865165932651117,
                               11.971418031142759,
                               6.997475248931833,
                               -53.215565196685432,
                               -63.761759868589564,
                               34.272183096784374,
                               -37.179720623951866,
                               -59.333146553803331,
                               23.212604906368718,
                               67.583252217545322,
                               16.310950236883073,
                               -53.068482891859105,
                               21.636164847444871,
                               -16.10782796808644,
                               -70.658223288253765,
                               -25.091102920385119,
                               52.160330473673866,
                               -65.898354965486732,
                               49.128263857326303,
                               -9.9470270765326845,
                               -67.205014003125697,
                               -77.014713855260766,
                               53.763406785374102,
                               24.157946352983643,
                               17.934233908857358,
                               -3.6134123797570705,
                               -55.110185809123919,
                               58.020826746804218,
                               -30.754745574579005,
                               -21.407113215369446,
                               40.124298503404859,
                               -43.819290971439415,
                               -31.520295009825254,
                               38.516473060664467,
                               37.974115809038466,
                               -38.301891849769234,
                               -45.380416705221009,
                               -77.762863651077936,
                               -72.039864245527454,
                               36.848504979100888,
                               -40.957293257028454,
                               -17.340452042536484,
                               -15.745633142547332,
                               64.513059961487329,
                               36.545828820137636,
                               -45.803470833920159,
                               49.953362386879022,
                               38.334455379331345,
                               -8.5379522807668735,
                               -27.254190527338793,
                               12.426499626794683,
                               30.136842208295654,
                               33.932332776125961,
                               49.868840777500509,
                               5.5992532483361845,
                               -53.027225537141014,
                               -35.052482597936532,
                               -21.815071846576714,
                               25.719387014112215,
                               55.732480311258342,
                               4.1808523181010973,
                               74.78814924825906,
                               -59.312176576141859,
                               -52.48019277211452,
                               47.264922914963122,
                               27.008313228790314,
                               22.85824218454669,
                               -62.291428002315925,
                               41.536869863937412,
                               32.130852839690036,
                               -21.240880775297597,
                               68.254941395426371,
                               -12.333243204461271,
                               -11.599792416997637,
                               76.827713003419277,
                               36.542642069251478,
                               -0.061296637560982248,
                               -66.150650056340424,
                               3.122401450031095,
                               50.483309402205037,
                               -38.433233752041168,
                               -38.296741855692552,
                               24.024385090390918,
                               -0.0052899285606802238,
                               2.8020144767727384,
                               -8.183097907112689,
                               13.378680435949194,
                               -41.948335114324358,
                               -37.227896628099764,
                               62.495687195376902,
                               75.658747464230601,
                               -54.995302396683584,
                               -31.821315684029287,
                               -20.655462663811566,
                               -5.1664667326928146,
                               14.890061156299488,
                               -52.07720435091376,
                               20.947053874803434,
                               -8.8832862908204788,
                               20.637471330289547,
                               22.717230666656526,
                               69.721173428484121,
                               61.946911623061169,
                               -78.001967289365183,
                               -31.509510332080492,
                               19.735453631922901,
                               13.159028272900668,
                               -44.071999301249072,
                               55.349821725186501,
                               42.854006311955075,
                               -20.7411703585041,
                               45.252484334100515,
                               62.910987951608206,
                               38.577317984197009,
                               -24.597265531169697,
                               -79.747963089039189,
                               -32.312204693026324,
                               -63.605097564083188,
                               47.836336982723168,
                               -27.908436375569536,
                               -6.1331802896022314,
                               17.149916409552745,
                               72.905706857622832,
                               -26.389072932203639,
                               -26.146836786666533,
                               -69.285841177381968,
                               67.438392242025145,
                               -72.236444386563235,
                               -68.731003238281616,
                               61.338222729930209,
                               67.156347975852029,
                               -8.0387723477838158,
                               -63.536061160368021,
                               -30.798456078236661,
                               -57.270130849343651,
                               -24.234470851974475,
                               -23.560417268135282,
                               -43.954245236866065,
                               -39.623405230105533,
                               -67.224891923735711,
                               -13.967671558794541,
                               -73.381118981789541,
                               77.290242577405309,
                               33.945445275834871,
                               -14.496233290421957,
                               18.956225636736274,
                               79.229565676067722,
                               -29.934666230273603,
                               -33.882784528499073,
                               -12.20475399492309,
                               52.465194552286334,
                               -60.780162480104991,
                               -25.939102926853856,
                               -57.078102491233729,
                               -57.470229606401695,
                               1.7783550916488355,
                               -58.968688538120347,
                               4.0562913192590333,
                               -3.268890700905617,
                               -48.988060405918262,
                               47.552978202862739,
                               -31.113783195852378,
                               15.244187338318184,
                               -28.685800275198304,
                               -17.491109962318252,
                               -28.728226808016963,
                               -18.23502590131968,
                               27.418895070312644,
                               -20.826287036184446,
                               -8.7508413065636059,
                               71.205385983586382,
                               -62.561082203032598,
                               -21.423297631823161,
                               39.903158292826014,
                               -51.106701789878414,
                               -20.050224993744067,
                               -59.839312149455466,
                               5.9150340155215524,
                               65.230556925568067,
                               -59.005190652640451,
                               -13.872207693870077,
                               -58.022453884305321,
                               61.309598090636896,
                               50.073318915850933,
                               -27.841976072452209,
                               61.190347352771866,
                               32.011121663553254,
                               74.631161260201409,
                               45.12921572703317,
                               -5.015165436960654,
                               19.494258791915726,
                               -10.610907744890021,
                               36.241933424502136,
                               -55.955439271637573,
                               -54.992366962392225,
                               -35.299541274423802,
                               -74.881035268045579,
                               53.386573603486625,
                               60.764611031905538,
                               -48.620495801424283,
                               -39.597663859738404,
                               -8.1210724597057187,
                               -9.6778237342965792,
                               2.8496056745161731,
                               -45.724056030190866,
                               -69.134053342928965,
                               66.949450098440337,
                               -20.730433276509604,
                               42.198957888859759,
                               -46.069206377076497,
                               -76.022073450523408,
                               -36.969571167465681,
                               65.493136563546614,
                               4.4009537048268648,
                               37.373386284638585,
                               52.602180736853413,
                               8.2915798544866455,
                               -42.540696639683318,
                               64.960378494643763,
                               -45.896563395450286,
                               17.361256102583901,
                               -15.201510836711499,
                               21.544623273564795,
                               -35.356583170636036,
                               -41.24849131496017,
                               23.768542502415205,
                               31.554413454962372,
                               -17.421028474743636,
                               -56.047645074984757,
                               14.911702871882524,
                               -37.539214344623268,
                               -16.616219885499682,
                               3.4246135063638228,
                               -67.847788530596759,
                               71.058372992185042,
                               -49.413961036799599,
                               17.466880400669105,
                               71.701161979106672,
                               69.083034946821812,
                               -61.430483946670535,
                               -56.616290903016875,
                               -40.36510755878372,
                               4.9823105876376559,
                               -22.498998182479305,
                               -45.503938958142413,
                               -64.924030192490591,
                               -17.706176479641051,
                               -64.470852242782698,
                               75.735365067842821,
                               67.583531312566649,
                               -42.048970120845325,
                               72.608740514921323,
                               23.839788496195531,
                               76.30928828691431,
                               -38.438178373005684,
                               55.112718866031834,
                               24.839258113986077,
                               -53.947642518638965,
                               -78.02690958280408,
                               -78.718909777041574,
                               -31.466982269901841,
                               -42.434860048553134,
                               70.781289408837736,
                               -12.541886247607613,
                               62.301472949633265,
                               -36.915733506985589,
                               66.573525298854008,
                               37.767779206682576,
                               53.157303940984647,
                               54.375019034263694,
                               -8.2846892041473428,
                               53.073557505757705,
                               1.4760732088024469,
                               78.829422534161296,
                               42.34503089466314,
                               -74.681936829968322,
                               -68.77310814717319,
                               22.017587129930472,
                               -22.318104740348002,
                               6.5689898658971586,
                               68.700412995906319,
                               25.149898608413167,
                               -41.370238591373322,
                               -53.75756647662886,
                               -2.6803995745379439,
                               28.382255982228948,
                               -22.300380717135369,
                               -76.46831549556417,
                               11.259797593444336,
                               15.329769901811069,
                               55.482746754526524,
                               -16.682953414917584,
                               53.225177888622873,
                               -67.121765219528868,
                               -72.736856177388148,
                               59.173538002281191,
                               -7.7747041031595501,
                               -63.137522450415801,
                               -36.133272858703407,
                               48.705059558561665,
                               43.799670711644538,
                               -16.855624901430922,
                               41.302039584305945,
                               -17.118077695008843,
                               60.84794206857773,
                               9.7251948532293682,
                               -19.851112884152027,
                               -3.6062100331447215,
                               -42.037709063534734,
                               -8.8443651219212196,
                               65.46684810794379,
                               51.245897710005892,
                               -19.389829818078859,
                               -3.879418530674025,
                               66.34015448145415,
                               -33.953573826868414,
                               45.751634310503107,
                               1.2696609467730973,
                               -23.96416111334122,
                               15.899771128972983,
                               -53.916323723895857,
                               1.6209360133854513,
                               -3.0680421283315074,
                               -66.376288723516467,
                               67.796478968755366,
                               60.599097693034686,
                               45.376838826539128,
                               30.855548941309422,
                               -38.246450151176077,
                               18.830150864127638,
                               -25.730796800381718,
                               78.092534660346047,
                               20.082991545297375,
                               -40.292428924046057,
                               -69.608753513621011,
                               37.579227600435559,
                               -78.296914685403181,
                               28.309256057267977,
                               19.241367687813948,
                               71.072107189469349,
                               68.337590675761803,
                               -8.0494916400778909,
                               -58.873428559319336,
                               -55.752095984843407,
                               -18.829243528268726,
                               77.654011266461112,
                               -61.535723580282003,
                               4.3009892849193481,
                               -57.689406281184993,
                               -77.805001248404352,
                               22.880544837781862,
                               -13.007202662178832,
                               -67.097814072759689,
                               20.405604469034785,
                               68.631314755275952,
                               32.581916277697466,
                               -24.616790304304622,
                               56.457180363973166,
                               39.391555890641882,
                               -0.68008066086505004,
                               -35.961830164218341,
                               16.097184744511488,
                               -25.627757008720131,
                               48.745024624808295,
                               77.456100084926661,
                               -65.575390953474937,
                               -36.650405411362286,
                               59.495352401681316,
                               -8.6451139135785837,
                               -69.879083853567948,
                               7.9266866097153468,
                               9.0694959748506516,
                               51.477567819240974,
                               -27.090239349090865,
                               26.074896940876478,
                               12.729471994583641,
                               -16.83255624868913,
                               -5.5600507121238518,
                               21.290907173364793,
                               79.905320643625743,
                               -74.355027030265958,
                               35.996379762939782,
                               -28.326956578183005,
                               20.693930307598443,
                               76.907456244667429,
                               -79.701656242480496,
                               -70.572294546546175,
                               6.8236978828902419,
                               54.998243268114805,
                               31.760889672395948,
                               10.548996396044322,
                               40.871632256814145,
                               11.311747242345675,
                               -7.1157762258281689,
                               -29.683801204068505,
                               -74.600052386315966,
                               31.657756220077545,
                               -35.407411609800306,
                               23.912557756422352,
                               32.931325191951956,
                               58.983483742471513,
                               -76.389412938425465,
                               67.310513233456163,
                               -37.11501954846603,
                               0.75433528495910096,
                               -56.231956303287923,
                               48.303005879651785,
                               74.075339559401925,
                               72.860391350636107,
                               -20.580230530586725,
                               11.636731248364683,
                               7.8882513081951551,
                               -65.720440751211342,
                               74.066081259760807,
                               20.146327162076624,
                               -53.057710031764401,
                               -71.783077041825194,
                               -25.257509159492503,
                               -68.616769338107204,
                               21.455219904816637,
                               46.029272915901103,
                               -46.940107331189587,
                               -63.448288748557815,
                               74.159805866038326,
                               -59.600959518480238,
                               -24.140224934545579,
                               -33.496799691136495,
                               79.17245937528746,
                               0.41254649339037464,
                               71.571097483507373,
                               53.200350079655585,
                               60.911892074468582,
                               47.337488059038108,
                               28.452587035276814,
                               18.454806910832328,
                               -70.054390920748233,
                               48.897367935837053,
                               -7.5084226946437482,
                               51.488795208696445,
                               6.8678725824913887,
                               55.05717352701965,
                               -49.363676243577402,
                               -77.71787553701283,
                               49.257497889360451,
                               15.676763543082185,
                               -50.409084451968155,
                               -45.359648049630849,
                               73.83022830679306,
                               -25.189304407696284,
                               -60.977064591498205,
                               -62.382275513800394,
                               -33.888615482621496,
                               -4.4964881923946471,
                               43.894583042476569,
                               -68.424660660245493,
                               -22.711845274203281,
                               7.6415282134361906,
                               20.581749407048772,
                               77.318703302785153,
                               -32.408418504335735,
                               63.905182179386948,
                               -57.064123156425033,
                               45.391638516376865,
                               15.626728719374768,
                               -71.88660309794038,
                               69.05956097363601,
                               15.916153368894429,
                               -26.326527590288205,
                               2.52254671116658,
                               -18.613266827339544,
                               -67.739828189102781,
                               -35.034885824054086,
                               -73.808798493818742,
                               -40.970050681140997,
                               51.069291716640706,
                               20.360694800587751,
                               39.80084731669681,
                               39.061479365641375,
                               -69.48378150630225,
                               -27.052952152087897,
                               22.41662337548113,
                               6.2859826307242361,
                               5.7670958921932218,
                               -22.398106087358983,
                               30.077475100316889,
                               36.564587767511419,
                               24.96225744862776,
                               -50.919252724683496,
                               23.700585909311698,
                               -18.353460076298095,
                               33.297418539713448,
                               48.476033900653121,
                               -63.995826317271508,
                               41.42563807875662,
                               43.115306434251778,
                               -6.2703705077967484,
                               57.47748101704061,
                               78.133670025729913,
                               47.170520557005332,
                               2.9768737620033825,
                               11.973284204855634,
                               -62.145009854867993,
                               -37.723631083649451,
                               64.136350996146959,
                               -3.0608717961932079,
                               56.482771172214612,
                               42.201070047080819,
                               36.060335255733833,
                               14.859373364876085,
                               48.941242225088878,
                               -53.179347933921832,
                               -23.50598589048256,
                               -35.597352646178095,
                               51.465972546884622,
                               -39.538557026297354,
                               -5.8985133564970358,
                               77.499536496062404,
                               -14.71982146131414,
                               -14.949240028395604,
                               -48.942016521143827,
                               -29.468004211230767,
                               -26.664100920596848,
                               44.114412226469213,
                               4.0833964847743314,
                               -14.685460457277825,
                               2.3649784858198384,
                               -3.396903254183119,
                               -6.8719740435017584,
                               56.806654214605643,
                               32.326748183922476,
                               -73.587348679536703,
                               6.8443568496602136,
                               50.910248926123856,
                               -14.548460362714495,
                               -26.446584996701937,
                               63.72598903713871,
                               0.16233200147572013,
                               -31.609829573908648,
                               -62.976439707932634,
                               18.999724484650159,
                               9.5847062233896523,
                               48.073497669503261,
                               -22.173510589404067,
                               -41.297879832963105,
                               -76.132110336304862,
                               -21.428393315678036,
                               -0.86736308498530512,
                               22.942231036193654,
                               49.52925165000633,
                               -32.694127182032872,
                               41.936984441518916,
                               11.598116102142551,
                               -42.857690472538813,
                               -65.335202285378884,
                               49.303945318141118,
                               -5.9823235012512122,
                               -6.6057365268112509,
                               -1.7393046702692381,
                               52.681483056881127,
                               -22.286233151662685,
                               69.548580212075947,
                               1.6966454113476139,
                               -40.978128550765966,
                               -77.209464088798768,
                               29.228968809712029,
                               -14.99435541624802,
                               -7.9856221354088142,
                               -6.7098624049691136,
                               -37.491881356446257,
                               71.804356382583151,
                               21.015738635512129,
                               42.421623695459694,
                               71.672364050157469,
                               49.385336173693545,
                               8.4266357908176328,
                               -40.420529563199423,
                               -47.543528787652193,
                               56.257981572232744,
                               -36.765939361280488,
                               36.961103956479043,
                               -57.597561415621705,
                               69.493266325750341,
                               43.962785894979412,
                               67.649975441610408,
                               -55.060469436792935,
                               -52.34675232862066,
                               -48.9776005854348,
                               -1.0269873840429593,
                               -51.461481055858769,
                               -68.299303202285998,
                               -55.673745501632304,
                               -72.966761059131471,
                               -12.247751889226347,
                               4.0800606321662727,
                               72.097772081854046,
                               68.113752453595595,
                               73.141703098452041,
                               9.0829785138224288,
                               13.60655773202742,
                               -35.899816388642293,
                               -7.8095038441467306,
                               32.123284556274456,
                               -18.589421892371547,
                               35.193965583071346,
                               39.296518969330108,
                               78.884821411662926,
                               -60.053128830530611,
                               60.807997772299679,
                               -52.180303458237212,
                               -53.345455832421536,
                               62.734029176512792,
                               -66.789600160081989,
                               2.4369916441028767,
                               31.264219915084542,
                               -9.9272984419197794,
                               78.790009643778831,
                               -50.1363772641146,
                               46.405456097297424,
                               3.6806499801295871,
                               -67.678600767269685,
                               4.9394754825105078,
                               -59.665509612474551,
                               -64.982433588364728,
                               -7.9695225396990637,
                               1.1163166116977479,
                               33.149358532952526,
                               5.5635053927970048,
                               -59.805353442362183,
                               -12.137076859530804,
                               -3.6304324793698068,
                               -14.090623486079718,
                               41.808615349550465,
                               -38.840474812104716,
                               66.367487483648759,
                               -38.456948364226868,
                               79.872164522757842,
                               74.529606879800028,
                               -51.026339446417985,
                               -26.967362422861143,
                               -36.193107097107081,
                               -77.908077338047036,
                               14.840850207328872,
                               -33.523999392528772,
                               25.362244162041662,
                               -52.105398449452274,
                               -15.384164972279249,
                               16.293974347375688,
                               -13.516927027141248,
                               6.7988989363980128,
                               16.068735486521799,
                               71.648764470553331,
                               61.487557174694203,
                               3.089024719390375,
                               -31.531421867423205,
                               34.033586072113692};

const double shift_24[1000] = {16.080462132817935,
                               51.012281869267689,
                               0.55188191655412133,
                               5.700101479940427,
                               73.89282845325846,
                               63.837846962421061,
                               72.778729505077862,
                               65.843307936288497,
                               76.251170010795207,
                               9.9009024664704768,
                               -37.180318555483957,
                               -65.539855181088313,
                               42.503806958006919,
                               -2.9561208749812611,
                               -64.55991510650307,
                               51.922092082947145,
                               -63.531864207404318,
                               73.363205432360758,
                               -63.938023431784202,
                               17.834694930925462,
                               58.023432017173306,
                               22.659490190124959,
                               -33.071042211757835,
                               37.223022548982037,
                               -42.247151281504685,
                               -49.659102512223022,
                               -79.795909297723654,
                               -47.007320119847535,
                               65.065401967225682,
                               11.622815664352474,
                               12.5345085414761,
                               -53.262135207504322,
                               51.96073604021543,
                               76.589754329656813,
                               61.437382764796979,
                               -9.8680332585597661,
                               2.5138126076394851,
                               -10.204708585373936,
                               50.155232458021928,
                               31.285916244440898,
                               -5.859186268896643,
                               -15.537566949358407,
                               54.578958251021803,
                               -39.646897902094864,
                               26.727322583295191,
                               31.527281396349224,
                               -77.219654668406349,
                               43.224844948400694,
                               33.734577436560386,
                               -40.391068408938253,
                               -52.077334335519005,
                               -5.7823904839818159,
                               24.514088969853347,
                               75.222323651910685,
                               -54.956209054626399,
                               60.935736143515705,
                               52.878093272104067,
                               -8.5372006064070121,
                               73.531314361262048,
                               76.794732706714768,
                               31.108111529303009,
                               28.628095061140478,
                               -23.466332675141459,
                               24.753535354824752,
                               -55.962121060367551,
                               -63.231542189082177,
                               1.076482952693695,
                               -14.119283170833414,
                               -38.067232846307398,
                               2.8797781997047736,
                               -75.144430102484833,
                               -53.14161278874964,
                               -50.803724220299571,
                               -71.124932453965116,
                               16.127044753356621,
                               -29.570368163166798,
                               -12.821590128248271,
                               -55.264018175571387,
                               -53.339121710488001,
                               42.043155233253856,
                               48.900632591781452,
                               10.076986672408783,
                               68.770101539024097,
                               -13.720570333384506,
                               18.259906534922241,
                               52.005272424404851,
                               37.981358667345546,
                               43.726772986979071,
                               -45.434169890082721,
                               -36.422107550364785,
                               21.206679766372016,
                               47.472510151574625,
                               38.084897012340349,
                               64.296046965104054,
                               -60.719867964517974,
                               -43.164201187280192,
                               -8.2771111697331659,
                               -16.185106122283489,
                               26.95620204976219,
                               -54.422551989046951,
                               -22.705732602179619,
                               -78.331952038369323,
                               23.821716217735357,
                               -22.355633608232978,
                               42.052277640839279,
                               -14.076342560149604,
                               -6.0501904438114185,
                               28.106716607749561,
                               -35.659145138261906,
                               23.248338593470329,
                               -25.987869260520135,
                               -49.198309680207849,
                               29.362554208368579,
                               10.214695330661732,
                               56.932775864494502,
                               -62.814615721761342,
                               -76.173183774608319,
                               -31.127365217443248,
                               -21.144581850867262,
                               -0.79367463788950943,
                               47.719880024095652,
                               6.887237013319357,
                               -22.354055024443245,
                               -20.897616666080104,
                               13.232238521280143,
                               -7.1203383761992161,
                               76.65561037826366,
                               39.97512678807346,
                               -74.508668471850342,
                               -73.662768940648689,
                               25.982762304331132,
                               38.024966831886147,
                               -54.392300741250565,
                               -25.16896625157824,
                               26.110706379395737,
                               -17.445920342434967,
                               26.002646348478461,
                               -43.508303454716817,
                               -34.767169448701466,
                               61.768993835594628,
                               -53.580021388529083,
                               -44.97353705836818,
                               -34.740521181438844,
                               -0.049912188985995698,
                               39.048551548422992,
                               -33.084882078518397,
                               -53.577582964183236,
                               -18.782368817376231,
                               -16.738754593694622,
                               68.311480851752705,
                               -40.365850375876654,
                               47.823220019547648,
                               15.208720769541376,
                               36.567928014264027,
                               30.475662706197507,
                               40.681318725036355,
                               45.145377848184523,
                               79.700286514474513,
                               -74.47994583529821,
                               -41.710345046308973,
                               -72.999443301438006,
                               -69.044979193284775,
                               -39.055534086881025,
                               -11.513647908967307,
                               -10.812856584527367,
                               -72.655641694743693,
                               41.21196184344911,
                               -36.058369274478082,
                               70.188710656451661,
                               -30.187661066721702,
                               -54.280960784754527,
                               -72.978817251327769,
                               -15.090960632071617,
                               50.038195079627975,
                               65.824953844461547,
                               36.218874456767644,
                               3.824202595972519,
                               -5.8675680223891522,
                               63.353414020697635,
                               -43.097662314488176,
                               22.570313796161308,
                               46.396773332325765,
                               -14.45706203375221,
                               56.355540833399708,
                               62.12201797590059,
                               16.147685670068803,
                               15.762876813262205,
                               64.641323661361582,
                               -74.465641905330983,
                               22.779680016168399,
                               52.726721651513778,
                               19.491609871885903,
                               -33.688744553388403,
                               25.940078189005007,
                               -41.055339287172977,
                               37.688311259411734,
                               41.156870324363183,
                               56.446420811335017,
                               13.796352079275904,
                               -37.304205659763589,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               11.287059065025295,
                               76.147101397597098,
                               -45.743088502408639,
                               63.354323151900722,
                               14.487731469555632,
                               -65.839335967339977,
                               -67.307332801578795,
                               52.696889510679043,
                               -56.044317937008138,
                               -42.531761868203034,
                               51.241359693950827,
                               25.198920031950397,
                               10.792918810060272,
                               60.854161375950483,
                               -8.0730814593542437,
                               -71.512655212249271,
                               -31.877831123641663,
                               42.082933622826843,
                               62.61044387796003,
                               -44.488461688801536,
                               5.4593783290838047,
                               -34.454304846892626,
                               37.335874078031985,
                               -1.7489940256232348,
                               -7.9932929238764583,
                               18.033960105472339,
                               51.081281388904408,
                               -29.926208283546956,
                               10.428429538088684,
                               59.277185585707009,
                               -75.296659612578537,
                               -74.590802255528601,
                               71.157900699258235,
                               -75.032490311887969,
                               -21.611167208681763,
                               46.54479747108482,
                               -49.860980624843826,
                               -52.545513467321953,
                               16.231307953860664,
                               0.45013708813211473,
                               46.181215538689692,
                               62.702774912168834,
                               36.799054767118363,
                               5.7435011099920903,
                               -37.366159677601324,
                               -0.74336043472862201,
                               13.093758119733435,
                               25.765604193807089,
                               -79.352134149453263,
                               1.3571593540933815,
                               -0.5347850711376676,
                               21.204627274972069,
                               74.705404530715768,
                               -42.588221351215118,
                               -67.863898748070795,
                               76.698976475037796,
                               22.038622782215572,
                               -52.153191435511999,
                               62.431699070063246,
                               10.596471475465753,
                               -45.855167065592958,
                               12.033802459352533,
                               72.747072450856024,
                               4.1508391676393543,
                               -77.512619354736458,
                               13.067403774255279,
                               -34.433405440471283,
                               45.470244088809643,
                               44.312119150546472,
                               -52.64315013824482,
                               77.481949303529902,
                               59.988539477303512,
                               -31.58922866690763,
                               -35.622002840163788,
                               42.144408626257224,
                               -9.0179662930956628,
                               -24.324262152984758,
                               53.06364458827332,
                               18.76464644888495,
                               9.8405482200629564,
                               8.7019738314359696,
                               -21.086143023207839,
                               -46.529056978519506,
                               13.798487342252717,
                               47.214798105180265,
                               -49.383670151161866,
                               -15.561618382694535,
                               31.250906814397631,
                               -50.424154255109428,
                               56.447478141424106,
                               6.3939033764617221,
                               -43.876859164750307,
                               3.7445851195602966,
                               34.784334196750514,
                               -29.724608440493988,
                               -57.529180668867546,
                               48.143757653886169,
                               -70.968417251476865,
                               -29.483426009381716,
                               -17.686974545307606,
                               62.82975317416814,
                               -10.874837887741627,
                               47.54224656250414,
                               -8.4189141884651733,
                               -36.201845789099195,
                               36.102162556750073,
                               6.3054908935864109,
                               44.737699775085446,
                               18.137662567196386,
                               -65.88155526509226,
                               42.762408230838872,
                               71.483748180671896,
                               -67.455554459700551,
                               -57.836545921923687,
                               -17.345199592796455,
                               44.850921201398961,
                               65.658753991933352,
                               30.468519866131395,
                               -39.815534524809188,
                               64.182840461025293,
                               -23.772191018846833,
                               79.228919312840802,
                               -9.9601252285595301,
                               56.798066322011579,
                               20.143718728340787,
                               -34.148748646193617,
                               -38.776778856700034,
                               29.697773335649849,
                               -6.9155354900690273,
                               -56.127029586567495,
                               -19.233840443320048,
                               79.43761131630167,
                               -77.476733668870736,
                               -54.742808577843682,
                               70.829359299825185,
                               70.376274575849251,
                               72.498873164615034,
                               52.634177374050239,
                               -77.992634293759522,
                               -74.641526729957022,
                               -72.833765702596637,
                               -61.906293077664827,
                               -11.722799118467927,
                               -69.119328869947225,
                               50.125983116448964,
                               2.6047305410800217,
                               -2.7110441802351311,
                               -75.680089222069341,
                               -12.657508128169141,
                               20.770125618944267,
                               73.361590227606598,
                               -27.473793514406218,
                               -29.844063828192159,
                               -1.6252048911794876,
                               36.672318160687681,
                               -63.178308277115164,
                               -45.693459040856979,
                               48.021030367811903,
                               28.256469827795009,
                               -12.732529257693182,
                               69.939006034279643,
                               40.02027924935107,
                               23.329071008014687,
                               77.913688885040486,
                               -38.916273947632412,
                               -26.212537916029778,
                               -59.856151325456523,
                               -74.761729937911213,
                               -55.848701997480767,
                               -40.56216854282075,
                               -3.2612941131028386,
                               5.4243337896210484,
                               42.013516501290383,
                               19.030613987552996,
                               -59.106822275072602,
                               -38.422995775361244,
                               -79.12989413013841,
                               -17.528588249406276,
                               76.323311826212148,
                               -1.3439438828047408,
                               -12.580936146833793,
                               53.573894435709832,
                               41.638404127451636,
                               -53.290173271129483,
                               -58.895565820016749,
                               -19.134776888151976,
                               -46.698871954290496,
                               -37.365726925554334,
                               -7.861451685723754,
                               -22.79763819470962,
                               69.8579200325497,
                               -65.290813538970767,
                               57.516642275978377,
                               -2.5618721602885213,
                               29.005050413680436,
                               1.9983931458092741,
                               -71.339202569791766,
                               68.096357340293125,
                               -44.814235170901455,
                               8.624165589014785,
                               -48.714046352463662,
                               -17.236673495316424,
                               -20.284528201412002,
                               23.609255066131528,
                               -74.699365717990574,
                               9.1534803561715705,
                               -34.687124713975329,
                               -24.975601797452576,
                               42.216731789196579,
                               32.162601642046624,
                               -58.168365196758401,
                               54.760502212295727,
                               -29.899959174451354,
                               23.173430091230713,
                               -38.807462557216041,
                               -2.6437070146764512,
                               53.124433413919384,
                               -34.028896678242575,
                               -6.9480376504968397,
                               0.26193057370696415,
                               66.900402729685254,
                               43.660215732094358,
                               59.082541829340805,
                               -57.508467300567553,
                               -54.884072002523375,
                               61.823438592961992,
                               -54.314348983736565,
                               10.757373502761256,
                               38.375331758588892,
                               18.367437286172162,
                               -63.570233853558307,
                               -20.251054937837509,
                               22.837706989140276,
                               -32.902257007378537,
                               9.2109757021309075,
                               -48.387235951422241,
                               -3.1788789646133644,
                               -25.403629463214799,
                               -51.964111180057543,
                               79.025496245638948,
                               -23.496812138246717,
                               75.737191093969955,
                               15.511737033479243,
                               48.122599128006463,
                               6.3750418945616438,
                               -68.648875335936879,
                               -40.020857504270168,
                               -13.084924042001216,
                               67.973504615136676,
                               -76.888942491964286,
                               5.0084398116435374,
                               -53.655971916505905,
                               -77.076539986980748,
                               -64.438321085172475,
                               59.613916130366434,
                               -77.909574442272074,
                               -52.401019071266049,
                               -35.868019405152609,
                               -19.902841080740743,
                               -67.733769644245854,
                               47.813441226219581,
                               -19.311623751013183,
                               -1.9884159589659252,
                               40.660295479775506,
                               34.276507837076117,
                               44.906120325811884,
                               68.663173695220266,
                               2.7846003901617298,
                               -20.262920962756542,
                               28.85868928687211,
                               39.310125002448906,
                               -40.558874740102524,
                               2.2869692846867107,
                               66.139770980688269,
                               13.597562787052725,
                               0.20291680840133886,
                               41.876958706545608,
                               14.48658629578796,
                               -1.9865987736798214,
                               -52.577381027209128,
                               71.096147958945153,
                               29.712235082557655,
                               -49.373722713682412,
                               -47.404775475982476,
                               -33.808614164696827,
                               -39.467930240230352,
                               -61.949294760015704,
                               -52.633904399609094,
                               61.503049213657448,
                               -60.71619740634938,
                               -51.642246608209689,
                               76.557158770792014,
                               -79.355550773159067,
                               -79.482746588688485,
                               -9.9906596005443475,
                               25.874920951556319,
                               27.776149858481887,
                               32.672624610645997,
                               -10.07239168353094,
                               67.6136110111958,
                               64.13273051828223,
                               46.049007083305881,
                               -50.588382772795271,
                               -62.502455263904743,
                               -9.8797729303456432,
                               -25.433362340834609,
                               21.748447383203391,
                               -50.522484770739631,
                               10.417109899239662,
                               -19.743560868889361,
                               77.896243171217463,
                               0.38260610175448306,
                               79.676637950260556,
                               -31.943112840748633,
                               65.079628848817435,
                               -17.677267520070295,
                               6.5294325992187545,
                               -7.9935875917571018,
                               7.655338347923152,
                               51.459637268419705,
                               -43.801089276321932,
                               -13.292555754965052,
                               -62.740168268053843,
                               7.8507354605856019,
                               32.734160106196335,
                               6.7019543602649971,
                               34.435725706761247,
                               -69.987146701263356,
                               -42.114821315205361,
                               34.366312917945578,
                               -4.61755798046587,
                               49.820085786414793,
                               34.438093285804285,
                               37.732910712869014,
                               -3.7943443239624841,
                               -79.403803528415665,
                               49.373902929926956,
                               -70.043120244558025,
                               71.208279393344341,
                               42.884651387289608,
                               49.824454970849132,
                               -29.541762705719098,
                               -21.024884664978487,
                               72.724558944513618,
                               -7.4386997485155124,
                               -30.524328057778426,
                               31.01071046005606,
                               65.53317971952157,
                               -57.207635794294447,
                               -52.049773568039981,
                               17.223031324993251,
                               75.774031781861595,
                               -62.380567388965503,
                               13.611303371415074,
                               -19.231070990014775,
                               24.250863319267708,
                               -21.825170934271583,
                               -66.917167572890506,
                               45.538437508397415,
                               32.110440763894232,
                               -3.104837434900837,
                               56.882910763153973,
                               60.116370607741104,
                               -75.846030718232015,
                               54.085816950602677,
                               -41.834366317196725,
                               -16.879102800961512,
                               26.038546623793522,
                               18.22382223519584,
                               67.32551615120353,
                               15.265390454282381,
                               30.333760747478525,
                               71.557316243980523,
                               -13.789325498314684,
                               -47.75122210345868,
                               67.441358209789669,
                               -59.839773107720085,
                               -73.99329946165355,
                               -34.222853922250657,
                               76.431435041029374,
                               -67.998147186938297,
                               -44.10105711665053,
                               -16.11140521079588,
                               40.507064591973872,
                               70.999016737451484,
                               -6.9974342942234014,
                               -21.452367132462236,
                               -75.499026874067894,
                               42.167269197595907,
                               -12.796279941808525,
                               -47.099622148121718,
                               -25.167232676677614,
                               -11.327169954271566,
                               -34.524829562550238,
                               46.460654503346646,
                               65.095812581999141,
                               -50.096498053360051,
                               -11.982472953146434,
                               65.26883592106438,
                               22.855198976116746,
                               -73.167002435844879,
                               -44.495009745741221,
                               49.799222069611169,
                               42.736352292533567,
                               31.444123983515624,
                               -50.563289827230179,
                               53.46683205823436,
                               -40.004384422058486,
                               -65.63566039148796,
                               57.585298679527796,
                               18.135599849348743,
                               -4.4917771708414325,
                               -56.212172613983718,
                               -71.82986231781635,
                               2.6561980332846868,
                               26.243357538638556,
                               19.983146797013696,
                               63.728579553231299,
                               41.625276775331756,
                               -63.023181660228495,
                               -8.8516139585183993,
                               54.503578862636658,
                               67.261050834648529,
                               -43.000384018515547,
                               -31.570581936603908,
                               68.393574957903724,
                               -19.081938865546633,
                               -63.605096477936016,
                               23.857819972924496,
                               -31.408540459061179,
                               70.487599556692302,
                               -47.162138894996176,
                               -1.6002970443380029,
                               -15.469944941278573,
                               -71.621076740072738,
                               62.31296711602009,
                               43.183765644154477,
                               18.167794420831697,
                               6.858261449663642,
                               -26.428246736105173,
                               23.525941363696042,
                               41.744789190140921,
                               -62.603759448638897,
                               26.003881580483373,
                               -68.35684090092191,
                               65.124722583644072,
                               32.005217541441901,
                               -50.496282228385439,
                               -39.356558607313495,
                               -11.831230690370544,
                               53.846143668644125,
                               9.4731932736583211,
                               -10.819373536035783,
                               20.108670673089549,
                               -37.621814414173045,
                               -31.53459917038883,
                               69.109969560589306,
                               12.591943808013264,
                               -11.38818186520505,
                               30.635873280479139,
                               -58.86656091503172,
                               -41.029390722599544,
                               6.2895774835920477,
                               60.609810944783881,
                               11.456597485420973,
                               68.527325970985245,
                               -73.685480934978955,
                               -29.216720574230976,
                               -12.32006030585392,
                               -4.785938363225485,
                               23.109410645317489,
                               -16.747773309980005,
                               -67.102333000813289,
                               12.705229062168351,
                               -75.918136719193882,
                               -59.257591130039735,
                               28.483095667704269,
                               -46.213146015763698,
                               45.603583715665962,
                               51.072448366257241,
                               -41.843422036588436,
                               -64.418818774371488,
                               55.454533655189849,
                               20.4165986577047,
                               -21.481093224920937,
                               39.628557629723176,
                               59.307758178257217,
                               15.185968408123575,
                               -29.474169979518116,
                               66.961725132719152,
                               40.886241767778266,
                               14.39234231822506,
                               -25.828344568900096,
                               -23.089648190043292,
                               77.085812995700039,
                               -75.242848995054402,
                               -39.087240527057368,
                               20.810511180844724,
                               -66.306625588745618,
                               56.942014031309398,
                               -7.3558734812675137,
                               -56.483859579314505,
                               -72.236312688803679,
                               -64.355693476764259,
                               -23.841829524749642,
                               69.596928656709935,
                               -58.031770802485674,
                               0.45247121433268589,
                               -11.80068056153554,
                               -10.515140775689714,
                               -77.994803337350504,
                               -21.958691051679523,
                               -40.563231794019742,
                               77.183534195649159,
                               36.742977696155606,
                               -43.010865537348387,
                               -6.225269115530331,
                               -74.864834221805907,
                               74.920285067473756,
                               32.19855913551195,
                               -50.5704115588996,
                               -78.761759247473194,
                               10.638903059200123,
                               -77.554653723960669,
                               51.94354566556737,
                               -64.265266034825657,
                               30.437966807074581,
                               69.021317757964667,
                               -56.598292224522915,
                               70.095896358440285,
                               45.206647361179087,
                               15.092798999366003,
                               -33.000787839481553,
                               52.159825861159554,
                               36.451264062193587,
                               14.151235790476516,
                               -25.747274585526071,
                               12.502272352040457,
                               37.204567819515141,
                               -60.341070124021201,
                               71.080658426402863,
                               0.14535837586901934,
                               67.783826993846731,
                               -30.353302732456662,
                               71.027259967068517,
                               41.552106644285956,
                               58.246227594140187,
                               -36.15250591645006,
                               26.339521086284687,
                               -22.667862700356736,
                               44.66264235141842,
                               49.971773540445973,
                               54.99642005076619,
                               -54.31490254958436,
                               69.431132869940882,
                               11.112889579033522,
                               -79.492997407969483,
                               22.761089338835294,
                               9.6988780183775685,
                               59.942771205794394,
                               -29.846637596388796,
                               -2.9510980850542126,
                               -52.513897625798521,
                               -29.371337745304672,
                               -28.98765158816213,
                               -11.39865511601098,
                               18.905308298814351,
                               66.652219902550314,
                               0.34995001118587155,
                               -77.808787622124029,
                               -43.53756304106475,
                               40.726948132135234,
                               48.472243323582468,
                               -52.309643413728153,
                               53.748658162769118,
                               56.182163712961312,
                               -38.574343180763748,
                               26.088847031944894,
                               -74.480370062311366,
                               -27.781006249179153,
                               46.415411296805971,
                               -51.765752731683527,
                               5.0103598947497137,
                               73.081883439283018,
                               -78.509968163011507,
                               -67.362458104558414,
                               24.629295154028014,
                               -8.0276815636115959,
                               76.516307391139449,
                               13.495685524433716,
                               -9.8514507912895208,
                               54.94370204855376,
                               -55.924544583126917,
                               -54.722251779595574,
                               -71.402857385022656,
                               -19.883022661831987,
                               12.927769266264331,
                               -46.897256837412726,
                               42.147166068635272,
                               -14.602631617487914,
                               -36.412047463678661,
                               13.720700940492502,
                               75.891420387213074,
                               -37.412240889312905,
                               -56.747978377468115,
                               -46.109516077541087,
                               -19.938647094563628,
                               -13.61508666806899,
                               54.159089519485981,
                               73.625093573735555,
                               4.6716280157764718,
                               -39.915320764706699,
                               -1.817736465787279,
                               -43.030456740537396,
                               21.215962719546781,
                               0.037580090875980687,
                               -36.763025306261817,
                               6.9242114324537773,
                               -65.907207314218525,
                               -75.087298017190889,
                               29.426268882238176,
                               -49.590843355911552,
                               -76.547819965239796,
                               70.220549358249144,
                               74.571714314064764,
                               42.473931889342417,
                               14.051654322167899,
                               -8.7901748434010258,
                               55.639747343967777,
                               -0.40989883146074746,
                               -46.507085393651245,
                               20.636358661881033,
                               -30.275862739598363,
                               14.870942060575452,
                               -53.594475621456894,
                               -39.642561471790572,
                               -66.790067009778994,
                               71.992926817756825,
                               -12.945877331868415,
                               -13.352470474108268,
                               -45.287970070160881,
                               25.543227871552595,
                               18.940387242653365,
                               38.29386433960471,
                               -16.979523191675778,
                               -48.118083051497301,
                               64.117691084423768,
                               1.0469789240903857,
                               1.8613135395904266,
                               55.528291083935926,
                               -21.544887342408238,
                               -47.942315127882488,
                               -44.774650764076014,
                               -17.152260443334807,
                               -12.472828113892721,
                               -13.820886245681093,
                               9.0600500257438057,
                               47.099679334873507,
                               -33.160231473726135,
                               -63.650668007769475,
                               54.558306877553946,
                               74.091995814151147,
                               35.331923279572621,
                               -63.181266122288868,
                               24.846859337139463,
                               60.642766960389352,
                               50.974160505575767,
                               -52.063764342912251,
                               -78.958780793322163,
                               40.223297676824075,
                               -19.207002556861475,
                               -10.324832285823467,
                               18.742699800871193,
                               -17.5864463259697,
                               -22.600190498735536,
                               19.664367148687802,
                               50.306060793721805,
                               32.227652429960408,
                               13.93976795808552,
                               -69.960710250513259,
                               -31.01746383639794,
                               71.780963092591406,
                               28.56600177660988,
                               -31.946647012100513,
                               7.5831779999504132,
                               12.0140232313883,
                               79.158581990510243,
                               -25.362631469098311,
                               18.582351495992203,
                               40.716015401555758,
                               -18.324397648824906,
                               -6.7564273593482049,
                               19.215173717852672,
                               52.632637100475563,
                               56.646011746653244,
                               53.807010985892958,
                               -31.657630128560193,
                               -55.344299474887293,
                               50.261172658991086,
                               41.874455911344569};

const double shift_23[1000] = {22.195926903730161,
                               -58.022979077717679,
                               -28.35659478357524,
                               31.034576162577068,
                               33.321483631979191,
                               16.682557694960778,
                               76.359921075001978,
                               -8.2295732816317173,
                               37.770185136035245,
                               -6.550261553285825,
                               15.41648458949483,
                               -43.704978857643468,
                               62.763913123025475,
                               -71.937795624632187,
                               78.994154661464989,
                               63.807595219693312,
                               -72.793702709566148,
                               -70.804205426297472,
                               -32.785356827760651,
                               17.136593342607242,
                               -12.766798455225095,
                               47.123415794695362,
                               -69.295318558695115,
                               -19.733088022056201,
                               -40.768868651833827,
                               22.797734587274014,
                               56.38048059145391,
                               70.438936797015103,
                               -26.615473187182999,
                               36.598836279720686,
                               -69.243676200681136,
                               63.394576496180157,
                               -54.165968671792868,
                               43.194140275612199,
                               68.318138619270414,
                               -6.6457391463182311,
                               7.2219976752551709,
                               59.661821888821983,
                               -45.058512888547604,
                               -62.149985933099856,
                               54.519291804841927,
                               8.6850098096568189,
                               6.9848765179562911,
                               54.288828086030605,
                               -57.480647873945614,
                               13.104009342829455,
                               -65.673223738522395,
                               45.247640786231791,
                               -16.312722409114009,
                               15.320689871392332,
                               20.593353810338819,
                               16.093349193157934,
                               -22.164167196537605,
                               -51.873853590067434,
                               -70.082945163826068,
                               30.202189854233666,
                               43.141031414578038,
                               45.577546807672782,
                               -3.1135309278720378,
                               -58.106386533939194,
                               -79.104759529487666,
                               -13.570468442968247,
                               -33.541367578183362,
                               20.946393902334677,
                               -0.99716993480359406,
                               -78.322844597457689,
                               -33.625978799909902,
                               -7.7477495488653698,
                               -43.277107135520609,
                               -73.520664318123238,
                               -18.864056336143655,
                               54.383894761786067,
                               40.91668289103886,
                               75.860863812776842,
                               -41.262890362209887,
                               -39.622527284621427,
                               -10.552347027753079,
                               23.798890470647127,
                               70.934957440528933,
                               42.682908226952051,
                               28.633927441968616,
                               -78.426603172085791,
                               4.4522723224300655,
                               32.95426597736585,
                               62.806990234103168,
                               73.740139317350454,
                               13.360439451754605,
                               73.562472262618854,
                               49.093431490144035,
                               -40.695597962895995,
                               63.522314126368556,
                               -30.250220644515391,
                               -8.4178100839659944,
                               -29.715788394429751,
                               3.8860186606897589,
                               -69.080677368796515,
                               -37.02900580833618,
                               1.9016524259159624,
                               25.028301204371168,
                               29.609825056059307,
                               -69.900980251695813,
                               27.570775666929524,
                               -60.021936645408474,
                               37.671291695477265,
                               24.189118719335603,
                               -67.474046832334025,
                               32.70664914820258,
                               -32.039034407804976,
                               -16.333933881057725,
                               16.760874769821857,
                               16.676764766632687,
                               65.508454241026342,
                               -75.141417924527744,
                               5.7993484930999362,
                               40.339247242758688,
                               -33.060389447265123,
                               -33.605584151854707,
                               -20.579270668269849,
                               -9.5987240742025985,
                               46.203827448523455,
                               -54.19504657863105,
                               -4.2516623090249706,
                               25.593368769965021,
                               31.79149239653853,
                               -7.478023960410459,
                               -11.883475443682242,
                               -17.583073509076392,
                               -68.704787932017865,
                               48.779817484516265,
                               -5.9959171171353525,
                               -15.843861601837448,
                               15.676243583615785,
                               48.982423076653554,
                               -11.915804757702579,
                               49.755877897502458,
                               55.080479395246137,
                               72.517598959982564,
                               -45.014856893738092,
                               -24.032818959696847,
                               -27.130416869814823,
                               -60.878855467451828,
                               -41.960718366866161,
                               16.787410885703782,
                               22.932783635345903,
                               3.3335357250135491,
                               25.998776445540436,
                               59.938367083803527,
                               11.085094621307668,
                               57.631676260408163,
                               -18.682661414071546,
                               -68.082114300133242,
                               41.764912481118003,
                               29.235345359146478,
                               -0.69848547998946131,
                               -59.830021129689271,
                               10.224497482899684,
                               -27.841691496249641,
                               -35.905374065472621,
                               71.354272161781864,
                               10.025455599284415,
                               55.112674605975542,
                               36.333304034421076,
                               -75.535373003606168,
                               62.652251264652634,
                               -22.696139962109878,
                               -20.260125867787501,
                               15.013053444059155,
                               -30.200601945867419,
                               -14.311021908235602,
                               -12.568868153344349,
                               73.703075331976436,
                               -77.927682223445331,
                               -4.7993172875260885,
                               -73.562722112214374,
                               -31.09098910442188,
                               -27.218953438287645,
                               2.209926448801383,
                               -52.06104096040248,
                               -47.774510796975626,
                               9.4947290845998609,
                               9.6223800840449467,
                               17.923192202354159,
                               21.436114626417037,
                               9.7236314611536869,
                               75.824349784350801,
                               -55.312132882475893,
                               -66.298387703403748,
                               38.719365910571184,
                               -7.4426926464496468,
                               -52.151574571185812,
                               45.428057840953535,
                               48.590040356541962,
                               -23.256325631531642,
                               54.50047907682152,
                               64.03581117697334,
                               12.981545845040092,
                               37.108825464334352,
                               -33.242271982559132,
                               -8.6220627235248095,
                               -22.161542957759117,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               0,
                               -32.047947654293637,
                               58.569869192046461,
                               76.833463048892867,
                               79.749590671751221,
                               -35.991679105220229,
                               -52.899398160209643,
                               -24.163779169224849,
                               -57.092461249852043,
                               -66.636471832349912,
                               55.221449285691889,
                               -33.967220425839301,
                               -62.047671707965925,
                               25.318927431798564,
                               -53.651045339635516,
                               -22.771867234271845,
                               -53.329095468680023,
                               26.771615783236122,
                               -1.8495192755840808,
                               -53.479511326465428,
                               70.978959291703177,
                               -34.889244124289988,
                               -74.239503326627656,
                               -55.996618811502358,
                               -77.709503646662782,
                               51.828649699096729,
                               55.921070780807348,
                               -38.417830234114163,
                               46.254861136411122,
                               -45.131170498851368,
                               76.184738970714349,
                               20.470271444047434,
                               -15.077530220562045,
                               3.7658683704139104,
                               -45.238327973637304,
                               -19.375537226976817,
                               -32.830260233663644,
                               -47.472961716001976,
                               -48.076544301923967,
                               70.45602222086977,
                               8.4954312374125038,
                               -8.4623701597480245,
                               -65.568147060695011,
                               73.50459250310594,
                               -33.322623346130477,
                               49.984414666368693,
                               43.816966745770365,
                               -38.676051098211339,
                               68.94990787876398,
                               16.822976857070525,
                               30.285333109088025,
                               46.839808114870848,
                               -16.606179268434186,
                               42.813785903244387,
                               36.421525060771572,
                               60.775773272344786,
                               54.325860383283363,
                               -39.626986905407847,
                               71.459229340650182,
                               -23.181754627129301,
                               -32.930915276161855,
                               -12.601521659490656,
                               69.136371473423225,
                               67.054445651911863,
                               -47.41719175159232,
                               -74.560220696285299,
                               66.365078626905699,
                               -20.344895456675424,
                               52.441777956230212,
                               68.537526673254106,
                               -22.300513078835468,
                               40.246000913919659,
                               6.9947589959145358,
                               -56.612194586109901,
                               54.934763415804184,
                               40.548656799056467,
                               -4.736494741580886,
                               -59.224008847052168,
                               65.078133017742502,
                               8.4389434044261442,
                               -33.922136955455954,
                               -55.265820657746723,
                               -17.613497051898172,
                               50.734451763991657,
                               -3.594651008656216,
                               31.859251197899923,
                               -72.45491397552243,
                               56.043940221599982,
                               -71.568323964882765,
                               70.557063986408039,
                               -78.774514641977333,
                               -14.12567734835878,
                               -51.59512234769857,
                               -58.015036915586819,
                               -60.58744169574566,
                               -64.765995057952111,
                               -32.209171680610396,
                               -11.834910469335526,
                               -62.640046967956756,
                               -33.960487423774019,
                               53.927772682464195,
                               9.6798502705321496,
                               37.55900232930864,
                               -3.128806662190879,
                               9.8630957613709622,
                               -73.41450378547944,
                               -18.508586591831847,
                               -78.273777518650178,
                               18.200745516273038,
                               70.622411979043036,
                               37.580556936160946,
                               -71.939507427581503,
                               21.568122555457816,
                               -63.260935098695235,
                               58.696195428056718,
                               53.957002572472192,
                               22.672759259884273,
                               70.517094768909004,
                               11.533690733070904,
                               -71.754124492614835,
                               -39.752664722554783,
                               -23.489773288113188,
                               6.884445521186489,
                               66.440010192039523,
                               14.669140324059809,
                               8.8621930526604,
                               33.907316150740591,
                               3.538951295025246,
                               -3.6421405821913186,
                               -71.481176279997882,
                               23.024595254202708,
                               70.282953215585792,
                               -58.01843734656029,
                               -78.535789324598227,
                               30.577072854364705,
                               -71.530241560299899,
                               -31.023537132919852,
                               44.634299259035053,
                               28.83618511622862,
                               15.907888170304805,
                               72.68267179898146,
                               77.511798343735165,
                               66.911687474704337,
                               -9.0134937338353414,
                               66.863602442043714,
                               23.055092424389176,
                               -25.301993371156591,
                               -18.321184976480723,
                               52.69388694413427,
                               44.110007535753958,
                               -68.023856681707329,
                               73.482668083302187,
                               60.817212111457913,
                               51.983191520636929,
                               -41.77393978289237,
                               79.799801203029645,
                               35.179788001582736,
                               56.315458526734048,
                               31.657022162559649,
                               51.514900982485536,
                               24.619944242515508,
                               27.240324354455421,
                               -35.479189636635205,
                               -53.193994905334485,
                               33.934598153290054,
                               0.76459667816105892,
                               -5.5915100087213983,
                               63.276077926021927,
                               30.732641727979274,
                               -78.530050667656013,
                               31.826972954230186,
                               -46.020904690170191,
                               -47.294733944516857,
                               61.610862441441647,
                               3.5471127482943654,
                               78.672907972569362,
                               6.1057740158221172,
                               75.131054829260307,
                               -18.226762383074004,
                               -65.657443528737062,
                               -30.473971422551607,
                               -3.0965311393066628,
                               8.3856961538778076,
                               -8.1416671358181532,
                               31.168037749333617,
                               -64.386483134240166,
                               36.48368143371718,
                               66.007039359994479,
                               -11.53944754206328,
                               33.359531929070826,
                               78.006617789996824,
                               -25.771493075255592,
                               31.996681031116026,
                               72.217009656681256,
                               25.736951654590847,
                               29.348322619500784,
                               -58.270007504287996,
                               19.980330606209229,
                               45.005320528241747,
                               1.4553870067875394,
                               -49.464986070749148,
                               -58.318821569938414,
                               -76.41967352484734,
                               15.777667870335522,
                               -60.515174500606008,
                               9.3371299001234309,
                               -1.2426880352595884,
                               -46.414475481240665,
                               -71.979473388748559,
                               -58.840633642203848,
                               -75.49597505362415,
                               -26.34973099297671,
                               33.946535268923618,
                               33.1309493661864,
                               28.609814854376758,
                               26.340831317610487,
                               47.548575887828704,
                               42.628478470688812,
                               55.016141187784207,
                               -20.442423770760033,
                               -26.709086944155729,
                               7.2622954508883506,
                               -56.732602050345619,
                               -14.044973585225284,
                               -55.050070841551936,
                               37.87503848507788,
                               4.760886146417894,
                               -61.781616454518478,
                               -53.67793941428188,
                               72.843714130863077,
                               8.6889948055016255,
                               -57.095821073569745,
                               41.519588780953541,
                               41.109730932558911,
                               67.678177261719938,
                               33.757787292010974,
                               70.294584101881227,
                               22.122339672959335,
                               -19.501675703443766,
                               -7.714470396255189,
                               30.419329482450294,
                               -76.828451287778577,
                               36.977754233664029,
                               32.794110424310247,
                               -53.770819804810301,
                               -33.854771093408615,
                               -42.459828533363599,
                               22.52369298169571,
                               -78.485938082205351,
                               -35.916473573154718,
                               37.704057874032074,
                               5.6002227040122587,
                               -49.022077159966905,
                               -57.559129726990037,
                               -25.1311602400026,
                               23.732713083748571,
                               -8.2553837310025315,
                               64.944488890631746,
                               48.810343962728695,
                               -40.785875941186717,
                               42.408122166080972,
                               -50.930317219618395,
                               -27.271452861361986,
                               34.109290647608198,
                               -0.43178201771487323,
                               58.9036562271394,
                               49.881047753948103,
                               -9.4907178455281862,
                               39.971646871285692,
                               20.523640259916135,
                               8.3189160809030103,
                               -5.7936380798170255,
                               -49.921862681313939,
                               26.878474968374697,
                               40.355719088408001,
                               2.7864839109445008,
                               61.487188623924617,
                               -42.59064329837949,
                               -40.513432547076064,
                               57.413863132724011,
                               -61.752009015219734,
                               -79.202279978470514,
                               -1.6010319915811912,
                               -31.615562799892025,
                               -16.649910699086618,
                               -8.607709379617722,
                               -47.044943481827069,
                               23.510296032669356,
                               6.0699173549770453,
                               -28.373764517690077,
                               46.044222801440817,
                               -56.034587055519978,
                               72.714919072115947,
                               47.213400941454523,
                               -38.594869978836321,
                               -2.1964459497787239,
                               -30.65621926790098,
                               62.572835715471051,
                               22.082287843856079,
                               56.507033374315725,
                               1.2397997042467477,
                               -5.5607828325021611,
                               -13.110129795950266,
                               40.570627050675803,
                               54.57006544095222,
                               -7.1713197610245203,
                               -47.843163963791007,
                               56.91672249287619,
                               14.311164089078291,
                               5.2867777537056444,
                               -22.006833328107064,
                               51.027309489958014,
                               -10.693356180117931,
                               -20.47734715973559,
                               66.136061754580993,
                               -64.900295340867331,
                               -19.02479948418776,
                               -60.709242568576585,
                               71.005122866660315,
                               66.622373093275328,
                               -64.050396566800828,
                               22.846574717122735,
                               -19.591125723991432,
                               -22.854148393534572,
                               52.342745990680243,
                               -53.505378875885739,
                               -77.755914251688893,
                               68.237961496777444,
                               21.933835503574485,
                               40.777060797711414,
                               -63.980825650559304,
                               47.139682456318823,
                               -30.142103795529593,
                               -47.824334523347012,
                               -70.075839422755664,
                               -34.259855454851134,
                               29.243714775172212,
                               -31.138193177031102,
                               38.787627358452895,
                               29.677626929450803,
                               -6.7169306697166018,
                               -17.914594233932807,
                               49.139753150793339,
                               49.457602806608861,
                               -72.62029184973602,
                               -78.227050859405594,
                               -13.508482714321724,
                               -15.442148799233108,
                               -4.1541524860118031,
                               -12.243477749394437,
                               -42.589882935615151,
                               48.821020109068726,
                               -8.9924291578752307,
                               71.612570025112518,
                               57.957177842439208,
                               -40.869500616966796,
                               -55.048361504203591,
                               -0.60809972934123557,
                               -22.347257986954425,
                               29.955768062745566,
                               59.62607251690423,
                               -20.890391030040934,
                               13.566568357020515,
                               -4.0448488939085916,
                               -26.780086831035,
                               73.578056426131752,
                               8.260329052386064,
                               20.086839279004842,
                               -60.26601971085492,
                               9.5012416730282911,
                               59.117971378993317,
                               -66.929421135207491,
                               22.077422670522051,
                               -19.948791476658332,
                               19.50390588338934,
                               -6.6280480762523553,
                               46.205775284979644,
                               45.706503630267036,
                               -8.5358078018962029,
                               -56.284313513011227,
                               58.368433840891271,
                               -26.856430882080176,
                               59.297721512137826,
                               70.388213028502875,
                               52.299397523884693,
                               -34.459141795462841,
                               -21.47151510995068,
                               -44.51415801701647,
                               -30.890118357295961,
                               -55.881033963149179,
                               26.059093471271069,
                               3.8467768635398212,
                               -45.130094475456374,
                               20.943537299510279,
                               -15.164423554797592,
                               -47.505367381305504,
                               75.821171870737018,
                               -65.094141808364881,
                               -70.39448330917611,
                               -59.83671036298044,
                               34.312430511176188,
                               -28.413256016269965,
                               -21.758135228052559,
                               49.393235518414279,
                               -31.330882176432731,
                               79.938497780749913,
                               59.269433991733884,
                               -12.908074712498072,
                               78.679901318657869,
                               -7.2110634717071562,
                               67.854479953921768,
                               -56.166490580426334,
                               2.4357442058071435,
                               76.80595347761772,
                               44.484733133505756,
                               -55.213470601281557,
                               -8.2472276506401538,
                               -1.8802190815952322,
                               16.29780439562218,
                               18.149413467659329,
                               -9.1199712257056582,
                               -71.938558690450435,
                               -41.817761622525239,
                               -44.512099219997545,
                               -2.4206523766674817,
                               -18.564841268485296,
                               75.302515640600973,
                               38.016177854796069,
                               61.702030523652169,
                               22.461707379683308,
                               -20.806128217647114,
                               62.503092264160031,
                               20.557179629769884,
                               -3.3643222715878114,
                               59.602917680374198,
                               7.2353192602077083,
                               4.56172937053827,
                               -65.470361335888796,
                               -67.859739758716742,
                               -67.781226821379818,
                               40.648806802723911,
                               6.4635099547350574,
                               -52.766936810245184,
                               -52.366726381623565,
                               -29.414838817754706,
                               71.532211933871309,
                               65.075562521010852,
                               14.166721527756852,
                               29.185251413862083,
                               77.714699345955339,
                               56.742430287870192,
                               -29.926448386599354,
                               -37.068979444800277,
                               -34.20708322506966,
                               29.595552867498778,
                               37.404992701936379,
                               -33.062529346524656,
                               -53.399742425038696,
                               1.8228902188548144,
                               11.21360116457697,
                               65.511817022729261,
                               -39.537240538745145,
                               28.557673457490395,
                               -17.463585618426006,
                               5.8405220048919588,
                               -44.062886926302426,
                               42.588419148456019,
                               68.283960583041534,
                               74.440319371972706,
                               -57.566582095407256,
                               39.838642598614314,
                               56.712351013539944,
                               47.674519037545188,
                               72.937047868846165,
                               -34.299982141653089,
                               -67.656237645353457,
                               78.380776893315044,
                               -65.181294678670838,
                               -73.001304388772468,
                               -22.033914489043273,
                               70.933905077417478,
                               68.531178141455129,
                               -50.246504744395644,
                               36.597593752241217,
                               -52.568453828016843,
                               40.383162388217741,
                               1.7541216978433898,
                               38.620319027991926,
                               -49.692228568567771,
                               4.6317578622330409,
                               9.1417153982521295,
                               26.958535914066339,
                               14.021616062760009,
                               63.711892493968321,
                               10.932926644894959,
                               58.063569665210096,
                               -11.995105818212792,
                               78.163520655910574,
                               51.905534649147043,
                               -19.102464263829653,
                               73.95826292930002,
                               70.737796060243866,
                               0.72081771957718743,
                               -40.773779672768434,
                               -77.794096121399065,
                               -22.66346921180866,
                               38.050978192803498,
                               17.585434394909033,
                               38.240078631124568,
                               25.911544882844478,
                               10.56700746100163,
                               -8.8089030948520275,
                               62.146448923994562,
                               -4.4519476240112521,
                               -29.780405822749685,
                               -15.586280462669766,
                               77.826360464499245,
                               49.965039902392412,
                               42.796423474052574,
                               32.967468351037255,
                               49.034137456813895,
                               75.126239230688057,
                               27.100041186142615,
                               10.738659727818447,
                               -47.926726016842821,
                               26.881048481333771,
                               -25.129642606627115,
                               -0.96992374585218855,
                               -28.51026032346752,
                               5.1508349309267807,
                               -42.937287780279313,
                               -36.889537445047132,
                               66.972452214537256,
                               71.940622170238157,
                               -54.395805671877952,
                               28.035647520799078,
                               -54.644502091786876,
                               -55.165199572546641,
                               -12.867232303572289,
                               58.863056143632534,
                               -64.578077920452571,
                               -42.770565626400391,
                               -0.73435541646058233,
                               -42.334136543094615,
                               9.2438220190785483,
                               47.299138434814047,
                               60.881798731311264,
                               -54.679703605311516,
                               -28.254111960656026,
                               -48.132740464608723,
                               -55.307209070638258,
                               -49.72372498830228,
                               67.727704534618368,
                               -0.14099538672331491,
                               9.1675418763277481,
                               4.8616259644424389,
                               79.874804839924877,
                               16.484322614716298,
                               -3.4677450015354196,
                               -56.641989936922975,
                               -67.972886546325,
                               8.6924791399976176,
                               -49.372994860099624,
                               49.976013317116809,
                               66.167651290904033,
                               16.863642546723817,
                               -50.266355836339876,
                               40.530611849741163,
                               -67.264720231101975,
                               -27.096051535577935,
                               -38.797062200514347,
                               30.335274042235731,
                               71.04299062830988,
                               -78.669505651944647,
                               -61.090558741348985,
                               27.657770569060961,
                               -53.267246256316426,
                               54.149017886121818,
                               7.9696717939633483,
                               41.718652658318966,
                               -10.359038380021767,
                               44.786960560709048,
                               34.844705469156466,
                               -46.526900691930116,
                               -37.13248551369589,
                               -25.470984089569427,
                               -1.7658351459353181,
                               -8.4125574322900469,
                               29.834760742128594,
                               17.09393435912326,
                               -21.308010954951534,
                               -72.192010263916345,
                               -1.5174665905338074,
                               7.9445970950431146,
                               -71.168610459927265,
                               -48.386336465084923,
                               40.500063419869711,
                               9.1082907372323056,
                               -7.5676007571621451,
                               34.998126226377707,
                               -39.840751407148737,
                               34.274994548648067,
                               -46.599994406774627,
                               -75.598883906849039,
                               -45.085742785753062,
                               -54.357788511417645,
                               75.672208728074352,
                               14.334265180681092,
                               -19.014358704074834,
                               -39.163814130266317,
                               -60.313870922920579,
                               47.567333346250152,
                               -73.544141710006556,
                               -44.872371781859229,
                               -8.390833059238993,
                               7.1444956525570298,
                               12.107987361048195,
                               -19.798631370028367,
                               -58.783325265235341,
                               49.347952837034555,
                               7.868900057659916,
                               57.920880866135576,
                               60.547721571707854,
                               32.89561851820465,
                               40.082129628781161,
                               -64.929297115019466,
                               -59.837916894200958,
                               23.722742006342621,
                               -39.163042487876325,
                               -12.996592822795723,
                               -76.979360437734314,
                               -27.891446987677632,
                               -38.694686668594144,
                               -22.82783386778604,
                               -30.554452189708407,
                               -50.720281087468877,
                               -66.587910599404381,
                               -3.1189883430575662,
                               71.97365732037683,
                               47.398463035391529,
                               -47.176827308316717,
                               18.867703622775146,
                               -20.240705193119769,
                               -19.512864862463605,
                               -4.5498335333204238,
                               -23.229875560374602,
                               -76.905059968974527,
                               32.582112487165311,
                               -35.68644913164264,
                               -71.382376980831651,
                               -7.1588451515846803,
                               -12.398913885953387,
                               -76.326359488508842,
                               3.2591820029699541,
                               -68.120483888203523,
                               -12.860721300299968,
                               -20.474508703988029,
                               -68.062312489297796,
                               -56.890714260812246,
                               -78.271263414151065,
                               -2.7351054595391897,
                               47.302952916167499,
                               -67.599554976288516,
                               4.1681841133367374,
                               -48.384679713920576,
                               -50.452624657911514,
                               -36.82880374112694,
                               -51.940222813871017,
                               -38.38657698504332,
                               34.483545935032005,
                               70.582749238204244,
                               -60.968456293032979,
                               -21.012479704307154,
                               3.4321959386238561,
                               -10.022739477121638,
                               -51.763399099914565,
                               -66.30764973821222,
                               -18.248318284691365,
                               49.368835718544915,
                               -12.302474190221844,
                               25.362906215657482,
                               -32.909282565512342,
                               -47.5579358694212,
                               -70.681097140728326,
                               -64.883456131931098,
                               -55.112903382083886,
                               63.763940999219244,
                               -49.603583696602755,
                               -35.546229466987029,
                               -42.141401021615003,
                               58.597627834048623,
                               67.442713804864539,
                               -73.766607857252907,
                               -79.781510933386642,
                               35.514494956498574,
                               45.017459078445896,
                               17.350769662049366,
                               -51.470369861045903,
                               78.150762545497201,
                               69.680533148374124,
                               -78.535069714002717};

const double shift_22[100]
    = {77.637862306372853,  9.5163849579640782,  69.374706534753443,  35.254912960119697,  -2.5538373100253153,
       22.244974828996845,  62.021898542336658,  -48.202119984172604, -16.741396167166371, 78.74804839924883,
       -15.623741290248304, 25.417036971668978,  64.215699685521855,  79.261084242861813,  24.506124975150456,
       -62.650171543117636, -74.221755072743036, 18.894598247515802,  10.743097903679285,  73.914345248852158,
       39.37687510702203,   26.002575749613072,  3.7301309459215304,  -38.416914962496413, 73.919002706587634,
       6.4326460021632101,  -75.156773852837006, 31.410314145780362,  3.1545852673404937,  -70.555111093682541,
       62.405797316514111,  -27.167641197756716, -43.247808340620878, -61.768217280769733, -30.252365847423079,
       -43.450828458282018, 24.319546754720506,  -69.414380064267718, -35.930979222253292, -34.908761990261311,
       60.81060155616899,   -8.9071426081224558, 40.946259345273788,  16.527420130455752,  45.322549984645804,
       -61.771097811451853, 76.570221625596474,  55.775468076727833,  -71.896560372713054, -5.4077065934982471,
       -27.895476008314631, 20.832819999959952,  -43.152133795572198, 12.781595725006241,  16.505011270383449,
       15.980655333257118,  -8.2515391385735626, -74.332246290753844, 2.21037360612425,    -14.763174116378082,
       -62.712634141510577, -6.4198993692297677, -7.8587594118671404, 8.1824537287070029,  48.864690721279629,
       32.136011645769699,  59.557680627455653,  -71.64925561137585,  -44.850990175144631, -6.4572783821813573,
       73.365375380641524,  46.407257116710113,  -7.7000625531998566, -26.651490166261368, -70.544749971187102,
       38.544848462974016,  1.0871238488803954,  -48.011933897703258, -11.649031823793905, -53.009555406036611,
       40.271134536749969,  -21.063865339391924, 70.69084723838148,   -77.252393454285226, 52.648945404608099,
       20.254555992844146,  6.1994424251550697,  24.081221660809689,  36.260725169042274,  -64.881829772707448,
       60.411829489225568,  -77.702056968642268, -32.911579704602048, -51.213619439321576, 68.207082911671989,
       -69.091130107674473, 12.974916412558628,  21.944195604035954,  24.203082362390774,  58.33952200536848};

const double shift_21[100]
    = {39.178856998667641,  62.762750116977173,  -41.183458195252847,  -59.264483865993554, -43.989138859533874,
       -23.997772959877409, -34.066461896611827, 68.398081148708457,   -71.789798909312722, 14.826680833021854,
       -53.936175965162825, 54.144923147684835,  -53.190251166196667,  0.35209846551563828, 79.892716644115097,
       -23.134855797138997, -72.467566472186576, -45.814306380672143,  -16.345740143567156, -26.613091139152836,
       -43.263594885088388, 69.779228400330936,  29.310205551997228,   73.938207315658133,  -9.9242915787523032,
       70.453864707345133,  -79.06650806842066,  17.649124811180045,   48.172121114579113,  -42.722954653816302,
       69.194988147356582,  42.122044053398696,  52.23192635242907,    11.754174176778577,  46.813066259236138,
       -27.353408665720394, -44.2460838198636,   -30.018185276919439,  13.523756564568885,  52.786262563443643,
       -33.526001352437106, -15.591297269900394, 57.929167749303389,   18.358328034623938,  78.590046132766844,
       -47.408179970300459, 52.353453591464785,  28.137859032443885,   -40.168084793630712, -3.8742997488747903,
       -16.147963723713303, 15.910119854625933,  48.083642528616167,   -63.188996593412682, 51.43075106022269,
       54.573812807267615,  -23.279000895929741, -11.188885981466655,  11.558274946029542,  32.13195692339788,
       38.795161117964824,  41.261464099325664,  -17.7393978289237,    -11.311602400026004, 73.015145200105394,
       11.675418763277477,  55.955528674987789,  -35.784749392284247,  19.571778424392065,  14.137869538166228,
       74.15495452911864,   -66.255568805239847, 0.079822656632089206, 3.4543482396887839,  -65.573439652965831,
       64.746636750420009,  61.502230161577671,  -9.7616533111055617,  45.0756180667466,    -56.245596329054649,
       19.17054836173935,   -38.300211296892698, -8.6950061696679626,  55.039921835989787,  -48.607213002999679,
       -31.383740355575611, -2.6728691625143028, -25.950072980636207,  47.757732723447859,  77.998012030296479,
       -54.552391244416881, -42.099234683831241, 32.357861226862468,   -19.924533968392417, 75.792784427997447,
       75.568888910153134,  22.991687907424762,  57.615820296665703,   -15.698656318706298, 21.108927676393137};

const double shift_20[100]
    = {-49.050599689745283, 40.707933038120018,   -24.598285333635999, -13.019933711565926, -55.08482714321724,
       51.04009342829454,   19.98776445540436,    38.169667457703639,  48.817987313112639,  -69.244374789891424,
       72.126450640890567,  -0.38767823645429189, 40.823344752083528,  38.784811308310694,  52.980732113618103,
       -54.959704519967758, -6.830604711774626,   18.896079375100939,  69.149336807528073,  53.614117689496197,
       63.267762614776018,  13.202963946884822,   13.239489017886626,  56.788150235192802,  -74.42148799233108,
       61.667215277568516,  -14.763070183042913,  -74.178875128346874, 39.383670838035258,  -55.227396679823087,
       -56.974667412021134, 16.953448531799538,   -39.283064951781043, -28.13532719906847,  -15.713453144480226,
       -14.98026857581965,  -18.209417830254026,  17.568291814072765,  -53.297484373400664, -49.905268288760269,
       -64.859380822053524, -28.29019635819769,   43.135508683573605,  -42.541119606560244, 38.458475139881969,
       30.850946213076682,  51.852514138620847,   52.476407862317899,  -33.061130558657283, -30.500921212360161,
       3.6847677507188905,  -27.95216120089183,   53.094801677770874,  49.64716651901449,   9.1197218045774378,
       -37.925754603174852, 28.890592368712035,   -42.615496729218414, -6.9719416619020933, -18.469296878156172,
       6.1762301916834872,  78.672595353912754,   40.835264268452832,  76.872775908859893,  -42.434777493944367,
       4.5694541684264181,  -71.770231429294739,  41.100075357539566,  16.316762604081632,  57.146993459553414,
       78.124342281298283,  68.717515588098792,   -14.477610649789554, -79.945366045097771, 6.5405316420869184,
       -46.763100480630499, -44.914625890811152,  -27.870997962524498, -64.648093342786481, 39.605385878128487,
       39.761433182926709,  6.927909293617418,    -25.898829356151495, 53.173385859284508,  8.4115484841532009,
       73.206898713923323,  62.85333109088026,    -22.959421259679296, 7.4243028787019512,  -24.530919799208149,
       19.648446505460853,  47.459949649343386,   39.339984246503988,  -59.914202983228847, 51.58304108144327,
       -75.975919771439649, -13.691379052154943,  37.025194875669953,  45.019840044154051,  -21.234253578980962};

const double shift_19[100]
    = {-48.284512877785772, -48.788554674518267, -27.705656264003892, 60.854057660671941,  -4.6237015974802489,
       -15.364900452649422, -51.322963772248528, 75.027999383566709,  -14.807081951580756, 55.117983437351711,
       18.452015540935918,  -19.74222751476205,  60.349079893935539,  45.576388365283805,  -5.6073146696745226,
       50.236308291349417,  63.751061948819256,  -11.321833101627618, -26.507292860444842, 15.463536711239399,
       64.318529393049943,  32.33063189754813,   -19.607183668661619, 37.592948068802315,  72.65644583539418,
       6.850098096568189,   6.4169331774985352,  -30.222457663359691, -68.602468492066606, -50.88312525295656,
       -65.121771700691525, -5.841720358041087,  -78.506798075556901, 66.404145877726364,  22.838678261296636,
       -79.77295068761552,  -75.138356400813166, -46.644764271148844, -7.205416799664448,  -59.637434667978653,
       -78.616369939505546, 36.332736183764354,  -23.341365430946169, 44.871351375363957,  -10.13493733835341,
       -10.151234820437082, -72.125891142962189, -72.058895756897556, -65.423971933911375, 15.045925031059397,
       -41.426551172956465, 54.619056315542991,  57.154042254496886,  74.177952152216761,  -1.7760342143033654,
       -44.750383909018723, -43.806617465394254, 5.8860487220521236,  41.937553473783581,  -24.389255928198509,
       -6.2029184973601303, 22.291801951897014,  66.773766538695213,  -54.148388177547062, 34.501664666795762,
       12.438220190785486,  -10.67216364654098,  61.478845220975018,  -17.111719139693946, -51.363975579562862,
       21.333372851219451,  19.840088689975047,  -27.529344484280202, 48.474450553317922,  79.916457381742731,
       76.956505749143417,  -59.674089248822867, -42.841576646113175, -76.218805334683992, 17.18921766429682,
       -62.270508594055997, -14.806478739456168, 61.452289065913874,  7.7012443962539976,  -20.95950772614124,
       -46.664642749864512, -9.4490757561082432, 72.991384348140457,  -60.155853336313086, -4.6778806612869062,
       57.103412445150923,  -73.057524549287493, 30.660023232208886,  76.637674668006156,  -34.677136241258104,
       -58.595120000892308, 29.644749506029967,  65.512728919903168,  17.73903718131892,   63.997247429257726};

const double shift_18[100]
    = {54.120894005956131,  13.554979082131254,  71.697397663363546,  -70.235371329198529,  13.542608536817681,
       -34.3827062946173,   52.437147751722108,  -49.442169488416354, -9.195206047538619,   -17.054158981187783,
       52.251836646842406,  28.299374950147026,  -46.783514499203122, -29.103243815957889,  -58.590242343019838,
       27.434062316484912,  11.358572073984902,  -52.83726943576184,  -56.375075655722107,  -3.8272450772069817,
       65.29638664111198,   8.3480042745335652,  -74.729617160019743, -71.381931770311013,  48.810116569424338,
       -7.7800232474482982, -18.776603270406639, 46.342992590350519,  -21.714100880032973,  5.1759895998256553,
       33.865072957002639,  59.436242879335481,  -27.409662132443358, 24.018884063644336,   75.973783680441215,
       -67.845222192938309, 13.923066733243488,  -13.77816035626239,  -30.538171765397273,  -37.786553355712762,
       41.402602412832636,  79.234556980760317,  -50.148568937380929, 44.983242965562326,   -48.672323035722883,
       78.777435708788232,  48.3618511622862,    -12.123726415471026, 36.618218888219829,   -0.26342679623172671,
       49.438442751847163,  -22.95857064303263,  -68.281050481630814, 14.558632843975886,   65.630052916502592,
       -48.997450213342347, -10.821153354496374, 39.865556650881473,  -73.730482136386712,  71.411998368877221,
       42.187731786201795,  9.4112880815296478,  -50.585128885476053, -0.32818959696848538, 2.8552960374481131,
       79.07888170304804,   56.776269294508012,  73.984630353915321,  28.630561436325323,   -15.439777791302291,
       69.596653788488283,  -3.2824726988029482, -42.913342133901295, -16.593560238435927,  32.812396018046215,
       9.3694455296880221,  41.060912143098818,  79.276969368841264,  73.989024698661439,   5.6107368409851119,
       74.219220795474314,  -61.499859330998525, -71.768273083167159, -31.304168698148246,  12.830693302833978,
       4.9543123741250383,  64.193294824502971,  6.4880680272390947,  -10.883102262930763,  6.8267179898146537,
       33.986368926323465,  -77.33204592956281,  48.147341129255722,  -57.198508012193514,  -3.444084335541902,
       -38.906343331258633, -20.945329788022313, 25.882386138466288,  -52.862589847309692,  -35.394556729756999};

const double shift_17[100]
    = {27.563237993188579,  -10.958210735697463, 31.104625549528691,  -38.914469876776337, -78.438616018374475,
       5.1652913697421923,  -35.297285559525662, 71.396824563188261,  65.030922641600341,  -17.170467844142152,
       -76.023162584820469, 27.429887451593572,  53.947301660328719,  75.439942129802148,  -70.890738330360321,
       -7.9481899626475183, 13.195248277805945,  29.862050319408525,  35.109240415359707,  24.006520308062534,
       36.306328146024327,  -20.184373465602938, 13.053133314058528,  -61.421037955295944, -70.775302205620449,
       76.762435836157835,  -34.428203702301161, 15.195887809535407,  73.945764961801558,  -50.275477854627475,
       -49.113629443675748, -25.336943256777325, 69.263663330892882,  -17.493194141184603, -36.285326720005848,
       -55.688467224504933, -16.462585161047727, -20.04440528780119,  -59.021646873119153, -10.393485136699709,
       -65.357893245982268, 18.340313282071335,  -78.243345233470123, 11.721661322139582,  46.35677728412189,
       -42.341316295860892, -8.3168458457518568, 11.097309325589123,  -70.175769233464479, -0.59377829761842804,
       22.770437533647765,  -44.597483179663264, 53.929031285100905,  75.372037030802176,  55.419662030907745,
       0.95991294248773329, -35.379902216763099, 39.458755492512211,  -42.091138541940779, 73.175245059059705,
       19.241605772443336,  16.041943281220455,  -52.383279736373026, -65.544521897084067, -39.158047577025798,
       57.371285001473581,  65.770728543647039,  31.941402756122002,  36.02917680374199,   -43.218227382800563,
       12.168553011416705,  49.700496801270276,  -15.385061058549496, 78.150282751959196,  -65.600189602097871,
       -28.649434776358177, 1.8254302110684648,  -70.302981349081236, 36.110067767335025,  9.0489197699187116,
       4.6975843970010658,  52.797189125311263,  57.401445451488627,  46.244627730231841,  -29.146711403803437,
       -7.6468073979229132, 40.356475207990769,  -62.422127079890274, -62.44122102497542,  -36.818613807295861,
       3.9419752634097449,  75.624172316399523,  33.665389644507115,  -30.102408776394739, -33.366859576363623,
       56.057173979939421,  65.863587841256532,  22.284183564170206,  -39.14075232888905,  -65.81346559483471};

const double shift_16[100]
    = {-57.559142516888912, -38.379168942009585, -66.109583861466618, -11.296426066271152,  -38.834754436822422,
       -32.391138535821057, -12.022654127259869, -60.926838492594072, -0.78929219192653477, 33.025156406009671,
       -41.028260371047871, 45.611213109440968,  -68.1456677022517,   -16.978651682928536,  -79.456940325710818,
       -44.691697290716164, -79.791909007904621, -49.731252640842371, -57.202551228644566,  -37.107840140259839,
       -52.017269546274747, -57.816164545184762, 15.821697658858398,  64.169264909236091,   70.300762541478122,
       -44.61048704974754,  -2.7725799365737913, -19.838221452039271, 3.8048059145391164,   -37.620385032225627,
       -69.062844724667343, -10.18766760318357,  -52.183514021599834, -75.822862695215207,  72.748523852871926,
       -11.104556822493237, 73.849371696586104,  41.986317440478871,  -78.824214223544487,  28.806182473622201,
       32.952120679821348,  23.220605857181198,  8.3695751212367782,  -45.1026032346752,    43.578594178086817,
       -43.515468223927968, -20.66164496425516,  62.548611364111196,  57.020305236521722,   -15.610632029848944,
       -29.11694120052239,  17.381668901598331,  65.631236271117075,  65.455710048141157,   14.655105425190058,
       -26.788574826311816, 56.490180673587076,  -9.2163371134135872, 64.696876514871008,   -74.691295047659608,
       5.1882372000212058,  34.639575440701094,  -51.311704988513696, -26.154731871829995,  -49.965928227957228,
       -28.491650690732193, -15.382926203166932, 7.7706079771141674,  -72.201825154837337,  8.4371413086307996,
       -36.030175225999898, -41.359721322542043, -41.096771294951907, -55.334488132788096,  73.026617761283859,
       69.705820082656032,  50.994309953319004,  36.521895651653452,  -51.87012347591525,   -22.340643673207424,
       -49.7936043773432,   -79.80825650559305,  -29.372877802793113, 31.938717823528876,   20.040828828646482,
       6.889948055016248,   -9.7540474579729306, -34.011637202793175, 0.26545707947043695,  41.847389707143492,
       41.98528780619425,   12.168944239449132,  39.626054022674623,  23.285520957011443,   -60.284877068079012,
       0.70365761484266898, -24.438189964538623, -65.256370431183299, -56.344085114796997,  -48.292847829375717};

const double shift_15[100]
    = {0.6144130954956637,  18.049534213689469,   51.107558757100151,  5.1022671188681272,  -47.667984552250942,
       -7.3770454911164904, -11.534252828772665,  74.568439937919834,  19.208808661355789,  31.262392306880571,
       35.226337922876709,  -24.496769553981821,  2.7184672840496376,  9.0711411219363072,  -54.960764941752878,
       9.9289672898839711,  31.168526257352994,   -11.767114286362016, 53.803267308210252,  37.021930585909288,
       -22.395033266276542, -7.3260205034562205,  -18.177616225252429, 44.08874276008568,   37.483376909750291,
       -11.155544788135103, 31.000411861426159,   71.234157946953644,  45.477215717078536,  32.891497300971011,
       -62.506521676104683, -17.611094854962403,  14.544756864853824,  -6.4991923253879378, -71.945602121767337,
       -43.409986556764665, 53.47024976910393,    -77.496849168555684, 58.193738408938515,  -67.508951514810519,
       27.046814413048864,  0.033811884976387319, -45.120992199975433, 11.458516064654262,  -60.449735852252843,
       27.386597278184468,  15.933687699650221,   -71.043814817953518, -70.98511703306292,  -55.599898079604756,
       -76.86062931750655,  -10.371912688487711,  53.155436045250838,  18.782427432653478,  3.220706449718719,
       58.218915669377708,  -64.368333094169103,  65.288352509883055,  -62.71732893811857,  2.7194812955111871,
       -57.095036466627818, 9.4992915844806305,   -79.267260168428237, 42.669119779437992,  55.79347623332518,
       66.691403240598078,  77.914923965385299,   0.82129628781160591, -36.572540093197588, -63.879918092602296,
       1.2558129327258598,  13.697460112300547,   42.061935345718538,  -66.725976142312987, 25.855390893234272,
       2.7166423529941,     -52.632317195928451,  70.169258293094799,  14.477308342811469,  -9.4984510782655889,
       70.707028849805283,  24.946211241142606,   -7.6886865183382724, 54.351587315147043,  5.2197603958954062,
       8.6219305266040038,  28.810484813337709,   -21.249615149221214, -41.713503009032742, 12.627758793454973,
       58.701928747601244,  -14.915718365563905,  -61.98157743599252,  -8.9846661236868215, -31.970495805775997,
       -15.778103389681149, 53.338170152501505,   -15.419413956222868, -17.571849899102943, -22.328177059368869};

const double shift_14[100]
    = {-14.923693585701798, 26.70904531319978,    69.396105527348737,  49.752005158122415,  -2.472276506401542,
       41.079873610481954,  -13.272407401157281,  75.485758878287044,  78.075952196933116,  58.263604644992427,
       -17.778595854011442, -7.2413075137421146,  -40.53004837790732,  45.507694883868339,  61.254016893288394,
       66.193869006882892,  9.3255877795640032,   15.818896439392859,  -56.179724745992146, 63.954157525718159,
       -7.9370270956615059, -47.092425685765846,  63.944158481452916,  42.013686299716312,  61.197809184047685,
       -34.407965116028606, 27.716157832361233,   26.284784706888118,  -60.349600976075862, -14.829052310909944,
       -35.954087789489591, 34.667158502262666,   -34.65849893937019,  63.391817095919265,  52.252622770169637,
       -17.595757949760369, -0.33552912573014737, 31.16883082759901,   53.499040175990046,  17.540750348117186,
       11.957945737025284,  -27.833252652353394,  -6.9720638637204786, 34.20729331730152,   61.504807244159196,
       35.336907330709039,  -77.021956043778218,  27.964234740525725,  -9.8385881221579439, -9.9487713333967918,
       -61.274108879094754, 50.349070322973148,   -28.023129819118552, -40.603501722457374, -25.165884620275278,
       -19.889257598465875, 7.4486068932734213,   9.9072246825562758,  -16.668443420159846, -16.299059274986263,
       2.4587550738515773,  25.204886735345752,   72.146431722393459,  35.575762292399673,  -15.987240742025989,
       53.09941429276958,   -58.505865323406695,  -70.325316489627454, -66.520471629654466, -53.77626906724668,
       -28.12481275295216,  -31.723715647256476,  -78.13104141914566,  6.3848150159400348,  -64.740369179548551,
       -56.557622969242956, 20.9825931223928,     57.491265828605663,  75.875460998194114,  11.334148395549363,
       79.49603433199178,   8.5666517592852074,   2.4733527744521382,  -27.090869441557274, -11.199712257056575,
       -1.310999423400844,  -68.634066573927569,  62.038274485234581,  -69.658625431861054, -10.21040708296826,
       52.260721059022671,  -16.874450522714639,  18.155981072841911,  50.982517613153448,  61.797606250017026,
       68.977860397955311,  -49.474456318540447,  -38.626839772996426, 63.658509574447862,  14.937897661777427};

const double shift_13[100]
    = {0.60492572418495172, -1.6649058042633271, 60.327795741607019,  -23.497309929767113, -8.0890309485202749,
       74.164845894948314,  -73.232352333673148, 75.673333462501546,  -49.726905100419842, 26.739248006411998,
       13.830338348626867,  28.017986624818448,  -22.23647212885426,  19.244548331373679,  49.784141616045645,
       -76.918803613737367, -66.580238674736023, 75.968266749582455,  24.215925186456531,  -43.001949413703642,
       -15.441417100065621, -60.476717079659267, -37.049788576434693, -38.74461278198325,  -26.933561801179309,
       -55.642557941928565, -24.318774445421845, -60.534647310763816, 61.464489239945635,  -64.915457589736633,
       68.806500177198245,  -16.15680495447112,  -72.415766075335881, -25.220239494281635, 37.75458542082626,
       47.14914517340884,   7.1849437191474408,  29.795754077446546,  62.981231349376259,  -71.233313612842807,
       -31.414179245277452, -72.60935098695235,  -48.723717818592256, 35.226528402644107,  35.480523759887475,
       60.447851384244359,  13.18927431798565,   -68.690506338136004, 67.639131230254748,  48.059534776177145,
       -34.248502972741889, 6.9861172546178949,  77.564197915297569,  34.508490740259447,  54.235135572800033,
       -10.678310238728272, -4.7000455029534862, 9.7141457671289686,  -36.945353035040398, 39.842954822711377,
       0.62204375367818443, 23.489546603644868,  -30.760706875049486, -57.804058227496867, -3.9083305923899303,
       -22.006515069000642, 46.098148543767564,  44.847331335057547,  26.961954280567184,  -58.639382454190034,
       -76.551058047440478, 9.5745129396015471,  -31.868957108881744, 70.305554219753333,  76.944581767497453,
       -34.140737776918506, 48.131245912245532,  63.377816229216592,  15.604252290852742,  61.442677715811158,
       70.997046591326637,  7.8652939871844296,  36.54189193509707,   12.281327657281565,  -75.862804626697653,
       -8.5550434744297092, 23.408313176104883,  3.3924724275869096,  -20.42997427527807,  69.941546614649951,
       52.725251924242372,  55.853676792712832,  -20.394521616073682, 14.90953203495846,   59.608410343609364,
       69.36025736113686,   26.95428389782009,   -46.915766730383197, 24.616094730014098,  -68.471751804696027};

const double shift_12[100]
    = {45.259531676659719,  31.00601839790356,   -78.431639637910067, 54.914134081681539,  67.573119647404127,
       43.352675307827923,  -73.174423050392207, -19.490218071964982, 32.694339917338823,  36.722087280743509,
       -44.115668693677691, -36.951242916261592, 27.684986400659028,  -3.6012483637021973, 19.794626026790795,
       -42.16881077745434,  -51.660199280269353, 52.742941711613526,  42.707466869642374,  69.516523698923123,
       -62.737775186501835, -50.843599103831082, -64.144754812406646, -1.6377916922484985, -49.080747124980718,
       63.34265180681092,   -64.145656050909679, -72.933508517974218, 9.1672249287618968,  43.59921075001985,
       -30.08959080059698,  -51.362803309706386, -25.767091480365082, -46.376698073031676, 1.6244031624400321,
       65.018291722434356,  20.627830184370865,  -63.754577790030055, -17.463239563783262, -71.261341564214788,
       0.20526611251443683, -10.924612498520446, 79.609655921950264,  49.856412959251657,  -2.2957328163171695,
       63.111640890782922,  -57.992544837269634, -17.599213688754332, 68.376995999699972,  66.799013186578719,
       34.17184185509052,   18.933981379510399,  -25.073937561384732, 69.764372270363168,  -60.036153494321184,
       36.893657840913136,  23.436389188130207,  53.304317707087193,  -16.274843484995927, 39.971553497701748,
       53.635281676500881,  -28.406336422038493, 8.3618586973367997,  76.66066118942274,   7.8893652829284378,
       -27.13222246294356,  19.115448828444784,  -22.298148639647565, 41.041526960311089,  -13.77588020956965,
       -1.2247832984099603, 31.158917301217613,  75.637421612765451,  -27.559206321054916, 54.048509292572106,
       38.251556363764493,  72.6679130207269,    -74.892379279363453, -22.900962210793274, 26.024613485954319,
       -34.959750536241501, -43.138709229205801, 33.780568188852016,  19.931666718929364,  14.497384467141757,
       25.6700746100163,    -72.391252301781435, -24.194430638390578, -7.7855071430810909, -41.455200460782287,
       34.407202127388246,  56.989166721006058,  -34.958768781031466, 36.968132755798635,  -57.957937196877381,
       53.875645079954808,  -57.823725481222397, 14.113501662318981,  -21.41491192720995,  49.081527145776903};

const double shift_11[100]
    = {20.990197483041797,  -23.188215699384159, 79.520523457063632,  -44.132560162699654, 24.392171674978385,
       16.798502705321496,  -18.040730962698404, -57.250054513519345, -75.978402286367498, -12.622039397561394,
       -50.543953691598205, 36.124042795112501,  -20.741970157568304, 54.649613994912983,  37.476750590930109,
       11.364139651900615,  -51.703190779951562, 73.181443615315743,  -37.548474209132792, 67.932943238336151,
       -44.196735248473438, -20.229790777176802, -65.999944067746284, 22.418647719474407,  -51.101297959502659,
       -72.791822804228133, 35.707756669295236,  -24.409976706913582, 25.698691920464611,  -18.581023828484575,
       20.375440390954722,  -76.536029659150969, 65.691198163684561,  48.089385004609767,  39.335597494835383,
       50.098050177721717,  -18.670989019915325, 18.76467717063187,   12.079177552450219,  4.8082727624024955,
       -35.988839068490392, -40.219366454084735, -7.7377967276843549, -43.565947835752382, 48.711933378091203,
       77.77667870335523,   -75.201287956897602, 5.706270506758031,   -66.067644815857221, 48.334630488928639,
       78.263185552054381,  -69.28859865635998,  70.303737901525579,  -77.091594618128681, 29.414178199416853,
       45.397836813314981,  5.4620108612365215,  61.657512148982676,  63.840783824982424,  20.150020172879337,
       -57.940961213990683, -45.151745006060068, -50.85742785753061,  -73.308821764327305, -62.889334631966882,
       18.630957613709626,  70.345761625770677,  -23.287083045227384, -14.29934559047777,  77.495906717512241,
       71.292670245642029,  28.263148549366264,  78.128361970125809,  42.69302195465508,   -26.12811769736382,
       25.981097663916998,  -40.933554113555317, -32.718839866944514, 28.828539396880331,  4.4554928670076634,
       -14.145037854794467, 16.422114885823547,  40.083208947797701,  13.365307881913381,  8.2868023897547971,
       13.371299001234306,  1.891187193356032,   -66.7851636802081,   35.13122157751836,   79.384977807499098,
       -23.274511206892505, 75.401410429344907,  -24.568198191942457, 61.847017881649009,  -7.2488216012947504,
       -13.851633756669557, -45.16286906283193,  -59.895266021979801, -30.573665029309552, 36.176709066373093};

const double shift_10[100]
    = {78.069557592399264,  -52.730876310898665, -38.753239908477909, -16.512109018697018, -68.160836867689923,
       29.45537071392144,   -15.617866768614093, 77.253632223032156,  -15.650562364402447, 19.307511551932549,
       -55.300831123316421, -18.984767288884484, -54.218564504102261, 41.297989012386978,  59.377779506462275,
       -23.875720818257179, 29.685713399605959,  -32.936218597144062, 4.900688617101693,   53.187741805629429,
       15.598430699612692,  -26.35018708716062,  -32.123996266702939, -7.5851933489081489, -12.376695484726014,
       -22.462989124442302, 9.3310719790875396,  38.807258512310256,  -12.106434619889498, -11.303073827807196,
       -60.020358604829944, -76.090557431940169, -33.570357579083648, -29.196706736123787, 24.590421434636028,
       73.109747851309464,  69.716939645580879,  -6.7381865833013137, -41.523456506866466, 42.223671085836529,
       41.49238130097541,   38.503690396578278,  38.990134637972162,  -63.052733322757547, 29.049668875250504,
       -5.8783074250049339, -46.053887159210504, -64.237001969902664, 51.771915828454155,  -51.998442018867266,
       -53.828814434401089, 26.557954625777697,  63.102300056678843,  2.6493133362032637,  32.432369112076046,
       -55.425539740895964, 72.553131181799642,  6.5414529986362311,  28.757423713674712,  -74.14991711224755,
       49.472616207006922,  39.779019484191537,  -60.770077122067093, 4.0072263620174056,  -27.866619397880129,
       7.431910384490962,   -16.179079618688164, -13.58505814191254,  -51.0819583592329,   -39.138121521911877,
       -76.714276054690473, 67.788098019265163,  24.591982241320466,  69.218171527770266,  -53.838021035595901,
       67.375560942751605,  47.145261662200511,  12.383071473063794,  -9.5943046783594212, -38.781802126009964,
       40.311423018791999,  -43.412882863119776, -69.730066017296224, 42.772721724251909,  27.392349657045685,
       34.434002365734415,  22.729732549416354,  -12.952273020018708, -17.478066847332073, 50.582416460051633,
       -29.211541815064059, 50.326363664104207,  46.251762390233324,  56.362222455015313,  0.90185881148099156,
       21.705822217820298,  72.143106460501627,  -8.9657351969903374, -70.39698883528385,  58.679983519890982};

const double shift_9[100]
    = {29.394491585337306,  -58.866727085829957, 35.635926345082538,  -62.343443097224224, -61.20114365570673,
       22.514867674548086,  -27.389725638911564, 24.60992361532378,   39.86103409656306,   13.309717032780185,
       38.40517247804442,   -42.427693640335313, 37.59320667136835,   75.295764013858332,  58.70884668030655,
       -66.202475221840587, -21.370141388928175, -20.928191307197096, 29.604555625857486,  15.670661661422258,
       46.298230982704865,  -21.175533049939688, -47.035542479168853, -66.133352416714843, 43.509426735857176,
       -47.092076565638422, -17.876539032351729, 8.2845651131563898,  -43.367479676304001, 22.710499263869963,
       -2.4831404162911355, -55.704715981397342, 45.109114654080301,  -63.902988422012555, -32.949386598619448,
       -42.020316847107324, 4.9395611244685398,  -65.360202985694045, -15.149532819105389, -63.224600461478957,
       -62.034566055035739, 45.50846251902604,   -33.348749134891058, 16.565350200141893,  74.307626754544202,
       -10.802400964742247, 31.160351138870425,  41.295884046312651,  -10.77722781646392,  24.879686368565984,
       -62.439191884311747, 69.401575741653176,  -50.00627097253016,  -37.411385774777784, 47.65284163385553,
       -1.9833959305722146, 43.033322249419058,  -16.638920765139972, -36.329792940209501, -74.042458548747518,
       27.727186257384503,  -11.269686519703512, -7.7217224152423114, 17.577147086434564,  -70.495472502675653,
       -29.470169865781429, 43.635540938069553,  31.429278240975179,  -59.946851022531206, -59.175767937692228,
       -65.22362580492775,  -78.748753028906421, -12.302498373733357, 24.891707990066294,  35.667603950723901,
       4.9934869731902012,  -62.589129876312732, 21.082619764558217,  -59.760021547311538, -58.51147130982806,
       -64.22494516624036,  -57.275640250891456, -53.079792241355563, -48.600172438887142, -29.20323597609034,
       -29.371360136593445, -45.189870492348696, -39.833304637482229, 62.867584845756312,  32.515715929006575,
       8.9180708351018581,  -50.490613158775481, -46.075065194828682, -67.624510701971715, 66.208065724730858,
       33.074434831508896,  9.2462346807801907,  -29.851361610145389, -53.407429935655898, 19.599561484783237};

const double shift_8[100]
    = {9.4452071981912127,  56.655991883750914,  -24.339328907638219, -8.6357363111835497, -71.32168248941926,
       -51.662794593742532, 26.049289913755899,  -27.067360767471271, 63.757782053487915,  -61.095168248526299,
       78.146868605596893,  6.3971358460686645,  33.106787091642047,  79.918659215632744,  -33.944104829578038,
       -13.676393777102646, -5.6256093399780269, 42.233132558713052,  50.91264622522732,   -63.96455356872135,
       -51.501287378117375, -22.458413842867145, -70.927249749073411, 3.5017077858046832,  -26.264164051692077,
       -51.892955251894278, -46.568532161098339, 64.824569440714242,  28.0625883737995,    -5.0450880153604203,
       65.94119587833967,   -63.358148035299436, 39.287371792274769,  37.802792895462161,  9.8978280450619849,
       -50.528944397515758, 15.553816054056782,  -32.01008158563377,  -58.54033074741082,  -45.983754662585135,
       63.190668070530307,  -68.567549954072874, -41.202150570124886, -71.399297246605784, -9.3244708696921776,
       -77.874687925239598, 63.550616155771536,  -48.534689381178886, -65.060717319185116, -30.821296065932785,
       -7.030773305001361,  -63.732897020039175, 79.262356424814669,  -26.865146647600149, -32.42450945793253,
       -70.072764588858774, -32.280964497957783, -72.583797616291079, 0.86850279323246582, 41.828141870418136,
       20.971199874174971,  -65.617335875825319, -67.062012299149814, 44.358485847830906,  64.821559075771347,
       5.4035122827200297,  -62.535326073206633, 52.129417256895721,  -25.9043649916525,   -32.96431151576256,
       39.410148432588699,  -78.346141065056571, -72.248425719484459, 26.866579451779785,  16.554877412923119,
       4.1763945272897871,  36.753511715716428,  33.160557650467439,  45.020328287884354,  -33.923683901732602,
       30.805117821843012,  9.0671735942420071,  -16.55667318694519,  -70.145493271365652, 44.828085038587773,
       -25.986581751672787, 17.258545162071329,  38.600647920354874,  -63.229881284240065, -59.53785923472077,
       7.9264171224316726,  -2.363294626406514,  62.476108669510126,  47.833644610060702,  37.494573391355161,
       -71.786898222020625, -68.338352144163821, -65.835606452044729, 47.736138258232387,  70.88130233131244};

const double shift_7[100]
    = {56.114027886241189,  9.6895243767815629,   68.737418681066117,  31.466752088836415,  13.246554428134402,
       50.463553836387376,  60.642224735548439,   78.225858572734268,  -79.916419942888837, 58.47017456208394,
       18.01063511743979,   78.392032913412947,   4.4288110941507739,  -3.2762583663649991, 48.215616883512354,
       -43.545130287033302, -0.30491340857764726, 64.136398165120767,  11.945795060830022,  55.228509608645851,
       38.182446719264291,  13.757925732236131,   -40.52247584224402,  26.626594771114881,  -66.642749823580374,
       20.153565627453318,  25.751129271574769,   36.760296850755367,  62.520338612051546,  77.168515661377029,
       43.044653653743396,  13.031438060063635,   68.530089970270069,  12.814458521350659,  -77.282729866038196,
       -60.662468624230698, 58.033714991947136,   -2.512558206063602,  55.176907932202113,  -46.495186556650445,
       8.366614646203999,   20.781341610307393,   -74.881437477989294, 18.354147058742484,  -22.014166036311579,
       -72.07478735327021,  -1.6688017316285197,  -49.198336630068042, -60.306600392648768, -47.120932654771224,
       -56.557614301617619, -49.748452084381789,  -73.175614254217066, 21.631666697581124,  -34.901303059131209,
       6.175468487254463,   31.226086311093127,   -0.1414378427856775, 5.7281689201781205,  -8.770693552633233,
       -60.170835584308776, -1.5428330451170922,  56.47970485453061,   59.828384937877331,  -36.752906833168382,
       -46.646182599789796, 10.396731318112188,   22.449892026041297,  -13.275367737138239, -47.043917514841063,
       71.669299406906987,  -66.868606864363869,  -63.086491746924565, -57.273420495360284, -53.366329459772679,
       19.353383029649336,  11.793562374591716,   -71.667537554260861, 68.992221537319949,  36.58586906852338,
       38.054664607614427,  -69.855279889149088,  57.670490086117098,  69.504819033794149,  77.503729958555454,
       57.430210669418585,  45.689438282404893,   2.1403869740119887,  -51.583606319061595, -16.225680522265108,
       -58.570999841924603, -75.057672200807758,  70.262672971127671,  -31.791029666177252, -32.714586483942973,
       -26.730194906211949, -5.2690900753836161,  23.711745034585135,  -75.963490961114189, 54.753057987093513};

const double shift_6[100]
    = {13.159866324356329,   6.5182939399055471,  59.190565177281172,   -37.635355763899199, -29.108147923030536,
       -60.925673431329415,  70.372715255187302,  23.288299995603765,   -3.2858840081779448, 22.29071376641734,
       7.1545776842820601,   23.569836846900429,  7.0217494399422407,   35.367459292769823,  3.5992489243363366,
       78.992739859336325,   -45.011738816058582, -63.072276279963489,  -62.448405676288928, -69.825380643983095,
       -15.267200662779871,  -8.2603340693607521, -21.469411705892597,  42.160742535810144,  20.463420738267004,
       43.516861688679214,   69.256571244611138,  75.638536640482215,   -49.275464091556017, -57.780127547335155,
       31.40261393327917,    -64.988795716021514, 4.0647046174937174,   4.8550749428581383,  57.782369822933191,
       -2.4234666316637004,  -17.046982205557377, 27.428982347844169,   38.601270952673033,  3.2083947824618804,
       -24.365972595595977,  -56.000439386930708, 13.774730757033907,   -38.056749163550819, -72.887345235481845,
       40.789322756988668,   -41.154342748646101, -9.2156299196890643,  30.04737361921714,   -22.523486335702302,
       37.814411888192282,   -16.846803955397895, 29.346538714876544,   32.64758885348256,   -9.2311338586606695,
       -76.867580231469006,  -27.062739165748638, -12.110480506698011,  -36.756732250869547, -48.471392304727075,
       51.475389593809581,   -11.212574498677384, 62.043352681016614,   -17.410720726213867, 43.058301982127304,
       -16.513357277821342,  49.362255341975214,  40.812335841133361,   -19.616712826383548, -45.436973446176907,
       46.465154874706144,   71.888625895967493,  -27.589530547967165,  27.40229927227837,   -9.816802786087095,
       53.360095294236032,   43.016680388738394,  -53.239432720844526,  57.916876592331562,  78.379544581040619,
       2.3077530409127007,   61.484963700312846,  14.0841688493596,     -55.239624215032848, -48.021948342807676,
       -14.88722605777491,   39.792914914510632,  52.09341052578489,    46.394084791124925,  -29.036120736161251,
       5.4502603793162194,   -65.607891396707032, -62.127080929087448,  -58.193192169872212, 28.584368768030117,
       -0.77167694565430622, -49.646335037187171, -0.79906800156466318, -56.382684483729818, -71.204136495009891};

const double shift_5[100]
    = {-12.338289743986479, -64.923305777962454, 15.763787001078583,  -4.6521189826665648, 31.351890128257267,
       31.982055988526653,  22.16492132349407,   -74.623386229371278, -68.991024141111808, -28.864042371120618,
       4.9382849110602365,  24.711313241130611,  -14.780928473415585, 51.196995645110491,  34.93743091294138,
       74.983892836974974,  5.0134250505079194,  -27.976690908710395, -63.099327467356488, 17.753385399392101,
       44.608358691854804,  -12.247532965961881, -65.468274274009687, -37.364561475348417, -55.414925185390942,
       -35.039151594580659, -9.5863777597246553, 4.3428386817043645,  -6.8121014899721644, 60.05945577666958,
       2.8883373377766617,  70.97961992774205,   22.033455691547843,  73.231030374653329,  -41.486874323174362,
       28.179568618200292,  -33.749668532083717, 27.489306466274428,  31.222479928277949,  -69.121157044798309,
       -39.233574944479145, -44.153595068125,    26.853236322194647,  55.10274504435273,   -24.886014191833254,
       44.883144437017265,  28.053130519519925,  -78.925549709043594, 16.347278013087248,  -18.116608876642459,
       66.558599061028048,  -79.815830859342839, -6.0081345212274186, -12.104153629539965, -6.2533814353657533,
       43.225556577377489,  -28.404510850115429, 45.558287161718653,  -4.5828554063021443, -74.277962676941129,
       -51.860093490635052, 35.481285342576399,  -4.2422411255487447, -55.564607929882911, -25.420062872142509,
       17.182274202935588,  -49.320759126112357, 38.148294396310661,  -41.144064269092944, 66.787894727901175,
       -36.950146130237073, 42.480002659430141,  -49.814083713361441, -34.000292309419002, -65.421845810154409,
       12.193500906081113,  29.338118927144478,  7.4548983344516415,  -11.883385300609945, 23.110845029013831,
       23.618820827629492,  28.642680654912311,  21.725873682253379,  71.227858097504225,  -46.570412411836344,
       33.485072433687165,  -42.203107680992545, -60.896600352431122, 17.168630509701543,  -7.9779684854566426,
       -6.6039210161811468, 25.911160304904314,  43.245682368585619,  -23.965117849423194, 25.921535737461525,
       -13.414625604832565, 54.708664430609446,  53.266691052034531,  -38.969441243336433, 18.153717890060051};

const double shift_4[100]
    = {-70.46098118725773,  29.115504663850103,  -73.211017999881335, -68.568725663897226, 3.4639747942853916,
       -64.523195875061276, 50.903768617539953,  50.807534732685809,  35.590334778694768,  -56.021529203525304,
       25.536840465329149,  2.9751908016861108,  75.675928762218007,  23.838638833976972,  48.052892056384223,
       -7.3923666036928779, -10.817359394646132, 52.050207264327298,  -66.644829622573752, -58.692638782854125,
       -52.257821900959115, -17.449951628202314, 53.020758854251142,  48.538302656390442,  -70.324611332817014,
       -16.118756701827891, 4.3001328813273432,  -13.312085131074099, 25.097582555793153,  20.475737470416675,
       -33.282547206125614, -10.935812760204755, -77.522059898236961, 77.450195900664596,  -53.253054413655043,
       -63.005384811413791, -20.414441591114084, -48.301055593124062, -1.6499779174361748, -25.681053857478773,
       72.260874364436319,  67.253126373850193,  -71.571680371073185, 38.057295282719451,  -36.940891776231055,
       -12.346301598590742, 7.6593441943751515,  70.837917484309486,  -13.160943309334044, 77.288394635176985,
       -31.767208206069526, 32.175800944148207,  26.614216253508104,  6.2602344068570659,  31.696883228849345,
       26.644466144413897,  -51.498807295945959, -59.517696044772386, 79.852863161817709,  -52.620629382970861,
       -74.783868715115517, 9.7919668335456151,  61.098640072289584,  27.068048725503004,  -49.530677251207337,
       -20.973352629776812, -6.2838500383341511, 77.062072155319953,  -54.97520764374984,  56.883648935345803,
       23.162325899214068,  -19.796446355386941, -49.452208762191518, -11.479521123298241, -2.876470234902996,
       -60.702141872454035, 14.321197551209437,  -43.80997123957188,  -18.46094010089427,  13.277821239627826,
       -39.711020404429945, -33.529493715683302, 18.734541502915732,  -37.555054430395302, 51.900202670213616,
       77.226143955512043,  36.839806762815627,  -24.979679341602704, 13.451093324552318,  -62.756957561001116,
       65.009304103957277,  60.74459591710476,   50.841689499302703,  -38.283520151125657, 15.097000106292938,
       -76.397985161562914, -11.958508765738415, -29.964978108701516, -54.162440910120004, -51.397410119621085};

const double shift_3[100]
    = {23.090900830990662,  -19.422498774357052, 49.852873325196356,    5.2520942079127764,   -23.883663427698671,
       70.240249919981892,  60.150849838877406,  8.0250148637475434,    19.596013760196399,   13.927152725026687,
       -46.761233162715442, -31.800587155281491, -4.6522642371854914,   -43.121894366150642,  55.089406831262238,
       -48.837713669272119, -43.852515044416194, -52.686712456342626,   -43.573712349351439,  -10.288210543376138,
       -30.223634135933949, 67.740742736519024,  -11.166817387266562,   -50.429388780138225,  64.780954988782867,
       76.759740536973624,  -9.7808042998234868, -62.220924249504193,   -38.709648654069291,  -14.604824621991668,
       15.183371841378289,  -38.04612035506473,  16.45489430113328,     33.794524869389278,   -44.520522557241584,
       -61.213175863071058, -32.531860285067694, -28.995471691858832,   -12.133318445790849,  1.2573255457789116,
       -66.317472465592971, -38.002842448266776, 48.162339643158191,    -75.324755590056597,  68.616662316487151,
       36.85293805687246,   -1.8225641914273325, 12.564009763750221,    -42.03462723655656,   -6.5841874912110256,
       74.094166285906084,  7.4889149982348755,  3.3817329286402469,    -42.94489812663619,   -1.7763609727732899,
       19.84961410779033,   28.661686538519632,  -16.717565493025113,   -21.210136232883755,  78.077120505861245,
       -73.961781401671658, 61.626881312396051,  66.125892422278241,    47.389419773633932,   -64.206035415108119,
       -38.100610580685426, -26.342905605952552, 28.756472220374079,    -58.151498023140853,  35.396399773078429,
       -62.91810214284137,  24.601175786969534,  -0.93217013771678126,  44.648275717004026,   34.405932544111053,
       64.595289689010599,  62.547600692926267,  -26.533911562000597,   31.799333173567121,   -48.350427730251333,
       -75.113448591258134, 39.051881658793974,  0.0035896944321365254, -3.212457416630329,   64.755558090778038,
       17.578663747609355,  18.826622334152745,  57.510768903393966,    48.878307924749691,   12.275442498349619,
       -50.732404893613761, -41.610878309005216, 61.841909292176211,    -75.412135605743032,  -1.6157778380441812,
       -53.131656690838923, 76.588903942585404,  34.031115468626254,    0.075459864774884977, -4.625860073289715};

const double shift_2[100]
    = {-54.05083068908116,  47.085526509425108,  -30.205593272831223, 4.5653016809940397,  -53.496203280035047,
       16.317110624261844,  -37.924594473576917, 24.652655756285156,  30.274320502401238,  39.704254851793507,
       -7.913344239600363,  -66.588579520490782, -43.363685005308987, 66.133977840267136,  -55.619516964924323,
       52.130716398327593,  6.1347896416091316,  79.381554660301674,  -67.491915399490608, -9.171476835928587,
       -62.935556771106498, 73.903692936808596,  -79.258524138549205, 43.98567435384038,   50.768515304549283,
       58.991152858161541,  -66.490264718254352, -16.034776144176561, -38.420735543895326, 48.010956835889203,
       -10.973787605832854, 65.703615108723682,  -50.904475471543606, -37.791533356481594, -56.713763138445273,
       -58.229030606613804, 59.086753222414302,  12.752733978491221,  7.9776322938131159,  -56.807232284203707,
       56.484978835503,     19.528821037610555,  -23.847619057236656, 2.1199263787285361,  -15.710714599689325,
       -67.845329329465301, -41.613415431414715, -60.268970426373514, -50.574753874813325, -41.607595893615553,
       -13.237268946500876, -72.055291147881263, 64.434577586444959,  71.165950355463366,  -1.4617452051072064,
       -1.7195778559969881, -25.964894428579655, 64.008615426825912,  -20.920515020765592, -62.207559152994008,
       44.84033093138207,   -17.641786086199446, -41.329394253786766, -15.374056705901637, -64.567275973057832,
       -58.884273182986391, 70.728094524077619,  72.981526436768377,  12.033375212554489,  -70.435273128455066,
       -42.43521386041499,  -23.49462860446863,  51.391046431673459,  -77.535449975751192, -73.116191734750743,
       -52.961595285967306, 23.858475993032329,  37.075581705387251,  23.639354101809076,  -7.8522069710488154,
       7.5214227658152026,  -32.588671102756294, 39.150849131864987,  -49.767197594792876, 29.884069338450402,
       -50.638215082036844, -21.042464561546161, 20.09896971675046,   44.836389624220288,  -67.019876981474354,
       68.701755354996806,  44.114028577344371,  -2.1133388154924262, -10.262625827052943, -8.5146000912310029,
       -30.984084477350819, 1.3613848609803227,  1.7234502675375438,  50.820433331561929,  47.173026701352484};

const double shift_1[100]
    = {50.355789822908633,   64.926709932099072,  -59.682109393039028, 66.140136982243092,  21.177479396065522,
       -64.393535200094476,  -35.440284981272256, 7.5010430727974153,  73.201093669487619,  74.382165631884249,
       -54.781906931592275,  75.294845081698497,  73.146711718871302,  -2.3398962043454077, 48.044875022208032,
       -57.298185819645546,  -12.518194779796005, 66.517684030250734,  46.7531727295287,    73.518788222864487,
       24.918511865053887,   -74.286131428129664, 55.860688939004348,  69.438919641208088,  28.597624777243752,
       41.238420892533355,   38.901194899986592,  -17.243676874533094, 24.87646242840907,   -52.610129950150117,
       32.9673740831374,     -74.906744579612692, -35.692322406257603, -72.612577499015373, -64.458915002264391,
       51.753252532366815,   31.172579676130724,  -29.264083190262312, 72.035527814136799,  -74.488627119534598,
       -9.8009024549762813,  -18.950646865118657, 42.482686103840379,  47.231984181930102,  -50.100383271299421,
       -1.6376966738830276,  -8.706207886256081,  23.410081617802348,  33.498372937291606,  40.749869117177738,
       -35.835987680227461,  28.752428296587965,  24.815680635814502,  -53.982122368859109, -60.960370950659737,
       -0.26175168285712402, 73.559033362572961,  -25.538283733418687, 13.642840156764379,  -44.190089681418087,
       40.202729488904453,   -39.184781526516943, 0.95312826642278026, 31.852275625069751,  62.544520405727752,
       73.486628032871096,   7.5544847942084914,  -57.820089147411338, -56.112959110550804, -38.79867934020217,
       54.514760957386017,   -39.314851364555032, 50.285572171010614,  -41.036005004001709, 68.682179709956444,
       -24.002597442430599,  -48.544759931006695, -39.826582723835031, 18.567148183462265,  -4.2737841755633212,
       -23.734478869920522,  52.932580463406538,  13.642254584435875,  7.9557773265823215,  66.750986212769618,
       -34.265756988740236,  41.152036657715399,  40.596655084559245,  -19.128664483942934, 10.851462516035383,
       -67.863313669909815,  -71.367981013342856, 4.9276084814356267,  44.666756816321794,  69.441709476669274,
       -59.215006644203179,  11.011785739550831,  -4.8974974306870678, -78.09566887980138,  -26.060376896178958};

std::unordered_map<unsigned, std::unordered_map<unsigned, std::vector<double>>> build_cec2014_rotation_data()
{
    std::unordered_map<unsigned, std::unordered_map<unsigned, std::vector<double>>> retval;

    retval[30].emplace(50, std::vector<double>(std::begin(rot_30_50), std::end(rot_30_50)));
    retval[30].emplace(20, std::vector<double>(std::begin(rot_30_20), std::end(rot_30_20)));
    retval[30].emplace(10, std::vector<double>(std::begin(rot_30_10), std::end(rot_30_10)));
    retval[30].emplace(100, std::vector<double>(std::begin(rot_30_100), std::end(rot_30_100)));
    retval[30].emplace(30, std::vector<double>(std::begin(rot_30_30), std::end(rot_30_30)));
    retval[30].emplace(2, std::vector<double>(std::begin(rot_30_2), std::end(rot_30_2)));
    retval[29].emplace(50, std::vector<double>(std::begin(rot_29_50), std::end(rot_29_50)));
    retval[29].emplace(20, std::vector<double>(std::begin(rot_29_20), std::end(rot_29_20)));
    retval[29].emplace(10, std::vector<double>(std::begin(rot_29_10), std::end(rot_29_10)));
    retval[29].emplace(100, std::vector<double>(std::begin(rot_29_100), std::end(rot_29_100)));
    retval[29].emplace(30, std::vector<double>(std::begin(rot_29_30), std::end(rot_29_30)));
    retval[29].emplace(2, std::vector<double>(std::begin(rot_29_2), std::end(rot_29_2)));
    retval[28].emplace(50, std::vector<double>(std::begin(rot_28_50), std::end(rot_28_50)));
    retval[28].emplace(20, std::vector<double>(std::begin(rot_28_20), std::end(rot_28_20)));
    retval[28].emplace(10, std::vector<double>(std::begin(rot_28_10), std::end(rot_28_10)));
    retval[28].emplace(100, std::vector<double>(std::begin(rot_28_100), std::end(rot_28_100)));
    retval[28].emplace(30, std::vector<double>(std::begin(rot_28_30), std::end(rot_28_30)));
    retval[28].emplace(2, std::vector<double>(std::begin(rot_28_2), std::end(rot_28_2)));
    retval[27].emplace(50, std::vector<double>(std::begin(rot_27_50), std::end(rot_27_50)));
    retval[27].emplace(20, std::vector<double>(std::begin(rot_27_20), std::end(rot_27_20)));
    retval[27].emplace(10, std::vector<double>(std::begin(rot_27_10), std::end(rot_27_10)));
    retval[27].emplace(100, std::vector<double>(std::begin(rot_27_100), std::end(rot_27_100)));
    retval[27].emplace(30, std::vector<double>(std::begin(rot_27_30), std::end(rot_27_30)));
    retval[27].emplace(2, std::vector<double>(std::begin(rot_27_2), std::end(rot_27_2)));
    retval[26].emplace(50, std::vector<double>(std::begin(rot_26_50), std::end(rot_26_50)));
    retval[26].emplace(20, std::vector<double>(std::begin(rot_26_20), std::end(rot_26_20)));
    retval[26].emplace(10, std::vector<double>(std::begin(rot_26_10), std::end(rot_26_10)));
    retval[26].emplace(100, std::vector<double>(std::begin(rot_26_100), std::end(rot_26_100)));
    retval[26].emplace(30, std::vector<double>(std::begin(rot_26_30), std::end(rot_26_30)));
    retval[26].emplace(2, std::vector<double>(std::begin(rot_26_2), std::end(rot_26_2)));
    retval[25].emplace(50, std::vector<double>(std::begin(rot_25_50), std::end(rot_25_50)));
    retval[25].emplace(20, std::vector<double>(std::begin(rot_25_20), std::end(rot_25_20)));
    retval[25].emplace(10, std::vector<double>(std::begin(rot_25_10), std::end(rot_25_10)));
    retval[25].emplace(100, std::vector<double>(std::begin(rot_25_100), std::end(rot_25_100)));
    retval[25].emplace(30, std::vector<double>(std::begin(rot_25_30), std::end(rot_25_30)));
    retval[25].emplace(2, std::vector<double>(std::begin(rot_25_2), std::end(rot_25_2)));
    retval[24].emplace(50, std::vector<double>(std::begin(rot_24_50), std::end(rot_24_50)));
    retval[24].emplace(20, std::vector<double>(std::begin(rot_24_20), std::end(rot_24_20)));
    retval[24].emplace(10, std::vector<double>(std::begin(rot_24_10), std::end(rot_24_10)));
    retval[24].emplace(100, std::vector<double>(std::begin(rot_24_100), std::end(rot_24_100)));
    retval[24].emplace(30, std::vector<double>(std::begin(rot_24_30), std::end(rot_24_30)));
    retval[24].emplace(2, std::vector<double>(std::begin(rot_24_2), std::end(rot_24_2)));
    retval[11].emplace(50, std::vector<double>(std::begin(rot_11_50), std::end(rot_11_50)));
    retval[11].emplace(20, std::vector<double>(std::begin(rot_11_20), std::end(rot_11_20)));
    retval[11].emplace(10, std::vector<double>(std::begin(rot_11_10), std::end(rot_11_10)));
    retval[11].emplace(100, std::vector<double>(std::begin(rot_11_100), std::end(rot_11_100)));
    retval[11].emplace(30, std::vector<double>(std::begin(rot_11_30), std::end(rot_11_30)));
    retval[11].emplace(2, std::vector<double>(std::begin(rot_11_2), std::end(rot_11_2)));
    retval[10].emplace(50, std::vector<double>(std::begin(rot_10_50), std::end(rot_10_50)));
    retval[10].emplace(20, std::vector<double>(std::begin(rot_10_20), std::end(rot_10_20)));
    retval[10].emplace(10, std::vector<double>(std::begin(rot_10_10), std::end(rot_10_10)));
    retval[10].emplace(100, std::vector<double>(std::begin(rot_10_100), std::end(rot_10_100)));
    retval[10].emplace(30, std::vector<double>(std::begin(rot_10_30), std::end(rot_10_30)));
    retval[10].emplace(2, std::vector<double>(std::begin(rot_10_2), std::end(rot_10_2)));
    retval[9].emplace(50, std::vector<double>(std::begin(rot_9_50), std::end(rot_9_50)));
    retval[9].emplace(20, std::vector<double>(std::begin(rot_9_20), std::end(rot_9_20)));
    retval[9].emplace(10, std::vector<double>(std::begin(rot_9_10), std::end(rot_9_10)));
    retval[9].emplace(100, std::vector<double>(std::begin(rot_9_100), std::end(rot_9_100)));
    retval[9].emplace(30, std::vector<double>(std::begin(rot_9_30), std::end(rot_9_30)));
    retval[9].emplace(2, std::vector<double>(std::begin(rot_9_2), std::end(rot_9_2)));
    retval[8].emplace(50, std::vector<double>(std::begin(rot_8_50), std::end(rot_8_50)));
    retval[8].emplace(20, std::vector<double>(std::begin(rot_8_20), std::end(rot_8_20)));
    retval[8].emplace(10, std::vector<double>(std::begin(rot_8_10), std::end(rot_8_10)));
    retval[8].emplace(100, std::vector<double>(std::begin(rot_8_100), std::end(rot_8_100)));
    retval[8].emplace(30, std::vector<double>(std::begin(rot_8_30), std::end(rot_8_30)));
    retval[8].emplace(2, std::vector<double>(std::begin(rot_8_2), std::end(rot_8_2)));
    retval[7].emplace(50, std::vector<double>(std::begin(rot_7_50), std::end(rot_7_50)));
    retval[7].emplace(20, std::vector<double>(std::begin(rot_7_20), std::end(rot_7_20)));
    retval[7].emplace(10, std::vector<double>(std::begin(rot_7_10), std::end(rot_7_10)));
    retval[7].emplace(100, std::vector<double>(std::begin(rot_7_100), std::end(rot_7_100)));
    retval[7].emplace(30, std::vector<double>(std::begin(rot_7_30), std::end(rot_7_30)));
    retval[7].emplace(2, std::vector<double>(std::begin(rot_7_2), std::end(rot_7_2)));
    retval[6].emplace(50, std::vector<double>(std::begin(rot_6_50), std::end(rot_6_50)));
    retval[6].emplace(20, std::vector<double>(std::begin(rot_6_20), std::end(rot_6_20)));
    retval[6].emplace(10, std::vector<double>(std::begin(rot_6_10), std::end(rot_6_10)));
    retval[6].emplace(100, std::vector<double>(std::begin(rot_6_100), std::end(rot_6_100)));
    retval[6].emplace(30, std::vector<double>(std::begin(rot_6_30), std::end(rot_6_30)));
    retval[6].emplace(2, std::vector<double>(std::begin(rot_6_2), std::end(rot_6_2)));
    retval[2].emplace(50, std::vector<double>(std::begin(rot_2_50), std::end(rot_2_50)));
    retval[2].emplace(20, std::vector<double>(std::begin(rot_2_20), std::end(rot_2_20)));
    retval[2].emplace(10, std::vector<double>(std::begin(rot_2_10), std::end(rot_2_10)));
    retval[2].emplace(100, std::vector<double>(std::begin(rot_2_100), std::end(rot_2_100)));
    retval[2].emplace(30, std::vector<double>(std::begin(rot_2_30), std::end(rot_2_30)));
    retval[2].emplace(2, std::vector<double>(std::begin(rot_2_2), std::end(rot_2_2)));
    retval[1].emplace(50, std::vector<double>(std::begin(rot_1_50), std::end(rot_1_50)));
    retval[1].emplace(20, std::vector<double>(std::begin(rot_1_20), std::end(rot_1_20)));
    retval[1].emplace(10, std::vector<double>(std::begin(rot_1_10), std::end(rot_1_10)));
    retval[1].emplace(100, std::vector<double>(std::begin(rot_1_100), std::end(rot_1_100)));
    retval[1].emplace(30, std::vector<double>(std::begin(rot_1_30), std::end(rot_1_30)));
    retval[1].emplace(2, std::vector<double>(std::begin(rot_1_2), std::end(rot_1_2)));
    retval[3].emplace(50, std::vector<double>(std::begin(rot_3_50), std::end(rot_3_50)));
    retval[3].emplace(20, std::vector<double>(std::begin(rot_3_20), std::end(rot_3_20)));
    retval[3].emplace(10, std::vector<double>(std::begin(rot_3_10), std::end(rot_3_10)));
    retval[3].emplace(100, std::vector<double>(std::begin(rot_3_100), std::end(rot_3_100)));
    retval[3].emplace(30, std::vector<double>(std::begin(rot_3_30), std::end(rot_3_30)));
    retval[3].emplace(2, std::vector<double>(std::begin(rot_3_2), std::end(rot_3_2)));
    retval[4].emplace(50, std::vector<double>(std::begin(rot_4_50), std::end(rot_4_50)));
    retval[4].emplace(20, std::vector<double>(std::begin(rot_4_20), std::end(rot_4_20)));
    retval[4].emplace(10, std::vector<double>(std::begin(rot_4_10), std::end(rot_4_10)));
    retval[4].emplace(100, std::vector<double>(std::begin(rot_4_100), std::end(rot_4_100)));
    retval[4].emplace(30, std::vector<double>(std::begin(rot_4_30), std::end(rot_4_30)));
    retval[4].emplace(2, std::vector<double>(std::begin(rot_4_2), std::end(rot_4_2)));
    retval[5].emplace(50, std::vector<double>(std::begin(rot_5_50), std::end(rot_5_50)));
    retval[5].emplace(20, std::vector<double>(std::begin(rot_5_20), std::end(rot_5_20)));
    retval[5].emplace(10, std::vector<double>(std::begin(rot_5_10), std::end(rot_5_10)));
    retval[5].emplace(100, std::vector<double>(std::begin(rot_5_100), std::end(rot_5_100)));
    retval[5].emplace(30, std::vector<double>(std::begin(rot_5_30), std::end(rot_5_30)));
    retval[5].emplace(2, std::vector<double>(std::begin(rot_5_2), std::end(rot_5_2)));
    retval[12].emplace(50, std::vector<double>(std::begin(rot_12_50), std::end(rot_12_50)));
    retval[12].emplace(20, std::vector<double>(std::begin(rot_12_20), std::end(rot_12_20)));
    retval[12].emplace(10, std::vector<double>(std::begin(rot_12_10), std::end(rot_12_10)));
    retval[12].emplace(100, std::vector<double>(std::begin(rot_12_100), std::end(rot_12_100)));
    retval[12].emplace(30, std::vector<double>(std::begin(rot_12_30), std::end(rot_12_30)));
    retval[12].emplace(2, std::vector<double>(std::begin(rot_12_2), std::end(rot_12_2)));
    retval[13].emplace(50, std::vector<double>(std::begin(rot_13_50), std::end(rot_13_50)));
    retval[13].emplace(20, std::vector<double>(std::begin(rot_13_20), std::end(rot_13_20)));
    retval[13].emplace(10, std::vector<double>(std::begin(rot_13_10), std::end(rot_13_10)));
    retval[13].emplace(100, std::vector<double>(std::begin(rot_13_100), std::end(rot_13_100)));
    retval[13].emplace(30, std::vector<double>(std::begin(rot_13_30), std::end(rot_13_30)));
    retval[13].emplace(2, std::vector<double>(std::begin(rot_13_2), std::end(rot_13_2)));
    retval[14].emplace(50, std::vector<double>(std::begin(rot_14_50), std::end(rot_14_50)));
    retval[14].emplace(20, std::vector<double>(std::begin(rot_14_20), std::end(rot_14_20)));
    retval[14].emplace(10, std::vector<double>(std::begin(rot_14_10), std::end(rot_14_10)));
    retval[14].emplace(100, std::vector<double>(std::begin(rot_14_100), std::end(rot_14_100)));
    retval[14].emplace(30, std::vector<double>(std::begin(rot_14_30), std::end(rot_14_30)));
    retval[14].emplace(2, std::vector<double>(std::begin(rot_14_2), std::end(rot_14_2)));
    retval[15].emplace(50, std::vector<double>(std::begin(rot_15_50), std::end(rot_15_50)));
    retval[15].emplace(20, std::vector<double>(std::begin(rot_15_20), std::end(rot_15_20)));
    retval[15].emplace(10, std::vector<double>(std::begin(rot_15_10), std::end(rot_15_10)));
    retval[15].emplace(100, std::vector<double>(std::begin(rot_15_100), std::end(rot_15_100)));
    retval[15].emplace(30, std::vector<double>(std::begin(rot_15_30), std::end(rot_15_30)));
    retval[15].emplace(2, std::vector<double>(std::begin(rot_15_2), std::end(rot_15_2)));
    retval[16].emplace(50, std::vector<double>(std::begin(rot_16_50), std::end(rot_16_50)));
    retval[16].emplace(20, std::vector<double>(std::begin(rot_16_20), std::end(rot_16_20)));
    retval[16].emplace(10, std::vector<double>(std::begin(rot_16_10), std::end(rot_16_10)));
    retval[16].emplace(100, std::vector<double>(std::begin(rot_16_100), std::end(rot_16_100)));
    retval[16].emplace(30, std::vector<double>(std::begin(rot_16_30), std::end(rot_16_30)));
    retval[16].emplace(2, std::vector<double>(std::begin(rot_16_2), std::end(rot_16_2)));
    retval[17].emplace(50, std::vector<double>(std::begin(rot_17_50), std::end(rot_17_50)));
    retval[17].emplace(20, std::vector<double>(std::begin(rot_17_20), std::end(rot_17_20)));
    retval[17].emplace(10, std::vector<double>(std::begin(rot_17_10), std::end(rot_17_10)));
    retval[17].emplace(100, std::vector<double>(std::begin(rot_17_100), std::end(rot_17_100)));
    retval[17].emplace(30, std::vector<double>(std::begin(rot_17_30), std::end(rot_17_30)));
    retval[17].emplace(2, std::vector<double>(std::begin(rot_17_2), std::end(rot_17_2)));
    retval[18].emplace(50, std::vector<double>(std::begin(rot_18_50), std::end(rot_18_50)));
    retval[18].emplace(20, std::vector<double>(std::begin(rot_18_20), std::end(rot_18_20)));
    retval[18].emplace(10, std::vector<double>(std::begin(rot_18_10), std::end(rot_18_10)));
    retval[18].emplace(100, std::vector<double>(std::begin(rot_18_100), std::end(rot_18_100)));
    retval[18].emplace(30, std::vector<double>(std::begin(rot_18_30), std::end(rot_18_30)));
    retval[18].emplace(2, std::vector<double>(std::begin(rot_18_2), std::end(rot_18_2)));
    retval[19].emplace(50, std::vector<double>(std::begin(rot_19_50), std::end(rot_19_50)));
    retval[19].emplace(20, std::vector<double>(std::begin(rot_19_20), std::end(rot_19_20)));
    retval[19].emplace(10, std::vector<double>(std::begin(rot_19_10), std::end(rot_19_10)));
    retval[19].emplace(100, std::vector<double>(std::begin(rot_19_100), std::end(rot_19_100)));
    retval[19].emplace(30, std::vector<double>(std::begin(rot_19_30), std::end(rot_19_30)));
    retval[19].emplace(2, std::vector<double>(std::begin(rot_19_2), std::end(rot_19_2)));
    retval[20].emplace(50, std::vector<double>(std::begin(rot_20_50), std::end(rot_20_50)));
    retval[20].emplace(20, std::vector<double>(std::begin(rot_20_20), std::end(rot_20_20)));
    retval[20].emplace(10, std::vector<double>(std::begin(rot_20_10), std::end(rot_20_10)));
    retval[20].emplace(100, std::vector<double>(std::begin(rot_20_100), std::end(rot_20_100)));
    retval[20].emplace(30, std::vector<double>(std::begin(rot_20_30), std::end(rot_20_30)));
    retval[20].emplace(2, std::vector<double>(std::begin(rot_20_2), std::end(rot_20_2)));
    retval[21].emplace(50, std::vector<double>(std::begin(rot_21_50), std::end(rot_21_50)));
    retval[21].emplace(20, std::vector<double>(std::begin(rot_21_20), std::end(rot_21_20)));
    retval[21].emplace(10, std::vector<double>(std::begin(rot_21_10), std::end(rot_21_10)));
    retval[21].emplace(100, std::vector<double>(std::begin(rot_21_100), std::end(rot_21_100)));
    retval[21].emplace(30, std::vector<double>(std::begin(rot_21_30), std::end(rot_21_30)));
    retval[21].emplace(2, std::vector<double>(std::begin(rot_21_2), std::end(rot_21_2)));
    retval[22].emplace(50, std::vector<double>(std::begin(rot_22_50), std::end(rot_22_50)));
    retval[22].emplace(20, std::vector<double>(std::begin(rot_22_20), std::end(rot_22_20)));
    retval[22].emplace(10, std::vector<double>(std::begin(rot_22_10), std::end(rot_22_10)));
    retval[22].emplace(100, std::vector<double>(std::begin(rot_22_100), std::end(rot_22_100)));
    retval[22].emplace(30, std::vector<double>(std::begin(rot_22_30), std::end(rot_22_30)));
    retval[22].emplace(2, std::vector<double>(std::begin(rot_22_2), std::end(rot_22_2)));
    retval[23].emplace(50, std::vector<double>(std::begin(rot_23_50), std::end(rot_23_50)));
    retval[23].emplace(20, std::vector<double>(std::begin(rot_23_20), std::end(rot_23_20)));
    retval[23].emplace(10, std::vector<double>(std::begin(rot_23_10), std::end(rot_23_10)));
    retval[23].emplace(100, std::vector<double>(std::begin(rot_23_100), std::end(rot_23_100)));
    retval[23].emplace(30, std::vector<double>(std::begin(rot_23_30), std::end(rot_23_30)));
    retval[23].emplace(2, std::vector<double>(std::begin(rot_23_2), std::end(rot_23_2)));

    return retval;
}

std::unordered_map<unsigned, std::unordered_map<unsigned, std::vector<int>>> build_cec2014_shuffle_data()
{
    std::unordered_map<unsigned, std::unordered_map<unsigned, std::vector<int>>> retval;

    retval[22].emplace(100, std::vector<int>(std::begin(shuffle_22_100), std::end(shuffle_22_100)));
    retval[22].emplace(50, std::vector<int>(std::begin(shuffle_22_50), std::end(shuffle_22_50)));
    retval[22].emplace(30, std::vector<int>(std::begin(shuffle_22_30), std::end(shuffle_22_30)));
    retval[22].emplace(20, std::vector<int>(std::begin(shuffle_22_20), std::end(shuffle_22_20)));
    retval[22].emplace(10, std::vector<int>(std::begin(shuffle_22_10), std::end(shuffle_22_10)));
    retval[21].emplace(100, std::vector<int>(std::begin(shuffle_21_100), std::end(shuffle_21_100)));
    retval[21].emplace(50, std::vector<int>(std::begin(shuffle_21_50), std::end(shuffle_21_50)));
    retval[21].emplace(30, std::vector<int>(std::begin(shuffle_21_30), std::end(shuffle_21_30)));
    retval[21].emplace(20, std::vector<int>(std::begin(shuffle_21_20), std::end(shuffle_21_20)));
    retval[21].emplace(10, std::vector<int>(std::begin(shuffle_21_10), std::end(shuffle_21_10)));
    retval[20].emplace(100, std::vector<int>(std::begin(shuffle_20_100), std::end(shuffle_20_100)));
    retval[20].emplace(50, std::vector<int>(std::begin(shuffle_20_50), std::end(shuffle_20_50)));
    retval[20].emplace(30, std::vector<int>(std::begin(shuffle_20_30), std::end(shuffle_20_30)));
    retval[20].emplace(20, std::vector<int>(std::begin(shuffle_20_20), std::end(shuffle_20_20)));
    retval[20].emplace(10, std::vector<int>(std::begin(shuffle_20_10), std::end(shuffle_20_10)));
    retval[30].emplace(100, std::vector<int>(std::begin(shuffle_30_100), std::end(shuffle_30_100)));
    retval[30].emplace(50, std::vector<int>(std::begin(shuffle_30_50), std::end(shuffle_30_50)));
    retval[30].emplace(30, std::vector<int>(std::begin(shuffle_30_30), std::end(shuffle_30_30)));
    retval[30].emplace(20, std::vector<int>(std::begin(shuffle_30_20), std::end(shuffle_30_20)));
    retval[30].emplace(10, std::vector<int>(std::begin(shuffle_30_10), std::end(shuffle_30_10)));
    retval[19].emplace(100, std::vector<int>(std::begin(shuffle_19_100), std::end(shuffle_19_100)));
    retval[19].emplace(50, std::vector<int>(std::begin(shuffle_19_50), std::end(shuffle_19_50)));
    retval[19].emplace(30, std::vector<int>(std::begin(shuffle_19_30), std::end(shuffle_19_30)));
    retval[19].emplace(20, std::vector<int>(std::begin(shuffle_19_20), std::end(shuffle_19_20)));
    retval[19].emplace(10, std::vector<int>(std::begin(shuffle_19_10), std::end(shuffle_19_10)));
    retval[29].emplace(100, std::vector<int>(std::begin(shuffle_29_100), std::end(shuffle_29_100)));
    retval[29].emplace(50, std::vector<int>(std::begin(shuffle_29_50), std::end(shuffle_29_50)));
    retval[29].emplace(30, std::vector<int>(std::begin(shuffle_29_30), std::end(shuffle_29_30)));
    retval[29].emplace(20, std::vector<int>(std::begin(shuffle_29_20), std::end(shuffle_29_20)));
    retval[29].emplace(10, std::vector<int>(std::begin(shuffle_29_10), std::end(shuffle_29_10)));
    retval[18].emplace(100, std::vector<int>(std::begin(shuffle_18_100), std::end(shuffle_18_100)));
    retval[18].emplace(50, std::vector<int>(std::begin(shuffle_18_50), std::end(shuffle_18_50)));
    retval[18].emplace(30, std::vector<int>(std::begin(shuffle_18_30), std::end(shuffle_18_30)));
    retval[18].emplace(20, std::vector<int>(std::begin(shuffle_18_20), std::end(shuffle_18_20)));
    retval[18].emplace(10, std::vector<int>(std::begin(shuffle_18_10), std::end(shuffle_18_10)));
    retval[17].emplace(100, std::vector<int>(std::begin(shuffle_17_100), std::end(shuffle_17_100)));
    retval[17].emplace(50, std::vector<int>(std::begin(shuffle_17_50), std::end(shuffle_17_50)));
    retval[17].emplace(30, std::vector<int>(std::begin(shuffle_17_30), std::end(shuffle_17_30)));
    retval[17].emplace(20, std::vector<int>(std::begin(shuffle_17_20), std::end(shuffle_17_20)));
    retval[17].emplace(10, std::vector<int>(std::begin(shuffle_17_10), std::end(shuffle_17_10)));

    return retval;
}

std::unordered_map<unsigned, std::vector<double>> build_cec2014_shift_data()
{
    std::unordered_map<unsigned, std::vector<double>> retval;
    retval.emplace(30, std::vector<double>(std::begin(shift_30), std::end(shift_30)));
    retval.emplace(29, std::vector<double>(std::begin(shift_29), std::end(shift_29)));
    retval.emplace(28, std::vector<double>(std::begin(shift_28), std::end(shift_28)));
    retval.emplace(27, std::vector<double>(std::begin(shift_27), std::end(shift_27)));
    retval.emplace(26, std::vector<double>(std::begin(shift_26), std::end(shift_26)));
    retval.emplace(25, std::vector<double>(std::begin(shift_25), std::end(shift_25)));
    retval.emplace(24, std::vector<double>(std::begin(shift_24), std::end(shift_24)));
    retval.emplace(23, std::vector<double>(std::begin(shift_23), std::end(shift_23)));
    retval.emplace(22, std::vector<double>(std::begin(shift_22), std::end(shift_22)));
    retval.emplace(21, std::vector<double>(std::begin(shift_21), std::end(shift_21)));
    retval.emplace(20, std::vector<double>(std::begin(shift_20), std::end(shift_20)));
    retval.emplace(19, std::vector<double>(std::begin(shift_19), std::end(shift_19)));
    retval.emplace(18, std::vector<double>(std::begin(shift_18), std::end(shift_18)));
    retval.emplace(17, std::vector<double>(std::begin(shift_17), std::end(shift_17)));
    retval.emplace(16, std::vector<double>(std::begin(shift_16), std::end(shift_16)));
    retval.emplace(15, std::vector<double>(std::begin(shift_15), std::end(shift_15)));
    retval.emplace(14, std::vector<double>(std::begin(shift_14), std::end(shift_14)));
    retval.emplace(13, std::vector<double>(std::begin(shift_13), std::end(shift_13)));
    retval.emplace(12, std::vector<double>(std::begin(shift_12), std::end(shift_12)));
    retval.emplace(11, std::vector<double>(std::begin(shift_11), std::end(shift_11)));
    retval.emplace(10, std::vector<double>(std::begin(shift_10), std::end(shift_10)));
    retval.emplace(9, std::vector<double>(std::begin(shift_9), std::end(shift_9)));
    retval.emplace(8, std::vector<double>(std::begin(shift_8), std::end(shift_8)));
    retval.emplace(7, std::vector<double>(std::begin(shift_7), std::end(shift_7)));
    retval.emplace(6, std::vector<double>(std::begin(shift_6), std::end(shift_6)));
    retval.emplace(5, std::vector<double>(std::begin(shift_5), std::end(shift_5)));
    retval.emplace(4, std::vector<double>(std::begin(shift_4), std::end(shift_4)));
    retval.emplace(3, std::vector<double>(std::begin(shift_3), std::end(shift_3)));
    retval.emplace(2, std::vector<double>(std::begin(shift_2), std::end(shift_2)));
    retval.emplace(1, std::vector<double>(std::begin(shift_1), std::end(shift_1)));

    return retval;
}

} // namespace

const std::unordered_map<unsigned, std::unordered_map<unsigned, std::vector<double>>> rotation_data
    = build_cec2014_rotation_data();
const std::unordered_map<unsigned, std::unordered_map<unsigned, std::vector<int>>> shuffle_data
    = build_cec2014_shuffle_data();
const std::unordered_map<unsigned, std::vector<double>> shift_data = build_cec2014_shift_data();

} // namespace cec2014_data

} // namespace detail

} // namespace pagmo
